#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __commonJS = (cb, mod) => function __require() {
  return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// node_modules/commander/lib/error.js
var require_error = __commonJS({
  "node_modules/commander/lib/error.js"(exports) {
    var CommanderError = class extends Error {
      /**
       * Constructs the CommanderError class
       * @param {number} exitCode suggested exit code which could be used with process.exit
       * @param {string} code an id string representing the error
       * @param {string} message human-readable description of the error
       * @constructor
       */
      constructor(exitCode, code, message) {
        super(message);
        Error.captureStackTrace(this, this.constructor);
        this.name = this.constructor.name;
        this.code = code;
        this.exitCode = exitCode;
        this.nestedError = void 0;
      }
    };
    var InvalidArgumentError = class extends CommanderError {
      /**
       * Constructs the InvalidArgumentError class
       * @param {string} [message] explanation of why argument is invalid
       * @constructor
       */
      constructor(message) {
        super(1, "commander.invalidArgument", message);
        Error.captureStackTrace(this, this.constructor);
        this.name = this.constructor.name;
      }
    };
    exports.CommanderError = CommanderError;
    exports.InvalidArgumentError = InvalidArgumentError;
  }
});

// node_modules/commander/lib/argument.js
var require_argument = __commonJS({
  "node_modules/commander/lib/argument.js"(exports) {
    var { InvalidArgumentError } = require_error();
    var Argument = class {
      /**
       * Initialize a new command argument with the given name and description.
       * The default is that the argument is required, and you can explicitly
       * indicate this with <> around the name. Put [] around the name for an optional argument.
       *
       * @param {string} name
       * @param {string} [description]
       */
      constructor(name, description) {
        this.description = description || "";
        this.variadic = false;
        this.parseArg = void 0;
        this.defaultValue = void 0;
        this.defaultValueDescription = void 0;
        this.argChoices = void 0;
        switch (name[0]) {
          case "<":
            this.required = true;
            this._name = name.slice(1, -1);
            break;
          case "[":
            this.required = false;
            this._name = name.slice(1, -1);
            break;
          default:
            this.required = true;
            this._name = name;
            break;
        }
        if (this._name.length > 3 && this._name.slice(-3) === "...") {
          this.variadic = true;
          this._name = this._name.slice(0, -3);
        }
      }
      /**
       * Return argument name.
       *
       * @return {string}
       */
      name() {
        return this._name;
      }
      /**
       * @api private
       */
      _concatValue(value2, previous) {
        if (previous === this.defaultValue || !Array.isArray(previous)) {
          return [value2];
        }
        return previous.concat(value2);
      }
      /**
       * Set the default value, and optionally supply the description to be displayed in the help.
       *
       * @param {any} value
       * @param {string} [description]
       * @return {Argument}
       */
      default(value2, description) {
        this.defaultValue = value2;
        this.defaultValueDescription = description;
        return this;
      }
      /**
       * Set the custom handler for processing CLI command arguments into argument values.
       *
       * @param {Function} [fn]
       * @return {Argument}
       */
      argParser(fn) {
        this.parseArg = fn;
        return this;
      }
      /**
       * Only allow option value to be one of choices.
       *
       * @param {string[]} values
       * @return {Argument}
       */
      choices(values2) {
        this.argChoices = values2;
        this.parseArg = (arg, previous) => {
          if (!values2.includes(arg)) {
            throw new InvalidArgumentError(`Allowed choices are ${values2.join(", ")}.`);
          }
          if (this.variadic) {
            return this._concatValue(arg, previous);
          }
          return arg;
        };
        return this;
      }
      /**
       * Make option-argument required.
       */
      argRequired() {
        this.required = true;
        return this;
      }
      /**
       * Make option-argument optional.
       */
      argOptional() {
        this.required = false;
        return this;
      }
    };
    function humanReadableArgName(arg) {
      const nameOutput = arg.name() + (arg.variadic === true ? "..." : "");
      return arg.required ? "<" + nameOutput + ">" : "[" + nameOutput + "]";
    }
    exports.Argument = Argument;
    exports.humanReadableArgName = humanReadableArgName;
  }
});

// node_modules/commander/lib/help.js
var require_help = __commonJS({
  "node_modules/commander/lib/help.js"(exports) {
    var { humanReadableArgName } = require_argument();
    var Help = class {
      constructor() {
        this.helpWidth = void 0;
        this.sortSubcommands = false;
        this.sortOptions = false;
      }
      /**
       * Get an array of the visible subcommands. Includes a placeholder for the implicit help command, if there is one.
       *
       * @param {Command} cmd
       * @returns {Command[]}
       */
      visibleCommands(cmd) {
        const visibleCommands = cmd.commands.filter((cmd2) => !cmd2._hidden);
        if (cmd._hasImplicitHelpCommand()) {
          const [, helpName, helpArgs] = cmd._helpCommandnameAndArgs.match(/([^ ]+) *(.*)/);
          const helpCommand = cmd.createCommand(helpName).helpOption(false);
          helpCommand.description(cmd._helpCommandDescription);
          if (helpArgs)
            helpCommand.arguments(helpArgs);
          visibleCommands.push(helpCommand);
        }
        if (this.sortSubcommands) {
          visibleCommands.sort((a, b) => {
            return a.name().localeCompare(b.name());
          });
        }
        return visibleCommands;
      }
      /**
       * Get an array of the visible options. Includes a placeholder for the implicit help option, if there is one.
       *
       * @param {Command} cmd
       * @returns {Option[]}
       */
      visibleOptions(cmd) {
        const visibleOptions = cmd.options.filter((option) => !option.hidden);
        const showShortHelpFlag = cmd._hasHelpOption && cmd._helpShortFlag && !cmd._findOption(cmd._helpShortFlag);
        const showLongHelpFlag = cmd._hasHelpOption && !cmd._findOption(cmd._helpLongFlag);
        if (showShortHelpFlag || showLongHelpFlag) {
          let helpOption;
          if (!showShortHelpFlag) {
            helpOption = cmd.createOption(cmd._helpLongFlag, cmd._helpDescription);
          } else if (!showLongHelpFlag) {
            helpOption = cmd.createOption(cmd._helpShortFlag, cmd._helpDescription);
          } else {
            helpOption = cmd.createOption(cmd._helpFlags, cmd._helpDescription);
          }
          visibleOptions.push(helpOption);
        }
        if (this.sortOptions) {
          const getSortKey = (option) => {
            return option.short ? option.short.replace(/^-/, "") : option.long.replace(/^--/, "");
          };
          visibleOptions.sort((a, b) => {
            return getSortKey(a).localeCompare(getSortKey(b));
          });
        }
        return visibleOptions;
      }
      /**
       * Get an array of the arguments if any have a description.
       *
       * @param {Command} cmd
       * @returns {Argument[]}
       */
      visibleArguments(cmd) {
        if (cmd._argsDescription) {
          cmd._args.forEach((argument) => {
            argument.description = argument.description || cmd._argsDescription[argument.name()] || "";
          });
        }
        if (cmd._args.find((argument) => argument.description)) {
          return cmd._args;
        }
        ;
        return [];
      }
      /**
       * Get the command term to show in the list of subcommands.
       *
       * @param {Command} cmd
       * @returns {string}
       */
      subcommandTerm(cmd) {
        const args = cmd._args.map((arg) => humanReadableArgName(arg)).join(" ");
        return cmd._name + (cmd._aliases[0] ? "|" + cmd._aliases[0] : "") + (cmd.options.length ? " [options]" : "") + // simplistic check for non-help option
        (args ? " " + args : "");
      }
      /**
       * Get the option term to show in the list of options.
       *
       * @param {Option} option
       * @returns {string}
       */
      optionTerm(option) {
        return option.flags;
      }
      /**
       * Get the argument term to show in the list of arguments.
       *
       * @param {Argument} argument
       * @returns {string}
       */
      argumentTerm(argument) {
        return argument.name();
      }
      /**
       * Get the longest command term length.
       *
       * @param {Command} cmd
       * @param {Help} helper
       * @returns {number}
       */
      longestSubcommandTermLength(cmd, helper) {
        return helper.visibleCommands(cmd).reduce((max2, command) => {
          return Math.max(max2, helper.subcommandTerm(command).length);
        }, 0);
      }
      /**
       * Get the longest option term length.
       *
       * @param {Command} cmd
       * @param {Help} helper
       * @returns {number}
       */
      longestOptionTermLength(cmd, helper) {
        return helper.visibleOptions(cmd).reduce((max2, option) => {
          return Math.max(max2, helper.optionTerm(option).length);
        }, 0);
      }
      /**
       * Get the longest argument term length.
       *
       * @param {Command} cmd
       * @param {Help} helper
       * @returns {number}
       */
      longestArgumentTermLength(cmd, helper) {
        return helper.visibleArguments(cmd).reduce((max2, argument) => {
          return Math.max(max2, helper.argumentTerm(argument).length);
        }, 0);
      }
      /**
       * Get the command usage to be displayed at the top of the built-in help.
       *
       * @param {Command} cmd
       * @returns {string}
       */
      commandUsage(cmd) {
        let cmdName = cmd._name;
        if (cmd._aliases[0]) {
          cmdName = cmdName + "|" + cmd._aliases[0];
        }
        let parentCmdNames = "";
        for (let parentCmd = cmd.parent; parentCmd; parentCmd = parentCmd.parent) {
          parentCmdNames = parentCmd.name() + " " + parentCmdNames;
        }
        return parentCmdNames + cmdName + " " + cmd.usage();
      }
      /**
       * Get the description for the command.
       *
       * @param {Command} cmd
       * @returns {string}
       */
      commandDescription(cmd) {
        return cmd.description();
      }
      /**
       * Get the command description to show in the list of subcommands.
       *
       * @param {Command} cmd
       * @returns {string}
       */
      subcommandDescription(cmd) {
        return cmd.description();
      }
      /**
       * Get the option description to show in the list of options.
       *
       * @param {Option} option
       * @return {string}
       */
      optionDescription(option) {
        const extraInfo = [];
        if (option.argChoices && !option.negate) {
          extraInfo.push(
            // use stringify to match the display of the default value
            `choices: ${option.argChoices.map((choice) => JSON.stringify(choice)).join(", ")}`
          );
        }
        if (option.defaultValue !== void 0 && !option.negate) {
          extraInfo.push(`default: ${option.defaultValueDescription || JSON.stringify(option.defaultValue)}`);
        }
        if (option.envVar !== void 0) {
          extraInfo.push(`env: ${option.envVar}`);
        }
        if (extraInfo.length > 0) {
          return `${option.description} (${extraInfo.join(", ")})`;
        }
        return option.description;
      }
      /**
       * Get the argument description to show in the list of arguments.
       *
       * @param {Argument} argument
       * @return {string}
       */
      argumentDescription(argument) {
        const extraInfo = [];
        if (argument.argChoices) {
          extraInfo.push(
            // use stringify to match the display of the default value
            `choices: ${argument.argChoices.map((choice) => JSON.stringify(choice)).join(", ")}`
          );
        }
        if (argument.defaultValue !== void 0) {
          extraInfo.push(`default: ${argument.defaultValueDescription || JSON.stringify(argument.defaultValue)}`);
        }
        if (extraInfo.length > 0) {
          const extraDescripton = `(${extraInfo.join(", ")})`;
          if (argument.description) {
            return `${argument.description} ${extraDescripton}`;
          }
          return extraDescripton;
        }
        return argument.description;
      }
      /**
       * Generate the built-in help text.
       *
       * @param {Command} cmd
       * @param {Help} helper
       * @returns {string}
       */
      formatHelp(cmd, helper) {
        const termWidth = helper.padWidth(cmd, helper);
        const helpWidth = helper.helpWidth || 80;
        const itemIndentWidth = 2;
        const itemSeparatorWidth = 2;
        function formatItem(term, description) {
          if (description) {
            const fullText = `${term.padEnd(termWidth + itemSeparatorWidth)}${description}`;
            return helper.wrap(fullText, helpWidth - itemIndentWidth, termWidth + itemSeparatorWidth);
          }
          return term;
        }
        ;
        function formatList(textArray) {
          return textArray.join("\n").replace(/^/gm, " ".repeat(itemIndentWidth));
        }
        let output = [`Usage: ${helper.commandUsage(cmd)}`, ""];
        const commandDescription = helper.commandDescription(cmd);
        if (commandDescription.length > 0) {
          output = output.concat([commandDescription, ""]);
        }
        const argumentList = helper.visibleArguments(cmd).map((argument) => {
          return formatItem(helper.argumentTerm(argument), helper.argumentDescription(argument));
        });
        if (argumentList.length > 0) {
          output = output.concat(["Arguments:", formatList(argumentList), ""]);
        }
        const optionList = helper.visibleOptions(cmd).map((option) => {
          return formatItem(helper.optionTerm(option), helper.optionDescription(option));
        });
        if (optionList.length > 0) {
          output = output.concat(["Options:", formatList(optionList), ""]);
        }
        const commandList = helper.visibleCommands(cmd).map((cmd2) => {
          return formatItem(helper.subcommandTerm(cmd2), helper.subcommandDescription(cmd2));
        });
        if (commandList.length > 0) {
          output = output.concat(["Commands:", formatList(commandList), ""]);
        }
        return output.join("\n");
      }
      /**
       * Calculate the pad width from the maximum term length.
       *
       * @param {Command} cmd
       * @param {Help} helper
       * @returns {number}
       */
      padWidth(cmd, helper) {
        return Math.max(
          helper.longestOptionTermLength(cmd, helper),
          helper.longestSubcommandTermLength(cmd, helper),
          helper.longestArgumentTermLength(cmd, helper)
        );
      }
      /**
       * Wrap the given string to width characters per line, with lines after the first indented.
       * Do not wrap if insufficient room for wrapping (minColumnWidth), or string is manually formatted.
       *
       * @param {string} str
       * @param {number} width
       * @param {number} indent
       * @param {number} [minColumnWidth=40]
       * @return {string}
       *
       */
      wrap(str, width, indent, minColumnWidth = 40) {
        if (str.match(/[\n]\s+/))
          return str;
        const columnWidth = width - indent;
        if (columnWidth < minColumnWidth)
          return str;
        const leadingStr = str.substr(0, indent);
        const columnText = str.substr(indent);
        const indentString = " ".repeat(indent);
        const regex = new RegExp(".{1," + (columnWidth - 1) + "}([\\s\u200B]|$)|[^\\s\u200B]+?([\\s\u200B]|$)", "g");
        const lines = columnText.match(regex) || [];
        return leadingStr + lines.map((line, i) => {
          if (line.slice(-1) === "\n") {
            line = line.slice(0, line.length - 1);
          }
          return (i > 0 ? indentString : "") + line.trimRight();
        }).join("\n");
      }
    };
    exports.Help = Help;
  }
});

// node_modules/commander/lib/option.js
var require_option = __commonJS({
  "node_modules/commander/lib/option.js"(exports) {
    var { InvalidArgumentError } = require_error();
    var Option = class {
      /**
       * Initialize a new `Option` with the given `flags` and `description`.
       *
       * @param {string} flags
       * @param {string} [description]
       */
      constructor(flags, description) {
        this.flags = flags;
        this.description = description || "";
        this.required = flags.includes("<");
        this.optional = flags.includes("[");
        this.variadic = /\w\.\.\.[>\]]$/.test(flags);
        this.mandatory = false;
        const optionFlags = splitOptionFlags(flags);
        this.short = optionFlags.shortFlag;
        this.long = optionFlags.longFlag;
        this.negate = false;
        if (this.long) {
          this.negate = this.long.startsWith("--no-");
        }
        this.defaultValue = void 0;
        this.defaultValueDescription = void 0;
        this.envVar = void 0;
        this.parseArg = void 0;
        this.hidden = false;
        this.argChoices = void 0;
      }
      /**
       * Set the default value, and optionally supply the description to be displayed in the help.
       *
       * @param {any} value
       * @param {string} [description]
       * @return {Option}
       */
      default(value2, description) {
        this.defaultValue = value2;
        this.defaultValueDescription = description;
        return this;
      }
      /**
       * Set environment variable to check for option value.
       * Priority order of option values is default < env < cli
       *
       * @param {string} name
       * @return {Option}
       */
      env(name) {
        this.envVar = name;
        return this;
      }
      /**
       * Set the custom handler for processing CLI option arguments into option values.
       *
       * @param {Function} [fn]
       * @return {Option}
       */
      argParser(fn) {
        this.parseArg = fn;
        return this;
      }
      /**
       * Whether the option is mandatory and must have a value after parsing.
       *
       * @param {boolean} [mandatory=true]
       * @return {Option}
       */
      makeOptionMandatory(mandatory = true) {
        this.mandatory = !!mandatory;
        return this;
      }
      /**
       * Hide option in help.
       *
       * @param {boolean} [hide=true]
       * @return {Option}
       */
      hideHelp(hide = true) {
        this.hidden = !!hide;
        return this;
      }
      /**
       * @api private
       */
      _concatValue(value2, previous) {
        if (previous === this.defaultValue || !Array.isArray(previous)) {
          return [value2];
        }
        return previous.concat(value2);
      }
      /**
       * Only allow option value to be one of choices.
       *
       * @param {string[]} values
       * @return {Option}
       */
      choices(values2) {
        this.argChoices = values2;
        this.parseArg = (arg, previous) => {
          if (!values2.includes(arg)) {
            throw new InvalidArgumentError(`Allowed choices are ${values2.join(", ")}.`);
          }
          if (this.variadic) {
            return this._concatValue(arg, previous);
          }
          return arg;
        };
        return this;
      }
      /**
       * Return option name.
       *
       * @return {string}
       */
      name() {
        if (this.long) {
          return this.long.replace(/^--/, "");
        }
        return this.short.replace(/^-/, "");
      }
      /**
       * Return option name, in a camelcase format that can be used
       * as a object attribute key.
       *
       * @return {string}
       * @api private
       */
      attributeName() {
        return camelcase(this.name().replace(/^no-/, ""));
      }
      /**
       * Check if `arg` matches the short or long flag.
       *
       * @param {string} arg
       * @return {boolean}
       * @api private
       */
      is(arg) {
        return this.short === arg || this.long === arg;
      }
    };
    function camelcase(str) {
      return str.split("-").reduce((str2, word) => {
        return str2 + word[0].toUpperCase() + word.slice(1);
      });
    }
    function splitOptionFlags(flags) {
      let shortFlag;
      let longFlag;
      const flagParts = flags.split(/[ |,]+/);
      if (flagParts.length > 1 && !/^[[<]/.test(flagParts[1]))
        shortFlag = flagParts.shift();
      longFlag = flagParts.shift();
      if (!shortFlag && /^-[^-]$/.test(longFlag)) {
        shortFlag = longFlag;
        longFlag = void 0;
      }
      return { shortFlag, longFlag };
    }
    exports.Option = Option;
    exports.splitOptionFlags = splitOptionFlags;
  }
});

// node_modules/commander/lib/suggestSimilar.js
var require_suggestSimilar = __commonJS({
  "node_modules/commander/lib/suggestSimilar.js"(exports) {
    var maxDistance = 3;
    function editDistance(a, b) {
      if (Math.abs(a.length - b.length) > maxDistance)
        return Math.max(a.length, b.length);
      const d = [];
      for (let i = 0; i <= a.length; i++) {
        d[i] = [i];
      }
      for (let j = 0; j <= b.length; j++) {
        d[0][j] = j;
      }
      for (let j = 1; j <= b.length; j++) {
        for (let i = 1; i <= a.length; i++) {
          let cost = 1;
          if (a[i - 1] === b[j - 1]) {
            cost = 0;
          } else {
            cost = 1;
          }
          d[i][j] = Math.min(
            d[i - 1][j] + 1,
            // deletion
            d[i][j - 1] + 1,
            // insertion
            d[i - 1][j - 1] + cost
            // substitution
          );
          if (i > 1 && j > 1 && a[i - 1] === b[j - 2] && a[i - 2] === b[j - 1]) {
            d[i][j] = Math.min(d[i][j], d[i - 2][j - 2] + 1);
          }
        }
      }
      return d[a.length][b.length];
    }
    function suggestSimilar(word, candidates) {
      if (!candidates || candidates.length === 0)
        return "";
      candidates = Array.from(new Set(candidates));
      const searchingOptions = word.startsWith("--");
      if (searchingOptions) {
        word = word.slice(2);
        candidates = candidates.map((candidate) => candidate.slice(2));
      }
      let similar = [];
      let bestDistance = maxDistance;
      const minSimilarity = 0.4;
      candidates.forEach((candidate) => {
        if (candidate.length <= 1)
          return;
        const distance = editDistance(word, candidate);
        const length = Math.max(word.length, candidate.length);
        const similarity = (length - distance) / length;
        if (similarity > minSimilarity) {
          if (distance < bestDistance) {
            bestDistance = distance;
            similar = [candidate];
          } else if (distance === bestDistance) {
            similar.push(candidate);
          }
        }
      });
      similar.sort((a, b) => a.localeCompare(b));
      if (searchingOptions) {
        similar = similar.map((candidate) => `--${candidate}`);
      }
      if (similar.length > 1) {
        return `
(Did you mean one of ${similar.join(", ")}?)`;
      }
      if (similar.length === 1) {
        return `
(Did you mean ${similar[0]}?)`;
      }
      return "";
    }
    exports.suggestSimilar = suggestSimilar;
  }
});

// node_modules/commander/lib/command.js
var require_command = __commonJS({
  "node_modules/commander/lib/command.js"(exports) {
    var EventEmitter = require("events").EventEmitter;
    var childProcess = require("child_process");
    var path2 = require("path");
    var fs2 = require("fs");
    var { Argument, humanReadableArgName } = require_argument();
    var { CommanderError } = require_error();
    var { Help } = require_help();
    var { Option, splitOptionFlags } = require_option();
    var { suggestSimilar } = require_suggestSimilar();
    var Command2 = class _Command extends EventEmitter {
      /**
       * Initialize a new `Command`.
       *
       * @param {string} [name]
       */
      constructor(name) {
        super();
        this.commands = [];
        this.options = [];
        this.parent = null;
        this._allowUnknownOption = false;
        this._allowExcessArguments = true;
        this._args = [];
        this.args = [];
        this.rawArgs = [];
        this.processedArgs = [];
        this._scriptPath = null;
        this._name = name || "";
        this._optionValues = {};
        this._optionValueSources = {};
        this._storeOptionsAsProperties = false;
        this._actionHandler = null;
        this._executableHandler = false;
        this._executableFile = null;
        this._defaultCommandName = null;
        this._exitCallback = null;
        this._aliases = [];
        this._combineFlagAndOptionalValue = true;
        this._description = "";
        this._argsDescription = void 0;
        this._enablePositionalOptions = false;
        this._passThroughOptions = false;
        this._lifeCycleHooks = {};
        this._showHelpAfterError = false;
        this._showSuggestionAfterError = false;
        this._outputConfiguration = {
          writeOut: (str) => process.stdout.write(str),
          writeErr: (str) => process.stderr.write(str),
          getOutHelpWidth: () => process.stdout.isTTY ? process.stdout.columns : void 0,
          getErrHelpWidth: () => process.stderr.isTTY ? process.stderr.columns : void 0,
          outputError: (str, write) => write(str)
        };
        this._hidden = false;
        this._hasHelpOption = true;
        this._helpFlags = "-h, --help";
        this._helpDescription = "display help for command";
        this._helpShortFlag = "-h";
        this._helpLongFlag = "--help";
        this._addImplicitHelpCommand = void 0;
        this._helpCommandName = "help";
        this._helpCommandnameAndArgs = "help [command]";
        this._helpCommandDescription = "display help for command";
        this._helpConfiguration = {};
      }
      /**
       * Copy settings that are useful to have in common across root command and subcommands.
       *
       * (Used internally when adding a command using `.command()` so subcommands inherit parent settings.)
       *
       * @param {Command} sourceCommand
       * @return {Command} returns `this` for executable command
       */
      copyInheritedSettings(sourceCommand) {
        this._outputConfiguration = sourceCommand._outputConfiguration;
        this._hasHelpOption = sourceCommand._hasHelpOption;
        this._helpFlags = sourceCommand._helpFlags;
        this._helpDescription = sourceCommand._helpDescription;
        this._helpShortFlag = sourceCommand._helpShortFlag;
        this._helpLongFlag = sourceCommand._helpLongFlag;
        this._helpCommandName = sourceCommand._helpCommandName;
        this._helpCommandnameAndArgs = sourceCommand._helpCommandnameAndArgs;
        this._helpCommandDescription = sourceCommand._helpCommandDescription;
        this._helpConfiguration = sourceCommand._helpConfiguration;
        this._exitCallback = sourceCommand._exitCallback;
        this._storeOptionsAsProperties = sourceCommand._storeOptionsAsProperties;
        this._combineFlagAndOptionalValue = sourceCommand._combineFlagAndOptionalValue;
        this._allowExcessArguments = sourceCommand._allowExcessArguments;
        this._enablePositionalOptions = sourceCommand._enablePositionalOptions;
        this._showHelpAfterError = sourceCommand._showHelpAfterError;
        this._showSuggestionAfterError = sourceCommand._showSuggestionAfterError;
        return this;
      }
      /**
       * Define a command.
       *
       * There are two styles of command: pay attention to where to put the description.
       *
       * @example
       * // Command implemented using action handler (description is supplied separately to `.command`)
       * program
       *   .command('clone <source> [destination]')
       *   .description('clone a repository into a newly created directory')
       *   .action((source, destination) => {
       *     console.log('clone command called');
       *   });
       *
       * // Command implemented using separate executable file (description is second parameter to `.command`)
       * program
       *   .command('start <service>', 'start named service')
       *   .command('stop [service]', 'stop named service, or all if no name supplied');
       *
       * @param {string} nameAndArgs - command name and arguments, args are `<required>` or `[optional]` and last may also be `variadic...`
       * @param {Object|string} [actionOptsOrExecDesc] - configuration options (for action), or description (for executable)
       * @param {Object} [execOpts] - configuration options (for executable)
       * @return {Command} returns new command for action handler, or `this` for executable command
       */
      command(nameAndArgs, actionOptsOrExecDesc, execOpts) {
        let desc = actionOptsOrExecDesc;
        let opts = execOpts;
        if (typeof desc === "object" && desc !== null) {
          opts = desc;
          desc = null;
        }
        opts = opts || {};
        const [, name, args] = nameAndArgs.match(/([^ ]+) *(.*)/);
        const cmd = this.createCommand(name);
        if (desc) {
          cmd.description(desc);
          cmd._executableHandler = true;
        }
        if (opts.isDefault)
          this._defaultCommandName = cmd._name;
        cmd._hidden = !!(opts.noHelp || opts.hidden);
        cmd._executableFile = opts.executableFile || null;
        if (args)
          cmd.arguments(args);
        this.commands.push(cmd);
        cmd.parent = this;
        cmd.copyInheritedSettings(this);
        if (desc)
          return this;
        return cmd;
      }
      /**
       * Factory routine to create a new unattached command.
       *
       * See .command() for creating an attached subcommand, which uses this routine to
       * create the command. You can override createCommand to customise subcommands.
       *
       * @param {string} [name]
       * @return {Command} new command
       */
      createCommand(name) {
        return new _Command(name);
      }
      /**
       * You can customise the help with a subclass of Help by overriding createHelp,
       * or by overriding Help properties using configureHelp().
       *
       * @return {Help}
       */
      createHelp() {
        return Object.assign(new Help(), this.configureHelp());
      }
      /**
       * You can customise the help by overriding Help properties using configureHelp(),
       * or with a subclass of Help by overriding createHelp().
       *
       * @param {Object} [configuration] - configuration options
       * @return {Command|Object} `this` command for chaining, or stored configuration
       */
      configureHelp(configuration) {
        if (configuration === void 0)
          return this._helpConfiguration;
        this._helpConfiguration = configuration;
        return this;
      }
      /**
       * The default output goes to stdout and stderr. You can customise this for special
       * applications. You can also customise the display of errors by overriding outputError.
       *
       * The configuration properties are all functions:
       *
       *     // functions to change where being written, stdout and stderr
       *     writeOut(str)
       *     writeErr(str)
       *     // matching functions to specify width for wrapping help
       *     getOutHelpWidth()
       *     getErrHelpWidth()
       *     // functions based on what is being written out
       *     outputError(str, write) // used for displaying errors, and not used for displaying help
       *
       * @param {Object} [configuration] - configuration options
       * @return {Command|Object} `this` command for chaining, or stored configuration
       */
      configureOutput(configuration) {
        if (configuration === void 0)
          return this._outputConfiguration;
        Object.assign(this._outputConfiguration, configuration);
        return this;
      }
      /**
       * Display the help or a custom message after an error occurs.
       *
       * @param {boolean|string} [displayHelp]
       * @return {Command} `this` command for chaining
       */
      showHelpAfterError(displayHelp = true) {
        if (typeof displayHelp !== "string")
          displayHelp = !!displayHelp;
        this._showHelpAfterError = displayHelp;
        return this;
      }
      /**
       * Display suggestion of similar commands for unknown commands, or options for unknown options.
       *
       * @param {boolean} [displaySuggestion]
       * @return {Command} `this` command for chaining
       */
      showSuggestionAfterError(displaySuggestion = true) {
        this._showSuggestionAfterError = !!displaySuggestion;
        return this;
      }
      /**
       * Add a prepared subcommand.
       *
       * See .command() for creating an attached subcommand which inherits settings from its parent.
       *
       * @param {Command} cmd - new subcommand
       * @param {Object} [opts] - configuration options
       * @return {Command} `this` command for chaining
       */
      addCommand(cmd, opts) {
        if (!cmd._name)
          throw new Error("Command passed to .addCommand() must have a name");
        function checkExplicitNames(commandArray) {
          commandArray.forEach((cmd2) => {
            if (cmd2._executableHandler && !cmd2._executableFile) {
              throw new Error(`Must specify executableFile for deeply nested executable: ${cmd2.name()}`);
            }
            checkExplicitNames(cmd2.commands);
          });
        }
        checkExplicitNames(cmd.commands);
        opts = opts || {};
        if (opts.isDefault)
          this._defaultCommandName = cmd._name;
        if (opts.noHelp || opts.hidden)
          cmd._hidden = true;
        this.commands.push(cmd);
        cmd.parent = this;
        return this;
      }
      /**
       * Factory routine to create a new unattached argument.
       *
       * See .argument() for creating an attached argument, which uses this routine to
       * create the argument. You can override createArgument to return a custom argument.
       *
       * @param {string} name
       * @param {string} [description]
       * @return {Argument} new argument
       */
      createArgument(name, description) {
        return new Argument(name, description);
      }
      /**
       * Define argument syntax for command.
       *
       * The default is that the argument is required, and you can explicitly
       * indicate this with <> around the name. Put [] around the name for an optional argument.
       *
       * @example
       * program.argument('<input-file>');
       * program.argument('[output-file]');
       *
       * @param {string} name
       * @param {string} [description]
       * @param {Function|*} [fn] - custom argument processing function
       * @param {*} [defaultValue]
       * @return {Command} `this` command for chaining
       */
      argument(name, description, fn, defaultValue) {
        const argument = this.createArgument(name, description);
        if (typeof fn === "function") {
          argument.default(defaultValue).argParser(fn);
        } else {
          argument.default(fn);
        }
        this.addArgument(argument);
        return this;
      }
      /**
       * Define argument syntax for command, adding multiple at once (without descriptions).
       *
       * See also .argument().
       *
       * @example
       * program.arguments('<cmd> [env]');
       *
       * @param {string} names
       * @return {Command} `this` command for chaining
       */
      arguments(names) {
        names.split(/ +/).forEach((detail) => {
          this.argument(detail);
        });
        return this;
      }
      /**
       * Define argument syntax for command, adding a prepared argument.
       *
       * @param {Argument} argument
       * @return {Command} `this` command for chaining
       */
      addArgument(argument) {
        const previousArgument = this._args.slice(-1)[0];
        if (previousArgument && previousArgument.variadic) {
          throw new Error(`only the last argument can be variadic '${previousArgument.name()}'`);
        }
        if (argument.required && argument.defaultValue !== void 0 && argument.parseArg === void 0) {
          throw new Error(`a default value for a required argument is never used: '${argument.name()}'`);
        }
        this._args.push(argument);
        return this;
      }
      /**
       * Override default decision whether to add implicit help command.
       *
       *    addHelpCommand() // force on
       *    addHelpCommand(false); // force off
       *    addHelpCommand('help [cmd]', 'display help for [cmd]'); // force on with custom details
       *
       * @return {Command} `this` command for chaining
       */
      addHelpCommand(enableOrNameAndArgs, description) {
        if (enableOrNameAndArgs === false) {
          this._addImplicitHelpCommand = false;
        } else {
          this._addImplicitHelpCommand = true;
          if (typeof enableOrNameAndArgs === "string") {
            this._helpCommandName = enableOrNameAndArgs.split(" ")[0];
            this._helpCommandnameAndArgs = enableOrNameAndArgs;
          }
          this._helpCommandDescription = description || this._helpCommandDescription;
        }
        return this;
      }
      /**
       * @return {boolean}
       * @api private
       */
      _hasImplicitHelpCommand() {
        if (this._addImplicitHelpCommand === void 0) {
          return this.commands.length && !this._actionHandler && !this._findCommand("help");
        }
        return this._addImplicitHelpCommand;
      }
      /**
       * Add hook for life cycle event.
       *
       * @param {string} event
       * @param {Function} listener
       * @return {Command} `this` command for chaining
       */
      hook(event, listener) {
        const allowedValues = ["preAction", "postAction"];
        if (!allowedValues.includes(event)) {
          throw new Error(`Unexpected value for event passed to hook : '${event}'.
Expecting one of '${allowedValues.join("', '")}'`);
        }
        if (this._lifeCycleHooks[event]) {
          this._lifeCycleHooks[event].push(listener);
        } else {
          this._lifeCycleHooks[event] = [listener];
        }
        return this;
      }
      /**
       * Register callback to use as replacement for calling process.exit.
       *
       * @param {Function} [fn] optional callback which will be passed a CommanderError, defaults to throwing
       * @return {Command} `this` command for chaining
       */
      exitOverride(fn) {
        if (fn) {
          this._exitCallback = fn;
        } else {
          this._exitCallback = (err) => {
            if (err.code !== "commander.executeSubCommandAsync") {
              throw err;
            } else {
            }
          };
        }
        return this;
      }
      /**
       * Call process.exit, and _exitCallback if defined.
       *
       * @param {number} exitCode exit code for using with process.exit
       * @param {string} code an id string representing the error
       * @param {string} message human-readable description of the error
       * @return never
       * @api private
       */
      _exit(exitCode, code, message) {
        if (this._exitCallback) {
          this._exitCallback(new CommanderError(exitCode, code, message));
        }
        process.exit(exitCode);
      }
      /**
       * Register callback `fn` for the command.
       *
       * @example
       * program
       *   .command('serve')
       *   .description('start service')
       *   .action(function() {
       *      // do work here
       *   });
       *
       * @param {Function} fn
       * @return {Command} `this` command for chaining
       */
      action(fn) {
        const listener = (args) => {
          const expectedArgsCount = this._args.length;
          const actionArgs = args.slice(0, expectedArgsCount);
          if (this._storeOptionsAsProperties) {
            actionArgs[expectedArgsCount] = this;
          } else {
            actionArgs[expectedArgsCount] = this.opts();
          }
          actionArgs.push(this);
          return fn.apply(this, actionArgs);
        };
        this._actionHandler = listener;
        return this;
      }
      /**
       * Factory routine to create a new unattached option.
       *
       * See .option() for creating an attached option, which uses this routine to
       * create the option. You can override createOption to return a custom option.
       *
       * @param {string} flags
       * @param {string} [description]
       * @return {Option} new option
       */
      createOption(flags, description) {
        return new Option(flags, description);
      }
      /**
       * Add an option.
       *
       * @param {Option} option
       * @return {Command} `this` command for chaining
       */
      addOption(option) {
        const oname = option.name();
        const name = option.attributeName();
        let defaultValue = option.defaultValue;
        if (option.negate || option.optional || option.required || typeof defaultValue === "boolean") {
          if (option.negate) {
            const positiveLongFlag = option.long.replace(/^--no-/, "--");
            defaultValue = this._findOption(positiveLongFlag) ? this.getOptionValue(name) : true;
          }
          if (defaultValue !== void 0) {
            this.setOptionValueWithSource(name, defaultValue, "default");
          }
        }
        this.options.push(option);
        const handleOptionValue = (val, invalidValueMessage, valueSource) => {
          const oldValue = this.getOptionValue(name);
          if (val !== null && option.parseArg) {
            try {
              val = option.parseArg(val, oldValue === void 0 ? defaultValue : oldValue);
            } catch (err) {
              if (err.code === "commander.invalidArgument") {
                const message = `${invalidValueMessage} ${err.message}`;
                this._displayError(err.exitCode, err.code, message);
              }
              throw err;
            }
          } else if (val !== null && option.variadic) {
            val = option._concatValue(val, oldValue);
          }
          if (typeof oldValue === "boolean" || typeof oldValue === "undefined") {
            if (val == null) {
              this.setOptionValueWithSource(name, option.negate ? false : defaultValue || true, valueSource);
            } else {
              this.setOptionValueWithSource(name, val, valueSource);
            }
          } else if (val !== null) {
            this.setOptionValueWithSource(name, option.negate ? false : val, valueSource);
          }
        };
        this.on("option:" + oname, (val) => {
          const invalidValueMessage = `error: option '${option.flags}' argument '${val}' is invalid.`;
          handleOptionValue(val, invalidValueMessage, "cli");
        });
        if (option.envVar) {
          this.on("optionEnv:" + oname, (val) => {
            const invalidValueMessage = `error: option '${option.flags}' value '${val}' from env '${option.envVar}' is invalid.`;
            handleOptionValue(val, invalidValueMessage, "env");
          });
        }
        return this;
      }
      /**
       * Internal implementation shared by .option() and .requiredOption()
       *
       * @api private
       */
      _optionEx(config, flags, description, fn, defaultValue) {
        const option = this.createOption(flags, description);
        option.makeOptionMandatory(!!config.mandatory);
        if (typeof fn === "function") {
          option.default(defaultValue).argParser(fn);
        } else if (fn instanceof RegExp) {
          const regex = fn;
          fn = (val, def) => {
            const m = regex.exec(val);
            return m ? m[0] : def;
          };
          option.default(defaultValue).argParser(fn);
        } else {
          option.default(fn);
        }
        return this.addOption(option);
      }
      /**
       * Define option with `flags`, `description` and optional
       * coercion `fn`.
       *
       * The `flags` string contains the short and/or long flags,
       * separated by comma, a pipe or space. The following are all valid
       * all will output this way when `--help` is used.
       *
       *     "-p, --pepper"
       *     "-p|--pepper"
       *     "-p --pepper"
       *
       * @example
       * // simple boolean defaulting to undefined
       * program.option('-p, --pepper', 'add pepper');
       *
       * program.pepper
       * // => undefined
       *
       * --pepper
       * program.pepper
       * // => true
       *
       * // simple boolean defaulting to true (unless non-negated option is also defined)
       * program.option('-C, --no-cheese', 'remove cheese');
       *
       * program.cheese
       * // => true
       *
       * --no-cheese
       * program.cheese
       * // => false
       *
       * // required argument
       * program.option('-C, --chdir <path>', 'change the working directory');
       *
       * --chdir /tmp
       * program.chdir
       * // => "/tmp"
       *
       * // optional argument
       * program.option('-c, --cheese [type]', 'add cheese [marble]');
       *
       * @param {string} flags
       * @param {string} [description]
       * @param {Function|*} [fn] - custom option processing function or default value
       * @param {*} [defaultValue]
       * @return {Command} `this` command for chaining
       */
      option(flags, description, fn, defaultValue) {
        return this._optionEx({}, flags, description, fn, defaultValue);
      }
      /**
      * Add a required option which must have a value after parsing. This usually means
      * the option must be specified on the command line. (Otherwise the same as .option().)
      *
      * The `flags` string contains the short and/or long flags, separated by comma, a pipe or space.
      *
      * @param {string} flags
      * @param {string} [description]
      * @param {Function|*} [fn] - custom option processing function or default value
      * @param {*} [defaultValue]
      * @return {Command} `this` command for chaining
      */
      requiredOption(flags, description, fn, defaultValue) {
        return this._optionEx({ mandatory: true }, flags, description, fn, defaultValue);
      }
      /**
       * Alter parsing of short flags with optional values.
       *
       * @example
       * // for `.option('-f,--flag [value]'):
       * program.combineFlagAndOptionalValue(true);  // `-f80` is treated like `--flag=80`, this is the default behaviour
       * program.combineFlagAndOptionalValue(false) // `-fb` is treated like `-f -b`
       *
       * @param {Boolean} [combine=true] - if `true` or omitted, an optional value can be specified directly after the flag.
       */
      combineFlagAndOptionalValue(combine = true) {
        this._combineFlagAndOptionalValue = !!combine;
        return this;
      }
      /**
       * Allow unknown options on the command line.
       *
       * @param {Boolean} [allowUnknown=true] - if `true` or omitted, no error will be thrown
       * for unknown options.
       */
      allowUnknownOption(allowUnknown = true) {
        this._allowUnknownOption = !!allowUnknown;
        return this;
      }
      /**
       * Allow excess command-arguments on the command line. Pass false to make excess arguments an error.
       *
       * @param {Boolean} [allowExcess=true] - if `true` or omitted, no error will be thrown
       * for excess arguments.
       */
      allowExcessArguments(allowExcess = true) {
        this._allowExcessArguments = !!allowExcess;
        return this;
      }
      /**
       * Enable positional options. Positional means global options are specified before subcommands which lets
       * subcommands reuse the same option names, and also enables subcommands to turn on passThroughOptions.
       * The default behaviour is non-positional and global options may appear anywhere on the command line.
       *
       * @param {Boolean} [positional=true]
       */
      enablePositionalOptions(positional = true) {
        this._enablePositionalOptions = !!positional;
        return this;
      }
      /**
       * Pass through options that come after command-arguments rather than treat them as command-options,
       * so actual command-options come before command-arguments. Turning this on for a subcommand requires
       * positional options to have been enabled on the program (parent commands).
       * The default behaviour is non-positional and options may appear before or after command-arguments.
       *
       * @param {Boolean} [passThrough=true]
       * for unknown options.
       */
      passThroughOptions(passThrough = true) {
        this._passThroughOptions = !!passThrough;
        if (!!this.parent && passThrough && !this.parent._enablePositionalOptions) {
          throw new Error("passThroughOptions can not be used without turning on enablePositionalOptions for parent command(s)");
        }
        return this;
      }
      /**
        * Whether to store option values as properties on command object,
        * or store separately (specify false). In both cases the option values can be accessed using .opts().
        *
        * @param {boolean} [storeAsProperties=true]
        * @return {Command} `this` command for chaining
        */
      storeOptionsAsProperties(storeAsProperties = true) {
        this._storeOptionsAsProperties = !!storeAsProperties;
        if (this.options.length) {
          throw new Error("call .storeOptionsAsProperties() before adding options");
        }
        return this;
      }
      /**
       * Retrieve option value.
       *
       * @param {string} key
       * @return {Object} value
       */
      getOptionValue(key) {
        if (this._storeOptionsAsProperties) {
          return this[key];
        }
        return this._optionValues[key];
      }
      /**
       * Store option value.
       *
       * @param {string} key
       * @param {Object} value
       * @return {Command} `this` command for chaining
       */
      setOptionValue(key, value2) {
        if (this._storeOptionsAsProperties) {
          this[key] = value2;
        } else {
          this._optionValues[key] = value2;
        }
        return this;
      }
      /**
       * Store option value and where the value came from.
        *
        * @param {string} key
        * @param {Object} value
        * @param {string} source - expected values are default/config/env/cli
        * @return {Command} `this` command for chaining
        */
      setOptionValueWithSource(key, value2, source) {
        this.setOptionValue(key, value2);
        this._optionValueSources[key] = source;
        return this;
      }
      /**
        * Get source of option value.
        * Expected values are default | config | env | cli
        *
        * @param {string} key
        * @return {string}
        */
      getOptionValueSource(key) {
        return this._optionValueSources[key];
      }
      /**
       * Get user arguments implied or explicit arguments.
       * Side-effects: set _scriptPath if args included application, and use that to set implicit command name.
       *
       * @api private
       */
      _prepareUserArgs(argv, parseOptions) {
        if (argv !== void 0 && !Array.isArray(argv)) {
          throw new Error("first parameter to parse must be array or undefined");
        }
        parseOptions = parseOptions || {};
        if (argv === void 0) {
          argv = process.argv;
          if (process.versions && process.versions.electron) {
            parseOptions.from = "electron";
          }
        }
        this.rawArgs = argv.slice();
        let userArgs;
        switch (parseOptions.from) {
          case void 0:
          case "node":
            this._scriptPath = argv[1];
            userArgs = argv.slice(2);
            break;
          case "electron":
            if (process.defaultApp) {
              this._scriptPath = argv[1];
              userArgs = argv.slice(2);
            } else {
              userArgs = argv.slice(1);
            }
            break;
          case "user":
            userArgs = argv.slice(0);
            break;
          default:
            throw new Error(`unexpected parse option { from: '${parseOptions.from}' }`);
        }
        if (!this._scriptPath && require.main) {
          this._scriptPath = require.main.filename;
        }
        this._name = this._name || this._scriptPath && path2.basename(this._scriptPath, path2.extname(this._scriptPath));
        return userArgs;
      }
      /**
       * Parse `argv`, setting options and invoking commands when defined.
       *
       * The default expectation is that the arguments are from node and have the application as argv[0]
       * and the script being run in argv[1], with user parameters after that.
       *
       * @example
       * program.parse(process.argv);
       * program.parse(); // implicitly use process.argv and auto-detect node vs electron conventions
       * program.parse(my-args, { from: 'user' }); // just user supplied arguments, nothing special about argv[0]
       *
       * @param {string[]} [argv] - optional, defaults to process.argv
       * @param {Object} [parseOptions] - optionally specify style of options with from: node/user/electron
       * @param {string} [parseOptions.from] - where the args are from: 'node', 'user', 'electron'
       * @return {Command} `this` command for chaining
       */
      parse(argv, parseOptions) {
        const userArgs = this._prepareUserArgs(argv, parseOptions);
        this._parseCommand([], userArgs);
        return this;
      }
      /**
       * Parse `argv`, setting options and invoking commands when defined.
       *
       * Use parseAsync instead of parse if any of your action handlers are async. Returns a Promise.
       *
       * The default expectation is that the arguments are from node and have the application as argv[0]
       * and the script being run in argv[1], with user parameters after that.
       *
       * @example
       * await program.parseAsync(process.argv);
       * await program.parseAsync(); // implicitly use process.argv and auto-detect node vs electron conventions
       * await program.parseAsync(my-args, { from: 'user' }); // just user supplied arguments, nothing special about argv[0]
       *
       * @param {string[]} [argv]
       * @param {Object} [parseOptions]
       * @param {string} parseOptions.from - where the args are from: 'node', 'user', 'electron'
       * @return {Promise}
       */
      async parseAsync(argv, parseOptions) {
        const userArgs = this._prepareUserArgs(argv, parseOptions);
        await this._parseCommand([], userArgs);
        return this;
      }
      /**
       * Execute a sub-command executable.
       *
       * @api private
       */
      _executeSubCommand(subcommand, args) {
        args = args.slice();
        let launchWithNode = false;
        const sourceExt = [".js", ".ts", ".tsx", ".mjs", ".cjs"];
        this._checkForMissingMandatoryOptions();
        let scriptPath = this._scriptPath;
        if (!scriptPath && require.main) {
          scriptPath = require.main.filename;
        }
        let baseDir;
        try {
          const resolvedLink = fs2.realpathSync(scriptPath);
          baseDir = path2.dirname(resolvedLink);
        } catch (e) {
          baseDir = ".";
        }
        let bin = path2.basename(scriptPath, path2.extname(scriptPath)) + "-" + subcommand._name;
        if (subcommand._executableFile) {
          bin = subcommand._executableFile;
        }
        const localBin = path2.join(baseDir, bin);
        if (fs2.existsSync(localBin)) {
          bin = localBin;
        } else {
          sourceExt.forEach((ext) => {
            if (fs2.existsSync(`${localBin}${ext}`)) {
              bin = `${localBin}${ext}`;
            }
          });
        }
        launchWithNode = sourceExt.includes(path2.extname(bin));
        let proc;
        if (process.platform !== "win32") {
          if (launchWithNode) {
            args.unshift(bin);
            args = incrementNodeInspectorPort(process.execArgv).concat(args);
            proc = childProcess.spawn(process.argv[0], args, { stdio: "inherit" });
          } else {
            proc = childProcess.spawn(bin, args, { stdio: "inherit" });
          }
        } else {
          args.unshift(bin);
          args = incrementNodeInspectorPort(process.execArgv).concat(args);
          proc = childProcess.spawn(process.execPath, args, { stdio: "inherit" });
        }
        const signals = ["SIGUSR1", "SIGUSR2", "SIGTERM", "SIGINT", "SIGHUP"];
        signals.forEach((signal) => {
          process.on(signal, () => {
            if (proc.killed === false && proc.exitCode === null) {
              proc.kill(signal);
            }
          });
        });
        const exitCallback = this._exitCallback;
        if (!exitCallback) {
          proc.on("close", process.exit.bind(process));
        } else {
          proc.on("close", () => {
            exitCallback(new CommanderError(process.exitCode || 0, "commander.executeSubCommandAsync", "(close)"));
          });
        }
        proc.on("error", (err) => {
          if (err.code === "ENOENT") {
            const executableMissing = `'${bin}' does not exist
 - if '${subcommand._name}' is not meant to be an executable command, remove description parameter from '.command()' and use '.description()' instead
 - if the default executable name is not suitable, use the executableFile option to supply a custom name`;
            throw new Error(executableMissing);
          } else if (err.code === "EACCES") {
            throw new Error(`'${bin}' not executable`);
          }
          if (!exitCallback) {
            process.exit(1);
          } else {
            const wrappedError = new CommanderError(1, "commander.executeSubCommandAsync", "(error)");
            wrappedError.nestedError = err;
            exitCallback(wrappedError);
          }
        });
        this.runningCommand = proc;
      }
      /**
       * @api private
       */
      _dispatchSubcommand(commandName, operands, unknown) {
        const subCommand = this._findCommand(commandName);
        if (!subCommand)
          this.help({ error: true });
        if (subCommand._executableHandler) {
          this._executeSubCommand(subCommand, operands.concat(unknown));
        } else {
          return subCommand._parseCommand(operands, unknown);
        }
      }
      /**
       * Check this.args against expected this._args.
       *
       * @api private
       */
      _checkNumberOfArguments() {
        this._args.forEach((arg, i) => {
          if (arg.required && this.args[i] == null) {
            this.missingArgument(arg.name());
          }
        });
        if (this._args.length > 0 && this._args[this._args.length - 1].variadic) {
          return;
        }
        if (this.args.length > this._args.length) {
          this._excessArguments(this.args);
        }
      }
      /**
       * Process this.args using this._args and save as this.processedArgs!
       *
       * @api private
       */
      _processArguments() {
        const myParseArg = (argument, value2, previous) => {
          let parsedValue = value2;
          if (value2 !== null && argument.parseArg) {
            try {
              parsedValue = argument.parseArg(value2, previous);
            } catch (err) {
              if (err.code === "commander.invalidArgument") {
                const message = `error: command-argument value '${value2}' is invalid for argument '${argument.name()}'. ${err.message}`;
                this._displayError(err.exitCode, err.code, message);
              }
              throw err;
            }
          }
          return parsedValue;
        };
        this._checkNumberOfArguments();
        const processedArgs = [];
        this._args.forEach((declaredArg, index) => {
          let value2 = declaredArg.defaultValue;
          if (declaredArg.variadic) {
            if (index < this.args.length) {
              value2 = this.args.slice(index);
              if (declaredArg.parseArg) {
                value2 = value2.reduce((processed, v) => {
                  return myParseArg(declaredArg, v, processed);
                }, declaredArg.defaultValue);
              }
            } else if (value2 === void 0) {
              value2 = [];
            }
          } else if (index < this.args.length) {
            value2 = this.args[index];
            if (declaredArg.parseArg) {
              value2 = myParseArg(declaredArg, value2, declaredArg.defaultValue);
            }
          }
          processedArgs[index] = value2;
        });
        this.processedArgs = processedArgs;
      }
      /**
       * Once we have a promise we chain, but call synchronously until then.
       *
       * @param {Promise|undefined} promise
       * @param {Function} fn
       * @return {Promise|undefined}
       * @api private
       */
      _chainOrCall(promise, fn) {
        if (promise && promise.then && typeof promise.then === "function") {
          return promise.then(() => fn());
        }
        return fn();
      }
      /**
       *
       * @param {Promise|undefined} promise
       * @param {string} event
       * @return {Promise|undefined}
       * @api private
       */
      _chainOrCallHooks(promise, event) {
        let result = promise;
        const hooks = [];
        getCommandAndParents(this).reverse().filter((cmd) => cmd._lifeCycleHooks[event] !== void 0).forEach((hookedCommand) => {
          hookedCommand._lifeCycleHooks[event].forEach((callback) => {
            hooks.push({ hookedCommand, callback });
          });
        });
        if (event === "postAction") {
          hooks.reverse();
        }
        hooks.forEach((hookDetail) => {
          result = this._chainOrCall(result, () => {
            return hookDetail.callback(hookDetail.hookedCommand, this);
          });
        });
        return result;
      }
      /**
       * Process arguments in context of this command.
       * Returns action result, in case it is a promise.
       *
       * @api private
       */
      _parseCommand(operands, unknown) {
        const parsed = this.parseOptions(unknown);
        this._parseOptionsEnv();
        operands = operands.concat(parsed.operands);
        unknown = parsed.unknown;
        this.args = operands.concat(unknown);
        if (operands && this._findCommand(operands[0])) {
          return this._dispatchSubcommand(operands[0], operands.slice(1), unknown);
        }
        if (this._hasImplicitHelpCommand() && operands[0] === this._helpCommandName) {
          if (operands.length === 1) {
            this.help();
          }
          return this._dispatchSubcommand(operands[1], [], [this._helpLongFlag]);
        }
        if (this._defaultCommandName) {
          outputHelpIfRequested(this, unknown);
          return this._dispatchSubcommand(this._defaultCommandName, operands, unknown);
        }
        if (this.commands.length && this.args.length === 0 && !this._actionHandler && !this._defaultCommandName) {
          this.help({ error: true });
        }
        outputHelpIfRequested(this, parsed.unknown);
        this._checkForMissingMandatoryOptions();
        const checkForUnknownOptions = () => {
          if (parsed.unknown.length > 0) {
            this.unknownOption(parsed.unknown[0]);
          }
        };
        const commandEvent = `command:${this.name()}`;
        if (this._actionHandler) {
          checkForUnknownOptions();
          this._processArguments();
          let actionResult;
          actionResult = this._chainOrCallHooks(actionResult, "preAction");
          actionResult = this._chainOrCall(actionResult, () => this._actionHandler(this.processedArgs));
          if (this.parent)
            this.parent.emit(commandEvent, operands, unknown);
          actionResult = this._chainOrCallHooks(actionResult, "postAction");
          return actionResult;
        }
        if (this.parent && this.parent.listenerCount(commandEvent)) {
          checkForUnknownOptions();
          this._processArguments();
          this.parent.emit(commandEvent, operands, unknown);
        } else if (operands.length) {
          if (this._findCommand("*")) {
            return this._dispatchSubcommand("*", operands, unknown);
          }
          if (this.listenerCount("command:*")) {
            this.emit("command:*", operands, unknown);
          } else if (this.commands.length) {
            this.unknownCommand();
          } else {
            checkForUnknownOptions();
            this._processArguments();
          }
        } else if (this.commands.length) {
          checkForUnknownOptions();
          this.help({ error: true });
        } else {
          checkForUnknownOptions();
          this._processArguments();
        }
      }
      /**
       * Find matching command.
       *
       * @api private
       */
      _findCommand(name) {
        if (!name)
          return void 0;
        return this.commands.find((cmd) => cmd._name === name || cmd._aliases.includes(name));
      }
      /**
       * Return an option matching `arg` if any.
       *
       * @param {string} arg
       * @return {Option}
       * @api private
       */
      _findOption(arg) {
        return this.options.find((option) => option.is(arg));
      }
      /**
       * Display an error message if a mandatory option does not have a value.
       * Lazy calling after checking for help flags from leaf subcommand.
       *
       * @api private
       */
      _checkForMissingMandatoryOptions() {
        for (let cmd = this; cmd; cmd = cmd.parent) {
          cmd.options.forEach((anOption) => {
            if (anOption.mandatory && cmd.getOptionValue(anOption.attributeName()) === void 0) {
              cmd.missingMandatoryOptionValue(anOption);
            }
          });
        }
      }
      /**
       * Parse options from `argv` removing known options,
       * and return argv split into operands and unknown arguments.
       *
       * Examples:
       *
       *     argv => operands, unknown
       *     --known kkk op => [op], []
       *     op --known kkk => [op], []
       *     sub --unknown uuu op => [sub], [--unknown uuu op]
       *     sub -- --unknown uuu op => [sub --unknown uuu op], []
       *
       * @param {String[]} argv
       * @return {{operands: String[], unknown: String[]}}
       */
      parseOptions(argv) {
        const operands = [];
        const unknown = [];
        let dest = operands;
        const args = argv.slice();
        function maybeOption(arg) {
          return arg.length > 1 && arg[0] === "-";
        }
        let activeVariadicOption = null;
        while (args.length) {
          const arg = args.shift();
          if (arg === "--") {
            if (dest === unknown)
              dest.push(arg);
            dest.push(...args);
            break;
          }
          if (activeVariadicOption && !maybeOption(arg)) {
            this.emit(`option:${activeVariadicOption.name()}`, arg);
            continue;
          }
          activeVariadicOption = null;
          if (maybeOption(arg)) {
            const option = this._findOption(arg);
            if (option) {
              if (option.required) {
                const value2 = args.shift();
                if (value2 === void 0)
                  this.optionMissingArgument(option);
                this.emit(`option:${option.name()}`, value2);
              } else if (option.optional) {
                let value2 = null;
                if (args.length > 0 && !maybeOption(args[0])) {
                  value2 = args.shift();
                }
                this.emit(`option:${option.name()}`, value2);
              } else {
                this.emit(`option:${option.name()}`);
              }
              activeVariadicOption = option.variadic ? option : null;
              continue;
            }
          }
          if (arg.length > 2 && arg[0] === "-" && arg[1] !== "-") {
            const option = this._findOption(`-${arg[1]}`);
            if (option) {
              if (option.required || option.optional && this._combineFlagAndOptionalValue) {
                this.emit(`option:${option.name()}`, arg.slice(2));
              } else {
                this.emit(`option:${option.name()}`);
                args.unshift(`-${arg.slice(2)}`);
              }
              continue;
            }
          }
          if (/^--[^=]+=/.test(arg)) {
            const index = arg.indexOf("=");
            const option = this._findOption(arg.slice(0, index));
            if (option && (option.required || option.optional)) {
              this.emit(`option:${option.name()}`, arg.slice(index + 1));
              continue;
            }
          }
          if (maybeOption(arg)) {
            dest = unknown;
          }
          if ((this._enablePositionalOptions || this._passThroughOptions) && operands.length === 0 && unknown.length === 0) {
            if (this._findCommand(arg)) {
              operands.push(arg);
              if (args.length > 0)
                unknown.push(...args);
              break;
            } else if (arg === this._helpCommandName && this._hasImplicitHelpCommand()) {
              operands.push(arg);
              if (args.length > 0)
                operands.push(...args);
              break;
            } else if (this._defaultCommandName) {
              unknown.push(arg);
              if (args.length > 0)
                unknown.push(...args);
              break;
            }
          }
          if (this._passThroughOptions) {
            dest.push(arg);
            if (args.length > 0)
              dest.push(...args);
            break;
          }
          dest.push(arg);
        }
        return { operands, unknown };
      }
      /**
       * Return an object containing options as key-value pairs
       *
       * @return {Object}
       */
      opts() {
        if (this._storeOptionsAsProperties) {
          const result = {};
          const len = this.options.length;
          for (let i = 0; i < len; i++) {
            const key = this.options[i].attributeName();
            result[key] = key === this._versionOptionName ? this._version : this[key];
          }
          return result;
        }
        return this._optionValues;
      }
      /**
       * Internal bottleneck for handling of parsing errors.
       *
       * @api private
       */
      _displayError(exitCode, code, message) {
        this._outputConfiguration.outputError(`${message}
`, this._outputConfiguration.writeErr);
        if (typeof this._showHelpAfterError === "string") {
          this._outputConfiguration.writeErr(`${this._showHelpAfterError}
`);
        } else if (this._showHelpAfterError) {
          this._outputConfiguration.writeErr("\n");
          this.outputHelp({ error: true });
        }
        this._exit(exitCode, code, message);
      }
      /**
       * Apply any option related environment variables, if option does
       * not have a value from cli or client code.
       *
       * @api private
       */
      _parseOptionsEnv() {
        this.options.forEach((option) => {
          if (option.envVar && option.envVar in process.env) {
            const optionKey = option.attributeName();
            if (this.getOptionValue(optionKey) === void 0 || ["default", "config", "env"].includes(this.getOptionValueSource(optionKey))) {
              if (option.required || option.optional) {
                this.emit(`optionEnv:${option.name()}`, process.env[option.envVar]);
              } else {
                this.emit(`optionEnv:${option.name()}`);
              }
            }
          }
        });
      }
      /**
       * Argument `name` is missing.
       *
       * @param {string} name
       * @api private
       */
      missingArgument(name) {
        const message = `error: missing required argument '${name}'`;
        this._displayError(1, "commander.missingArgument", message);
      }
      /**
       * `Option` is missing an argument.
       *
       * @param {Option} option
       * @api private
       */
      optionMissingArgument(option) {
        const message = `error: option '${option.flags}' argument missing`;
        this._displayError(1, "commander.optionMissingArgument", message);
      }
      /**
       * `Option` does not have a value, and is a mandatory option.
       *
       * @param {Option} option
       * @api private
       */
      missingMandatoryOptionValue(option) {
        const message = `error: required option '${option.flags}' not specified`;
        this._displayError(1, "commander.missingMandatoryOptionValue", message);
      }
      /**
       * Unknown option `flag`.
       *
       * @param {string} flag
       * @api private
       */
      unknownOption(flag) {
        if (this._allowUnknownOption)
          return;
        let suggestion = "";
        if (flag.startsWith("--") && this._showSuggestionAfterError) {
          let candidateFlags = [];
          let command = this;
          do {
            const moreFlags = command.createHelp().visibleOptions(command).filter((option) => option.long).map((option) => option.long);
            candidateFlags = candidateFlags.concat(moreFlags);
            command = command.parent;
          } while (command && !command._enablePositionalOptions);
          suggestion = suggestSimilar(flag, candidateFlags);
        }
        const message = `error: unknown option '${flag}'${suggestion}`;
        this._displayError(1, "commander.unknownOption", message);
      }
      /**
       * Excess arguments, more than expected.
       *
       * @param {string[]} receivedArgs
       * @api private
       */
      _excessArguments(receivedArgs) {
        if (this._allowExcessArguments)
          return;
        const expected = this._args.length;
        const s = expected === 1 ? "" : "s";
        const forSubcommand = this.parent ? ` for '${this.name()}'` : "";
        const message = `error: too many arguments${forSubcommand}. Expected ${expected} argument${s} but got ${receivedArgs.length}.`;
        this._displayError(1, "commander.excessArguments", message);
      }
      /**
       * Unknown command.
       *
       * @api private
       */
      unknownCommand() {
        const unknownName = this.args[0];
        let suggestion = "";
        if (this._showSuggestionAfterError) {
          const candidateNames = [];
          this.createHelp().visibleCommands(this).forEach((command) => {
            candidateNames.push(command.name());
            if (command.alias())
              candidateNames.push(command.alias());
          });
          suggestion = suggestSimilar(unknownName, candidateNames);
        }
        const message = `error: unknown command '${unknownName}'${suggestion}`;
        this._displayError(1, "commander.unknownCommand", message);
      }
      /**
       * Set the program version to `str`.
       *
       * This method auto-registers the "-V, --version" flag
       * which will print the version number when passed.
       *
       * You can optionally supply the  flags and description to override the defaults.
       *
       * @param {string} str
       * @param {string} [flags]
       * @param {string} [description]
       * @return {this | string} `this` command for chaining, or version string if no arguments
       */
      version(str, flags, description) {
        if (str === void 0)
          return this._version;
        this._version = str;
        flags = flags || "-V, --version";
        description = description || "output the version number";
        const versionOption = this.createOption(flags, description);
        this._versionOptionName = versionOption.attributeName();
        this.options.push(versionOption);
        this.on("option:" + versionOption.name(), () => {
          this._outputConfiguration.writeOut(`${str}
`);
          this._exit(0, "commander.version", str);
        });
        return this;
      }
      /**
       * Set the description to `str`.
       *
       * @param {string} [str]
       * @param {Object} [argsDescription]
       * @return {string|Command}
       */
      description(str, argsDescription) {
        if (str === void 0 && argsDescription === void 0)
          return this._description;
        this._description = str;
        if (argsDescription) {
          this._argsDescription = argsDescription;
        }
        return this;
      }
      /**
       * Set an alias for the command.
       *
       * You may call more than once to add multiple aliases. Only the first alias is shown in the auto-generated help.
       *
       * @param {string} [alias]
       * @return {string|Command}
       */
      alias(alias) {
        if (alias === void 0)
          return this._aliases[0];
        let command = this;
        if (this.commands.length !== 0 && this.commands[this.commands.length - 1]._executableHandler) {
          command = this.commands[this.commands.length - 1];
        }
        if (alias === command._name)
          throw new Error("Command alias can't be the same as its name");
        command._aliases.push(alias);
        return this;
      }
      /**
       * Set aliases for the command.
       *
       * Only the first alias is shown in the auto-generated help.
       *
       * @param {string[]} [aliases]
       * @return {string[]|Command}
       */
      aliases(aliases) {
        if (aliases === void 0)
          return this._aliases;
        aliases.forEach((alias) => this.alias(alias));
        return this;
      }
      /**
       * Set / get the command usage `str`.
       *
       * @param {string} [str]
       * @return {String|Command}
       */
      usage(str) {
        if (str === void 0) {
          if (this._usage)
            return this._usage;
          const args = this._args.map((arg) => {
            return humanReadableArgName(arg);
          });
          return [].concat(
            this.options.length || this._hasHelpOption ? "[options]" : [],
            this.commands.length ? "[command]" : [],
            this._args.length ? args : []
          ).join(" ");
        }
        this._usage = str;
        return this;
      }
      /**
       * Get or set the name of the command
       *
       * @param {string} [str]
       * @return {string|Command}
       */
      name(str) {
        if (str === void 0)
          return this._name;
        this._name = str;
        return this;
      }
      /**
       * Return program help documentation.
       *
       * @param {{ error: boolean }} [contextOptions] - pass {error:true} to wrap for stderr instead of stdout
       * @return {string}
       */
      helpInformation(contextOptions) {
        const helper = this.createHelp();
        if (helper.helpWidth === void 0) {
          helper.helpWidth = contextOptions && contextOptions.error ? this._outputConfiguration.getErrHelpWidth() : this._outputConfiguration.getOutHelpWidth();
        }
        return helper.formatHelp(this, helper);
      }
      /**
       * @api private
       */
      _getHelpContext(contextOptions) {
        contextOptions = contextOptions || {};
        const context = { error: !!contextOptions.error };
        let write;
        if (context.error) {
          write = (arg) => this._outputConfiguration.writeErr(arg);
        } else {
          write = (arg) => this._outputConfiguration.writeOut(arg);
        }
        context.write = contextOptions.write || write;
        context.command = this;
        return context;
      }
      /**
       * Output help information for this command.
       *
       * Outputs built-in help, and custom text added using `.addHelpText()`.
       *
       * @param {{ error: boolean } | Function} [contextOptions] - pass {error:true} to write to stderr instead of stdout
       */
      outputHelp(contextOptions) {
        let deprecatedCallback;
        if (typeof contextOptions === "function") {
          deprecatedCallback = contextOptions;
          contextOptions = void 0;
        }
        const context = this._getHelpContext(contextOptions);
        getCommandAndParents(this).reverse().forEach((command) => command.emit("beforeAllHelp", context));
        this.emit("beforeHelp", context);
        let helpInformation = this.helpInformation(context);
        if (deprecatedCallback) {
          helpInformation = deprecatedCallback(helpInformation);
          if (typeof helpInformation !== "string" && !Buffer.isBuffer(helpInformation)) {
            throw new Error("outputHelp callback must return a string or a Buffer");
          }
        }
        context.write(helpInformation);
        this.emit(this._helpLongFlag);
        this.emit("afterHelp", context);
        getCommandAndParents(this).forEach((command) => command.emit("afterAllHelp", context));
      }
      /**
       * You can pass in flags and a description to override the help
       * flags and help description for your command. Pass in false to
       * disable the built-in help option.
       *
       * @param {string | boolean} [flags]
       * @param {string} [description]
       * @return {Command} `this` command for chaining
       */
      helpOption(flags, description) {
        if (typeof flags === "boolean") {
          this._hasHelpOption = flags;
          return this;
        }
        this._helpFlags = flags || this._helpFlags;
        this._helpDescription = description || this._helpDescription;
        const helpFlags = splitOptionFlags(this._helpFlags);
        this._helpShortFlag = helpFlags.shortFlag;
        this._helpLongFlag = helpFlags.longFlag;
        return this;
      }
      /**
       * Output help information and exit.
       *
       * Outputs built-in help, and custom text added using `.addHelpText()`.
       *
       * @param {{ error: boolean }} [contextOptions] - pass {error:true} to write to stderr instead of stdout
       */
      help(contextOptions) {
        this.outputHelp(contextOptions);
        let exitCode = process.exitCode || 0;
        if (exitCode === 0 && contextOptions && typeof contextOptions !== "function" && contextOptions.error) {
          exitCode = 1;
        }
        this._exit(exitCode, "commander.help", "(outputHelp)");
      }
      /**
       * Add additional text to be displayed with the built-in help.
       *
       * Position is 'before' or 'after' to affect just this command,
       * and 'beforeAll' or 'afterAll' to affect this command and all its subcommands.
       *
       * @param {string} position - before or after built-in help
       * @param {string | Function} text - string to add, or a function returning a string
       * @return {Command} `this` command for chaining
       */
      addHelpText(position, text) {
        const allowedValues = ["beforeAll", "before", "after", "afterAll"];
        if (!allowedValues.includes(position)) {
          throw new Error(`Unexpected value for position to addHelpText.
Expecting one of '${allowedValues.join("', '")}'`);
        }
        const helpEvent = `${position}Help`;
        this.on(helpEvent, (context) => {
          let helpStr;
          if (typeof text === "function") {
            helpStr = text({ error: context.error, command: context.command });
          } else {
            helpStr = text;
          }
          if (helpStr) {
            context.write(`${helpStr}
`);
          }
        });
        return this;
      }
    };
    function outputHelpIfRequested(cmd, args) {
      const helpOption = cmd._hasHelpOption && args.find((arg) => arg === cmd._helpLongFlag || arg === cmd._helpShortFlag);
      if (helpOption) {
        cmd.outputHelp();
        cmd._exit(0, "commander.helpDisplayed", "(outputHelp)");
      }
    }
    function incrementNodeInspectorPort(args) {
      return args.map((arg) => {
        if (!arg.startsWith("--inspect")) {
          return arg;
        }
        let debugOption;
        let debugHost = "127.0.0.1";
        let debugPort = "9229";
        let match;
        if ((match = arg.match(/^(--inspect(-brk)?)$/)) !== null) {
          debugOption = match[1];
        } else if ((match = arg.match(/^(--inspect(-brk|-port)?)=([^:]+)$/)) !== null) {
          debugOption = match[1];
          if (/^\d+$/.test(match[3])) {
            debugPort = match[3];
          } else {
            debugHost = match[3];
          }
        } else if ((match = arg.match(/^(--inspect(-brk|-port)?)=([^:]+):(\d+)$/)) !== null) {
          debugOption = match[1];
          debugHost = match[3];
          debugPort = match[4];
        }
        if (debugOption && debugPort !== "0") {
          return `${debugOption}=${debugHost}:${parseInt(debugPort) + 1}`;
        }
        return arg;
      });
    }
    function getCommandAndParents(startCommand) {
      const result = [];
      for (let command = startCommand; command; command = command.parent) {
        result.push(command);
      }
      return result;
    }
    exports.Command = Command2;
  }
});

// node_modules/commander/index.js
var require_commander = __commonJS({
  "node_modules/commander/index.js"(exports, module2) {
    var { Argument } = require_argument();
    var { Command: Command2 } = require_command();
    var { CommanderError, InvalidArgumentError } = require_error();
    var { Help } = require_help();
    var { Option } = require_option();
    exports = module2.exports = new Command2();
    exports.program = exports;
    exports.Argument = Argument;
    exports.Command = Command2;
    exports.CommanderError = CommanderError;
    exports.Help = Help;
    exports.InvalidArgumentError = InvalidArgumentError;
    exports.InvalidOptionArgumentError = InvalidArgumentError;
    exports.Option = Option;
  }
});

// node_modules/lodash/lodash.js
var require_lodash = __commonJS({
  "node_modules/lodash/lodash.js"(exports, module2) {
    (function() {
      var undefined2;
      var VERSION = "4.17.21";
      var LARGE_ARRAY_SIZE = 200;
      var CORE_ERROR_TEXT = "Unsupported core-js use. Try https://npms.io/search?q=ponyfill.", FUNC_ERROR_TEXT = "Expected a function", INVALID_TEMPL_VAR_ERROR_TEXT = "Invalid `variable` option passed into `_.template`";
      var HASH_UNDEFINED = "__lodash_hash_undefined__";
      var MAX_MEMOIZE_SIZE = 500;
      var PLACEHOLDER = "__lodash_placeholder__";
      var CLONE_DEEP_FLAG = 1, CLONE_FLAT_FLAG = 2, CLONE_SYMBOLS_FLAG = 4;
      var COMPARE_PARTIAL_FLAG = 1, COMPARE_UNORDERED_FLAG = 2;
      var WRAP_BIND_FLAG = 1, WRAP_BIND_KEY_FLAG = 2, WRAP_CURRY_BOUND_FLAG = 4, WRAP_CURRY_FLAG = 8, WRAP_CURRY_RIGHT_FLAG = 16, WRAP_PARTIAL_FLAG = 32, WRAP_PARTIAL_RIGHT_FLAG = 64, WRAP_ARY_FLAG = 128, WRAP_REARG_FLAG = 256, WRAP_FLIP_FLAG = 512;
      var DEFAULT_TRUNC_LENGTH = 30, DEFAULT_TRUNC_OMISSION = "...";
      var HOT_COUNT = 800, HOT_SPAN = 16;
      var LAZY_FILTER_FLAG = 1, LAZY_MAP_FLAG = 2, LAZY_WHILE_FLAG = 3;
      var INFINITY = 1 / 0, MAX_SAFE_INTEGER = 9007199254740991, MAX_INTEGER = 17976931348623157e292, NAN = 0 / 0;
      var MAX_ARRAY_LENGTH = 4294967295, MAX_ARRAY_INDEX = MAX_ARRAY_LENGTH - 1, HALF_MAX_ARRAY_LENGTH = MAX_ARRAY_LENGTH >>> 1;
      var wrapFlags = [
        ["ary", WRAP_ARY_FLAG],
        ["bind", WRAP_BIND_FLAG],
        ["bindKey", WRAP_BIND_KEY_FLAG],
        ["curry", WRAP_CURRY_FLAG],
        ["curryRight", WRAP_CURRY_RIGHT_FLAG],
        ["flip", WRAP_FLIP_FLAG],
        ["partial", WRAP_PARTIAL_FLAG],
        ["partialRight", WRAP_PARTIAL_RIGHT_FLAG],
        ["rearg", WRAP_REARG_FLAG]
      ];
      var argsTag = "[object Arguments]", arrayTag = "[object Array]", asyncTag = "[object AsyncFunction]", boolTag = "[object Boolean]", dateTag = "[object Date]", domExcTag = "[object DOMException]", errorTag = "[object Error]", funcTag = "[object Function]", genTag = "[object GeneratorFunction]", mapTag = "[object Map]", numberTag = "[object Number]", nullTag = "[object Null]", objectTag = "[object Object]", promiseTag = "[object Promise]", proxyTag = "[object Proxy]", regexpTag = "[object RegExp]", setTag = "[object Set]", stringTag = "[object String]", symbolTag = "[object Symbol]", undefinedTag = "[object Undefined]", weakMapTag = "[object WeakMap]", weakSetTag = "[object WeakSet]";
      var arrayBufferTag = "[object ArrayBuffer]", dataViewTag = "[object DataView]", float32Tag = "[object Float32Array]", float64Tag = "[object Float64Array]", int8Tag = "[object Int8Array]", int16Tag = "[object Int16Array]", int32Tag = "[object Int32Array]", uint8Tag = "[object Uint8Array]", uint8ClampedTag = "[object Uint8ClampedArray]", uint16Tag = "[object Uint16Array]", uint32Tag = "[object Uint32Array]";
      var reEmptyStringLeading = /\b__p \+= '';/g, reEmptyStringMiddle = /\b(__p \+=) '' \+/g, reEmptyStringTrailing = /(__e\(.*?\)|\b__t\)) \+\n'';/g;
      var reEscapedHtml = /&(?:amp|lt|gt|quot|#39);/g, reUnescapedHtml = /[&<>"']/g, reHasEscapedHtml = RegExp(reEscapedHtml.source), reHasUnescapedHtml = RegExp(reUnescapedHtml.source);
      var reEscape = /<%-([\s\S]+?)%>/g, reEvaluate = /<%([\s\S]+?)%>/g, reInterpolate = /<%=([\s\S]+?)%>/g;
      var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, reIsPlainProp = /^\w*$/, rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;
      var reRegExpChar = /[\\^$.*+?()[\]{}|]/g, reHasRegExpChar = RegExp(reRegExpChar.source);
      var reTrimStart = /^\s+/;
      var reWhitespace = /\s/;
      var reWrapComment = /\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/, reWrapDetails = /\{\n\/\* \[wrapped with (.+)\] \*/, reSplitDetails = /,? & /;
      var reAsciiWord = /[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g;
      var reForbiddenIdentifierChars = /[()=,{}\[\]\/\s]/;
      var reEscapeChar = /\\(\\)?/g;
      var reEsTemplate = /\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g;
      var reFlags = /\w*$/;
      var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
      var reIsBinary = /^0b[01]+$/i;
      var reIsHostCtor = /^\[object .+?Constructor\]$/;
      var reIsOctal = /^0o[0-7]+$/i;
      var reIsUint = /^(?:0|[1-9]\d*)$/;
      var reLatin = /[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g;
      var reNoMatch = /($^)/;
      var reUnescapedString = /['\n\r\u2028\u2029\\]/g;
      var rsAstralRange = "\\ud800-\\udfff", rsComboMarksRange = "\\u0300-\\u036f", reComboHalfMarksRange = "\\ufe20-\\ufe2f", rsComboSymbolsRange = "\\u20d0-\\u20ff", rsComboRange = rsComboMarksRange + reComboHalfMarksRange + rsComboSymbolsRange, rsDingbatRange = "\\u2700-\\u27bf", rsLowerRange = "a-z\\xdf-\\xf6\\xf8-\\xff", rsMathOpRange = "\\xac\\xb1\\xd7\\xf7", rsNonCharRange = "\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf", rsPunctuationRange = "\\u2000-\\u206f", rsSpaceRange = " \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000", rsUpperRange = "A-Z\\xc0-\\xd6\\xd8-\\xde", rsVarRange = "\\ufe0e\\ufe0f", rsBreakRange = rsMathOpRange + rsNonCharRange + rsPunctuationRange + rsSpaceRange;
      var rsApos = "['\u2019]", rsAstral = "[" + rsAstralRange + "]", rsBreak = "[" + rsBreakRange + "]", rsCombo = "[" + rsComboRange + "]", rsDigits = "\\d+", rsDingbat = "[" + rsDingbatRange + "]", rsLower = "[" + rsLowerRange + "]", rsMisc = "[^" + rsAstralRange + rsBreakRange + rsDigits + rsDingbatRange + rsLowerRange + rsUpperRange + "]", rsFitz = "\\ud83c[\\udffb-\\udfff]", rsModifier = "(?:" + rsCombo + "|" + rsFitz + ")", rsNonAstral = "[^" + rsAstralRange + "]", rsRegional = "(?:\\ud83c[\\udde6-\\uddff]){2}", rsSurrPair = "[\\ud800-\\udbff][\\udc00-\\udfff]", rsUpper = "[" + rsUpperRange + "]", rsZWJ = "\\u200d";
      var rsMiscLower = "(?:" + rsLower + "|" + rsMisc + ")", rsMiscUpper = "(?:" + rsUpper + "|" + rsMisc + ")", rsOptContrLower = "(?:" + rsApos + "(?:d|ll|m|re|s|t|ve))?", rsOptContrUpper = "(?:" + rsApos + "(?:D|LL|M|RE|S|T|VE))?", reOptMod = rsModifier + "?", rsOptVar = "[" + rsVarRange + "]?", rsOptJoin = "(?:" + rsZWJ + "(?:" + [rsNonAstral, rsRegional, rsSurrPair].join("|") + ")" + rsOptVar + reOptMod + ")*", rsOrdLower = "\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])", rsOrdUpper = "\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])", rsSeq = rsOptVar + reOptMod + rsOptJoin, rsEmoji = "(?:" + [rsDingbat, rsRegional, rsSurrPair].join("|") + ")" + rsSeq, rsSymbol = "(?:" + [rsNonAstral + rsCombo + "?", rsCombo, rsRegional, rsSurrPair, rsAstral].join("|") + ")";
      var reApos = RegExp(rsApos, "g");
      var reComboMark = RegExp(rsCombo, "g");
      var reUnicode = RegExp(rsFitz + "(?=" + rsFitz + ")|" + rsSymbol + rsSeq, "g");
      var reUnicodeWord = RegExp([
        rsUpper + "?" + rsLower + "+" + rsOptContrLower + "(?=" + [rsBreak, rsUpper, "$"].join("|") + ")",
        rsMiscUpper + "+" + rsOptContrUpper + "(?=" + [rsBreak, rsUpper + rsMiscLower, "$"].join("|") + ")",
        rsUpper + "?" + rsMiscLower + "+" + rsOptContrLower,
        rsUpper + "+" + rsOptContrUpper,
        rsOrdUpper,
        rsOrdLower,
        rsDigits,
        rsEmoji
      ].join("|"), "g");
      var reHasUnicode = RegExp("[" + rsZWJ + rsAstralRange + rsComboRange + rsVarRange + "]");
      var reHasUnicodeWord = /[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/;
      var contextProps = [
        "Array",
        "Buffer",
        "DataView",
        "Date",
        "Error",
        "Float32Array",
        "Float64Array",
        "Function",
        "Int8Array",
        "Int16Array",
        "Int32Array",
        "Map",
        "Math",
        "Object",
        "Promise",
        "RegExp",
        "Set",
        "String",
        "Symbol",
        "TypeError",
        "Uint8Array",
        "Uint8ClampedArray",
        "Uint16Array",
        "Uint32Array",
        "WeakMap",
        "_",
        "clearTimeout",
        "isFinite",
        "parseInt",
        "setTimeout"
      ];
      var templateCounter = -1;
      var typedArrayTags = {};
      typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
      typedArrayTags[argsTag] = typedArrayTags[arrayTag] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag] = typedArrayTags[mapTag] = typedArrayTags[numberTag] = typedArrayTags[objectTag] = typedArrayTags[regexpTag] = typedArrayTags[setTag] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;
      var cloneableTags = {};
      cloneableTags[argsTag] = cloneableTags[arrayTag] = cloneableTags[arrayBufferTag] = cloneableTags[dataViewTag] = cloneableTags[boolTag] = cloneableTags[dateTag] = cloneableTags[float32Tag] = cloneableTags[float64Tag] = cloneableTags[int8Tag] = cloneableTags[int16Tag] = cloneableTags[int32Tag] = cloneableTags[mapTag] = cloneableTags[numberTag] = cloneableTags[objectTag] = cloneableTags[regexpTag] = cloneableTags[setTag] = cloneableTags[stringTag] = cloneableTags[symbolTag] = cloneableTags[uint8Tag] = cloneableTags[uint8ClampedTag] = cloneableTags[uint16Tag] = cloneableTags[uint32Tag] = true;
      cloneableTags[errorTag] = cloneableTags[funcTag] = cloneableTags[weakMapTag] = false;
      var deburredLetters = {
        // Latin-1 Supplement block.
        "\xC0": "A",
        "\xC1": "A",
        "\xC2": "A",
        "\xC3": "A",
        "\xC4": "A",
        "\xC5": "A",
        "\xE0": "a",
        "\xE1": "a",
        "\xE2": "a",
        "\xE3": "a",
        "\xE4": "a",
        "\xE5": "a",
        "\xC7": "C",
        "\xE7": "c",
        "\xD0": "D",
        "\xF0": "d",
        "\xC8": "E",
        "\xC9": "E",
        "\xCA": "E",
        "\xCB": "E",
        "\xE8": "e",
        "\xE9": "e",
        "\xEA": "e",
        "\xEB": "e",
        "\xCC": "I",
        "\xCD": "I",
        "\xCE": "I",
        "\xCF": "I",
        "\xEC": "i",
        "\xED": "i",
        "\xEE": "i",
        "\xEF": "i",
        "\xD1": "N",
        "\xF1": "n",
        "\xD2": "O",
        "\xD3": "O",
        "\xD4": "O",
        "\xD5": "O",
        "\xD6": "O",
        "\xD8": "O",
        "\xF2": "o",
        "\xF3": "o",
        "\xF4": "o",
        "\xF5": "o",
        "\xF6": "o",
        "\xF8": "o",
        "\xD9": "U",
        "\xDA": "U",
        "\xDB": "U",
        "\xDC": "U",
        "\xF9": "u",
        "\xFA": "u",
        "\xFB": "u",
        "\xFC": "u",
        "\xDD": "Y",
        "\xFD": "y",
        "\xFF": "y",
        "\xC6": "Ae",
        "\xE6": "ae",
        "\xDE": "Th",
        "\xFE": "th",
        "\xDF": "ss",
        // Latin Extended-A block.
        "\u0100": "A",
        "\u0102": "A",
        "\u0104": "A",
        "\u0101": "a",
        "\u0103": "a",
        "\u0105": "a",
        "\u0106": "C",
        "\u0108": "C",
        "\u010A": "C",
        "\u010C": "C",
        "\u0107": "c",
        "\u0109": "c",
        "\u010B": "c",
        "\u010D": "c",
        "\u010E": "D",
        "\u0110": "D",
        "\u010F": "d",
        "\u0111": "d",
        "\u0112": "E",
        "\u0114": "E",
        "\u0116": "E",
        "\u0118": "E",
        "\u011A": "E",
        "\u0113": "e",
        "\u0115": "e",
        "\u0117": "e",
        "\u0119": "e",
        "\u011B": "e",
        "\u011C": "G",
        "\u011E": "G",
        "\u0120": "G",
        "\u0122": "G",
        "\u011D": "g",
        "\u011F": "g",
        "\u0121": "g",
        "\u0123": "g",
        "\u0124": "H",
        "\u0126": "H",
        "\u0125": "h",
        "\u0127": "h",
        "\u0128": "I",
        "\u012A": "I",
        "\u012C": "I",
        "\u012E": "I",
        "\u0130": "I",
        "\u0129": "i",
        "\u012B": "i",
        "\u012D": "i",
        "\u012F": "i",
        "\u0131": "i",
        "\u0134": "J",
        "\u0135": "j",
        "\u0136": "K",
        "\u0137": "k",
        "\u0138": "k",
        "\u0139": "L",
        "\u013B": "L",
        "\u013D": "L",
        "\u013F": "L",
        "\u0141": "L",
        "\u013A": "l",
        "\u013C": "l",
        "\u013E": "l",
        "\u0140": "l",
        "\u0142": "l",
        "\u0143": "N",
        "\u0145": "N",
        "\u0147": "N",
        "\u014A": "N",
        "\u0144": "n",
        "\u0146": "n",
        "\u0148": "n",
        "\u014B": "n",
        "\u014C": "O",
        "\u014E": "O",
        "\u0150": "O",
        "\u014D": "o",
        "\u014F": "o",
        "\u0151": "o",
        "\u0154": "R",
        "\u0156": "R",
        "\u0158": "R",
        "\u0155": "r",
        "\u0157": "r",
        "\u0159": "r",
        "\u015A": "S",
        "\u015C": "S",
        "\u015E": "S",
        "\u0160": "S",
        "\u015B": "s",
        "\u015D": "s",
        "\u015F": "s",
        "\u0161": "s",
        "\u0162": "T",
        "\u0164": "T",
        "\u0166": "T",
        "\u0163": "t",
        "\u0165": "t",
        "\u0167": "t",
        "\u0168": "U",
        "\u016A": "U",
        "\u016C": "U",
        "\u016E": "U",
        "\u0170": "U",
        "\u0172": "U",
        "\u0169": "u",
        "\u016B": "u",
        "\u016D": "u",
        "\u016F": "u",
        "\u0171": "u",
        "\u0173": "u",
        "\u0174": "W",
        "\u0175": "w",
        "\u0176": "Y",
        "\u0177": "y",
        "\u0178": "Y",
        "\u0179": "Z",
        "\u017B": "Z",
        "\u017D": "Z",
        "\u017A": "z",
        "\u017C": "z",
        "\u017E": "z",
        "\u0132": "IJ",
        "\u0133": "ij",
        "\u0152": "Oe",
        "\u0153": "oe",
        "\u0149": "'n",
        "\u017F": "s"
      };
      var htmlEscapes = {
        "&": "&amp;",
        "<": "&lt;",
        ">": "&gt;",
        '"': "&quot;",
        "'": "&#39;"
      };
      var htmlUnescapes = {
        "&amp;": "&",
        "&lt;": "<",
        "&gt;": ">",
        "&quot;": '"',
        "&#39;": "'"
      };
      var stringEscapes = {
        "\\": "\\",
        "'": "'",
        "\n": "n",
        "\r": "r",
        "\u2028": "u2028",
        "\u2029": "u2029"
      };
      var freeParseFloat = parseFloat, freeParseInt = parseInt;
      var freeGlobal = typeof global == "object" && global && global.Object === Object && global;
      var freeSelf = typeof self == "object" && self && self.Object === Object && self;
      var root2 = freeGlobal || freeSelf || Function("return this")();
      var freeExports = typeof exports == "object" && exports && !exports.nodeType && exports;
      var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
      var moduleExports = freeModule && freeModule.exports === freeExports;
      var freeProcess = moduleExports && freeGlobal.process;
      var nodeUtil = function() {
        try {
          var types = freeModule && freeModule.require && freeModule.require("util").types;
          if (types) {
            return types;
          }
          return freeProcess && freeProcess.binding && freeProcess.binding("util");
        } catch (e) {
        }
      }();
      var nodeIsArrayBuffer = nodeUtil && nodeUtil.isArrayBuffer, nodeIsDate = nodeUtil && nodeUtil.isDate, nodeIsMap = nodeUtil && nodeUtil.isMap, nodeIsRegExp = nodeUtil && nodeUtil.isRegExp, nodeIsSet = nodeUtil && nodeUtil.isSet, nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
      function apply(func, thisArg, args) {
        switch (args.length) {
          case 0:
            return func.call(thisArg);
          case 1:
            return func.call(thisArg, args[0]);
          case 2:
            return func.call(thisArg, args[0], args[1]);
          case 3:
            return func.call(thisArg, args[0], args[1], args[2]);
        }
        return func.apply(thisArg, args);
      }
      function arrayAggregator(array, setter, iteratee, accumulator) {
        var index = -1, length = array == null ? 0 : array.length;
        while (++index < length) {
          var value2 = array[index];
          setter(accumulator, value2, iteratee(value2), array);
        }
        return accumulator;
      }
      function arrayEach(array, iteratee) {
        var index = -1, length = array == null ? 0 : array.length;
        while (++index < length) {
          if (iteratee(array[index], index, array) === false) {
            break;
          }
        }
        return array;
      }
      function arrayEachRight(array, iteratee) {
        var length = array == null ? 0 : array.length;
        while (length--) {
          if (iteratee(array[length], length, array) === false) {
            break;
          }
        }
        return array;
      }
      function arrayEvery(array, predicate) {
        var index = -1, length = array == null ? 0 : array.length;
        while (++index < length) {
          if (!predicate(array[index], index, array)) {
            return false;
          }
        }
        return true;
      }
      function arrayFilter(array, predicate) {
        var index = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
        while (++index < length) {
          var value2 = array[index];
          if (predicate(value2, index, array)) {
            result[resIndex++] = value2;
          }
        }
        return result;
      }
      function arrayIncludes(array, value2) {
        var length = array == null ? 0 : array.length;
        return !!length && baseIndexOf(array, value2, 0) > -1;
      }
      function arrayIncludesWith(array, value2, comparator) {
        var index = -1, length = array == null ? 0 : array.length;
        while (++index < length) {
          if (comparator(value2, array[index])) {
            return true;
          }
        }
        return false;
      }
      function arrayMap(array, iteratee) {
        var index = -1, length = array == null ? 0 : array.length, result = Array(length);
        while (++index < length) {
          result[index] = iteratee(array[index], index, array);
        }
        return result;
      }
      function arrayPush(array, values2) {
        var index = -1, length = values2.length, offset = array.length;
        while (++index < length) {
          array[offset + index] = values2[index];
        }
        return array;
      }
      function arrayReduce(array, iteratee, accumulator, initAccum) {
        var index = -1, length = array == null ? 0 : array.length;
        if (initAccum && length) {
          accumulator = array[++index];
        }
        while (++index < length) {
          accumulator = iteratee(accumulator, array[index], index, array);
        }
        return accumulator;
      }
      function arrayReduceRight(array, iteratee, accumulator, initAccum) {
        var length = array == null ? 0 : array.length;
        if (initAccum && length) {
          accumulator = array[--length];
        }
        while (length--) {
          accumulator = iteratee(accumulator, array[length], length, array);
        }
        return accumulator;
      }
      function arraySome(array, predicate) {
        var index = -1, length = array == null ? 0 : array.length;
        while (++index < length) {
          if (predicate(array[index], index, array)) {
            return true;
          }
        }
        return false;
      }
      var asciiSize = baseProperty("length");
      function asciiToArray(string) {
        return string.split("");
      }
      function asciiWords(string) {
        return string.match(reAsciiWord) || [];
      }
      function baseFindKey(collection, predicate, eachFunc) {
        var result;
        eachFunc(collection, function(value2, key, collection2) {
          if (predicate(value2, key, collection2)) {
            result = key;
            return false;
          }
        });
        return result;
      }
      function baseFindIndex(array, predicate, fromIndex, fromRight) {
        var length = array.length, index = fromIndex + (fromRight ? 1 : -1);
        while (fromRight ? index-- : ++index < length) {
          if (predicate(array[index], index, array)) {
            return index;
          }
        }
        return -1;
      }
      function baseIndexOf(array, value2, fromIndex) {
        return value2 === value2 ? strictIndexOf(array, value2, fromIndex) : baseFindIndex(array, baseIsNaN, fromIndex);
      }
      function baseIndexOfWith(array, value2, fromIndex, comparator) {
        var index = fromIndex - 1, length = array.length;
        while (++index < length) {
          if (comparator(array[index], value2)) {
            return index;
          }
        }
        return -1;
      }
      function baseIsNaN(value2) {
        return value2 !== value2;
      }
      function baseMean(array, iteratee) {
        var length = array == null ? 0 : array.length;
        return length ? baseSum(array, iteratee) / length : NAN;
      }
      function baseProperty(key) {
        return function(object) {
          return object == null ? undefined2 : object[key];
        };
      }
      function basePropertyOf(object) {
        return function(key) {
          return object == null ? undefined2 : object[key];
        };
      }
      function baseReduce(collection, iteratee, accumulator, initAccum, eachFunc) {
        eachFunc(collection, function(value2, index, collection2) {
          accumulator = initAccum ? (initAccum = false, value2) : iteratee(accumulator, value2, index, collection2);
        });
        return accumulator;
      }
      function baseSortBy(array, comparer) {
        var length = array.length;
        array.sort(comparer);
        while (length--) {
          array[length] = array[length].value;
        }
        return array;
      }
      function baseSum(array, iteratee) {
        var result, index = -1, length = array.length;
        while (++index < length) {
          var current = iteratee(array[index]);
          if (current !== undefined2) {
            result = result === undefined2 ? current : result + current;
          }
        }
        return result;
      }
      function baseTimes(n, iteratee) {
        var index = -1, result = Array(n);
        while (++index < n) {
          result[index] = iteratee(index);
        }
        return result;
      }
      function baseToPairs(object, props) {
        return arrayMap(props, function(key) {
          return [key, object[key]];
        });
      }
      function baseTrim(string) {
        return string ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, "") : string;
      }
      function baseUnary(func) {
        return function(value2) {
          return func(value2);
        };
      }
      function baseValues(object, props) {
        return arrayMap(props, function(key) {
          return object[key];
        });
      }
      function cacheHas(cache, key) {
        return cache.has(key);
      }
      function charsStartIndex(strSymbols, chrSymbols) {
        var index = -1, length = strSymbols.length;
        while (++index < length && baseIndexOf(chrSymbols, strSymbols[index], 0) > -1) {
        }
        return index;
      }
      function charsEndIndex(strSymbols, chrSymbols) {
        var index = strSymbols.length;
        while (index-- && baseIndexOf(chrSymbols, strSymbols[index], 0) > -1) {
        }
        return index;
      }
      function countHolders(array, placeholder) {
        var length = array.length, result = 0;
        while (length--) {
          if (array[length] === placeholder) {
            ++result;
          }
        }
        return result;
      }
      var deburrLetter = basePropertyOf(deburredLetters);
      var escapeHtmlChar = basePropertyOf(htmlEscapes);
      function escapeStringChar(chr) {
        return "\\" + stringEscapes[chr];
      }
      function getValue(object, key) {
        return object == null ? undefined2 : object[key];
      }
      function hasUnicode(string) {
        return reHasUnicode.test(string);
      }
      function hasUnicodeWord(string) {
        return reHasUnicodeWord.test(string);
      }
      function iteratorToArray(iterator) {
        var data, result = [];
        while (!(data = iterator.next()).done) {
          result.push(data.value);
        }
        return result;
      }
      function mapToArray(map) {
        var index = -1, result = Array(map.size);
        map.forEach(function(value2, key) {
          result[++index] = [key, value2];
        });
        return result;
      }
      function overArg(func, transform) {
        return function(arg) {
          return func(transform(arg));
        };
      }
      function replaceHolders(array, placeholder) {
        var index = -1, length = array.length, resIndex = 0, result = [];
        while (++index < length) {
          var value2 = array[index];
          if (value2 === placeholder || value2 === PLACEHOLDER) {
            array[index] = PLACEHOLDER;
            result[resIndex++] = index;
          }
        }
        return result;
      }
      function setToArray(set) {
        var index = -1, result = Array(set.size);
        set.forEach(function(value2) {
          result[++index] = value2;
        });
        return result;
      }
      function setToPairs(set) {
        var index = -1, result = Array(set.size);
        set.forEach(function(value2) {
          result[++index] = [value2, value2];
        });
        return result;
      }
      function strictIndexOf(array, value2, fromIndex) {
        var index = fromIndex - 1, length = array.length;
        while (++index < length) {
          if (array[index] === value2) {
            return index;
          }
        }
        return -1;
      }
      function strictLastIndexOf(array, value2, fromIndex) {
        var index = fromIndex + 1;
        while (index--) {
          if (array[index] === value2) {
            return index;
          }
        }
        return index;
      }
      function stringSize(string) {
        return hasUnicode(string) ? unicodeSize(string) : asciiSize(string);
      }
      function stringToArray(string) {
        return hasUnicode(string) ? unicodeToArray(string) : asciiToArray(string);
      }
      function trimmedEndIndex(string) {
        var index = string.length;
        while (index-- && reWhitespace.test(string.charAt(index))) {
        }
        return index;
      }
      var unescapeHtmlChar = basePropertyOf(htmlUnescapes);
      function unicodeSize(string) {
        var result = reUnicode.lastIndex = 0;
        while (reUnicode.test(string)) {
          ++result;
        }
        return result;
      }
      function unicodeToArray(string) {
        return string.match(reUnicode) || [];
      }
      function unicodeWords(string) {
        return string.match(reUnicodeWord) || [];
      }
      var runInContext = function runInContext2(context) {
        context = context == null ? root2 : _.defaults(root2.Object(), context, _.pick(root2, contextProps));
        var Array2 = context.Array, Date2 = context.Date, Error2 = context.Error, Function2 = context.Function, Math2 = context.Math, Object2 = context.Object, RegExp2 = context.RegExp, String2 = context.String, TypeError2 = context.TypeError;
        var arrayProto = Array2.prototype, funcProto = Function2.prototype, objectProto = Object2.prototype;
        var coreJsData = context["__core-js_shared__"];
        var funcToString = funcProto.toString;
        var hasOwnProperty = objectProto.hasOwnProperty;
        var idCounter = 0;
        var maskSrcKey = function() {
          var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
          return uid ? "Symbol(src)_1." + uid : "";
        }();
        var nativeObjectToString = objectProto.toString;
        var objectCtorString = funcToString.call(Object2);
        var oldDash = root2._;
        var reIsNative = RegExp2(
          "^" + funcToString.call(hasOwnProperty).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
        );
        var Buffer2 = moduleExports ? context.Buffer : undefined2, Symbol2 = context.Symbol, Uint8Array2 = context.Uint8Array, allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : undefined2, getPrototype = overArg(Object2.getPrototypeOf, Object2), objectCreate = Object2.create, propertyIsEnumerable = objectProto.propertyIsEnumerable, splice = arrayProto.splice, spreadableSymbol = Symbol2 ? Symbol2.isConcatSpreadable : undefined2, symIterator = Symbol2 ? Symbol2.iterator : undefined2, symToStringTag = Symbol2 ? Symbol2.toStringTag : undefined2;
        var defineProperty = function() {
          try {
            var func = getNative(Object2, "defineProperty");
            func({}, "", {});
            return func;
          } catch (e) {
          }
        }();
        var ctxClearTimeout = context.clearTimeout !== root2.clearTimeout && context.clearTimeout, ctxNow = Date2 && Date2.now !== root2.Date.now && Date2.now, ctxSetTimeout = context.setTimeout !== root2.setTimeout && context.setTimeout;
        var nativeCeil = Math2.ceil, nativeFloor = Math2.floor, nativeGetSymbols = Object2.getOwnPropertySymbols, nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : undefined2, nativeIsFinite = context.isFinite, nativeJoin = arrayProto.join, nativeKeys = overArg(Object2.keys, Object2), nativeMax = Math2.max, nativeMin = Math2.min, nativeNow = Date2.now, nativeParseInt = context.parseInt, nativeRandom = Math2.random, nativeReverse = arrayProto.reverse;
        var DataView2 = getNative(context, "DataView"), Map2 = getNative(context, "Map"), Promise2 = getNative(context, "Promise"), Set2 = getNative(context, "Set"), WeakMap2 = getNative(context, "WeakMap"), nativeCreate = getNative(Object2, "create");
        var metaMap = WeakMap2 && new WeakMap2();
        var realNames = {};
        var dataViewCtorString = toSource(DataView2), mapCtorString = toSource(Map2), promiseCtorString = toSource(Promise2), setCtorString = toSource(Set2), weakMapCtorString = toSource(WeakMap2);
        var symbolProto = Symbol2 ? Symbol2.prototype : undefined2, symbolValueOf = symbolProto ? symbolProto.valueOf : undefined2, symbolToString = symbolProto ? symbolProto.toString : undefined2;
        function lodash(value2) {
          if (isObjectLike(value2) && !isArray2(value2) && !(value2 instanceof LazyWrapper)) {
            if (value2 instanceof LodashWrapper) {
              return value2;
            }
            if (hasOwnProperty.call(value2, "__wrapped__")) {
              return wrapperClone(value2);
            }
          }
          return new LodashWrapper(value2);
        }
        var baseCreate = function() {
          function object() {
          }
          return function(proto) {
            if (!isObject(proto)) {
              return {};
            }
            if (objectCreate) {
              return objectCreate(proto);
            }
            object.prototype = proto;
            var result2 = new object();
            object.prototype = undefined2;
            return result2;
          };
        }();
        function baseLodash() {
        }
        function LodashWrapper(value2, chainAll) {
          this.__wrapped__ = value2;
          this.__actions__ = [];
          this.__chain__ = !!chainAll;
          this.__index__ = 0;
          this.__values__ = undefined2;
        }
        lodash.templateSettings = {
          /**
           * Used to detect `data` property values to be HTML-escaped.
           *
           * @memberOf _.templateSettings
           * @type {RegExp}
           */
          "escape": reEscape,
          /**
           * Used to detect code to be evaluated.
           *
           * @memberOf _.templateSettings
           * @type {RegExp}
           */
          "evaluate": reEvaluate,
          /**
           * Used to detect `data` property values to inject.
           *
           * @memberOf _.templateSettings
           * @type {RegExp}
           */
          "interpolate": reInterpolate,
          /**
           * Used to reference the data object in the template text.
           *
           * @memberOf _.templateSettings
           * @type {string}
           */
          "variable": "",
          /**
           * Used to import variables into the compiled template.
           *
           * @memberOf _.templateSettings
           * @type {Object}
           */
          "imports": {
            /**
             * A reference to the `lodash` function.
             *
             * @memberOf _.templateSettings.imports
             * @type {Function}
             */
            "_": lodash
          }
        };
        lodash.prototype = baseLodash.prototype;
        lodash.prototype.constructor = lodash;
        LodashWrapper.prototype = baseCreate(baseLodash.prototype);
        LodashWrapper.prototype.constructor = LodashWrapper;
        function LazyWrapper(value2) {
          this.__wrapped__ = value2;
          this.__actions__ = [];
          this.__dir__ = 1;
          this.__filtered__ = false;
          this.__iteratees__ = [];
          this.__takeCount__ = MAX_ARRAY_LENGTH;
          this.__views__ = [];
        }
        function lazyClone() {
          var result2 = new LazyWrapper(this.__wrapped__);
          result2.__actions__ = copyArray(this.__actions__);
          result2.__dir__ = this.__dir__;
          result2.__filtered__ = this.__filtered__;
          result2.__iteratees__ = copyArray(this.__iteratees__);
          result2.__takeCount__ = this.__takeCount__;
          result2.__views__ = copyArray(this.__views__);
          return result2;
        }
        function lazyReverse() {
          if (this.__filtered__) {
            var result2 = new LazyWrapper(this);
            result2.__dir__ = -1;
            result2.__filtered__ = true;
          } else {
            result2 = this.clone();
            result2.__dir__ *= -1;
          }
          return result2;
        }
        function lazyValue() {
          var array = this.__wrapped__.value(), dir = this.__dir__, isArr = isArray2(array), isRight = dir < 0, arrLength = isArr ? array.length : 0, view = getView(0, arrLength, this.__views__), start = view.start, end = view.end, length = end - start, index = isRight ? end : start - 1, iteratees = this.__iteratees__, iterLength = iteratees.length, resIndex = 0, takeCount = nativeMin(length, this.__takeCount__);
          if (!isArr || !isRight && arrLength == length && takeCount == length) {
            return baseWrapperValue(array, this.__actions__);
          }
          var result2 = [];
          outer:
            while (length-- && resIndex < takeCount) {
              index += dir;
              var iterIndex = -1, value2 = array[index];
              while (++iterIndex < iterLength) {
                var data = iteratees[iterIndex], iteratee2 = data.iteratee, type = data.type, computed = iteratee2(value2);
                if (type == LAZY_MAP_FLAG) {
                  value2 = computed;
                } else if (!computed) {
                  if (type == LAZY_FILTER_FLAG) {
                    continue outer;
                  } else {
                    break outer;
                  }
                }
              }
              result2[resIndex++] = value2;
            }
          return result2;
        }
        LazyWrapper.prototype = baseCreate(baseLodash.prototype);
        LazyWrapper.prototype.constructor = LazyWrapper;
        function Hash(entries) {
          var index = -1, length = entries == null ? 0 : entries.length;
          this.clear();
          while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
          }
        }
        function hashClear() {
          this.__data__ = nativeCreate ? nativeCreate(null) : {};
          this.size = 0;
        }
        function hashDelete(key) {
          var result2 = this.has(key) && delete this.__data__[key];
          this.size -= result2 ? 1 : 0;
          return result2;
        }
        function hashGet(key) {
          var data = this.__data__;
          if (nativeCreate) {
            var result2 = data[key];
            return result2 === HASH_UNDEFINED ? undefined2 : result2;
          }
          return hasOwnProperty.call(data, key) ? data[key] : undefined2;
        }
        function hashHas(key) {
          var data = this.__data__;
          return nativeCreate ? data[key] !== undefined2 : hasOwnProperty.call(data, key);
        }
        function hashSet(key, value2) {
          var data = this.__data__;
          this.size += this.has(key) ? 0 : 1;
          data[key] = nativeCreate && value2 === undefined2 ? HASH_UNDEFINED : value2;
          return this;
        }
        Hash.prototype.clear = hashClear;
        Hash.prototype["delete"] = hashDelete;
        Hash.prototype.get = hashGet;
        Hash.prototype.has = hashHas;
        Hash.prototype.set = hashSet;
        function ListCache(entries) {
          var index = -1, length = entries == null ? 0 : entries.length;
          this.clear();
          while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
          }
        }
        function listCacheClear() {
          this.__data__ = [];
          this.size = 0;
        }
        function listCacheDelete(key) {
          var data = this.__data__, index = assocIndexOf(data, key);
          if (index < 0) {
            return false;
          }
          var lastIndex = data.length - 1;
          if (index == lastIndex) {
            data.pop();
          } else {
            splice.call(data, index, 1);
          }
          --this.size;
          return true;
        }
        function listCacheGet(key) {
          var data = this.__data__, index = assocIndexOf(data, key);
          return index < 0 ? undefined2 : data[index][1];
        }
        function listCacheHas(key) {
          return assocIndexOf(this.__data__, key) > -1;
        }
        function listCacheSet(key, value2) {
          var data = this.__data__, index = assocIndexOf(data, key);
          if (index < 0) {
            ++this.size;
            data.push([key, value2]);
          } else {
            data[index][1] = value2;
          }
          return this;
        }
        ListCache.prototype.clear = listCacheClear;
        ListCache.prototype["delete"] = listCacheDelete;
        ListCache.prototype.get = listCacheGet;
        ListCache.prototype.has = listCacheHas;
        ListCache.prototype.set = listCacheSet;
        function MapCache(entries) {
          var index = -1, length = entries == null ? 0 : entries.length;
          this.clear();
          while (++index < length) {
            var entry = entries[index];
            this.set(entry[0], entry[1]);
          }
        }
        function mapCacheClear() {
          this.size = 0;
          this.__data__ = {
            "hash": new Hash(),
            "map": new (Map2 || ListCache)(),
            "string": new Hash()
          };
        }
        function mapCacheDelete(key) {
          var result2 = getMapData(this, key)["delete"](key);
          this.size -= result2 ? 1 : 0;
          return result2;
        }
        function mapCacheGet(key) {
          return getMapData(this, key).get(key);
        }
        function mapCacheHas(key) {
          return getMapData(this, key).has(key);
        }
        function mapCacheSet(key, value2) {
          var data = getMapData(this, key), size2 = data.size;
          data.set(key, value2);
          this.size += data.size == size2 ? 0 : 1;
          return this;
        }
        MapCache.prototype.clear = mapCacheClear;
        MapCache.prototype["delete"] = mapCacheDelete;
        MapCache.prototype.get = mapCacheGet;
        MapCache.prototype.has = mapCacheHas;
        MapCache.prototype.set = mapCacheSet;
        function SetCache(values3) {
          var index = -1, length = values3 == null ? 0 : values3.length;
          this.__data__ = new MapCache();
          while (++index < length) {
            this.add(values3[index]);
          }
        }
        function setCacheAdd(value2) {
          this.__data__.set(value2, HASH_UNDEFINED);
          return this;
        }
        function setCacheHas(value2) {
          return this.__data__.has(value2);
        }
        SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
        SetCache.prototype.has = setCacheHas;
        function Stack(entries) {
          var data = this.__data__ = new ListCache(entries);
          this.size = data.size;
        }
        function stackClear() {
          this.__data__ = new ListCache();
          this.size = 0;
        }
        function stackDelete(key) {
          var data = this.__data__, result2 = data["delete"](key);
          this.size = data.size;
          return result2;
        }
        function stackGet(key) {
          return this.__data__.get(key);
        }
        function stackHas(key) {
          return this.__data__.has(key);
        }
        function stackSet(key, value2) {
          var data = this.__data__;
          if (data instanceof ListCache) {
            var pairs = data.__data__;
            if (!Map2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
              pairs.push([key, value2]);
              this.size = ++data.size;
              return this;
            }
            data = this.__data__ = new MapCache(pairs);
          }
          data.set(key, value2);
          this.size = data.size;
          return this;
        }
        Stack.prototype.clear = stackClear;
        Stack.prototype["delete"] = stackDelete;
        Stack.prototype.get = stackGet;
        Stack.prototype.has = stackHas;
        Stack.prototype.set = stackSet;
        function arrayLikeKeys(value2, inherited) {
          var isArr = isArray2(value2), isArg = !isArr && isArguments(value2), isBuff = !isArr && !isArg && isBuffer(value2), isType = !isArr && !isArg && !isBuff && isTypedArray(value2), skipIndexes = isArr || isArg || isBuff || isType, result2 = skipIndexes ? baseTimes(value2.length, String2) : [], length = result2.length;
          for (var key in value2) {
            if ((inherited || hasOwnProperty.call(value2, key)) && !(skipIndexes && // Safari 9 has enumerable `arguments.length` in strict mode.
            (key == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
            isBuff && (key == "offset" || key == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
            isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || // Skip index properties.
            isIndex(key, length)))) {
              result2.push(key);
            }
          }
          return result2;
        }
        function arraySample(array) {
          var length = array.length;
          return length ? array[baseRandom(0, length - 1)] : undefined2;
        }
        function arraySampleSize(array, n) {
          return shuffleSelf(copyArray(array), baseClamp(n, 0, array.length));
        }
        function arrayShuffle(array) {
          return shuffleSelf(copyArray(array));
        }
        function assignMergeValue(object, key, value2) {
          if (value2 !== undefined2 && !eq(object[key], value2) || value2 === undefined2 && !(key in object)) {
            baseAssignValue(object, key, value2);
          }
        }
        function assignValue(object, key, value2) {
          var objValue = object[key];
          if (!(hasOwnProperty.call(object, key) && eq(objValue, value2)) || value2 === undefined2 && !(key in object)) {
            baseAssignValue(object, key, value2);
          }
        }
        function assocIndexOf(array, key) {
          var length = array.length;
          while (length--) {
            if (eq(array[length][0], key)) {
              return length;
            }
          }
          return -1;
        }
        function baseAggregator(collection, setter, iteratee2, accumulator) {
          baseEach(collection, function(value2, key, collection2) {
            setter(accumulator, value2, iteratee2(value2), collection2);
          });
          return accumulator;
        }
        function baseAssign(object, source) {
          return object && copyObject(source, keys3(source), object);
        }
        function baseAssignIn(object, source) {
          return object && copyObject(source, keysIn(source), object);
        }
        function baseAssignValue(object, key, value2) {
          if (key == "__proto__" && defineProperty) {
            defineProperty(object, key, {
              "configurable": true,
              "enumerable": true,
              "value": value2,
              "writable": true
            });
          } else {
            object[key] = value2;
          }
        }
        function baseAt(object, paths) {
          var index = -1, length = paths.length, result2 = Array2(length), skip = object == null;
          while (++index < length) {
            result2[index] = skip ? undefined2 : get(object, paths[index]);
          }
          return result2;
        }
        function baseClamp(number, lower, upper) {
          if (number === number) {
            if (upper !== undefined2) {
              number = number <= upper ? number : upper;
            }
            if (lower !== undefined2) {
              number = number >= lower ? number : lower;
            }
          }
          return number;
        }
        function baseClone(value2, bitmask, customizer, key, object, stack) {
          var result2, isDeep = bitmask & CLONE_DEEP_FLAG, isFlat = bitmask & CLONE_FLAT_FLAG, isFull = bitmask & CLONE_SYMBOLS_FLAG;
          if (customizer) {
            result2 = object ? customizer(value2, key, object, stack) : customizer(value2);
          }
          if (result2 !== undefined2) {
            return result2;
          }
          if (!isObject(value2)) {
            return value2;
          }
          var isArr = isArray2(value2);
          if (isArr) {
            result2 = initCloneArray(value2);
            if (!isDeep) {
              return copyArray(value2, result2);
            }
          } else {
            var tag = getTag(value2), isFunc = tag == funcTag || tag == genTag;
            if (isBuffer(value2)) {
              return cloneBuffer(value2, isDeep);
            }
            if (tag == objectTag || tag == argsTag || isFunc && !object) {
              result2 = isFlat || isFunc ? {} : initCloneObject(value2);
              if (!isDeep) {
                return isFlat ? copySymbolsIn(value2, baseAssignIn(result2, value2)) : copySymbols(value2, baseAssign(result2, value2));
              }
            } else {
              if (!cloneableTags[tag]) {
                return object ? value2 : {};
              }
              result2 = initCloneByTag(value2, tag, isDeep);
            }
          }
          stack || (stack = new Stack());
          var stacked = stack.get(value2);
          if (stacked) {
            return stacked;
          }
          stack.set(value2, result2);
          if (isSet(value2)) {
            value2.forEach(function(subValue) {
              result2.add(baseClone(subValue, bitmask, customizer, subValue, value2, stack));
            });
          } else if (isMap(value2)) {
            value2.forEach(function(subValue, key2) {
              result2.set(key2, baseClone(subValue, bitmask, customizer, key2, value2, stack));
            });
          }
          var keysFunc = isFull ? isFlat ? getAllKeysIn : getAllKeys : isFlat ? keysIn : keys3;
          var props = isArr ? undefined2 : keysFunc(value2);
          arrayEach(props || value2, function(subValue, key2) {
            if (props) {
              key2 = subValue;
              subValue = value2[key2];
            }
            assignValue(result2, key2, baseClone(subValue, bitmask, customizer, key2, value2, stack));
          });
          return result2;
        }
        function baseConforms(source) {
          var props = keys3(source);
          return function(object) {
            return baseConformsTo(object, source, props);
          };
        }
        function baseConformsTo(object, source, props) {
          var length = props.length;
          if (object == null) {
            return !length;
          }
          object = Object2(object);
          while (length--) {
            var key = props[length], predicate = source[key], value2 = object[key];
            if (value2 === undefined2 && !(key in object) || !predicate(value2)) {
              return false;
            }
          }
          return true;
        }
        function baseDelay(func, wait, args) {
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          return setTimeout2(function() {
            func.apply(undefined2, args);
          }, wait);
        }
        function baseDifference(array, values3, iteratee2, comparator) {
          var index = -1, includes2 = arrayIncludes, isCommon = true, length = array.length, result2 = [], valuesLength = values3.length;
          if (!length) {
            return result2;
          }
          if (iteratee2) {
            values3 = arrayMap(values3, baseUnary(iteratee2));
          }
          if (comparator) {
            includes2 = arrayIncludesWith;
            isCommon = false;
          } else if (values3.length >= LARGE_ARRAY_SIZE) {
            includes2 = cacheHas;
            isCommon = false;
            values3 = new SetCache(values3);
          }
          outer:
            while (++index < length) {
              var value2 = array[index], computed = iteratee2 == null ? value2 : iteratee2(value2);
              value2 = comparator || value2 !== 0 ? value2 : 0;
              if (isCommon && computed === computed) {
                var valuesIndex = valuesLength;
                while (valuesIndex--) {
                  if (values3[valuesIndex] === computed) {
                    continue outer;
                  }
                }
                result2.push(value2);
              } else if (!includes2(values3, computed, comparator)) {
                result2.push(value2);
              }
            }
          return result2;
        }
        var baseEach = createBaseEach(baseForOwn);
        var baseEachRight = createBaseEach(baseForOwnRight, true);
        function baseEvery(collection, predicate) {
          var result2 = true;
          baseEach(collection, function(value2, index, collection2) {
            result2 = !!predicate(value2, index, collection2);
            return result2;
          });
          return result2;
        }
        function baseExtremum(array, iteratee2, comparator) {
          var index = -1, length = array.length;
          while (++index < length) {
            var value2 = array[index], current = iteratee2(value2);
            if (current != null && (computed === undefined2 ? current === current && !isSymbol(current) : comparator(current, computed))) {
              var computed = current, result2 = value2;
            }
          }
          return result2;
        }
        function baseFill(array, value2, start, end) {
          var length = array.length;
          start = toInteger(start);
          if (start < 0) {
            start = -start > length ? 0 : length + start;
          }
          end = end === undefined2 || end > length ? length : toInteger(end);
          if (end < 0) {
            end += length;
          }
          end = start > end ? 0 : toLength(end);
          while (start < end) {
            array[start++] = value2;
          }
          return array;
        }
        function baseFilter(collection, predicate) {
          var result2 = [];
          baseEach(collection, function(value2, index, collection2) {
            if (predicate(value2, index, collection2)) {
              result2.push(value2);
            }
          });
          return result2;
        }
        function baseFlatten(array, depth, predicate, isStrict, result2) {
          var index = -1, length = array.length;
          predicate || (predicate = isFlattenable);
          result2 || (result2 = []);
          while (++index < length) {
            var value2 = array[index];
            if (depth > 0 && predicate(value2)) {
              if (depth > 1) {
                baseFlatten(value2, depth - 1, predicate, isStrict, result2);
              } else {
                arrayPush(result2, value2);
              }
            } else if (!isStrict) {
              result2[result2.length] = value2;
            }
          }
          return result2;
        }
        var baseFor = createBaseFor();
        var baseForRight = createBaseFor(true);
        function baseForOwn(object, iteratee2) {
          return object && baseFor(object, iteratee2, keys3);
        }
        function baseForOwnRight(object, iteratee2) {
          return object && baseForRight(object, iteratee2, keys3);
        }
        function baseFunctions(object, props) {
          return arrayFilter(props, function(key) {
            return isFunction(object[key]);
          });
        }
        function baseGet(object, path2) {
          path2 = castPath(path2, object);
          var index = 0, length = path2.length;
          while (object != null && index < length) {
            object = object[toKey(path2[index++])];
          }
          return index && index == length ? object : undefined2;
        }
        function baseGetAllKeys(object, keysFunc, symbolsFunc) {
          var result2 = keysFunc(object);
          return isArray2(object) ? result2 : arrayPush(result2, symbolsFunc(object));
        }
        function baseGetTag(value2) {
          if (value2 == null) {
            return value2 === undefined2 ? undefinedTag : nullTag;
          }
          return symToStringTag && symToStringTag in Object2(value2) ? getRawTag(value2) : objectToString(value2);
        }
        function baseGt(value2, other) {
          return value2 > other;
        }
        function baseHas(object, key) {
          return object != null && hasOwnProperty.call(object, key);
        }
        function baseHasIn(object, key) {
          return object != null && key in Object2(object);
        }
        function baseInRange(number, start, end) {
          return number >= nativeMin(start, end) && number < nativeMax(start, end);
        }
        function baseIntersection(arrays, iteratee2, comparator) {
          var includes2 = comparator ? arrayIncludesWith : arrayIncludes, length = arrays[0].length, othLength = arrays.length, othIndex = othLength, caches = Array2(othLength), maxLength = Infinity, result2 = [];
          while (othIndex--) {
            var array = arrays[othIndex];
            if (othIndex && iteratee2) {
              array = arrayMap(array, baseUnary(iteratee2));
            }
            maxLength = nativeMin(array.length, maxLength);
            caches[othIndex] = !comparator && (iteratee2 || length >= 120 && array.length >= 120) ? new SetCache(othIndex && array) : undefined2;
          }
          array = arrays[0];
          var index = -1, seen = caches[0];
          outer:
            while (++index < length && result2.length < maxLength) {
              var value2 = array[index], computed = iteratee2 ? iteratee2(value2) : value2;
              value2 = comparator || value2 !== 0 ? value2 : 0;
              if (!(seen ? cacheHas(seen, computed) : includes2(result2, computed, comparator))) {
                othIndex = othLength;
                while (--othIndex) {
                  var cache = caches[othIndex];
                  if (!(cache ? cacheHas(cache, computed) : includes2(arrays[othIndex], computed, comparator))) {
                    continue outer;
                  }
                }
                if (seen) {
                  seen.push(computed);
                }
                result2.push(value2);
              }
            }
          return result2;
        }
        function baseInverter(object, setter, iteratee2, accumulator) {
          baseForOwn(object, function(value2, key, object2) {
            setter(accumulator, iteratee2(value2), key, object2);
          });
          return accumulator;
        }
        function baseInvoke(object, path2, args) {
          path2 = castPath(path2, object);
          object = parent(object, path2);
          var func = object == null ? object : object[toKey(last2(path2))];
          return func == null ? undefined2 : apply(func, object, args);
        }
        function baseIsArguments(value2) {
          return isObjectLike(value2) && baseGetTag(value2) == argsTag;
        }
        function baseIsArrayBuffer(value2) {
          return isObjectLike(value2) && baseGetTag(value2) == arrayBufferTag;
        }
        function baseIsDate(value2) {
          return isObjectLike(value2) && baseGetTag(value2) == dateTag;
        }
        function baseIsEqual(value2, other, bitmask, customizer, stack) {
          if (value2 === other) {
            return true;
          }
          if (value2 == null || other == null || !isObjectLike(value2) && !isObjectLike(other)) {
            return value2 !== value2 && other !== other;
          }
          return baseIsEqualDeep(value2, other, bitmask, customizer, baseIsEqual, stack);
        }
        function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
          var objIsArr = isArray2(object), othIsArr = isArray2(other), objTag = objIsArr ? arrayTag : getTag(object), othTag = othIsArr ? arrayTag : getTag(other);
          objTag = objTag == argsTag ? objectTag : objTag;
          othTag = othTag == argsTag ? objectTag : othTag;
          var objIsObj = objTag == objectTag, othIsObj = othTag == objectTag, isSameTag = objTag == othTag;
          if (isSameTag && isBuffer(object)) {
            if (!isBuffer(other)) {
              return false;
            }
            objIsArr = true;
            objIsObj = false;
          }
          if (isSameTag && !objIsObj) {
            stack || (stack = new Stack());
            return objIsArr || isTypedArray(object) ? equalArrays(object, other, bitmask, customizer, equalFunc, stack) : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
          }
          if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
            var objIsWrapped = objIsObj && hasOwnProperty.call(object, "__wrapped__"), othIsWrapped = othIsObj && hasOwnProperty.call(other, "__wrapped__");
            if (objIsWrapped || othIsWrapped) {
              var objUnwrapped = objIsWrapped ? object.value() : object, othUnwrapped = othIsWrapped ? other.value() : other;
              stack || (stack = new Stack());
              return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
            }
          }
          if (!isSameTag) {
            return false;
          }
          stack || (stack = new Stack());
          return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
        }
        function baseIsMap(value2) {
          return isObjectLike(value2) && getTag(value2) == mapTag;
        }
        function baseIsMatch(object, source, matchData, customizer) {
          var index = matchData.length, length = index, noCustomizer = !customizer;
          if (object == null) {
            return !length;
          }
          object = Object2(object);
          while (index--) {
            var data = matchData[index];
            if (noCustomizer && data[2] ? data[1] !== object[data[0]] : !(data[0] in object)) {
              return false;
            }
          }
          while (++index < length) {
            data = matchData[index];
            var key = data[0], objValue = object[key], srcValue = data[1];
            if (noCustomizer && data[2]) {
              if (objValue === undefined2 && !(key in object)) {
                return false;
              }
            } else {
              var stack = new Stack();
              if (customizer) {
                var result2 = customizer(objValue, srcValue, key, object, source, stack);
              }
              if (!(result2 === undefined2 ? baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG, customizer, stack) : result2)) {
                return false;
              }
            }
          }
          return true;
        }
        function baseIsNative(value2) {
          if (!isObject(value2) || isMasked(value2)) {
            return false;
          }
          var pattern = isFunction(value2) ? reIsNative : reIsHostCtor;
          return pattern.test(toSource(value2));
        }
        function baseIsRegExp(value2) {
          return isObjectLike(value2) && baseGetTag(value2) == regexpTag;
        }
        function baseIsSet(value2) {
          return isObjectLike(value2) && getTag(value2) == setTag;
        }
        function baseIsTypedArray(value2) {
          return isObjectLike(value2) && isLength(value2.length) && !!typedArrayTags[baseGetTag(value2)];
        }
        function baseIteratee(value2) {
          if (typeof value2 == "function") {
            return value2;
          }
          if (value2 == null) {
            return identity;
          }
          if (typeof value2 == "object") {
            return isArray2(value2) ? baseMatchesProperty(value2[0], value2[1]) : baseMatches(value2);
          }
          return property(value2);
        }
        function baseKeys(object) {
          if (!isPrototype(object)) {
            return nativeKeys(object);
          }
          var result2 = [];
          for (var key in Object2(object)) {
            if (hasOwnProperty.call(object, key) && key != "constructor") {
              result2.push(key);
            }
          }
          return result2;
        }
        function baseKeysIn(object) {
          if (!isObject(object)) {
            return nativeKeysIn(object);
          }
          var isProto = isPrototype(object), result2 = [];
          for (var key in object) {
            if (!(key == "constructor" && (isProto || !hasOwnProperty.call(object, key)))) {
              result2.push(key);
            }
          }
          return result2;
        }
        function baseLt(value2, other) {
          return value2 < other;
        }
        function baseMap(collection, iteratee2) {
          var index = -1, result2 = isArrayLike(collection) ? Array2(collection.length) : [];
          baseEach(collection, function(value2, key, collection2) {
            result2[++index] = iteratee2(value2, key, collection2);
          });
          return result2;
        }
        function baseMatches(source) {
          var matchData = getMatchData(source);
          if (matchData.length == 1 && matchData[0][2]) {
            return matchesStrictComparable(matchData[0][0], matchData[0][1]);
          }
          return function(object) {
            return object === source || baseIsMatch(object, source, matchData);
          };
        }
        function baseMatchesProperty(path2, srcValue) {
          if (isKey(path2) && isStrictComparable(srcValue)) {
            return matchesStrictComparable(toKey(path2), srcValue);
          }
          return function(object) {
            var objValue = get(object, path2);
            return objValue === undefined2 && objValue === srcValue ? hasIn(object, path2) : baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG);
          };
        }
        function baseMerge(object, source, srcIndex, customizer, stack) {
          if (object === source) {
            return;
          }
          baseFor(source, function(srcValue, key) {
            stack || (stack = new Stack());
            if (isObject(srcValue)) {
              baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack);
            } else {
              var newValue = customizer ? customizer(safeGet(object, key), srcValue, key + "", object, source, stack) : undefined2;
              if (newValue === undefined2) {
                newValue = srcValue;
              }
              assignMergeValue(object, key, newValue);
            }
          }, keysIn);
        }
        function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack) {
          var objValue = safeGet(object, key), srcValue = safeGet(source, key), stacked = stack.get(srcValue);
          if (stacked) {
            assignMergeValue(object, key, stacked);
            return;
          }
          var newValue = customizer ? customizer(objValue, srcValue, key + "", object, source, stack) : undefined2;
          var isCommon = newValue === undefined2;
          if (isCommon) {
            var isArr = isArray2(srcValue), isBuff = !isArr && isBuffer(srcValue), isTyped = !isArr && !isBuff && isTypedArray(srcValue);
            newValue = srcValue;
            if (isArr || isBuff || isTyped) {
              if (isArray2(objValue)) {
                newValue = objValue;
              } else if (isArrayLikeObject(objValue)) {
                newValue = copyArray(objValue);
              } else if (isBuff) {
                isCommon = false;
                newValue = cloneBuffer(srcValue, true);
              } else if (isTyped) {
                isCommon = false;
                newValue = cloneTypedArray(srcValue, true);
              } else {
                newValue = [];
              }
            } else if (isPlainObject(srcValue) || isArguments(srcValue)) {
              newValue = objValue;
              if (isArguments(objValue)) {
                newValue = toPlainObject(objValue);
              } else if (!isObject(objValue) || isFunction(objValue)) {
                newValue = initCloneObject(srcValue);
              }
            } else {
              isCommon = false;
            }
          }
          if (isCommon) {
            stack.set(srcValue, newValue);
            mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
            stack["delete"](srcValue);
          }
          assignMergeValue(object, key, newValue);
        }
        function baseNth(array, n) {
          var length = array.length;
          if (!length) {
            return;
          }
          n += n < 0 ? length : 0;
          return isIndex(n, length) ? array[n] : undefined2;
        }
        function baseOrderBy(collection, iteratees, orders) {
          if (iteratees.length) {
            iteratees = arrayMap(iteratees, function(iteratee2) {
              if (isArray2(iteratee2)) {
                return function(value2) {
                  return baseGet(value2, iteratee2.length === 1 ? iteratee2[0] : iteratee2);
                };
              }
              return iteratee2;
            });
          } else {
            iteratees = [identity];
          }
          var index = -1;
          iteratees = arrayMap(iteratees, baseUnary(getIteratee()));
          var result2 = baseMap(collection, function(value2, key, collection2) {
            var criteria = arrayMap(iteratees, function(iteratee2) {
              return iteratee2(value2);
            });
            return { "criteria": criteria, "index": ++index, "value": value2 };
          });
          return baseSortBy(result2, function(object, other) {
            return compareMultiple(object, other, orders);
          });
        }
        function basePick(object, paths) {
          return basePickBy(object, paths, function(value2, path2) {
            return hasIn(object, path2);
          });
        }
        function basePickBy(object, paths, predicate) {
          var index = -1, length = paths.length, result2 = {};
          while (++index < length) {
            var path2 = paths[index], value2 = baseGet(object, path2);
            if (predicate(value2, path2)) {
              baseSet(result2, castPath(path2, object), value2);
            }
          }
          return result2;
        }
        function basePropertyDeep(path2) {
          return function(object) {
            return baseGet(object, path2);
          };
        }
        function basePullAll(array, values3, iteratee2, comparator) {
          var indexOf2 = comparator ? baseIndexOfWith : baseIndexOf, index = -1, length = values3.length, seen = array;
          if (array === values3) {
            values3 = copyArray(values3);
          }
          if (iteratee2) {
            seen = arrayMap(array, baseUnary(iteratee2));
          }
          while (++index < length) {
            var fromIndex = 0, value2 = values3[index], computed = iteratee2 ? iteratee2(value2) : value2;
            while ((fromIndex = indexOf2(seen, computed, fromIndex, comparator)) > -1) {
              if (seen !== array) {
                splice.call(seen, fromIndex, 1);
              }
              splice.call(array, fromIndex, 1);
            }
          }
          return array;
        }
        function basePullAt(array, indexes) {
          var length = array ? indexes.length : 0, lastIndex = length - 1;
          while (length--) {
            var index = indexes[length];
            if (length == lastIndex || index !== previous) {
              var previous = index;
              if (isIndex(index)) {
                splice.call(array, index, 1);
              } else {
                baseUnset(array, index);
              }
            }
          }
          return array;
        }
        function baseRandom(lower, upper) {
          return lower + nativeFloor(nativeRandom() * (upper - lower + 1));
        }
        function baseRange(start, end, step, fromRight) {
          var index = -1, length = nativeMax(nativeCeil((end - start) / (step || 1)), 0), result2 = Array2(length);
          while (length--) {
            result2[fromRight ? length : ++index] = start;
            start += step;
          }
          return result2;
        }
        function baseRepeat(string, n) {
          var result2 = "";
          if (!string || n < 1 || n > MAX_SAFE_INTEGER) {
            return result2;
          }
          do {
            if (n % 2) {
              result2 += string;
            }
            n = nativeFloor(n / 2);
            if (n) {
              string += string;
            }
          } while (n);
          return result2;
        }
        function baseRest(func, start) {
          return setToString(overRest(func, start, identity), func + "");
        }
        function baseSample(collection) {
          return arraySample(values2(collection));
        }
        function baseSampleSize(collection, n) {
          var array = values2(collection);
          return shuffleSelf(array, baseClamp(n, 0, array.length));
        }
        function baseSet(object, path2, value2, customizer) {
          if (!isObject(object)) {
            return object;
          }
          path2 = castPath(path2, object);
          var index = -1, length = path2.length, lastIndex = length - 1, nested = object;
          while (nested != null && ++index < length) {
            var key = toKey(path2[index]), newValue = value2;
            if (key === "__proto__" || key === "constructor" || key === "prototype") {
              return object;
            }
            if (index != lastIndex) {
              var objValue = nested[key];
              newValue = customizer ? customizer(objValue, key, nested) : undefined2;
              if (newValue === undefined2) {
                newValue = isObject(objValue) ? objValue : isIndex(path2[index + 1]) ? [] : {};
              }
            }
            assignValue(nested, key, newValue);
            nested = nested[key];
          }
          return object;
        }
        var baseSetData = !metaMap ? identity : function(func, data) {
          metaMap.set(func, data);
          return func;
        };
        var baseSetToString = !defineProperty ? identity : function(func, string) {
          return defineProperty(func, "toString", {
            "configurable": true,
            "enumerable": false,
            "value": constant(string),
            "writable": true
          });
        };
        function baseShuffle(collection) {
          return shuffleSelf(values2(collection));
        }
        function baseSlice(array, start, end) {
          var index = -1, length = array.length;
          if (start < 0) {
            start = -start > length ? 0 : length + start;
          }
          end = end > length ? length : end;
          if (end < 0) {
            end += length;
          }
          length = start > end ? 0 : end - start >>> 0;
          start >>>= 0;
          var result2 = Array2(length);
          while (++index < length) {
            result2[index] = array[index + start];
          }
          return result2;
        }
        function baseSome(collection, predicate) {
          var result2;
          baseEach(collection, function(value2, index, collection2) {
            result2 = predicate(value2, index, collection2);
            return !result2;
          });
          return !!result2;
        }
        function baseSortedIndex(array, value2, retHighest) {
          var low = 0, high = array == null ? low : array.length;
          if (typeof value2 == "number" && value2 === value2 && high <= HALF_MAX_ARRAY_LENGTH) {
            while (low < high) {
              var mid = low + high >>> 1, computed = array[mid];
              if (computed !== null && !isSymbol(computed) && (retHighest ? computed <= value2 : computed < value2)) {
                low = mid + 1;
              } else {
                high = mid;
              }
            }
            return high;
          }
          return baseSortedIndexBy(array, value2, identity, retHighest);
        }
        function baseSortedIndexBy(array, value2, iteratee2, retHighest) {
          var low = 0, high = array == null ? 0 : array.length;
          if (high === 0) {
            return 0;
          }
          value2 = iteratee2(value2);
          var valIsNaN = value2 !== value2, valIsNull = value2 === null, valIsSymbol = isSymbol(value2), valIsUndefined = value2 === undefined2;
          while (low < high) {
            var mid = nativeFloor((low + high) / 2), computed = iteratee2(array[mid]), othIsDefined = computed !== undefined2, othIsNull = computed === null, othIsReflexive = computed === computed, othIsSymbol = isSymbol(computed);
            if (valIsNaN) {
              var setLow = retHighest || othIsReflexive;
            } else if (valIsUndefined) {
              setLow = othIsReflexive && (retHighest || othIsDefined);
            } else if (valIsNull) {
              setLow = othIsReflexive && othIsDefined && (retHighest || !othIsNull);
            } else if (valIsSymbol) {
              setLow = othIsReflexive && othIsDefined && !othIsNull && (retHighest || !othIsSymbol);
            } else if (othIsNull || othIsSymbol) {
              setLow = false;
            } else {
              setLow = retHighest ? computed <= value2 : computed < value2;
            }
            if (setLow) {
              low = mid + 1;
            } else {
              high = mid;
            }
          }
          return nativeMin(high, MAX_ARRAY_INDEX);
        }
        function baseSortedUniq(array, iteratee2) {
          var index = -1, length = array.length, resIndex = 0, result2 = [];
          while (++index < length) {
            var value2 = array[index], computed = iteratee2 ? iteratee2(value2) : value2;
            if (!index || !eq(computed, seen)) {
              var seen = computed;
              result2[resIndex++] = value2 === 0 ? 0 : value2;
            }
          }
          return result2;
        }
        function baseToNumber(value2) {
          if (typeof value2 == "number") {
            return value2;
          }
          if (isSymbol(value2)) {
            return NAN;
          }
          return +value2;
        }
        function baseToString(value2) {
          if (typeof value2 == "string") {
            return value2;
          }
          if (isArray2(value2)) {
            return arrayMap(value2, baseToString) + "";
          }
          if (isSymbol(value2)) {
            return symbolToString ? symbolToString.call(value2) : "";
          }
          var result2 = value2 + "";
          return result2 == "0" && 1 / value2 == -INFINITY ? "-0" : result2;
        }
        function baseUniq(array, iteratee2, comparator) {
          var index = -1, includes2 = arrayIncludes, length = array.length, isCommon = true, result2 = [], seen = result2;
          if (comparator) {
            isCommon = false;
            includes2 = arrayIncludesWith;
          } else if (length >= LARGE_ARRAY_SIZE) {
            var set2 = iteratee2 ? null : createSet(array);
            if (set2) {
              return setToArray(set2);
            }
            isCommon = false;
            includes2 = cacheHas;
            seen = new SetCache();
          } else {
            seen = iteratee2 ? [] : result2;
          }
          outer:
            while (++index < length) {
              var value2 = array[index], computed = iteratee2 ? iteratee2(value2) : value2;
              value2 = comparator || value2 !== 0 ? value2 : 0;
              if (isCommon && computed === computed) {
                var seenIndex = seen.length;
                while (seenIndex--) {
                  if (seen[seenIndex] === computed) {
                    continue outer;
                  }
                }
                if (iteratee2) {
                  seen.push(computed);
                }
                result2.push(value2);
              } else if (!includes2(seen, computed, comparator)) {
                if (seen !== result2) {
                  seen.push(computed);
                }
                result2.push(value2);
              }
            }
          return result2;
        }
        function baseUnset(object, path2) {
          path2 = castPath(path2, object);
          object = parent(object, path2);
          return object == null || delete object[toKey(last2(path2))];
        }
        function baseUpdate(object, path2, updater, customizer) {
          return baseSet(object, path2, updater(baseGet(object, path2)), customizer);
        }
        function baseWhile(array, predicate, isDrop, fromRight) {
          var length = array.length, index = fromRight ? length : -1;
          while ((fromRight ? index-- : ++index < length) && predicate(array[index], index, array)) {
          }
          return isDrop ? baseSlice(array, fromRight ? 0 : index, fromRight ? index + 1 : length) : baseSlice(array, fromRight ? index + 1 : 0, fromRight ? length : index);
        }
        function baseWrapperValue(value2, actions) {
          var result2 = value2;
          if (result2 instanceof LazyWrapper) {
            result2 = result2.value();
          }
          return arrayReduce(actions, function(result3, action) {
            return action.func.apply(action.thisArg, arrayPush([result3], action.args));
          }, result2);
        }
        function baseXor(arrays, iteratee2, comparator) {
          var length = arrays.length;
          if (length < 2) {
            return length ? baseUniq(arrays[0]) : [];
          }
          var index = -1, result2 = Array2(length);
          while (++index < length) {
            var array = arrays[index], othIndex = -1;
            while (++othIndex < length) {
              if (othIndex != index) {
                result2[index] = baseDifference(result2[index] || array, arrays[othIndex], iteratee2, comparator);
              }
            }
          }
          return baseUniq(baseFlatten(result2, 1), iteratee2, comparator);
        }
        function baseZipObject(props, values3, assignFunc) {
          var index = -1, length = props.length, valsLength = values3.length, result2 = {};
          while (++index < length) {
            var value2 = index < valsLength ? values3[index] : undefined2;
            assignFunc(result2, props[index], value2);
          }
          return result2;
        }
        function castArrayLikeObject(value2) {
          return isArrayLikeObject(value2) ? value2 : [];
        }
        function castFunction(value2) {
          return typeof value2 == "function" ? value2 : identity;
        }
        function castPath(value2, object) {
          if (isArray2(value2)) {
            return value2;
          }
          return isKey(value2, object) ? [value2] : stringToPath(toString(value2));
        }
        var castRest = baseRest;
        function castSlice(array, start, end) {
          var length = array.length;
          end = end === undefined2 ? length : end;
          return !start && end >= length ? array : baseSlice(array, start, end);
        }
        var clearTimeout2 = ctxClearTimeout || function(id) {
          return root2.clearTimeout(id);
        };
        function cloneBuffer(buffer, isDeep) {
          if (isDeep) {
            return buffer.slice();
          }
          var length = buffer.length, result2 = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
          buffer.copy(result2);
          return result2;
        }
        function cloneArrayBuffer(arrayBuffer) {
          var result2 = new arrayBuffer.constructor(arrayBuffer.byteLength);
          new Uint8Array2(result2).set(new Uint8Array2(arrayBuffer));
          return result2;
        }
        function cloneDataView(dataView, isDeep) {
          var buffer = isDeep ? cloneArrayBuffer(dataView.buffer) : dataView.buffer;
          return new dataView.constructor(buffer, dataView.byteOffset, dataView.byteLength);
        }
        function cloneRegExp(regexp) {
          var result2 = new regexp.constructor(regexp.source, reFlags.exec(regexp));
          result2.lastIndex = regexp.lastIndex;
          return result2;
        }
        function cloneSymbol(symbol) {
          return symbolValueOf ? Object2(symbolValueOf.call(symbol)) : {};
        }
        function cloneTypedArray(typedArray, isDeep) {
          var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
          return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
        }
        function compareAscending(value2, other) {
          if (value2 !== other) {
            var valIsDefined = value2 !== undefined2, valIsNull = value2 === null, valIsReflexive = value2 === value2, valIsSymbol = isSymbol(value2);
            var othIsDefined = other !== undefined2, othIsNull = other === null, othIsReflexive = other === other, othIsSymbol = isSymbol(other);
            if (!othIsNull && !othIsSymbol && !valIsSymbol && value2 > other || valIsSymbol && othIsDefined && othIsReflexive && !othIsNull && !othIsSymbol || valIsNull && othIsDefined && othIsReflexive || !valIsDefined && othIsReflexive || !valIsReflexive) {
              return 1;
            }
            if (!valIsNull && !valIsSymbol && !othIsSymbol && value2 < other || othIsSymbol && valIsDefined && valIsReflexive && !valIsNull && !valIsSymbol || othIsNull && valIsDefined && valIsReflexive || !othIsDefined && valIsReflexive || !othIsReflexive) {
              return -1;
            }
          }
          return 0;
        }
        function compareMultiple(object, other, orders) {
          var index = -1, objCriteria = object.criteria, othCriteria = other.criteria, length = objCriteria.length, ordersLength = orders.length;
          while (++index < length) {
            var result2 = compareAscending(objCriteria[index], othCriteria[index]);
            if (result2) {
              if (index >= ordersLength) {
                return result2;
              }
              var order = orders[index];
              return result2 * (order == "desc" ? -1 : 1);
            }
          }
          return object.index - other.index;
        }
        function composeArgs(args, partials, holders, isCurried) {
          var argsIndex = -1, argsLength = args.length, holdersLength = holders.length, leftIndex = -1, leftLength = partials.length, rangeLength = nativeMax(argsLength - holdersLength, 0), result2 = Array2(leftLength + rangeLength), isUncurried = !isCurried;
          while (++leftIndex < leftLength) {
            result2[leftIndex] = partials[leftIndex];
          }
          while (++argsIndex < holdersLength) {
            if (isUncurried || argsIndex < argsLength) {
              result2[holders[argsIndex]] = args[argsIndex];
            }
          }
          while (rangeLength--) {
            result2[leftIndex++] = args[argsIndex++];
          }
          return result2;
        }
        function composeArgsRight(args, partials, holders, isCurried) {
          var argsIndex = -1, argsLength = args.length, holdersIndex = -1, holdersLength = holders.length, rightIndex = -1, rightLength = partials.length, rangeLength = nativeMax(argsLength - holdersLength, 0), result2 = Array2(rangeLength + rightLength), isUncurried = !isCurried;
          while (++argsIndex < rangeLength) {
            result2[argsIndex] = args[argsIndex];
          }
          var offset = argsIndex;
          while (++rightIndex < rightLength) {
            result2[offset + rightIndex] = partials[rightIndex];
          }
          while (++holdersIndex < holdersLength) {
            if (isUncurried || argsIndex < argsLength) {
              result2[offset + holders[holdersIndex]] = args[argsIndex++];
            }
          }
          return result2;
        }
        function copyArray(source, array) {
          var index = -1, length = source.length;
          array || (array = Array2(length));
          while (++index < length) {
            array[index] = source[index];
          }
          return array;
        }
        function copyObject(source, props, object, customizer) {
          var isNew = !object;
          object || (object = {});
          var index = -1, length = props.length;
          while (++index < length) {
            var key = props[index];
            var newValue = customizer ? customizer(object[key], source[key], key, object, source) : undefined2;
            if (newValue === undefined2) {
              newValue = source[key];
            }
            if (isNew) {
              baseAssignValue(object, key, newValue);
            } else {
              assignValue(object, key, newValue);
            }
          }
          return object;
        }
        function copySymbols(source, object) {
          return copyObject(source, getSymbols(source), object);
        }
        function copySymbolsIn(source, object) {
          return copyObject(source, getSymbolsIn(source), object);
        }
        function createAggregator(setter, initializer) {
          return function(collection, iteratee2) {
            var func = isArray2(collection) ? arrayAggregator : baseAggregator, accumulator = initializer ? initializer() : {};
            return func(collection, setter, getIteratee(iteratee2, 2), accumulator);
          };
        }
        function createAssigner(assigner) {
          return baseRest(function(object, sources) {
            var index = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : undefined2, guard = length > 2 ? sources[2] : undefined2;
            customizer = assigner.length > 3 && typeof customizer == "function" ? (length--, customizer) : undefined2;
            if (guard && isIterateeCall(sources[0], sources[1], guard)) {
              customizer = length < 3 ? undefined2 : customizer;
              length = 1;
            }
            object = Object2(object);
            while (++index < length) {
              var source = sources[index];
              if (source) {
                assigner(object, source, index, customizer);
              }
            }
            return object;
          });
        }
        function createBaseEach(eachFunc, fromRight) {
          return function(collection, iteratee2) {
            if (collection == null) {
              return collection;
            }
            if (!isArrayLike(collection)) {
              return eachFunc(collection, iteratee2);
            }
            var length = collection.length, index = fromRight ? length : -1, iterable = Object2(collection);
            while (fromRight ? index-- : ++index < length) {
              if (iteratee2(iterable[index], index, iterable) === false) {
                break;
              }
            }
            return collection;
          };
        }
        function createBaseFor(fromRight) {
          return function(object, iteratee2, keysFunc) {
            var index = -1, iterable = Object2(object), props = keysFunc(object), length = props.length;
            while (length--) {
              var key = props[fromRight ? length : ++index];
              if (iteratee2(iterable[key], key, iterable) === false) {
                break;
              }
            }
            return object;
          };
        }
        function createBind(func, bitmask, thisArg) {
          var isBind = bitmask & WRAP_BIND_FLAG, Ctor = createCtor(func);
          function wrapper() {
            var fn = this && this !== root2 && this instanceof wrapper ? Ctor : func;
            return fn.apply(isBind ? thisArg : this, arguments);
          }
          return wrapper;
        }
        function createCaseFirst(methodName) {
          return function(string) {
            string = toString(string);
            var strSymbols = hasUnicode(string) ? stringToArray(string) : undefined2;
            var chr = strSymbols ? strSymbols[0] : string.charAt(0);
            var trailing = strSymbols ? castSlice(strSymbols, 1).join("") : string.slice(1);
            return chr[methodName]() + trailing;
          };
        }
        function createCompounder(callback) {
          return function(string) {
            return arrayReduce(words(deburr(string).replace(reApos, "")), callback, "");
          };
        }
        function createCtor(Ctor) {
          return function() {
            var args = arguments;
            switch (args.length) {
              case 0:
                return new Ctor();
              case 1:
                return new Ctor(args[0]);
              case 2:
                return new Ctor(args[0], args[1]);
              case 3:
                return new Ctor(args[0], args[1], args[2]);
              case 4:
                return new Ctor(args[0], args[1], args[2], args[3]);
              case 5:
                return new Ctor(args[0], args[1], args[2], args[3], args[4]);
              case 6:
                return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5]);
              case 7:
                return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);
            }
            var thisBinding = baseCreate(Ctor.prototype), result2 = Ctor.apply(thisBinding, args);
            return isObject(result2) ? result2 : thisBinding;
          };
        }
        function createCurry(func, bitmask, arity) {
          var Ctor = createCtor(func);
          function wrapper() {
            var length = arguments.length, args = Array2(length), index = length, placeholder = getHolder(wrapper);
            while (index--) {
              args[index] = arguments[index];
            }
            var holders = length < 3 && args[0] !== placeholder && args[length - 1] !== placeholder ? [] : replaceHolders(args, placeholder);
            length -= holders.length;
            if (length < arity) {
              return createRecurry(
                func,
                bitmask,
                createHybrid,
                wrapper.placeholder,
                undefined2,
                args,
                holders,
                undefined2,
                undefined2,
                arity - length
              );
            }
            var fn = this && this !== root2 && this instanceof wrapper ? Ctor : func;
            return apply(fn, this, args);
          }
          return wrapper;
        }
        function createFind(findIndexFunc) {
          return function(collection, predicate, fromIndex) {
            var iterable = Object2(collection);
            if (!isArrayLike(collection)) {
              var iteratee2 = getIteratee(predicate, 3);
              collection = keys3(collection);
              predicate = function(key) {
                return iteratee2(iterable[key], key, iterable);
              };
            }
            var index = findIndexFunc(collection, predicate, fromIndex);
            return index > -1 ? iterable[iteratee2 ? collection[index] : index] : undefined2;
          };
        }
        function createFlow(fromRight) {
          return flatRest(function(funcs) {
            var length = funcs.length, index = length, prereq = LodashWrapper.prototype.thru;
            if (fromRight) {
              funcs.reverse();
            }
            while (index--) {
              var func = funcs[index];
              if (typeof func != "function") {
                throw new TypeError2(FUNC_ERROR_TEXT);
              }
              if (prereq && !wrapper && getFuncName(func) == "wrapper") {
                var wrapper = new LodashWrapper([], true);
              }
            }
            index = wrapper ? index : length;
            while (++index < length) {
              func = funcs[index];
              var funcName = getFuncName(func), data = funcName == "wrapper" ? getData(func) : undefined2;
              if (data && isLaziable(data[0]) && data[1] == (WRAP_ARY_FLAG | WRAP_CURRY_FLAG | WRAP_PARTIAL_FLAG | WRAP_REARG_FLAG) && !data[4].length && data[9] == 1) {
                wrapper = wrapper[getFuncName(data[0])].apply(wrapper, data[3]);
              } else {
                wrapper = func.length == 1 && isLaziable(func) ? wrapper[funcName]() : wrapper.thru(func);
              }
            }
            return function() {
              var args = arguments, value2 = args[0];
              if (wrapper && args.length == 1 && isArray2(value2)) {
                return wrapper.plant(value2).value();
              }
              var index2 = 0, result2 = length ? funcs[index2].apply(this, args) : value2;
              while (++index2 < length) {
                result2 = funcs[index2].call(this, result2);
              }
              return result2;
            };
          });
        }
        function createHybrid(func, bitmask, thisArg, partials, holders, partialsRight, holdersRight, argPos, ary2, arity) {
          var isAry = bitmask & WRAP_ARY_FLAG, isBind = bitmask & WRAP_BIND_FLAG, isBindKey = bitmask & WRAP_BIND_KEY_FLAG, isCurried = bitmask & (WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG), isFlip = bitmask & WRAP_FLIP_FLAG, Ctor = isBindKey ? undefined2 : createCtor(func);
          function wrapper() {
            var length = arguments.length, args = Array2(length), index = length;
            while (index--) {
              args[index] = arguments[index];
            }
            if (isCurried) {
              var placeholder = getHolder(wrapper), holdersCount = countHolders(args, placeholder);
            }
            if (partials) {
              args = composeArgs(args, partials, holders, isCurried);
            }
            if (partialsRight) {
              args = composeArgsRight(args, partialsRight, holdersRight, isCurried);
            }
            length -= holdersCount;
            if (isCurried && length < arity) {
              var newHolders = replaceHolders(args, placeholder);
              return createRecurry(
                func,
                bitmask,
                createHybrid,
                wrapper.placeholder,
                thisArg,
                args,
                newHolders,
                argPos,
                ary2,
                arity - length
              );
            }
            var thisBinding = isBind ? thisArg : this, fn = isBindKey ? thisBinding[func] : func;
            length = args.length;
            if (argPos) {
              args = reorder(args, argPos);
            } else if (isFlip && length > 1) {
              args.reverse();
            }
            if (isAry && ary2 < length) {
              args.length = ary2;
            }
            if (this && this !== root2 && this instanceof wrapper) {
              fn = Ctor || createCtor(fn);
            }
            return fn.apply(thisBinding, args);
          }
          return wrapper;
        }
        function createInverter(setter, toIteratee) {
          return function(object, iteratee2) {
            return baseInverter(object, setter, toIteratee(iteratee2), {});
          };
        }
        function createMathOperation(operator, defaultValue) {
          return function(value2, other) {
            var result2;
            if (value2 === undefined2 && other === undefined2) {
              return defaultValue;
            }
            if (value2 !== undefined2) {
              result2 = value2;
            }
            if (other !== undefined2) {
              if (result2 === undefined2) {
                return other;
              }
              if (typeof value2 == "string" || typeof other == "string") {
                value2 = baseToString(value2);
                other = baseToString(other);
              } else {
                value2 = baseToNumber(value2);
                other = baseToNumber(other);
              }
              result2 = operator(value2, other);
            }
            return result2;
          };
        }
        function createOver(arrayFunc) {
          return flatRest(function(iteratees) {
            iteratees = arrayMap(iteratees, baseUnary(getIteratee()));
            return baseRest(function(args) {
              var thisArg = this;
              return arrayFunc(iteratees, function(iteratee2) {
                return apply(iteratee2, thisArg, args);
              });
            });
          });
        }
        function createPadding(length, chars) {
          chars = chars === undefined2 ? " " : baseToString(chars);
          var charsLength = chars.length;
          if (charsLength < 2) {
            return charsLength ? baseRepeat(chars, length) : chars;
          }
          var result2 = baseRepeat(chars, nativeCeil(length / stringSize(chars)));
          return hasUnicode(chars) ? castSlice(stringToArray(result2), 0, length).join("") : result2.slice(0, length);
        }
        function createPartial(func, bitmask, thisArg, partials) {
          var isBind = bitmask & WRAP_BIND_FLAG, Ctor = createCtor(func);
          function wrapper() {
            var argsIndex = -1, argsLength = arguments.length, leftIndex = -1, leftLength = partials.length, args = Array2(leftLength + argsLength), fn = this && this !== root2 && this instanceof wrapper ? Ctor : func;
            while (++leftIndex < leftLength) {
              args[leftIndex] = partials[leftIndex];
            }
            while (argsLength--) {
              args[leftIndex++] = arguments[++argsIndex];
            }
            return apply(fn, isBind ? thisArg : this, args);
          }
          return wrapper;
        }
        function createRange(fromRight) {
          return function(start, end, step) {
            if (step && typeof step != "number" && isIterateeCall(start, end, step)) {
              end = step = undefined2;
            }
            start = toFinite(start);
            if (end === undefined2) {
              end = start;
              start = 0;
            } else {
              end = toFinite(end);
            }
            step = step === undefined2 ? start < end ? 1 : -1 : toFinite(step);
            return baseRange(start, end, step, fromRight);
          };
        }
        function createRelationalOperation(operator) {
          return function(value2, other) {
            if (!(typeof value2 == "string" && typeof other == "string")) {
              value2 = toNumber(value2);
              other = toNumber(other);
            }
            return operator(value2, other);
          };
        }
        function createRecurry(func, bitmask, wrapFunc, placeholder, thisArg, partials, holders, argPos, ary2, arity) {
          var isCurry = bitmask & WRAP_CURRY_FLAG, newHolders = isCurry ? holders : undefined2, newHoldersRight = isCurry ? undefined2 : holders, newPartials = isCurry ? partials : undefined2, newPartialsRight = isCurry ? undefined2 : partials;
          bitmask |= isCurry ? WRAP_PARTIAL_FLAG : WRAP_PARTIAL_RIGHT_FLAG;
          bitmask &= ~(isCurry ? WRAP_PARTIAL_RIGHT_FLAG : WRAP_PARTIAL_FLAG);
          if (!(bitmask & WRAP_CURRY_BOUND_FLAG)) {
            bitmask &= ~(WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG);
          }
          var newData = [
            func,
            bitmask,
            thisArg,
            newPartials,
            newHolders,
            newPartialsRight,
            newHoldersRight,
            argPos,
            ary2,
            arity
          ];
          var result2 = wrapFunc.apply(undefined2, newData);
          if (isLaziable(func)) {
            setData(result2, newData);
          }
          result2.placeholder = placeholder;
          return setWrapToString(result2, func, bitmask);
        }
        function createRound(methodName) {
          var func = Math2[methodName];
          return function(number, precision) {
            number = toNumber(number);
            precision = precision == null ? 0 : nativeMin(toInteger(precision), 292);
            if (precision && nativeIsFinite(number)) {
              var pair = (toString(number) + "e").split("e"), value2 = func(pair[0] + "e" + (+pair[1] + precision));
              pair = (toString(value2) + "e").split("e");
              return +(pair[0] + "e" + (+pair[1] - precision));
            }
            return func(number);
          };
        }
        var createSet = !(Set2 && 1 / setToArray(new Set2([, -0]))[1] == INFINITY) ? noop : function(values3) {
          return new Set2(values3);
        };
        function createToPairs(keysFunc) {
          return function(object) {
            var tag = getTag(object);
            if (tag == mapTag) {
              return mapToArray(object);
            }
            if (tag == setTag) {
              return setToPairs(object);
            }
            return baseToPairs(object, keysFunc(object));
          };
        }
        function createWrap(func, bitmask, thisArg, partials, holders, argPos, ary2, arity) {
          var isBindKey = bitmask & WRAP_BIND_KEY_FLAG;
          if (!isBindKey && typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          var length = partials ? partials.length : 0;
          if (!length) {
            bitmask &= ~(WRAP_PARTIAL_FLAG | WRAP_PARTIAL_RIGHT_FLAG);
            partials = holders = undefined2;
          }
          ary2 = ary2 === undefined2 ? ary2 : nativeMax(toInteger(ary2), 0);
          arity = arity === undefined2 ? arity : toInteger(arity);
          length -= holders ? holders.length : 0;
          if (bitmask & WRAP_PARTIAL_RIGHT_FLAG) {
            var partialsRight = partials, holdersRight = holders;
            partials = holders = undefined2;
          }
          var data = isBindKey ? undefined2 : getData(func);
          var newData = [
            func,
            bitmask,
            thisArg,
            partials,
            holders,
            partialsRight,
            holdersRight,
            argPos,
            ary2,
            arity
          ];
          if (data) {
            mergeData(newData, data);
          }
          func = newData[0];
          bitmask = newData[1];
          thisArg = newData[2];
          partials = newData[3];
          holders = newData[4];
          arity = newData[9] = newData[9] === undefined2 ? isBindKey ? 0 : func.length : nativeMax(newData[9] - length, 0);
          if (!arity && bitmask & (WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG)) {
            bitmask &= ~(WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG);
          }
          if (!bitmask || bitmask == WRAP_BIND_FLAG) {
            var result2 = createBind(func, bitmask, thisArg);
          } else if (bitmask == WRAP_CURRY_FLAG || bitmask == WRAP_CURRY_RIGHT_FLAG) {
            result2 = createCurry(func, bitmask, arity);
          } else if ((bitmask == WRAP_PARTIAL_FLAG || bitmask == (WRAP_BIND_FLAG | WRAP_PARTIAL_FLAG)) && !holders.length) {
            result2 = createPartial(func, bitmask, thisArg, partials);
          } else {
            result2 = createHybrid.apply(undefined2, newData);
          }
          var setter = data ? baseSetData : setData;
          return setWrapToString(setter(result2, newData), func, bitmask);
        }
        function customDefaultsAssignIn(objValue, srcValue, key, object) {
          if (objValue === undefined2 || eq(objValue, objectProto[key]) && !hasOwnProperty.call(object, key)) {
            return srcValue;
          }
          return objValue;
        }
        function customDefaultsMerge(objValue, srcValue, key, object, source, stack) {
          if (isObject(objValue) && isObject(srcValue)) {
            stack.set(srcValue, objValue);
            baseMerge(objValue, srcValue, undefined2, customDefaultsMerge, stack);
            stack["delete"](srcValue);
          }
          return objValue;
        }
        function customOmitClone(value2) {
          return isPlainObject(value2) ? undefined2 : value2;
        }
        function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
          var isPartial = bitmask & COMPARE_PARTIAL_FLAG, arrLength = array.length, othLength = other.length;
          if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
            return false;
          }
          var arrStacked = stack.get(array);
          var othStacked = stack.get(other);
          if (arrStacked && othStacked) {
            return arrStacked == other && othStacked == array;
          }
          var index = -1, result2 = true, seen = bitmask & COMPARE_UNORDERED_FLAG ? new SetCache() : undefined2;
          stack.set(array, other);
          stack.set(other, array);
          while (++index < arrLength) {
            var arrValue = array[index], othValue = other[index];
            if (customizer) {
              var compared = isPartial ? customizer(othValue, arrValue, index, other, array, stack) : customizer(arrValue, othValue, index, array, other, stack);
            }
            if (compared !== undefined2) {
              if (compared) {
                continue;
              }
              result2 = false;
              break;
            }
            if (seen) {
              if (!arraySome(other, function(othValue2, othIndex) {
                if (!cacheHas(seen, othIndex) && (arrValue === othValue2 || equalFunc(arrValue, othValue2, bitmask, customizer, stack))) {
                  return seen.push(othIndex);
                }
              })) {
                result2 = false;
                break;
              }
            } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
              result2 = false;
              break;
            }
          }
          stack["delete"](array);
          stack["delete"](other);
          return result2;
        }
        function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
          switch (tag) {
            case dataViewTag:
              if (object.byteLength != other.byteLength || object.byteOffset != other.byteOffset) {
                return false;
              }
              object = object.buffer;
              other = other.buffer;
            case arrayBufferTag:
              if (object.byteLength != other.byteLength || !equalFunc(new Uint8Array2(object), new Uint8Array2(other))) {
                return false;
              }
              return true;
            case boolTag:
            case dateTag:
            case numberTag:
              return eq(+object, +other);
            case errorTag:
              return object.name == other.name && object.message == other.message;
            case regexpTag:
            case stringTag:
              return object == other + "";
            case mapTag:
              var convert = mapToArray;
            case setTag:
              var isPartial = bitmask & COMPARE_PARTIAL_FLAG;
              convert || (convert = setToArray);
              if (object.size != other.size && !isPartial) {
                return false;
              }
              var stacked = stack.get(object);
              if (stacked) {
                return stacked == other;
              }
              bitmask |= COMPARE_UNORDERED_FLAG;
              stack.set(object, other);
              var result2 = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
              stack["delete"](object);
              return result2;
            case symbolTag:
              if (symbolValueOf) {
                return symbolValueOf.call(object) == symbolValueOf.call(other);
              }
          }
          return false;
        }
        function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
          var isPartial = bitmask & COMPARE_PARTIAL_FLAG, objProps = getAllKeys(object), objLength = objProps.length, othProps = getAllKeys(other), othLength = othProps.length;
          if (objLength != othLength && !isPartial) {
            return false;
          }
          var index = objLength;
          while (index--) {
            var key = objProps[index];
            if (!(isPartial ? key in other : hasOwnProperty.call(other, key))) {
              return false;
            }
          }
          var objStacked = stack.get(object);
          var othStacked = stack.get(other);
          if (objStacked && othStacked) {
            return objStacked == other && othStacked == object;
          }
          var result2 = true;
          stack.set(object, other);
          stack.set(other, object);
          var skipCtor = isPartial;
          while (++index < objLength) {
            key = objProps[index];
            var objValue = object[key], othValue = other[key];
            if (customizer) {
              var compared = isPartial ? customizer(othValue, objValue, key, other, object, stack) : customizer(objValue, othValue, key, object, other, stack);
            }
            if (!(compared === undefined2 ? objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack) : compared)) {
              result2 = false;
              break;
            }
            skipCtor || (skipCtor = key == "constructor");
          }
          if (result2 && !skipCtor) {
            var objCtor = object.constructor, othCtor = other.constructor;
            if (objCtor != othCtor && ("constructor" in object && "constructor" in other) && !(typeof objCtor == "function" && objCtor instanceof objCtor && typeof othCtor == "function" && othCtor instanceof othCtor)) {
              result2 = false;
            }
          }
          stack["delete"](object);
          stack["delete"](other);
          return result2;
        }
        function flatRest(func) {
          return setToString(overRest(func, undefined2, flatten), func + "");
        }
        function getAllKeys(object) {
          return baseGetAllKeys(object, keys3, getSymbols);
        }
        function getAllKeysIn(object) {
          return baseGetAllKeys(object, keysIn, getSymbolsIn);
        }
        var getData = !metaMap ? noop : function(func) {
          return metaMap.get(func);
        };
        function getFuncName(func) {
          var result2 = func.name + "", array = realNames[result2], length = hasOwnProperty.call(realNames, result2) ? array.length : 0;
          while (length--) {
            var data = array[length], otherFunc = data.func;
            if (otherFunc == null || otherFunc == func) {
              return data.name;
            }
          }
          return result2;
        }
        function getHolder(func) {
          var object = hasOwnProperty.call(lodash, "placeholder") ? lodash : func;
          return object.placeholder;
        }
        function getIteratee() {
          var result2 = lodash.iteratee || iteratee;
          result2 = result2 === iteratee ? baseIteratee : result2;
          return arguments.length ? result2(arguments[0], arguments[1]) : result2;
        }
        function getMapData(map2, key) {
          var data = map2.__data__;
          return isKeyable(key) ? data[typeof key == "string" ? "string" : "hash"] : data.map;
        }
        function getMatchData(object) {
          var result2 = keys3(object), length = result2.length;
          while (length--) {
            var key = result2[length], value2 = object[key];
            result2[length] = [key, value2, isStrictComparable(value2)];
          }
          return result2;
        }
        function getNative(object, key) {
          var value2 = getValue(object, key);
          return baseIsNative(value2) ? value2 : undefined2;
        }
        function getRawTag(value2) {
          var isOwn = hasOwnProperty.call(value2, symToStringTag), tag = value2[symToStringTag];
          try {
            value2[symToStringTag] = undefined2;
            var unmasked = true;
          } catch (e) {
          }
          var result2 = nativeObjectToString.call(value2);
          if (unmasked) {
            if (isOwn) {
              value2[symToStringTag] = tag;
            } else {
              delete value2[symToStringTag];
            }
          }
          return result2;
        }
        var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
          if (object == null) {
            return [];
          }
          object = Object2(object);
          return arrayFilter(nativeGetSymbols(object), function(symbol) {
            return propertyIsEnumerable.call(object, symbol);
          });
        };
        var getSymbolsIn = !nativeGetSymbols ? stubArray : function(object) {
          var result2 = [];
          while (object) {
            arrayPush(result2, getSymbols(object));
            object = getPrototype(object);
          }
          return result2;
        };
        var getTag = baseGetTag;
        if (DataView2 && getTag(new DataView2(new ArrayBuffer(1))) != dataViewTag || Map2 && getTag(new Map2()) != mapTag || Promise2 && getTag(Promise2.resolve()) != promiseTag || Set2 && getTag(new Set2()) != setTag || WeakMap2 && getTag(new WeakMap2()) != weakMapTag) {
          getTag = function(value2) {
            var result2 = baseGetTag(value2), Ctor = result2 == objectTag ? value2.constructor : undefined2, ctorString = Ctor ? toSource(Ctor) : "";
            if (ctorString) {
              switch (ctorString) {
                case dataViewCtorString:
                  return dataViewTag;
                case mapCtorString:
                  return mapTag;
                case promiseCtorString:
                  return promiseTag;
                case setCtorString:
                  return setTag;
                case weakMapCtorString:
                  return weakMapTag;
              }
            }
            return result2;
          };
        }
        function getView(start, end, transforms) {
          var index = -1, length = transforms.length;
          while (++index < length) {
            var data = transforms[index], size2 = data.size;
            switch (data.type) {
              case "drop":
                start += size2;
                break;
              case "dropRight":
                end -= size2;
                break;
              case "take":
                end = nativeMin(end, start + size2);
                break;
              case "takeRight":
                start = nativeMax(start, end - size2);
                break;
            }
          }
          return { "start": start, "end": end };
        }
        function getWrapDetails(source) {
          var match = source.match(reWrapDetails);
          return match ? match[1].split(reSplitDetails) : [];
        }
        function hasPath(object, path2, hasFunc) {
          path2 = castPath(path2, object);
          var index = -1, length = path2.length, result2 = false;
          while (++index < length) {
            var key = toKey(path2[index]);
            if (!(result2 = object != null && hasFunc(object, key))) {
              break;
            }
            object = object[key];
          }
          if (result2 || ++index != length) {
            return result2;
          }
          length = object == null ? 0 : object.length;
          return !!length && isLength(length) && isIndex(key, length) && (isArray2(object) || isArguments(object));
        }
        function initCloneArray(array) {
          var length = array.length, result2 = new array.constructor(length);
          if (length && typeof array[0] == "string" && hasOwnProperty.call(array, "index")) {
            result2.index = array.index;
            result2.input = array.input;
          }
          return result2;
        }
        function initCloneObject(object) {
          return typeof object.constructor == "function" && !isPrototype(object) ? baseCreate(getPrototype(object)) : {};
        }
        function initCloneByTag(object, tag, isDeep) {
          var Ctor = object.constructor;
          switch (tag) {
            case arrayBufferTag:
              return cloneArrayBuffer(object);
            case boolTag:
            case dateTag:
              return new Ctor(+object);
            case dataViewTag:
              return cloneDataView(object, isDeep);
            case float32Tag:
            case float64Tag:
            case int8Tag:
            case int16Tag:
            case int32Tag:
            case uint8Tag:
            case uint8ClampedTag:
            case uint16Tag:
            case uint32Tag:
              return cloneTypedArray(object, isDeep);
            case mapTag:
              return new Ctor();
            case numberTag:
            case stringTag:
              return new Ctor(object);
            case regexpTag:
              return cloneRegExp(object);
            case setTag:
              return new Ctor();
            case symbolTag:
              return cloneSymbol(object);
          }
        }
        function insertWrapDetails(source, details) {
          var length = details.length;
          if (!length) {
            return source;
          }
          var lastIndex = length - 1;
          details[lastIndex] = (length > 1 ? "& " : "") + details[lastIndex];
          details = details.join(length > 2 ? ", " : " ");
          return source.replace(reWrapComment, "{\n/* [wrapped with " + details + "] */\n");
        }
        function isFlattenable(value2) {
          return isArray2(value2) || isArguments(value2) || !!(spreadableSymbol && value2 && value2[spreadableSymbol]);
        }
        function isIndex(value2, length) {
          var type = typeof value2;
          length = length == null ? MAX_SAFE_INTEGER : length;
          return !!length && (type == "number" || type != "symbol" && reIsUint.test(value2)) && (value2 > -1 && value2 % 1 == 0 && value2 < length);
        }
        function isIterateeCall(value2, index, object) {
          if (!isObject(object)) {
            return false;
          }
          var type = typeof index;
          if (type == "number" ? isArrayLike(object) && isIndex(index, object.length) : type == "string" && index in object) {
            return eq(object[index], value2);
          }
          return false;
        }
        function isKey(value2, object) {
          if (isArray2(value2)) {
            return false;
          }
          var type = typeof value2;
          if (type == "number" || type == "symbol" || type == "boolean" || value2 == null || isSymbol(value2)) {
            return true;
          }
          return reIsPlainProp.test(value2) || !reIsDeepProp.test(value2) || object != null && value2 in Object2(object);
        }
        function isKeyable(value2) {
          var type = typeof value2;
          return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value2 !== "__proto__" : value2 === null;
        }
        function isLaziable(func) {
          var funcName = getFuncName(func), other = lodash[funcName];
          if (typeof other != "function" || !(funcName in LazyWrapper.prototype)) {
            return false;
          }
          if (func === other) {
            return true;
          }
          var data = getData(other);
          return !!data && func === data[0];
        }
        function isMasked(func) {
          return !!maskSrcKey && maskSrcKey in func;
        }
        var isMaskable = coreJsData ? isFunction : stubFalse;
        function isPrototype(value2) {
          var Ctor = value2 && value2.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto;
          return value2 === proto;
        }
        function isStrictComparable(value2) {
          return value2 === value2 && !isObject(value2);
        }
        function matchesStrictComparable(key, srcValue) {
          return function(object) {
            if (object == null) {
              return false;
            }
            return object[key] === srcValue && (srcValue !== undefined2 || key in Object2(object));
          };
        }
        function memoizeCapped(func) {
          var result2 = memoize(func, function(key) {
            if (cache.size === MAX_MEMOIZE_SIZE) {
              cache.clear();
            }
            return key;
          });
          var cache = result2.cache;
          return result2;
        }
        function mergeData(data, source) {
          var bitmask = data[1], srcBitmask = source[1], newBitmask = bitmask | srcBitmask, isCommon = newBitmask < (WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG | WRAP_ARY_FLAG);
          var isCombo = srcBitmask == WRAP_ARY_FLAG && bitmask == WRAP_CURRY_FLAG || srcBitmask == WRAP_ARY_FLAG && bitmask == WRAP_REARG_FLAG && data[7].length <= source[8] || srcBitmask == (WRAP_ARY_FLAG | WRAP_REARG_FLAG) && source[7].length <= source[8] && bitmask == WRAP_CURRY_FLAG;
          if (!(isCommon || isCombo)) {
            return data;
          }
          if (srcBitmask & WRAP_BIND_FLAG) {
            data[2] = source[2];
            newBitmask |= bitmask & WRAP_BIND_FLAG ? 0 : WRAP_CURRY_BOUND_FLAG;
          }
          var value2 = source[3];
          if (value2) {
            var partials = data[3];
            data[3] = partials ? composeArgs(partials, value2, source[4]) : value2;
            data[4] = partials ? replaceHolders(data[3], PLACEHOLDER) : source[4];
          }
          value2 = source[5];
          if (value2) {
            partials = data[5];
            data[5] = partials ? composeArgsRight(partials, value2, source[6]) : value2;
            data[6] = partials ? replaceHolders(data[5], PLACEHOLDER) : source[6];
          }
          value2 = source[7];
          if (value2) {
            data[7] = value2;
          }
          if (srcBitmask & WRAP_ARY_FLAG) {
            data[8] = data[8] == null ? source[8] : nativeMin(data[8], source[8]);
          }
          if (data[9] == null) {
            data[9] = source[9];
          }
          data[0] = source[0];
          data[1] = newBitmask;
          return data;
        }
        function nativeKeysIn(object) {
          var result2 = [];
          if (object != null) {
            for (var key in Object2(object)) {
              result2.push(key);
            }
          }
          return result2;
        }
        function objectToString(value2) {
          return nativeObjectToString.call(value2);
        }
        function overRest(func, start, transform2) {
          start = nativeMax(start === undefined2 ? func.length - 1 : start, 0);
          return function() {
            var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array2(length);
            while (++index < length) {
              array[index] = args[start + index];
            }
            index = -1;
            var otherArgs = Array2(start + 1);
            while (++index < start) {
              otherArgs[index] = args[index];
            }
            otherArgs[start] = transform2(array);
            return apply(func, this, otherArgs);
          };
        }
        function parent(object, path2) {
          return path2.length < 2 ? object : baseGet(object, baseSlice(path2, 0, -1));
        }
        function reorder(array, indexes) {
          var arrLength = array.length, length = nativeMin(indexes.length, arrLength), oldArray = copyArray(array);
          while (length--) {
            var index = indexes[length];
            array[length] = isIndex(index, arrLength) ? oldArray[index] : undefined2;
          }
          return array;
        }
        function safeGet(object, key) {
          if (key === "constructor" && typeof object[key] === "function") {
            return;
          }
          if (key == "__proto__") {
            return;
          }
          return object[key];
        }
        var setData = shortOut(baseSetData);
        var setTimeout2 = ctxSetTimeout || function(func, wait) {
          return root2.setTimeout(func, wait);
        };
        var setToString = shortOut(baseSetToString);
        function setWrapToString(wrapper, reference, bitmask) {
          var source = reference + "";
          return setToString(wrapper, insertWrapDetails(source, updateWrapDetails(getWrapDetails(source), bitmask)));
        }
        function shortOut(func) {
          var count = 0, lastCalled = 0;
          return function() {
            var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
            lastCalled = stamp;
            if (remaining > 0) {
              if (++count >= HOT_COUNT) {
                return arguments[0];
              }
            } else {
              count = 0;
            }
            return func.apply(undefined2, arguments);
          };
        }
        function shuffleSelf(array, size2) {
          var index = -1, length = array.length, lastIndex = length - 1;
          size2 = size2 === undefined2 ? length : size2;
          while (++index < size2) {
            var rand = baseRandom(index, lastIndex), value2 = array[rand];
            array[rand] = array[index];
            array[index] = value2;
          }
          array.length = size2;
          return array;
        }
        var stringToPath = memoizeCapped(function(string) {
          var result2 = [];
          if (string.charCodeAt(0) === 46) {
            result2.push("");
          }
          string.replace(rePropName, function(match, number, quote, subString) {
            result2.push(quote ? subString.replace(reEscapeChar, "$1") : number || match);
          });
          return result2;
        });
        function toKey(value2) {
          if (typeof value2 == "string" || isSymbol(value2)) {
            return value2;
          }
          var result2 = value2 + "";
          return result2 == "0" && 1 / value2 == -INFINITY ? "-0" : result2;
        }
        function toSource(func) {
          if (func != null) {
            try {
              return funcToString.call(func);
            } catch (e) {
            }
            try {
              return func + "";
            } catch (e) {
            }
          }
          return "";
        }
        function updateWrapDetails(details, bitmask) {
          arrayEach(wrapFlags, function(pair) {
            var value2 = "_." + pair[0];
            if (bitmask & pair[1] && !arrayIncludes(details, value2)) {
              details.push(value2);
            }
          });
          return details.sort();
        }
        function wrapperClone(wrapper) {
          if (wrapper instanceof LazyWrapper) {
            return wrapper.clone();
          }
          var result2 = new LodashWrapper(wrapper.__wrapped__, wrapper.__chain__);
          result2.__actions__ = copyArray(wrapper.__actions__);
          result2.__index__ = wrapper.__index__;
          result2.__values__ = wrapper.__values__;
          return result2;
        }
        function chunk(array, size2, guard) {
          if (guard ? isIterateeCall(array, size2, guard) : size2 === undefined2) {
            size2 = 1;
          } else {
            size2 = nativeMax(toInteger(size2), 0);
          }
          var length = array == null ? 0 : array.length;
          if (!length || size2 < 1) {
            return [];
          }
          var index = 0, resIndex = 0, result2 = Array2(nativeCeil(length / size2));
          while (index < length) {
            result2[resIndex++] = baseSlice(array, index, index += size2);
          }
          return result2;
        }
        function compact(array) {
          var index = -1, length = array == null ? 0 : array.length, resIndex = 0, result2 = [];
          while (++index < length) {
            var value2 = array[index];
            if (value2) {
              result2[resIndex++] = value2;
            }
          }
          return result2;
        }
        function concat() {
          var length = arguments.length;
          if (!length) {
            return [];
          }
          var args = Array2(length - 1), array = arguments[0], index = length;
          while (index--) {
            args[index - 1] = arguments[index];
          }
          return arrayPush(isArray2(array) ? copyArray(array) : [array], baseFlatten(args, 1));
        }
        var difference = baseRest(function(array, values3) {
          return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values3, 1, isArrayLikeObject, true)) : [];
        });
        var differenceBy = baseRest(function(array, values3) {
          var iteratee2 = last2(values3);
          if (isArrayLikeObject(iteratee2)) {
            iteratee2 = undefined2;
          }
          return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values3, 1, isArrayLikeObject, true), getIteratee(iteratee2, 2)) : [];
        });
        var differenceWith = baseRest(function(array, values3) {
          var comparator = last2(values3);
          if (isArrayLikeObject(comparator)) {
            comparator = undefined2;
          }
          return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values3, 1, isArrayLikeObject, true), undefined2, comparator) : [];
        });
        function drop(array, n, guard) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          n = guard || n === undefined2 ? 1 : toInteger(n);
          return baseSlice(array, n < 0 ? 0 : n, length);
        }
        function dropRight(array, n, guard) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          n = guard || n === undefined2 ? 1 : toInteger(n);
          n = length - n;
          return baseSlice(array, 0, n < 0 ? 0 : n);
        }
        function dropRightWhile(array, predicate) {
          return array && array.length ? baseWhile(array, getIteratee(predicate, 3), true, true) : [];
        }
        function dropWhile(array, predicate) {
          return array && array.length ? baseWhile(array, getIteratee(predicate, 3), true) : [];
        }
        function fill(array, value2, start, end) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          if (start && typeof start != "number" && isIterateeCall(array, value2, start)) {
            start = 0;
            end = length;
          }
          return baseFill(array, value2, start, end);
        }
        function findIndex(array, predicate, fromIndex) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return -1;
          }
          var index = fromIndex == null ? 0 : toInteger(fromIndex);
          if (index < 0) {
            index = nativeMax(length + index, 0);
          }
          return baseFindIndex(array, getIteratee(predicate, 3), index);
        }
        function findLastIndex(array, predicate, fromIndex) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return -1;
          }
          var index = length - 1;
          if (fromIndex !== undefined2) {
            index = toInteger(fromIndex);
            index = fromIndex < 0 ? nativeMax(length + index, 0) : nativeMin(index, length - 1);
          }
          return baseFindIndex(array, getIteratee(predicate, 3), index, true);
        }
        function flatten(array) {
          var length = array == null ? 0 : array.length;
          return length ? baseFlatten(array, 1) : [];
        }
        function flattenDeep(array) {
          var length = array == null ? 0 : array.length;
          return length ? baseFlatten(array, INFINITY) : [];
        }
        function flattenDepth(array, depth) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          depth = depth === undefined2 ? 1 : toInteger(depth);
          return baseFlatten(array, depth);
        }
        function fromPairs(pairs) {
          var index = -1, length = pairs == null ? 0 : pairs.length, result2 = {};
          while (++index < length) {
            var pair = pairs[index];
            result2[pair[0]] = pair[1];
          }
          return result2;
        }
        function head(array) {
          return array && array.length ? array[0] : undefined2;
        }
        function indexOf(array, value2, fromIndex) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return -1;
          }
          var index = fromIndex == null ? 0 : toInteger(fromIndex);
          if (index < 0) {
            index = nativeMax(length + index, 0);
          }
          return baseIndexOf(array, value2, index);
        }
        function initial(array) {
          var length = array == null ? 0 : array.length;
          return length ? baseSlice(array, 0, -1) : [];
        }
        var intersection = baseRest(function(arrays) {
          var mapped = arrayMap(arrays, castArrayLikeObject);
          return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped) : [];
        });
        var intersectionBy = baseRest(function(arrays) {
          var iteratee2 = last2(arrays), mapped = arrayMap(arrays, castArrayLikeObject);
          if (iteratee2 === last2(mapped)) {
            iteratee2 = undefined2;
          } else {
            mapped.pop();
          }
          return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped, getIteratee(iteratee2, 2)) : [];
        });
        var intersectionWith = baseRest(function(arrays) {
          var comparator = last2(arrays), mapped = arrayMap(arrays, castArrayLikeObject);
          comparator = typeof comparator == "function" ? comparator : undefined2;
          if (comparator) {
            mapped.pop();
          }
          return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped, undefined2, comparator) : [];
        });
        function join(array, separator) {
          return array == null ? "" : nativeJoin.call(array, separator);
        }
        function last2(array) {
          var length = array == null ? 0 : array.length;
          return length ? array[length - 1] : undefined2;
        }
        function lastIndexOf(array, value2, fromIndex) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return -1;
          }
          var index = length;
          if (fromIndex !== undefined2) {
            index = toInteger(fromIndex);
            index = index < 0 ? nativeMax(length + index, 0) : nativeMin(index, length - 1);
          }
          return value2 === value2 ? strictLastIndexOf(array, value2, index) : baseFindIndex(array, baseIsNaN, index, true);
        }
        function nth(array, n) {
          return array && array.length ? baseNth(array, toInteger(n)) : undefined2;
        }
        var pull = baseRest(pullAll);
        function pullAll(array, values3) {
          return array && array.length && values3 && values3.length ? basePullAll(array, values3) : array;
        }
        function pullAllBy(array, values3, iteratee2) {
          return array && array.length && values3 && values3.length ? basePullAll(array, values3, getIteratee(iteratee2, 2)) : array;
        }
        function pullAllWith(array, values3, comparator) {
          return array && array.length && values3 && values3.length ? basePullAll(array, values3, undefined2, comparator) : array;
        }
        var pullAt = flatRest(function(array, indexes) {
          var length = array == null ? 0 : array.length, result2 = baseAt(array, indexes);
          basePullAt(array, arrayMap(indexes, function(index) {
            return isIndex(index, length) ? +index : index;
          }).sort(compareAscending));
          return result2;
        });
        function remove(array, predicate) {
          var result2 = [];
          if (!(array && array.length)) {
            return result2;
          }
          var index = -1, indexes = [], length = array.length;
          predicate = getIteratee(predicate, 3);
          while (++index < length) {
            var value2 = array[index];
            if (predicate(value2, index, array)) {
              result2.push(value2);
              indexes.push(index);
            }
          }
          basePullAt(array, indexes);
          return result2;
        }
        function reverse(array) {
          return array == null ? array : nativeReverse.call(array);
        }
        function slice(array, start, end) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          if (end && typeof end != "number" && isIterateeCall(array, start, end)) {
            start = 0;
            end = length;
          } else {
            start = start == null ? 0 : toInteger(start);
            end = end === undefined2 ? length : toInteger(end);
          }
          return baseSlice(array, start, end);
        }
        function sortedIndex(array, value2) {
          return baseSortedIndex(array, value2);
        }
        function sortedIndexBy(array, value2, iteratee2) {
          return baseSortedIndexBy(array, value2, getIteratee(iteratee2, 2));
        }
        function sortedIndexOf(array, value2) {
          var length = array == null ? 0 : array.length;
          if (length) {
            var index = baseSortedIndex(array, value2);
            if (index < length && eq(array[index], value2)) {
              return index;
            }
          }
          return -1;
        }
        function sortedLastIndex(array, value2) {
          return baseSortedIndex(array, value2, true);
        }
        function sortedLastIndexBy(array, value2, iteratee2) {
          return baseSortedIndexBy(array, value2, getIteratee(iteratee2, 2), true);
        }
        function sortedLastIndexOf(array, value2) {
          var length = array == null ? 0 : array.length;
          if (length) {
            var index = baseSortedIndex(array, value2, true) - 1;
            if (eq(array[index], value2)) {
              return index;
            }
          }
          return -1;
        }
        function sortedUniq(array) {
          return array && array.length ? baseSortedUniq(array) : [];
        }
        function sortedUniqBy(array, iteratee2) {
          return array && array.length ? baseSortedUniq(array, getIteratee(iteratee2, 2)) : [];
        }
        function tail(array) {
          var length = array == null ? 0 : array.length;
          return length ? baseSlice(array, 1, length) : [];
        }
        function take(array, n, guard) {
          if (!(array && array.length)) {
            return [];
          }
          n = guard || n === undefined2 ? 1 : toInteger(n);
          return baseSlice(array, 0, n < 0 ? 0 : n);
        }
        function takeRight(array, n, guard) {
          var length = array == null ? 0 : array.length;
          if (!length) {
            return [];
          }
          n = guard || n === undefined2 ? 1 : toInteger(n);
          n = length - n;
          return baseSlice(array, n < 0 ? 0 : n, length);
        }
        function takeRightWhile(array, predicate) {
          return array && array.length ? baseWhile(array, getIteratee(predicate, 3), false, true) : [];
        }
        function takeWhile(array, predicate) {
          return array && array.length ? baseWhile(array, getIteratee(predicate, 3)) : [];
        }
        var union = baseRest(function(arrays) {
          return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true));
        });
        var unionBy = baseRest(function(arrays) {
          var iteratee2 = last2(arrays);
          if (isArrayLikeObject(iteratee2)) {
            iteratee2 = undefined2;
          }
          return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true), getIteratee(iteratee2, 2));
        });
        var unionWith = baseRest(function(arrays) {
          var comparator = last2(arrays);
          comparator = typeof comparator == "function" ? comparator : undefined2;
          return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true), undefined2, comparator);
        });
        function uniq(array) {
          return array && array.length ? baseUniq(array) : [];
        }
        function uniqBy(array, iteratee2) {
          return array && array.length ? baseUniq(array, getIteratee(iteratee2, 2)) : [];
        }
        function uniqWith(array, comparator) {
          comparator = typeof comparator == "function" ? comparator : undefined2;
          return array && array.length ? baseUniq(array, undefined2, comparator) : [];
        }
        function unzip(array) {
          if (!(array && array.length)) {
            return [];
          }
          var length = 0;
          array = arrayFilter(array, function(group) {
            if (isArrayLikeObject(group)) {
              length = nativeMax(group.length, length);
              return true;
            }
          });
          return baseTimes(length, function(index) {
            return arrayMap(array, baseProperty(index));
          });
        }
        function unzipWith(array, iteratee2) {
          if (!(array && array.length)) {
            return [];
          }
          var result2 = unzip(array);
          if (iteratee2 == null) {
            return result2;
          }
          return arrayMap(result2, function(group) {
            return apply(iteratee2, undefined2, group);
          });
        }
        var without = baseRest(function(array, values3) {
          return isArrayLikeObject(array) ? baseDifference(array, values3) : [];
        });
        var xor = baseRest(function(arrays) {
          return baseXor(arrayFilter(arrays, isArrayLikeObject));
        });
        var xorBy = baseRest(function(arrays) {
          var iteratee2 = last2(arrays);
          if (isArrayLikeObject(iteratee2)) {
            iteratee2 = undefined2;
          }
          return baseXor(arrayFilter(arrays, isArrayLikeObject), getIteratee(iteratee2, 2));
        });
        var xorWith = baseRest(function(arrays) {
          var comparator = last2(arrays);
          comparator = typeof comparator == "function" ? comparator : undefined2;
          return baseXor(arrayFilter(arrays, isArrayLikeObject), undefined2, comparator);
        });
        var zip = baseRest(unzip);
        function zipObject(props, values3) {
          return baseZipObject(props || [], values3 || [], assignValue);
        }
        function zipObjectDeep(props, values3) {
          return baseZipObject(props || [], values3 || [], baseSet);
        }
        var zipWith = baseRest(function(arrays) {
          var length = arrays.length, iteratee2 = length > 1 ? arrays[length - 1] : undefined2;
          iteratee2 = typeof iteratee2 == "function" ? (arrays.pop(), iteratee2) : undefined2;
          return unzipWith(arrays, iteratee2);
        });
        function chain(value2) {
          var result2 = lodash(value2);
          result2.__chain__ = true;
          return result2;
        }
        function tap(value2, interceptor) {
          interceptor(value2);
          return value2;
        }
        function thru(value2, interceptor) {
          return interceptor(value2);
        }
        var wrapperAt = flatRest(function(paths) {
          var length = paths.length, start = length ? paths[0] : 0, value2 = this.__wrapped__, interceptor = function(object) {
            return baseAt(object, paths);
          };
          if (length > 1 || this.__actions__.length || !(value2 instanceof LazyWrapper) || !isIndex(start)) {
            return this.thru(interceptor);
          }
          value2 = value2.slice(start, +start + (length ? 1 : 0));
          value2.__actions__.push({
            "func": thru,
            "args": [interceptor],
            "thisArg": undefined2
          });
          return new LodashWrapper(value2, this.__chain__).thru(function(array) {
            if (length && !array.length) {
              array.push(undefined2);
            }
            return array;
          });
        });
        function wrapperChain() {
          return chain(this);
        }
        function wrapperCommit() {
          return new LodashWrapper(this.value(), this.__chain__);
        }
        function wrapperNext() {
          if (this.__values__ === undefined2) {
            this.__values__ = toArray(this.value());
          }
          var done = this.__index__ >= this.__values__.length, value2 = done ? undefined2 : this.__values__[this.__index__++];
          return { "done": done, "value": value2 };
        }
        function wrapperToIterator() {
          return this;
        }
        function wrapperPlant(value2) {
          var result2, parent2 = this;
          while (parent2 instanceof baseLodash) {
            var clone2 = wrapperClone(parent2);
            clone2.__index__ = 0;
            clone2.__values__ = undefined2;
            if (result2) {
              previous.__wrapped__ = clone2;
            } else {
              result2 = clone2;
            }
            var previous = clone2;
            parent2 = parent2.__wrapped__;
          }
          previous.__wrapped__ = value2;
          return result2;
        }
        function wrapperReverse() {
          var value2 = this.__wrapped__;
          if (value2 instanceof LazyWrapper) {
            var wrapped = value2;
            if (this.__actions__.length) {
              wrapped = new LazyWrapper(this);
            }
            wrapped = wrapped.reverse();
            wrapped.__actions__.push({
              "func": thru,
              "args": [reverse],
              "thisArg": undefined2
            });
            return new LodashWrapper(wrapped, this.__chain__);
          }
          return this.thru(reverse);
        }
        function wrapperValue() {
          return baseWrapperValue(this.__wrapped__, this.__actions__);
        }
        var countBy = createAggregator(function(result2, value2, key) {
          if (hasOwnProperty.call(result2, key)) {
            ++result2[key];
          } else {
            baseAssignValue(result2, key, 1);
          }
        });
        function every(collection, predicate, guard) {
          var func = isArray2(collection) ? arrayEvery : baseEvery;
          if (guard && isIterateeCall(collection, predicate, guard)) {
            predicate = undefined2;
          }
          return func(collection, getIteratee(predicate, 3));
        }
        function filter(collection, predicate) {
          var func = isArray2(collection) ? arrayFilter : baseFilter;
          return func(collection, getIteratee(predicate, 3));
        }
        var find = createFind(findIndex);
        var findLast = createFind(findLastIndex);
        function flatMap(collection, iteratee2) {
          return baseFlatten(map(collection, iteratee2), 1);
        }
        function flatMapDeep(collection, iteratee2) {
          return baseFlatten(map(collection, iteratee2), INFINITY);
        }
        function flatMapDepth(collection, iteratee2, depth) {
          depth = depth === undefined2 ? 1 : toInteger(depth);
          return baseFlatten(map(collection, iteratee2), depth);
        }
        function forEach(collection, iteratee2) {
          var func = isArray2(collection) ? arrayEach : baseEach;
          return func(collection, getIteratee(iteratee2, 3));
        }
        function forEachRight(collection, iteratee2) {
          var func = isArray2(collection) ? arrayEachRight : baseEachRight;
          return func(collection, getIteratee(iteratee2, 3));
        }
        var groupBy = createAggregator(function(result2, value2, key) {
          if (hasOwnProperty.call(result2, key)) {
            result2[key].push(value2);
          } else {
            baseAssignValue(result2, key, [value2]);
          }
        });
        function includes(collection, value2, fromIndex, guard) {
          collection = isArrayLike(collection) ? collection : values2(collection);
          fromIndex = fromIndex && !guard ? toInteger(fromIndex) : 0;
          var length = collection.length;
          if (fromIndex < 0) {
            fromIndex = nativeMax(length + fromIndex, 0);
          }
          return isString(collection) ? fromIndex <= length && collection.indexOf(value2, fromIndex) > -1 : !!length && baseIndexOf(collection, value2, fromIndex) > -1;
        }
        var invokeMap = baseRest(function(collection, path2, args) {
          var index = -1, isFunc = typeof path2 == "function", result2 = isArrayLike(collection) ? Array2(collection.length) : [];
          baseEach(collection, function(value2) {
            result2[++index] = isFunc ? apply(path2, value2, args) : baseInvoke(value2, path2, args);
          });
          return result2;
        });
        var keyBy = createAggregator(function(result2, value2, key) {
          baseAssignValue(result2, key, value2);
        });
        function map(collection, iteratee2) {
          var func = isArray2(collection) ? arrayMap : baseMap;
          return func(collection, getIteratee(iteratee2, 3));
        }
        function orderBy(collection, iteratees, orders, guard) {
          if (collection == null) {
            return [];
          }
          if (!isArray2(iteratees)) {
            iteratees = iteratees == null ? [] : [iteratees];
          }
          orders = guard ? undefined2 : orders;
          if (!isArray2(orders)) {
            orders = orders == null ? [] : [orders];
          }
          return baseOrderBy(collection, iteratees, orders);
        }
        var partition = createAggregator(function(result2, value2, key) {
          result2[key ? 0 : 1].push(value2);
        }, function() {
          return [[], []];
        });
        function reduce(collection, iteratee2, accumulator) {
          var func = isArray2(collection) ? arrayReduce : baseReduce, initAccum = arguments.length < 3;
          return func(collection, getIteratee(iteratee2, 4), accumulator, initAccum, baseEach);
        }
        function reduceRight(collection, iteratee2, accumulator) {
          var func = isArray2(collection) ? arrayReduceRight : baseReduce, initAccum = arguments.length < 3;
          return func(collection, getIteratee(iteratee2, 4), accumulator, initAccum, baseEachRight);
        }
        function reject(collection, predicate) {
          var func = isArray2(collection) ? arrayFilter : baseFilter;
          return func(collection, negate(getIteratee(predicate, 3)));
        }
        function sample2(collection) {
          var func = isArray2(collection) ? arraySample : baseSample;
          return func(collection);
        }
        function sampleSize(collection, n, guard) {
          if (guard ? isIterateeCall(collection, n, guard) : n === undefined2) {
            n = 1;
          } else {
            n = toInteger(n);
          }
          var func = isArray2(collection) ? arraySampleSize : baseSampleSize;
          return func(collection, n);
        }
        function shuffle(collection) {
          var func = isArray2(collection) ? arrayShuffle : baseShuffle;
          return func(collection);
        }
        function size(collection) {
          if (collection == null) {
            return 0;
          }
          if (isArrayLike(collection)) {
            return isString(collection) ? stringSize(collection) : collection.length;
          }
          var tag = getTag(collection);
          if (tag == mapTag || tag == setTag) {
            return collection.size;
          }
          return baseKeys(collection).length;
        }
        function some(collection, predicate, guard) {
          var func = isArray2(collection) ? arraySome : baseSome;
          if (guard && isIterateeCall(collection, predicate, guard)) {
            predicate = undefined2;
          }
          return func(collection, getIteratee(predicate, 3));
        }
        var sortBy = baseRest(function(collection, iteratees) {
          if (collection == null) {
            return [];
          }
          var length = iteratees.length;
          if (length > 1 && isIterateeCall(collection, iteratees[0], iteratees[1])) {
            iteratees = [];
          } else if (length > 2 && isIterateeCall(iteratees[0], iteratees[1], iteratees[2])) {
            iteratees = [iteratees[0]];
          }
          return baseOrderBy(collection, baseFlatten(iteratees, 1), []);
        });
        var now = ctxNow || function() {
          return root2.Date.now();
        };
        function after(n, func) {
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          n = toInteger(n);
          return function() {
            if (--n < 1) {
              return func.apply(this, arguments);
            }
          };
        }
        function ary(func, n, guard) {
          n = guard ? undefined2 : n;
          n = func && n == null ? func.length : n;
          return createWrap(func, WRAP_ARY_FLAG, undefined2, undefined2, undefined2, undefined2, n);
        }
        function before(n, func) {
          var result2;
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          n = toInteger(n);
          return function() {
            if (--n > 0) {
              result2 = func.apply(this, arguments);
            }
            if (n <= 1) {
              func = undefined2;
            }
            return result2;
          };
        }
        var bind = baseRest(function(func, thisArg, partials) {
          var bitmask = WRAP_BIND_FLAG;
          if (partials.length) {
            var holders = replaceHolders(partials, getHolder(bind));
            bitmask |= WRAP_PARTIAL_FLAG;
          }
          return createWrap(func, bitmask, thisArg, partials, holders);
        });
        var bindKey = baseRest(function(object, key, partials) {
          var bitmask = WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG;
          if (partials.length) {
            var holders = replaceHolders(partials, getHolder(bindKey));
            bitmask |= WRAP_PARTIAL_FLAG;
          }
          return createWrap(key, bitmask, object, partials, holders);
        });
        function curry(func, arity, guard) {
          arity = guard ? undefined2 : arity;
          var result2 = createWrap(func, WRAP_CURRY_FLAG, undefined2, undefined2, undefined2, undefined2, undefined2, arity);
          result2.placeholder = curry.placeholder;
          return result2;
        }
        function curryRight(func, arity, guard) {
          arity = guard ? undefined2 : arity;
          var result2 = createWrap(func, WRAP_CURRY_RIGHT_FLAG, undefined2, undefined2, undefined2, undefined2, undefined2, arity);
          result2.placeholder = curryRight.placeholder;
          return result2;
        }
        function debounce(func, wait, options) {
          var lastArgs, lastThis, maxWait, result2, timerId, lastCallTime, lastInvokeTime = 0, leading = false, maxing = false, trailing = true;
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          wait = toNumber(wait) || 0;
          if (isObject(options)) {
            leading = !!options.leading;
            maxing = "maxWait" in options;
            maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
            trailing = "trailing" in options ? !!options.trailing : trailing;
          }
          function invokeFunc(time) {
            var args = lastArgs, thisArg = lastThis;
            lastArgs = lastThis = undefined2;
            lastInvokeTime = time;
            result2 = func.apply(thisArg, args);
            return result2;
          }
          function leadingEdge(time) {
            lastInvokeTime = time;
            timerId = setTimeout2(timerExpired, wait);
            return leading ? invokeFunc(time) : result2;
          }
          function remainingWait(time) {
            var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime, timeWaiting = wait - timeSinceLastCall;
            return maxing ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke) : timeWaiting;
          }
          function shouldInvoke(time) {
            var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime;
            return lastCallTime === undefined2 || timeSinceLastCall >= wait || timeSinceLastCall < 0 || maxing && timeSinceLastInvoke >= maxWait;
          }
          function timerExpired() {
            var time = now();
            if (shouldInvoke(time)) {
              return trailingEdge(time);
            }
            timerId = setTimeout2(timerExpired, remainingWait(time));
          }
          function trailingEdge(time) {
            timerId = undefined2;
            if (trailing && lastArgs) {
              return invokeFunc(time);
            }
            lastArgs = lastThis = undefined2;
            return result2;
          }
          function cancel() {
            if (timerId !== undefined2) {
              clearTimeout2(timerId);
            }
            lastInvokeTime = 0;
            lastArgs = lastCallTime = lastThis = timerId = undefined2;
          }
          function flush() {
            return timerId === undefined2 ? result2 : trailingEdge(now());
          }
          function debounced() {
            var time = now(), isInvoking = shouldInvoke(time);
            lastArgs = arguments;
            lastThis = this;
            lastCallTime = time;
            if (isInvoking) {
              if (timerId === undefined2) {
                return leadingEdge(lastCallTime);
              }
              if (maxing) {
                clearTimeout2(timerId);
                timerId = setTimeout2(timerExpired, wait);
                return invokeFunc(lastCallTime);
              }
            }
            if (timerId === undefined2) {
              timerId = setTimeout2(timerExpired, wait);
            }
            return result2;
          }
          debounced.cancel = cancel;
          debounced.flush = flush;
          return debounced;
        }
        var defer = baseRest(function(func, args) {
          return baseDelay(func, 1, args);
        });
        var delay = baseRest(function(func, wait, args) {
          return baseDelay(func, toNumber(wait) || 0, args);
        });
        function flip(func) {
          return createWrap(func, WRAP_FLIP_FLAG);
        }
        function memoize(func, resolver) {
          if (typeof func != "function" || resolver != null && typeof resolver != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          var memoized = function() {
            var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache = memoized.cache;
            if (cache.has(key)) {
              return cache.get(key);
            }
            var result2 = func.apply(this, args);
            memoized.cache = cache.set(key, result2) || cache;
            return result2;
          };
          memoized.cache = new (memoize.Cache || MapCache)();
          return memoized;
        }
        memoize.Cache = MapCache;
        function negate(predicate) {
          if (typeof predicate != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          return function() {
            var args = arguments;
            switch (args.length) {
              case 0:
                return !predicate.call(this);
              case 1:
                return !predicate.call(this, args[0]);
              case 2:
                return !predicate.call(this, args[0], args[1]);
              case 3:
                return !predicate.call(this, args[0], args[1], args[2]);
            }
            return !predicate.apply(this, args);
          };
        }
        function once(func) {
          return before(2, func);
        }
        var overArgs = castRest(function(func, transforms) {
          transforms = transforms.length == 1 && isArray2(transforms[0]) ? arrayMap(transforms[0], baseUnary(getIteratee())) : arrayMap(baseFlatten(transforms, 1), baseUnary(getIteratee()));
          var funcsLength = transforms.length;
          return baseRest(function(args) {
            var index = -1, length = nativeMin(args.length, funcsLength);
            while (++index < length) {
              args[index] = transforms[index].call(this, args[index]);
            }
            return apply(func, this, args);
          });
        });
        var partial = baseRest(function(func, partials) {
          var holders = replaceHolders(partials, getHolder(partial));
          return createWrap(func, WRAP_PARTIAL_FLAG, undefined2, partials, holders);
        });
        var partialRight = baseRest(function(func, partials) {
          var holders = replaceHolders(partials, getHolder(partialRight));
          return createWrap(func, WRAP_PARTIAL_RIGHT_FLAG, undefined2, partials, holders);
        });
        var rearg = flatRest(function(func, indexes) {
          return createWrap(func, WRAP_REARG_FLAG, undefined2, undefined2, undefined2, indexes);
        });
        function rest(func, start) {
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          start = start === undefined2 ? start : toInteger(start);
          return baseRest(func, start);
        }
        function spread(func, start) {
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          start = start == null ? 0 : nativeMax(toInteger(start), 0);
          return baseRest(function(args) {
            var array = args[start], otherArgs = castSlice(args, 0, start);
            if (array) {
              arrayPush(otherArgs, array);
            }
            return apply(func, this, otherArgs);
          });
        }
        function throttle(func, wait, options) {
          var leading = true, trailing = true;
          if (typeof func != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          if (isObject(options)) {
            leading = "leading" in options ? !!options.leading : leading;
            trailing = "trailing" in options ? !!options.trailing : trailing;
          }
          return debounce(func, wait, {
            "leading": leading,
            "maxWait": wait,
            "trailing": trailing
          });
        }
        function unary(func) {
          return ary(func, 1);
        }
        function wrap(value2, wrapper) {
          return partial(castFunction(wrapper), value2);
        }
        function castArray() {
          if (!arguments.length) {
            return [];
          }
          var value2 = arguments[0];
          return isArray2(value2) ? value2 : [value2];
        }
        function clone(value2) {
          return baseClone(value2, CLONE_SYMBOLS_FLAG);
        }
        function cloneWith(value2, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          return baseClone(value2, CLONE_SYMBOLS_FLAG, customizer);
        }
        function cloneDeep3(value2) {
          return baseClone(value2, CLONE_DEEP_FLAG | CLONE_SYMBOLS_FLAG);
        }
        function cloneDeepWith(value2, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          return baseClone(value2, CLONE_DEEP_FLAG | CLONE_SYMBOLS_FLAG, customizer);
        }
        function conformsTo(object, source) {
          return source == null || baseConformsTo(object, source, keys3(source));
        }
        function eq(value2, other) {
          return value2 === other || value2 !== value2 && other !== other;
        }
        var gt = createRelationalOperation(baseGt);
        var gte = createRelationalOperation(function(value2, other) {
          return value2 >= other;
        });
        var isArguments = baseIsArguments(function() {
          return arguments;
        }()) ? baseIsArguments : function(value2) {
          return isObjectLike(value2) && hasOwnProperty.call(value2, "callee") && !propertyIsEnumerable.call(value2, "callee");
        };
        var isArray2 = Array2.isArray;
        var isArrayBuffer = nodeIsArrayBuffer ? baseUnary(nodeIsArrayBuffer) : baseIsArrayBuffer;
        function isArrayLike(value2) {
          return value2 != null && isLength(value2.length) && !isFunction(value2);
        }
        function isArrayLikeObject(value2) {
          return isObjectLike(value2) && isArrayLike(value2);
        }
        function isBoolean(value2) {
          return value2 === true || value2 === false || isObjectLike(value2) && baseGetTag(value2) == boolTag;
        }
        var isBuffer = nativeIsBuffer || stubFalse;
        var isDate = nodeIsDate ? baseUnary(nodeIsDate) : baseIsDate;
        function isElement(value2) {
          return isObjectLike(value2) && value2.nodeType === 1 && !isPlainObject(value2);
        }
        function isEmpty2(value2) {
          if (value2 == null) {
            return true;
          }
          if (isArrayLike(value2) && (isArray2(value2) || typeof value2 == "string" || typeof value2.splice == "function" || isBuffer(value2) || isTypedArray(value2) || isArguments(value2))) {
            return !value2.length;
          }
          var tag = getTag(value2);
          if (tag == mapTag || tag == setTag) {
            return !value2.size;
          }
          if (isPrototype(value2)) {
            return !baseKeys(value2).length;
          }
          for (var key in value2) {
            if (hasOwnProperty.call(value2, key)) {
              return false;
            }
          }
          return true;
        }
        function isEqual(value2, other) {
          return baseIsEqual(value2, other);
        }
        function isEqualWith(value2, other, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          var result2 = customizer ? customizer(value2, other) : undefined2;
          return result2 === undefined2 ? baseIsEqual(value2, other, undefined2, customizer) : !!result2;
        }
        function isError(value2) {
          if (!isObjectLike(value2)) {
            return false;
          }
          var tag = baseGetTag(value2);
          return tag == errorTag || tag == domExcTag || typeof value2.message == "string" && typeof value2.name == "string" && !isPlainObject(value2);
        }
        function isFinite2(value2) {
          return typeof value2 == "number" && nativeIsFinite(value2);
        }
        function isFunction(value2) {
          if (!isObject(value2)) {
            return false;
          }
          var tag = baseGetTag(value2);
          return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
        }
        function isInteger(value2) {
          return typeof value2 == "number" && value2 == toInteger(value2);
        }
        function isLength(value2) {
          return typeof value2 == "number" && value2 > -1 && value2 % 1 == 0 && value2 <= MAX_SAFE_INTEGER;
        }
        function isObject(value2) {
          var type = typeof value2;
          return value2 != null && (type == "object" || type == "function");
        }
        function isObjectLike(value2) {
          return value2 != null && typeof value2 == "object";
        }
        var isMap = nodeIsMap ? baseUnary(nodeIsMap) : baseIsMap;
        function isMatch(object, source) {
          return object === source || baseIsMatch(object, source, getMatchData(source));
        }
        function isMatchWith(object, source, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          return baseIsMatch(object, source, getMatchData(source), customizer);
        }
        function isNaN2(value2) {
          return isNumber(value2) && value2 != +value2;
        }
        function isNative(value2) {
          if (isMaskable(value2)) {
            throw new Error2(CORE_ERROR_TEXT);
          }
          return baseIsNative(value2);
        }
        function isNull2(value2) {
          return value2 === null;
        }
        function isNil(value2) {
          return value2 == null;
        }
        function isNumber(value2) {
          return typeof value2 == "number" || isObjectLike(value2) && baseGetTag(value2) == numberTag;
        }
        function isPlainObject(value2) {
          if (!isObjectLike(value2) || baseGetTag(value2) != objectTag) {
            return false;
          }
          var proto = getPrototype(value2);
          if (proto === null) {
            return true;
          }
          var Ctor = hasOwnProperty.call(proto, "constructor") && proto.constructor;
          return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString.call(Ctor) == objectCtorString;
        }
        var isRegExp = nodeIsRegExp ? baseUnary(nodeIsRegExp) : baseIsRegExp;
        function isSafeInteger(value2) {
          return isInteger(value2) && value2 >= -MAX_SAFE_INTEGER && value2 <= MAX_SAFE_INTEGER;
        }
        var isSet = nodeIsSet ? baseUnary(nodeIsSet) : baseIsSet;
        function isString(value2) {
          return typeof value2 == "string" || !isArray2(value2) && isObjectLike(value2) && baseGetTag(value2) == stringTag;
        }
        function isSymbol(value2) {
          return typeof value2 == "symbol" || isObjectLike(value2) && baseGetTag(value2) == symbolTag;
        }
        var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
        function isUndefined2(value2) {
          return value2 === undefined2;
        }
        function isWeakMap(value2) {
          return isObjectLike(value2) && getTag(value2) == weakMapTag;
        }
        function isWeakSet(value2) {
          return isObjectLike(value2) && baseGetTag(value2) == weakSetTag;
        }
        var lt = createRelationalOperation(baseLt);
        var lte = createRelationalOperation(function(value2, other) {
          return value2 <= other;
        });
        function toArray(value2) {
          if (!value2) {
            return [];
          }
          if (isArrayLike(value2)) {
            return isString(value2) ? stringToArray(value2) : copyArray(value2);
          }
          if (symIterator && value2[symIterator]) {
            return iteratorToArray(value2[symIterator]());
          }
          var tag = getTag(value2), func = tag == mapTag ? mapToArray : tag == setTag ? setToArray : values2;
          return func(value2);
        }
        function toFinite(value2) {
          if (!value2) {
            return value2 === 0 ? value2 : 0;
          }
          value2 = toNumber(value2);
          if (value2 === INFINITY || value2 === -INFINITY) {
            var sign = value2 < 0 ? -1 : 1;
            return sign * MAX_INTEGER;
          }
          return value2 === value2 ? value2 : 0;
        }
        function toInteger(value2) {
          var result2 = toFinite(value2), remainder = result2 % 1;
          return result2 === result2 ? remainder ? result2 - remainder : result2 : 0;
        }
        function toLength(value2) {
          return value2 ? baseClamp(toInteger(value2), 0, MAX_ARRAY_LENGTH) : 0;
        }
        function toNumber(value2) {
          if (typeof value2 == "number") {
            return value2;
          }
          if (isSymbol(value2)) {
            return NAN;
          }
          if (isObject(value2)) {
            var other = typeof value2.valueOf == "function" ? value2.valueOf() : value2;
            value2 = isObject(other) ? other + "" : other;
          }
          if (typeof value2 != "string") {
            return value2 === 0 ? value2 : +value2;
          }
          value2 = baseTrim(value2);
          var isBinary = reIsBinary.test(value2);
          return isBinary || reIsOctal.test(value2) ? freeParseInt(value2.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value2) ? NAN : +value2;
        }
        function toPlainObject(value2) {
          return copyObject(value2, keysIn(value2));
        }
        function toSafeInteger(value2) {
          return value2 ? baseClamp(toInteger(value2), -MAX_SAFE_INTEGER, MAX_SAFE_INTEGER) : value2 === 0 ? value2 : 0;
        }
        function toString(value2) {
          return value2 == null ? "" : baseToString(value2);
        }
        var assign = createAssigner(function(object, source) {
          if (isPrototype(source) || isArrayLike(source)) {
            copyObject(source, keys3(source), object);
            return;
          }
          for (var key in source) {
            if (hasOwnProperty.call(source, key)) {
              assignValue(object, key, source[key]);
            }
          }
        });
        var assignIn = createAssigner(function(object, source) {
          copyObject(source, keysIn(source), object);
        });
        var assignInWith = createAssigner(function(object, source, srcIndex, customizer) {
          copyObject(source, keysIn(source), object, customizer);
        });
        var assignWith = createAssigner(function(object, source, srcIndex, customizer) {
          copyObject(source, keys3(source), object, customizer);
        });
        var at = flatRest(baseAt);
        function create(prototype, properties) {
          var result2 = baseCreate(prototype);
          return properties == null ? result2 : baseAssign(result2, properties);
        }
        var defaults = baseRest(function(object, sources) {
          object = Object2(object);
          var index = -1;
          var length = sources.length;
          var guard = length > 2 ? sources[2] : undefined2;
          if (guard && isIterateeCall(sources[0], sources[1], guard)) {
            length = 1;
          }
          while (++index < length) {
            var source = sources[index];
            var props = keysIn(source);
            var propsIndex = -1;
            var propsLength = props.length;
            while (++propsIndex < propsLength) {
              var key = props[propsIndex];
              var value2 = object[key];
              if (value2 === undefined2 || eq(value2, objectProto[key]) && !hasOwnProperty.call(object, key)) {
                object[key] = source[key];
              }
            }
          }
          return object;
        });
        var defaultsDeep = baseRest(function(args) {
          args.push(undefined2, customDefaultsMerge);
          return apply(mergeWith, undefined2, args);
        });
        function findKey(object, predicate) {
          return baseFindKey(object, getIteratee(predicate, 3), baseForOwn);
        }
        function findLastKey(object, predicate) {
          return baseFindKey(object, getIteratee(predicate, 3), baseForOwnRight);
        }
        function forIn(object, iteratee2) {
          return object == null ? object : baseFor(object, getIteratee(iteratee2, 3), keysIn);
        }
        function forInRight(object, iteratee2) {
          return object == null ? object : baseForRight(object, getIteratee(iteratee2, 3), keysIn);
        }
        function forOwn(object, iteratee2) {
          return object && baseForOwn(object, getIteratee(iteratee2, 3));
        }
        function forOwnRight(object, iteratee2) {
          return object && baseForOwnRight(object, getIteratee(iteratee2, 3));
        }
        function functions(object) {
          return object == null ? [] : baseFunctions(object, keys3(object));
        }
        function functionsIn(object) {
          return object == null ? [] : baseFunctions(object, keysIn(object));
        }
        function get(object, path2, defaultValue) {
          var result2 = object == null ? undefined2 : baseGet(object, path2);
          return result2 === undefined2 ? defaultValue : result2;
        }
        function has(object, path2) {
          return object != null && hasPath(object, path2, baseHas);
        }
        function hasIn(object, path2) {
          return object != null && hasPath(object, path2, baseHasIn);
        }
        var invert = createInverter(function(result2, value2, key) {
          if (value2 != null && typeof value2.toString != "function") {
            value2 = nativeObjectToString.call(value2);
          }
          result2[value2] = key;
        }, constant(identity));
        var invertBy = createInverter(function(result2, value2, key) {
          if (value2 != null && typeof value2.toString != "function") {
            value2 = nativeObjectToString.call(value2);
          }
          if (hasOwnProperty.call(result2, value2)) {
            result2[value2].push(key);
          } else {
            result2[value2] = [key];
          }
        }, getIteratee);
        var invoke = baseRest(baseInvoke);
        function keys3(object) {
          return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
        }
        function keysIn(object) {
          return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
        }
        function mapKeys(object, iteratee2) {
          var result2 = {};
          iteratee2 = getIteratee(iteratee2, 3);
          baseForOwn(object, function(value2, key, object2) {
            baseAssignValue(result2, iteratee2(value2, key, object2), value2);
          });
          return result2;
        }
        function mapValues(object, iteratee2) {
          var result2 = {};
          iteratee2 = getIteratee(iteratee2, 3);
          baseForOwn(object, function(value2, key, object2) {
            baseAssignValue(result2, key, iteratee2(value2, key, object2));
          });
          return result2;
        }
        var merge4 = createAssigner(function(object, source, srcIndex) {
          baseMerge(object, source, srcIndex);
        });
        var mergeWith = createAssigner(function(object, source, srcIndex, customizer) {
          baseMerge(object, source, srcIndex, customizer);
        });
        var omit = flatRest(function(object, paths) {
          var result2 = {};
          if (object == null) {
            return result2;
          }
          var isDeep = false;
          paths = arrayMap(paths, function(path2) {
            path2 = castPath(path2, object);
            isDeep || (isDeep = path2.length > 1);
            return path2;
          });
          copyObject(object, getAllKeysIn(object), result2);
          if (isDeep) {
            result2 = baseClone(result2, CLONE_DEEP_FLAG | CLONE_FLAT_FLAG | CLONE_SYMBOLS_FLAG, customOmitClone);
          }
          var length = paths.length;
          while (length--) {
            baseUnset(result2, paths[length]);
          }
          return result2;
        });
        function omitBy(object, predicate) {
          return pickBy(object, negate(getIteratee(predicate)));
        }
        var pick = flatRest(function(object, paths) {
          return object == null ? {} : basePick(object, paths);
        });
        function pickBy(object, predicate) {
          if (object == null) {
            return {};
          }
          var props = arrayMap(getAllKeysIn(object), function(prop) {
            return [prop];
          });
          predicate = getIteratee(predicate);
          return basePickBy(object, props, function(value2, path2) {
            return predicate(value2, path2[0]);
          });
        }
        function result(object, path2, defaultValue) {
          path2 = castPath(path2, object);
          var index = -1, length = path2.length;
          if (!length) {
            length = 1;
            object = undefined2;
          }
          while (++index < length) {
            var value2 = object == null ? undefined2 : object[toKey(path2[index])];
            if (value2 === undefined2) {
              index = length;
              value2 = defaultValue;
            }
            object = isFunction(value2) ? value2.call(object) : value2;
          }
          return object;
        }
        function set(object, path2, value2) {
          return object == null ? object : baseSet(object, path2, value2);
        }
        function setWith(object, path2, value2, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          return object == null ? object : baseSet(object, path2, value2, customizer);
        }
        var toPairs = createToPairs(keys3);
        var toPairsIn = createToPairs(keysIn);
        function transform(object, iteratee2, accumulator) {
          var isArr = isArray2(object), isArrLike = isArr || isBuffer(object) || isTypedArray(object);
          iteratee2 = getIteratee(iteratee2, 4);
          if (accumulator == null) {
            var Ctor = object && object.constructor;
            if (isArrLike) {
              accumulator = isArr ? new Ctor() : [];
            } else if (isObject(object)) {
              accumulator = isFunction(Ctor) ? baseCreate(getPrototype(object)) : {};
            } else {
              accumulator = {};
            }
          }
          (isArrLike ? arrayEach : baseForOwn)(object, function(value2, index, object2) {
            return iteratee2(accumulator, value2, index, object2);
          });
          return accumulator;
        }
        function unset(object, path2) {
          return object == null ? true : baseUnset(object, path2);
        }
        function update(object, path2, updater) {
          return object == null ? object : baseUpdate(object, path2, castFunction(updater));
        }
        function updateWith(object, path2, updater, customizer) {
          customizer = typeof customizer == "function" ? customizer : undefined2;
          return object == null ? object : baseUpdate(object, path2, castFunction(updater), customizer);
        }
        function values2(object) {
          return object == null ? [] : baseValues(object, keys3(object));
        }
        function valuesIn(object) {
          return object == null ? [] : baseValues(object, keysIn(object));
        }
        function clamp(number, lower, upper) {
          if (upper === undefined2) {
            upper = lower;
            lower = undefined2;
          }
          if (upper !== undefined2) {
            upper = toNumber(upper);
            upper = upper === upper ? upper : 0;
          }
          if (lower !== undefined2) {
            lower = toNumber(lower);
            lower = lower === lower ? lower : 0;
          }
          return baseClamp(toNumber(number), lower, upper);
        }
        function inRange(number, start, end) {
          start = toFinite(start);
          if (end === undefined2) {
            end = start;
            start = 0;
          } else {
            end = toFinite(end);
          }
          number = toNumber(number);
          return baseInRange(number, start, end);
        }
        function random(lower, upper, floating) {
          if (floating && typeof floating != "boolean" && isIterateeCall(lower, upper, floating)) {
            upper = floating = undefined2;
          }
          if (floating === undefined2) {
            if (typeof upper == "boolean") {
              floating = upper;
              upper = undefined2;
            } else if (typeof lower == "boolean") {
              floating = lower;
              lower = undefined2;
            }
          }
          if (lower === undefined2 && upper === undefined2) {
            lower = 0;
            upper = 1;
          } else {
            lower = toFinite(lower);
            if (upper === undefined2) {
              upper = lower;
              lower = 0;
            } else {
              upper = toFinite(upper);
            }
          }
          if (lower > upper) {
            var temp = lower;
            lower = upper;
            upper = temp;
          }
          if (floating || lower % 1 || upper % 1) {
            var rand = nativeRandom();
            return nativeMin(lower + rand * (upper - lower + freeParseFloat("1e-" + ((rand + "").length - 1))), upper);
          }
          return baseRandom(lower, upper);
        }
        var camelCase = createCompounder(function(result2, word, index) {
          word = word.toLowerCase();
          return result2 + (index ? capitalize(word) : word);
        });
        function capitalize(string) {
          return upperFirst(toString(string).toLowerCase());
        }
        function deburr(string) {
          string = toString(string);
          return string && string.replace(reLatin, deburrLetter).replace(reComboMark, "");
        }
        function endsWith(string, target, position) {
          string = toString(string);
          target = baseToString(target);
          var length = string.length;
          position = position === undefined2 ? length : baseClamp(toInteger(position), 0, length);
          var end = position;
          position -= target.length;
          return position >= 0 && string.slice(position, end) == target;
        }
        function escape2(string) {
          string = toString(string);
          return string && reHasUnescapedHtml.test(string) ? string.replace(reUnescapedHtml, escapeHtmlChar) : string;
        }
        function escapeRegExp(string) {
          string = toString(string);
          return string && reHasRegExpChar.test(string) ? string.replace(reRegExpChar, "\\$&") : string;
        }
        var kebabCase = createCompounder(function(result2, word, index) {
          return result2 + (index ? "-" : "") + word.toLowerCase();
        });
        var lowerCase = createCompounder(function(result2, word, index) {
          return result2 + (index ? " " : "") + word.toLowerCase();
        });
        var lowerFirst = createCaseFirst("toLowerCase");
        function pad(string, length, chars) {
          string = toString(string);
          length = toInteger(length);
          var strLength = length ? stringSize(string) : 0;
          if (!length || strLength >= length) {
            return string;
          }
          var mid = (length - strLength) / 2;
          return createPadding(nativeFloor(mid), chars) + string + createPadding(nativeCeil(mid), chars);
        }
        function padEnd(string, length, chars) {
          string = toString(string);
          length = toInteger(length);
          var strLength = length ? stringSize(string) : 0;
          return length && strLength < length ? string + createPadding(length - strLength, chars) : string;
        }
        function padStart(string, length, chars) {
          string = toString(string);
          length = toInteger(length);
          var strLength = length ? stringSize(string) : 0;
          return length && strLength < length ? createPadding(length - strLength, chars) + string : string;
        }
        function parseInt2(string, radix, guard) {
          if (guard || radix == null) {
            radix = 0;
          } else if (radix) {
            radix = +radix;
          }
          return nativeParseInt(toString(string).replace(reTrimStart, ""), radix || 0);
        }
        function repeat(string, n, guard) {
          if (guard ? isIterateeCall(string, n, guard) : n === undefined2) {
            n = 1;
          } else {
            n = toInteger(n);
          }
          return baseRepeat(toString(string), n);
        }
        function replace() {
          var args = arguments, string = toString(args[0]);
          return args.length < 3 ? string : string.replace(args[1], args[2]);
        }
        var snakeCase = createCompounder(function(result2, word, index) {
          return result2 + (index ? "_" : "") + word.toLowerCase();
        });
        function split(string, separator, limit) {
          if (limit && typeof limit != "number" && isIterateeCall(string, separator, limit)) {
            separator = limit = undefined2;
          }
          limit = limit === undefined2 ? MAX_ARRAY_LENGTH : limit >>> 0;
          if (!limit) {
            return [];
          }
          string = toString(string);
          if (string && (typeof separator == "string" || separator != null && !isRegExp(separator))) {
            separator = baseToString(separator);
            if (!separator && hasUnicode(string)) {
              return castSlice(stringToArray(string), 0, limit);
            }
          }
          return string.split(separator, limit);
        }
        var startCase = createCompounder(function(result2, word, index) {
          return result2 + (index ? " " : "") + upperFirst(word);
        });
        function startsWith(string, target, position) {
          string = toString(string);
          position = position == null ? 0 : baseClamp(toInteger(position), 0, string.length);
          target = baseToString(target);
          return string.slice(position, position + target.length) == target;
        }
        function template(string, options, guard) {
          var settings = lodash.templateSettings;
          if (guard && isIterateeCall(string, options, guard)) {
            options = undefined2;
          }
          string = toString(string);
          options = assignInWith({}, options, settings, customDefaultsAssignIn);
          var imports = assignInWith({}, options.imports, settings.imports, customDefaultsAssignIn), importsKeys = keys3(imports), importsValues = baseValues(imports, importsKeys);
          var isEscaping, isEvaluating, index = 0, interpolate = options.interpolate || reNoMatch, source = "__p += '";
          var reDelimiters = RegExp2(
            (options.escape || reNoMatch).source + "|" + interpolate.source + "|" + (interpolate === reInterpolate ? reEsTemplate : reNoMatch).source + "|" + (options.evaluate || reNoMatch).source + "|$",
            "g"
          );
          var sourceURL = "//# sourceURL=" + (hasOwnProperty.call(options, "sourceURL") ? (options.sourceURL + "").replace(/\s/g, " ") : "lodash.templateSources[" + ++templateCounter + "]") + "\n";
          string.replace(reDelimiters, function(match, escapeValue, interpolateValue, esTemplateValue, evaluateValue, offset) {
            interpolateValue || (interpolateValue = esTemplateValue);
            source += string.slice(index, offset).replace(reUnescapedString, escapeStringChar);
            if (escapeValue) {
              isEscaping = true;
              source += "' +\n__e(" + escapeValue + ") +\n'";
            }
            if (evaluateValue) {
              isEvaluating = true;
              source += "';\n" + evaluateValue + ";\n__p += '";
            }
            if (interpolateValue) {
              source += "' +\n((__t = (" + interpolateValue + ")) == null ? '' : __t) +\n'";
            }
            index = offset + match.length;
            return match;
          });
          source += "';\n";
          var variable = hasOwnProperty.call(options, "variable") && options.variable;
          if (!variable) {
            source = "with (obj) {\n" + source + "\n}\n";
          } else if (reForbiddenIdentifierChars.test(variable)) {
            throw new Error2(INVALID_TEMPL_VAR_ERROR_TEXT);
          }
          source = (isEvaluating ? source.replace(reEmptyStringLeading, "") : source).replace(reEmptyStringMiddle, "$1").replace(reEmptyStringTrailing, "$1;");
          source = "function(" + (variable || "obj") + ") {\n" + (variable ? "" : "obj || (obj = {});\n") + "var __t, __p = ''" + (isEscaping ? ", __e = _.escape" : "") + (isEvaluating ? ", __j = Array.prototype.join;\nfunction print() { __p += __j.call(arguments, '') }\n" : ";\n") + source + "return __p\n}";
          var result2 = attempt(function() {
            return Function2(importsKeys, sourceURL + "return " + source).apply(undefined2, importsValues);
          });
          result2.source = source;
          if (isError(result2)) {
            throw result2;
          }
          return result2;
        }
        function toLower(value2) {
          return toString(value2).toLowerCase();
        }
        function toUpper(value2) {
          return toString(value2).toUpperCase();
        }
        function trim(string, chars, guard) {
          string = toString(string);
          if (string && (guard || chars === undefined2)) {
            return baseTrim(string);
          }
          if (!string || !(chars = baseToString(chars))) {
            return string;
          }
          var strSymbols = stringToArray(string), chrSymbols = stringToArray(chars), start = charsStartIndex(strSymbols, chrSymbols), end = charsEndIndex(strSymbols, chrSymbols) + 1;
          return castSlice(strSymbols, start, end).join("");
        }
        function trimEnd(string, chars, guard) {
          string = toString(string);
          if (string && (guard || chars === undefined2)) {
            return string.slice(0, trimmedEndIndex(string) + 1);
          }
          if (!string || !(chars = baseToString(chars))) {
            return string;
          }
          var strSymbols = stringToArray(string), end = charsEndIndex(strSymbols, stringToArray(chars)) + 1;
          return castSlice(strSymbols, 0, end).join("");
        }
        function trimStart(string, chars, guard) {
          string = toString(string);
          if (string && (guard || chars === undefined2)) {
            return string.replace(reTrimStart, "");
          }
          if (!string || !(chars = baseToString(chars))) {
            return string;
          }
          var strSymbols = stringToArray(string), start = charsStartIndex(strSymbols, stringToArray(chars));
          return castSlice(strSymbols, start).join("");
        }
        function truncate(string, options) {
          var length = DEFAULT_TRUNC_LENGTH, omission = DEFAULT_TRUNC_OMISSION;
          if (isObject(options)) {
            var separator = "separator" in options ? options.separator : separator;
            length = "length" in options ? toInteger(options.length) : length;
            omission = "omission" in options ? baseToString(options.omission) : omission;
          }
          string = toString(string);
          var strLength = string.length;
          if (hasUnicode(string)) {
            var strSymbols = stringToArray(string);
            strLength = strSymbols.length;
          }
          if (length >= strLength) {
            return string;
          }
          var end = length - stringSize(omission);
          if (end < 1) {
            return omission;
          }
          var result2 = strSymbols ? castSlice(strSymbols, 0, end).join("") : string.slice(0, end);
          if (separator === undefined2) {
            return result2 + omission;
          }
          if (strSymbols) {
            end += result2.length - end;
          }
          if (isRegExp(separator)) {
            if (string.slice(end).search(separator)) {
              var match, substring = result2;
              if (!separator.global) {
                separator = RegExp2(separator.source, toString(reFlags.exec(separator)) + "g");
              }
              separator.lastIndex = 0;
              while (match = separator.exec(substring)) {
                var newEnd = match.index;
              }
              result2 = result2.slice(0, newEnd === undefined2 ? end : newEnd);
            }
          } else if (string.indexOf(baseToString(separator), end) != end) {
            var index = result2.lastIndexOf(separator);
            if (index > -1) {
              result2 = result2.slice(0, index);
            }
          }
          return result2 + omission;
        }
        function unescape2(string) {
          string = toString(string);
          return string && reHasEscapedHtml.test(string) ? string.replace(reEscapedHtml, unescapeHtmlChar) : string;
        }
        var upperCase = createCompounder(function(result2, word, index) {
          return result2 + (index ? " " : "") + word.toUpperCase();
        });
        var upperFirst = createCaseFirst("toUpperCase");
        function words(string, pattern, guard) {
          string = toString(string);
          pattern = guard ? undefined2 : pattern;
          if (pattern === undefined2) {
            return hasUnicodeWord(string) ? unicodeWords(string) : asciiWords(string);
          }
          return string.match(pattern) || [];
        }
        var attempt = baseRest(function(func, args) {
          try {
            return apply(func, undefined2, args);
          } catch (e) {
            return isError(e) ? e : new Error2(e);
          }
        });
        var bindAll = flatRest(function(object, methodNames) {
          arrayEach(methodNames, function(key) {
            key = toKey(key);
            baseAssignValue(object, key, bind(object[key], object));
          });
          return object;
        });
        function cond(pairs) {
          var length = pairs == null ? 0 : pairs.length, toIteratee = getIteratee();
          pairs = !length ? [] : arrayMap(pairs, function(pair) {
            if (typeof pair[1] != "function") {
              throw new TypeError2(FUNC_ERROR_TEXT);
            }
            return [toIteratee(pair[0]), pair[1]];
          });
          return baseRest(function(args) {
            var index = -1;
            while (++index < length) {
              var pair = pairs[index];
              if (apply(pair[0], this, args)) {
                return apply(pair[1], this, args);
              }
            }
          });
        }
        function conforms(source) {
          return baseConforms(baseClone(source, CLONE_DEEP_FLAG));
        }
        function constant(value2) {
          return function() {
            return value2;
          };
        }
        function defaultTo(value2, defaultValue) {
          return value2 == null || value2 !== value2 ? defaultValue : value2;
        }
        var flow = createFlow();
        var flowRight = createFlow(true);
        function identity(value2) {
          return value2;
        }
        function iteratee(func) {
          return baseIteratee(typeof func == "function" ? func : baseClone(func, CLONE_DEEP_FLAG));
        }
        function matches(source) {
          return baseMatches(baseClone(source, CLONE_DEEP_FLAG));
        }
        function matchesProperty(path2, srcValue) {
          return baseMatchesProperty(path2, baseClone(srcValue, CLONE_DEEP_FLAG));
        }
        var method = baseRest(function(path2, args) {
          return function(object) {
            return baseInvoke(object, path2, args);
          };
        });
        var methodOf = baseRest(function(object, args) {
          return function(path2) {
            return baseInvoke(object, path2, args);
          };
        });
        function mixin(object, source, options) {
          var props = keys3(source), methodNames = baseFunctions(source, props);
          if (options == null && !(isObject(source) && (methodNames.length || !props.length))) {
            options = source;
            source = object;
            object = this;
            methodNames = baseFunctions(source, keys3(source));
          }
          var chain2 = !(isObject(options) && "chain" in options) || !!options.chain, isFunc = isFunction(object);
          arrayEach(methodNames, function(methodName) {
            var func = source[methodName];
            object[methodName] = func;
            if (isFunc) {
              object.prototype[methodName] = function() {
                var chainAll = this.__chain__;
                if (chain2 || chainAll) {
                  var result2 = object(this.__wrapped__), actions = result2.__actions__ = copyArray(this.__actions__);
                  actions.push({ "func": func, "args": arguments, "thisArg": object });
                  result2.__chain__ = chainAll;
                  return result2;
                }
                return func.apply(object, arrayPush([this.value()], arguments));
              };
            }
          });
          return object;
        }
        function noConflict() {
          if (root2._ === this) {
            root2._ = oldDash;
          }
          return this;
        }
        function noop() {
        }
        function nthArg(n) {
          n = toInteger(n);
          return baseRest(function(args) {
            return baseNth(args, n);
          });
        }
        var over = createOver(arrayMap);
        var overEvery = createOver(arrayEvery);
        var overSome = createOver(arraySome);
        function property(path2) {
          return isKey(path2) ? baseProperty(toKey(path2)) : basePropertyDeep(path2);
        }
        function propertyOf(object) {
          return function(path2) {
            return object == null ? undefined2 : baseGet(object, path2);
          };
        }
        var range = createRange();
        var rangeRight = createRange(true);
        function stubArray() {
          return [];
        }
        function stubFalse() {
          return false;
        }
        function stubObject() {
          return {};
        }
        function stubString() {
          return "";
        }
        function stubTrue() {
          return true;
        }
        function times(n, iteratee2) {
          n = toInteger(n);
          if (n < 1 || n > MAX_SAFE_INTEGER) {
            return [];
          }
          var index = MAX_ARRAY_LENGTH, length = nativeMin(n, MAX_ARRAY_LENGTH);
          iteratee2 = getIteratee(iteratee2);
          n -= MAX_ARRAY_LENGTH;
          var result2 = baseTimes(length, iteratee2);
          while (++index < n) {
            iteratee2(index);
          }
          return result2;
        }
        function toPath(value2) {
          if (isArray2(value2)) {
            return arrayMap(value2, toKey);
          }
          return isSymbol(value2) ? [value2] : copyArray(stringToPath(toString(value2)));
        }
        function uniqueId(prefix) {
          var id = ++idCounter;
          return toString(prefix) + id;
        }
        var add = createMathOperation(function(augend, addend) {
          return augend + addend;
        }, 0);
        var ceil = createRound("ceil");
        var divide = createMathOperation(function(dividend, divisor) {
          return dividend / divisor;
        }, 1);
        var floor = createRound("floor");
        function max2(array) {
          return array && array.length ? baseExtremum(array, identity, baseGt) : undefined2;
        }
        function maxBy(array, iteratee2) {
          return array && array.length ? baseExtremum(array, getIteratee(iteratee2, 2), baseGt) : undefined2;
        }
        function mean(array) {
          return baseMean(array, identity);
        }
        function meanBy(array, iteratee2) {
          return baseMean(array, getIteratee(iteratee2, 2));
        }
        function min2(array) {
          return array && array.length ? baseExtremum(array, identity, baseLt) : undefined2;
        }
        function minBy(array, iteratee2) {
          return array && array.length ? baseExtremum(array, getIteratee(iteratee2, 2), baseLt) : undefined2;
        }
        var multiply = createMathOperation(function(multiplier, multiplicand) {
          return multiplier * multiplicand;
        }, 1);
        var round = createRound("round");
        var subtract = createMathOperation(function(minuend, subtrahend) {
          return minuend - subtrahend;
        }, 0);
        function sum(array) {
          return array && array.length ? baseSum(array, identity) : 0;
        }
        function sumBy(array, iteratee2) {
          return array && array.length ? baseSum(array, getIteratee(iteratee2, 2)) : 0;
        }
        lodash.after = after;
        lodash.ary = ary;
        lodash.assign = assign;
        lodash.assignIn = assignIn;
        lodash.assignInWith = assignInWith;
        lodash.assignWith = assignWith;
        lodash.at = at;
        lodash.before = before;
        lodash.bind = bind;
        lodash.bindAll = bindAll;
        lodash.bindKey = bindKey;
        lodash.castArray = castArray;
        lodash.chain = chain;
        lodash.chunk = chunk;
        lodash.compact = compact;
        lodash.concat = concat;
        lodash.cond = cond;
        lodash.conforms = conforms;
        lodash.constant = constant;
        lodash.countBy = countBy;
        lodash.create = create;
        lodash.curry = curry;
        lodash.curryRight = curryRight;
        lodash.debounce = debounce;
        lodash.defaults = defaults;
        lodash.defaultsDeep = defaultsDeep;
        lodash.defer = defer;
        lodash.delay = delay;
        lodash.difference = difference;
        lodash.differenceBy = differenceBy;
        lodash.differenceWith = differenceWith;
        lodash.drop = drop;
        lodash.dropRight = dropRight;
        lodash.dropRightWhile = dropRightWhile;
        lodash.dropWhile = dropWhile;
        lodash.fill = fill;
        lodash.filter = filter;
        lodash.flatMap = flatMap;
        lodash.flatMapDeep = flatMapDeep;
        lodash.flatMapDepth = flatMapDepth;
        lodash.flatten = flatten;
        lodash.flattenDeep = flattenDeep;
        lodash.flattenDepth = flattenDepth;
        lodash.flip = flip;
        lodash.flow = flow;
        lodash.flowRight = flowRight;
        lodash.fromPairs = fromPairs;
        lodash.functions = functions;
        lodash.functionsIn = functionsIn;
        lodash.groupBy = groupBy;
        lodash.initial = initial;
        lodash.intersection = intersection;
        lodash.intersectionBy = intersectionBy;
        lodash.intersectionWith = intersectionWith;
        lodash.invert = invert;
        lodash.invertBy = invertBy;
        lodash.invokeMap = invokeMap;
        lodash.iteratee = iteratee;
        lodash.keyBy = keyBy;
        lodash.keys = keys3;
        lodash.keysIn = keysIn;
        lodash.map = map;
        lodash.mapKeys = mapKeys;
        lodash.mapValues = mapValues;
        lodash.matches = matches;
        lodash.matchesProperty = matchesProperty;
        lodash.memoize = memoize;
        lodash.merge = merge4;
        lodash.mergeWith = mergeWith;
        lodash.method = method;
        lodash.methodOf = methodOf;
        lodash.mixin = mixin;
        lodash.negate = negate;
        lodash.nthArg = nthArg;
        lodash.omit = omit;
        lodash.omitBy = omitBy;
        lodash.once = once;
        lodash.orderBy = orderBy;
        lodash.over = over;
        lodash.overArgs = overArgs;
        lodash.overEvery = overEvery;
        lodash.overSome = overSome;
        lodash.partial = partial;
        lodash.partialRight = partialRight;
        lodash.partition = partition;
        lodash.pick = pick;
        lodash.pickBy = pickBy;
        lodash.property = property;
        lodash.propertyOf = propertyOf;
        lodash.pull = pull;
        lodash.pullAll = pullAll;
        lodash.pullAllBy = pullAllBy;
        lodash.pullAllWith = pullAllWith;
        lodash.pullAt = pullAt;
        lodash.range = range;
        lodash.rangeRight = rangeRight;
        lodash.rearg = rearg;
        lodash.reject = reject;
        lodash.remove = remove;
        lodash.rest = rest;
        lodash.reverse = reverse;
        lodash.sampleSize = sampleSize;
        lodash.set = set;
        lodash.setWith = setWith;
        lodash.shuffle = shuffle;
        lodash.slice = slice;
        lodash.sortBy = sortBy;
        lodash.sortedUniq = sortedUniq;
        lodash.sortedUniqBy = sortedUniqBy;
        lodash.split = split;
        lodash.spread = spread;
        lodash.tail = tail;
        lodash.take = take;
        lodash.takeRight = takeRight;
        lodash.takeRightWhile = takeRightWhile;
        lodash.takeWhile = takeWhile;
        lodash.tap = tap;
        lodash.throttle = throttle;
        lodash.thru = thru;
        lodash.toArray = toArray;
        lodash.toPairs = toPairs;
        lodash.toPairsIn = toPairsIn;
        lodash.toPath = toPath;
        lodash.toPlainObject = toPlainObject;
        lodash.transform = transform;
        lodash.unary = unary;
        lodash.union = union;
        lodash.unionBy = unionBy;
        lodash.unionWith = unionWith;
        lodash.uniq = uniq;
        lodash.uniqBy = uniqBy;
        lodash.uniqWith = uniqWith;
        lodash.unset = unset;
        lodash.unzip = unzip;
        lodash.unzipWith = unzipWith;
        lodash.update = update;
        lodash.updateWith = updateWith;
        lodash.values = values2;
        lodash.valuesIn = valuesIn;
        lodash.without = without;
        lodash.words = words;
        lodash.wrap = wrap;
        lodash.xor = xor;
        lodash.xorBy = xorBy;
        lodash.xorWith = xorWith;
        lodash.zip = zip;
        lodash.zipObject = zipObject;
        lodash.zipObjectDeep = zipObjectDeep;
        lodash.zipWith = zipWith;
        lodash.entries = toPairs;
        lodash.entriesIn = toPairsIn;
        lodash.extend = assignIn;
        lodash.extendWith = assignInWith;
        mixin(lodash, lodash);
        lodash.add = add;
        lodash.attempt = attempt;
        lodash.camelCase = camelCase;
        lodash.capitalize = capitalize;
        lodash.ceil = ceil;
        lodash.clamp = clamp;
        lodash.clone = clone;
        lodash.cloneDeep = cloneDeep3;
        lodash.cloneDeepWith = cloneDeepWith;
        lodash.cloneWith = cloneWith;
        lodash.conformsTo = conformsTo;
        lodash.deburr = deburr;
        lodash.defaultTo = defaultTo;
        lodash.divide = divide;
        lodash.endsWith = endsWith;
        lodash.eq = eq;
        lodash.escape = escape2;
        lodash.escapeRegExp = escapeRegExp;
        lodash.every = every;
        lodash.find = find;
        lodash.findIndex = findIndex;
        lodash.findKey = findKey;
        lodash.findLast = findLast;
        lodash.findLastIndex = findLastIndex;
        lodash.findLastKey = findLastKey;
        lodash.floor = floor;
        lodash.forEach = forEach;
        lodash.forEachRight = forEachRight;
        lodash.forIn = forIn;
        lodash.forInRight = forInRight;
        lodash.forOwn = forOwn;
        lodash.forOwnRight = forOwnRight;
        lodash.get = get;
        lodash.gt = gt;
        lodash.gte = gte;
        lodash.has = has;
        lodash.hasIn = hasIn;
        lodash.head = head;
        lodash.identity = identity;
        lodash.includes = includes;
        lodash.indexOf = indexOf;
        lodash.inRange = inRange;
        lodash.invoke = invoke;
        lodash.isArguments = isArguments;
        lodash.isArray = isArray2;
        lodash.isArrayBuffer = isArrayBuffer;
        lodash.isArrayLike = isArrayLike;
        lodash.isArrayLikeObject = isArrayLikeObject;
        lodash.isBoolean = isBoolean;
        lodash.isBuffer = isBuffer;
        lodash.isDate = isDate;
        lodash.isElement = isElement;
        lodash.isEmpty = isEmpty2;
        lodash.isEqual = isEqual;
        lodash.isEqualWith = isEqualWith;
        lodash.isError = isError;
        lodash.isFinite = isFinite2;
        lodash.isFunction = isFunction;
        lodash.isInteger = isInteger;
        lodash.isLength = isLength;
        lodash.isMap = isMap;
        lodash.isMatch = isMatch;
        lodash.isMatchWith = isMatchWith;
        lodash.isNaN = isNaN2;
        lodash.isNative = isNative;
        lodash.isNil = isNil;
        lodash.isNull = isNull2;
        lodash.isNumber = isNumber;
        lodash.isObject = isObject;
        lodash.isObjectLike = isObjectLike;
        lodash.isPlainObject = isPlainObject;
        lodash.isRegExp = isRegExp;
        lodash.isSafeInteger = isSafeInteger;
        lodash.isSet = isSet;
        lodash.isString = isString;
        lodash.isSymbol = isSymbol;
        lodash.isTypedArray = isTypedArray;
        lodash.isUndefined = isUndefined2;
        lodash.isWeakMap = isWeakMap;
        lodash.isWeakSet = isWeakSet;
        lodash.join = join;
        lodash.kebabCase = kebabCase;
        lodash.last = last2;
        lodash.lastIndexOf = lastIndexOf;
        lodash.lowerCase = lowerCase;
        lodash.lowerFirst = lowerFirst;
        lodash.lt = lt;
        lodash.lte = lte;
        lodash.max = max2;
        lodash.maxBy = maxBy;
        lodash.mean = mean;
        lodash.meanBy = meanBy;
        lodash.min = min2;
        lodash.minBy = minBy;
        lodash.stubArray = stubArray;
        lodash.stubFalse = stubFalse;
        lodash.stubObject = stubObject;
        lodash.stubString = stubString;
        lodash.stubTrue = stubTrue;
        lodash.multiply = multiply;
        lodash.nth = nth;
        lodash.noConflict = noConflict;
        lodash.noop = noop;
        lodash.now = now;
        lodash.pad = pad;
        lodash.padEnd = padEnd;
        lodash.padStart = padStart;
        lodash.parseInt = parseInt2;
        lodash.random = random;
        lodash.reduce = reduce;
        lodash.reduceRight = reduceRight;
        lodash.repeat = repeat;
        lodash.replace = replace;
        lodash.result = result;
        lodash.round = round;
        lodash.runInContext = runInContext2;
        lodash.sample = sample2;
        lodash.size = size;
        lodash.snakeCase = snakeCase;
        lodash.some = some;
        lodash.sortedIndex = sortedIndex;
        lodash.sortedIndexBy = sortedIndexBy;
        lodash.sortedIndexOf = sortedIndexOf;
        lodash.sortedLastIndex = sortedLastIndex;
        lodash.sortedLastIndexBy = sortedLastIndexBy;
        lodash.sortedLastIndexOf = sortedLastIndexOf;
        lodash.startCase = startCase;
        lodash.startsWith = startsWith;
        lodash.subtract = subtract;
        lodash.sum = sum;
        lodash.sumBy = sumBy;
        lodash.template = template;
        lodash.times = times;
        lodash.toFinite = toFinite;
        lodash.toInteger = toInteger;
        lodash.toLength = toLength;
        lodash.toLower = toLower;
        lodash.toNumber = toNumber;
        lodash.toSafeInteger = toSafeInteger;
        lodash.toString = toString;
        lodash.toUpper = toUpper;
        lodash.trim = trim;
        lodash.trimEnd = trimEnd;
        lodash.trimStart = trimStart;
        lodash.truncate = truncate;
        lodash.unescape = unescape2;
        lodash.uniqueId = uniqueId;
        lodash.upperCase = upperCase;
        lodash.upperFirst = upperFirst;
        lodash.each = forEach;
        lodash.eachRight = forEachRight;
        lodash.first = head;
        mixin(lodash, function() {
          var source = {};
          baseForOwn(lodash, function(func, methodName) {
            if (!hasOwnProperty.call(lodash.prototype, methodName)) {
              source[methodName] = func;
            }
          });
          return source;
        }(), { "chain": false });
        lodash.VERSION = VERSION;
        arrayEach(["bind", "bindKey", "curry", "curryRight", "partial", "partialRight"], function(methodName) {
          lodash[methodName].placeholder = lodash;
        });
        arrayEach(["drop", "take"], function(methodName, index) {
          LazyWrapper.prototype[methodName] = function(n) {
            n = n === undefined2 ? 1 : nativeMax(toInteger(n), 0);
            var result2 = this.__filtered__ && !index ? new LazyWrapper(this) : this.clone();
            if (result2.__filtered__) {
              result2.__takeCount__ = nativeMin(n, result2.__takeCount__);
            } else {
              result2.__views__.push({
                "size": nativeMin(n, MAX_ARRAY_LENGTH),
                "type": methodName + (result2.__dir__ < 0 ? "Right" : "")
              });
            }
            return result2;
          };
          LazyWrapper.prototype[methodName + "Right"] = function(n) {
            return this.reverse()[methodName](n).reverse();
          };
        });
        arrayEach(["filter", "map", "takeWhile"], function(methodName, index) {
          var type = index + 1, isFilter = type == LAZY_FILTER_FLAG || type == LAZY_WHILE_FLAG;
          LazyWrapper.prototype[methodName] = function(iteratee2) {
            var result2 = this.clone();
            result2.__iteratees__.push({
              "iteratee": getIteratee(iteratee2, 3),
              "type": type
            });
            result2.__filtered__ = result2.__filtered__ || isFilter;
            return result2;
          };
        });
        arrayEach(["head", "last"], function(methodName, index) {
          var takeName = "take" + (index ? "Right" : "");
          LazyWrapper.prototype[methodName] = function() {
            return this[takeName](1).value()[0];
          };
        });
        arrayEach(["initial", "tail"], function(methodName, index) {
          var dropName = "drop" + (index ? "" : "Right");
          LazyWrapper.prototype[methodName] = function() {
            return this.__filtered__ ? new LazyWrapper(this) : this[dropName](1);
          };
        });
        LazyWrapper.prototype.compact = function() {
          return this.filter(identity);
        };
        LazyWrapper.prototype.find = function(predicate) {
          return this.filter(predicate).head();
        };
        LazyWrapper.prototype.findLast = function(predicate) {
          return this.reverse().find(predicate);
        };
        LazyWrapper.prototype.invokeMap = baseRest(function(path2, args) {
          if (typeof path2 == "function") {
            return new LazyWrapper(this);
          }
          return this.map(function(value2) {
            return baseInvoke(value2, path2, args);
          });
        });
        LazyWrapper.prototype.reject = function(predicate) {
          return this.filter(negate(getIteratee(predicate)));
        };
        LazyWrapper.prototype.slice = function(start, end) {
          start = toInteger(start);
          var result2 = this;
          if (result2.__filtered__ && (start > 0 || end < 0)) {
            return new LazyWrapper(result2);
          }
          if (start < 0) {
            result2 = result2.takeRight(-start);
          } else if (start) {
            result2 = result2.drop(start);
          }
          if (end !== undefined2) {
            end = toInteger(end);
            result2 = end < 0 ? result2.dropRight(-end) : result2.take(end - start);
          }
          return result2;
        };
        LazyWrapper.prototype.takeRightWhile = function(predicate) {
          return this.reverse().takeWhile(predicate).reverse();
        };
        LazyWrapper.prototype.toArray = function() {
          return this.take(MAX_ARRAY_LENGTH);
        };
        baseForOwn(LazyWrapper.prototype, function(func, methodName) {
          var checkIteratee = /^(?:filter|find|map|reject)|While$/.test(methodName), isTaker = /^(?:head|last)$/.test(methodName), lodashFunc = lodash[isTaker ? "take" + (methodName == "last" ? "Right" : "") : methodName], retUnwrapped = isTaker || /^find/.test(methodName);
          if (!lodashFunc) {
            return;
          }
          lodash.prototype[methodName] = function() {
            var value2 = this.__wrapped__, args = isTaker ? [1] : arguments, isLazy = value2 instanceof LazyWrapper, iteratee2 = args[0], useLazy = isLazy || isArray2(value2);
            var interceptor = function(value3) {
              var result3 = lodashFunc.apply(lodash, arrayPush([value3], args));
              return isTaker && chainAll ? result3[0] : result3;
            };
            if (useLazy && checkIteratee && typeof iteratee2 == "function" && iteratee2.length != 1) {
              isLazy = useLazy = false;
            }
            var chainAll = this.__chain__, isHybrid = !!this.__actions__.length, isUnwrapped = retUnwrapped && !chainAll, onlyLazy = isLazy && !isHybrid;
            if (!retUnwrapped && useLazy) {
              value2 = onlyLazy ? value2 : new LazyWrapper(this);
              var result2 = func.apply(value2, args);
              result2.__actions__.push({ "func": thru, "args": [interceptor], "thisArg": undefined2 });
              return new LodashWrapper(result2, chainAll);
            }
            if (isUnwrapped && onlyLazy) {
              return func.apply(this, args);
            }
            result2 = this.thru(interceptor);
            return isUnwrapped ? isTaker ? result2.value()[0] : result2.value() : result2;
          };
        });
        arrayEach(["pop", "push", "shift", "sort", "splice", "unshift"], function(methodName) {
          var func = arrayProto[methodName], chainName = /^(?:push|sort|unshift)$/.test(methodName) ? "tap" : "thru", retUnwrapped = /^(?:pop|shift)$/.test(methodName);
          lodash.prototype[methodName] = function() {
            var args = arguments;
            if (retUnwrapped && !this.__chain__) {
              var value2 = this.value();
              return func.apply(isArray2(value2) ? value2 : [], args);
            }
            return this[chainName](function(value3) {
              return func.apply(isArray2(value3) ? value3 : [], args);
            });
          };
        });
        baseForOwn(LazyWrapper.prototype, function(func, methodName) {
          var lodashFunc = lodash[methodName];
          if (lodashFunc) {
            var key = lodashFunc.name + "";
            if (!hasOwnProperty.call(realNames, key)) {
              realNames[key] = [];
            }
            realNames[key].push({ "name": methodName, "func": lodashFunc });
          }
        });
        realNames[createHybrid(undefined2, WRAP_BIND_KEY_FLAG).name] = [{
          "name": "wrapper",
          "func": undefined2
        }];
        LazyWrapper.prototype.clone = lazyClone;
        LazyWrapper.prototype.reverse = lazyReverse;
        LazyWrapper.prototype.value = lazyValue;
        lodash.prototype.at = wrapperAt;
        lodash.prototype.chain = wrapperChain;
        lodash.prototype.commit = wrapperCommit;
        lodash.prototype.next = wrapperNext;
        lodash.prototype.plant = wrapperPlant;
        lodash.prototype.reverse = wrapperReverse;
        lodash.prototype.toJSON = lodash.prototype.valueOf = lodash.prototype.value = wrapperValue;
        lodash.prototype.first = lodash.prototype.head;
        if (symIterator) {
          lodash.prototype[symIterator] = wrapperToIterator;
        }
        return lodash;
      };
      var _ = runInContext();
      if (typeof define == "function" && typeof define.amd == "object" && define.amd) {
        root2._ = _;
        define(function() {
          return _;
        });
      } else if (freeModule) {
        (freeModule.exports = _)._ = _;
        freeExports._ = _;
      } else {
        root2._ = _;
      }
    }).call(exports);
  }
});

// node_modules/color-name/index.js
var require_color_name = __commonJS({
  "node_modules/color-name/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      "aliceblue": [240, 248, 255],
      "antiquewhite": [250, 235, 215],
      "aqua": [0, 255, 255],
      "aquamarine": [127, 255, 212],
      "azure": [240, 255, 255],
      "beige": [245, 245, 220],
      "bisque": [255, 228, 196],
      "black": [0, 0, 0],
      "blanchedalmond": [255, 235, 205],
      "blue": [0, 0, 255],
      "blueviolet": [138, 43, 226],
      "brown": [165, 42, 42],
      "burlywood": [222, 184, 135],
      "cadetblue": [95, 158, 160],
      "chartreuse": [127, 255, 0],
      "chocolate": [210, 105, 30],
      "coral": [255, 127, 80],
      "cornflowerblue": [100, 149, 237],
      "cornsilk": [255, 248, 220],
      "crimson": [220, 20, 60],
      "cyan": [0, 255, 255],
      "darkblue": [0, 0, 139],
      "darkcyan": [0, 139, 139],
      "darkgoldenrod": [184, 134, 11],
      "darkgray": [169, 169, 169],
      "darkgreen": [0, 100, 0],
      "darkgrey": [169, 169, 169],
      "darkkhaki": [189, 183, 107],
      "darkmagenta": [139, 0, 139],
      "darkolivegreen": [85, 107, 47],
      "darkorange": [255, 140, 0],
      "darkorchid": [153, 50, 204],
      "darkred": [139, 0, 0],
      "darksalmon": [233, 150, 122],
      "darkseagreen": [143, 188, 143],
      "darkslateblue": [72, 61, 139],
      "darkslategray": [47, 79, 79],
      "darkslategrey": [47, 79, 79],
      "darkturquoise": [0, 206, 209],
      "darkviolet": [148, 0, 211],
      "deeppink": [255, 20, 147],
      "deepskyblue": [0, 191, 255],
      "dimgray": [105, 105, 105],
      "dimgrey": [105, 105, 105],
      "dodgerblue": [30, 144, 255],
      "firebrick": [178, 34, 34],
      "floralwhite": [255, 250, 240],
      "forestgreen": [34, 139, 34],
      "fuchsia": [255, 0, 255],
      "gainsboro": [220, 220, 220],
      "ghostwhite": [248, 248, 255],
      "gold": [255, 215, 0],
      "goldenrod": [218, 165, 32],
      "gray": [128, 128, 128],
      "green": [0, 128, 0],
      "greenyellow": [173, 255, 47],
      "grey": [128, 128, 128],
      "honeydew": [240, 255, 240],
      "hotpink": [255, 105, 180],
      "indianred": [205, 92, 92],
      "indigo": [75, 0, 130],
      "ivory": [255, 255, 240],
      "khaki": [240, 230, 140],
      "lavender": [230, 230, 250],
      "lavenderblush": [255, 240, 245],
      "lawngreen": [124, 252, 0],
      "lemonchiffon": [255, 250, 205],
      "lightblue": [173, 216, 230],
      "lightcoral": [240, 128, 128],
      "lightcyan": [224, 255, 255],
      "lightgoldenrodyellow": [250, 250, 210],
      "lightgray": [211, 211, 211],
      "lightgreen": [144, 238, 144],
      "lightgrey": [211, 211, 211],
      "lightpink": [255, 182, 193],
      "lightsalmon": [255, 160, 122],
      "lightseagreen": [32, 178, 170],
      "lightskyblue": [135, 206, 250],
      "lightslategray": [119, 136, 153],
      "lightslategrey": [119, 136, 153],
      "lightsteelblue": [176, 196, 222],
      "lightyellow": [255, 255, 224],
      "lime": [0, 255, 0],
      "limegreen": [50, 205, 50],
      "linen": [250, 240, 230],
      "magenta": [255, 0, 255],
      "maroon": [128, 0, 0],
      "mediumaquamarine": [102, 205, 170],
      "mediumblue": [0, 0, 205],
      "mediumorchid": [186, 85, 211],
      "mediumpurple": [147, 112, 219],
      "mediumseagreen": [60, 179, 113],
      "mediumslateblue": [123, 104, 238],
      "mediumspringgreen": [0, 250, 154],
      "mediumturquoise": [72, 209, 204],
      "mediumvioletred": [199, 21, 133],
      "midnightblue": [25, 25, 112],
      "mintcream": [245, 255, 250],
      "mistyrose": [255, 228, 225],
      "moccasin": [255, 228, 181],
      "navajowhite": [255, 222, 173],
      "navy": [0, 0, 128],
      "oldlace": [253, 245, 230],
      "olive": [128, 128, 0],
      "olivedrab": [107, 142, 35],
      "orange": [255, 165, 0],
      "orangered": [255, 69, 0],
      "orchid": [218, 112, 214],
      "palegoldenrod": [238, 232, 170],
      "palegreen": [152, 251, 152],
      "paleturquoise": [175, 238, 238],
      "palevioletred": [219, 112, 147],
      "papayawhip": [255, 239, 213],
      "peachpuff": [255, 218, 185],
      "peru": [205, 133, 63],
      "pink": [255, 192, 203],
      "plum": [221, 160, 221],
      "powderblue": [176, 224, 230],
      "purple": [128, 0, 128],
      "rebeccapurple": [102, 51, 153],
      "red": [255, 0, 0],
      "rosybrown": [188, 143, 143],
      "royalblue": [65, 105, 225],
      "saddlebrown": [139, 69, 19],
      "salmon": [250, 128, 114],
      "sandybrown": [244, 164, 96],
      "seagreen": [46, 139, 87],
      "seashell": [255, 245, 238],
      "sienna": [160, 82, 45],
      "silver": [192, 192, 192],
      "skyblue": [135, 206, 235],
      "slateblue": [106, 90, 205],
      "slategray": [112, 128, 144],
      "slategrey": [112, 128, 144],
      "snow": [255, 250, 250],
      "springgreen": [0, 255, 127],
      "steelblue": [70, 130, 180],
      "tan": [210, 180, 140],
      "teal": [0, 128, 128],
      "thistle": [216, 191, 216],
      "tomato": [255, 99, 71],
      "turquoise": [64, 224, 208],
      "violet": [238, 130, 238],
      "wheat": [245, 222, 179],
      "white": [255, 255, 255],
      "whitesmoke": [245, 245, 245],
      "yellow": [255, 255, 0],
      "yellowgreen": [154, 205, 50]
    };
  }
});

// node_modules/color-convert/conversions.js
var require_conversions = __commonJS({
  "node_modules/color-convert/conversions.js"(exports, module2) {
    var cssKeywords = require_color_name();
    var reverseKeywords = {};
    for (const key of Object.keys(cssKeywords)) {
      reverseKeywords[cssKeywords[key]] = key;
    }
    var convert = {
      rgb: { channels: 3, labels: "rgb" },
      hsl: { channels: 3, labels: "hsl" },
      hsv: { channels: 3, labels: "hsv" },
      hwb: { channels: 3, labels: "hwb" },
      cmyk: { channels: 4, labels: "cmyk" },
      xyz: { channels: 3, labels: "xyz" },
      lab: { channels: 3, labels: "lab" },
      lch: { channels: 3, labels: "lch" },
      hex: { channels: 1, labels: ["hex"] },
      keyword: { channels: 1, labels: ["keyword"] },
      ansi16: { channels: 1, labels: ["ansi16"] },
      ansi256: { channels: 1, labels: ["ansi256"] },
      hcg: { channels: 3, labels: ["h", "c", "g"] },
      apple: { channels: 3, labels: ["r16", "g16", "b16"] },
      gray: { channels: 1, labels: ["gray"] }
    };
    module2.exports = convert;
    for (const model of Object.keys(convert)) {
      if (!("channels" in convert[model])) {
        throw new Error("missing channels property: " + model);
      }
      if (!("labels" in convert[model])) {
        throw new Error("missing channel labels property: " + model);
      }
      if (convert[model].labels.length !== convert[model].channels) {
        throw new Error("channel and label counts mismatch: " + model);
      }
      const { channels, labels } = convert[model];
      delete convert[model].channels;
      delete convert[model].labels;
      Object.defineProperty(convert[model], "channels", { value: channels });
      Object.defineProperty(convert[model], "labels", { value: labels });
    }
    convert.rgb.hsl = function(rgb) {
      const r = rgb[0] / 255;
      const g = rgb[1] / 255;
      const b = rgb[2] / 255;
      const min2 = Math.min(r, g, b);
      const max2 = Math.max(r, g, b);
      const delta = max2 - min2;
      let h;
      let s;
      if (max2 === min2) {
        h = 0;
      } else if (r === max2) {
        h = (g - b) / delta;
      } else if (g === max2) {
        h = 2 + (b - r) / delta;
      } else if (b === max2) {
        h = 4 + (r - g) / delta;
      }
      h = Math.min(h * 60, 360);
      if (h < 0) {
        h += 360;
      }
      const l = (min2 + max2) / 2;
      if (max2 === min2) {
        s = 0;
      } else if (l <= 0.5) {
        s = delta / (max2 + min2);
      } else {
        s = delta / (2 - max2 - min2);
      }
      return [h, s * 100, l * 100];
    };
    convert.rgb.hsv = function(rgb) {
      let rdif;
      let gdif;
      let bdif;
      let h;
      let s;
      const r = rgb[0] / 255;
      const g = rgb[1] / 255;
      const b = rgb[2] / 255;
      const v = Math.max(r, g, b);
      const diff = v - Math.min(r, g, b);
      const diffc = function(c) {
        return (v - c) / 6 / diff + 1 / 2;
      };
      if (diff === 0) {
        h = 0;
        s = 0;
      } else {
        s = diff / v;
        rdif = diffc(r);
        gdif = diffc(g);
        bdif = diffc(b);
        if (r === v) {
          h = bdif - gdif;
        } else if (g === v) {
          h = 1 / 3 + rdif - bdif;
        } else if (b === v) {
          h = 2 / 3 + gdif - rdif;
        }
        if (h < 0) {
          h += 1;
        } else if (h > 1) {
          h -= 1;
        }
      }
      return [
        h * 360,
        s * 100,
        v * 100
      ];
    };
    convert.rgb.hwb = function(rgb) {
      const r = rgb[0];
      const g = rgb[1];
      let b = rgb[2];
      const h = convert.rgb.hsl(rgb)[0];
      const w = 1 / 255 * Math.min(r, Math.min(g, b));
      b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
      return [h, w * 100, b * 100];
    };
    convert.rgb.cmyk = function(rgb) {
      const r = rgb[0] / 255;
      const g = rgb[1] / 255;
      const b = rgb[2] / 255;
      const k = Math.min(1 - r, 1 - g, 1 - b);
      const c = (1 - r - k) / (1 - k) || 0;
      const m = (1 - g - k) / (1 - k) || 0;
      const y = (1 - b - k) / (1 - k) || 0;
      return [c * 100, m * 100, y * 100, k * 100];
    };
    function comparativeDistance(x, y) {
      return (x[0] - y[0]) ** 2 + (x[1] - y[1]) ** 2 + (x[2] - y[2]) ** 2;
    }
    convert.rgb.keyword = function(rgb) {
      const reversed = reverseKeywords[rgb];
      if (reversed) {
        return reversed;
      }
      let currentClosestDistance = Infinity;
      let currentClosestKeyword;
      for (const keyword of Object.keys(cssKeywords)) {
        const value2 = cssKeywords[keyword];
        const distance = comparativeDistance(rgb, value2);
        if (distance < currentClosestDistance) {
          currentClosestDistance = distance;
          currentClosestKeyword = keyword;
        }
      }
      return currentClosestKeyword;
    };
    convert.keyword.rgb = function(keyword) {
      return cssKeywords[keyword];
    };
    convert.rgb.xyz = function(rgb) {
      let r = rgb[0] / 255;
      let g = rgb[1] / 255;
      let b = rgb[2] / 255;
      r = r > 0.04045 ? ((r + 0.055) / 1.055) ** 2.4 : r / 12.92;
      g = g > 0.04045 ? ((g + 0.055) / 1.055) ** 2.4 : g / 12.92;
      b = b > 0.04045 ? ((b + 0.055) / 1.055) ** 2.4 : b / 12.92;
      const x = r * 0.4124 + g * 0.3576 + b * 0.1805;
      const y = r * 0.2126 + g * 0.7152 + b * 0.0722;
      const z = r * 0.0193 + g * 0.1192 + b * 0.9505;
      return [x * 100, y * 100, z * 100];
    };
    convert.rgb.lab = function(rgb) {
      const xyz = convert.rgb.xyz(rgb);
      let x = xyz[0];
      let y = xyz[1];
      let z = xyz[2];
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
      const l = 116 * y - 16;
      const a = 500 * (x - y);
      const b = 200 * (y - z);
      return [l, a, b];
    };
    convert.hsl.rgb = function(hsl) {
      const h = hsl[0] / 360;
      const s = hsl[1] / 100;
      const l = hsl[2] / 100;
      let t22;
      let t3;
      let val;
      if (s === 0) {
        val = l * 255;
        return [val, val, val];
      }
      if (l < 0.5) {
        t22 = l * (1 + s);
      } else {
        t22 = l + s - l * s;
      }
      const t1 = 2 * l - t22;
      const rgb = [0, 0, 0];
      for (let i = 0; i < 3; i++) {
        t3 = h + 1 / 3 * -(i - 1);
        if (t3 < 0) {
          t3++;
        }
        if (t3 > 1) {
          t3--;
        }
        if (6 * t3 < 1) {
          val = t1 + (t22 - t1) * 6 * t3;
        } else if (2 * t3 < 1) {
          val = t22;
        } else if (3 * t3 < 2) {
          val = t1 + (t22 - t1) * (2 / 3 - t3) * 6;
        } else {
          val = t1;
        }
        rgb[i] = val * 255;
      }
      return rgb;
    };
    convert.hsl.hsv = function(hsl) {
      const h = hsl[0];
      let s = hsl[1] / 100;
      let l = hsl[2] / 100;
      let smin = s;
      const lmin = Math.max(l, 0.01);
      l *= 2;
      s *= l <= 1 ? l : 2 - l;
      smin *= lmin <= 1 ? lmin : 2 - lmin;
      const v = (l + s) / 2;
      const sv = l === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l + s);
      return [h, sv * 100, v * 100];
    };
    convert.hsv.rgb = function(hsv) {
      const h = hsv[0] / 60;
      const s = hsv[1] / 100;
      let v = hsv[2] / 100;
      const hi = Math.floor(h) % 6;
      const f = h - Math.floor(h);
      const p = 255 * v * (1 - s);
      const q = 255 * v * (1 - s * f);
      const t3 = 255 * v * (1 - s * (1 - f));
      v *= 255;
      switch (hi) {
        case 0:
          return [v, t3, p];
        case 1:
          return [q, v, p];
        case 2:
          return [p, v, t3];
        case 3:
          return [p, q, v];
        case 4:
          return [t3, p, v];
        case 5:
          return [v, p, q];
      }
    };
    convert.hsv.hsl = function(hsv) {
      const h = hsv[0];
      const s = hsv[1] / 100;
      const v = hsv[2] / 100;
      const vmin = Math.max(v, 0.01);
      let sl;
      let l;
      l = (2 - s) * v;
      const lmin = (2 - s) * vmin;
      sl = s * vmin;
      sl /= lmin <= 1 ? lmin : 2 - lmin;
      sl = sl || 0;
      l /= 2;
      return [h, sl * 100, l * 100];
    };
    convert.hwb.rgb = function(hwb) {
      const h = hwb[0] / 360;
      let wh = hwb[1] / 100;
      let bl = hwb[2] / 100;
      const ratio = wh + bl;
      let f;
      if (ratio > 1) {
        wh /= ratio;
        bl /= ratio;
      }
      const i = Math.floor(6 * h);
      const v = 1 - bl;
      f = 6 * h - i;
      if ((i & 1) !== 0) {
        f = 1 - f;
      }
      const n = wh + f * (v - wh);
      let r;
      let g;
      let b;
      switch (i) {
        default:
        case 6:
        case 0:
          r = v;
          g = n;
          b = wh;
          break;
        case 1:
          r = n;
          g = v;
          b = wh;
          break;
        case 2:
          r = wh;
          g = v;
          b = n;
          break;
        case 3:
          r = wh;
          g = n;
          b = v;
          break;
        case 4:
          r = n;
          g = wh;
          b = v;
          break;
        case 5:
          r = v;
          g = wh;
          b = n;
          break;
      }
      return [r * 255, g * 255, b * 255];
    };
    convert.cmyk.rgb = function(cmyk) {
      const c = cmyk[0] / 100;
      const m = cmyk[1] / 100;
      const y = cmyk[2] / 100;
      const k = cmyk[3] / 100;
      const r = 1 - Math.min(1, c * (1 - k) + k);
      const g = 1 - Math.min(1, m * (1 - k) + k);
      const b = 1 - Math.min(1, y * (1 - k) + k);
      return [r * 255, g * 255, b * 255];
    };
    convert.xyz.rgb = function(xyz) {
      const x = xyz[0] / 100;
      const y = xyz[1] / 100;
      const z = xyz[2] / 100;
      let r;
      let g;
      let b;
      r = x * 3.2406 + y * -1.5372 + z * -0.4986;
      g = x * -0.9689 + y * 1.8758 + z * 0.0415;
      b = x * 0.0557 + y * -0.204 + z * 1.057;
      r = r > 31308e-7 ? 1.055 * r ** (1 / 2.4) - 0.055 : r * 12.92;
      g = g > 31308e-7 ? 1.055 * g ** (1 / 2.4) - 0.055 : g * 12.92;
      b = b > 31308e-7 ? 1.055 * b ** (1 / 2.4) - 0.055 : b * 12.92;
      r = Math.min(Math.max(0, r), 1);
      g = Math.min(Math.max(0, g), 1);
      b = Math.min(Math.max(0, b), 1);
      return [r * 255, g * 255, b * 255];
    };
    convert.xyz.lab = function(xyz) {
      let x = xyz[0];
      let y = xyz[1];
      let z = xyz[2];
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
      const l = 116 * y - 16;
      const a = 500 * (x - y);
      const b = 200 * (y - z);
      return [l, a, b];
    };
    convert.lab.xyz = function(lab) {
      const l = lab[0];
      const a = lab[1];
      const b = lab[2];
      let x;
      let y;
      let z;
      y = (l + 16) / 116;
      x = a / 500 + y;
      z = y - b / 200;
      const y2 = y ** 3;
      const x2 = x ** 3;
      const z2 = z ** 3;
      y = y2 > 8856e-6 ? y2 : (y - 16 / 116) / 7.787;
      x = x2 > 8856e-6 ? x2 : (x - 16 / 116) / 7.787;
      z = z2 > 8856e-6 ? z2 : (z - 16 / 116) / 7.787;
      x *= 95.047;
      y *= 100;
      z *= 108.883;
      return [x, y, z];
    };
    convert.lab.lch = function(lab) {
      const l = lab[0];
      const a = lab[1];
      const b = lab[2];
      let h;
      const hr = Math.atan2(b, a);
      h = hr * 360 / 2 / Math.PI;
      if (h < 0) {
        h += 360;
      }
      const c = Math.sqrt(a * a + b * b);
      return [l, c, h];
    };
    convert.lch.lab = function(lch) {
      const l = lch[0];
      const c = lch[1];
      const h = lch[2];
      const hr = h / 360 * 2 * Math.PI;
      const a = c * Math.cos(hr);
      const b = c * Math.sin(hr);
      return [l, a, b];
    };
    convert.rgb.ansi16 = function(args, saturation = null) {
      const [r, g, b] = args;
      let value2 = saturation === null ? convert.rgb.hsv(args)[2] : saturation;
      value2 = Math.round(value2 / 50);
      if (value2 === 0) {
        return 30;
      }
      let ansi = 30 + (Math.round(b / 255) << 2 | Math.round(g / 255) << 1 | Math.round(r / 255));
      if (value2 === 2) {
        ansi += 60;
      }
      return ansi;
    };
    convert.hsv.ansi16 = function(args) {
      return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
    };
    convert.rgb.ansi256 = function(args) {
      const r = args[0];
      const g = args[1];
      const b = args[2];
      if (r === g && g === b) {
        if (r < 8) {
          return 16;
        }
        if (r > 248) {
          return 231;
        }
        return Math.round((r - 8) / 247 * 24) + 232;
      }
      const ansi = 16 + 36 * Math.round(r / 255 * 5) + 6 * Math.round(g / 255 * 5) + Math.round(b / 255 * 5);
      return ansi;
    };
    convert.ansi16.rgb = function(args) {
      let color = args % 10;
      if (color === 0 || color === 7) {
        if (args > 50) {
          color += 3.5;
        }
        color = color / 10.5 * 255;
        return [color, color, color];
      }
      const mult = (~~(args > 50) + 1) * 0.5;
      const r = (color & 1) * mult * 255;
      const g = (color >> 1 & 1) * mult * 255;
      const b = (color >> 2 & 1) * mult * 255;
      return [r, g, b];
    };
    convert.ansi256.rgb = function(args) {
      if (args >= 232) {
        const c = (args - 232) * 10 + 8;
        return [c, c, c];
      }
      args -= 16;
      let rem;
      const r = Math.floor(args / 36) / 5 * 255;
      const g = Math.floor((rem = args % 36) / 6) / 5 * 255;
      const b = rem % 6 / 5 * 255;
      return [r, g, b];
    };
    convert.rgb.hex = function(args) {
      const integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
      const string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.hex.rgb = function(args) {
      const match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
      if (!match) {
        return [0, 0, 0];
      }
      let colorString = match[0];
      if (match[0].length === 3) {
        colorString = colorString.split("").map((char) => {
          return char + char;
        }).join("");
      }
      const integer = parseInt(colorString, 16);
      const r = integer >> 16 & 255;
      const g = integer >> 8 & 255;
      const b = integer & 255;
      return [r, g, b];
    };
    convert.rgb.hcg = function(rgb) {
      const r = rgb[0] / 255;
      const g = rgb[1] / 255;
      const b = rgb[2] / 255;
      const max2 = Math.max(Math.max(r, g), b);
      const min2 = Math.min(Math.min(r, g), b);
      const chroma = max2 - min2;
      let grayscale;
      let hue;
      if (chroma < 1) {
        grayscale = min2 / (1 - chroma);
      } else {
        grayscale = 0;
      }
      if (chroma <= 0) {
        hue = 0;
      } else if (max2 === r) {
        hue = (g - b) / chroma % 6;
      } else if (max2 === g) {
        hue = 2 + (b - r) / chroma;
      } else {
        hue = 4 + (r - g) / chroma;
      }
      hue /= 6;
      hue %= 1;
      return [hue * 360, chroma * 100, grayscale * 100];
    };
    convert.hsl.hcg = function(hsl) {
      const s = hsl[1] / 100;
      const l = hsl[2] / 100;
      const c = l < 0.5 ? 2 * s * l : 2 * s * (1 - l);
      let f = 0;
      if (c < 1) {
        f = (l - 0.5 * c) / (1 - c);
      }
      return [hsl[0], c * 100, f * 100];
    };
    convert.hsv.hcg = function(hsv) {
      const s = hsv[1] / 100;
      const v = hsv[2] / 100;
      const c = s * v;
      let f = 0;
      if (c < 1) {
        f = (v - c) / (1 - c);
      }
      return [hsv[0], c * 100, f * 100];
    };
    convert.hcg.rgb = function(hcg) {
      const h = hcg[0] / 360;
      const c = hcg[1] / 100;
      const g = hcg[2] / 100;
      if (c === 0) {
        return [g * 255, g * 255, g * 255];
      }
      const pure = [0, 0, 0];
      const hi = h % 1 * 6;
      const v = hi % 1;
      const w = 1 - v;
      let mg = 0;
      switch (Math.floor(hi)) {
        case 0:
          pure[0] = 1;
          pure[1] = v;
          pure[2] = 0;
          break;
        case 1:
          pure[0] = w;
          pure[1] = 1;
          pure[2] = 0;
          break;
        case 2:
          pure[0] = 0;
          pure[1] = 1;
          pure[2] = v;
          break;
        case 3:
          pure[0] = 0;
          pure[1] = w;
          pure[2] = 1;
          break;
        case 4:
          pure[0] = v;
          pure[1] = 0;
          pure[2] = 1;
          break;
        default:
          pure[0] = 1;
          pure[1] = 0;
          pure[2] = w;
      }
      mg = (1 - c) * g;
      return [
        (c * pure[0] + mg) * 255,
        (c * pure[1] + mg) * 255,
        (c * pure[2] + mg) * 255
      ];
    };
    convert.hcg.hsv = function(hcg) {
      const c = hcg[1] / 100;
      const g = hcg[2] / 100;
      const v = c + g * (1 - c);
      let f = 0;
      if (v > 0) {
        f = c / v;
      }
      return [hcg[0], f * 100, v * 100];
    };
    convert.hcg.hsl = function(hcg) {
      const c = hcg[1] / 100;
      const g = hcg[2] / 100;
      const l = g * (1 - c) + 0.5 * c;
      let s = 0;
      if (l > 0 && l < 0.5) {
        s = c / (2 * l);
      } else if (l >= 0.5 && l < 1) {
        s = c / (2 * (1 - l));
      }
      return [hcg[0], s * 100, l * 100];
    };
    convert.hcg.hwb = function(hcg) {
      const c = hcg[1] / 100;
      const g = hcg[2] / 100;
      const v = c + g * (1 - c);
      return [hcg[0], (v - c) * 100, (1 - v) * 100];
    };
    convert.hwb.hcg = function(hwb) {
      const w = hwb[1] / 100;
      const b = hwb[2] / 100;
      const v = 1 - b;
      const c = v - w;
      let g = 0;
      if (c < 1) {
        g = (v - c) / (1 - c);
      }
      return [hwb[0], c * 100, g * 100];
    };
    convert.apple.rgb = function(apple) {
      return [apple[0] / 65535 * 255, apple[1] / 65535 * 255, apple[2] / 65535 * 255];
    };
    convert.rgb.apple = function(rgb) {
      return [rgb[0] / 255 * 65535, rgb[1] / 255 * 65535, rgb[2] / 255 * 65535];
    };
    convert.gray.rgb = function(args) {
      return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
    };
    convert.gray.hsl = function(args) {
      return [0, 0, args[0]];
    };
    convert.gray.hsv = convert.gray.hsl;
    convert.gray.hwb = function(gray) {
      return [0, 100, gray[0]];
    };
    convert.gray.cmyk = function(gray) {
      return [0, 0, 0, gray[0]];
    };
    convert.gray.lab = function(gray) {
      return [gray[0], 0, 0];
    };
    convert.gray.hex = function(gray) {
      const val = Math.round(gray[0] / 100 * 255) & 255;
      const integer = (val << 16) + (val << 8) + val;
      const string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.rgb.gray = function(rgb) {
      const val = (rgb[0] + rgb[1] + rgb[2]) / 3;
      return [val / 255 * 100];
    };
  }
});

// node_modules/color-convert/route.js
var require_route = __commonJS({
  "node_modules/color-convert/route.js"(exports, module2) {
    var conversions = require_conversions();
    function buildGraph() {
      const graph = {};
      const models = Object.keys(conversions);
      for (let len = models.length, i = 0; i < len; i++) {
        graph[models[i]] = {
          // http://jsperf.com/1-vs-infinity
          // micro-opt, but this is simple.
          distance: -1,
          parent: null
        };
      }
      return graph;
    }
    function deriveBFS(fromModel) {
      const graph = buildGraph();
      const queue = [fromModel];
      graph[fromModel].distance = 0;
      while (queue.length) {
        const current = queue.pop();
        const adjacents = Object.keys(conversions[current]);
        for (let len = adjacents.length, i = 0; i < len; i++) {
          const adjacent = adjacents[i];
          const node = graph[adjacent];
          if (node.distance === -1) {
            node.distance = graph[current].distance + 1;
            node.parent = current;
            queue.unshift(adjacent);
          }
        }
      }
      return graph;
    }
    function link(from, to) {
      return function(args) {
        return to(from(args));
      };
    }
    function wrapConversion(toModel, graph) {
      const path2 = [graph[toModel].parent, toModel];
      let fn = conversions[graph[toModel].parent][toModel];
      let cur = graph[toModel].parent;
      while (graph[cur].parent) {
        path2.unshift(graph[cur].parent);
        fn = link(conversions[graph[cur].parent][cur], fn);
        cur = graph[cur].parent;
      }
      fn.conversion = path2;
      return fn;
    }
    module2.exports = function(fromModel) {
      const graph = deriveBFS(fromModel);
      const conversion = {};
      const models = Object.keys(graph);
      for (let len = models.length, i = 0; i < len; i++) {
        const toModel = models[i];
        const node = graph[toModel];
        if (node.parent === null) {
          continue;
        }
        conversion[toModel] = wrapConversion(toModel, graph);
      }
      return conversion;
    };
  }
});

// node_modules/color-convert/index.js
var require_color_convert = __commonJS({
  "node_modules/color-convert/index.js"(exports, module2) {
    var conversions = require_conversions();
    var route = require_route();
    var convert = {};
    var models = Object.keys(conversions);
    function wrapRaw(fn) {
      const wrappedFn = function(...args) {
        const arg0 = args[0];
        if (arg0 === void 0 || arg0 === null) {
          return arg0;
        }
        if (arg0.length > 1) {
          args = arg0;
        }
        return fn(args);
      };
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    function wrapRounded(fn) {
      const wrappedFn = function(...args) {
        const arg0 = args[0];
        if (arg0 === void 0 || arg0 === null) {
          return arg0;
        }
        if (arg0.length > 1) {
          args = arg0;
        }
        const result = fn(args);
        if (typeof result === "object") {
          for (let len = result.length, i = 0; i < len; i++) {
            result[i] = Math.round(result[i]);
          }
        }
        return result;
      };
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    models.forEach((fromModel) => {
      convert[fromModel] = {};
      Object.defineProperty(convert[fromModel], "channels", { value: conversions[fromModel].channels });
      Object.defineProperty(convert[fromModel], "labels", { value: conversions[fromModel].labels });
      const routes = route(fromModel);
      const routeModels = Object.keys(routes);
      routeModels.forEach((toModel) => {
        const fn = routes[toModel];
        convert[fromModel][toModel] = wrapRounded(fn);
        convert[fromModel][toModel].raw = wrapRaw(fn);
      });
    });
    module2.exports = convert;
  }
});

// node_modules/ansi-styles/index.js
var require_ansi_styles = __commonJS({
  "node_modules/ansi-styles/index.js"(exports, module2) {
    "use strict";
    var wrapAnsi16 = (fn, offset) => (...args) => {
      const code = fn(...args);
      return `\x1B[${code + offset}m`;
    };
    var wrapAnsi256 = (fn, offset) => (...args) => {
      const code = fn(...args);
      return `\x1B[${38 + offset};5;${code}m`;
    };
    var wrapAnsi16m = (fn, offset) => (...args) => {
      const rgb = fn(...args);
      return `\x1B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
    };
    var ansi2ansi = (n) => n;
    var rgb2rgb = (r, g, b) => [r, g, b];
    var setLazyProperty = (object, property, get) => {
      Object.defineProperty(object, property, {
        get: () => {
          const value2 = get();
          Object.defineProperty(object, property, {
            value: value2,
            enumerable: true,
            configurable: true
          });
          return value2;
        },
        enumerable: true,
        configurable: true
      });
    };
    var colorConvert;
    var makeDynamicStyles = (wrap, targetSpace, identity, isBackground) => {
      if (colorConvert === void 0) {
        colorConvert = require_color_convert();
      }
      const offset = isBackground ? 10 : 0;
      const styles = {};
      for (const [sourceSpace, suite] of Object.entries(colorConvert)) {
        const name = sourceSpace === "ansi16" ? "ansi" : sourceSpace;
        if (sourceSpace === targetSpace) {
          styles[name] = wrap(identity, offset);
        } else if (typeof suite === "object") {
          styles[name] = wrap(suite[targetSpace], offset);
        }
      }
      return styles;
    };
    function assembleStyles() {
      const codes = /* @__PURE__ */ new Map();
      const styles = {
        modifier: {
          reset: [0, 0],
          // 21 isn't widely supported and 22 does the same thing
          bold: [1, 22],
          dim: [2, 22],
          italic: [3, 23],
          underline: [4, 24],
          inverse: [7, 27],
          hidden: [8, 28],
          strikethrough: [9, 29]
        },
        color: {
          black: [30, 39],
          red: [31, 39],
          green: [32, 39],
          yellow: [33, 39],
          blue: [34, 39],
          magenta: [35, 39],
          cyan: [36, 39],
          white: [37, 39],
          // Bright color
          blackBright: [90, 39],
          redBright: [91, 39],
          greenBright: [92, 39],
          yellowBright: [93, 39],
          blueBright: [94, 39],
          magentaBright: [95, 39],
          cyanBright: [96, 39],
          whiteBright: [97, 39]
        },
        bgColor: {
          bgBlack: [40, 49],
          bgRed: [41, 49],
          bgGreen: [42, 49],
          bgYellow: [43, 49],
          bgBlue: [44, 49],
          bgMagenta: [45, 49],
          bgCyan: [46, 49],
          bgWhite: [47, 49],
          // Bright color
          bgBlackBright: [100, 49],
          bgRedBright: [101, 49],
          bgGreenBright: [102, 49],
          bgYellowBright: [103, 49],
          bgBlueBright: [104, 49],
          bgMagentaBright: [105, 49],
          bgCyanBright: [106, 49],
          bgWhiteBright: [107, 49]
        }
      };
      styles.color.gray = styles.color.blackBright;
      styles.bgColor.bgGray = styles.bgColor.bgBlackBright;
      styles.color.grey = styles.color.blackBright;
      styles.bgColor.bgGrey = styles.bgColor.bgBlackBright;
      for (const [groupName, group] of Object.entries(styles)) {
        for (const [styleName, style] of Object.entries(group)) {
          styles[styleName] = {
            open: `\x1B[${style[0]}m`,
            close: `\x1B[${style[1]}m`
          };
          group[styleName] = styles[styleName];
          codes.set(style[0], style[1]);
        }
        Object.defineProperty(styles, groupName, {
          value: group,
          enumerable: false
        });
      }
      Object.defineProperty(styles, "codes", {
        value: codes,
        enumerable: false
      });
      styles.color.close = "\x1B[39m";
      styles.bgColor.close = "\x1B[49m";
      setLazyProperty(styles.color, "ansi", () => makeDynamicStyles(wrapAnsi16, "ansi16", ansi2ansi, false));
      setLazyProperty(styles.color, "ansi256", () => makeDynamicStyles(wrapAnsi256, "ansi256", ansi2ansi, false));
      setLazyProperty(styles.color, "ansi16m", () => makeDynamicStyles(wrapAnsi16m, "rgb", rgb2rgb, false));
      setLazyProperty(styles.bgColor, "ansi", () => makeDynamicStyles(wrapAnsi16, "ansi16", ansi2ansi, true));
      setLazyProperty(styles.bgColor, "ansi256", () => makeDynamicStyles(wrapAnsi256, "ansi256", ansi2ansi, true));
      setLazyProperty(styles.bgColor, "ansi16m", () => makeDynamicStyles(wrapAnsi16m, "rgb", rgb2rgb, true));
      return styles;
    }
    Object.defineProperty(module2, "exports", {
      enumerable: true,
      get: assembleStyles
    });
  }
});

// node_modules/has-flag/index.js
var require_has_flag = __commonJS({
  "node_modules/has-flag/index.js"(exports, module2) {
    "use strict";
    module2.exports = (flag, argv = process.argv) => {
      const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
      const position = argv.indexOf(prefix + flag);
      const terminatorPosition = argv.indexOf("--");
      return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
    };
  }
});

// node_modules/supports-color/index.js
var require_supports_color = __commonJS({
  "node_modules/supports-color/index.js"(exports, module2) {
    "use strict";
    var os = require("os");
    var tty = require("tty");
    var hasFlag = require_has_flag();
    var { env } = process;
    var forceColor;
    if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false") || hasFlag("color=never")) {
      forceColor = 0;
    } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
      forceColor = 1;
    }
    if ("FORCE_COLOR" in env) {
      if (env.FORCE_COLOR === "true") {
        forceColor = 1;
      } else if (env.FORCE_COLOR === "false") {
        forceColor = 0;
      } else {
        forceColor = env.FORCE_COLOR.length === 0 ? 1 : Math.min(parseInt(env.FORCE_COLOR, 10), 3);
      }
    }
    function translateLevel(level) {
      if (level === 0) {
        return false;
      }
      return {
        level,
        hasBasic: true,
        has256: level >= 2,
        has16m: level >= 3
      };
    }
    function supportsColor(haveStream, streamIsTTY) {
      if (forceColor === 0) {
        return 0;
      }
      if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
        return 3;
      }
      if (hasFlag("color=256")) {
        return 2;
      }
      if (haveStream && !streamIsTTY && forceColor === void 0) {
        return 0;
      }
      const min2 = forceColor || 0;
      if (env.TERM === "dumb") {
        return min2;
      }
      if (process.platform === "win32") {
        const osRelease = os.release().split(".");
        if (Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
          return Number(osRelease[2]) >= 14931 ? 3 : 2;
        }
        return 1;
      }
      if ("CI" in env) {
        if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI", "GITHUB_ACTIONS", "BUILDKITE"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
          return 1;
        }
        return min2;
      }
      if ("TEAMCITY_VERSION" in env) {
        return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
      }
      if (env.COLORTERM === "truecolor") {
        return 3;
      }
      if ("TERM_PROGRAM" in env) {
        const version2 = parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
        switch (env.TERM_PROGRAM) {
          case "iTerm.app":
            return version2 >= 3 ? 3 : 2;
          case "Apple_Terminal":
            return 2;
        }
      }
      if (/-256(color)?$/i.test(env.TERM)) {
        return 2;
      }
      if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
        return 1;
      }
      if ("COLORTERM" in env) {
        return 1;
      }
      return min2;
    }
    function getSupportLevel(stream) {
      const level = supportsColor(stream, stream && stream.isTTY);
      return translateLevel(level);
    }
    module2.exports = {
      supportsColor: getSupportLevel,
      stdout: translateLevel(supportsColor(true, tty.isatty(1))),
      stderr: translateLevel(supportsColor(true, tty.isatty(2)))
    };
  }
});

// node_modules/chalk/source/util.js
var require_util = __commonJS({
  "node_modules/chalk/source/util.js"(exports, module2) {
    "use strict";
    var stringReplaceAll = (string, substring, replacer) => {
      let index = string.indexOf(substring);
      if (index === -1) {
        return string;
      }
      const substringLength = substring.length;
      let endIndex = 0;
      let returnValue = "";
      do {
        returnValue += string.substr(endIndex, index - endIndex) + substring + replacer;
        endIndex = index + substringLength;
        index = string.indexOf(substring, endIndex);
      } while (index !== -1);
      returnValue += string.substr(endIndex);
      return returnValue;
    };
    var stringEncaseCRLFWithFirstIndex = (string, prefix, postfix, index) => {
      let endIndex = 0;
      let returnValue = "";
      do {
        const gotCR = string[index - 1] === "\r";
        returnValue += string.substr(endIndex, (gotCR ? index - 1 : index) - endIndex) + prefix + (gotCR ? "\r\n" : "\n") + postfix;
        endIndex = index + 1;
        index = string.indexOf("\n", endIndex);
      } while (index !== -1);
      returnValue += string.substr(endIndex);
      return returnValue;
    };
    module2.exports = {
      stringReplaceAll,
      stringEncaseCRLFWithFirstIndex
    };
  }
});

// node_modules/chalk/source/templates.js
var require_templates = __commonJS({
  "node_modules/chalk/source/templates.js"(exports, module2) {
    "use strict";
    var TEMPLATE_REGEX = /(?:\\(u(?:[a-f\d]{4}|\{[a-f\d]{1,6}\})|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
    var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
    var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
    var ESCAPE_REGEX = /\\(u(?:[a-f\d]{4}|{[a-f\d]{1,6}})|x[a-f\d]{2}|.)|([^\\])/gi;
    var ESCAPES = /* @__PURE__ */ new Map([
      ["n", "\n"],
      ["r", "\r"],
      ["t", "	"],
      ["b", "\b"],
      ["f", "\f"],
      ["v", "\v"],
      ["0", "\0"],
      ["\\", "\\"],
      ["e", "\x1B"],
      ["a", "\x07"]
    ]);
    function unescape2(c) {
      const u = c[0] === "u";
      const bracket = c[1] === "{";
      if (u && !bracket && c.length === 5 || c[0] === "x" && c.length === 3) {
        return String.fromCharCode(parseInt(c.slice(1), 16));
      }
      if (u && bracket) {
        return String.fromCodePoint(parseInt(c.slice(2, -1), 16));
      }
      return ESCAPES.get(c) || c;
    }
    function parseArguments(name, arguments_) {
      const results = [];
      const chunks = arguments_.trim().split(/\s*,\s*/g);
      let matches;
      for (const chunk of chunks) {
        const number = Number(chunk);
        if (!Number.isNaN(number)) {
          results.push(number);
        } else if (matches = chunk.match(STRING_REGEX)) {
          results.push(matches[2].replace(ESCAPE_REGEX, (m, escape2, character) => escape2 ? unescape2(escape2) : character));
        } else {
          throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
        }
      }
      return results;
    }
    function parseStyle(style) {
      STYLE_REGEX.lastIndex = 0;
      const results = [];
      let matches;
      while ((matches = STYLE_REGEX.exec(style)) !== null) {
        const name = matches[1];
        if (matches[2]) {
          const args = parseArguments(name, matches[2]);
          results.push([name].concat(args));
        } else {
          results.push([name]);
        }
      }
      return results;
    }
    function buildStyle(chalk3, styles) {
      const enabled = {};
      for (const layer of styles) {
        for (const style of layer.styles) {
          enabled[style[0]] = layer.inverse ? null : style.slice(1);
        }
      }
      let current = chalk3;
      for (const [styleName, styles2] of Object.entries(enabled)) {
        if (!Array.isArray(styles2)) {
          continue;
        }
        if (!(styleName in current)) {
          throw new Error(`Unknown Chalk style: ${styleName}`);
        }
        current = styles2.length > 0 ? current[styleName](...styles2) : current[styleName];
      }
      return current;
    }
    module2.exports = (chalk3, temporary) => {
      const styles = [];
      const chunks = [];
      let chunk = [];
      temporary.replace(TEMPLATE_REGEX, (m, escapeCharacter, inverse, style, close, character) => {
        if (escapeCharacter) {
          chunk.push(unescape2(escapeCharacter));
        } else if (style) {
          const string = chunk.join("");
          chunk = [];
          chunks.push(styles.length === 0 ? string : buildStyle(chalk3, styles)(string));
          styles.push({ inverse, styles: parseStyle(style) });
        } else if (close) {
          if (styles.length === 0) {
            throw new Error("Found extraneous } in Chalk template literal");
          }
          chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
          chunk = [];
          styles.pop();
        } else {
          chunk.push(character);
        }
      });
      chunks.push(chunk.join(""));
      if (styles.length > 0) {
        const errMessage = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
        throw new Error(errMessage);
      }
      return chunks.join("");
    };
  }
});

// node_modules/chalk/source/index.js
var require_source = __commonJS({
  "node_modules/chalk/source/index.js"(exports, module2) {
    "use strict";
    var ansiStyles = require_ansi_styles();
    var { stdout: stdoutColor, stderr: stderrColor } = require_supports_color();
    var {
      stringReplaceAll,
      stringEncaseCRLFWithFirstIndex
    } = require_util();
    var { isArray: isArray2 } = Array;
    var levelMapping = [
      "ansi",
      "ansi",
      "ansi256",
      "ansi16m"
    ];
    var styles = /* @__PURE__ */ Object.create(null);
    var applyOptions = (object, options = {}) => {
      if (options.level && !(Number.isInteger(options.level) && options.level >= 0 && options.level <= 3)) {
        throw new Error("The `level` option should be an integer from 0 to 3");
      }
      const colorLevel = stdoutColor ? stdoutColor.level : 0;
      object.level = options.level === void 0 ? colorLevel : options.level;
    };
    var ChalkClass = class {
      constructor(options) {
        return chalkFactory(options);
      }
    };
    var chalkFactory = (options) => {
      const chalk4 = {};
      applyOptions(chalk4, options);
      chalk4.template = (...arguments_) => chalkTag(chalk4.template, ...arguments_);
      Object.setPrototypeOf(chalk4, Chalk.prototype);
      Object.setPrototypeOf(chalk4.template, chalk4);
      chalk4.template.constructor = () => {
        throw new Error("`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.");
      };
      chalk4.template.Instance = ChalkClass;
      return chalk4.template;
    };
    function Chalk(options) {
      return chalkFactory(options);
    }
    for (const [styleName, style] of Object.entries(ansiStyles)) {
      styles[styleName] = {
        get() {
          const builder = createBuilder(this, createStyler(style.open, style.close, this._styler), this._isEmpty);
          Object.defineProperty(this, styleName, { value: builder });
          return builder;
        }
      };
    }
    styles.visible = {
      get() {
        const builder = createBuilder(this, this._styler, true);
        Object.defineProperty(this, "visible", { value: builder });
        return builder;
      }
    };
    var usedModels = ["rgb", "hex", "keyword", "hsl", "hsv", "hwb", "ansi", "ansi256"];
    for (const model of usedModels) {
      styles[model] = {
        get() {
          const { level } = this;
          return function(...arguments_) {
            const styler = createStyler(ansiStyles.color[levelMapping[level]][model](...arguments_), ansiStyles.color.close, this._styler);
            return createBuilder(this, styler, this._isEmpty);
          };
        }
      };
    }
    for (const model of usedModels) {
      const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
      styles[bgModel] = {
        get() {
          const { level } = this;
          return function(...arguments_) {
            const styler = createStyler(ansiStyles.bgColor[levelMapping[level]][model](...arguments_), ansiStyles.bgColor.close, this._styler);
            return createBuilder(this, styler, this._isEmpty);
          };
        }
      };
    }
    var proto = Object.defineProperties(() => {
    }, {
      ...styles,
      level: {
        enumerable: true,
        get() {
          return this._generator.level;
        },
        set(level) {
          this._generator.level = level;
        }
      }
    });
    var createStyler = (open, close, parent) => {
      let openAll;
      let closeAll;
      if (parent === void 0) {
        openAll = open;
        closeAll = close;
      } else {
        openAll = parent.openAll + open;
        closeAll = close + parent.closeAll;
      }
      return {
        open,
        close,
        openAll,
        closeAll,
        parent
      };
    };
    var createBuilder = (self2, _styler, _isEmpty) => {
      const builder = (...arguments_) => {
        if (isArray2(arguments_[0]) && isArray2(arguments_[0].raw)) {
          return applyStyle(builder, chalkTag(builder, ...arguments_));
        }
        return applyStyle(builder, arguments_.length === 1 ? "" + arguments_[0] : arguments_.join(" "));
      };
      Object.setPrototypeOf(builder, proto);
      builder._generator = self2;
      builder._styler = _styler;
      builder._isEmpty = _isEmpty;
      return builder;
    };
    var applyStyle = (self2, string) => {
      if (self2.level <= 0 || !string) {
        return self2._isEmpty ? "" : string;
      }
      let styler = self2._styler;
      if (styler === void 0) {
        return string;
      }
      const { openAll, closeAll } = styler;
      if (string.indexOf("\x1B") !== -1) {
        while (styler !== void 0) {
          string = stringReplaceAll(string, styler.close, styler.open);
          styler = styler.parent;
        }
      }
      const lfIndex = string.indexOf("\n");
      if (lfIndex !== -1) {
        string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
      }
      return openAll + string + closeAll;
    };
    var template;
    var chalkTag = (chalk4, ...strings) => {
      const [firstString] = strings;
      if (!isArray2(firstString) || !isArray2(firstString.raw)) {
        return strings.join(" ");
      }
      const arguments_ = strings.slice(1);
      const parts = [firstString.raw[0]];
      for (let i = 1; i < firstString.length; i++) {
        parts.push(
          String(arguments_[i - 1]).replace(/[{}\\]/g, "\\$&"),
          String(firstString.raw[i])
        );
      }
      if (template === void 0) {
        template = require_templates();
      }
      return template(chalk4, parts.join(""));
    };
    Object.defineProperties(Chalk.prototype, styles);
    var chalk3 = Chalk();
    chalk3.supportsColor = stdoutColor;
    chalk3.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 });
    chalk3.stderr.supportsColor = stderrColor;
    module2.exports = chalk3;
  }
});

// node_modules/fs.realpath/old.js
var require_old = __commonJS({
  "node_modules/fs.realpath/old.js"(exports) {
    var pathModule = require("path");
    var isWindows = process.platform === "win32";
    var fs2 = require("fs");
    var DEBUG = process.env.NODE_DEBUG && /fs/.test(process.env.NODE_DEBUG);
    function rethrow() {
      var callback;
      if (DEBUG) {
        var backtrace = new Error();
        callback = debugCallback;
      } else
        callback = missingCallback;
      return callback;
      function debugCallback(err) {
        if (err) {
          backtrace.message = err.message;
          err = backtrace;
          missingCallback(err);
        }
      }
      function missingCallback(err) {
        if (err) {
          if (process.throwDeprecation)
            throw err;
          else if (!process.noDeprecation) {
            var msg = "fs: missing callback " + (err.stack || err.message);
            if (process.traceDeprecation)
              console.trace(msg);
            else
              console.error(msg);
          }
        }
      }
    }
    function maybeCallback(cb) {
      return typeof cb === "function" ? cb : rethrow();
    }
    var normalize = pathModule.normalize;
    if (isWindows) {
      nextPartRe = /(.*?)(?:[\/\\]+|$)/g;
    } else {
      nextPartRe = /(.*?)(?:[\/]+|$)/g;
    }
    var nextPartRe;
    if (isWindows) {
      splitRootRe = /^(?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/][^\\\/]+)?[\\\/]*/;
    } else {
      splitRootRe = /^[\/]*/;
    }
    var splitRootRe;
    exports.realpathSync = function realpathSync(p, cache) {
      p = pathModule.resolve(p);
      if (cache && Object.prototype.hasOwnProperty.call(cache, p)) {
        return cache[p];
      }
      var original = p, seenLinks = {}, knownHard = {};
      var pos;
      var current;
      var base;
      var previous;
      start();
      function start() {
        var m = splitRootRe.exec(p);
        pos = m[0].length;
        current = m[0];
        base = m[0];
        previous = "";
        if (isWindows && !knownHard[base]) {
          fs2.lstatSync(base);
          knownHard[base] = true;
        }
      }
      while (pos < p.length) {
        nextPartRe.lastIndex = pos;
        var result = nextPartRe.exec(p);
        previous = current;
        current += result[0];
        base = previous + result[1];
        pos = nextPartRe.lastIndex;
        if (knownHard[base] || cache && cache[base] === base) {
          continue;
        }
        var resolvedLink;
        if (cache && Object.prototype.hasOwnProperty.call(cache, base)) {
          resolvedLink = cache[base];
        } else {
          var stat = fs2.lstatSync(base);
          if (!stat.isSymbolicLink()) {
            knownHard[base] = true;
            if (cache)
              cache[base] = base;
            continue;
          }
          var linkTarget = null;
          if (!isWindows) {
            var id = stat.dev.toString(32) + ":" + stat.ino.toString(32);
            if (seenLinks.hasOwnProperty(id)) {
              linkTarget = seenLinks[id];
            }
          }
          if (linkTarget === null) {
            fs2.statSync(base);
            linkTarget = fs2.readlinkSync(base);
          }
          resolvedLink = pathModule.resolve(previous, linkTarget);
          if (cache)
            cache[base] = resolvedLink;
          if (!isWindows)
            seenLinks[id] = linkTarget;
        }
        p = pathModule.resolve(resolvedLink, p.slice(pos));
        start();
      }
      if (cache)
        cache[original] = p;
      return p;
    };
    exports.realpath = function realpath(p, cache, cb) {
      if (typeof cb !== "function") {
        cb = maybeCallback(cache);
        cache = null;
      }
      p = pathModule.resolve(p);
      if (cache && Object.prototype.hasOwnProperty.call(cache, p)) {
        return process.nextTick(cb.bind(null, null, cache[p]));
      }
      var original = p, seenLinks = {}, knownHard = {};
      var pos;
      var current;
      var base;
      var previous;
      start();
      function start() {
        var m = splitRootRe.exec(p);
        pos = m[0].length;
        current = m[0];
        base = m[0];
        previous = "";
        if (isWindows && !knownHard[base]) {
          fs2.lstat(base, function(err) {
            if (err)
              return cb(err);
            knownHard[base] = true;
            LOOP();
          });
        } else {
          process.nextTick(LOOP);
        }
      }
      function LOOP() {
        if (pos >= p.length) {
          if (cache)
            cache[original] = p;
          return cb(null, p);
        }
        nextPartRe.lastIndex = pos;
        var result = nextPartRe.exec(p);
        previous = current;
        current += result[0];
        base = previous + result[1];
        pos = nextPartRe.lastIndex;
        if (knownHard[base] || cache && cache[base] === base) {
          return process.nextTick(LOOP);
        }
        if (cache && Object.prototype.hasOwnProperty.call(cache, base)) {
          return gotResolvedLink(cache[base]);
        }
        return fs2.lstat(base, gotStat);
      }
      function gotStat(err, stat) {
        if (err)
          return cb(err);
        if (!stat.isSymbolicLink()) {
          knownHard[base] = true;
          if (cache)
            cache[base] = base;
          return process.nextTick(LOOP);
        }
        if (!isWindows) {
          var id = stat.dev.toString(32) + ":" + stat.ino.toString(32);
          if (seenLinks.hasOwnProperty(id)) {
            return gotTarget(null, seenLinks[id], base);
          }
        }
        fs2.stat(base, function(err2) {
          if (err2)
            return cb(err2);
          fs2.readlink(base, function(err3, target) {
            if (!isWindows)
              seenLinks[id] = target;
            gotTarget(err3, target);
          });
        });
      }
      function gotTarget(err, target, base2) {
        if (err)
          return cb(err);
        var resolvedLink = pathModule.resolve(previous, target);
        if (cache)
          cache[base2] = resolvedLink;
        gotResolvedLink(resolvedLink);
      }
      function gotResolvedLink(resolvedLink) {
        p = pathModule.resolve(resolvedLink, p.slice(pos));
        start();
      }
    };
  }
});

// node_modules/fs.realpath/index.js
var require_fs = __commonJS({
  "node_modules/fs.realpath/index.js"(exports, module2) {
    module2.exports = realpath;
    realpath.realpath = realpath;
    realpath.sync = realpathSync;
    realpath.realpathSync = realpathSync;
    realpath.monkeypatch = monkeypatch;
    realpath.unmonkeypatch = unmonkeypatch;
    var fs2 = require("fs");
    var origRealpath = fs2.realpath;
    var origRealpathSync = fs2.realpathSync;
    var version2 = process.version;
    var ok = /^v[0-5]\./.test(version2);
    var old = require_old();
    function newError(er) {
      return er && er.syscall === "realpath" && (er.code === "ELOOP" || er.code === "ENOMEM" || er.code === "ENAMETOOLONG");
    }
    function realpath(p, cache, cb) {
      if (ok) {
        return origRealpath(p, cache, cb);
      }
      if (typeof cache === "function") {
        cb = cache;
        cache = null;
      }
      origRealpath(p, cache, function(er, result) {
        if (newError(er)) {
          old.realpath(p, cache, cb);
        } else {
          cb(er, result);
        }
      });
    }
    function realpathSync(p, cache) {
      if (ok) {
        return origRealpathSync(p, cache);
      }
      try {
        return origRealpathSync(p, cache);
      } catch (er) {
        if (newError(er)) {
          return old.realpathSync(p, cache);
        } else {
          throw er;
        }
      }
    }
    function monkeypatch() {
      fs2.realpath = realpath;
      fs2.realpathSync = realpathSync;
    }
    function unmonkeypatch() {
      fs2.realpath = origRealpath;
      fs2.realpathSync = origRealpathSync;
    }
  }
});

// node_modules/concat-map/index.js
var require_concat_map = __commonJS({
  "node_modules/concat-map/index.js"(exports, module2) {
    module2.exports = function(xs, fn) {
      var res = [];
      for (var i = 0; i < xs.length; i++) {
        var x = fn(xs[i], i);
        if (isArray2(x))
          res.push.apply(res, x);
        else
          res.push(x);
      }
      return res;
    };
    var isArray2 = Array.isArray || function(xs) {
      return Object.prototype.toString.call(xs) === "[object Array]";
    };
  }
});

// node_modules/balanced-match/index.js
var require_balanced_match = __commonJS({
  "node_modules/balanced-match/index.js"(exports, module2) {
    "use strict";
    module2.exports = balanced;
    function balanced(a, b, str) {
      if (a instanceof RegExp)
        a = maybeMatch(a, str);
      if (b instanceof RegExp)
        b = maybeMatch(b, str);
      var r = range(a, b, str);
      return r && {
        start: r[0],
        end: r[1],
        pre: str.slice(0, r[0]),
        body: str.slice(r[0] + a.length, r[1]),
        post: str.slice(r[1] + b.length)
      };
    }
    function maybeMatch(reg, str) {
      var m = str.match(reg);
      return m ? m[0] : null;
    }
    balanced.range = range;
    function range(a, b, str) {
      var begs, beg, left, right, result;
      var ai = str.indexOf(a);
      var bi = str.indexOf(b, ai + 1);
      var i = ai;
      if (ai >= 0 && bi > 0) {
        if (a === b) {
          return [ai, bi];
        }
        begs = [];
        left = str.length;
        while (i >= 0 && !result) {
          if (i == ai) {
            begs.push(i);
            ai = str.indexOf(a, i + 1);
          } else if (begs.length == 1) {
            result = [begs.pop(), bi];
          } else {
            beg = begs.pop();
            if (beg < left) {
              left = beg;
              right = bi;
            }
            bi = str.indexOf(b, i + 1);
          }
          i = ai < bi && ai >= 0 ? ai : bi;
        }
        if (begs.length) {
          result = [left, right];
        }
      }
      return result;
    }
  }
});

// node_modules/brace-expansion/index.js
var require_brace_expansion = __commonJS({
  "node_modules/brace-expansion/index.js"(exports, module2) {
    var concatMap = require_concat_map();
    var balanced = require_balanced_match();
    module2.exports = expandTop;
    var escSlash = "\0SLASH" + Math.random() + "\0";
    var escOpen = "\0OPEN" + Math.random() + "\0";
    var escClose = "\0CLOSE" + Math.random() + "\0";
    var escComma = "\0COMMA" + Math.random() + "\0";
    var escPeriod = "\0PERIOD" + Math.random() + "\0";
    function numeric(str) {
      return parseInt(str, 10) == str ? parseInt(str, 10) : str.charCodeAt(0);
    }
    function escapeBraces(str) {
      return str.split("\\\\").join(escSlash).split("\\{").join(escOpen).split("\\}").join(escClose).split("\\,").join(escComma).split("\\.").join(escPeriod);
    }
    function unescapeBraces(str) {
      return str.split(escSlash).join("\\").split(escOpen).join("{").split(escClose).join("}").split(escComma).join(",").split(escPeriod).join(".");
    }
    function parseCommaParts(str) {
      if (!str)
        return [""];
      var parts = [];
      var m = balanced("{", "}", str);
      if (!m)
        return str.split(",");
      var pre = m.pre;
      var body = m.body;
      var post = m.post;
      var p = pre.split(",");
      p[p.length - 1] += "{" + body + "}";
      var postParts = parseCommaParts(post);
      if (post.length) {
        p[p.length - 1] += postParts.shift();
        p.push.apply(p, postParts);
      }
      parts.push.apply(parts, p);
      return parts;
    }
    function expandTop(str) {
      if (!str)
        return [];
      if (str.substr(0, 2) === "{}") {
        str = "\\{\\}" + str.substr(2);
      }
      return expand(escapeBraces(str), true).map(unescapeBraces);
    }
    function embrace(str) {
      return "{" + str + "}";
    }
    function isPadded(el) {
      return /^-?0\d/.test(el);
    }
    function lte(i, y) {
      return i <= y;
    }
    function gte(i, y) {
      return i >= y;
    }
    function expand(str, isTop) {
      var expansions = [];
      var m = balanced("{", "}", str);
      if (!m || /\$$/.test(m.pre))
        return [str];
      var isNumericSequence = /^-?\d+\.\.-?\d+(?:\.\.-?\d+)?$/.test(m.body);
      var isAlphaSequence = /^[a-zA-Z]\.\.[a-zA-Z](?:\.\.-?\d+)?$/.test(m.body);
      var isSequence = isNumericSequence || isAlphaSequence;
      var isOptions = m.body.indexOf(",") >= 0;
      if (!isSequence && !isOptions) {
        if (m.post.match(/,.*\}/)) {
          str = m.pre + "{" + m.body + escClose + m.post;
          return expand(str);
        }
        return [str];
      }
      var n;
      if (isSequence) {
        n = m.body.split(/\.\./);
      } else {
        n = parseCommaParts(m.body);
        if (n.length === 1) {
          n = expand(n[0], false).map(embrace);
          if (n.length === 1) {
            var post = m.post.length ? expand(m.post, false) : [""];
            return post.map(function(p) {
              return m.pre + n[0] + p;
            });
          }
        }
      }
      var pre = m.pre;
      var post = m.post.length ? expand(m.post, false) : [""];
      var N;
      if (isSequence) {
        var x = numeric(n[0]);
        var y = numeric(n[1]);
        var width = Math.max(n[0].length, n[1].length);
        var incr = n.length == 3 ? Math.abs(numeric(n[2])) : 1;
        var test = lte;
        var reverse = y < x;
        if (reverse) {
          incr *= -1;
          test = gte;
        }
        var pad = n.some(isPadded);
        N = [];
        for (var i = x; test(i, y); i += incr) {
          var c;
          if (isAlphaSequence) {
            c = String.fromCharCode(i);
            if (c === "\\")
              c = "";
          } else {
            c = String(i);
            if (pad) {
              var need = width - c.length;
              if (need > 0) {
                var z = new Array(need + 1).join("0");
                if (i < 0)
                  c = "-" + z + c.slice(1);
                else
                  c = z + c;
              }
            }
          }
          N.push(c);
        }
      } else {
        N = concatMap(n, function(el) {
          return expand(el, false);
        });
      }
      for (var j = 0; j < N.length; j++) {
        for (var k = 0; k < post.length; k++) {
          var expansion = pre + N[j] + post[k];
          if (!isTop || isSequence || expansion)
            expansions.push(expansion);
        }
      }
      return expansions;
    }
  }
});

// node_modules/minimatch/minimatch.js
var require_minimatch = __commonJS({
  "node_modules/minimatch/minimatch.js"(exports, module2) {
    module2.exports = minimatch;
    minimatch.Minimatch = Minimatch;
    var path2 = function() {
      try {
        return require("path");
      } catch (e) {
      }
    }() || {
      sep: "/"
    };
    minimatch.sep = path2.sep;
    var GLOBSTAR = minimatch.GLOBSTAR = Minimatch.GLOBSTAR = {};
    var expand = require_brace_expansion();
    var plTypes = {
      "!": { open: "(?:(?!(?:", close: "))[^/]*?)" },
      "?": { open: "(?:", close: ")?" },
      "+": { open: "(?:", close: ")+" },
      "*": { open: "(?:", close: ")*" },
      "@": { open: "(?:", close: ")" }
    };
    var qmark = "[^/]";
    var star = qmark + "*?";
    var twoStarDot = "(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?";
    var twoStarNoDot = "(?:(?!(?:\\/|^)\\.).)*?";
    var reSpecials = charSet("().*{}+?[]^$\\!");
    function charSet(s) {
      return s.split("").reduce(function(set, c) {
        set[c] = true;
        return set;
      }, {});
    }
    var slashSplit = /\/+/;
    minimatch.filter = filter;
    function filter(pattern, options) {
      options = options || {};
      return function(p, i, list) {
        return minimatch(p, pattern, options);
      };
    }
    function ext(a, b) {
      b = b || {};
      var t3 = {};
      Object.keys(a).forEach(function(k) {
        t3[k] = a[k];
      });
      Object.keys(b).forEach(function(k) {
        t3[k] = b[k];
      });
      return t3;
    }
    minimatch.defaults = function(def) {
      if (!def || typeof def !== "object" || !Object.keys(def).length) {
        return minimatch;
      }
      var orig = minimatch;
      var m = function minimatch2(p, pattern, options) {
        return orig(p, pattern, ext(def, options));
      };
      m.Minimatch = function Minimatch2(pattern, options) {
        return new orig.Minimatch(pattern, ext(def, options));
      };
      m.Minimatch.defaults = function defaults(options) {
        return orig.defaults(ext(def, options)).Minimatch;
      };
      m.filter = function filter2(pattern, options) {
        return orig.filter(pattern, ext(def, options));
      };
      m.defaults = function defaults(options) {
        return orig.defaults(ext(def, options));
      };
      m.makeRe = function makeRe2(pattern, options) {
        return orig.makeRe(pattern, ext(def, options));
      };
      m.braceExpand = function braceExpand2(pattern, options) {
        return orig.braceExpand(pattern, ext(def, options));
      };
      m.match = function(list, pattern, options) {
        return orig.match(list, pattern, ext(def, options));
      };
      return m;
    };
    Minimatch.defaults = function(def) {
      return minimatch.defaults(def).Minimatch;
    };
    function minimatch(p, pattern, options) {
      assertValidPattern(pattern);
      if (!options)
        options = {};
      if (!options.nocomment && pattern.charAt(0) === "#") {
        return false;
      }
      return new Minimatch(pattern, options).match(p);
    }
    function Minimatch(pattern, options) {
      if (!(this instanceof Minimatch)) {
        return new Minimatch(pattern, options);
      }
      assertValidPattern(pattern);
      if (!options)
        options = {};
      pattern = pattern.trim();
      if (!options.allowWindowsEscape && path2.sep !== "/") {
        pattern = pattern.split(path2.sep).join("/");
      }
      this.options = options;
      this.set = [];
      this.pattern = pattern;
      this.regexp = null;
      this.negate = false;
      this.comment = false;
      this.empty = false;
      this.partial = !!options.partial;
      this.make();
    }
    Minimatch.prototype.debug = function() {
    };
    Minimatch.prototype.make = make;
    function make() {
      var pattern = this.pattern;
      var options = this.options;
      if (!options.nocomment && pattern.charAt(0) === "#") {
        this.comment = true;
        return;
      }
      if (!pattern) {
        this.empty = true;
        return;
      }
      this.parseNegate();
      var set = this.globSet = this.braceExpand();
      if (options.debug)
        this.debug = function debug() {
          console.error.apply(console, arguments);
        };
      this.debug(this.pattern, set);
      set = this.globParts = set.map(function(s) {
        return s.split(slashSplit);
      });
      this.debug(this.pattern, set);
      set = set.map(function(s, si, set2) {
        return s.map(this.parse, this);
      }, this);
      this.debug(this.pattern, set);
      set = set.filter(function(s) {
        return s.indexOf(false) === -1;
      });
      this.debug(this.pattern, set);
      this.set = set;
    }
    Minimatch.prototype.parseNegate = parseNegate;
    function parseNegate() {
      var pattern = this.pattern;
      var negate = false;
      var options = this.options;
      var negateOffset = 0;
      if (options.nonegate)
        return;
      for (var i = 0, l = pattern.length; i < l && pattern.charAt(i) === "!"; i++) {
        negate = !negate;
        negateOffset++;
      }
      if (negateOffset)
        this.pattern = pattern.substr(negateOffset);
      this.negate = negate;
    }
    minimatch.braceExpand = function(pattern, options) {
      return braceExpand(pattern, options);
    };
    Minimatch.prototype.braceExpand = braceExpand;
    function braceExpand(pattern, options) {
      if (!options) {
        if (this instanceof Minimatch) {
          options = this.options;
        } else {
          options = {};
        }
      }
      pattern = typeof pattern === "undefined" ? this.pattern : pattern;
      assertValidPattern(pattern);
      if (options.nobrace || !/\{(?:(?!\{).)*\}/.test(pattern)) {
        return [pattern];
      }
      return expand(pattern);
    }
    var MAX_PATTERN_LENGTH = 1024 * 64;
    var assertValidPattern = function(pattern) {
      if (typeof pattern !== "string") {
        throw new TypeError("invalid pattern");
      }
      if (pattern.length > MAX_PATTERN_LENGTH) {
        throw new TypeError("pattern is too long");
      }
    };
    Minimatch.prototype.parse = parse3;
    var SUBPARSE = {};
    function parse3(pattern, isSub) {
      assertValidPattern(pattern);
      var options = this.options;
      if (pattern === "**") {
        if (!options.noglobstar)
          return GLOBSTAR;
        else
          pattern = "*";
      }
      if (pattern === "")
        return "";
      var re = "";
      var hasMagic = !!options.nocase;
      var escaping = false;
      var patternListStack = [];
      var negativeLists = [];
      var stateChar;
      var inClass = false;
      var reClassStart = -1;
      var classStart = -1;
      var patternStart = pattern.charAt(0) === "." ? "" : options.dot ? "(?!(?:^|\\/)\\.{1,2}(?:$|\\/))" : "(?!\\.)";
      var self2 = this;
      function clearStateChar() {
        if (stateChar) {
          switch (stateChar) {
            case "*":
              re += star;
              hasMagic = true;
              break;
            case "?":
              re += qmark;
              hasMagic = true;
              break;
            default:
              re += "\\" + stateChar;
              break;
          }
          self2.debug("clearStateChar %j %j", stateChar, re);
          stateChar = false;
        }
      }
      for (var i = 0, len = pattern.length, c; i < len && (c = pattern.charAt(i)); i++) {
        this.debug("%s	%s %s %j", pattern, i, re, c);
        if (escaping && reSpecials[c]) {
          re += "\\" + c;
          escaping = false;
          continue;
        }
        switch (c) {
          case "/": {
            return false;
          }
          case "\\":
            clearStateChar();
            escaping = true;
            continue;
          case "?":
          case "*":
          case "+":
          case "@":
          case "!":
            this.debug("%s	%s %s %j <-- stateChar", pattern, i, re, c);
            if (inClass) {
              this.debug("  in class");
              if (c === "!" && i === classStart + 1)
                c = "^";
              re += c;
              continue;
            }
            self2.debug("call clearStateChar %j", stateChar);
            clearStateChar();
            stateChar = c;
            if (options.noext)
              clearStateChar();
            continue;
          case "(":
            if (inClass) {
              re += "(";
              continue;
            }
            if (!stateChar) {
              re += "\\(";
              continue;
            }
            patternListStack.push({
              type: stateChar,
              start: i - 1,
              reStart: re.length,
              open: plTypes[stateChar].open,
              close: plTypes[stateChar].close
            });
            re += stateChar === "!" ? "(?:(?!(?:" : "(?:";
            this.debug("plType %j %j", stateChar, re);
            stateChar = false;
            continue;
          case ")":
            if (inClass || !patternListStack.length) {
              re += "\\)";
              continue;
            }
            clearStateChar();
            hasMagic = true;
            var pl = patternListStack.pop();
            re += pl.close;
            if (pl.type === "!") {
              negativeLists.push(pl);
            }
            pl.reEnd = re.length;
            continue;
          case "|":
            if (inClass || !patternListStack.length || escaping) {
              re += "\\|";
              escaping = false;
              continue;
            }
            clearStateChar();
            re += "|";
            continue;
          case "[":
            clearStateChar();
            if (inClass) {
              re += "\\" + c;
              continue;
            }
            inClass = true;
            classStart = i;
            reClassStart = re.length;
            re += c;
            continue;
          case "]":
            if (i === classStart + 1 || !inClass) {
              re += "\\" + c;
              escaping = false;
              continue;
            }
            var cs = pattern.substring(classStart + 1, i);
            try {
              RegExp("[" + cs + "]");
            } catch (er) {
              var sp = this.parse(cs, SUBPARSE);
              re = re.substr(0, reClassStart) + "\\[" + sp[0] + "\\]";
              hasMagic = hasMagic || sp[1];
              inClass = false;
              continue;
            }
            hasMagic = true;
            inClass = false;
            re += c;
            continue;
          default:
            clearStateChar();
            if (escaping) {
              escaping = false;
            } else if (reSpecials[c] && !(c === "^" && inClass)) {
              re += "\\";
            }
            re += c;
        }
      }
      if (inClass) {
        cs = pattern.substr(classStart + 1);
        sp = this.parse(cs, SUBPARSE);
        re = re.substr(0, reClassStart) + "\\[" + sp[0];
        hasMagic = hasMagic || sp[1];
      }
      for (pl = patternListStack.pop(); pl; pl = patternListStack.pop()) {
        var tail = re.slice(pl.reStart + pl.open.length);
        this.debug("setting tail", re, pl);
        tail = tail.replace(/((?:\\{2}){0,64})(\\?)\|/g, function(_, $1, $2) {
          if (!$2) {
            $2 = "\\";
          }
          return $1 + $1 + $2 + "|";
        });
        this.debug("tail=%j\n   %s", tail, tail, pl, re);
        var t3 = pl.type === "*" ? star : pl.type === "?" ? qmark : "\\" + pl.type;
        hasMagic = true;
        re = re.slice(0, pl.reStart) + t3 + "\\(" + tail;
      }
      clearStateChar();
      if (escaping) {
        re += "\\\\";
      }
      var addPatternStart = false;
      switch (re.charAt(0)) {
        case "[":
        case ".":
        case "(":
          addPatternStart = true;
      }
      for (var n = negativeLists.length - 1; n > -1; n--) {
        var nl = negativeLists[n];
        var nlBefore = re.slice(0, nl.reStart);
        var nlFirst = re.slice(nl.reStart, nl.reEnd - 8);
        var nlLast = re.slice(nl.reEnd - 8, nl.reEnd);
        var nlAfter = re.slice(nl.reEnd);
        nlLast += nlAfter;
        var openParensBefore = nlBefore.split("(").length - 1;
        var cleanAfter = nlAfter;
        for (i = 0; i < openParensBefore; i++) {
          cleanAfter = cleanAfter.replace(/\)[+*?]?/, "");
        }
        nlAfter = cleanAfter;
        var dollar = "";
        if (nlAfter === "" && isSub !== SUBPARSE) {
          dollar = "$";
        }
        var newRe = nlBefore + nlFirst + nlAfter + dollar + nlLast;
        re = newRe;
      }
      if (re !== "" && hasMagic) {
        re = "(?=.)" + re;
      }
      if (addPatternStart) {
        re = patternStart + re;
      }
      if (isSub === SUBPARSE) {
        return [re, hasMagic];
      }
      if (!hasMagic) {
        return globUnescape(pattern);
      }
      var flags = options.nocase ? "i" : "";
      try {
        var regExp = new RegExp("^" + re + "$", flags);
      } catch (er) {
        return new RegExp("$.");
      }
      regExp._glob = pattern;
      regExp._src = re;
      return regExp;
    }
    minimatch.makeRe = function(pattern, options) {
      return new Minimatch(pattern, options || {}).makeRe();
    };
    Minimatch.prototype.makeRe = makeRe;
    function makeRe() {
      if (this.regexp || this.regexp === false)
        return this.regexp;
      var set = this.set;
      if (!set.length) {
        this.regexp = false;
        return this.regexp;
      }
      var options = this.options;
      var twoStar = options.noglobstar ? star : options.dot ? twoStarDot : twoStarNoDot;
      var flags = options.nocase ? "i" : "";
      var re = set.map(function(pattern) {
        return pattern.map(function(p) {
          return p === GLOBSTAR ? twoStar : typeof p === "string" ? regExpEscape(p) : p._src;
        }).join("\\/");
      }).join("|");
      re = "^(?:" + re + ")$";
      if (this.negate)
        re = "^(?!" + re + ").*$";
      try {
        this.regexp = new RegExp(re, flags);
      } catch (ex) {
        this.regexp = false;
      }
      return this.regexp;
    }
    minimatch.match = function(list, pattern, options) {
      options = options || {};
      var mm = new Minimatch(pattern, options);
      list = list.filter(function(f) {
        return mm.match(f);
      });
      if (mm.options.nonull && !list.length) {
        list.push(pattern);
      }
      return list;
    };
    Minimatch.prototype.match = function match(f, partial) {
      if (typeof partial === "undefined")
        partial = this.partial;
      this.debug("match", f, this.pattern);
      if (this.comment)
        return false;
      if (this.empty)
        return f === "";
      if (f === "/" && partial)
        return true;
      var options = this.options;
      if (path2.sep !== "/") {
        f = f.split(path2.sep).join("/");
      }
      f = f.split(slashSplit);
      this.debug(this.pattern, "split", f);
      var set = this.set;
      this.debug(this.pattern, "set", set);
      var filename;
      var i;
      for (i = f.length - 1; i >= 0; i--) {
        filename = f[i];
        if (filename)
          break;
      }
      for (i = 0; i < set.length; i++) {
        var pattern = set[i];
        var file = f;
        if (options.matchBase && pattern.length === 1) {
          file = [filename];
        }
        var hit = this.matchOne(file, pattern, partial);
        if (hit) {
          if (options.flipNegate)
            return true;
          return !this.negate;
        }
      }
      if (options.flipNegate)
        return false;
      return this.negate;
    };
    Minimatch.prototype.matchOne = function(file, pattern, partial) {
      var options = this.options;
      this.debug(
        "matchOne",
        { "this": this, file, pattern }
      );
      this.debug("matchOne", file.length, pattern.length);
      for (var fi = 0, pi = 0, fl = file.length, pl = pattern.length; fi < fl && pi < pl; fi++, pi++) {
        this.debug("matchOne loop");
        var p = pattern[pi];
        var f = file[fi];
        this.debug(pattern, p, f);
        if (p === false)
          return false;
        if (p === GLOBSTAR) {
          this.debug("GLOBSTAR", [pattern, p, f]);
          var fr = fi;
          var pr = pi + 1;
          if (pr === pl) {
            this.debug("** at the end");
            for (; fi < fl; fi++) {
              if (file[fi] === "." || file[fi] === ".." || !options.dot && file[fi].charAt(0) === ".")
                return false;
            }
            return true;
          }
          while (fr < fl) {
            var swallowee = file[fr];
            this.debug("\nglobstar while", file, fr, pattern, pr, swallowee);
            if (this.matchOne(file.slice(fr), pattern.slice(pr), partial)) {
              this.debug("globstar found match!", fr, fl, swallowee);
              return true;
            } else {
              if (swallowee === "." || swallowee === ".." || !options.dot && swallowee.charAt(0) === ".") {
                this.debug("dot detected!", file, fr, pattern, pr);
                break;
              }
              this.debug("globstar swallow a segment, and continue");
              fr++;
            }
          }
          if (partial) {
            this.debug("\n>>> no match, partial?", file, fr, pattern, pr);
            if (fr === fl)
              return true;
          }
          return false;
        }
        var hit;
        if (typeof p === "string") {
          hit = f === p;
          this.debug("string match", p, f, hit);
        } else {
          hit = f.match(p);
          this.debug("pattern match", p, f, hit);
        }
        if (!hit)
          return false;
      }
      if (fi === fl && pi === pl) {
        return true;
      } else if (fi === fl) {
        return partial;
      } else if (pi === pl) {
        return fi === fl - 1 && file[fi] === "";
      }
      throw new Error("wtf?");
    };
    function globUnescape(s) {
      return s.replace(/\\(.)/g, "$1");
    }
    function regExpEscape(s) {
      return s.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }
  }
});

// node_modules/inherits/inherits_browser.js
var require_inherits_browser = __commonJS({
  "node_modules/inherits/inherits_browser.js"(exports, module2) {
    if (typeof Object.create === "function") {
      module2.exports = function inherits(ctor, superCtor) {
        if (superCtor) {
          ctor.super_ = superCtor;
          ctor.prototype = Object.create(superCtor.prototype, {
            constructor: {
              value: ctor,
              enumerable: false,
              writable: true,
              configurable: true
            }
          });
        }
      };
    } else {
      module2.exports = function inherits(ctor, superCtor) {
        if (superCtor) {
          ctor.super_ = superCtor;
          var TempCtor = function() {
          };
          TempCtor.prototype = superCtor.prototype;
          ctor.prototype = new TempCtor();
          ctor.prototype.constructor = ctor;
        }
      };
    }
  }
});

// node_modules/inherits/inherits.js
var require_inherits = __commonJS({
  "node_modules/inherits/inherits.js"(exports, module2) {
    try {
      util = require("util");
      if (typeof util.inherits !== "function")
        throw "";
      module2.exports = util.inherits;
    } catch (e) {
      module2.exports = require_inherits_browser();
    }
    var util;
  }
});

// node_modules/path-is-absolute/index.js
var require_path_is_absolute = __commonJS({
  "node_modules/path-is-absolute/index.js"(exports, module2) {
    "use strict";
    function posix(path2) {
      return path2.charAt(0) === "/";
    }
    function win32(path2) {
      var splitDeviceRe = /^([a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?([\\\/])?([\s\S]*?)$/;
      var result = splitDeviceRe.exec(path2);
      var device = result[1] || "";
      var isUnc = Boolean(device && device.charAt(1) !== ":");
      return Boolean(result[2] || isUnc);
    }
    module2.exports = process.platform === "win32" ? win32 : posix;
    module2.exports.posix = posix;
    module2.exports.win32 = win32;
  }
});

// node_modules/glob/common.js
var require_common = __commonJS({
  "node_modules/glob/common.js"(exports) {
    exports.setopts = setopts;
    exports.ownProp = ownProp;
    exports.makeAbs = makeAbs;
    exports.finish = finish;
    exports.mark = mark;
    exports.isIgnored = isIgnored;
    exports.childrenIgnored = childrenIgnored;
    function ownProp(obj, field) {
      return Object.prototype.hasOwnProperty.call(obj, field);
    }
    var fs2 = require("fs");
    var path2 = require("path");
    var minimatch = require_minimatch();
    var isAbsolute = require_path_is_absolute();
    var Minimatch = minimatch.Minimatch;
    function alphasort(a, b) {
      return a.localeCompare(b, "en");
    }
    function setupIgnores(self2, options) {
      self2.ignore = options.ignore || [];
      if (!Array.isArray(self2.ignore))
        self2.ignore = [self2.ignore];
      if (self2.ignore.length) {
        self2.ignore = self2.ignore.map(ignoreMap);
      }
    }
    function ignoreMap(pattern) {
      var gmatcher = null;
      if (pattern.slice(-3) === "/**") {
        var gpattern = pattern.replace(/(\/\*\*)+$/, "");
        gmatcher = new Minimatch(gpattern, { dot: true });
      }
      return {
        matcher: new Minimatch(pattern, { dot: true }),
        gmatcher
      };
    }
    function setopts(self2, pattern, options) {
      if (!options)
        options = {};
      if (options.matchBase && -1 === pattern.indexOf("/")) {
        if (options.noglobstar) {
          throw new Error("base matching requires globstar");
        }
        pattern = "**/" + pattern;
      }
      self2.silent = !!options.silent;
      self2.pattern = pattern;
      self2.strict = options.strict !== false;
      self2.realpath = !!options.realpath;
      self2.realpathCache = options.realpathCache || /* @__PURE__ */ Object.create(null);
      self2.follow = !!options.follow;
      self2.dot = !!options.dot;
      self2.mark = !!options.mark;
      self2.nodir = !!options.nodir;
      if (self2.nodir)
        self2.mark = true;
      self2.sync = !!options.sync;
      self2.nounique = !!options.nounique;
      self2.nonull = !!options.nonull;
      self2.nosort = !!options.nosort;
      self2.nocase = !!options.nocase;
      self2.stat = !!options.stat;
      self2.noprocess = !!options.noprocess;
      self2.absolute = !!options.absolute;
      self2.fs = options.fs || fs2;
      self2.maxLength = options.maxLength || Infinity;
      self2.cache = options.cache || /* @__PURE__ */ Object.create(null);
      self2.statCache = options.statCache || /* @__PURE__ */ Object.create(null);
      self2.symlinks = options.symlinks || /* @__PURE__ */ Object.create(null);
      setupIgnores(self2, options);
      self2.changedCwd = false;
      var cwd = process.cwd();
      if (!ownProp(options, "cwd"))
        self2.cwd = cwd;
      else {
        self2.cwd = path2.resolve(options.cwd);
        self2.changedCwd = self2.cwd !== cwd;
      }
      self2.root = options.root || path2.resolve(self2.cwd, "/");
      self2.root = path2.resolve(self2.root);
      if (process.platform === "win32")
        self2.root = self2.root.replace(/\\/g, "/");
      self2.cwdAbs = isAbsolute(self2.cwd) ? self2.cwd : makeAbs(self2, self2.cwd);
      if (process.platform === "win32")
        self2.cwdAbs = self2.cwdAbs.replace(/\\/g, "/");
      self2.nomount = !!options.nomount;
      options.nonegate = true;
      options.nocomment = true;
      options.allowWindowsEscape = false;
      self2.minimatch = new Minimatch(pattern, options);
      self2.options = self2.minimatch.options;
    }
    function finish(self2) {
      var nou = self2.nounique;
      var all = nou ? [] : /* @__PURE__ */ Object.create(null);
      for (var i = 0, l = self2.matches.length; i < l; i++) {
        var matches = self2.matches[i];
        if (!matches || Object.keys(matches).length === 0) {
          if (self2.nonull) {
            var literal = self2.minimatch.globSet[i];
            if (nou)
              all.push(literal);
            else
              all[literal] = true;
          }
        } else {
          var m = Object.keys(matches);
          if (nou)
            all.push.apply(all, m);
          else
            m.forEach(function(m2) {
              all[m2] = true;
            });
        }
      }
      if (!nou)
        all = Object.keys(all);
      if (!self2.nosort)
        all = all.sort(alphasort);
      if (self2.mark) {
        for (var i = 0; i < all.length; i++) {
          all[i] = self2._mark(all[i]);
        }
        if (self2.nodir) {
          all = all.filter(function(e) {
            var notDir = !/\/$/.test(e);
            var c = self2.cache[e] || self2.cache[makeAbs(self2, e)];
            if (notDir && c)
              notDir = c !== "DIR" && !Array.isArray(c);
            return notDir;
          });
        }
      }
      if (self2.ignore.length)
        all = all.filter(function(m2) {
          return !isIgnored(self2, m2);
        });
      self2.found = all;
    }
    function mark(self2, p) {
      var abs = makeAbs(self2, p);
      var c = self2.cache[abs];
      var m = p;
      if (c) {
        var isDir = c === "DIR" || Array.isArray(c);
        var slash = p.slice(-1) === "/";
        if (isDir && !slash)
          m += "/";
        else if (!isDir && slash)
          m = m.slice(0, -1);
        if (m !== p) {
          var mabs = makeAbs(self2, m);
          self2.statCache[mabs] = self2.statCache[abs];
          self2.cache[mabs] = self2.cache[abs];
        }
      }
      return m;
    }
    function makeAbs(self2, f) {
      var abs = f;
      if (f.charAt(0) === "/") {
        abs = path2.join(self2.root, f);
      } else if (isAbsolute(f) || f === "") {
        abs = f;
      } else if (self2.changedCwd) {
        abs = path2.resolve(self2.cwd, f);
      } else {
        abs = path2.resolve(f);
      }
      if (process.platform === "win32")
        abs = abs.replace(/\\/g, "/");
      return abs;
    }
    function isIgnored(self2, path3) {
      if (!self2.ignore.length)
        return false;
      return self2.ignore.some(function(item) {
        return item.matcher.match(path3) || !!(item.gmatcher && item.gmatcher.match(path3));
      });
    }
    function childrenIgnored(self2, path3) {
      if (!self2.ignore.length)
        return false;
      return self2.ignore.some(function(item) {
        return !!(item.gmatcher && item.gmatcher.match(path3));
      });
    }
  }
});

// node_modules/glob/sync.js
var require_sync = __commonJS({
  "node_modules/glob/sync.js"(exports, module2) {
    module2.exports = globSync;
    globSync.GlobSync = GlobSync;
    var rp = require_fs();
    var minimatch = require_minimatch();
    var Minimatch = minimatch.Minimatch;
    var Glob = require_glob().Glob;
    var util = require("util");
    var path2 = require("path");
    var assert = require("assert");
    var isAbsolute = require_path_is_absolute();
    var common = require_common();
    var setopts = common.setopts;
    var ownProp = common.ownProp;
    var childrenIgnored = common.childrenIgnored;
    var isIgnored = common.isIgnored;
    function globSync(pattern, options) {
      if (typeof options === "function" || arguments.length === 3)
        throw new TypeError("callback provided to sync glob\nSee: https://github.com/isaacs/node-glob/issues/167");
      return new GlobSync(pattern, options).found;
    }
    function GlobSync(pattern, options) {
      if (!pattern)
        throw new Error("must provide pattern");
      if (typeof options === "function" || arguments.length === 3)
        throw new TypeError("callback provided to sync glob\nSee: https://github.com/isaacs/node-glob/issues/167");
      if (!(this instanceof GlobSync))
        return new GlobSync(pattern, options);
      setopts(this, pattern, options);
      if (this.noprocess)
        return this;
      var n = this.minimatch.set.length;
      this.matches = new Array(n);
      for (var i = 0; i < n; i++) {
        this._process(this.minimatch.set[i], i, false);
      }
      this._finish();
    }
    GlobSync.prototype._finish = function() {
      assert.ok(this instanceof GlobSync);
      if (this.realpath) {
        var self2 = this;
        this.matches.forEach(function(matchset, index) {
          var set = self2.matches[index] = /* @__PURE__ */ Object.create(null);
          for (var p in matchset) {
            try {
              p = self2._makeAbs(p);
              var real = rp.realpathSync(p, self2.realpathCache);
              set[real] = true;
            } catch (er) {
              if (er.syscall === "stat")
                set[self2._makeAbs(p)] = true;
              else
                throw er;
            }
          }
        });
      }
      common.finish(this);
    };
    GlobSync.prototype._process = function(pattern, index, inGlobStar) {
      assert.ok(this instanceof GlobSync);
      var n = 0;
      while (typeof pattern[n] === "string") {
        n++;
      }
      var prefix;
      switch (n) {
        case pattern.length:
          this._processSimple(pattern.join("/"), index);
          return;
        case 0:
          prefix = null;
          break;
        default:
          prefix = pattern.slice(0, n).join("/");
          break;
      }
      var remain = pattern.slice(n);
      var read;
      if (prefix === null)
        read = ".";
      else if (isAbsolute(prefix) || isAbsolute(pattern.map(function(p) {
        return typeof p === "string" ? p : "[*]";
      }).join("/"))) {
        if (!prefix || !isAbsolute(prefix))
          prefix = "/" + prefix;
        read = prefix;
      } else
        read = prefix;
      var abs = this._makeAbs(read);
      if (childrenIgnored(this, read))
        return;
      var isGlobStar = remain[0] === minimatch.GLOBSTAR;
      if (isGlobStar)
        this._processGlobStar(prefix, read, abs, remain, index, inGlobStar);
      else
        this._processReaddir(prefix, read, abs, remain, index, inGlobStar);
    };
    GlobSync.prototype._processReaddir = function(prefix, read, abs, remain, index, inGlobStar) {
      var entries = this._readdir(abs, inGlobStar);
      if (!entries)
        return;
      var pn = remain[0];
      var negate = !!this.minimatch.negate;
      var rawGlob = pn._glob;
      var dotOk = this.dot || rawGlob.charAt(0) === ".";
      var matchedEntries = [];
      for (var i = 0; i < entries.length; i++) {
        var e = entries[i];
        if (e.charAt(0) !== "." || dotOk) {
          var m;
          if (negate && !prefix) {
            m = !e.match(pn);
          } else {
            m = e.match(pn);
          }
          if (m)
            matchedEntries.push(e);
        }
      }
      var len = matchedEntries.length;
      if (len === 0)
        return;
      if (remain.length === 1 && !this.mark && !this.stat) {
        if (!this.matches[index])
          this.matches[index] = /* @__PURE__ */ Object.create(null);
        for (var i = 0; i < len; i++) {
          var e = matchedEntries[i];
          if (prefix) {
            if (prefix.slice(-1) !== "/")
              e = prefix + "/" + e;
            else
              e = prefix + e;
          }
          if (e.charAt(0) === "/" && !this.nomount) {
            e = path2.join(this.root, e);
          }
          this._emitMatch(index, e);
        }
        return;
      }
      remain.shift();
      for (var i = 0; i < len; i++) {
        var e = matchedEntries[i];
        var newPattern;
        if (prefix)
          newPattern = [prefix, e];
        else
          newPattern = [e];
        this._process(newPattern.concat(remain), index, inGlobStar);
      }
    };
    GlobSync.prototype._emitMatch = function(index, e) {
      if (isIgnored(this, e))
        return;
      var abs = this._makeAbs(e);
      if (this.mark)
        e = this._mark(e);
      if (this.absolute) {
        e = abs;
      }
      if (this.matches[index][e])
        return;
      if (this.nodir) {
        var c = this.cache[abs];
        if (c === "DIR" || Array.isArray(c))
          return;
      }
      this.matches[index][e] = true;
      if (this.stat)
        this._stat(e);
    };
    GlobSync.prototype._readdirInGlobStar = function(abs) {
      if (this.follow)
        return this._readdir(abs, false);
      var entries;
      var lstat;
      var stat;
      try {
        lstat = this.fs.lstatSync(abs);
      } catch (er) {
        if (er.code === "ENOENT") {
          return null;
        }
      }
      var isSym = lstat && lstat.isSymbolicLink();
      this.symlinks[abs] = isSym;
      if (!isSym && lstat && !lstat.isDirectory())
        this.cache[abs] = "FILE";
      else
        entries = this._readdir(abs, false);
      return entries;
    };
    GlobSync.prototype._readdir = function(abs, inGlobStar) {
      var entries;
      if (inGlobStar && !ownProp(this.symlinks, abs))
        return this._readdirInGlobStar(abs);
      if (ownProp(this.cache, abs)) {
        var c = this.cache[abs];
        if (!c || c === "FILE")
          return null;
        if (Array.isArray(c))
          return c;
      }
      try {
        return this._readdirEntries(abs, this.fs.readdirSync(abs));
      } catch (er) {
        this._readdirError(abs, er);
        return null;
      }
    };
    GlobSync.prototype._readdirEntries = function(abs, entries) {
      if (!this.mark && !this.stat) {
        for (var i = 0; i < entries.length; i++) {
          var e = entries[i];
          if (abs === "/")
            e = abs + e;
          else
            e = abs + "/" + e;
          this.cache[e] = true;
        }
      }
      this.cache[abs] = entries;
      return entries;
    };
    GlobSync.prototype._readdirError = function(f, er) {
      switch (er.code) {
        case "ENOTSUP":
        case "ENOTDIR":
          var abs = this._makeAbs(f);
          this.cache[abs] = "FILE";
          if (abs === this.cwdAbs) {
            var error = new Error(er.code + " invalid cwd " + this.cwd);
            error.path = this.cwd;
            error.code = er.code;
            throw error;
          }
          break;
        case "ENOENT":
        case "ELOOP":
        case "ENAMETOOLONG":
        case "UNKNOWN":
          this.cache[this._makeAbs(f)] = false;
          break;
        default:
          this.cache[this._makeAbs(f)] = false;
          if (this.strict)
            throw er;
          if (!this.silent)
            console.error("glob error", er);
          break;
      }
    };
    GlobSync.prototype._processGlobStar = function(prefix, read, abs, remain, index, inGlobStar) {
      var entries = this._readdir(abs, inGlobStar);
      if (!entries)
        return;
      var remainWithoutGlobStar = remain.slice(1);
      var gspref = prefix ? [prefix] : [];
      var noGlobStar = gspref.concat(remainWithoutGlobStar);
      this._process(noGlobStar, index, false);
      var len = entries.length;
      var isSym = this.symlinks[abs];
      if (isSym && inGlobStar)
        return;
      for (var i = 0; i < len; i++) {
        var e = entries[i];
        if (e.charAt(0) === "." && !this.dot)
          continue;
        var instead = gspref.concat(entries[i], remainWithoutGlobStar);
        this._process(instead, index, true);
        var below = gspref.concat(entries[i], remain);
        this._process(below, index, true);
      }
    };
    GlobSync.prototype._processSimple = function(prefix, index) {
      var exists = this._stat(prefix);
      if (!this.matches[index])
        this.matches[index] = /* @__PURE__ */ Object.create(null);
      if (!exists)
        return;
      if (prefix && isAbsolute(prefix) && !this.nomount) {
        var trail = /[\/\\]$/.test(prefix);
        if (prefix.charAt(0) === "/") {
          prefix = path2.join(this.root, prefix);
        } else {
          prefix = path2.resolve(this.root, prefix);
          if (trail)
            prefix += "/";
        }
      }
      if (process.platform === "win32")
        prefix = prefix.replace(/\\/g, "/");
      this._emitMatch(index, prefix);
    };
    GlobSync.prototype._stat = function(f) {
      var abs = this._makeAbs(f);
      var needDir = f.slice(-1) === "/";
      if (f.length > this.maxLength)
        return false;
      if (!this.stat && ownProp(this.cache, abs)) {
        var c = this.cache[abs];
        if (Array.isArray(c))
          c = "DIR";
        if (!needDir || c === "DIR")
          return c;
        if (needDir && c === "FILE")
          return false;
      }
      var exists;
      var stat = this.statCache[abs];
      if (!stat) {
        var lstat;
        try {
          lstat = this.fs.lstatSync(abs);
        } catch (er) {
          if (er && (er.code === "ENOENT" || er.code === "ENOTDIR")) {
            this.statCache[abs] = false;
            return false;
          }
        }
        if (lstat && lstat.isSymbolicLink()) {
          try {
            stat = this.fs.statSync(abs);
          } catch (er) {
            stat = lstat;
          }
        } else {
          stat = lstat;
        }
      }
      this.statCache[abs] = stat;
      var c = true;
      if (stat)
        c = stat.isDirectory() ? "DIR" : "FILE";
      this.cache[abs] = this.cache[abs] || c;
      if (needDir && c === "FILE")
        return false;
      return c;
    };
    GlobSync.prototype._mark = function(p) {
      return common.mark(this, p);
    };
    GlobSync.prototype._makeAbs = function(f) {
      return common.makeAbs(this, f);
    };
  }
});

// node_modules/wrappy/wrappy.js
var require_wrappy = __commonJS({
  "node_modules/wrappy/wrappy.js"(exports, module2) {
    module2.exports = wrappy;
    function wrappy(fn, cb) {
      if (fn && cb)
        return wrappy(fn)(cb);
      if (typeof fn !== "function")
        throw new TypeError("need wrapper function");
      Object.keys(fn).forEach(function(k) {
        wrapper[k] = fn[k];
      });
      return wrapper;
      function wrapper() {
        var args = new Array(arguments.length);
        for (var i = 0; i < args.length; i++) {
          args[i] = arguments[i];
        }
        var ret = fn.apply(this, args);
        var cb2 = args[args.length - 1];
        if (typeof ret === "function" && ret !== cb2) {
          Object.keys(cb2).forEach(function(k) {
            ret[k] = cb2[k];
          });
        }
        return ret;
      }
    }
  }
});

// node_modules/once/once.js
var require_once = __commonJS({
  "node_modules/once/once.js"(exports, module2) {
    var wrappy = require_wrappy();
    module2.exports = wrappy(once);
    module2.exports.strict = wrappy(onceStrict);
    once.proto = once(function() {
      Object.defineProperty(Function.prototype, "once", {
        value: function() {
          return once(this);
        },
        configurable: true
      });
      Object.defineProperty(Function.prototype, "onceStrict", {
        value: function() {
          return onceStrict(this);
        },
        configurable: true
      });
    });
    function once(fn) {
      var f = function() {
        if (f.called)
          return f.value;
        f.called = true;
        return f.value = fn.apply(this, arguments);
      };
      f.called = false;
      return f;
    }
    function onceStrict(fn) {
      var f = function() {
        if (f.called)
          throw new Error(f.onceError);
        f.called = true;
        return f.value = fn.apply(this, arguments);
      };
      var name = fn.name || "Function wrapped with `once`";
      f.onceError = name + " shouldn't be called more than once";
      f.called = false;
      return f;
    }
  }
});

// node_modules/inflight/inflight.js
var require_inflight = __commonJS({
  "node_modules/inflight/inflight.js"(exports, module2) {
    var wrappy = require_wrappy();
    var reqs = /* @__PURE__ */ Object.create(null);
    var once = require_once();
    module2.exports = wrappy(inflight);
    function inflight(key, cb) {
      if (reqs[key]) {
        reqs[key].push(cb);
        return null;
      } else {
        reqs[key] = [cb];
        return makeres(key);
      }
    }
    function makeres(key) {
      return once(function RES() {
        var cbs = reqs[key];
        var len = cbs.length;
        var args = slice(arguments);
        try {
          for (var i = 0; i < len; i++) {
            cbs[i].apply(null, args);
          }
        } finally {
          if (cbs.length > len) {
            cbs.splice(0, len);
            process.nextTick(function() {
              RES.apply(null, args);
            });
          } else {
            delete reqs[key];
          }
        }
      });
    }
    function slice(args) {
      var length = args.length;
      var array = [];
      for (var i = 0; i < length; i++)
        array[i] = args[i];
      return array;
    }
  }
});

// node_modules/glob/glob.js
var require_glob = __commonJS({
  "node_modules/glob/glob.js"(exports, module2) {
    module2.exports = glob2;
    var rp = require_fs();
    var minimatch = require_minimatch();
    var Minimatch = minimatch.Minimatch;
    var inherits = require_inherits();
    var EE = require("events").EventEmitter;
    var path2 = require("path");
    var assert = require("assert");
    var isAbsolute = require_path_is_absolute();
    var globSync = require_sync();
    var common = require_common();
    var setopts = common.setopts;
    var ownProp = common.ownProp;
    var inflight = require_inflight();
    var util = require("util");
    var childrenIgnored = common.childrenIgnored;
    var isIgnored = common.isIgnored;
    var once = require_once();
    function glob2(pattern, options, cb) {
      if (typeof options === "function")
        cb = options, options = {};
      if (!options)
        options = {};
      if (options.sync) {
        if (cb)
          throw new TypeError("callback provided to sync glob");
        return globSync(pattern, options);
      }
      return new Glob(pattern, options, cb);
    }
    glob2.sync = globSync;
    var GlobSync = glob2.GlobSync = globSync.GlobSync;
    glob2.glob = glob2;
    function extend(origin, add) {
      if (add === null || typeof add !== "object") {
        return origin;
      }
      var keys3 = Object.keys(add);
      var i = keys3.length;
      while (i--) {
        origin[keys3[i]] = add[keys3[i]];
      }
      return origin;
    }
    glob2.hasMagic = function(pattern, options_) {
      var options = extend({}, options_);
      options.noprocess = true;
      var g = new Glob(pattern, options);
      var set = g.minimatch.set;
      if (!pattern)
        return false;
      if (set.length > 1)
        return true;
      for (var j = 0; j < set[0].length; j++) {
        if (typeof set[0][j] !== "string")
          return true;
      }
      return false;
    };
    glob2.Glob = Glob;
    inherits(Glob, EE);
    function Glob(pattern, options, cb) {
      if (typeof options === "function") {
        cb = options;
        options = null;
      }
      if (options && options.sync) {
        if (cb)
          throw new TypeError("callback provided to sync glob");
        return new GlobSync(pattern, options);
      }
      if (!(this instanceof Glob))
        return new Glob(pattern, options, cb);
      setopts(this, pattern, options);
      this._didRealPath = false;
      var n = this.minimatch.set.length;
      this.matches = new Array(n);
      if (typeof cb === "function") {
        cb = once(cb);
        this.on("error", cb);
        this.on("end", function(matches) {
          cb(null, matches);
        });
      }
      var self2 = this;
      this._processing = 0;
      this._emitQueue = [];
      this._processQueue = [];
      this.paused = false;
      if (this.noprocess)
        return this;
      if (n === 0)
        return done();
      var sync = true;
      for (var i = 0; i < n; i++) {
        this._process(this.minimatch.set[i], i, false, done);
      }
      sync = false;
      function done() {
        --self2._processing;
        if (self2._processing <= 0) {
          if (sync) {
            process.nextTick(function() {
              self2._finish();
            });
          } else {
            self2._finish();
          }
        }
      }
    }
    Glob.prototype._finish = function() {
      assert(this instanceof Glob);
      if (this.aborted)
        return;
      if (this.realpath && !this._didRealpath)
        return this._realpath();
      common.finish(this);
      this.emit("end", this.found);
    };
    Glob.prototype._realpath = function() {
      if (this._didRealpath)
        return;
      this._didRealpath = true;
      var n = this.matches.length;
      if (n === 0)
        return this._finish();
      var self2 = this;
      for (var i = 0; i < this.matches.length; i++)
        this._realpathSet(i, next);
      function next() {
        if (--n === 0)
          self2._finish();
      }
    };
    Glob.prototype._realpathSet = function(index, cb) {
      var matchset = this.matches[index];
      if (!matchset)
        return cb();
      var found = Object.keys(matchset);
      var self2 = this;
      var n = found.length;
      if (n === 0)
        return cb();
      var set = this.matches[index] = /* @__PURE__ */ Object.create(null);
      found.forEach(function(p, i) {
        p = self2._makeAbs(p);
        rp.realpath(p, self2.realpathCache, function(er, real) {
          if (!er)
            set[real] = true;
          else if (er.syscall === "stat")
            set[p] = true;
          else
            self2.emit("error", er);
          if (--n === 0) {
            self2.matches[index] = set;
            cb();
          }
        });
      });
    };
    Glob.prototype._mark = function(p) {
      return common.mark(this, p);
    };
    Glob.prototype._makeAbs = function(f) {
      return common.makeAbs(this, f);
    };
    Glob.prototype.abort = function() {
      this.aborted = true;
      this.emit("abort");
    };
    Glob.prototype.pause = function() {
      if (!this.paused) {
        this.paused = true;
        this.emit("pause");
      }
    };
    Glob.prototype.resume = function() {
      if (this.paused) {
        this.emit("resume");
        this.paused = false;
        if (this._emitQueue.length) {
          var eq = this._emitQueue.slice(0);
          this._emitQueue.length = 0;
          for (var i = 0; i < eq.length; i++) {
            var e = eq[i];
            this._emitMatch(e[0], e[1]);
          }
        }
        if (this._processQueue.length) {
          var pq = this._processQueue.slice(0);
          this._processQueue.length = 0;
          for (var i = 0; i < pq.length; i++) {
            var p = pq[i];
            this._processing--;
            this._process(p[0], p[1], p[2], p[3]);
          }
        }
      }
    };
    Glob.prototype._process = function(pattern, index, inGlobStar, cb) {
      assert(this instanceof Glob);
      assert(typeof cb === "function");
      if (this.aborted)
        return;
      this._processing++;
      if (this.paused) {
        this._processQueue.push([pattern, index, inGlobStar, cb]);
        return;
      }
      var n = 0;
      while (typeof pattern[n] === "string") {
        n++;
      }
      var prefix;
      switch (n) {
        case pattern.length:
          this._processSimple(pattern.join("/"), index, cb);
          return;
        case 0:
          prefix = null;
          break;
        default:
          prefix = pattern.slice(0, n).join("/");
          break;
      }
      var remain = pattern.slice(n);
      var read;
      if (prefix === null)
        read = ".";
      else if (isAbsolute(prefix) || isAbsolute(pattern.map(function(p) {
        return typeof p === "string" ? p : "[*]";
      }).join("/"))) {
        if (!prefix || !isAbsolute(prefix))
          prefix = "/" + prefix;
        read = prefix;
      } else
        read = prefix;
      var abs = this._makeAbs(read);
      if (childrenIgnored(this, read))
        return cb();
      var isGlobStar = remain[0] === minimatch.GLOBSTAR;
      if (isGlobStar)
        this._processGlobStar(prefix, read, abs, remain, index, inGlobStar, cb);
      else
        this._processReaddir(prefix, read, abs, remain, index, inGlobStar, cb);
    };
    Glob.prototype._processReaddir = function(prefix, read, abs, remain, index, inGlobStar, cb) {
      var self2 = this;
      this._readdir(abs, inGlobStar, function(er, entries) {
        return self2._processReaddir2(prefix, read, abs, remain, index, inGlobStar, entries, cb);
      });
    };
    Glob.prototype._processReaddir2 = function(prefix, read, abs, remain, index, inGlobStar, entries, cb) {
      if (!entries)
        return cb();
      var pn = remain[0];
      var negate = !!this.minimatch.negate;
      var rawGlob = pn._glob;
      var dotOk = this.dot || rawGlob.charAt(0) === ".";
      var matchedEntries = [];
      for (var i = 0; i < entries.length; i++) {
        var e = entries[i];
        if (e.charAt(0) !== "." || dotOk) {
          var m;
          if (negate && !prefix) {
            m = !e.match(pn);
          } else {
            m = e.match(pn);
          }
          if (m)
            matchedEntries.push(e);
        }
      }
      var len = matchedEntries.length;
      if (len === 0)
        return cb();
      if (remain.length === 1 && !this.mark && !this.stat) {
        if (!this.matches[index])
          this.matches[index] = /* @__PURE__ */ Object.create(null);
        for (var i = 0; i < len; i++) {
          var e = matchedEntries[i];
          if (prefix) {
            if (prefix !== "/")
              e = prefix + "/" + e;
            else
              e = prefix + e;
          }
          if (e.charAt(0) === "/" && !this.nomount) {
            e = path2.join(this.root, e);
          }
          this._emitMatch(index, e);
        }
        return cb();
      }
      remain.shift();
      for (var i = 0; i < len; i++) {
        var e = matchedEntries[i];
        var newPattern;
        if (prefix) {
          if (prefix !== "/")
            e = prefix + "/" + e;
          else
            e = prefix + e;
        }
        this._process([e].concat(remain), index, inGlobStar, cb);
      }
      cb();
    };
    Glob.prototype._emitMatch = function(index, e) {
      if (this.aborted)
        return;
      if (isIgnored(this, e))
        return;
      if (this.paused) {
        this._emitQueue.push([index, e]);
        return;
      }
      var abs = isAbsolute(e) ? e : this._makeAbs(e);
      if (this.mark)
        e = this._mark(e);
      if (this.absolute)
        e = abs;
      if (this.matches[index][e])
        return;
      if (this.nodir) {
        var c = this.cache[abs];
        if (c === "DIR" || Array.isArray(c))
          return;
      }
      this.matches[index][e] = true;
      var st = this.statCache[abs];
      if (st)
        this.emit("stat", e, st);
      this.emit("match", e);
    };
    Glob.prototype._readdirInGlobStar = function(abs, cb) {
      if (this.aborted)
        return;
      if (this.follow)
        return this._readdir(abs, false, cb);
      var lstatkey = "lstat\0" + abs;
      var self2 = this;
      var lstatcb = inflight(lstatkey, lstatcb_);
      if (lstatcb)
        self2.fs.lstat(abs, lstatcb);
      function lstatcb_(er, lstat) {
        if (er && er.code === "ENOENT")
          return cb();
        var isSym = lstat && lstat.isSymbolicLink();
        self2.symlinks[abs] = isSym;
        if (!isSym && lstat && !lstat.isDirectory()) {
          self2.cache[abs] = "FILE";
          cb();
        } else
          self2._readdir(abs, false, cb);
      }
    };
    Glob.prototype._readdir = function(abs, inGlobStar, cb) {
      if (this.aborted)
        return;
      cb = inflight("readdir\0" + abs + "\0" + inGlobStar, cb);
      if (!cb)
        return;
      if (inGlobStar && !ownProp(this.symlinks, abs))
        return this._readdirInGlobStar(abs, cb);
      if (ownProp(this.cache, abs)) {
        var c = this.cache[abs];
        if (!c || c === "FILE")
          return cb();
        if (Array.isArray(c))
          return cb(null, c);
      }
      var self2 = this;
      self2.fs.readdir(abs, readdirCb(this, abs, cb));
    };
    function readdirCb(self2, abs, cb) {
      return function(er, entries) {
        if (er)
          self2._readdirError(abs, er, cb);
        else
          self2._readdirEntries(abs, entries, cb);
      };
    }
    Glob.prototype._readdirEntries = function(abs, entries, cb) {
      if (this.aborted)
        return;
      if (!this.mark && !this.stat) {
        for (var i = 0; i < entries.length; i++) {
          var e = entries[i];
          if (abs === "/")
            e = abs + e;
          else
            e = abs + "/" + e;
          this.cache[e] = true;
        }
      }
      this.cache[abs] = entries;
      return cb(null, entries);
    };
    Glob.prototype._readdirError = function(f, er, cb) {
      if (this.aborted)
        return;
      switch (er.code) {
        case "ENOTSUP":
        case "ENOTDIR":
          var abs = this._makeAbs(f);
          this.cache[abs] = "FILE";
          if (abs === this.cwdAbs) {
            var error = new Error(er.code + " invalid cwd " + this.cwd);
            error.path = this.cwd;
            error.code = er.code;
            this.emit("error", error);
            this.abort();
          }
          break;
        case "ENOENT":
        case "ELOOP":
        case "ENAMETOOLONG":
        case "UNKNOWN":
          this.cache[this._makeAbs(f)] = false;
          break;
        default:
          this.cache[this._makeAbs(f)] = false;
          if (this.strict) {
            this.emit("error", er);
            this.abort();
          }
          if (!this.silent)
            console.error("glob error", er);
          break;
      }
      return cb();
    };
    Glob.prototype._processGlobStar = function(prefix, read, abs, remain, index, inGlobStar, cb) {
      var self2 = this;
      this._readdir(abs, inGlobStar, function(er, entries) {
        self2._processGlobStar2(prefix, read, abs, remain, index, inGlobStar, entries, cb);
      });
    };
    Glob.prototype._processGlobStar2 = function(prefix, read, abs, remain, index, inGlobStar, entries, cb) {
      if (!entries)
        return cb();
      var remainWithoutGlobStar = remain.slice(1);
      var gspref = prefix ? [prefix] : [];
      var noGlobStar = gspref.concat(remainWithoutGlobStar);
      this._process(noGlobStar, index, false, cb);
      var isSym = this.symlinks[abs];
      var len = entries.length;
      if (isSym && inGlobStar)
        return cb();
      for (var i = 0; i < len; i++) {
        var e = entries[i];
        if (e.charAt(0) === "." && !this.dot)
          continue;
        var instead = gspref.concat(entries[i], remainWithoutGlobStar);
        this._process(instead, index, true, cb);
        var below = gspref.concat(entries[i], remain);
        this._process(below, index, true, cb);
      }
      cb();
    };
    Glob.prototype._processSimple = function(prefix, index, cb) {
      var self2 = this;
      this._stat(prefix, function(er, exists) {
        self2._processSimple2(prefix, index, er, exists, cb);
      });
    };
    Glob.prototype._processSimple2 = function(prefix, index, er, exists, cb) {
      if (!this.matches[index])
        this.matches[index] = /* @__PURE__ */ Object.create(null);
      if (!exists)
        return cb();
      if (prefix && isAbsolute(prefix) && !this.nomount) {
        var trail = /[\/\\]$/.test(prefix);
        if (prefix.charAt(0) === "/") {
          prefix = path2.join(this.root, prefix);
        } else {
          prefix = path2.resolve(this.root, prefix);
          if (trail)
            prefix += "/";
        }
      }
      if (process.platform === "win32")
        prefix = prefix.replace(/\\/g, "/");
      this._emitMatch(index, prefix);
      cb();
    };
    Glob.prototype._stat = function(f, cb) {
      var abs = this._makeAbs(f);
      var needDir = f.slice(-1) === "/";
      if (f.length > this.maxLength)
        return cb();
      if (!this.stat && ownProp(this.cache, abs)) {
        var c = this.cache[abs];
        if (Array.isArray(c))
          c = "DIR";
        if (!needDir || c === "DIR")
          return cb(null, c);
        if (needDir && c === "FILE")
          return cb();
      }
      var exists;
      var stat = this.statCache[abs];
      if (stat !== void 0) {
        if (stat === false)
          return cb(null, stat);
        else {
          var type = stat.isDirectory() ? "DIR" : "FILE";
          if (needDir && type === "FILE")
            return cb();
          else
            return cb(null, type, stat);
        }
      }
      var self2 = this;
      var statcb = inflight("stat\0" + abs, lstatcb_);
      if (statcb)
        self2.fs.lstat(abs, statcb);
      function lstatcb_(er, lstat) {
        if (lstat && lstat.isSymbolicLink()) {
          return self2.fs.stat(abs, function(er2, stat2) {
            if (er2)
              self2._stat2(f, abs, null, lstat, cb);
            else
              self2._stat2(f, abs, er2, stat2, cb);
          });
        } else {
          self2._stat2(f, abs, er, lstat, cb);
        }
      }
    };
    Glob.prototype._stat2 = function(f, abs, er, stat, cb) {
      if (er && (er.code === "ENOENT" || er.code === "ENOTDIR")) {
        this.statCache[abs] = false;
        return cb();
      }
      var needDir = f.slice(-1) === "/";
      this.statCache[abs] = stat;
      if (abs.slice(-1) === "/" && stat && !stat.isDirectory())
        return cb(null, false, stat);
      var c = true;
      if (stat)
        c = stat.isDirectory() ? "DIR" : "FILE";
      this.cache[abs] = this.cache[abs] || c;
      if (needDir && c === "FILE")
        return cb();
      return cb(null, c, stat);
    };
  }
});

// node_modules/mimic-fn/index.js
var require_mimic_fn = __commonJS({
  "node_modules/mimic-fn/index.js"(exports, module2) {
    "use strict";
    var mimicFn = (to, from) => {
      for (const prop of Reflect.ownKeys(from)) {
        Object.defineProperty(to, prop, Object.getOwnPropertyDescriptor(from, prop));
      }
      return to;
    };
    module2.exports = mimicFn;
    module2.exports.default = mimicFn;
  }
});

// node_modules/onetime/index.js
var require_onetime = __commonJS({
  "node_modules/onetime/index.js"(exports, module2) {
    "use strict";
    var mimicFn = require_mimic_fn();
    var calledFunctions = /* @__PURE__ */ new WeakMap();
    var onetime = (function_, options = {}) => {
      if (typeof function_ !== "function") {
        throw new TypeError("Expected a function");
      }
      let returnValue;
      let callCount = 0;
      const functionName = function_.displayName || function_.name || "<anonymous>";
      const onetime2 = function(...arguments_) {
        calledFunctions.set(onetime2, ++callCount);
        if (callCount === 1) {
          returnValue = function_.apply(this, arguments_);
          function_ = null;
        } else if (options.throw === true) {
          throw new Error(`Function \`${functionName}\` can only be called once`);
        }
        return returnValue;
      };
      mimicFn(onetime2, function_);
      calledFunctions.set(onetime2, callCount);
      return onetime2;
    };
    module2.exports = onetime;
    module2.exports.default = onetime;
    module2.exports.callCount = (function_) => {
      if (!calledFunctions.has(function_)) {
        throw new Error(`The given function \`${function_.name}\` is not wrapped by the \`onetime\` package`);
      }
      return calledFunctions.get(function_);
    };
  }
});

// node_modules/signal-exit/signals.js
var require_signals = __commonJS({
  "node_modules/signal-exit/signals.js"(exports, module2) {
    module2.exports = [
      "SIGABRT",
      "SIGALRM",
      "SIGHUP",
      "SIGINT",
      "SIGTERM"
    ];
    if (process.platform !== "win32") {
      module2.exports.push(
        "SIGVTALRM",
        "SIGXCPU",
        "SIGXFSZ",
        "SIGUSR2",
        "SIGTRAP",
        "SIGSYS",
        "SIGQUIT",
        "SIGIOT"
        // should detect profiler and enable/disable accordingly.
        // see #21
        // 'SIGPROF'
      );
    }
    if (process.platform === "linux") {
      module2.exports.push(
        "SIGIO",
        "SIGPOLL",
        "SIGPWR",
        "SIGSTKFLT",
        "SIGUNUSED"
      );
    }
  }
});

// node_modules/signal-exit/index.js
var require_signal_exit = __commonJS({
  "node_modules/signal-exit/index.js"(exports, module2) {
    var process2 = global.process;
    var processOk = function(process3) {
      return process3 && typeof process3 === "object" && typeof process3.removeListener === "function" && typeof process3.emit === "function" && typeof process3.reallyExit === "function" && typeof process3.listeners === "function" && typeof process3.kill === "function" && typeof process3.pid === "number" && typeof process3.on === "function";
    };
    if (!processOk(process2)) {
      module2.exports = function() {
        return function() {
        };
      };
    } else {
      assert = require("assert");
      signals = require_signals();
      isWin = /^win/i.test(process2.platform);
      EE = require("events");
      if (typeof EE !== "function") {
        EE = EE.EventEmitter;
      }
      if (process2.__signal_exit_emitter__) {
        emitter = process2.__signal_exit_emitter__;
      } else {
        emitter = process2.__signal_exit_emitter__ = new EE();
        emitter.count = 0;
        emitter.emitted = {};
      }
      if (!emitter.infinite) {
        emitter.setMaxListeners(Infinity);
        emitter.infinite = true;
      }
      module2.exports = function(cb, opts) {
        if (!processOk(global.process)) {
          return function() {
          };
        }
        assert.equal(typeof cb, "function", "a callback must be provided for exit handler");
        if (loaded === false) {
          load();
        }
        var ev = "exit";
        if (opts && opts.alwaysLast) {
          ev = "afterexit";
        }
        var remove = function() {
          emitter.removeListener(ev, cb);
          if (emitter.listeners("exit").length === 0 && emitter.listeners("afterexit").length === 0) {
            unload();
          }
        };
        emitter.on(ev, cb);
        return remove;
      };
      unload = function unload2() {
        if (!loaded || !processOk(global.process)) {
          return;
        }
        loaded = false;
        signals.forEach(function(sig) {
          try {
            process2.removeListener(sig, sigListeners[sig]);
          } catch (er) {
          }
        });
        process2.emit = originalProcessEmit;
        process2.reallyExit = originalProcessReallyExit;
        emitter.count -= 1;
      };
      module2.exports.unload = unload;
      emit = function emit2(event, code, signal) {
        if (emitter.emitted[event]) {
          return;
        }
        emitter.emitted[event] = true;
        emitter.emit(event, code, signal);
      };
      sigListeners = {};
      signals.forEach(function(sig) {
        sigListeners[sig] = function listener() {
          if (!processOk(global.process)) {
            return;
          }
          var listeners = process2.listeners(sig);
          if (listeners.length === emitter.count) {
            unload();
            emit("exit", null, sig);
            emit("afterexit", null, sig);
            if (isWin && sig === "SIGHUP") {
              sig = "SIGINT";
            }
            process2.kill(process2.pid, sig);
          }
        };
      });
      module2.exports.signals = function() {
        return signals;
      };
      loaded = false;
      load = function load2() {
        if (loaded || !processOk(global.process)) {
          return;
        }
        loaded = true;
        emitter.count += 1;
        signals = signals.filter(function(sig) {
          try {
            process2.on(sig, sigListeners[sig]);
            return true;
          } catch (er) {
            return false;
          }
        });
        process2.emit = processEmit;
        process2.reallyExit = processReallyExit;
      };
      module2.exports.load = load;
      originalProcessReallyExit = process2.reallyExit;
      processReallyExit = function processReallyExit2(code) {
        if (!processOk(global.process)) {
          return;
        }
        process2.exitCode = code || /* istanbul ignore next */
        0;
        emit("exit", process2.exitCode, null);
        emit("afterexit", process2.exitCode, null);
        originalProcessReallyExit.call(process2, process2.exitCode);
      };
      originalProcessEmit = process2.emit;
      processEmit = function processEmit2(ev, arg) {
        if (ev === "exit" && processOk(global.process)) {
          if (arg !== void 0) {
            process2.exitCode = arg;
          }
          var ret = originalProcessEmit.apply(this, arguments);
          emit("exit", process2.exitCode, null);
          emit("afterexit", process2.exitCode, null);
          return ret;
        } else {
          return originalProcessEmit.apply(this, arguments);
        }
      };
    }
    var assert;
    var signals;
    var isWin;
    var EE;
    var emitter;
    var unload;
    var emit;
    var sigListeners;
    var loaded;
    var load;
    var originalProcessReallyExit;
    var processReallyExit;
    var originalProcessEmit;
    var processEmit;
  }
});

// node_modules/restore-cursor/index.js
var require_restore_cursor = __commonJS({
  "node_modules/restore-cursor/index.js"(exports, module2) {
    "use strict";
    var onetime = require_onetime();
    var signalExit = require_signal_exit();
    module2.exports = onetime(() => {
      signalExit(() => {
        process.stderr.write("\x1B[?25h");
      }, { alwaysLast: true });
    });
  }
});

// node_modules/cli-cursor/index.js
var require_cli_cursor = __commonJS({
  "node_modules/cli-cursor/index.js"(exports) {
    "use strict";
    var restoreCursor = require_restore_cursor();
    var isHidden = false;
    exports.show = (writableStream = process.stderr) => {
      if (!writableStream.isTTY) {
        return;
      }
      isHidden = false;
      writableStream.write("\x1B[?25h");
    };
    exports.hide = (writableStream = process.stderr) => {
      if (!writableStream.isTTY) {
        return;
      }
      restoreCursor();
      isHidden = true;
      writableStream.write("\x1B[?25l");
    };
    exports.toggle = (force, writableStream) => {
      if (force !== void 0) {
        isHidden = force;
      }
      if (isHidden) {
        exports.show(writableStream);
      } else {
        exports.hide(writableStream);
      }
    };
  }
});

// node_modules/cli-spinners/spinners.json
var require_spinners = __commonJS({
  "node_modules/cli-spinners/spinners.json"(exports, module2) {
    module2.exports = {
      dots: {
        interval: 80,
        frames: [
          "\u280B",
          "\u2819",
          "\u2839",
          "\u2838",
          "\u283C",
          "\u2834",
          "\u2826",
          "\u2827",
          "\u2807",
          "\u280F"
        ]
      },
      dots2: {
        interval: 80,
        frames: [
          "\u28FE",
          "\u28FD",
          "\u28FB",
          "\u28BF",
          "\u287F",
          "\u28DF",
          "\u28EF",
          "\u28F7"
        ]
      },
      dots3: {
        interval: 80,
        frames: [
          "\u280B",
          "\u2819",
          "\u281A",
          "\u281E",
          "\u2816",
          "\u2826",
          "\u2834",
          "\u2832",
          "\u2833",
          "\u2813"
        ]
      },
      dots4: {
        interval: 80,
        frames: [
          "\u2804",
          "\u2806",
          "\u2807",
          "\u280B",
          "\u2819",
          "\u2838",
          "\u2830",
          "\u2820",
          "\u2830",
          "\u2838",
          "\u2819",
          "\u280B",
          "\u2807",
          "\u2806"
        ]
      },
      dots5: {
        interval: 80,
        frames: [
          "\u280B",
          "\u2819",
          "\u281A",
          "\u2812",
          "\u2802",
          "\u2802",
          "\u2812",
          "\u2832",
          "\u2834",
          "\u2826",
          "\u2816",
          "\u2812",
          "\u2810",
          "\u2810",
          "\u2812",
          "\u2813",
          "\u280B"
        ]
      },
      dots6: {
        interval: 80,
        frames: [
          "\u2801",
          "\u2809",
          "\u2819",
          "\u281A",
          "\u2812",
          "\u2802",
          "\u2802",
          "\u2812",
          "\u2832",
          "\u2834",
          "\u2824",
          "\u2804",
          "\u2804",
          "\u2824",
          "\u2834",
          "\u2832",
          "\u2812",
          "\u2802",
          "\u2802",
          "\u2812",
          "\u281A",
          "\u2819",
          "\u2809",
          "\u2801"
        ]
      },
      dots7: {
        interval: 80,
        frames: [
          "\u2808",
          "\u2809",
          "\u280B",
          "\u2813",
          "\u2812",
          "\u2810",
          "\u2810",
          "\u2812",
          "\u2816",
          "\u2826",
          "\u2824",
          "\u2820",
          "\u2820",
          "\u2824",
          "\u2826",
          "\u2816",
          "\u2812",
          "\u2810",
          "\u2810",
          "\u2812",
          "\u2813",
          "\u280B",
          "\u2809",
          "\u2808"
        ]
      },
      dots8: {
        interval: 80,
        frames: [
          "\u2801",
          "\u2801",
          "\u2809",
          "\u2819",
          "\u281A",
          "\u2812",
          "\u2802",
          "\u2802",
          "\u2812",
          "\u2832",
          "\u2834",
          "\u2824",
          "\u2804",
          "\u2804",
          "\u2824",
          "\u2820",
          "\u2820",
          "\u2824",
          "\u2826",
          "\u2816",
          "\u2812",
          "\u2810",
          "\u2810",
          "\u2812",
          "\u2813",
          "\u280B",
          "\u2809",
          "\u2808",
          "\u2808"
        ]
      },
      dots9: {
        interval: 80,
        frames: [
          "\u28B9",
          "\u28BA",
          "\u28BC",
          "\u28F8",
          "\u28C7",
          "\u2867",
          "\u2857",
          "\u284F"
        ]
      },
      dots10: {
        interval: 80,
        frames: [
          "\u2884",
          "\u2882",
          "\u2881",
          "\u2841",
          "\u2848",
          "\u2850",
          "\u2860"
        ]
      },
      dots11: {
        interval: 100,
        frames: [
          "\u2801",
          "\u2802",
          "\u2804",
          "\u2840",
          "\u2880",
          "\u2820",
          "\u2810",
          "\u2808"
        ]
      },
      dots12: {
        interval: 80,
        frames: [
          "\u2880\u2800",
          "\u2840\u2800",
          "\u2804\u2800",
          "\u2882\u2800",
          "\u2842\u2800",
          "\u2805\u2800",
          "\u2883\u2800",
          "\u2843\u2800",
          "\u280D\u2800",
          "\u288B\u2800",
          "\u284B\u2800",
          "\u280D\u2801",
          "\u288B\u2801",
          "\u284B\u2801",
          "\u280D\u2809",
          "\u280B\u2809",
          "\u280B\u2809",
          "\u2809\u2819",
          "\u2809\u2819",
          "\u2809\u2829",
          "\u2808\u2899",
          "\u2808\u2859",
          "\u2888\u2829",
          "\u2840\u2899",
          "\u2804\u2859",
          "\u2882\u2829",
          "\u2842\u2898",
          "\u2805\u2858",
          "\u2883\u2828",
          "\u2843\u2890",
          "\u280D\u2850",
          "\u288B\u2820",
          "\u284B\u2880",
          "\u280D\u2841",
          "\u288B\u2801",
          "\u284B\u2801",
          "\u280D\u2809",
          "\u280B\u2809",
          "\u280B\u2809",
          "\u2809\u2819",
          "\u2809\u2819",
          "\u2809\u2829",
          "\u2808\u2899",
          "\u2808\u2859",
          "\u2808\u2829",
          "\u2800\u2899",
          "\u2800\u2859",
          "\u2800\u2829",
          "\u2800\u2898",
          "\u2800\u2858",
          "\u2800\u2828",
          "\u2800\u2890",
          "\u2800\u2850",
          "\u2800\u2820",
          "\u2800\u2880",
          "\u2800\u2840"
        ]
      },
      dots13: {
        interval: 80,
        frames: [
          "\u28FC",
          "\u28F9",
          "\u28BB",
          "\u283F",
          "\u285F",
          "\u28CF",
          "\u28E7",
          "\u28F6"
        ]
      },
      dots8Bit: {
        interval: 80,
        frames: [
          "\u2800",
          "\u2801",
          "\u2802",
          "\u2803",
          "\u2804",
          "\u2805",
          "\u2806",
          "\u2807",
          "\u2840",
          "\u2841",
          "\u2842",
          "\u2843",
          "\u2844",
          "\u2845",
          "\u2846",
          "\u2847",
          "\u2808",
          "\u2809",
          "\u280A",
          "\u280B",
          "\u280C",
          "\u280D",
          "\u280E",
          "\u280F",
          "\u2848",
          "\u2849",
          "\u284A",
          "\u284B",
          "\u284C",
          "\u284D",
          "\u284E",
          "\u284F",
          "\u2810",
          "\u2811",
          "\u2812",
          "\u2813",
          "\u2814",
          "\u2815",
          "\u2816",
          "\u2817",
          "\u2850",
          "\u2851",
          "\u2852",
          "\u2853",
          "\u2854",
          "\u2855",
          "\u2856",
          "\u2857",
          "\u2818",
          "\u2819",
          "\u281A",
          "\u281B",
          "\u281C",
          "\u281D",
          "\u281E",
          "\u281F",
          "\u2858",
          "\u2859",
          "\u285A",
          "\u285B",
          "\u285C",
          "\u285D",
          "\u285E",
          "\u285F",
          "\u2820",
          "\u2821",
          "\u2822",
          "\u2823",
          "\u2824",
          "\u2825",
          "\u2826",
          "\u2827",
          "\u2860",
          "\u2861",
          "\u2862",
          "\u2863",
          "\u2864",
          "\u2865",
          "\u2866",
          "\u2867",
          "\u2828",
          "\u2829",
          "\u282A",
          "\u282B",
          "\u282C",
          "\u282D",
          "\u282E",
          "\u282F",
          "\u2868",
          "\u2869",
          "\u286A",
          "\u286B",
          "\u286C",
          "\u286D",
          "\u286E",
          "\u286F",
          "\u2830",
          "\u2831",
          "\u2832",
          "\u2833",
          "\u2834",
          "\u2835",
          "\u2836",
          "\u2837",
          "\u2870",
          "\u2871",
          "\u2872",
          "\u2873",
          "\u2874",
          "\u2875",
          "\u2876",
          "\u2877",
          "\u2838",
          "\u2839",
          "\u283A",
          "\u283B",
          "\u283C",
          "\u283D",
          "\u283E",
          "\u283F",
          "\u2878",
          "\u2879",
          "\u287A",
          "\u287B",
          "\u287C",
          "\u287D",
          "\u287E",
          "\u287F",
          "\u2880",
          "\u2881",
          "\u2882",
          "\u2883",
          "\u2884",
          "\u2885",
          "\u2886",
          "\u2887",
          "\u28C0",
          "\u28C1",
          "\u28C2",
          "\u28C3",
          "\u28C4",
          "\u28C5",
          "\u28C6",
          "\u28C7",
          "\u2888",
          "\u2889",
          "\u288A",
          "\u288B",
          "\u288C",
          "\u288D",
          "\u288E",
          "\u288F",
          "\u28C8",
          "\u28C9",
          "\u28CA",
          "\u28CB",
          "\u28CC",
          "\u28CD",
          "\u28CE",
          "\u28CF",
          "\u2890",
          "\u2891",
          "\u2892",
          "\u2893",
          "\u2894",
          "\u2895",
          "\u2896",
          "\u2897",
          "\u28D0",
          "\u28D1",
          "\u28D2",
          "\u28D3",
          "\u28D4",
          "\u28D5",
          "\u28D6",
          "\u28D7",
          "\u2898",
          "\u2899",
          "\u289A",
          "\u289B",
          "\u289C",
          "\u289D",
          "\u289E",
          "\u289F",
          "\u28D8",
          "\u28D9",
          "\u28DA",
          "\u28DB",
          "\u28DC",
          "\u28DD",
          "\u28DE",
          "\u28DF",
          "\u28A0",
          "\u28A1",
          "\u28A2",
          "\u28A3",
          "\u28A4",
          "\u28A5",
          "\u28A6",
          "\u28A7",
          "\u28E0",
          "\u28E1",
          "\u28E2",
          "\u28E3",
          "\u28E4",
          "\u28E5",
          "\u28E6",
          "\u28E7",
          "\u28A8",
          "\u28A9",
          "\u28AA",
          "\u28AB",
          "\u28AC",
          "\u28AD",
          "\u28AE",
          "\u28AF",
          "\u28E8",
          "\u28E9",
          "\u28EA",
          "\u28EB",
          "\u28EC",
          "\u28ED",
          "\u28EE",
          "\u28EF",
          "\u28B0",
          "\u28B1",
          "\u28B2",
          "\u28B3",
          "\u28B4",
          "\u28B5",
          "\u28B6",
          "\u28B7",
          "\u28F0",
          "\u28F1",
          "\u28F2",
          "\u28F3",
          "\u28F4",
          "\u28F5",
          "\u28F6",
          "\u28F7",
          "\u28B8",
          "\u28B9",
          "\u28BA",
          "\u28BB",
          "\u28BC",
          "\u28BD",
          "\u28BE",
          "\u28BF",
          "\u28F8",
          "\u28F9",
          "\u28FA",
          "\u28FB",
          "\u28FC",
          "\u28FD",
          "\u28FE",
          "\u28FF"
        ]
      },
      sand: {
        interval: 80,
        frames: [
          "\u2801",
          "\u2802",
          "\u2804",
          "\u2840",
          "\u2848",
          "\u2850",
          "\u2860",
          "\u28C0",
          "\u28C1",
          "\u28C2",
          "\u28C4",
          "\u28CC",
          "\u28D4",
          "\u28E4",
          "\u28E5",
          "\u28E6",
          "\u28EE",
          "\u28F6",
          "\u28F7",
          "\u28FF",
          "\u287F",
          "\u283F",
          "\u289F",
          "\u281F",
          "\u285B",
          "\u281B",
          "\u282B",
          "\u288B",
          "\u280B",
          "\u280D",
          "\u2849",
          "\u2809",
          "\u2811",
          "\u2821",
          "\u2881"
        ]
      },
      line: {
        interval: 130,
        frames: [
          "-",
          "\\",
          "|",
          "/"
        ]
      },
      line2: {
        interval: 100,
        frames: [
          "\u2802",
          "-",
          "\u2013",
          "\u2014",
          "\u2013",
          "-"
        ]
      },
      pipe: {
        interval: 100,
        frames: [
          "\u2524",
          "\u2518",
          "\u2534",
          "\u2514",
          "\u251C",
          "\u250C",
          "\u252C",
          "\u2510"
        ]
      },
      simpleDots: {
        interval: 400,
        frames: [
          ".  ",
          ".. ",
          "...",
          "   "
        ]
      },
      simpleDotsScrolling: {
        interval: 200,
        frames: [
          ".  ",
          ".. ",
          "...",
          " ..",
          "  .",
          "   "
        ]
      },
      star: {
        interval: 70,
        frames: [
          "\u2736",
          "\u2738",
          "\u2739",
          "\u273A",
          "\u2739",
          "\u2737"
        ]
      },
      star2: {
        interval: 80,
        frames: [
          "+",
          "x",
          "*"
        ]
      },
      flip: {
        interval: 70,
        frames: [
          "_",
          "_",
          "_",
          "-",
          "`",
          "`",
          "'",
          "\xB4",
          "-",
          "_",
          "_",
          "_"
        ]
      },
      hamburger: {
        interval: 100,
        frames: [
          "\u2631",
          "\u2632",
          "\u2634"
        ]
      },
      growVertical: {
        interval: 120,
        frames: [
          "\u2581",
          "\u2583",
          "\u2584",
          "\u2585",
          "\u2586",
          "\u2587",
          "\u2586",
          "\u2585",
          "\u2584",
          "\u2583"
        ]
      },
      growHorizontal: {
        interval: 120,
        frames: [
          "\u258F",
          "\u258E",
          "\u258D",
          "\u258C",
          "\u258B",
          "\u258A",
          "\u2589",
          "\u258A",
          "\u258B",
          "\u258C",
          "\u258D",
          "\u258E"
        ]
      },
      balloon: {
        interval: 140,
        frames: [
          " ",
          ".",
          "o",
          "O",
          "@",
          "*",
          " "
        ]
      },
      balloon2: {
        interval: 120,
        frames: [
          ".",
          "o",
          "O",
          "\xB0",
          "O",
          "o",
          "."
        ]
      },
      noise: {
        interval: 100,
        frames: [
          "\u2593",
          "\u2592",
          "\u2591"
        ]
      },
      bounce: {
        interval: 120,
        frames: [
          "\u2801",
          "\u2802",
          "\u2804",
          "\u2802"
        ]
      },
      boxBounce: {
        interval: 120,
        frames: [
          "\u2596",
          "\u2598",
          "\u259D",
          "\u2597"
        ]
      },
      boxBounce2: {
        interval: 100,
        frames: [
          "\u258C",
          "\u2580",
          "\u2590",
          "\u2584"
        ]
      },
      triangle: {
        interval: 50,
        frames: [
          "\u25E2",
          "\u25E3",
          "\u25E4",
          "\u25E5"
        ]
      },
      arc: {
        interval: 100,
        frames: [
          "\u25DC",
          "\u25E0",
          "\u25DD",
          "\u25DE",
          "\u25E1",
          "\u25DF"
        ]
      },
      circle: {
        interval: 120,
        frames: [
          "\u25E1",
          "\u2299",
          "\u25E0"
        ]
      },
      squareCorners: {
        interval: 180,
        frames: [
          "\u25F0",
          "\u25F3",
          "\u25F2",
          "\u25F1"
        ]
      },
      circleQuarters: {
        interval: 120,
        frames: [
          "\u25F4",
          "\u25F7",
          "\u25F6",
          "\u25F5"
        ]
      },
      circleHalves: {
        interval: 50,
        frames: [
          "\u25D0",
          "\u25D3",
          "\u25D1",
          "\u25D2"
        ]
      },
      squish: {
        interval: 100,
        frames: [
          "\u256B",
          "\u256A"
        ]
      },
      toggle: {
        interval: 250,
        frames: [
          "\u22B6",
          "\u22B7"
        ]
      },
      toggle2: {
        interval: 80,
        frames: [
          "\u25AB",
          "\u25AA"
        ]
      },
      toggle3: {
        interval: 120,
        frames: [
          "\u25A1",
          "\u25A0"
        ]
      },
      toggle4: {
        interval: 100,
        frames: [
          "\u25A0",
          "\u25A1",
          "\u25AA",
          "\u25AB"
        ]
      },
      toggle5: {
        interval: 100,
        frames: [
          "\u25AE",
          "\u25AF"
        ]
      },
      toggle6: {
        interval: 300,
        frames: [
          "\u101D",
          "\u1040"
        ]
      },
      toggle7: {
        interval: 80,
        frames: [
          "\u29BE",
          "\u29BF"
        ]
      },
      toggle8: {
        interval: 100,
        frames: [
          "\u25CD",
          "\u25CC"
        ]
      },
      toggle9: {
        interval: 100,
        frames: [
          "\u25C9",
          "\u25CE"
        ]
      },
      toggle10: {
        interval: 100,
        frames: [
          "\u3282",
          "\u3280",
          "\u3281"
        ]
      },
      toggle11: {
        interval: 50,
        frames: [
          "\u29C7",
          "\u29C6"
        ]
      },
      toggle12: {
        interval: 120,
        frames: [
          "\u2617",
          "\u2616"
        ]
      },
      toggle13: {
        interval: 80,
        frames: [
          "=",
          "*",
          "-"
        ]
      },
      arrow: {
        interval: 100,
        frames: [
          "\u2190",
          "\u2196",
          "\u2191",
          "\u2197",
          "\u2192",
          "\u2198",
          "\u2193",
          "\u2199"
        ]
      },
      arrow2: {
        interval: 80,
        frames: [
          "\u2B06\uFE0F ",
          "\u2197\uFE0F ",
          "\u27A1\uFE0F ",
          "\u2198\uFE0F ",
          "\u2B07\uFE0F ",
          "\u2199\uFE0F ",
          "\u2B05\uFE0F ",
          "\u2196\uFE0F "
        ]
      },
      arrow3: {
        interval: 120,
        frames: [
          "\u25B9\u25B9\u25B9\u25B9\u25B9",
          "\u25B8\u25B9\u25B9\u25B9\u25B9",
          "\u25B9\u25B8\u25B9\u25B9\u25B9",
          "\u25B9\u25B9\u25B8\u25B9\u25B9",
          "\u25B9\u25B9\u25B9\u25B8\u25B9",
          "\u25B9\u25B9\u25B9\u25B9\u25B8"
        ]
      },
      bouncingBar: {
        interval: 80,
        frames: [
          "[    ]",
          "[=   ]",
          "[==  ]",
          "[=== ]",
          "[ ===]",
          "[  ==]",
          "[   =]",
          "[    ]",
          "[   =]",
          "[  ==]",
          "[ ===]",
          "[====]",
          "[=== ]",
          "[==  ]",
          "[=   ]"
        ]
      },
      bouncingBall: {
        interval: 80,
        frames: [
          "( \u25CF    )",
          "(  \u25CF   )",
          "(   \u25CF  )",
          "(    \u25CF )",
          "(     \u25CF)",
          "(    \u25CF )",
          "(   \u25CF  )",
          "(  \u25CF   )",
          "( \u25CF    )",
          "(\u25CF     )"
        ]
      },
      smiley: {
        interval: 200,
        frames: [
          "\u{1F604} ",
          "\u{1F61D} "
        ]
      },
      monkey: {
        interval: 300,
        frames: [
          "\u{1F648} ",
          "\u{1F648} ",
          "\u{1F649} ",
          "\u{1F64A} "
        ]
      },
      hearts: {
        interval: 100,
        frames: [
          "\u{1F49B} ",
          "\u{1F499} ",
          "\u{1F49C} ",
          "\u{1F49A} ",
          "\u2764\uFE0F "
        ]
      },
      clock: {
        interval: 100,
        frames: [
          "\u{1F55B} ",
          "\u{1F550} ",
          "\u{1F551} ",
          "\u{1F552} ",
          "\u{1F553} ",
          "\u{1F554} ",
          "\u{1F555} ",
          "\u{1F556} ",
          "\u{1F557} ",
          "\u{1F558} ",
          "\u{1F559} ",
          "\u{1F55A} "
        ]
      },
      earth: {
        interval: 180,
        frames: [
          "\u{1F30D} ",
          "\u{1F30E} ",
          "\u{1F30F} "
        ]
      },
      material: {
        interval: 17,
        frames: [
          "\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588",
          "\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588",
          "\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588",
          "\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588",
          "\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588",
          "\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588",
          "\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2588",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581",
          "\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581\u2581"
        ]
      },
      moon: {
        interval: 80,
        frames: [
          "\u{1F311} ",
          "\u{1F312} ",
          "\u{1F313} ",
          "\u{1F314} ",
          "\u{1F315} ",
          "\u{1F316} ",
          "\u{1F317} ",
          "\u{1F318} "
        ]
      },
      runner: {
        interval: 140,
        frames: [
          "\u{1F6B6} ",
          "\u{1F3C3} "
        ]
      },
      pong: {
        interval: 80,
        frames: [
          "\u2590\u2802       \u258C",
          "\u2590\u2808       \u258C",
          "\u2590 \u2802      \u258C",
          "\u2590 \u2820      \u258C",
          "\u2590  \u2840     \u258C",
          "\u2590  \u2820     \u258C",
          "\u2590   \u2802    \u258C",
          "\u2590   \u2808    \u258C",
          "\u2590    \u2802   \u258C",
          "\u2590    \u2820   \u258C",
          "\u2590     \u2840  \u258C",
          "\u2590     \u2820  \u258C",
          "\u2590      \u2802 \u258C",
          "\u2590      \u2808 \u258C",
          "\u2590       \u2802\u258C",
          "\u2590       \u2820\u258C",
          "\u2590       \u2840\u258C",
          "\u2590      \u2820 \u258C",
          "\u2590      \u2802 \u258C",
          "\u2590     \u2808  \u258C",
          "\u2590     \u2802  \u258C",
          "\u2590    \u2820   \u258C",
          "\u2590    \u2840   \u258C",
          "\u2590   \u2820    \u258C",
          "\u2590   \u2802    \u258C",
          "\u2590  \u2808     \u258C",
          "\u2590  \u2802     \u258C",
          "\u2590 \u2820      \u258C",
          "\u2590 \u2840      \u258C",
          "\u2590\u2820       \u258C"
        ]
      },
      shark: {
        interval: 120,
        frames: [
          "\u2590|\\____________\u258C",
          "\u2590_|\\___________\u258C",
          "\u2590__|\\__________\u258C",
          "\u2590___|\\_________\u258C",
          "\u2590____|\\________\u258C",
          "\u2590_____|\\_______\u258C",
          "\u2590______|\\______\u258C",
          "\u2590_______|\\_____\u258C",
          "\u2590________|\\____\u258C",
          "\u2590_________|\\___\u258C",
          "\u2590__________|\\__\u258C",
          "\u2590___________|\\_\u258C",
          "\u2590____________|\\\u258C",
          "\u2590____________/|\u258C",
          "\u2590___________/|_\u258C",
          "\u2590__________/|__\u258C",
          "\u2590_________/|___\u258C",
          "\u2590________/|____\u258C",
          "\u2590_______/|_____\u258C",
          "\u2590______/|______\u258C",
          "\u2590_____/|_______\u258C",
          "\u2590____/|________\u258C",
          "\u2590___/|_________\u258C",
          "\u2590__/|__________\u258C",
          "\u2590_/|___________\u258C",
          "\u2590/|____________\u258C"
        ]
      },
      dqpb: {
        interval: 100,
        frames: [
          "d",
          "q",
          "p",
          "b"
        ]
      },
      weather: {
        interval: 100,
        frames: [
          "\u2600\uFE0F ",
          "\u2600\uFE0F ",
          "\u2600\uFE0F ",
          "\u{1F324} ",
          "\u26C5\uFE0F ",
          "\u{1F325} ",
          "\u2601\uFE0F ",
          "\u{1F327} ",
          "\u{1F328} ",
          "\u{1F327} ",
          "\u{1F328} ",
          "\u{1F327} ",
          "\u{1F328} ",
          "\u26C8 ",
          "\u{1F328} ",
          "\u{1F327} ",
          "\u{1F328} ",
          "\u2601\uFE0F ",
          "\u{1F325} ",
          "\u26C5\uFE0F ",
          "\u{1F324} ",
          "\u2600\uFE0F ",
          "\u2600\uFE0F "
        ]
      },
      christmas: {
        interval: 400,
        frames: [
          "\u{1F332}",
          "\u{1F384}"
        ]
      },
      grenade: {
        interval: 80,
        frames: [
          "\u060C  ",
          "\u2032  ",
          " \xB4 ",
          " \u203E ",
          "  \u2E0C",
          "  \u2E0A",
          "  |",
          "  \u204E",
          "  \u2055",
          " \u0DF4 ",
          "  \u2053",
          "   ",
          "   ",
          "   "
        ]
      },
      point: {
        interval: 125,
        frames: [
          "\u2219\u2219\u2219",
          "\u25CF\u2219\u2219",
          "\u2219\u25CF\u2219",
          "\u2219\u2219\u25CF",
          "\u2219\u2219\u2219"
        ]
      },
      layer: {
        interval: 150,
        frames: [
          "-",
          "=",
          "\u2261"
        ]
      },
      betaWave: {
        interval: 80,
        frames: [
          "\u03C1\u03B2\u03B2\u03B2\u03B2\u03B2\u03B2",
          "\u03B2\u03C1\u03B2\u03B2\u03B2\u03B2\u03B2",
          "\u03B2\u03B2\u03C1\u03B2\u03B2\u03B2\u03B2",
          "\u03B2\u03B2\u03B2\u03C1\u03B2\u03B2\u03B2",
          "\u03B2\u03B2\u03B2\u03B2\u03C1\u03B2\u03B2",
          "\u03B2\u03B2\u03B2\u03B2\u03B2\u03C1\u03B2",
          "\u03B2\u03B2\u03B2\u03B2\u03B2\u03B2\u03C1"
        ]
      },
      fingerDance: {
        interval: 160,
        frames: [
          "\u{1F918} ",
          "\u{1F91F} ",
          "\u{1F596} ",
          "\u270B ",
          "\u{1F91A} ",
          "\u{1F446} "
        ]
      },
      fistBump: {
        interval: 80,
        frames: [
          "\u{1F91C}\u3000\u3000\u3000\u3000\u{1F91B} ",
          "\u{1F91C}\u3000\u3000\u3000\u3000\u{1F91B} ",
          "\u{1F91C}\u3000\u3000\u3000\u3000\u{1F91B} ",
          "\u3000\u{1F91C}\u3000\u3000\u{1F91B}\u3000 ",
          "\u3000\u3000\u{1F91C}\u{1F91B}\u3000\u3000 ",
          "\u3000\u{1F91C}\u2728\u{1F91B}\u3000\u3000 ",
          "\u{1F91C}\u3000\u2728\u3000\u{1F91B}\u3000 "
        ]
      },
      soccerHeader: {
        interval: 80,
        frames: [
          " \u{1F9D1}\u26BD\uFE0F       \u{1F9D1} ",
          "\u{1F9D1}  \u26BD\uFE0F      \u{1F9D1} ",
          "\u{1F9D1}   \u26BD\uFE0F     \u{1F9D1} ",
          "\u{1F9D1}    \u26BD\uFE0F    \u{1F9D1} ",
          "\u{1F9D1}     \u26BD\uFE0F   \u{1F9D1} ",
          "\u{1F9D1}      \u26BD\uFE0F  \u{1F9D1} ",
          "\u{1F9D1}       \u26BD\uFE0F\u{1F9D1}  ",
          "\u{1F9D1}      \u26BD\uFE0F  \u{1F9D1} ",
          "\u{1F9D1}     \u26BD\uFE0F   \u{1F9D1} ",
          "\u{1F9D1}    \u26BD\uFE0F    \u{1F9D1} ",
          "\u{1F9D1}   \u26BD\uFE0F     \u{1F9D1} ",
          "\u{1F9D1}  \u26BD\uFE0F      \u{1F9D1} "
        ]
      },
      mindblown: {
        interval: 160,
        frames: [
          "\u{1F610} ",
          "\u{1F610} ",
          "\u{1F62E} ",
          "\u{1F62E} ",
          "\u{1F626} ",
          "\u{1F626} ",
          "\u{1F627} ",
          "\u{1F627} ",
          "\u{1F92F} ",
          "\u{1F4A5} ",
          "\u2728 ",
          "\u3000 ",
          "\u3000 ",
          "\u3000 "
        ]
      },
      speaker: {
        interval: 160,
        frames: [
          "\u{1F508} ",
          "\u{1F509} ",
          "\u{1F50A} ",
          "\u{1F509} "
        ]
      },
      orangePulse: {
        interval: 100,
        frames: [
          "\u{1F538} ",
          "\u{1F536} ",
          "\u{1F7E0} ",
          "\u{1F7E0} ",
          "\u{1F536} "
        ]
      },
      bluePulse: {
        interval: 100,
        frames: [
          "\u{1F539} ",
          "\u{1F537} ",
          "\u{1F535} ",
          "\u{1F535} ",
          "\u{1F537} "
        ]
      },
      orangeBluePulse: {
        interval: 100,
        frames: [
          "\u{1F538} ",
          "\u{1F536} ",
          "\u{1F7E0} ",
          "\u{1F7E0} ",
          "\u{1F536} ",
          "\u{1F539} ",
          "\u{1F537} ",
          "\u{1F535} ",
          "\u{1F535} ",
          "\u{1F537} "
        ]
      },
      timeTravel: {
        interval: 100,
        frames: [
          "\u{1F55B} ",
          "\u{1F55A} ",
          "\u{1F559} ",
          "\u{1F558} ",
          "\u{1F557} ",
          "\u{1F556} ",
          "\u{1F555} ",
          "\u{1F554} ",
          "\u{1F553} ",
          "\u{1F552} ",
          "\u{1F551} ",
          "\u{1F550} "
        ]
      },
      aesthetic: {
        interval: 80,
        frames: [
          "\u25B0\u25B1\u25B1\u25B1\u25B1\u25B1\u25B1",
          "\u25B0\u25B0\u25B1\u25B1\u25B1\u25B1\u25B1",
          "\u25B0\u25B0\u25B0\u25B1\u25B1\u25B1\u25B1",
          "\u25B0\u25B0\u25B0\u25B0\u25B1\u25B1\u25B1",
          "\u25B0\u25B0\u25B0\u25B0\u25B0\u25B1\u25B1",
          "\u25B0\u25B0\u25B0\u25B0\u25B0\u25B0\u25B1",
          "\u25B0\u25B0\u25B0\u25B0\u25B0\u25B0\u25B0",
          "\u25B0\u25B1\u25B1\u25B1\u25B1\u25B1\u25B1"
        ]
      }
    };
  }
});

// node_modules/cli-spinners/index.js
var require_cli_spinners = __commonJS({
  "node_modules/cli-spinners/index.js"(exports, module2) {
    "use strict";
    var spinners = Object.assign({}, require_spinners());
    var spinnersList = Object.keys(spinners);
    Object.defineProperty(spinners, "random", {
      get() {
        const randomIndex = Math.floor(Math.random() * spinnersList.length);
        const spinnerName = spinnersList[randomIndex];
        return spinners[spinnerName];
      }
    });
    module2.exports = spinners;
  }
});

// node_modules/is-unicode-supported/index.js
var require_is_unicode_supported = __commonJS({
  "node_modules/is-unicode-supported/index.js"(exports, module2) {
    "use strict";
    module2.exports = () => {
      if (process.platform !== "win32") {
        return true;
      }
      return Boolean(process.env.CI) || Boolean(process.env.WT_SESSION) || // Windows Terminal
      process.env.TERM_PROGRAM === "vscode" || process.env.TERM === "xterm-256color" || process.env.TERM === "alacritty";
    };
  }
});

// node_modules/log-symbols/index.js
var require_log_symbols = __commonJS({
  "node_modules/log-symbols/index.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var isUnicodeSupported = require_is_unicode_supported();
    var main = {
      info: chalk3.blue("\u2139"),
      success: chalk3.green("\u2714"),
      warning: chalk3.yellow("\u26A0"),
      error: chalk3.red("\u2716")
    };
    var fallback = {
      info: chalk3.blue("i"),
      success: chalk3.green("\u221A"),
      warning: chalk3.yellow("\u203C"),
      error: chalk3.red("\xD7")
    };
    module2.exports = isUnicodeSupported() ? main : fallback;
  }
});

// node_modules/ansi-regex/index.js
var require_ansi_regex = __commonJS({
  "node_modules/ansi-regex/index.js"(exports, module2) {
    "use strict";
    module2.exports = ({ onlyFirst = false } = {}) => {
      const pattern = [
        "[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)",
        "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"
      ].join("|");
      return new RegExp(pattern, onlyFirst ? void 0 : "g");
    };
  }
});

// node_modules/strip-ansi/index.js
var require_strip_ansi = __commonJS({
  "node_modules/strip-ansi/index.js"(exports, module2) {
    "use strict";
    var ansiRegex = require_ansi_regex();
    module2.exports = (string) => typeof string === "string" ? string.replace(ansiRegex(), "") : string;
  }
});

// node_modules/clone/clone.js
var require_clone = __commonJS({
  "node_modules/clone/clone.js"(exports, module2) {
    var clone = function() {
      "use strict";
      function clone2(parent, circular, depth, prototype) {
        var filter;
        if (typeof circular === "object") {
          depth = circular.depth;
          prototype = circular.prototype;
          filter = circular.filter;
          circular = circular.circular;
        }
        var allParents = [];
        var allChildren = [];
        var useBuffer = typeof Buffer != "undefined";
        if (typeof circular == "undefined")
          circular = true;
        if (typeof depth == "undefined")
          depth = Infinity;
        function _clone(parent2, depth2) {
          if (parent2 === null)
            return null;
          if (depth2 == 0)
            return parent2;
          var child;
          var proto;
          if (typeof parent2 != "object") {
            return parent2;
          }
          if (clone2.__isArray(parent2)) {
            child = [];
          } else if (clone2.__isRegExp(parent2)) {
            child = new RegExp(parent2.source, __getRegExpFlags(parent2));
            if (parent2.lastIndex)
              child.lastIndex = parent2.lastIndex;
          } else if (clone2.__isDate(parent2)) {
            child = new Date(parent2.getTime());
          } else if (useBuffer && Buffer.isBuffer(parent2)) {
            if (Buffer.allocUnsafe) {
              child = Buffer.allocUnsafe(parent2.length);
            } else {
              child = new Buffer(parent2.length);
            }
            parent2.copy(child);
            return child;
          } else {
            if (typeof prototype == "undefined") {
              proto = Object.getPrototypeOf(parent2);
              child = Object.create(proto);
            } else {
              child = Object.create(prototype);
              proto = prototype;
            }
          }
          if (circular) {
            var index = allParents.indexOf(parent2);
            if (index != -1) {
              return allChildren[index];
            }
            allParents.push(parent2);
            allChildren.push(child);
          }
          for (var i in parent2) {
            var attrs;
            if (proto) {
              attrs = Object.getOwnPropertyDescriptor(proto, i);
            }
            if (attrs && attrs.set == null) {
              continue;
            }
            child[i] = _clone(parent2[i], depth2 - 1);
          }
          return child;
        }
        return _clone(parent, depth);
      }
      clone2.clonePrototype = function clonePrototype(parent) {
        if (parent === null)
          return null;
        var c = function() {
        };
        c.prototype = parent;
        return new c();
      };
      function __objToStr(o) {
        return Object.prototype.toString.call(o);
      }
      ;
      clone2.__objToStr = __objToStr;
      function __isDate(o) {
        return typeof o === "object" && __objToStr(o) === "[object Date]";
      }
      ;
      clone2.__isDate = __isDate;
      function __isArray(o) {
        return typeof o === "object" && __objToStr(o) === "[object Array]";
      }
      ;
      clone2.__isArray = __isArray;
      function __isRegExp(o) {
        return typeof o === "object" && __objToStr(o) === "[object RegExp]";
      }
      ;
      clone2.__isRegExp = __isRegExp;
      function __getRegExpFlags(re) {
        var flags = "";
        if (re.global)
          flags += "g";
        if (re.ignoreCase)
          flags += "i";
        if (re.multiline)
          flags += "m";
        return flags;
      }
      ;
      clone2.__getRegExpFlags = __getRegExpFlags;
      return clone2;
    }();
    if (typeof module2 === "object" && module2.exports) {
      module2.exports = clone;
    }
  }
});

// node_modules/defaults/index.js
var require_defaults = __commonJS({
  "node_modules/defaults/index.js"(exports, module2) {
    var clone = require_clone();
    module2.exports = function(options, defaults) {
      options = options || {};
      Object.keys(defaults).forEach(function(key) {
        if (typeof options[key] === "undefined") {
          options[key] = clone(defaults[key]);
        }
      });
      return options;
    };
  }
});

// node_modules/wcwidth/combining.js
var require_combining = __commonJS({
  "node_modules/wcwidth/combining.js"(exports, module2) {
    module2.exports = [
      [768, 879],
      [1155, 1158],
      [1160, 1161],
      [1425, 1469],
      [1471, 1471],
      [1473, 1474],
      [1476, 1477],
      [1479, 1479],
      [1536, 1539],
      [1552, 1557],
      [1611, 1630],
      [1648, 1648],
      [1750, 1764],
      [1767, 1768],
      [1770, 1773],
      [1807, 1807],
      [1809, 1809],
      [1840, 1866],
      [1958, 1968],
      [2027, 2035],
      [2305, 2306],
      [2364, 2364],
      [2369, 2376],
      [2381, 2381],
      [2385, 2388],
      [2402, 2403],
      [2433, 2433],
      [2492, 2492],
      [2497, 2500],
      [2509, 2509],
      [2530, 2531],
      [2561, 2562],
      [2620, 2620],
      [2625, 2626],
      [2631, 2632],
      [2635, 2637],
      [2672, 2673],
      [2689, 2690],
      [2748, 2748],
      [2753, 2757],
      [2759, 2760],
      [2765, 2765],
      [2786, 2787],
      [2817, 2817],
      [2876, 2876],
      [2879, 2879],
      [2881, 2883],
      [2893, 2893],
      [2902, 2902],
      [2946, 2946],
      [3008, 3008],
      [3021, 3021],
      [3134, 3136],
      [3142, 3144],
      [3146, 3149],
      [3157, 3158],
      [3260, 3260],
      [3263, 3263],
      [3270, 3270],
      [3276, 3277],
      [3298, 3299],
      [3393, 3395],
      [3405, 3405],
      [3530, 3530],
      [3538, 3540],
      [3542, 3542],
      [3633, 3633],
      [3636, 3642],
      [3655, 3662],
      [3761, 3761],
      [3764, 3769],
      [3771, 3772],
      [3784, 3789],
      [3864, 3865],
      [3893, 3893],
      [3895, 3895],
      [3897, 3897],
      [3953, 3966],
      [3968, 3972],
      [3974, 3975],
      [3984, 3991],
      [3993, 4028],
      [4038, 4038],
      [4141, 4144],
      [4146, 4146],
      [4150, 4151],
      [4153, 4153],
      [4184, 4185],
      [4448, 4607],
      [4959, 4959],
      [5906, 5908],
      [5938, 5940],
      [5970, 5971],
      [6002, 6003],
      [6068, 6069],
      [6071, 6077],
      [6086, 6086],
      [6089, 6099],
      [6109, 6109],
      [6155, 6157],
      [6313, 6313],
      [6432, 6434],
      [6439, 6440],
      [6450, 6450],
      [6457, 6459],
      [6679, 6680],
      [6912, 6915],
      [6964, 6964],
      [6966, 6970],
      [6972, 6972],
      [6978, 6978],
      [7019, 7027],
      [7616, 7626],
      [7678, 7679],
      [8203, 8207],
      [8234, 8238],
      [8288, 8291],
      [8298, 8303],
      [8400, 8431],
      [12330, 12335],
      [12441, 12442],
      [43014, 43014],
      [43019, 43019],
      [43045, 43046],
      [64286, 64286],
      [65024, 65039],
      [65056, 65059],
      [65279, 65279],
      [65529, 65531],
      [68097, 68099],
      [68101, 68102],
      [68108, 68111],
      [68152, 68154],
      [68159, 68159],
      [119143, 119145],
      [119155, 119170],
      [119173, 119179],
      [119210, 119213],
      [119362, 119364],
      [917505, 917505],
      [917536, 917631],
      [917760, 917999]
    ];
  }
});

// node_modules/wcwidth/index.js
var require_wcwidth = __commonJS({
  "node_modules/wcwidth/index.js"(exports, module2) {
    "use strict";
    var defaults = require_defaults();
    var combining = require_combining();
    var DEFAULTS = {
      nul: 0,
      control: 0
    };
    module2.exports = function wcwidth2(str) {
      return wcswidth(str, DEFAULTS);
    };
    module2.exports.config = function(opts) {
      opts = defaults(opts || {}, DEFAULTS);
      return function wcwidth2(str) {
        return wcswidth(str, opts);
      };
    };
    function wcswidth(str, opts) {
      if (typeof str !== "string")
        return wcwidth(str, opts);
      var s = 0;
      for (var i = 0; i < str.length; i++) {
        var n = wcwidth(str.charCodeAt(i), opts);
        if (n < 0)
          return -1;
        s += n;
      }
      return s;
    }
    function wcwidth(ucs, opts) {
      if (ucs === 0)
        return opts.nul;
      if (ucs < 32 || ucs >= 127 && ucs < 160)
        return opts.control;
      if (bisearch(ucs))
        return 0;
      return 1 + (ucs >= 4352 && (ucs <= 4447 || // Hangul Jamo init. consonants
      ucs == 9001 || ucs == 9002 || ucs >= 11904 && ucs <= 42191 && ucs != 12351 || // CJK ... Yi
      ucs >= 44032 && ucs <= 55203 || // Hangul Syllables
      ucs >= 63744 && ucs <= 64255 || // CJK Compatibility Ideographs
      ucs >= 65040 && ucs <= 65049 || // Vertical forms
      ucs >= 65072 && ucs <= 65135 || // CJK Compatibility Forms
      ucs >= 65280 && ucs <= 65376 || // Fullwidth Forms
      ucs >= 65504 && ucs <= 65510 || ucs >= 131072 && ucs <= 196605 || ucs >= 196608 && ucs <= 262141));
    }
    function bisearch(ucs) {
      var min2 = 0;
      var max2 = combining.length - 1;
      var mid;
      if (ucs < combining[0][0] || ucs > combining[max2][1])
        return false;
      while (max2 >= min2) {
        mid = Math.floor((min2 + max2) / 2);
        if (ucs > combining[mid][1])
          min2 = mid + 1;
        else if (ucs < combining[mid][0])
          max2 = mid - 1;
        else
          return true;
      }
      return false;
    }
  }
});

// node_modules/is-interactive/index.js
var require_is_interactive = __commonJS({
  "node_modules/is-interactive/index.js"(exports, module2) {
    "use strict";
    module2.exports = ({ stream = process.stdout } = {}) => {
      return Boolean(
        stream && stream.isTTY && process.env.TERM !== "dumb" && !("CI" in process.env)
      );
    };
  }
});

// node_modules/readable-stream/lib/internal/streams/stream.js
var require_stream = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/stream.js"(exports, module2) {
    module2.exports = require("stream");
  }
});

// node_modules/readable-stream/lib/internal/streams/buffer_list.js
var require_buffer_list = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/buffer_list.js"(exports, module2) {
    "use strict";
    function ownKeys(object, enumerableOnly) {
      var keys3 = Object.keys(object);
      if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);
        if (enumerableOnly)
          symbols = symbols.filter(function(sym) {
            return Object.getOwnPropertyDescriptor(object, sym).enumerable;
          });
        keys3.push.apply(keys3, symbols);
      }
      return keys3;
    }
    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};
        if (i % 2) {
          ownKeys(Object(source), true).forEach(function(key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function(key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }
      return target;
    }
    function _defineProperty(obj, key, value2) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value2, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value2;
      }
      return obj;
    }
    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }
    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor)
          descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }
    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps)
        _defineProperties(Constructor.prototype, protoProps);
      if (staticProps)
        _defineProperties(Constructor, staticProps);
      return Constructor;
    }
    var _require = require("buffer");
    var Buffer2 = _require.Buffer;
    var _require2 = require("util");
    var inspect = _require2.inspect;
    var custom = inspect && inspect.custom || "inspect";
    function copyBuffer(src, target, offset) {
      Buffer2.prototype.copy.call(src, target, offset);
    }
    module2.exports = /* @__PURE__ */ function() {
      function BufferList() {
        _classCallCheck(this, BufferList);
        this.head = null;
        this.tail = null;
        this.length = 0;
      }
      _createClass(BufferList, [{
        key: "push",
        value: function push(v) {
          var entry = {
            data: v,
            next: null
          };
          if (this.length > 0)
            this.tail.next = entry;
          else
            this.head = entry;
          this.tail = entry;
          ++this.length;
        }
      }, {
        key: "unshift",
        value: function unshift(v) {
          var entry = {
            data: v,
            next: this.head
          };
          if (this.length === 0)
            this.tail = entry;
          this.head = entry;
          ++this.length;
        }
      }, {
        key: "shift",
        value: function shift() {
          if (this.length === 0)
            return;
          var ret = this.head.data;
          if (this.length === 1)
            this.head = this.tail = null;
          else
            this.head = this.head.next;
          --this.length;
          return ret;
        }
      }, {
        key: "clear",
        value: function clear() {
          this.head = this.tail = null;
          this.length = 0;
        }
      }, {
        key: "join",
        value: function join(s) {
          if (this.length === 0)
            return "";
          var p = this.head;
          var ret = "" + p.data;
          while (p = p.next) {
            ret += s + p.data;
          }
          return ret;
        }
      }, {
        key: "concat",
        value: function concat(n) {
          if (this.length === 0)
            return Buffer2.alloc(0);
          var ret = Buffer2.allocUnsafe(n >>> 0);
          var p = this.head;
          var i = 0;
          while (p) {
            copyBuffer(p.data, ret, i);
            i += p.data.length;
            p = p.next;
          }
          return ret;
        }
        // Consumes a specified amount of bytes or characters from the buffered data.
      }, {
        key: "consume",
        value: function consume(n, hasStrings) {
          var ret;
          if (n < this.head.data.length) {
            ret = this.head.data.slice(0, n);
            this.head.data = this.head.data.slice(n);
          } else if (n === this.head.data.length) {
            ret = this.shift();
          } else {
            ret = hasStrings ? this._getString(n) : this._getBuffer(n);
          }
          return ret;
        }
      }, {
        key: "first",
        value: function first2() {
          return this.head.data;
        }
        // Consumes a specified amount of characters from the buffered data.
      }, {
        key: "_getString",
        value: function _getString(n) {
          var p = this.head;
          var c = 1;
          var ret = p.data;
          n -= ret.length;
          while (p = p.next) {
            var str = p.data;
            var nb = n > str.length ? str.length : n;
            if (nb === str.length)
              ret += str;
            else
              ret += str.slice(0, n);
            n -= nb;
            if (n === 0) {
              if (nb === str.length) {
                ++c;
                if (p.next)
                  this.head = p.next;
                else
                  this.head = this.tail = null;
              } else {
                this.head = p;
                p.data = str.slice(nb);
              }
              break;
            }
            ++c;
          }
          this.length -= c;
          return ret;
        }
        // Consumes a specified amount of bytes from the buffered data.
      }, {
        key: "_getBuffer",
        value: function _getBuffer(n) {
          var ret = Buffer2.allocUnsafe(n);
          var p = this.head;
          var c = 1;
          p.data.copy(ret);
          n -= p.data.length;
          while (p = p.next) {
            var buf = p.data;
            var nb = n > buf.length ? buf.length : n;
            buf.copy(ret, ret.length - n, 0, nb);
            n -= nb;
            if (n === 0) {
              if (nb === buf.length) {
                ++c;
                if (p.next)
                  this.head = p.next;
                else
                  this.head = this.tail = null;
              } else {
                this.head = p;
                p.data = buf.slice(nb);
              }
              break;
            }
            ++c;
          }
          this.length -= c;
          return ret;
        }
        // Make sure the linked list only shows the minimal necessary information.
      }, {
        key: custom,
        value: function value2(_, options) {
          return inspect(this, _objectSpread({}, options, {
            // Only inspect one level.
            depth: 0,
            // It should not recurse.
            customInspect: false
          }));
        }
      }]);
      return BufferList;
    }();
  }
});

// node_modules/readable-stream/lib/internal/streams/destroy.js
var require_destroy = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/destroy.js"(exports, module2) {
    "use strict";
    function destroy(err, cb) {
      var _this = this;
      var readableDestroyed = this._readableState && this._readableState.destroyed;
      var writableDestroyed = this._writableState && this._writableState.destroyed;
      if (readableDestroyed || writableDestroyed) {
        if (cb) {
          cb(err);
        } else if (err) {
          if (!this._writableState) {
            process.nextTick(emitErrorNT, this, err);
          } else if (!this._writableState.errorEmitted) {
            this._writableState.errorEmitted = true;
            process.nextTick(emitErrorNT, this, err);
          }
        }
        return this;
      }
      if (this._readableState) {
        this._readableState.destroyed = true;
      }
      if (this._writableState) {
        this._writableState.destroyed = true;
      }
      this._destroy(err || null, function(err2) {
        if (!cb && err2) {
          if (!_this._writableState) {
            process.nextTick(emitErrorAndCloseNT, _this, err2);
          } else if (!_this._writableState.errorEmitted) {
            _this._writableState.errorEmitted = true;
            process.nextTick(emitErrorAndCloseNT, _this, err2);
          } else {
            process.nextTick(emitCloseNT, _this);
          }
        } else if (cb) {
          process.nextTick(emitCloseNT, _this);
          cb(err2);
        } else {
          process.nextTick(emitCloseNT, _this);
        }
      });
      return this;
    }
    function emitErrorAndCloseNT(self2, err) {
      emitErrorNT(self2, err);
      emitCloseNT(self2);
    }
    function emitCloseNT(self2) {
      if (self2._writableState && !self2._writableState.emitClose)
        return;
      if (self2._readableState && !self2._readableState.emitClose)
        return;
      self2.emit("close");
    }
    function undestroy() {
      if (this._readableState) {
        this._readableState.destroyed = false;
        this._readableState.reading = false;
        this._readableState.ended = false;
        this._readableState.endEmitted = false;
      }
      if (this._writableState) {
        this._writableState.destroyed = false;
        this._writableState.ended = false;
        this._writableState.ending = false;
        this._writableState.finalCalled = false;
        this._writableState.prefinished = false;
        this._writableState.finished = false;
        this._writableState.errorEmitted = false;
      }
    }
    function emitErrorNT(self2, err) {
      self2.emit("error", err);
    }
    function errorOrDestroy(stream, err) {
      var rState = stream._readableState;
      var wState = stream._writableState;
      if (rState && rState.autoDestroy || wState && wState.autoDestroy)
        stream.destroy(err);
      else
        stream.emit("error", err);
    }
    module2.exports = {
      destroy,
      undestroy,
      errorOrDestroy
    };
  }
});

// node_modules/readable-stream/errors.js
var require_errors = __commonJS({
  "node_modules/readable-stream/errors.js"(exports, module2) {
    "use strict";
    var codes = {};
    function createErrorType(code, message, Base) {
      if (!Base) {
        Base = Error;
      }
      function getMessage(arg1, arg2, arg3) {
        if (typeof message === "string") {
          return message;
        } else {
          return message(arg1, arg2, arg3);
        }
      }
      class NodeError extends Base {
        constructor(arg1, arg2, arg3) {
          super(getMessage(arg1, arg2, arg3));
        }
      }
      NodeError.prototype.name = Base.name;
      NodeError.prototype.code = code;
      codes[code] = NodeError;
    }
    function oneOf(expected, thing) {
      if (Array.isArray(expected)) {
        const len = expected.length;
        expected = expected.map((i) => String(i));
        if (len > 2) {
          return `one of ${thing} ${expected.slice(0, len - 1).join(", ")}, or ` + expected[len - 1];
        } else if (len === 2) {
          return `one of ${thing} ${expected[0]} or ${expected[1]}`;
        } else {
          return `of ${thing} ${expected[0]}`;
        }
      } else {
        return `of ${thing} ${String(expected)}`;
      }
    }
    function startsWith(str, search, pos) {
      return str.substr(!pos || pos < 0 ? 0 : +pos, search.length) === search;
    }
    function endsWith(str, search, this_len) {
      if (this_len === void 0 || this_len > str.length) {
        this_len = str.length;
      }
      return str.substring(this_len - search.length, this_len) === search;
    }
    function includes(str, search, start) {
      if (typeof start !== "number") {
        start = 0;
      }
      if (start + search.length > str.length) {
        return false;
      } else {
        return str.indexOf(search, start) !== -1;
      }
    }
    createErrorType("ERR_INVALID_OPT_VALUE", function(name, value2) {
      return 'The value "' + value2 + '" is invalid for option "' + name + '"';
    }, TypeError);
    createErrorType("ERR_INVALID_ARG_TYPE", function(name, expected, actual) {
      let determiner;
      if (typeof expected === "string" && startsWith(expected, "not ")) {
        determiner = "must not be";
        expected = expected.replace(/^not /, "");
      } else {
        determiner = "must be";
      }
      let msg;
      if (endsWith(name, " argument")) {
        msg = `The ${name} ${determiner} ${oneOf(expected, "type")}`;
      } else {
        const type = includes(name, ".") ? "property" : "argument";
        msg = `The "${name}" ${type} ${determiner} ${oneOf(expected, "type")}`;
      }
      msg += `. Received type ${typeof actual}`;
      return msg;
    }, TypeError);
    createErrorType("ERR_STREAM_PUSH_AFTER_EOF", "stream.push() after EOF");
    createErrorType("ERR_METHOD_NOT_IMPLEMENTED", function(name) {
      return "The " + name + " method is not implemented";
    });
    createErrorType("ERR_STREAM_PREMATURE_CLOSE", "Premature close");
    createErrorType("ERR_STREAM_DESTROYED", function(name) {
      return "Cannot call " + name + " after a stream was destroyed";
    });
    createErrorType("ERR_MULTIPLE_CALLBACK", "Callback called multiple times");
    createErrorType("ERR_STREAM_CANNOT_PIPE", "Cannot pipe, not readable");
    createErrorType("ERR_STREAM_WRITE_AFTER_END", "write after end");
    createErrorType("ERR_STREAM_NULL_VALUES", "May not write null values to stream", TypeError);
    createErrorType("ERR_UNKNOWN_ENCODING", function(arg) {
      return "Unknown encoding: " + arg;
    }, TypeError);
    createErrorType("ERR_STREAM_UNSHIFT_AFTER_END_EVENT", "stream.unshift() after end event");
    module2.exports.codes = codes;
  }
});

// node_modules/readable-stream/lib/internal/streams/state.js
var require_state = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/state.js"(exports, module2) {
    "use strict";
    var ERR_INVALID_OPT_VALUE = require_errors().codes.ERR_INVALID_OPT_VALUE;
    function highWaterMarkFrom(options, isDuplex, duplexKey) {
      return options.highWaterMark != null ? options.highWaterMark : isDuplex ? options[duplexKey] : null;
    }
    function getHighWaterMark(state, options, duplexKey, isDuplex) {
      var hwm = highWaterMarkFrom(options, isDuplex, duplexKey);
      if (hwm != null) {
        if (!(isFinite(hwm) && Math.floor(hwm) === hwm) || hwm < 0) {
          var name = isDuplex ? duplexKey : "highWaterMark";
          throw new ERR_INVALID_OPT_VALUE(name, hwm);
        }
        return Math.floor(hwm);
      }
      return state.objectMode ? 16 : 16 * 1024;
    }
    module2.exports = {
      getHighWaterMark
    };
  }
});

// node_modules/util-deprecate/node.js
var require_node = __commonJS({
  "node_modules/util-deprecate/node.js"(exports, module2) {
    module2.exports = require("util").deprecate;
  }
});

// node_modules/readable-stream/lib/_stream_writable.js
var require_stream_writable = __commonJS({
  "node_modules/readable-stream/lib/_stream_writable.js"(exports, module2) {
    "use strict";
    module2.exports = Writable;
    function CorkedRequest(state) {
      var _this = this;
      this.next = null;
      this.entry = null;
      this.finish = function() {
        onCorkedFinish(_this, state);
      };
    }
    var Duplex;
    Writable.WritableState = WritableState;
    var internalUtil = {
      deprecate: require_node()
    };
    var Stream = require_stream();
    var Buffer2 = require("buffer").Buffer;
    var OurUint8Array = global.Uint8Array || function() {
    };
    function _uint8ArrayToBuffer(chunk) {
      return Buffer2.from(chunk);
    }
    function _isUint8Array(obj) {
      return Buffer2.isBuffer(obj) || obj instanceof OurUint8Array;
    }
    var destroyImpl = require_destroy();
    var _require = require_state();
    var getHighWaterMark = _require.getHighWaterMark;
    var _require$codes = require_errors().codes;
    var ERR_INVALID_ARG_TYPE = _require$codes.ERR_INVALID_ARG_TYPE;
    var ERR_METHOD_NOT_IMPLEMENTED = _require$codes.ERR_METHOD_NOT_IMPLEMENTED;
    var ERR_MULTIPLE_CALLBACK = _require$codes.ERR_MULTIPLE_CALLBACK;
    var ERR_STREAM_CANNOT_PIPE = _require$codes.ERR_STREAM_CANNOT_PIPE;
    var ERR_STREAM_DESTROYED = _require$codes.ERR_STREAM_DESTROYED;
    var ERR_STREAM_NULL_VALUES = _require$codes.ERR_STREAM_NULL_VALUES;
    var ERR_STREAM_WRITE_AFTER_END = _require$codes.ERR_STREAM_WRITE_AFTER_END;
    var ERR_UNKNOWN_ENCODING = _require$codes.ERR_UNKNOWN_ENCODING;
    var errorOrDestroy = destroyImpl.errorOrDestroy;
    require_inherits()(Writable, Stream);
    function nop() {
    }
    function WritableState(options, stream, isDuplex) {
      Duplex = Duplex || require_stream_duplex();
      options = options || {};
      if (typeof isDuplex !== "boolean")
        isDuplex = stream instanceof Duplex;
      this.objectMode = !!options.objectMode;
      if (isDuplex)
        this.objectMode = this.objectMode || !!options.writableObjectMode;
      this.highWaterMark = getHighWaterMark(this, options, "writableHighWaterMark", isDuplex);
      this.finalCalled = false;
      this.needDrain = false;
      this.ending = false;
      this.ended = false;
      this.finished = false;
      this.destroyed = false;
      var noDecode = options.decodeStrings === false;
      this.decodeStrings = !noDecode;
      this.defaultEncoding = options.defaultEncoding || "utf8";
      this.length = 0;
      this.writing = false;
      this.corked = 0;
      this.sync = true;
      this.bufferProcessing = false;
      this.onwrite = function(er) {
        onwrite(stream, er);
      };
      this.writecb = null;
      this.writelen = 0;
      this.bufferedRequest = null;
      this.lastBufferedRequest = null;
      this.pendingcb = 0;
      this.prefinished = false;
      this.errorEmitted = false;
      this.emitClose = options.emitClose !== false;
      this.autoDestroy = !!options.autoDestroy;
      this.bufferedRequestCount = 0;
      this.corkedRequestsFree = new CorkedRequest(this);
    }
    WritableState.prototype.getBuffer = function getBuffer() {
      var current = this.bufferedRequest;
      var out = [];
      while (current) {
        out.push(current);
        current = current.next;
      }
      return out;
    };
    (function() {
      try {
        Object.defineProperty(WritableState.prototype, "buffer", {
          get: internalUtil.deprecate(function writableStateBufferGetter() {
            return this.getBuffer();
          }, "_writableState.buffer is deprecated. Use _writableState.getBuffer instead.", "DEP0003")
        });
      } catch (_) {
      }
    })();
    var realHasInstance;
    if (typeof Symbol === "function" && Symbol.hasInstance && typeof Function.prototype[Symbol.hasInstance] === "function") {
      realHasInstance = Function.prototype[Symbol.hasInstance];
      Object.defineProperty(Writable, Symbol.hasInstance, {
        value: function value2(object) {
          if (realHasInstance.call(this, object))
            return true;
          if (this !== Writable)
            return false;
          return object && object._writableState instanceof WritableState;
        }
      });
    } else {
      realHasInstance = function realHasInstance2(object) {
        return object instanceof this;
      };
    }
    function Writable(options) {
      Duplex = Duplex || require_stream_duplex();
      var isDuplex = this instanceof Duplex;
      if (!isDuplex && !realHasInstance.call(Writable, this))
        return new Writable(options);
      this._writableState = new WritableState(options, this, isDuplex);
      this.writable = true;
      if (options) {
        if (typeof options.write === "function")
          this._write = options.write;
        if (typeof options.writev === "function")
          this._writev = options.writev;
        if (typeof options.destroy === "function")
          this._destroy = options.destroy;
        if (typeof options.final === "function")
          this._final = options.final;
      }
      Stream.call(this);
    }
    Writable.prototype.pipe = function() {
      errorOrDestroy(this, new ERR_STREAM_CANNOT_PIPE());
    };
    function writeAfterEnd(stream, cb) {
      var er = new ERR_STREAM_WRITE_AFTER_END();
      errorOrDestroy(stream, er);
      process.nextTick(cb, er);
    }
    function validChunk(stream, state, chunk, cb) {
      var er;
      if (chunk === null) {
        er = new ERR_STREAM_NULL_VALUES();
      } else if (typeof chunk !== "string" && !state.objectMode) {
        er = new ERR_INVALID_ARG_TYPE("chunk", ["string", "Buffer"], chunk);
      }
      if (er) {
        errorOrDestroy(stream, er);
        process.nextTick(cb, er);
        return false;
      }
      return true;
    }
    Writable.prototype.write = function(chunk, encoding, cb) {
      var state = this._writableState;
      var ret = false;
      var isBuf = !state.objectMode && _isUint8Array(chunk);
      if (isBuf && !Buffer2.isBuffer(chunk)) {
        chunk = _uint8ArrayToBuffer(chunk);
      }
      if (typeof encoding === "function") {
        cb = encoding;
        encoding = null;
      }
      if (isBuf)
        encoding = "buffer";
      else if (!encoding)
        encoding = state.defaultEncoding;
      if (typeof cb !== "function")
        cb = nop;
      if (state.ending)
        writeAfterEnd(this, cb);
      else if (isBuf || validChunk(this, state, chunk, cb)) {
        state.pendingcb++;
        ret = writeOrBuffer(this, state, isBuf, chunk, encoding, cb);
      }
      return ret;
    };
    Writable.prototype.cork = function() {
      this._writableState.corked++;
    };
    Writable.prototype.uncork = function() {
      var state = this._writableState;
      if (state.corked) {
        state.corked--;
        if (!state.writing && !state.corked && !state.bufferProcessing && state.bufferedRequest)
          clearBuffer(this, state);
      }
    };
    Writable.prototype.setDefaultEncoding = function setDefaultEncoding(encoding) {
      if (typeof encoding === "string")
        encoding = encoding.toLowerCase();
      if (!(["hex", "utf8", "utf-8", "ascii", "binary", "base64", "ucs2", "ucs-2", "utf16le", "utf-16le", "raw"].indexOf((encoding + "").toLowerCase()) > -1))
        throw new ERR_UNKNOWN_ENCODING(encoding);
      this._writableState.defaultEncoding = encoding;
      return this;
    };
    Object.defineProperty(Writable.prototype, "writableBuffer", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState && this._writableState.getBuffer();
      }
    });
    function decodeChunk(state, chunk, encoding) {
      if (!state.objectMode && state.decodeStrings !== false && typeof chunk === "string") {
        chunk = Buffer2.from(chunk, encoding);
      }
      return chunk;
    }
    Object.defineProperty(Writable.prototype, "writableHighWaterMark", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState.highWaterMark;
      }
    });
    function writeOrBuffer(stream, state, isBuf, chunk, encoding, cb) {
      if (!isBuf) {
        var newChunk = decodeChunk(state, chunk, encoding);
        if (chunk !== newChunk) {
          isBuf = true;
          encoding = "buffer";
          chunk = newChunk;
        }
      }
      var len = state.objectMode ? 1 : chunk.length;
      state.length += len;
      var ret = state.length < state.highWaterMark;
      if (!ret)
        state.needDrain = true;
      if (state.writing || state.corked) {
        var last2 = state.lastBufferedRequest;
        state.lastBufferedRequest = {
          chunk,
          encoding,
          isBuf,
          callback: cb,
          next: null
        };
        if (last2) {
          last2.next = state.lastBufferedRequest;
        } else {
          state.bufferedRequest = state.lastBufferedRequest;
        }
        state.bufferedRequestCount += 1;
      } else {
        doWrite(stream, state, false, len, chunk, encoding, cb);
      }
      return ret;
    }
    function doWrite(stream, state, writev, len, chunk, encoding, cb) {
      state.writelen = len;
      state.writecb = cb;
      state.writing = true;
      state.sync = true;
      if (state.destroyed)
        state.onwrite(new ERR_STREAM_DESTROYED("write"));
      else if (writev)
        stream._writev(chunk, state.onwrite);
      else
        stream._write(chunk, encoding, state.onwrite);
      state.sync = false;
    }
    function onwriteError(stream, state, sync, er, cb) {
      --state.pendingcb;
      if (sync) {
        process.nextTick(cb, er);
        process.nextTick(finishMaybe, stream, state);
        stream._writableState.errorEmitted = true;
        errorOrDestroy(stream, er);
      } else {
        cb(er);
        stream._writableState.errorEmitted = true;
        errorOrDestroy(stream, er);
        finishMaybe(stream, state);
      }
    }
    function onwriteStateUpdate(state) {
      state.writing = false;
      state.writecb = null;
      state.length -= state.writelen;
      state.writelen = 0;
    }
    function onwrite(stream, er) {
      var state = stream._writableState;
      var sync = state.sync;
      var cb = state.writecb;
      if (typeof cb !== "function")
        throw new ERR_MULTIPLE_CALLBACK();
      onwriteStateUpdate(state);
      if (er)
        onwriteError(stream, state, sync, er, cb);
      else {
        var finished = needFinish(state) || stream.destroyed;
        if (!finished && !state.corked && !state.bufferProcessing && state.bufferedRequest) {
          clearBuffer(stream, state);
        }
        if (sync) {
          process.nextTick(afterWrite, stream, state, finished, cb);
        } else {
          afterWrite(stream, state, finished, cb);
        }
      }
    }
    function afterWrite(stream, state, finished, cb) {
      if (!finished)
        onwriteDrain(stream, state);
      state.pendingcb--;
      cb();
      finishMaybe(stream, state);
    }
    function onwriteDrain(stream, state) {
      if (state.length === 0 && state.needDrain) {
        state.needDrain = false;
        stream.emit("drain");
      }
    }
    function clearBuffer(stream, state) {
      state.bufferProcessing = true;
      var entry = state.bufferedRequest;
      if (stream._writev && entry && entry.next) {
        var l = state.bufferedRequestCount;
        var buffer = new Array(l);
        var holder = state.corkedRequestsFree;
        holder.entry = entry;
        var count = 0;
        var allBuffers = true;
        while (entry) {
          buffer[count] = entry;
          if (!entry.isBuf)
            allBuffers = false;
          entry = entry.next;
          count += 1;
        }
        buffer.allBuffers = allBuffers;
        doWrite(stream, state, true, state.length, buffer, "", holder.finish);
        state.pendingcb++;
        state.lastBufferedRequest = null;
        if (holder.next) {
          state.corkedRequestsFree = holder.next;
          holder.next = null;
        } else {
          state.corkedRequestsFree = new CorkedRequest(state);
        }
        state.bufferedRequestCount = 0;
      } else {
        while (entry) {
          var chunk = entry.chunk;
          var encoding = entry.encoding;
          var cb = entry.callback;
          var len = state.objectMode ? 1 : chunk.length;
          doWrite(stream, state, false, len, chunk, encoding, cb);
          entry = entry.next;
          state.bufferedRequestCount--;
          if (state.writing) {
            break;
          }
        }
        if (entry === null)
          state.lastBufferedRequest = null;
      }
      state.bufferedRequest = entry;
      state.bufferProcessing = false;
    }
    Writable.prototype._write = function(chunk, encoding, cb) {
      cb(new ERR_METHOD_NOT_IMPLEMENTED("_write()"));
    };
    Writable.prototype._writev = null;
    Writable.prototype.end = function(chunk, encoding, cb) {
      var state = this._writableState;
      if (typeof chunk === "function") {
        cb = chunk;
        chunk = null;
        encoding = null;
      } else if (typeof encoding === "function") {
        cb = encoding;
        encoding = null;
      }
      if (chunk !== null && chunk !== void 0)
        this.write(chunk, encoding);
      if (state.corked) {
        state.corked = 1;
        this.uncork();
      }
      if (!state.ending)
        endWritable(this, state, cb);
      return this;
    };
    Object.defineProperty(Writable.prototype, "writableLength", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState.length;
      }
    });
    function needFinish(state) {
      return state.ending && state.length === 0 && state.bufferedRequest === null && !state.finished && !state.writing;
    }
    function callFinal(stream, state) {
      stream._final(function(err) {
        state.pendingcb--;
        if (err) {
          errorOrDestroy(stream, err);
        }
        state.prefinished = true;
        stream.emit("prefinish");
        finishMaybe(stream, state);
      });
    }
    function prefinish(stream, state) {
      if (!state.prefinished && !state.finalCalled) {
        if (typeof stream._final === "function" && !state.destroyed) {
          state.pendingcb++;
          state.finalCalled = true;
          process.nextTick(callFinal, stream, state);
        } else {
          state.prefinished = true;
          stream.emit("prefinish");
        }
      }
    }
    function finishMaybe(stream, state) {
      var need = needFinish(state);
      if (need) {
        prefinish(stream, state);
        if (state.pendingcb === 0) {
          state.finished = true;
          stream.emit("finish");
          if (state.autoDestroy) {
            var rState = stream._readableState;
            if (!rState || rState.autoDestroy && rState.endEmitted) {
              stream.destroy();
            }
          }
        }
      }
      return need;
    }
    function endWritable(stream, state, cb) {
      state.ending = true;
      finishMaybe(stream, state);
      if (cb) {
        if (state.finished)
          process.nextTick(cb);
        else
          stream.once("finish", cb);
      }
      state.ended = true;
      stream.writable = false;
    }
    function onCorkedFinish(corkReq, state, err) {
      var entry = corkReq.entry;
      corkReq.entry = null;
      while (entry) {
        var cb = entry.callback;
        state.pendingcb--;
        cb(err);
        entry = entry.next;
      }
      state.corkedRequestsFree.next = corkReq;
    }
    Object.defineProperty(Writable.prototype, "destroyed", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        if (this._writableState === void 0) {
          return false;
        }
        return this._writableState.destroyed;
      },
      set: function set(value2) {
        if (!this._writableState) {
          return;
        }
        this._writableState.destroyed = value2;
      }
    });
    Writable.prototype.destroy = destroyImpl.destroy;
    Writable.prototype._undestroy = destroyImpl.undestroy;
    Writable.prototype._destroy = function(err, cb) {
      cb(err);
    };
  }
});

// node_modules/readable-stream/lib/_stream_duplex.js
var require_stream_duplex = __commonJS({
  "node_modules/readable-stream/lib/_stream_duplex.js"(exports, module2) {
    "use strict";
    var objectKeys = Object.keys || function(obj) {
      var keys4 = [];
      for (var key in obj) {
        keys4.push(key);
      }
      return keys4;
    };
    module2.exports = Duplex;
    var Readable = require_stream_readable();
    var Writable = require_stream_writable();
    require_inherits()(Duplex, Readable);
    {
      keys3 = objectKeys(Writable.prototype);
      for (v = 0; v < keys3.length; v++) {
        method = keys3[v];
        if (!Duplex.prototype[method])
          Duplex.prototype[method] = Writable.prototype[method];
      }
    }
    var keys3;
    var method;
    var v;
    function Duplex(options) {
      if (!(this instanceof Duplex))
        return new Duplex(options);
      Readable.call(this, options);
      Writable.call(this, options);
      this.allowHalfOpen = true;
      if (options) {
        if (options.readable === false)
          this.readable = false;
        if (options.writable === false)
          this.writable = false;
        if (options.allowHalfOpen === false) {
          this.allowHalfOpen = false;
          this.once("end", onend);
        }
      }
    }
    Object.defineProperty(Duplex.prototype, "writableHighWaterMark", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState.highWaterMark;
      }
    });
    Object.defineProperty(Duplex.prototype, "writableBuffer", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState && this._writableState.getBuffer();
      }
    });
    Object.defineProperty(Duplex.prototype, "writableLength", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._writableState.length;
      }
    });
    function onend() {
      if (this._writableState.ended)
        return;
      process.nextTick(onEndNT, this);
    }
    function onEndNT(self2) {
      self2.end();
    }
    Object.defineProperty(Duplex.prototype, "destroyed", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        if (this._readableState === void 0 || this._writableState === void 0) {
          return false;
        }
        return this._readableState.destroyed && this._writableState.destroyed;
      },
      set: function set(value2) {
        if (this._readableState === void 0 || this._writableState === void 0) {
          return;
        }
        this._readableState.destroyed = value2;
        this._writableState.destroyed = value2;
      }
    });
  }
});

// node_modules/safe-buffer/index.js
var require_safe_buffer = __commonJS({
  "node_modules/safe-buffer/index.js"(exports, module2) {
    var buffer = require("buffer");
    var Buffer2 = buffer.Buffer;
    function copyProps(src, dst) {
      for (var key in src) {
        dst[key] = src[key];
      }
    }
    if (Buffer2.from && Buffer2.alloc && Buffer2.allocUnsafe && Buffer2.allocUnsafeSlow) {
      module2.exports = buffer;
    } else {
      copyProps(buffer, exports);
      exports.Buffer = SafeBuffer;
    }
    function SafeBuffer(arg, encodingOrOffset, length) {
      return Buffer2(arg, encodingOrOffset, length);
    }
    SafeBuffer.prototype = Object.create(Buffer2.prototype);
    copyProps(Buffer2, SafeBuffer);
    SafeBuffer.from = function(arg, encodingOrOffset, length) {
      if (typeof arg === "number") {
        throw new TypeError("Argument must not be a number");
      }
      return Buffer2(arg, encodingOrOffset, length);
    };
    SafeBuffer.alloc = function(size, fill, encoding) {
      if (typeof size !== "number") {
        throw new TypeError("Argument must be a number");
      }
      var buf = Buffer2(size);
      if (fill !== void 0) {
        if (typeof encoding === "string") {
          buf.fill(fill, encoding);
        } else {
          buf.fill(fill);
        }
      } else {
        buf.fill(0);
      }
      return buf;
    };
    SafeBuffer.allocUnsafe = function(size) {
      if (typeof size !== "number") {
        throw new TypeError("Argument must be a number");
      }
      return Buffer2(size);
    };
    SafeBuffer.allocUnsafeSlow = function(size) {
      if (typeof size !== "number") {
        throw new TypeError("Argument must be a number");
      }
      return buffer.SlowBuffer(size);
    };
  }
});

// node_modules/string_decoder/lib/string_decoder.js
var require_string_decoder = __commonJS({
  "node_modules/string_decoder/lib/string_decoder.js"(exports) {
    "use strict";
    var Buffer2 = require_safe_buffer().Buffer;
    var isEncoding = Buffer2.isEncoding || function(encoding) {
      encoding = "" + encoding;
      switch (encoding && encoding.toLowerCase()) {
        case "hex":
        case "utf8":
        case "utf-8":
        case "ascii":
        case "binary":
        case "base64":
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
        case "raw":
          return true;
        default:
          return false;
      }
    };
    function _normalizeEncoding(enc) {
      if (!enc)
        return "utf8";
      var retried;
      while (true) {
        switch (enc) {
          case "utf8":
          case "utf-8":
            return "utf8";
          case "ucs2":
          case "ucs-2":
          case "utf16le":
          case "utf-16le":
            return "utf16le";
          case "latin1":
          case "binary":
            return "latin1";
          case "base64":
          case "ascii":
          case "hex":
            return enc;
          default:
            if (retried)
              return;
            enc = ("" + enc).toLowerCase();
            retried = true;
        }
      }
    }
    function normalizeEncoding(enc) {
      var nenc = _normalizeEncoding(enc);
      if (typeof nenc !== "string" && (Buffer2.isEncoding === isEncoding || !isEncoding(enc)))
        throw new Error("Unknown encoding: " + enc);
      return nenc || enc;
    }
    exports.StringDecoder = StringDecoder;
    function StringDecoder(encoding) {
      this.encoding = normalizeEncoding(encoding);
      var nb;
      switch (this.encoding) {
        case "utf16le":
          this.text = utf16Text;
          this.end = utf16End;
          nb = 4;
          break;
        case "utf8":
          this.fillLast = utf8FillLast;
          nb = 4;
          break;
        case "base64":
          this.text = base64Text;
          this.end = base64End;
          nb = 3;
          break;
        default:
          this.write = simpleWrite;
          this.end = simpleEnd;
          return;
      }
      this.lastNeed = 0;
      this.lastTotal = 0;
      this.lastChar = Buffer2.allocUnsafe(nb);
    }
    StringDecoder.prototype.write = function(buf) {
      if (buf.length === 0)
        return "";
      var r;
      var i;
      if (this.lastNeed) {
        r = this.fillLast(buf);
        if (r === void 0)
          return "";
        i = this.lastNeed;
        this.lastNeed = 0;
      } else {
        i = 0;
      }
      if (i < buf.length)
        return r ? r + this.text(buf, i) : this.text(buf, i);
      return r || "";
    };
    StringDecoder.prototype.end = utf8End;
    StringDecoder.prototype.text = utf8Text;
    StringDecoder.prototype.fillLast = function(buf) {
      if (this.lastNeed <= buf.length) {
        buf.copy(this.lastChar, this.lastTotal - this.lastNeed, 0, this.lastNeed);
        return this.lastChar.toString(this.encoding, 0, this.lastTotal);
      }
      buf.copy(this.lastChar, this.lastTotal - this.lastNeed, 0, buf.length);
      this.lastNeed -= buf.length;
    };
    function utf8CheckByte(byte) {
      if (byte <= 127)
        return 0;
      else if (byte >> 5 === 6)
        return 2;
      else if (byte >> 4 === 14)
        return 3;
      else if (byte >> 3 === 30)
        return 4;
      return byte >> 6 === 2 ? -1 : -2;
    }
    function utf8CheckIncomplete(self2, buf, i) {
      var j = buf.length - 1;
      if (j < i)
        return 0;
      var nb = utf8CheckByte(buf[j]);
      if (nb >= 0) {
        if (nb > 0)
          self2.lastNeed = nb - 1;
        return nb;
      }
      if (--j < i || nb === -2)
        return 0;
      nb = utf8CheckByte(buf[j]);
      if (nb >= 0) {
        if (nb > 0)
          self2.lastNeed = nb - 2;
        return nb;
      }
      if (--j < i || nb === -2)
        return 0;
      nb = utf8CheckByte(buf[j]);
      if (nb >= 0) {
        if (nb > 0) {
          if (nb === 2)
            nb = 0;
          else
            self2.lastNeed = nb - 3;
        }
        return nb;
      }
      return 0;
    }
    function utf8CheckExtraBytes(self2, buf, p) {
      if ((buf[0] & 192) !== 128) {
        self2.lastNeed = 0;
        return "\uFFFD";
      }
      if (self2.lastNeed > 1 && buf.length > 1) {
        if ((buf[1] & 192) !== 128) {
          self2.lastNeed = 1;
          return "\uFFFD";
        }
        if (self2.lastNeed > 2 && buf.length > 2) {
          if ((buf[2] & 192) !== 128) {
            self2.lastNeed = 2;
            return "\uFFFD";
          }
        }
      }
    }
    function utf8FillLast(buf) {
      var p = this.lastTotal - this.lastNeed;
      var r = utf8CheckExtraBytes(this, buf, p);
      if (r !== void 0)
        return r;
      if (this.lastNeed <= buf.length) {
        buf.copy(this.lastChar, p, 0, this.lastNeed);
        return this.lastChar.toString(this.encoding, 0, this.lastTotal);
      }
      buf.copy(this.lastChar, p, 0, buf.length);
      this.lastNeed -= buf.length;
    }
    function utf8Text(buf, i) {
      var total = utf8CheckIncomplete(this, buf, i);
      if (!this.lastNeed)
        return buf.toString("utf8", i);
      this.lastTotal = total;
      var end = buf.length - (total - this.lastNeed);
      buf.copy(this.lastChar, 0, end);
      return buf.toString("utf8", i, end);
    }
    function utf8End(buf) {
      var r = buf && buf.length ? this.write(buf) : "";
      if (this.lastNeed)
        return r + "\uFFFD";
      return r;
    }
    function utf16Text(buf, i) {
      if ((buf.length - i) % 2 === 0) {
        var r = buf.toString("utf16le", i);
        if (r) {
          var c = r.charCodeAt(r.length - 1);
          if (c >= 55296 && c <= 56319) {
            this.lastNeed = 2;
            this.lastTotal = 4;
            this.lastChar[0] = buf[buf.length - 2];
            this.lastChar[1] = buf[buf.length - 1];
            return r.slice(0, -1);
          }
        }
        return r;
      }
      this.lastNeed = 1;
      this.lastTotal = 2;
      this.lastChar[0] = buf[buf.length - 1];
      return buf.toString("utf16le", i, buf.length - 1);
    }
    function utf16End(buf) {
      var r = buf && buf.length ? this.write(buf) : "";
      if (this.lastNeed) {
        var end = this.lastTotal - this.lastNeed;
        return r + this.lastChar.toString("utf16le", 0, end);
      }
      return r;
    }
    function base64Text(buf, i) {
      var n = (buf.length - i) % 3;
      if (n === 0)
        return buf.toString("base64", i);
      this.lastNeed = 3 - n;
      this.lastTotal = 3;
      if (n === 1) {
        this.lastChar[0] = buf[buf.length - 1];
      } else {
        this.lastChar[0] = buf[buf.length - 2];
        this.lastChar[1] = buf[buf.length - 1];
      }
      return buf.toString("base64", i, buf.length - n);
    }
    function base64End(buf) {
      var r = buf && buf.length ? this.write(buf) : "";
      if (this.lastNeed)
        return r + this.lastChar.toString("base64", 0, 3 - this.lastNeed);
      return r;
    }
    function simpleWrite(buf) {
      return buf.toString(this.encoding);
    }
    function simpleEnd(buf) {
      return buf && buf.length ? this.write(buf) : "";
    }
  }
});

// node_modules/readable-stream/lib/internal/streams/end-of-stream.js
var require_end_of_stream = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/end-of-stream.js"(exports, module2) {
    "use strict";
    var ERR_STREAM_PREMATURE_CLOSE = require_errors().codes.ERR_STREAM_PREMATURE_CLOSE;
    function once(callback) {
      var called = false;
      return function() {
        if (called)
          return;
        called = true;
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }
        callback.apply(this, args);
      };
    }
    function noop() {
    }
    function isRequest(stream) {
      return stream.setHeader && typeof stream.abort === "function";
    }
    function eos(stream, opts, callback) {
      if (typeof opts === "function")
        return eos(stream, null, opts);
      if (!opts)
        opts = {};
      callback = once(callback || noop);
      var readable = opts.readable || opts.readable !== false && stream.readable;
      var writable = opts.writable || opts.writable !== false && stream.writable;
      var onlegacyfinish = function onlegacyfinish2() {
        if (!stream.writable)
          onfinish();
      };
      var writableEnded = stream._writableState && stream._writableState.finished;
      var onfinish = function onfinish2() {
        writable = false;
        writableEnded = true;
        if (!readable)
          callback.call(stream);
      };
      var readableEnded = stream._readableState && stream._readableState.endEmitted;
      var onend = function onend2() {
        readable = false;
        readableEnded = true;
        if (!writable)
          callback.call(stream);
      };
      var onerror = function onerror2(err) {
        callback.call(stream, err);
      };
      var onclose = function onclose2() {
        var err;
        if (readable && !readableEnded) {
          if (!stream._readableState || !stream._readableState.ended)
            err = new ERR_STREAM_PREMATURE_CLOSE();
          return callback.call(stream, err);
        }
        if (writable && !writableEnded) {
          if (!stream._writableState || !stream._writableState.ended)
            err = new ERR_STREAM_PREMATURE_CLOSE();
          return callback.call(stream, err);
        }
      };
      var onrequest = function onrequest2() {
        stream.req.on("finish", onfinish);
      };
      if (isRequest(stream)) {
        stream.on("complete", onfinish);
        stream.on("abort", onclose);
        if (stream.req)
          onrequest();
        else
          stream.on("request", onrequest);
      } else if (writable && !stream._writableState) {
        stream.on("end", onlegacyfinish);
        stream.on("close", onlegacyfinish);
      }
      stream.on("end", onend);
      stream.on("finish", onfinish);
      if (opts.error !== false)
        stream.on("error", onerror);
      stream.on("close", onclose);
      return function() {
        stream.removeListener("complete", onfinish);
        stream.removeListener("abort", onclose);
        stream.removeListener("request", onrequest);
        if (stream.req)
          stream.req.removeListener("finish", onfinish);
        stream.removeListener("end", onlegacyfinish);
        stream.removeListener("close", onlegacyfinish);
        stream.removeListener("finish", onfinish);
        stream.removeListener("end", onend);
        stream.removeListener("error", onerror);
        stream.removeListener("close", onclose);
      };
    }
    module2.exports = eos;
  }
});

// node_modules/readable-stream/lib/internal/streams/async_iterator.js
var require_async_iterator = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/async_iterator.js"(exports, module2) {
    "use strict";
    var _Object$setPrototypeO;
    function _defineProperty(obj, key, value2) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value2, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value2;
      }
      return obj;
    }
    var finished = require_end_of_stream();
    var kLastResolve = Symbol("lastResolve");
    var kLastReject = Symbol("lastReject");
    var kError = Symbol("error");
    var kEnded = Symbol("ended");
    var kLastPromise = Symbol("lastPromise");
    var kHandlePromise = Symbol("handlePromise");
    var kStream = Symbol("stream");
    function createIterResult(value2, done) {
      return {
        value: value2,
        done
      };
    }
    function readAndResolve(iter) {
      var resolve = iter[kLastResolve];
      if (resolve !== null) {
        var data = iter[kStream].read();
        if (data !== null) {
          iter[kLastPromise] = null;
          iter[kLastResolve] = null;
          iter[kLastReject] = null;
          resolve(createIterResult(data, false));
        }
      }
    }
    function onReadable(iter) {
      process.nextTick(readAndResolve, iter);
    }
    function wrapForNext(lastPromise, iter) {
      return function(resolve, reject) {
        lastPromise.then(function() {
          if (iter[kEnded]) {
            resolve(createIterResult(void 0, true));
            return;
          }
          iter[kHandlePromise](resolve, reject);
        }, reject);
      };
    }
    var AsyncIteratorPrototype = Object.getPrototypeOf(function() {
    });
    var ReadableStreamAsyncIteratorPrototype = Object.setPrototypeOf((_Object$setPrototypeO = {
      get stream() {
        return this[kStream];
      },
      next: function next() {
        var _this = this;
        var error = this[kError];
        if (error !== null) {
          return Promise.reject(error);
        }
        if (this[kEnded]) {
          return Promise.resolve(createIterResult(void 0, true));
        }
        if (this[kStream].destroyed) {
          return new Promise(function(resolve, reject) {
            process.nextTick(function() {
              if (_this[kError]) {
                reject(_this[kError]);
              } else {
                resolve(createIterResult(void 0, true));
              }
            });
          });
        }
        var lastPromise = this[kLastPromise];
        var promise;
        if (lastPromise) {
          promise = new Promise(wrapForNext(lastPromise, this));
        } else {
          var data = this[kStream].read();
          if (data !== null) {
            return Promise.resolve(createIterResult(data, false));
          }
          promise = new Promise(this[kHandlePromise]);
        }
        this[kLastPromise] = promise;
        return promise;
      }
    }, _defineProperty(_Object$setPrototypeO, Symbol.asyncIterator, function() {
      return this;
    }), _defineProperty(_Object$setPrototypeO, "return", function _return() {
      var _this2 = this;
      return new Promise(function(resolve, reject) {
        _this2[kStream].destroy(null, function(err) {
          if (err) {
            reject(err);
            return;
          }
          resolve(createIterResult(void 0, true));
        });
      });
    }), _Object$setPrototypeO), AsyncIteratorPrototype);
    var createReadableStreamAsyncIterator = function createReadableStreamAsyncIterator2(stream) {
      var _Object$create;
      var iterator = Object.create(ReadableStreamAsyncIteratorPrototype, (_Object$create = {}, _defineProperty(_Object$create, kStream, {
        value: stream,
        writable: true
      }), _defineProperty(_Object$create, kLastResolve, {
        value: null,
        writable: true
      }), _defineProperty(_Object$create, kLastReject, {
        value: null,
        writable: true
      }), _defineProperty(_Object$create, kError, {
        value: null,
        writable: true
      }), _defineProperty(_Object$create, kEnded, {
        value: stream._readableState.endEmitted,
        writable: true
      }), _defineProperty(_Object$create, kHandlePromise, {
        value: function value2(resolve, reject) {
          var data = iterator[kStream].read();
          if (data) {
            iterator[kLastPromise] = null;
            iterator[kLastResolve] = null;
            iterator[kLastReject] = null;
            resolve(createIterResult(data, false));
          } else {
            iterator[kLastResolve] = resolve;
            iterator[kLastReject] = reject;
          }
        },
        writable: true
      }), _Object$create));
      iterator[kLastPromise] = null;
      finished(stream, function(err) {
        if (err && err.code !== "ERR_STREAM_PREMATURE_CLOSE") {
          var reject = iterator[kLastReject];
          if (reject !== null) {
            iterator[kLastPromise] = null;
            iterator[kLastResolve] = null;
            iterator[kLastReject] = null;
            reject(err);
          }
          iterator[kError] = err;
          return;
        }
        var resolve = iterator[kLastResolve];
        if (resolve !== null) {
          iterator[kLastPromise] = null;
          iterator[kLastResolve] = null;
          iterator[kLastReject] = null;
          resolve(createIterResult(void 0, true));
        }
        iterator[kEnded] = true;
      });
      stream.on("readable", onReadable.bind(null, iterator));
      return iterator;
    };
    module2.exports = createReadableStreamAsyncIterator;
  }
});

// node_modules/readable-stream/lib/internal/streams/from.js
var require_from = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/from.js"(exports, module2) {
    "use strict";
    function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    function ownKeys(object, enumerableOnly) {
      var keys3 = Object.keys(object);
      if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);
        if (enumerableOnly)
          symbols = symbols.filter(function(sym) {
            return Object.getOwnPropertyDescriptor(object, sym).enumerable;
          });
        keys3.push.apply(keys3, symbols);
      }
      return keys3;
    }
    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};
        if (i % 2) {
          ownKeys(Object(source), true).forEach(function(key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function(key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }
      return target;
    }
    function _defineProperty(obj, key, value2) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value2, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value2;
      }
      return obj;
    }
    var ERR_INVALID_ARG_TYPE = require_errors().codes.ERR_INVALID_ARG_TYPE;
    function from(Readable, iterable, opts) {
      var iterator;
      if (iterable && typeof iterable.next === "function") {
        iterator = iterable;
      } else if (iterable && iterable[Symbol.asyncIterator])
        iterator = iterable[Symbol.asyncIterator]();
      else if (iterable && iterable[Symbol.iterator])
        iterator = iterable[Symbol.iterator]();
      else
        throw new ERR_INVALID_ARG_TYPE("iterable", ["Iterable"], iterable);
      var readable = new Readable(_objectSpread({
        objectMode: true
      }, opts));
      var reading = false;
      readable._read = function() {
        if (!reading) {
          reading = true;
          next();
        }
      };
      function next() {
        return _next2.apply(this, arguments);
      }
      function _next2() {
        _next2 = _asyncToGenerator(function* () {
          try {
            var _ref = yield iterator.next(), value2 = _ref.value, done = _ref.done;
            if (done) {
              readable.push(null);
            } else if (readable.push(yield value2)) {
              next();
            } else {
              reading = false;
            }
          } catch (err) {
            readable.destroy(err);
          }
        });
        return _next2.apply(this, arguments);
      }
      return readable;
    }
    module2.exports = from;
  }
});

// node_modules/readable-stream/lib/_stream_readable.js
var require_stream_readable = __commonJS({
  "node_modules/readable-stream/lib/_stream_readable.js"(exports, module2) {
    "use strict";
    module2.exports = Readable;
    var Duplex;
    Readable.ReadableState = ReadableState;
    var EE = require("events").EventEmitter;
    var EElistenerCount = function EElistenerCount2(emitter, type) {
      return emitter.listeners(type).length;
    };
    var Stream = require_stream();
    var Buffer2 = require("buffer").Buffer;
    var OurUint8Array = global.Uint8Array || function() {
    };
    function _uint8ArrayToBuffer(chunk) {
      return Buffer2.from(chunk);
    }
    function _isUint8Array(obj) {
      return Buffer2.isBuffer(obj) || obj instanceof OurUint8Array;
    }
    var debugUtil = require("util");
    var debug;
    if (debugUtil && debugUtil.debuglog) {
      debug = debugUtil.debuglog("stream");
    } else {
      debug = function debug2() {
      };
    }
    var BufferList = require_buffer_list();
    var destroyImpl = require_destroy();
    var _require = require_state();
    var getHighWaterMark = _require.getHighWaterMark;
    var _require$codes = require_errors().codes;
    var ERR_INVALID_ARG_TYPE = _require$codes.ERR_INVALID_ARG_TYPE;
    var ERR_STREAM_PUSH_AFTER_EOF = _require$codes.ERR_STREAM_PUSH_AFTER_EOF;
    var ERR_METHOD_NOT_IMPLEMENTED = _require$codes.ERR_METHOD_NOT_IMPLEMENTED;
    var ERR_STREAM_UNSHIFT_AFTER_END_EVENT = _require$codes.ERR_STREAM_UNSHIFT_AFTER_END_EVENT;
    var StringDecoder;
    var createReadableStreamAsyncIterator;
    var from;
    require_inherits()(Readable, Stream);
    var errorOrDestroy = destroyImpl.errorOrDestroy;
    var kProxyEvents = ["error", "close", "destroy", "pause", "resume"];
    function prependListener(emitter, event, fn) {
      if (typeof emitter.prependListener === "function")
        return emitter.prependListener(event, fn);
      if (!emitter._events || !emitter._events[event])
        emitter.on(event, fn);
      else if (Array.isArray(emitter._events[event]))
        emitter._events[event].unshift(fn);
      else
        emitter._events[event] = [fn, emitter._events[event]];
    }
    function ReadableState(options, stream, isDuplex) {
      Duplex = Duplex || require_stream_duplex();
      options = options || {};
      if (typeof isDuplex !== "boolean")
        isDuplex = stream instanceof Duplex;
      this.objectMode = !!options.objectMode;
      if (isDuplex)
        this.objectMode = this.objectMode || !!options.readableObjectMode;
      this.highWaterMark = getHighWaterMark(this, options, "readableHighWaterMark", isDuplex);
      this.buffer = new BufferList();
      this.length = 0;
      this.pipes = null;
      this.pipesCount = 0;
      this.flowing = null;
      this.ended = false;
      this.endEmitted = false;
      this.reading = false;
      this.sync = true;
      this.needReadable = false;
      this.emittedReadable = false;
      this.readableListening = false;
      this.resumeScheduled = false;
      this.paused = true;
      this.emitClose = options.emitClose !== false;
      this.autoDestroy = !!options.autoDestroy;
      this.destroyed = false;
      this.defaultEncoding = options.defaultEncoding || "utf8";
      this.awaitDrain = 0;
      this.readingMore = false;
      this.decoder = null;
      this.encoding = null;
      if (options.encoding) {
        if (!StringDecoder)
          StringDecoder = require_string_decoder().StringDecoder;
        this.decoder = new StringDecoder(options.encoding);
        this.encoding = options.encoding;
      }
    }
    function Readable(options) {
      Duplex = Duplex || require_stream_duplex();
      if (!(this instanceof Readable))
        return new Readable(options);
      var isDuplex = this instanceof Duplex;
      this._readableState = new ReadableState(options, this, isDuplex);
      this.readable = true;
      if (options) {
        if (typeof options.read === "function")
          this._read = options.read;
        if (typeof options.destroy === "function")
          this._destroy = options.destroy;
      }
      Stream.call(this);
    }
    Object.defineProperty(Readable.prototype, "destroyed", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        if (this._readableState === void 0) {
          return false;
        }
        return this._readableState.destroyed;
      },
      set: function set(value2) {
        if (!this._readableState) {
          return;
        }
        this._readableState.destroyed = value2;
      }
    });
    Readable.prototype.destroy = destroyImpl.destroy;
    Readable.prototype._undestroy = destroyImpl.undestroy;
    Readable.prototype._destroy = function(err, cb) {
      cb(err);
    };
    Readable.prototype.push = function(chunk, encoding) {
      var state = this._readableState;
      var skipChunkCheck;
      if (!state.objectMode) {
        if (typeof chunk === "string") {
          encoding = encoding || state.defaultEncoding;
          if (encoding !== state.encoding) {
            chunk = Buffer2.from(chunk, encoding);
            encoding = "";
          }
          skipChunkCheck = true;
        }
      } else {
        skipChunkCheck = true;
      }
      return readableAddChunk(this, chunk, encoding, false, skipChunkCheck);
    };
    Readable.prototype.unshift = function(chunk) {
      return readableAddChunk(this, chunk, null, true, false);
    };
    function readableAddChunk(stream, chunk, encoding, addToFront, skipChunkCheck) {
      debug("readableAddChunk", chunk);
      var state = stream._readableState;
      if (chunk === null) {
        state.reading = false;
        onEofChunk(stream, state);
      } else {
        var er;
        if (!skipChunkCheck)
          er = chunkInvalid(state, chunk);
        if (er) {
          errorOrDestroy(stream, er);
        } else if (state.objectMode || chunk && chunk.length > 0) {
          if (typeof chunk !== "string" && !state.objectMode && Object.getPrototypeOf(chunk) !== Buffer2.prototype) {
            chunk = _uint8ArrayToBuffer(chunk);
          }
          if (addToFront) {
            if (state.endEmitted)
              errorOrDestroy(stream, new ERR_STREAM_UNSHIFT_AFTER_END_EVENT());
            else
              addChunk(stream, state, chunk, true);
          } else if (state.ended) {
            errorOrDestroy(stream, new ERR_STREAM_PUSH_AFTER_EOF());
          } else if (state.destroyed) {
            return false;
          } else {
            state.reading = false;
            if (state.decoder && !encoding) {
              chunk = state.decoder.write(chunk);
              if (state.objectMode || chunk.length !== 0)
                addChunk(stream, state, chunk, false);
              else
                maybeReadMore(stream, state);
            } else {
              addChunk(stream, state, chunk, false);
            }
          }
        } else if (!addToFront) {
          state.reading = false;
          maybeReadMore(stream, state);
        }
      }
      return !state.ended && (state.length < state.highWaterMark || state.length === 0);
    }
    function addChunk(stream, state, chunk, addToFront) {
      if (state.flowing && state.length === 0 && !state.sync) {
        state.awaitDrain = 0;
        stream.emit("data", chunk);
      } else {
        state.length += state.objectMode ? 1 : chunk.length;
        if (addToFront)
          state.buffer.unshift(chunk);
        else
          state.buffer.push(chunk);
        if (state.needReadable)
          emitReadable(stream);
      }
      maybeReadMore(stream, state);
    }
    function chunkInvalid(state, chunk) {
      var er;
      if (!_isUint8Array(chunk) && typeof chunk !== "string" && chunk !== void 0 && !state.objectMode) {
        er = new ERR_INVALID_ARG_TYPE("chunk", ["string", "Buffer", "Uint8Array"], chunk);
      }
      return er;
    }
    Readable.prototype.isPaused = function() {
      return this._readableState.flowing === false;
    };
    Readable.prototype.setEncoding = function(enc) {
      if (!StringDecoder)
        StringDecoder = require_string_decoder().StringDecoder;
      var decoder = new StringDecoder(enc);
      this._readableState.decoder = decoder;
      this._readableState.encoding = this._readableState.decoder.encoding;
      var p = this._readableState.buffer.head;
      var content = "";
      while (p !== null) {
        content += decoder.write(p.data);
        p = p.next;
      }
      this._readableState.buffer.clear();
      if (content !== "")
        this._readableState.buffer.push(content);
      this._readableState.length = content.length;
      return this;
    };
    var MAX_HWM = 1073741824;
    function computeNewHighWaterMark(n) {
      if (n >= MAX_HWM) {
        n = MAX_HWM;
      } else {
        n--;
        n |= n >>> 1;
        n |= n >>> 2;
        n |= n >>> 4;
        n |= n >>> 8;
        n |= n >>> 16;
        n++;
      }
      return n;
    }
    function howMuchToRead(n, state) {
      if (n <= 0 || state.length === 0 && state.ended)
        return 0;
      if (state.objectMode)
        return 1;
      if (n !== n) {
        if (state.flowing && state.length)
          return state.buffer.head.data.length;
        else
          return state.length;
      }
      if (n > state.highWaterMark)
        state.highWaterMark = computeNewHighWaterMark(n);
      if (n <= state.length)
        return n;
      if (!state.ended) {
        state.needReadable = true;
        return 0;
      }
      return state.length;
    }
    Readable.prototype.read = function(n) {
      debug("read", n);
      n = parseInt(n, 10);
      var state = this._readableState;
      var nOrig = n;
      if (n !== 0)
        state.emittedReadable = false;
      if (n === 0 && state.needReadable && ((state.highWaterMark !== 0 ? state.length >= state.highWaterMark : state.length > 0) || state.ended)) {
        debug("read: emitReadable", state.length, state.ended);
        if (state.length === 0 && state.ended)
          endReadable(this);
        else
          emitReadable(this);
        return null;
      }
      n = howMuchToRead(n, state);
      if (n === 0 && state.ended) {
        if (state.length === 0)
          endReadable(this);
        return null;
      }
      var doRead = state.needReadable;
      debug("need readable", doRead);
      if (state.length === 0 || state.length - n < state.highWaterMark) {
        doRead = true;
        debug("length less than watermark", doRead);
      }
      if (state.ended || state.reading) {
        doRead = false;
        debug("reading or ended", doRead);
      } else if (doRead) {
        debug("do read");
        state.reading = true;
        state.sync = true;
        if (state.length === 0)
          state.needReadable = true;
        this._read(state.highWaterMark);
        state.sync = false;
        if (!state.reading)
          n = howMuchToRead(nOrig, state);
      }
      var ret;
      if (n > 0)
        ret = fromList(n, state);
      else
        ret = null;
      if (ret === null) {
        state.needReadable = state.length <= state.highWaterMark;
        n = 0;
      } else {
        state.length -= n;
        state.awaitDrain = 0;
      }
      if (state.length === 0) {
        if (!state.ended)
          state.needReadable = true;
        if (nOrig !== n && state.ended)
          endReadable(this);
      }
      if (ret !== null)
        this.emit("data", ret);
      return ret;
    };
    function onEofChunk(stream, state) {
      debug("onEofChunk");
      if (state.ended)
        return;
      if (state.decoder) {
        var chunk = state.decoder.end();
        if (chunk && chunk.length) {
          state.buffer.push(chunk);
          state.length += state.objectMode ? 1 : chunk.length;
        }
      }
      state.ended = true;
      if (state.sync) {
        emitReadable(stream);
      } else {
        state.needReadable = false;
        if (!state.emittedReadable) {
          state.emittedReadable = true;
          emitReadable_(stream);
        }
      }
    }
    function emitReadable(stream) {
      var state = stream._readableState;
      debug("emitReadable", state.needReadable, state.emittedReadable);
      state.needReadable = false;
      if (!state.emittedReadable) {
        debug("emitReadable", state.flowing);
        state.emittedReadable = true;
        process.nextTick(emitReadable_, stream);
      }
    }
    function emitReadable_(stream) {
      var state = stream._readableState;
      debug("emitReadable_", state.destroyed, state.length, state.ended);
      if (!state.destroyed && (state.length || state.ended)) {
        stream.emit("readable");
        state.emittedReadable = false;
      }
      state.needReadable = !state.flowing && !state.ended && state.length <= state.highWaterMark;
      flow(stream);
    }
    function maybeReadMore(stream, state) {
      if (!state.readingMore) {
        state.readingMore = true;
        process.nextTick(maybeReadMore_, stream, state);
      }
    }
    function maybeReadMore_(stream, state) {
      while (!state.reading && !state.ended && (state.length < state.highWaterMark || state.flowing && state.length === 0)) {
        var len = state.length;
        debug("maybeReadMore read 0");
        stream.read(0);
        if (len === state.length)
          break;
      }
      state.readingMore = false;
    }
    Readable.prototype._read = function(n) {
      errorOrDestroy(this, new ERR_METHOD_NOT_IMPLEMENTED("_read()"));
    };
    Readable.prototype.pipe = function(dest, pipeOpts) {
      var src = this;
      var state = this._readableState;
      switch (state.pipesCount) {
        case 0:
          state.pipes = dest;
          break;
        case 1:
          state.pipes = [state.pipes, dest];
          break;
        default:
          state.pipes.push(dest);
          break;
      }
      state.pipesCount += 1;
      debug("pipe count=%d opts=%j", state.pipesCount, pipeOpts);
      var doEnd = (!pipeOpts || pipeOpts.end !== false) && dest !== process.stdout && dest !== process.stderr;
      var endFn = doEnd ? onend : unpipe;
      if (state.endEmitted)
        process.nextTick(endFn);
      else
        src.once("end", endFn);
      dest.on("unpipe", onunpipe);
      function onunpipe(readable, unpipeInfo) {
        debug("onunpipe");
        if (readable === src) {
          if (unpipeInfo && unpipeInfo.hasUnpiped === false) {
            unpipeInfo.hasUnpiped = true;
            cleanup();
          }
        }
      }
      function onend() {
        debug("onend");
        dest.end();
      }
      var ondrain = pipeOnDrain(src);
      dest.on("drain", ondrain);
      var cleanedUp = false;
      function cleanup() {
        debug("cleanup");
        dest.removeListener("close", onclose);
        dest.removeListener("finish", onfinish);
        dest.removeListener("drain", ondrain);
        dest.removeListener("error", onerror);
        dest.removeListener("unpipe", onunpipe);
        src.removeListener("end", onend);
        src.removeListener("end", unpipe);
        src.removeListener("data", ondata);
        cleanedUp = true;
        if (state.awaitDrain && (!dest._writableState || dest._writableState.needDrain))
          ondrain();
      }
      src.on("data", ondata);
      function ondata(chunk) {
        debug("ondata");
        var ret = dest.write(chunk);
        debug("dest.write", ret);
        if (ret === false) {
          if ((state.pipesCount === 1 && state.pipes === dest || state.pipesCount > 1 && indexOf(state.pipes, dest) !== -1) && !cleanedUp) {
            debug("false write response, pause", state.awaitDrain);
            state.awaitDrain++;
          }
          src.pause();
        }
      }
      function onerror(er) {
        debug("onerror", er);
        unpipe();
        dest.removeListener("error", onerror);
        if (EElistenerCount(dest, "error") === 0)
          errorOrDestroy(dest, er);
      }
      prependListener(dest, "error", onerror);
      function onclose() {
        dest.removeListener("finish", onfinish);
        unpipe();
      }
      dest.once("close", onclose);
      function onfinish() {
        debug("onfinish");
        dest.removeListener("close", onclose);
        unpipe();
      }
      dest.once("finish", onfinish);
      function unpipe() {
        debug("unpipe");
        src.unpipe(dest);
      }
      dest.emit("pipe", src);
      if (!state.flowing) {
        debug("pipe resume");
        src.resume();
      }
      return dest;
    };
    function pipeOnDrain(src) {
      return function pipeOnDrainFunctionResult() {
        var state = src._readableState;
        debug("pipeOnDrain", state.awaitDrain);
        if (state.awaitDrain)
          state.awaitDrain--;
        if (state.awaitDrain === 0 && EElistenerCount(src, "data")) {
          state.flowing = true;
          flow(src);
        }
      };
    }
    Readable.prototype.unpipe = function(dest) {
      var state = this._readableState;
      var unpipeInfo = {
        hasUnpiped: false
      };
      if (state.pipesCount === 0)
        return this;
      if (state.pipesCount === 1) {
        if (dest && dest !== state.pipes)
          return this;
        if (!dest)
          dest = state.pipes;
        state.pipes = null;
        state.pipesCount = 0;
        state.flowing = false;
        if (dest)
          dest.emit("unpipe", this, unpipeInfo);
        return this;
      }
      if (!dest) {
        var dests = state.pipes;
        var len = state.pipesCount;
        state.pipes = null;
        state.pipesCount = 0;
        state.flowing = false;
        for (var i = 0; i < len; i++) {
          dests[i].emit("unpipe", this, {
            hasUnpiped: false
          });
        }
        return this;
      }
      var index = indexOf(state.pipes, dest);
      if (index === -1)
        return this;
      state.pipes.splice(index, 1);
      state.pipesCount -= 1;
      if (state.pipesCount === 1)
        state.pipes = state.pipes[0];
      dest.emit("unpipe", this, unpipeInfo);
      return this;
    };
    Readable.prototype.on = function(ev, fn) {
      var res = Stream.prototype.on.call(this, ev, fn);
      var state = this._readableState;
      if (ev === "data") {
        state.readableListening = this.listenerCount("readable") > 0;
        if (state.flowing !== false)
          this.resume();
      } else if (ev === "readable") {
        if (!state.endEmitted && !state.readableListening) {
          state.readableListening = state.needReadable = true;
          state.flowing = false;
          state.emittedReadable = false;
          debug("on readable", state.length, state.reading);
          if (state.length) {
            emitReadable(this);
          } else if (!state.reading) {
            process.nextTick(nReadingNextTick, this);
          }
        }
      }
      return res;
    };
    Readable.prototype.addListener = Readable.prototype.on;
    Readable.prototype.removeListener = function(ev, fn) {
      var res = Stream.prototype.removeListener.call(this, ev, fn);
      if (ev === "readable") {
        process.nextTick(updateReadableListening, this);
      }
      return res;
    };
    Readable.prototype.removeAllListeners = function(ev) {
      var res = Stream.prototype.removeAllListeners.apply(this, arguments);
      if (ev === "readable" || ev === void 0) {
        process.nextTick(updateReadableListening, this);
      }
      return res;
    };
    function updateReadableListening(self2) {
      var state = self2._readableState;
      state.readableListening = self2.listenerCount("readable") > 0;
      if (state.resumeScheduled && !state.paused) {
        state.flowing = true;
      } else if (self2.listenerCount("data") > 0) {
        self2.resume();
      }
    }
    function nReadingNextTick(self2) {
      debug("readable nexttick read 0");
      self2.read(0);
    }
    Readable.prototype.resume = function() {
      var state = this._readableState;
      if (!state.flowing) {
        debug("resume");
        state.flowing = !state.readableListening;
        resume(this, state);
      }
      state.paused = false;
      return this;
    };
    function resume(stream, state) {
      if (!state.resumeScheduled) {
        state.resumeScheduled = true;
        process.nextTick(resume_, stream, state);
      }
    }
    function resume_(stream, state) {
      debug("resume", state.reading);
      if (!state.reading) {
        stream.read(0);
      }
      state.resumeScheduled = false;
      stream.emit("resume");
      flow(stream);
      if (state.flowing && !state.reading)
        stream.read(0);
    }
    Readable.prototype.pause = function() {
      debug("call pause flowing=%j", this._readableState.flowing);
      if (this._readableState.flowing !== false) {
        debug("pause");
        this._readableState.flowing = false;
        this.emit("pause");
      }
      this._readableState.paused = true;
      return this;
    };
    function flow(stream) {
      var state = stream._readableState;
      debug("flow", state.flowing);
      while (state.flowing && stream.read() !== null) {
        ;
      }
    }
    Readable.prototype.wrap = function(stream) {
      var _this = this;
      var state = this._readableState;
      var paused = false;
      stream.on("end", function() {
        debug("wrapped end");
        if (state.decoder && !state.ended) {
          var chunk = state.decoder.end();
          if (chunk && chunk.length)
            _this.push(chunk);
        }
        _this.push(null);
      });
      stream.on("data", function(chunk) {
        debug("wrapped data");
        if (state.decoder)
          chunk = state.decoder.write(chunk);
        if (state.objectMode && (chunk === null || chunk === void 0))
          return;
        else if (!state.objectMode && (!chunk || !chunk.length))
          return;
        var ret = _this.push(chunk);
        if (!ret) {
          paused = true;
          stream.pause();
        }
      });
      for (var i in stream) {
        if (this[i] === void 0 && typeof stream[i] === "function") {
          this[i] = function methodWrap(method) {
            return function methodWrapReturnFunction() {
              return stream[method].apply(stream, arguments);
            };
          }(i);
        }
      }
      for (var n = 0; n < kProxyEvents.length; n++) {
        stream.on(kProxyEvents[n], this.emit.bind(this, kProxyEvents[n]));
      }
      this._read = function(n2) {
        debug("wrapped _read", n2);
        if (paused) {
          paused = false;
          stream.resume();
        }
      };
      return this;
    };
    if (typeof Symbol === "function") {
      Readable.prototype[Symbol.asyncIterator] = function() {
        if (createReadableStreamAsyncIterator === void 0) {
          createReadableStreamAsyncIterator = require_async_iterator();
        }
        return createReadableStreamAsyncIterator(this);
      };
    }
    Object.defineProperty(Readable.prototype, "readableHighWaterMark", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._readableState.highWaterMark;
      }
    });
    Object.defineProperty(Readable.prototype, "readableBuffer", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._readableState && this._readableState.buffer;
      }
    });
    Object.defineProperty(Readable.prototype, "readableFlowing", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._readableState.flowing;
      },
      set: function set(state) {
        if (this._readableState) {
          this._readableState.flowing = state;
        }
      }
    });
    Readable._fromList = fromList;
    Object.defineProperty(Readable.prototype, "readableLength", {
      // making it explicit this property is not enumerable
      // because otherwise some prototype manipulation in
      // userland will fail
      enumerable: false,
      get: function get() {
        return this._readableState.length;
      }
    });
    function fromList(n, state) {
      if (state.length === 0)
        return null;
      var ret;
      if (state.objectMode)
        ret = state.buffer.shift();
      else if (!n || n >= state.length) {
        if (state.decoder)
          ret = state.buffer.join("");
        else if (state.buffer.length === 1)
          ret = state.buffer.first();
        else
          ret = state.buffer.concat(state.length);
        state.buffer.clear();
      } else {
        ret = state.buffer.consume(n, state.decoder);
      }
      return ret;
    }
    function endReadable(stream) {
      var state = stream._readableState;
      debug("endReadable", state.endEmitted);
      if (!state.endEmitted) {
        state.ended = true;
        process.nextTick(endReadableNT, state, stream);
      }
    }
    function endReadableNT(state, stream) {
      debug("endReadableNT", state.endEmitted, state.length);
      if (!state.endEmitted && state.length === 0) {
        state.endEmitted = true;
        stream.readable = false;
        stream.emit("end");
        if (state.autoDestroy) {
          var wState = stream._writableState;
          if (!wState || wState.autoDestroy && wState.finished) {
            stream.destroy();
          }
        }
      }
    }
    if (typeof Symbol === "function") {
      Readable.from = function(iterable, opts) {
        if (from === void 0) {
          from = require_from();
        }
        return from(Readable, iterable, opts);
      };
    }
    function indexOf(xs, x) {
      for (var i = 0, l = xs.length; i < l; i++) {
        if (xs[i] === x)
          return i;
      }
      return -1;
    }
  }
});

// node_modules/readable-stream/lib/_stream_transform.js
var require_stream_transform = __commonJS({
  "node_modules/readable-stream/lib/_stream_transform.js"(exports, module2) {
    "use strict";
    module2.exports = Transform2;
    var _require$codes = require_errors().codes;
    var ERR_METHOD_NOT_IMPLEMENTED = _require$codes.ERR_METHOD_NOT_IMPLEMENTED;
    var ERR_MULTIPLE_CALLBACK = _require$codes.ERR_MULTIPLE_CALLBACK;
    var ERR_TRANSFORM_ALREADY_TRANSFORMING = _require$codes.ERR_TRANSFORM_ALREADY_TRANSFORMING;
    var ERR_TRANSFORM_WITH_LENGTH_0 = _require$codes.ERR_TRANSFORM_WITH_LENGTH_0;
    var Duplex = require_stream_duplex();
    require_inherits()(Transform2, Duplex);
    function afterTransform(er, data) {
      var ts = this._transformState;
      ts.transforming = false;
      var cb = ts.writecb;
      if (cb === null) {
        return this.emit("error", new ERR_MULTIPLE_CALLBACK());
      }
      ts.writechunk = null;
      ts.writecb = null;
      if (data != null)
        this.push(data);
      cb(er);
      var rs = this._readableState;
      rs.reading = false;
      if (rs.needReadable || rs.length < rs.highWaterMark) {
        this._read(rs.highWaterMark);
      }
    }
    function Transform2(options) {
      if (!(this instanceof Transform2))
        return new Transform2(options);
      Duplex.call(this, options);
      this._transformState = {
        afterTransform: afterTransform.bind(this),
        needTransform: false,
        transforming: false,
        writecb: null,
        writechunk: null,
        writeencoding: null
      };
      this._readableState.needReadable = true;
      this._readableState.sync = false;
      if (options) {
        if (typeof options.transform === "function")
          this._transform = options.transform;
        if (typeof options.flush === "function")
          this._flush = options.flush;
      }
      this.on("prefinish", prefinish);
    }
    function prefinish() {
      var _this = this;
      if (typeof this._flush === "function" && !this._readableState.destroyed) {
        this._flush(function(er, data) {
          done(_this, er, data);
        });
      } else {
        done(this, null, null);
      }
    }
    Transform2.prototype.push = function(chunk, encoding) {
      this._transformState.needTransform = false;
      return Duplex.prototype.push.call(this, chunk, encoding);
    };
    Transform2.prototype._transform = function(chunk, encoding, cb) {
      cb(new ERR_METHOD_NOT_IMPLEMENTED("_transform()"));
    };
    Transform2.prototype._write = function(chunk, encoding, cb) {
      var ts = this._transformState;
      ts.writecb = cb;
      ts.writechunk = chunk;
      ts.writeencoding = encoding;
      if (!ts.transforming) {
        var rs = this._readableState;
        if (ts.needTransform || rs.needReadable || rs.length < rs.highWaterMark)
          this._read(rs.highWaterMark);
      }
    };
    Transform2.prototype._read = function(n) {
      var ts = this._transformState;
      if (ts.writechunk !== null && !ts.transforming) {
        ts.transforming = true;
        this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
      } else {
        ts.needTransform = true;
      }
    };
    Transform2.prototype._destroy = function(err, cb) {
      Duplex.prototype._destroy.call(this, err, function(err2) {
        cb(err2);
      });
    };
    function done(stream, er, data) {
      if (er)
        return stream.emit("error", er);
      if (data != null)
        stream.push(data);
      if (stream._writableState.length)
        throw new ERR_TRANSFORM_WITH_LENGTH_0();
      if (stream._transformState.transforming)
        throw new ERR_TRANSFORM_ALREADY_TRANSFORMING();
      return stream.push(null);
    }
  }
});

// node_modules/readable-stream/lib/_stream_passthrough.js
var require_stream_passthrough = __commonJS({
  "node_modules/readable-stream/lib/_stream_passthrough.js"(exports, module2) {
    "use strict";
    module2.exports = PassThrough;
    var Transform2 = require_stream_transform();
    require_inherits()(PassThrough, Transform2);
    function PassThrough(options) {
      if (!(this instanceof PassThrough))
        return new PassThrough(options);
      Transform2.call(this, options);
    }
    PassThrough.prototype._transform = function(chunk, encoding, cb) {
      cb(null, chunk);
    };
  }
});

// node_modules/readable-stream/lib/internal/streams/pipeline.js
var require_pipeline = __commonJS({
  "node_modules/readable-stream/lib/internal/streams/pipeline.js"(exports, module2) {
    "use strict";
    var eos;
    function once(callback) {
      var called = false;
      return function() {
        if (called)
          return;
        called = true;
        callback.apply(void 0, arguments);
      };
    }
    var _require$codes = require_errors().codes;
    var ERR_MISSING_ARGS = _require$codes.ERR_MISSING_ARGS;
    var ERR_STREAM_DESTROYED = _require$codes.ERR_STREAM_DESTROYED;
    function noop(err) {
      if (err)
        throw err;
    }
    function isRequest(stream) {
      return stream.setHeader && typeof stream.abort === "function";
    }
    function destroyer(stream, reading, writing, callback) {
      callback = once(callback);
      var closed = false;
      stream.on("close", function() {
        closed = true;
      });
      if (eos === void 0)
        eos = require_end_of_stream();
      eos(stream, {
        readable: reading,
        writable: writing
      }, function(err) {
        if (err)
          return callback(err);
        closed = true;
        callback();
      });
      var destroyed = false;
      return function(err) {
        if (closed)
          return;
        if (destroyed)
          return;
        destroyed = true;
        if (isRequest(stream))
          return stream.abort();
        if (typeof stream.destroy === "function")
          return stream.destroy();
        callback(err || new ERR_STREAM_DESTROYED("pipe"));
      };
    }
    function call(fn) {
      fn();
    }
    function pipe(from, to) {
      return from.pipe(to);
    }
    function popCallback(streams) {
      if (!streams.length)
        return noop;
      if (typeof streams[streams.length - 1] !== "function")
        return noop;
      return streams.pop();
    }
    function pipeline() {
      for (var _len = arguments.length, streams = new Array(_len), _key = 0; _key < _len; _key++) {
        streams[_key] = arguments[_key];
      }
      var callback = popCallback(streams);
      if (Array.isArray(streams[0]))
        streams = streams[0];
      if (streams.length < 2) {
        throw new ERR_MISSING_ARGS("streams");
      }
      var error;
      var destroys = streams.map(function(stream, i) {
        var reading = i < streams.length - 1;
        var writing = i > 0;
        return destroyer(stream, reading, writing, function(err) {
          if (!error)
            error = err;
          if (err)
            destroys.forEach(call);
          if (reading)
            return;
          destroys.forEach(call);
          callback(error);
        });
      });
      return streams.reduce(pipe);
    }
    module2.exports = pipeline;
  }
});

// node_modules/readable-stream/readable.js
var require_readable = __commonJS({
  "node_modules/readable-stream/readable.js"(exports, module2) {
    var Stream = require("stream");
    if (process.env.READABLE_STREAM === "disable" && Stream) {
      module2.exports = Stream.Readable;
      Object.assign(module2.exports, Stream);
      module2.exports.Stream = Stream;
    } else {
      exports = module2.exports = require_stream_readable();
      exports.Stream = Stream || exports;
      exports.Readable = exports;
      exports.Writable = require_stream_writable();
      exports.Duplex = require_stream_duplex();
      exports.Transform = require_stream_transform();
      exports.PassThrough = require_stream_passthrough();
      exports.finished = require_end_of_stream();
      exports.pipeline = require_pipeline();
    }
  }
});

// node_modules/bl/BufferList.js
var require_BufferList = __commonJS({
  "node_modules/bl/BufferList.js"(exports, module2) {
    "use strict";
    var { Buffer: Buffer2 } = require("buffer");
    var symbol = Symbol.for("BufferList");
    function BufferList(buf) {
      if (!(this instanceof BufferList)) {
        return new BufferList(buf);
      }
      BufferList._init.call(this, buf);
    }
    BufferList._init = function _init(buf) {
      Object.defineProperty(this, symbol, { value: true });
      this._bufs = [];
      this.length = 0;
      if (buf) {
        this.append(buf);
      }
    };
    BufferList.prototype._new = function _new(buf) {
      return new BufferList(buf);
    };
    BufferList.prototype._offset = function _offset(offset) {
      if (offset === 0) {
        return [0, 0];
      }
      let tot = 0;
      for (let i = 0; i < this._bufs.length; i++) {
        const _t = tot + this._bufs[i].length;
        if (offset < _t || i === this._bufs.length - 1) {
          return [i, offset - tot];
        }
        tot = _t;
      }
    };
    BufferList.prototype._reverseOffset = function(blOffset) {
      const bufferId = blOffset[0];
      let offset = blOffset[1];
      for (let i = 0; i < bufferId; i++) {
        offset += this._bufs[i].length;
      }
      return offset;
    };
    BufferList.prototype.get = function get(index) {
      if (index > this.length || index < 0) {
        return void 0;
      }
      const offset = this._offset(index);
      return this._bufs[offset[0]][offset[1]];
    };
    BufferList.prototype.slice = function slice(start, end) {
      if (typeof start === "number" && start < 0) {
        start += this.length;
      }
      if (typeof end === "number" && end < 0) {
        end += this.length;
      }
      return this.copy(null, 0, start, end);
    };
    BufferList.prototype.copy = function copy(dst, dstStart, srcStart, srcEnd) {
      if (typeof srcStart !== "number" || srcStart < 0) {
        srcStart = 0;
      }
      if (typeof srcEnd !== "number" || srcEnd > this.length) {
        srcEnd = this.length;
      }
      if (srcStart >= this.length) {
        return dst || Buffer2.alloc(0);
      }
      if (srcEnd <= 0) {
        return dst || Buffer2.alloc(0);
      }
      const copy2 = !!dst;
      const off = this._offset(srcStart);
      const len = srcEnd - srcStart;
      let bytes = len;
      let bufoff = copy2 && dstStart || 0;
      let start = off[1];
      if (srcStart === 0 && srcEnd === this.length) {
        if (!copy2) {
          return this._bufs.length === 1 ? this._bufs[0] : Buffer2.concat(this._bufs, this.length);
        }
        for (let i = 0; i < this._bufs.length; i++) {
          this._bufs[i].copy(dst, bufoff);
          bufoff += this._bufs[i].length;
        }
        return dst;
      }
      if (bytes <= this._bufs[off[0]].length - start) {
        return copy2 ? this._bufs[off[0]].copy(dst, dstStart, start, start + bytes) : this._bufs[off[0]].slice(start, start + bytes);
      }
      if (!copy2) {
        dst = Buffer2.allocUnsafe(len);
      }
      for (let i = off[0]; i < this._bufs.length; i++) {
        const l = this._bufs[i].length - start;
        if (bytes > l) {
          this._bufs[i].copy(dst, bufoff, start);
          bufoff += l;
        } else {
          this._bufs[i].copy(dst, bufoff, start, start + bytes);
          bufoff += l;
          break;
        }
        bytes -= l;
        if (start) {
          start = 0;
        }
      }
      if (dst.length > bufoff)
        return dst.slice(0, bufoff);
      return dst;
    };
    BufferList.prototype.shallowSlice = function shallowSlice(start, end) {
      start = start || 0;
      end = typeof end !== "number" ? this.length : end;
      if (start < 0) {
        start += this.length;
      }
      if (end < 0) {
        end += this.length;
      }
      if (start === end) {
        return this._new();
      }
      const startOffset = this._offset(start);
      const endOffset = this._offset(end);
      const buffers = this._bufs.slice(startOffset[0], endOffset[0] + 1);
      if (endOffset[1] === 0) {
        buffers.pop();
      } else {
        buffers[buffers.length - 1] = buffers[buffers.length - 1].slice(0, endOffset[1]);
      }
      if (startOffset[1] !== 0) {
        buffers[0] = buffers[0].slice(startOffset[1]);
      }
      return this._new(buffers);
    };
    BufferList.prototype.toString = function toString(encoding, start, end) {
      return this.slice(start, end).toString(encoding);
    };
    BufferList.prototype.consume = function consume(bytes) {
      bytes = Math.trunc(bytes);
      if (Number.isNaN(bytes) || bytes <= 0)
        return this;
      while (this._bufs.length) {
        if (bytes >= this._bufs[0].length) {
          bytes -= this._bufs[0].length;
          this.length -= this._bufs[0].length;
          this._bufs.shift();
        } else {
          this._bufs[0] = this._bufs[0].slice(bytes);
          this.length -= bytes;
          break;
        }
      }
      return this;
    };
    BufferList.prototype.duplicate = function duplicate() {
      const copy = this._new();
      for (let i = 0; i < this._bufs.length; i++) {
        copy.append(this._bufs[i]);
      }
      return copy;
    };
    BufferList.prototype.append = function append(buf) {
      if (buf == null) {
        return this;
      }
      if (buf.buffer) {
        this._appendBuffer(Buffer2.from(buf.buffer, buf.byteOffset, buf.byteLength));
      } else if (Array.isArray(buf)) {
        for (let i = 0; i < buf.length; i++) {
          this.append(buf[i]);
        }
      } else if (this._isBufferList(buf)) {
        for (let i = 0; i < buf._bufs.length; i++) {
          this.append(buf._bufs[i]);
        }
      } else {
        if (typeof buf === "number") {
          buf = buf.toString();
        }
        this._appendBuffer(Buffer2.from(buf));
      }
      return this;
    };
    BufferList.prototype._appendBuffer = function appendBuffer(buf) {
      this._bufs.push(buf);
      this.length += buf.length;
    };
    BufferList.prototype.indexOf = function(search, offset, encoding) {
      if (encoding === void 0 && typeof offset === "string") {
        encoding = offset;
        offset = void 0;
      }
      if (typeof search === "function" || Array.isArray(search)) {
        throw new TypeError('The "value" argument must be one of type string, Buffer, BufferList, or Uint8Array.');
      } else if (typeof search === "number") {
        search = Buffer2.from([search]);
      } else if (typeof search === "string") {
        search = Buffer2.from(search, encoding);
      } else if (this._isBufferList(search)) {
        search = search.slice();
      } else if (Array.isArray(search.buffer)) {
        search = Buffer2.from(search.buffer, search.byteOffset, search.byteLength);
      } else if (!Buffer2.isBuffer(search)) {
        search = Buffer2.from(search);
      }
      offset = Number(offset || 0);
      if (isNaN(offset)) {
        offset = 0;
      }
      if (offset < 0) {
        offset = this.length + offset;
      }
      if (offset < 0) {
        offset = 0;
      }
      if (search.length === 0) {
        return offset > this.length ? this.length : offset;
      }
      const blOffset = this._offset(offset);
      let blIndex = blOffset[0];
      let buffOffset = blOffset[1];
      for (; blIndex < this._bufs.length; blIndex++) {
        const buff = this._bufs[blIndex];
        while (buffOffset < buff.length) {
          const availableWindow = buff.length - buffOffset;
          if (availableWindow >= search.length) {
            const nativeSearchResult = buff.indexOf(search, buffOffset);
            if (nativeSearchResult !== -1) {
              return this._reverseOffset([blIndex, nativeSearchResult]);
            }
            buffOffset = buff.length - search.length + 1;
          } else {
            const revOffset = this._reverseOffset([blIndex, buffOffset]);
            if (this._match(revOffset, search)) {
              return revOffset;
            }
            buffOffset++;
          }
        }
        buffOffset = 0;
      }
      return -1;
    };
    BufferList.prototype._match = function(offset, search) {
      if (this.length - offset < search.length) {
        return false;
      }
      for (let searchOffset = 0; searchOffset < search.length; searchOffset++) {
        if (this.get(offset + searchOffset) !== search[searchOffset]) {
          return false;
        }
      }
      return true;
    };
    (function() {
      const methods = {
        readDoubleBE: 8,
        readDoubleLE: 8,
        readFloatBE: 4,
        readFloatLE: 4,
        readInt32BE: 4,
        readInt32LE: 4,
        readUInt32BE: 4,
        readUInt32LE: 4,
        readInt16BE: 2,
        readInt16LE: 2,
        readUInt16BE: 2,
        readUInt16LE: 2,
        readInt8: 1,
        readUInt8: 1,
        readIntBE: null,
        readIntLE: null,
        readUIntBE: null,
        readUIntLE: null
      };
      for (const m in methods) {
        (function(m2) {
          if (methods[m2] === null) {
            BufferList.prototype[m2] = function(offset, byteLength) {
              return this.slice(offset, offset + byteLength)[m2](0, byteLength);
            };
          } else {
            BufferList.prototype[m2] = function(offset = 0) {
              return this.slice(offset, offset + methods[m2])[m2](0);
            };
          }
        })(m);
      }
    })();
    BufferList.prototype._isBufferList = function _isBufferList(b) {
      return b instanceof BufferList || BufferList.isBufferList(b);
    };
    BufferList.isBufferList = function isBufferList(b) {
      return b != null && b[symbol];
    };
    module2.exports = BufferList;
  }
});

// node_modules/bl/bl.js
var require_bl = __commonJS({
  "node_modules/bl/bl.js"(exports, module2) {
    "use strict";
    var DuplexStream = require_readable().Duplex;
    var inherits = require_inherits();
    var BufferList = require_BufferList();
    function BufferListStream(callback) {
      if (!(this instanceof BufferListStream)) {
        return new BufferListStream(callback);
      }
      if (typeof callback === "function") {
        this._callback = callback;
        const piper = function piper2(err) {
          if (this._callback) {
            this._callback(err);
            this._callback = null;
          }
        }.bind(this);
        this.on("pipe", function onPipe(src) {
          src.on("error", piper);
        });
        this.on("unpipe", function onUnpipe(src) {
          src.removeListener("error", piper);
        });
        callback = null;
      }
      BufferList._init.call(this, callback);
      DuplexStream.call(this);
    }
    inherits(BufferListStream, DuplexStream);
    Object.assign(BufferListStream.prototype, BufferList.prototype);
    BufferListStream.prototype._new = function _new(callback) {
      return new BufferListStream(callback);
    };
    BufferListStream.prototype._write = function _write(buf, encoding, callback) {
      this._appendBuffer(buf);
      if (typeof callback === "function") {
        callback();
      }
    };
    BufferListStream.prototype._read = function _read(size) {
      if (!this.length) {
        return this.push(null);
      }
      size = Math.min(size, this.length);
      this.push(this.slice(0, size));
      this.consume(size);
    };
    BufferListStream.prototype.end = function end(chunk) {
      DuplexStream.prototype.end.call(this, chunk);
      if (this._callback) {
        this._callback(null, this.slice());
        this._callback = null;
      }
    };
    BufferListStream.prototype._destroy = function _destroy(err, cb) {
      this._bufs.length = 0;
      this.length = 0;
      cb(err);
    };
    BufferListStream.prototype._isBufferList = function _isBufferList(b) {
      return b instanceof BufferListStream || b instanceof BufferList || BufferListStream.isBufferList(b);
    };
    BufferListStream.isBufferList = BufferList.isBufferList;
    module2.exports = BufferListStream;
    module2.exports.BufferListStream = BufferListStream;
    module2.exports.BufferList = BufferList;
  }
});

// node_modules/ora/index.js
var require_ora = __commonJS({
  "node_modules/ora/index.js"(exports, module2) {
    "use strict";
    var readline = require("readline");
    var chalk3 = require_source();
    var cliCursor = require_cli_cursor();
    var cliSpinners = require_cli_spinners();
    var logSymbols = require_log_symbols();
    var stripAnsi = require_strip_ansi();
    var wcwidth = require_wcwidth();
    var isInteractive = require_is_interactive();
    var isUnicodeSupported = require_is_unicode_supported();
    var { BufferListStream } = require_bl();
    var TEXT = Symbol("text");
    var PREFIX_TEXT = Symbol("prefixText");
    var ASCII_ETX_CODE = 3;
    var StdinDiscarder = class {
      constructor() {
        this.requests = 0;
        this.mutedStream = new BufferListStream();
        this.mutedStream.pipe(process.stdout);
        const self2 = this;
        this.ourEmit = function(event, data, ...args) {
          const { stdin } = process;
          if (self2.requests > 0 || stdin.emit === self2.ourEmit) {
            if (event === "keypress") {
              return;
            }
            if (event === "data" && data.includes(ASCII_ETX_CODE)) {
              process.emit("SIGINT");
            }
            Reflect.apply(self2.oldEmit, this, [event, data, ...args]);
          } else {
            Reflect.apply(process.stdin.emit, this, [event, data, ...args]);
          }
        };
      }
      start() {
        this.requests++;
        if (this.requests === 1) {
          this.realStart();
        }
      }
      stop() {
        if (this.requests <= 0) {
          throw new Error("`stop` called more times than `start`");
        }
        this.requests--;
        if (this.requests === 0) {
          this.realStop();
        }
      }
      realStart() {
        if (process.platform === "win32") {
          return;
        }
        this.rl = readline.createInterface({
          input: process.stdin,
          output: this.mutedStream
        });
        this.rl.on("SIGINT", () => {
          if (process.listenerCount("SIGINT") === 0) {
            process.emit("SIGINT");
          } else {
            this.rl.close();
            process.kill(process.pid, "SIGINT");
          }
        });
      }
      realStop() {
        if (process.platform === "win32") {
          return;
        }
        this.rl.close();
        this.rl = void 0;
      }
    };
    var stdinDiscarder;
    var Ora = class {
      constructor(options) {
        if (!stdinDiscarder) {
          stdinDiscarder = new StdinDiscarder();
        }
        if (typeof options === "string") {
          options = {
            text: options
          };
        }
        this.options = {
          text: "",
          color: "cyan",
          stream: process.stderr,
          discardStdin: true,
          ...options
        };
        this.spinner = this.options.spinner;
        this.color = this.options.color;
        this.hideCursor = this.options.hideCursor !== false;
        this.interval = this.options.interval || this.spinner.interval || 100;
        this.stream = this.options.stream;
        this.id = void 0;
        this.isEnabled = typeof this.options.isEnabled === "boolean" ? this.options.isEnabled : isInteractive({ stream: this.stream });
        this.isSilent = typeof this.options.isSilent === "boolean" ? this.options.isSilent : false;
        this.text = this.options.text;
        this.prefixText = this.options.prefixText;
        this.linesToClear = 0;
        this.indent = this.options.indent;
        this.discardStdin = this.options.discardStdin;
        this.isDiscardingStdin = false;
      }
      get indent() {
        return this._indent;
      }
      set indent(indent = 0) {
        if (!(indent >= 0 && Number.isInteger(indent))) {
          throw new Error("The `indent` option must be an integer from 0 and up");
        }
        this._indent = indent;
      }
      _updateInterval(interval) {
        if (interval !== void 0) {
          this.interval = interval;
        }
      }
      get spinner() {
        return this._spinner;
      }
      set spinner(spinner2) {
        this.frameIndex = 0;
        if (typeof spinner2 === "object") {
          if (spinner2.frames === void 0) {
            throw new Error("The given spinner must have a `frames` property");
          }
          this._spinner = spinner2;
        } else if (!isUnicodeSupported()) {
          this._spinner = cliSpinners.line;
        } else if (spinner2 === void 0) {
          this._spinner = cliSpinners.dots;
        } else if (spinner2 !== "default" && cliSpinners[spinner2]) {
          this._spinner = cliSpinners[spinner2];
        } else {
          throw new Error(`There is no built-in spinner named '${spinner2}'. See https://github.com/sindresorhus/cli-spinners/blob/main/spinners.json for a full list.`);
        }
        this._updateInterval(this._spinner.interval);
      }
      get text() {
        return this[TEXT];
      }
      set text(value2) {
        this[TEXT] = value2;
        this.updateLineCount();
      }
      get prefixText() {
        return this[PREFIX_TEXT];
      }
      set prefixText(value2) {
        this[PREFIX_TEXT] = value2;
        this.updateLineCount();
      }
      get isSpinning() {
        return this.id !== void 0;
      }
      getFullPrefixText(prefixText = this[PREFIX_TEXT], postfix = " ") {
        if (typeof prefixText === "string") {
          return prefixText + postfix;
        }
        if (typeof prefixText === "function") {
          return prefixText() + postfix;
        }
        return "";
      }
      updateLineCount() {
        const columns = this.stream.columns || 80;
        const fullPrefixText = this.getFullPrefixText(this.prefixText, "-");
        this.lineCount = 0;
        for (const line of stripAnsi(fullPrefixText + "--" + this[TEXT]).split("\n")) {
          this.lineCount += Math.max(1, Math.ceil(wcwidth(line) / columns));
        }
      }
      get isEnabled() {
        return this._isEnabled && !this.isSilent;
      }
      set isEnabled(value2) {
        if (typeof value2 !== "boolean") {
          throw new TypeError("The `isEnabled` option must be a boolean");
        }
        this._isEnabled = value2;
      }
      get isSilent() {
        return this._isSilent;
      }
      set isSilent(value2) {
        if (typeof value2 !== "boolean") {
          throw new TypeError("The `isSilent` option must be a boolean");
        }
        this._isSilent = value2;
      }
      frame() {
        const { frames } = this.spinner;
        let frame = frames[this.frameIndex];
        if (this.color) {
          frame = chalk3[this.color](frame);
        }
        this.frameIndex = ++this.frameIndex % frames.length;
        const fullPrefixText = typeof this.prefixText === "string" && this.prefixText !== "" ? this.prefixText + " " : "";
        const fullText = typeof this.text === "string" ? " " + this.text : "";
        return fullPrefixText + frame + fullText;
      }
      clear() {
        if (!this.isEnabled || !this.stream.isTTY) {
          return this;
        }
        for (let i = 0; i < this.linesToClear; i++) {
          if (i > 0) {
            this.stream.moveCursor(0, -1);
          }
          this.stream.clearLine();
          this.stream.cursorTo(this.indent);
        }
        this.linesToClear = 0;
        return this;
      }
      render() {
        if (this.isSilent) {
          return this;
        }
        this.clear();
        this.stream.write(this.frame());
        this.linesToClear = this.lineCount;
        return this;
      }
      start(text) {
        if (text) {
          this.text = text;
        }
        if (this.isSilent) {
          return this;
        }
        if (!this.isEnabled) {
          if (this.text) {
            this.stream.write(`- ${this.text}
`);
          }
          return this;
        }
        if (this.isSpinning) {
          return this;
        }
        if (this.hideCursor) {
          cliCursor.hide(this.stream);
        }
        if (this.discardStdin && process.stdin.isTTY) {
          this.isDiscardingStdin = true;
          stdinDiscarder.start();
        }
        this.render();
        this.id = setInterval(this.render.bind(this), this.interval);
        return this;
      }
      stop() {
        if (!this.isEnabled) {
          return this;
        }
        clearInterval(this.id);
        this.id = void 0;
        this.frameIndex = 0;
        this.clear();
        if (this.hideCursor) {
          cliCursor.show(this.stream);
        }
        if (this.discardStdin && process.stdin.isTTY && this.isDiscardingStdin) {
          stdinDiscarder.stop();
          this.isDiscardingStdin = false;
        }
        return this;
      }
      succeed(text) {
        return this.stopAndPersist({ symbol: logSymbols.success, text });
      }
      fail(text) {
        return this.stopAndPersist({ symbol: logSymbols.error, text });
      }
      warn(text) {
        return this.stopAndPersist({ symbol: logSymbols.warning, text });
      }
      info(text) {
        return this.stopAndPersist({ symbol: logSymbols.info, text });
      }
      stopAndPersist(options = {}) {
        if (this.isSilent) {
          return this;
        }
        const prefixText = options.prefixText || this.prefixText;
        const text = options.text || this.text;
        const fullText = typeof text === "string" ? " " + text : "";
        this.stop();
        this.stream.write(`${this.getFullPrefixText(prefixText, " ")}${options.symbol || " "}${fullText}
`);
        return this;
      }
    };
    var oraFactory = function(options) {
      return new Ora(options);
    };
    module2.exports = oraFactory;
    module2.exports.promise = (action, options) => {
      if (typeof action.then !== "function") {
        throw new TypeError("Parameter `action` must be a Promise");
      }
      const spinner2 = new Ora(options);
      spinner2.start();
      (async () => {
        try {
          await action;
          spinner2.succeed();
        } catch {
          spinner2.fail();
        }
      })();
      return spinner2;
    };
  }
});

// node_modules/escape-string-regexp/index.js
var require_escape_string_regexp = __commonJS({
  "node_modules/escape-string-regexp/index.js"(exports, module2) {
    "use strict";
    var matchOperatorsRe = /[|\\{}()[\]^$+*?.]/g;
    module2.exports = function(str) {
      if (typeof str !== "string") {
        throw new TypeError("Expected a string");
      }
      return str.replace(matchOperatorsRe, "\\$&");
    };
  }
});

// node_modules/figures/index.js
var require_figures = __commonJS({
  "node_modules/figures/index.js"(exports, module2) {
    "use strict";
    var escapeStringRegexp = require_escape_string_regexp();
    var { platform } = process;
    var main = {
      tick: "\u2714",
      cross: "\u2716",
      star: "\u2605",
      square: "\u2587",
      squareSmall: "\u25FB",
      squareSmallFilled: "\u25FC",
      play: "\u25B6",
      circle: "\u25EF",
      circleFilled: "\u25C9",
      circleDotted: "\u25CC",
      circleDouble: "\u25CE",
      circleCircle: "\u24DE",
      circleCross: "\u24E7",
      circlePipe: "\u24BE",
      circleQuestionMark: "?\u20DD",
      bullet: "\u25CF",
      dot: "\u2024",
      line: "\u2500",
      ellipsis: "\u2026",
      pointer: "\u276F",
      pointerSmall: "\u203A",
      info: "\u2139",
      warning: "\u26A0",
      hamburger: "\u2630",
      smiley: "\u32E1",
      mustache: "\u0DF4",
      heart: "\u2665",
      nodejs: "\u2B22",
      arrowUp: "\u2191",
      arrowDown: "\u2193",
      arrowLeft: "\u2190",
      arrowRight: "\u2192",
      radioOn: "\u25C9",
      radioOff: "\u25EF",
      checkboxOn: "\u2612",
      checkboxOff: "\u2610",
      checkboxCircleOn: "\u24E7",
      checkboxCircleOff: "\u24BE",
      questionMarkPrefix: "?\u20DD",
      oneHalf: "\xBD",
      oneThird: "\u2153",
      oneQuarter: "\xBC",
      oneFifth: "\u2155",
      oneSixth: "\u2159",
      oneSeventh: "\u2150",
      oneEighth: "\u215B",
      oneNinth: "\u2151",
      oneTenth: "\u2152",
      twoThirds: "\u2154",
      twoFifths: "\u2156",
      threeQuarters: "\xBE",
      threeFifths: "\u2157",
      threeEighths: "\u215C",
      fourFifths: "\u2158",
      fiveSixths: "\u215A",
      fiveEighths: "\u215D",
      sevenEighths: "\u215E"
    };
    var windows = {
      tick: "\u221A",
      cross: "\xD7",
      star: "*",
      square: "\u2588",
      squareSmall: "[ ]",
      squareSmallFilled: "[\u2588]",
      play: "\u25BA",
      circle: "( )",
      circleFilled: "(*)",
      circleDotted: "( )",
      circleDouble: "( )",
      circleCircle: "(\u25CB)",
      circleCross: "(\xD7)",
      circlePipe: "(\u2502)",
      circleQuestionMark: "(?)",
      bullet: "*",
      dot: ".",
      line: "\u2500",
      ellipsis: "...",
      pointer: ">",
      pointerSmall: "\xBB",
      info: "i",
      warning: "\u203C",
      hamburger: "\u2261",
      smiley: "\u263A",
      mustache: "\u250C\u2500\u2510",
      heart: main.heart,
      nodejs: "\u2666",
      arrowUp: main.arrowUp,
      arrowDown: main.arrowDown,
      arrowLeft: main.arrowLeft,
      arrowRight: main.arrowRight,
      radioOn: "(*)",
      radioOff: "( )",
      checkboxOn: "[\xD7]",
      checkboxOff: "[ ]",
      checkboxCircleOn: "(\xD7)",
      checkboxCircleOff: "( )",
      questionMarkPrefix: "\uFF1F",
      oneHalf: "1/2",
      oneThird: "1/3",
      oneQuarter: "1/4",
      oneFifth: "1/5",
      oneSixth: "1/6",
      oneSeventh: "1/7",
      oneEighth: "1/8",
      oneNinth: "1/9",
      oneTenth: "1/10",
      twoThirds: "2/3",
      twoFifths: "2/5",
      threeQuarters: "3/4",
      threeFifths: "3/5",
      threeEighths: "3/8",
      fourFifths: "4/5",
      fiveSixths: "5/6",
      fiveEighths: "5/8",
      sevenEighths: "7/8"
    };
    if (platform === "linux") {
      main.questionMarkPrefix = "?";
    }
    var figures = platform === "win32" ? windows : main;
    var fn = (string) => {
      if (figures === main) {
        return string;
      }
      for (const [key, value2] of Object.entries(main)) {
        if (value2 === figures[key]) {
          continue;
        }
        string = string.replace(new RegExp(escapeStringRegexp(value2), "g"), figures[key]);
      }
      return string;
    };
    module2.exports = Object.assign(fn, figures);
    module2.exports.main = main;
    module2.exports.windows = windows;
  }
});

// node_modules/inquirer/lib/objects/separator.js
var require_separator = __commonJS({
  "node_modules/inquirer/lib/objects/separator.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var figures = require_figures();
    var Separator = class {
      constructor(line) {
        this.type = "separator";
        this.line = chalk3.dim(line || new Array(15).join(figures.line));
      }
      /**
       * Stringify separator
       * @return {String} the separator display string
       */
      toString() {
        return this.line;
      }
    };
    Separator.exclude = function(obj) {
      return obj.type !== "separator";
    };
    module2.exports = Separator;
  }
});

// node_modules/through/index.js
var require_through = __commonJS({
  "node_modules/through/index.js"(exports, module2) {
    var Stream = require("stream");
    exports = module2.exports = through;
    through.through = through;
    function through(write, end, opts) {
      write = write || function(data) {
        this.queue(data);
      };
      end = end || function() {
        this.queue(null);
      };
      var ended = false, destroyed = false, buffer = [], _ended = false;
      var stream = new Stream();
      stream.readable = stream.writable = true;
      stream.paused = false;
      stream.autoDestroy = !(opts && opts.autoDestroy === false);
      stream.write = function(data) {
        write.call(this, data);
        return !stream.paused;
      };
      function drain() {
        while (buffer.length && !stream.paused) {
          var data = buffer.shift();
          if (null === data)
            return stream.emit("end");
          else
            stream.emit("data", data);
        }
      }
      stream.queue = stream.push = function(data) {
        if (_ended)
          return stream;
        if (data === null)
          _ended = true;
        buffer.push(data);
        drain();
        return stream;
      };
      stream.on("end", function() {
        stream.readable = false;
        if (!stream.writable && stream.autoDestroy)
          process.nextTick(function() {
            stream.destroy();
          });
      });
      function _end() {
        stream.writable = false;
        end.call(stream);
        if (!stream.readable && stream.autoDestroy)
          stream.destroy();
      }
      stream.end = function(data) {
        if (ended)
          return;
        ended = true;
        if (arguments.length)
          stream.write(data);
        _end();
        return stream;
      };
      stream.destroy = function() {
        if (destroyed)
          return;
        destroyed = true;
        ended = true;
        buffer.length = 0;
        stream.writable = stream.readable = false;
        stream.emit("close");
        return stream;
      };
      stream.pause = function() {
        if (stream.paused)
          return;
        stream.paused = true;
        return stream;
      };
      stream.resume = function() {
        if (stream.paused) {
          stream.paused = false;
          stream.emit("resume");
        }
        drain();
        if (!stream.paused)
          stream.emit("drain");
        return stream;
      };
      return stream;
    }
  }
});

// node_modules/mute-stream/mute.js
var require_mute = __commonJS({
  "node_modules/mute-stream/mute.js"(exports, module2) {
    var Stream = require("stream");
    module2.exports = MuteStream;
    function MuteStream(opts) {
      Stream.apply(this);
      opts = opts || {};
      this.writable = this.readable = true;
      this.muted = false;
      this.on("pipe", this._onpipe);
      this.replace = opts.replace;
      this._prompt = opts.prompt || null;
      this._hadControl = false;
    }
    MuteStream.prototype = Object.create(Stream.prototype);
    Object.defineProperty(MuteStream.prototype, "constructor", {
      value: MuteStream,
      enumerable: false
    });
    MuteStream.prototype.mute = function() {
      this.muted = true;
    };
    MuteStream.prototype.unmute = function() {
      this.muted = false;
    };
    Object.defineProperty(MuteStream.prototype, "_onpipe", {
      value: onPipe,
      enumerable: false,
      writable: true,
      configurable: true
    });
    function onPipe(src) {
      this._src = src;
    }
    Object.defineProperty(MuteStream.prototype, "isTTY", {
      get: getIsTTY,
      set: setIsTTY,
      enumerable: true,
      configurable: true
    });
    function getIsTTY() {
      return this._dest ? this._dest.isTTY : this._src ? this._src.isTTY : false;
    }
    function setIsTTY(isTTY) {
      Object.defineProperty(this, "isTTY", {
        value: isTTY,
        enumerable: true,
        writable: true,
        configurable: true
      });
    }
    Object.defineProperty(MuteStream.prototype, "rows", {
      get: function() {
        return this._dest ? this._dest.rows : this._src ? this._src.rows : void 0;
      },
      enumerable: true,
      configurable: true
    });
    Object.defineProperty(MuteStream.prototype, "columns", {
      get: function() {
        return this._dest ? this._dest.columns : this._src ? this._src.columns : void 0;
      },
      enumerable: true,
      configurable: true
    });
    MuteStream.prototype.pipe = function(dest, options) {
      this._dest = dest;
      return Stream.prototype.pipe.call(this, dest, options);
    };
    MuteStream.prototype.pause = function() {
      if (this._src)
        return this._src.pause();
    };
    MuteStream.prototype.resume = function() {
      if (this._src)
        return this._src.resume();
    };
    MuteStream.prototype.write = function(c) {
      if (this.muted) {
        if (!this.replace)
          return true;
        if (c.match(/^\u001b/)) {
          if (c.indexOf(this._prompt) === 0) {
            c = c.substr(this._prompt.length);
            c = c.replace(/./g, this.replace);
            c = this._prompt + c;
          }
          this._hadControl = true;
          return this.emit("data", c);
        } else {
          if (this._prompt && this._hadControl && c.indexOf(this._prompt) === 0) {
            this._hadControl = false;
            this.emit("data", this._prompt);
            c = c.substr(this._prompt.length);
          }
          c = c.toString().replace(/./g, this.replace);
        }
      }
      this.emit("data", c);
    };
    MuteStream.prototype.end = function(c) {
      if (this.muted) {
        if (c && this.replace) {
          c = c.toString().replace(/./g, this.replace);
        } else {
          c = null;
        }
      }
      if (c)
        this.emit("data", c);
      this.emit("end");
    };
    function proxy(fn) {
      return function() {
        var d = this._dest;
        var s = this._src;
        if (d && d[fn])
          d[fn].apply(d, arguments);
        if (s && s[fn])
          s[fn].apply(s, arguments);
      };
    }
    MuteStream.prototype.destroy = proxy("destroy");
    MuteStream.prototype.destroySoon = proxy("destroySoon");
    MuteStream.prototype.close = proxy("close");
  }
});

// node_modules/inquirer/lib/ui/baseUI.js
var require_baseUI = __commonJS({
  "node_modules/inquirer/lib/ui/baseUI.js"(exports, module2) {
    "use strict";
    var MuteStream = require_mute();
    var readline = require("readline");
    var UI = class {
      constructor(opt) {
        if (!this.rl) {
          this.rl = readline.createInterface(setupReadlineOptions(opt));
        }
        this.rl.resume();
        this.onForceClose = this.onForceClose.bind(this);
        process.on("exit", this.onForceClose);
        this.rl.on("SIGINT", this.onForceClose);
      }
      /**
       * Handle the ^C exit
       * @return {null}
       */
      onForceClose() {
        this.close();
        process.kill(process.pid, "SIGINT");
        console.log("");
      }
      /**
       * Close the interface and cleanup listeners
       */
      close() {
        this.rl.removeListener("SIGINT", this.onForceClose);
        process.removeListener("exit", this.onForceClose);
        this.rl.output.unmute();
        if (this.activePrompt && typeof this.activePrompt.close === "function") {
          this.activePrompt.close();
        }
        this.rl.output.end();
        this.rl.pause();
        this.rl.close();
      }
    };
    function setupReadlineOptions(opt = {}) {
      opt.skipTTYChecks = opt.skipTTYChecks === void 0 ? true : opt.skipTTYChecks;
      const input = opt.input || process.stdin;
      if (!opt.skipTTYChecks && !input.isTTY) {
        const nonTtyError = new Error(
          "Prompts can not be meaningfully rendered in non-TTY environments"
        );
        nonTtyError.isTtyError = true;
        throw nonTtyError;
      }
      const ms = new MuteStream();
      ms.pipe(opt.output || process.stdout);
      const output = ms;
      return {
        terminal: true,
        ...opt,
        input,
        output
      };
    }
    module2.exports = UI;
  }
});

// node_modules/ansi-escapes/index.js
var require_ansi_escapes = __commonJS({
  "node_modules/ansi-escapes/index.js"(exports, module2) {
    "use strict";
    var ansiEscapes = module2.exports;
    module2.exports.default = ansiEscapes;
    var ESC = "\x1B[";
    var OSC = "\x1B]";
    var BEL = "\x07";
    var SEP = ";";
    var isTerminalApp = process.env.TERM_PROGRAM === "Apple_Terminal";
    ansiEscapes.cursorTo = (x, y) => {
      if (typeof x !== "number") {
        throw new TypeError("The `x` argument is required");
      }
      if (typeof y !== "number") {
        return ESC + (x + 1) + "G";
      }
      return ESC + (y + 1) + ";" + (x + 1) + "H";
    };
    ansiEscapes.cursorMove = (x, y) => {
      if (typeof x !== "number") {
        throw new TypeError("The `x` argument is required");
      }
      let ret = "";
      if (x < 0) {
        ret += ESC + -x + "D";
      } else if (x > 0) {
        ret += ESC + x + "C";
      }
      if (y < 0) {
        ret += ESC + -y + "A";
      } else if (y > 0) {
        ret += ESC + y + "B";
      }
      return ret;
    };
    ansiEscapes.cursorUp = (count = 1) => ESC + count + "A";
    ansiEscapes.cursorDown = (count = 1) => ESC + count + "B";
    ansiEscapes.cursorForward = (count = 1) => ESC + count + "C";
    ansiEscapes.cursorBackward = (count = 1) => ESC + count + "D";
    ansiEscapes.cursorLeft = ESC + "G";
    ansiEscapes.cursorSavePosition = isTerminalApp ? "\x1B7" : ESC + "s";
    ansiEscapes.cursorRestorePosition = isTerminalApp ? "\x1B8" : ESC + "u";
    ansiEscapes.cursorGetPosition = ESC + "6n";
    ansiEscapes.cursorNextLine = ESC + "E";
    ansiEscapes.cursorPrevLine = ESC + "F";
    ansiEscapes.cursorHide = ESC + "?25l";
    ansiEscapes.cursorShow = ESC + "?25h";
    ansiEscapes.eraseLines = (count) => {
      let clear = "";
      for (let i = 0; i < count; i++) {
        clear += ansiEscapes.eraseLine + (i < count - 1 ? ansiEscapes.cursorUp() : "");
      }
      if (count) {
        clear += ansiEscapes.cursorLeft;
      }
      return clear;
    };
    ansiEscapes.eraseEndLine = ESC + "K";
    ansiEscapes.eraseStartLine = ESC + "1K";
    ansiEscapes.eraseLine = ESC + "2K";
    ansiEscapes.eraseDown = ESC + "J";
    ansiEscapes.eraseUp = ESC + "1J";
    ansiEscapes.eraseScreen = ESC + "2J";
    ansiEscapes.scrollUp = ESC + "S";
    ansiEscapes.scrollDown = ESC + "T";
    ansiEscapes.clearScreen = "\x1Bc";
    ansiEscapes.clearTerminal = process.platform === "win32" ? `${ansiEscapes.eraseScreen}${ESC}0f` : (
      // 1. Erases the screen (Only done in case `2` is not supported)
      // 2. Erases the whole screen including scrollback buffer
      // 3. Moves cursor to the top-left position
      // More info: https://www.real-world-systems.com/docs/ANSIcode.html
      `${ansiEscapes.eraseScreen}${ESC}3J${ESC}H`
    );
    ansiEscapes.beep = BEL;
    ansiEscapes.link = (text, url) => {
      return [
        OSC,
        "8",
        SEP,
        SEP,
        url,
        BEL,
        text,
        OSC,
        "8",
        SEP,
        SEP,
        BEL
      ].join("");
    };
    ansiEscapes.image = (buffer, options = {}) => {
      let ret = `${OSC}1337;File=inline=1`;
      if (options.width) {
        ret += `;width=${options.width}`;
      }
      if (options.height) {
        ret += `;height=${options.height}`;
      }
      if (options.preserveAspectRatio === false) {
        ret += ";preserveAspectRatio=0";
      }
      return ret + ":" + buffer.toString("base64") + BEL;
    };
    ansiEscapes.iTerm = {
      setCwd: (cwd = process.cwd()) => `${OSC}50;CurrentDir=${cwd}${BEL}`,
      annotation: (message, options = {}) => {
        let ret = `${OSC}1337;`;
        const hasX = typeof options.x !== "undefined";
        const hasY = typeof options.y !== "undefined";
        if ((hasX || hasY) && !(hasX && hasY && typeof options.length !== "undefined")) {
          throw new Error("`x`, `y` and `length` must be defined when `x` or `y` is defined");
        }
        message = message.replace(/\|/g, "");
        ret += options.isHidden ? "AddHiddenAnnotation=" : "AddAnnotation=";
        if (options.length > 0) {
          ret += (hasX ? [message, options.length, options.x, options.y] : [options.length, message]).join("|");
        } else {
          ret += message;
        }
        return ret + BEL;
      }
    };
  }
});

// node_modules/inquirer/lib/utils/readline.js
var require_readline = __commonJS({
  "node_modules/inquirer/lib/utils/readline.js"(exports) {
    "use strict";
    var ansiEscapes = require_ansi_escapes();
    exports.left = function(rl, x) {
      rl.output.write(ansiEscapes.cursorBackward(x));
    };
    exports.right = function(rl, x) {
      rl.output.write(ansiEscapes.cursorForward(x));
    };
    exports.up = function(rl, x) {
      rl.output.write(ansiEscapes.cursorUp(x));
    };
    exports.down = function(rl, x) {
      rl.output.write(ansiEscapes.cursorDown(x));
    };
    exports.clearLine = function(rl, len) {
      rl.output.write(ansiEscapes.eraseLines(len));
    };
  }
});

// node_modules/inquirer/lib/ui/bottom-bar.js
var require_bottom_bar = __commonJS({
  "node_modules/inquirer/lib/ui/bottom-bar.js"(exports, module2) {
    "use strict";
    var through = require_through();
    var Base = require_baseUI();
    var rlUtils = require_readline();
    var BottomBar = class extends Base {
      constructor(opt = {}) {
        super(opt);
        this.log = through(this.writeLog.bind(this));
        this.bottomBar = opt.bottomBar || "";
        this.render();
      }
      /**
       * Render the prompt to screen
       * @return {BottomBar} self
       */
      render() {
        this.write(this.bottomBar);
        return this;
      }
      clean() {
        rlUtils.clearLine(this.rl, this.bottomBar.split("\n").length);
        return this;
      }
      /**
       * Update the bottom bar content and rerender
       * @param  {String} bottomBar Bottom bar content
       * @return {BottomBar}           self
       */
      updateBottomBar(bottomBar) {
        rlUtils.clearLine(this.rl, 1);
        this.rl.output.unmute();
        this.clean();
        this.bottomBar = bottomBar;
        this.render();
        this.rl.output.mute();
        return this;
      }
      /**
       * Write out log data
       * @param {String} data - The log data to be output
       * @return {BottomBar} self
       */
      writeLog(data) {
        this.rl.output.unmute();
        this.clean();
        this.rl.output.write(this.enforceLF(data.toString()));
        this.render();
        this.rl.output.mute();
        return this;
      }
      /**
       * Make sure line end on a line feed
       * @param  {String} str Input string
       * @return {String}     The input string with a final line feed
       */
      enforceLF(str) {
        return str.match(/[\r\n]$/) ? str : str + "\n";
      }
      /**
       * Helper for writing message in Prompt
       * @param {String} message - The message to be output
       */
      write(message) {
        const msgLines = message.split(/\n/);
        this.height = msgLines.length;
        this.rl.setPrompt(msgLines[msgLines.length - 1]);
        if (this.rl.output.rows === 0 && this.rl.output.columns === 0) {
          rlUtils.left(this.rl, message.length + this.rl.line.length);
        }
        this.rl.output.write(message);
      }
    };
    module2.exports = BottomBar;
  }
});

// node_modules/lodash/_freeGlobal.js
var require_freeGlobal = __commonJS({
  "node_modules/lodash/_freeGlobal.js"(exports, module2) {
    var freeGlobal = typeof global == "object" && global && global.Object === Object && global;
    module2.exports = freeGlobal;
  }
});

// node_modules/lodash/_root.js
var require_root = __commonJS({
  "node_modules/lodash/_root.js"(exports, module2) {
    var freeGlobal = require_freeGlobal();
    var freeSelf = typeof self == "object" && self && self.Object === Object && self;
    var root2 = freeGlobal || freeSelf || Function("return this")();
    module2.exports = root2;
  }
});

// node_modules/lodash/_Symbol.js
var require_Symbol = __commonJS({
  "node_modules/lodash/_Symbol.js"(exports, module2) {
    var root2 = require_root();
    var Symbol2 = root2.Symbol;
    module2.exports = Symbol2;
  }
});

// node_modules/lodash/_getRawTag.js
var require_getRawTag = __commonJS({
  "node_modules/lodash/_getRawTag.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var nativeObjectToString = objectProto.toString;
    var symToStringTag = Symbol2 ? Symbol2.toStringTag : void 0;
    function getRawTag(value2) {
      var isOwn = hasOwnProperty.call(value2, symToStringTag), tag = value2[symToStringTag];
      try {
        value2[symToStringTag] = void 0;
        var unmasked = true;
      } catch (e) {
      }
      var result = nativeObjectToString.call(value2);
      if (unmasked) {
        if (isOwn) {
          value2[symToStringTag] = tag;
        } else {
          delete value2[symToStringTag];
        }
      }
      return result;
    }
    module2.exports = getRawTag;
  }
});

// node_modules/lodash/_objectToString.js
var require_objectToString = __commonJS({
  "node_modules/lodash/_objectToString.js"(exports, module2) {
    var objectProto = Object.prototype;
    var nativeObjectToString = objectProto.toString;
    function objectToString(value2) {
      return nativeObjectToString.call(value2);
    }
    module2.exports = objectToString;
  }
});

// node_modules/lodash/_baseGetTag.js
var require_baseGetTag = __commonJS({
  "node_modules/lodash/_baseGetTag.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var getRawTag = require_getRawTag();
    var objectToString = require_objectToString();
    var nullTag = "[object Null]";
    var undefinedTag = "[object Undefined]";
    var symToStringTag = Symbol2 ? Symbol2.toStringTag : void 0;
    function baseGetTag(value2) {
      if (value2 == null) {
        return value2 === void 0 ? undefinedTag : nullTag;
      }
      return symToStringTag && symToStringTag in Object(value2) ? getRawTag(value2) : objectToString(value2);
    }
    module2.exports = baseGetTag;
  }
});

// node_modules/lodash/_overArg.js
var require_overArg = __commonJS({
  "node_modules/lodash/_overArg.js"(exports, module2) {
    function overArg(func, transform) {
      return function(arg) {
        return func(transform(arg));
      };
    }
    module2.exports = overArg;
  }
});

// node_modules/lodash/_getPrototype.js
var require_getPrototype = __commonJS({
  "node_modules/lodash/_getPrototype.js"(exports, module2) {
    var overArg = require_overArg();
    var getPrototype = overArg(Object.getPrototypeOf, Object);
    module2.exports = getPrototype;
  }
});

// node_modules/lodash/isObjectLike.js
var require_isObjectLike = __commonJS({
  "node_modules/lodash/isObjectLike.js"(exports, module2) {
    function isObjectLike(value2) {
      return value2 != null && typeof value2 == "object";
    }
    module2.exports = isObjectLike;
  }
});

// node_modules/lodash/isPlainObject.js
var require_isPlainObject = __commonJS({
  "node_modules/lodash/isPlainObject.js"(exports, module2) {
    var baseGetTag = require_baseGetTag();
    var getPrototype = require_getPrototype();
    var isObjectLike = require_isObjectLike();
    var objectTag = "[object Object]";
    var funcProto = Function.prototype;
    var objectProto = Object.prototype;
    var funcToString = funcProto.toString;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var objectCtorString = funcToString.call(Object);
    function isPlainObject(value2) {
      if (!isObjectLike(value2) || baseGetTag(value2) != objectTag) {
        return false;
      }
      var proto = getPrototype(value2);
      if (proto === null) {
        return true;
      }
      var Ctor = hasOwnProperty.call(proto, "constructor") && proto.constructor;
      return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString.call(Ctor) == objectCtorString;
    }
    module2.exports = isPlainObject;
  }
});

// node_modules/lodash/isArray.js
var require_isArray = __commonJS({
  "node_modules/lodash/isArray.js"(exports, module2) {
    var isArray2 = Array.isArray;
    module2.exports = isArray2;
  }
});

// node_modules/lodash/isSymbol.js
var require_isSymbol = __commonJS({
  "node_modules/lodash/isSymbol.js"(exports, module2) {
    var baseGetTag = require_baseGetTag();
    var isObjectLike = require_isObjectLike();
    var symbolTag = "[object Symbol]";
    function isSymbol(value2) {
      return typeof value2 == "symbol" || isObjectLike(value2) && baseGetTag(value2) == symbolTag;
    }
    module2.exports = isSymbol;
  }
});

// node_modules/lodash/_isKey.js
var require_isKey = __commonJS({
  "node_modules/lodash/_isKey.js"(exports, module2) {
    var isArray2 = require_isArray();
    var isSymbol = require_isSymbol();
    var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/;
    var reIsPlainProp = /^\w*$/;
    function isKey(value2, object) {
      if (isArray2(value2)) {
        return false;
      }
      var type = typeof value2;
      if (type == "number" || type == "symbol" || type == "boolean" || value2 == null || isSymbol(value2)) {
        return true;
      }
      return reIsPlainProp.test(value2) || !reIsDeepProp.test(value2) || object != null && value2 in Object(object);
    }
    module2.exports = isKey;
  }
});

// node_modules/lodash/isObject.js
var require_isObject = __commonJS({
  "node_modules/lodash/isObject.js"(exports, module2) {
    function isObject(value2) {
      var type = typeof value2;
      return value2 != null && (type == "object" || type == "function");
    }
    module2.exports = isObject;
  }
});

// node_modules/lodash/isFunction.js
var require_isFunction = __commonJS({
  "node_modules/lodash/isFunction.js"(exports, module2) {
    var baseGetTag = require_baseGetTag();
    var isObject = require_isObject();
    var asyncTag = "[object AsyncFunction]";
    var funcTag = "[object Function]";
    var genTag = "[object GeneratorFunction]";
    var proxyTag = "[object Proxy]";
    function isFunction(value2) {
      if (!isObject(value2)) {
        return false;
      }
      var tag = baseGetTag(value2);
      return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
    }
    module2.exports = isFunction;
  }
});

// node_modules/lodash/_coreJsData.js
var require_coreJsData = __commonJS({
  "node_modules/lodash/_coreJsData.js"(exports, module2) {
    var root2 = require_root();
    var coreJsData = root2["__core-js_shared__"];
    module2.exports = coreJsData;
  }
});

// node_modules/lodash/_isMasked.js
var require_isMasked = __commonJS({
  "node_modules/lodash/_isMasked.js"(exports, module2) {
    var coreJsData = require_coreJsData();
    var maskSrcKey = function() {
      var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
      return uid ? "Symbol(src)_1." + uid : "";
    }();
    function isMasked(func) {
      return !!maskSrcKey && maskSrcKey in func;
    }
    module2.exports = isMasked;
  }
});

// node_modules/lodash/_toSource.js
var require_toSource = __commonJS({
  "node_modules/lodash/_toSource.js"(exports, module2) {
    var funcProto = Function.prototype;
    var funcToString = funcProto.toString;
    function toSource(func) {
      if (func != null) {
        try {
          return funcToString.call(func);
        } catch (e) {
        }
        try {
          return func + "";
        } catch (e) {
        }
      }
      return "";
    }
    module2.exports = toSource;
  }
});

// node_modules/lodash/_baseIsNative.js
var require_baseIsNative = __commonJS({
  "node_modules/lodash/_baseIsNative.js"(exports, module2) {
    var isFunction = require_isFunction();
    var isMasked = require_isMasked();
    var isObject = require_isObject();
    var toSource = require_toSource();
    var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
    var reIsHostCtor = /^\[object .+?Constructor\]$/;
    var funcProto = Function.prototype;
    var objectProto = Object.prototype;
    var funcToString = funcProto.toString;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var reIsNative = RegExp(
      "^" + funcToString.call(hasOwnProperty).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
    );
    function baseIsNative(value2) {
      if (!isObject(value2) || isMasked(value2)) {
        return false;
      }
      var pattern = isFunction(value2) ? reIsNative : reIsHostCtor;
      return pattern.test(toSource(value2));
    }
    module2.exports = baseIsNative;
  }
});

// node_modules/lodash/_getValue.js
var require_getValue = __commonJS({
  "node_modules/lodash/_getValue.js"(exports, module2) {
    function getValue(object, key) {
      return object == null ? void 0 : object[key];
    }
    module2.exports = getValue;
  }
});

// node_modules/lodash/_getNative.js
var require_getNative = __commonJS({
  "node_modules/lodash/_getNative.js"(exports, module2) {
    var baseIsNative = require_baseIsNative();
    var getValue = require_getValue();
    function getNative(object, key) {
      var value2 = getValue(object, key);
      return baseIsNative(value2) ? value2 : void 0;
    }
    module2.exports = getNative;
  }
});

// node_modules/lodash/_nativeCreate.js
var require_nativeCreate = __commonJS({
  "node_modules/lodash/_nativeCreate.js"(exports, module2) {
    var getNative = require_getNative();
    var nativeCreate = getNative(Object, "create");
    module2.exports = nativeCreate;
  }
});

// node_modules/lodash/_hashClear.js
var require_hashClear = __commonJS({
  "node_modules/lodash/_hashClear.js"(exports, module2) {
    var nativeCreate = require_nativeCreate();
    function hashClear() {
      this.__data__ = nativeCreate ? nativeCreate(null) : {};
      this.size = 0;
    }
    module2.exports = hashClear;
  }
});

// node_modules/lodash/_hashDelete.js
var require_hashDelete = __commonJS({
  "node_modules/lodash/_hashDelete.js"(exports, module2) {
    function hashDelete(key) {
      var result = this.has(key) && delete this.__data__[key];
      this.size -= result ? 1 : 0;
      return result;
    }
    module2.exports = hashDelete;
  }
});

// node_modules/lodash/_hashGet.js
var require_hashGet = __commonJS({
  "node_modules/lodash/_hashGet.js"(exports, module2) {
    var nativeCreate = require_nativeCreate();
    var HASH_UNDEFINED = "__lodash_hash_undefined__";
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function hashGet(key) {
      var data = this.__data__;
      if (nativeCreate) {
        var result = data[key];
        return result === HASH_UNDEFINED ? void 0 : result;
      }
      return hasOwnProperty.call(data, key) ? data[key] : void 0;
    }
    module2.exports = hashGet;
  }
});

// node_modules/lodash/_hashHas.js
var require_hashHas = __commonJS({
  "node_modules/lodash/_hashHas.js"(exports, module2) {
    var nativeCreate = require_nativeCreate();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function hashHas(key) {
      var data = this.__data__;
      return nativeCreate ? data[key] !== void 0 : hasOwnProperty.call(data, key);
    }
    module2.exports = hashHas;
  }
});

// node_modules/lodash/_hashSet.js
var require_hashSet = __commonJS({
  "node_modules/lodash/_hashSet.js"(exports, module2) {
    var nativeCreate = require_nativeCreate();
    var HASH_UNDEFINED = "__lodash_hash_undefined__";
    function hashSet(key, value2) {
      var data = this.__data__;
      this.size += this.has(key) ? 0 : 1;
      data[key] = nativeCreate && value2 === void 0 ? HASH_UNDEFINED : value2;
      return this;
    }
    module2.exports = hashSet;
  }
});

// node_modules/lodash/_Hash.js
var require_Hash = __commonJS({
  "node_modules/lodash/_Hash.js"(exports, module2) {
    var hashClear = require_hashClear();
    var hashDelete = require_hashDelete();
    var hashGet = require_hashGet();
    var hashHas = require_hashHas();
    var hashSet = require_hashSet();
    function Hash(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    Hash.prototype.clear = hashClear;
    Hash.prototype["delete"] = hashDelete;
    Hash.prototype.get = hashGet;
    Hash.prototype.has = hashHas;
    Hash.prototype.set = hashSet;
    module2.exports = Hash;
  }
});

// node_modules/lodash/_listCacheClear.js
var require_listCacheClear = __commonJS({
  "node_modules/lodash/_listCacheClear.js"(exports, module2) {
    function listCacheClear() {
      this.__data__ = [];
      this.size = 0;
    }
    module2.exports = listCacheClear;
  }
});

// node_modules/lodash/eq.js
var require_eq = __commonJS({
  "node_modules/lodash/eq.js"(exports, module2) {
    function eq(value2, other) {
      return value2 === other || value2 !== value2 && other !== other;
    }
    module2.exports = eq;
  }
});

// node_modules/lodash/_assocIndexOf.js
var require_assocIndexOf = __commonJS({
  "node_modules/lodash/_assocIndexOf.js"(exports, module2) {
    var eq = require_eq();
    function assocIndexOf(array, key) {
      var length = array.length;
      while (length--) {
        if (eq(array[length][0], key)) {
          return length;
        }
      }
      return -1;
    }
    module2.exports = assocIndexOf;
  }
});

// node_modules/lodash/_listCacheDelete.js
var require_listCacheDelete = __commonJS({
  "node_modules/lodash/_listCacheDelete.js"(exports, module2) {
    var assocIndexOf = require_assocIndexOf();
    var arrayProto = Array.prototype;
    var splice = arrayProto.splice;
    function listCacheDelete(key) {
      var data = this.__data__, index = assocIndexOf(data, key);
      if (index < 0) {
        return false;
      }
      var lastIndex = data.length - 1;
      if (index == lastIndex) {
        data.pop();
      } else {
        splice.call(data, index, 1);
      }
      --this.size;
      return true;
    }
    module2.exports = listCacheDelete;
  }
});

// node_modules/lodash/_listCacheGet.js
var require_listCacheGet = __commonJS({
  "node_modules/lodash/_listCacheGet.js"(exports, module2) {
    var assocIndexOf = require_assocIndexOf();
    function listCacheGet(key) {
      var data = this.__data__, index = assocIndexOf(data, key);
      return index < 0 ? void 0 : data[index][1];
    }
    module2.exports = listCacheGet;
  }
});

// node_modules/lodash/_listCacheHas.js
var require_listCacheHas = __commonJS({
  "node_modules/lodash/_listCacheHas.js"(exports, module2) {
    var assocIndexOf = require_assocIndexOf();
    function listCacheHas(key) {
      return assocIndexOf(this.__data__, key) > -1;
    }
    module2.exports = listCacheHas;
  }
});

// node_modules/lodash/_listCacheSet.js
var require_listCacheSet = __commonJS({
  "node_modules/lodash/_listCacheSet.js"(exports, module2) {
    var assocIndexOf = require_assocIndexOf();
    function listCacheSet(key, value2) {
      var data = this.__data__, index = assocIndexOf(data, key);
      if (index < 0) {
        ++this.size;
        data.push([key, value2]);
      } else {
        data[index][1] = value2;
      }
      return this;
    }
    module2.exports = listCacheSet;
  }
});

// node_modules/lodash/_ListCache.js
var require_ListCache = __commonJS({
  "node_modules/lodash/_ListCache.js"(exports, module2) {
    var listCacheClear = require_listCacheClear();
    var listCacheDelete = require_listCacheDelete();
    var listCacheGet = require_listCacheGet();
    var listCacheHas = require_listCacheHas();
    var listCacheSet = require_listCacheSet();
    function ListCache(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    ListCache.prototype.clear = listCacheClear;
    ListCache.prototype["delete"] = listCacheDelete;
    ListCache.prototype.get = listCacheGet;
    ListCache.prototype.has = listCacheHas;
    ListCache.prototype.set = listCacheSet;
    module2.exports = ListCache;
  }
});

// node_modules/lodash/_Map.js
var require_Map = __commonJS({
  "node_modules/lodash/_Map.js"(exports, module2) {
    var getNative = require_getNative();
    var root2 = require_root();
    var Map2 = getNative(root2, "Map");
    module2.exports = Map2;
  }
});

// node_modules/lodash/_mapCacheClear.js
var require_mapCacheClear = __commonJS({
  "node_modules/lodash/_mapCacheClear.js"(exports, module2) {
    var Hash = require_Hash();
    var ListCache = require_ListCache();
    var Map2 = require_Map();
    function mapCacheClear() {
      this.size = 0;
      this.__data__ = {
        "hash": new Hash(),
        "map": new (Map2 || ListCache)(),
        "string": new Hash()
      };
    }
    module2.exports = mapCacheClear;
  }
});

// node_modules/lodash/_isKeyable.js
var require_isKeyable = __commonJS({
  "node_modules/lodash/_isKeyable.js"(exports, module2) {
    function isKeyable(value2) {
      var type = typeof value2;
      return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value2 !== "__proto__" : value2 === null;
    }
    module2.exports = isKeyable;
  }
});

// node_modules/lodash/_getMapData.js
var require_getMapData = __commonJS({
  "node_modules/lodash/_getMapData.js"(exports, module2) {
    var isKeyable = require_isKeyable();
    function getMapData(map, key) {
      var data = map.__data__;
      return isKeyable(key) ? data[typeof key == "string" ? "string" : "hash"] : data.map;
    }
    module2.exports = getMapData;
  }
});

// node_modules/lodash/_mapCacheDelete.js
var require_mapCacheDelete = __commonJS({
  "node_modules/lodash/_mapCacheDelete.js"(exports, module2) {
    var getMapData = require_getMapData();
    function mapCacheDelete(key) {
      var result = getMapData(this, key)["delete"](key);
      this.size -= result ? 1 : 0;
      return result;
    }
    module2.exports = mapCacheDelete;
  }
});

// node_modules/lodash/_mapCacheGet.js
var require_mapCacheGet = __commonJS({
  "node_modules/lodash/_mapCacheGet.js"(exports, module2) {
    var getMapData = require_getMapData();
    function mapCacheGet(key) {
      return getMapData(this, key).get(key);
    }
    module2.exports = mapCacheGet;
  }
});

// node_modules/lodash/_mapCacheHas.js
var require_mapCacheHas = __commonJS({
  "node_modules/lodash/_mapCacheHas.js"(exports, module2) {
    var getMapData = require_getMapData();
    function mapCacheHas(key) {
      return getMapData(this, key).has(key);
    }
    module2.exports = mapCacheHas;
  }
});

// node_modules/lodash/_mapCacheSet.js
var require_mapCacheSet = __commonJS({
  "node_modules/lodash/_mapCacheSet.js"(exports, module2) {
    var getMapData = require_getMapData();
    function mapCacheSet(key, value2) {
      var data = getMapData(this, key), size = data.size;
      data.set(key, value2);
      this.size += data.size == size ? 0 : 1;
      return this;
    }
    module2.exports = mapCacheSet;
  }
});

// node_modules/lodash/_MapCache.js
var require_MapCache = __commonJS({
  "node_modules/lodash/_MapCache.js"(exports, module2) {
    var mapCacheClear = require_mapCacheClear();
    var mapCacheDelete = require_mapCacheDelete();
    var mapCacheGet = require_mapCacheGet();
    var mapCacheHas = require_mapCacheHas();
    var mapCacheSet = require_mapCacheSet();
    function MapCache(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    MapCache.prototype.clear = mapCacheClear;
    MapCache.prototype["delete"] = mapCacheDelete;
    MapCache.prototype.get = mapCacheGet;
    MapCache.prototype.has = mapCacheHas;
    MapCache.prototype.set = mapCacheSet;
    module2.exports = MapCache;
  }
});

// node_modules/lodash/memoize.js
var require_memoize = __commonJS({
  "node_modules/lodash/memoize.js"(exports, module2) {
    var MapCache = require_MapCache();
    var FUNC_ERROR_TEXT = "Expected a function";
    function memoize(func, resolver) {
      if (typeof func != "function" || resolver != null && typeof resolver != "function") {
        throw new TypeError(FUNC_ERROR_TEXT);
      }
      var memoized = function() {
        var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache = memoized.cache;
        if (cache.has(key)) {
          return cache.get(key);
        }
        var result = func.apply(this, args);
        memoized.cache = cache.set(key, result) || cache;
        return result;
      };
      memoized.cache = new (memoize.Cache || MapCache)();
      return memoized;
    }
    memoize.Cache = MapCache;
    module2.exports = memoize;
  }
});

// node_modules/lodash/_memoizeCapped.js
var require_memoizeCapped = __commonJS({
  "node_modules/lodash/_memoizeCapped.js"(exports, module2) {
    var memoize = require_memoize();
    var MAX_MEMOIZE_SIZE = 500;
    function memoizeCapped(func) {
      var result = memoize(func, function(key) {
        if (cache.size === MAX_MEMOIZE_SIZE) {
          cache.clear();
        }
        return key;
      });
      var cache = result.cache;
      return result;
    }
    module2.exports = memoizeCapped;
  }
});

// node_modules/lodash/_stringToPath.js
var require_stringToPath = __commonJS({
  "node_modules/lodash/_stringToPath.js"(exports, module2) {
    var memoizeCapped = require_memoizeCapped();
    var rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;
    var reEscapeChar = /\\(\\)?/g;
    var stringToPath = memoizeCapped(function(string) {
      var result = [];
      if (string.charCodeAt(0) === 46) {
        result.push("");
      }
      string.replace(rePropName, function(match, number, quote, subString) {
        result.push(quote ? subString.replace(reEscapeChar, "$1") : number || match);
      });
      return result;
    });
    module2.exports = stringToPath;
  }
});

// node_modules/lodash/_arrayMap.js
var require_arrayMap = __commonJS({
  "node_modules/lodash/_arrayMap.js"(exports, module2) {
    function arrayMap(array, iteratee) {
      var index = -1, length = array == null ? 0 : array.length, result = Array(length);
      while (++index < length) {
        result[index] = iteratee(array[index], index, array);
      }
      return result;
    }
    module2.exports = arrayMap;
  }
});

// node_modules/lodash/_baseToString.js
var require_baseToString = __commonJS({
  "node_modules/lodash/_baseToString.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var arrayMap = require_arrayMap();
    var isArray2 = require_isArray();
    var isSymbol = require_isSymbol();
    var INFINITY = 1 / 0;
    var symbolProto = Symbol2 ? Symbol2.prototype : void 0;
    var symbolToString = symbolProto ? symbolProto.toString : void 0;
    function baseToString(value2) {
      if (typeof value2 == "string") {
        return value2;
      }
      if (isArray2(value2)) {
        return arrayMap(value2, baseToString) + "";
      }
      if (isSymbol(value2)) {
        return symbolToString ? symbolToString.call(value2) : "";
      }
      var result = value2 + "";
      return result == "0" && 1 / value2 == -INFINITY ? "-0" : result;
    }
    module2.exports = baseToString;
  }
});

// node_modules/lodash/toString.js
var require_toString = __commonJS({
  "node_modules/lodash/toString.js"(exports, module2) {
    var baseToString = require_baseToString();
    function toString(value2) {
      return value2 == null ? "" : baseToString(value2);
    }
    module2.exports = toString;
  }
});

// node_modules/lodash/_castPath.js
var require_castPath = __commonJS({
  "node_modules/lodash/_castPath.js"(exports, module2) {
    var isArray2 = require_isArray();
    var isKey = require_isKey();
    var stringToPath = require_stringToPath();
    var toString = require_toString();
    function castPath(value2, object) {
      if (isArray2(value2)) {
        return value2;
      }
      return isKey(value2, object) ? [value2] : stringToPath(toString(value2));
    }
    module2.exports = castPath;
  }
});

// node_modules/lodash/_toKey.js
var require_toKey = __commonJS({
  "node_modules/lodash/_toKey.js"(exports, module2) {
    var isSymbol = require_isSymbol();
    var INFINITY = 1 / 0;
    function toKey(value2) {
      if (typeof value2 == "string" || isSymbol(value2)) {
        return value2;
      }
      var result = value2 + "";
      return result == "0" && 1 / value2 == -INFINITY ? "-0" : result;
    }
    module2.exports = toKey;
  }
});

// node_modules/lodash/_baseGet.js
var require_baseGet = __commonJS({
  "node_modules/lodash/_baseGet.js"(exports, module2) {
    var castPath = require_castPath();
    var toKey = require_toKey();
    function baseGet(object, path2) {
      path2 = castPath(path2, object);
      var index = 0, length = path2.length;
      while (object != null && index < length) {
        object = object[toKey(path2[index++])];
      }
      return index && index == length ? object : void 0;
    }
    module2.exports = baseGet;
  }
});

// node_modules/lodash/get.js
var require_get = __commonJS({
  "node_modules/lodash/get.js"(exports, module2) {
    var baseGet = require_baseGet();
    function get(object, path2, defaultValue) {
      var result = object == null ? void 0 : baseGet(object, path2);
      return result === void 0 ? defaultValue : result;
    }
    module2.exports = get;
  }
});

// node_modules/lodash/_defineProperty.js
var require_defineProperty = __commonJS({
  "node_modules/lodash/_defineProperty.js"(exports, module2) {
    var getNative = require_getNative();
    var defineProperty = function() {
      try {
        var func = getNative(Object, "defineProperty");
        func({}, "", {});
        return func;
      } catch (e) {
      }
    }();
    module2.exports = defineProperty;
  }
});

// node_modules/lodash/_baseAssignValue.js
var require_baseAssignValue = __commonJS({
  "node_modules/lodash/_baseAssignValue.js"(exports, module2) {
    var defineProperty = require_defineProperty();
    function baseAssignValue(object, key, value2) {
      if (key == "__proto__" && defineProperty) {
        defineProperty(object, key, {
          "configurable": true,
          "enumerable": true,
          "value": value2,
          "writable": true
        });
      } else {
        object[key] = value2;
      }
    }
    module2.exports = baseAssignValue;
  }
});

// node_modules/lodash/_assignValue.js
var require_assignValue = __commonJS({
  "node_modules/lodash/_assignValue.js"(exports, module2) {
    var baseAssignValue = require_baseAssignValue();
    var eq = require_eq();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function assignValue(object, key, value2) {
      var objValue = object[key];
      if (!(hasOwnProperty.call(object, key) && eq(objValue, value2)) || value2 === void 0 && !(key in object)) {
        baseAssignValue(object, key, value2);
      }
    }
    module2.exports = assignValue;
  }
});

// node_modules/lodash/_isIndex.js
var require_isIndex = __commonJS({
  "node_modules/lodash/_isIndex.js"(exports, module2) {
    var MAX_SAFE_INTEGER = 9007199254740991;
    var reIsUint = /^(?:0|[1-9]\d*)$/;
    function isIndex(value2, length) {
      var type = typeof value2;
      length = length == null ? MAX_SAFE_INTEGER : length;
      return !!length && (type == "number" || type != "symbol" && reIsUint.test(value2)) && (value2 > -1 && value2 % 1 == 0 && value2 < length);
    }
    module2.exports = isIndex;
  }
});

// node_modules/lodash/_baseSet.js
var require_baseSet = __commonJS({
  "node_modules/lodash/_baseSet.js"(exports, module2) {
    var assignValue = require_assignValue();
    var castPath = require_castPath();
    var isIndex = require_isIndex();
    var isObject = require_isObject();
    var toKey = require_toKey();
    function baseSet(object, path2, value2, customizer) {
      if (!isObject(object)) {
        return object;
      }
      path2 = castPath(path2, object);
      var index = -1, length = path2.length, lastIndex = length - 1, nested = object;
      while (nested != null && ++index < length) {
        var key = toKey(path2[index]), newValue = value2;
        if (key === "__proto__" || key === "constructor" || key === "prototype") {
          return object;
        }
        if (index != lastIndex) {
          var objValue = nested[key];
          newValue = customizer ? customizer(objValue, key, nested) : void 0;
          if (newValue === void 0) {
            newValue = isObject(objValue) ? objValue : isIndex(path2[index + 1]) ? [] : {};
          }
        }
        assignValue(nested, key, newValue);
        nested = nested[key];
      }
      return object;
    }
    module2.exports = baseSet;
  }
});

// node_modules/lodash/set.js
var require_set = __commonJS({
  "node_modules/lodash/set.js"(exports, module2) {
    var baseSet = require_baseSet();
    function set(object, path2, value2) {
      return object == null ? object : baseSet(object, path2, value2);
    }
    module2.exports = set;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isFunction.js
var require_isFunction2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isFunction.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isFunction = void 0;
    function isFunction(value2) {
      return typeof value2 === "function";
    }
    exports.isFunction = isFunction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/createErrorClass.js
var require_createErrorClass = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/createErrorClass.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createErrorClass = void 0;
    function createErrorClass(createImpl) {
      var _super = function(instance) {
        Error.call(instance);
        instance.stack = new Error().stack;
      };
      var ctorFunc = createImpl(_super);
      ctorFunc.prototype = Object.create(Error.prototype);
      ctorFunc.prototype.constructor = ctorFunc;
      return ctorFunc;
    }
    exports.createErrorClass = createErrorClass;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/UnsubscriptionError.js
var require_UnsubscriptionError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/UnsubscriptionError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.UnsubscriptionError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.UnsubscriptionError = createErrorClass_1.createErrorClass(function(_super) {
      return function UnsubscriptionErrorImpl(errors) {
        _super(this);
        this.message = errors ? errors.length + " errors occurred during unsubscription:\n" + errors.map(function(err, i) {
          return i + 1 + ") " + err.toString();
        }).join("\n  ") : "";
        this.name = "UnsubscriptionError";
        this.errors = errors;
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/arrRemove.js
var require_arrRemove = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/arrRemove.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.arrRemove = void 0;
    function arrRemove(arr, item) {
      if (arr) {
        var index = arr.indexOf(item);
        0 <= index && arr.splice(index, 1);
      }
    }
    exports.arrRemove = arrRemove;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subscription.js
var require_Subscription = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subscription.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isSubscription = exports.EMPTY_SUBSCRIPTION = exports.Subscription = void 0;
    var isFunction_1 = require_isFunction2();
    var UnsubscriptionError_1 = require_UnsubscriptionError();
    var arrRemove_1 = require_arrRemove();
    var Subscription = function() {
      function Subscription2(initialTeardown) {
        this.initialTeardown = initialTeardown;
        this.closed = false;
        this._parentage = null;
        this._finalizers = null;
      }
      Subscription2.prototype.unsubscribe = function() {
        var e_1, _a, e_2, _b;
        var errors;
        if (!this.closed) {
          this.closed = true;
          var _parentage = this._parentage;
          if (_parentage) {
            this._parentage = null;
            if (Array.isArray(_parentage)) {
              try {
                for (var _parentage_1 = __values(_parentage), _parentage_1_1 = _parentage_1.next(); !_parentage_1_1.done; _parentage_1_1 = _parentage_1.next()) {
                  var parent_1 = _parentage_1_1.value;
                  parent_1.remove(this);
                }
              } catch (e_1_1) {
                e_1 = { error: e_1_1 };
              } finally {
                try {
                  if (_parentage_1_1 && !_parentage_1_1.done && (_a = _parentage_1.return))
                    _a.call(_parentage_1);
                } finally {
                  if (e_1)
                    throw e_1.error;
                }
              }
            } else {
              _parentage.remove(this);
            }
          }
          var initialFinalizer = this.initialTeardown;
          if (isFunction_1.isFunction(initialFinalizer)) {
            try {
              initialFinalizer();
            } catch (e) {
              errors = e instanceof UnsubscriptionError_1.UnsubscriptionError ? e.errors : [e];
            }
          }
          var _finalizers = this._finalizers;
          if (_finalizers) {
            this._finalizers = null;
            try {
              for (var _finalizers_1 = __values(_finalizers), _finalizers_1_1 = _finalizers_1.next(); !_finalizers_1_1.done; _finalizers_1_1 = _finalizers_1.next()) {
                var finalizer = _finalizers_1_1.value;
                try {
                  execFinalizer(finalizer);
                } catch (err) {
                  errors = errors !== null && errors !== void 0 ? errors : [];
                  if (err instanceof UnsubscriptionError_1.UnsubscriptionError) {
                    errors = __spreadArray(__spreadArray([], __read(errors)), __read(err.errors));
                  } else {
                    errors.push(err);
                  }
                }
              }
            } catch (e_2_1) {
              e_2 = { error: e_2_1 };
            } finally {
              try {
                if (_finalizers_1_1 && !_finalizers_1_1.done && (_b = _finalizers_1.return))
                  _b.call(_finalizers_1);
              } finally {
                if (e_2)
                  throw e_2.error;
              }
            }
          }
          if (errors) {
            throw new UnsubscriptionError_1.UnsubscriptionError(errors);
          }
        }
      };
      Subscription2.prototype.add = function(teardown) {
        var _a;
        if (teardown && teardown !== this) {
          if (this.closed) {
            execFinalizer(teardown);
          } else {
            if (teardown instanceof Subscription2) {
              if (teardown.closed || teardown._hasParent(this)) {
                return;
              }
              teardown._addParent(this);
            }
            (this._finalizers = (_a = this._finalizers) !== null && _a !== void 0 ? _a : []).push(teardown);
          }
        }
      };
      Subscription2.prototype._hasParent = function(parent) {
        var _parentage = this._parentage;
        return _parentage === parent || Array.isArray(_parentage) && _parentage.includes(parent);
      };
      Subscription2.prototype._addParent = function(parent) {
        var _parentage = this._parentage;
        this._parentage = Array.isArray(_parentage) ? (_parentage.push(parent), _parentage) : _parentage ? [_parentage, parent] : parent;
      };
      Subscription2.prototype._removeParent = function(parent) {
        var _parentage = this._parentage;
        if (_parentage === parent) {
          this._parentage = null;
        } else if (Array.isArray(_parentage)) {
          arrRemove_1.arrRemove(_parentage, parent);
        }
      };
      Subscription2.prototype.remove = function(teardown) {
        var _finalizers = this._finalizers;
        _finalizers && arrRemove_1.arrRemove(_finalizers, teardown);
        if (teardown instanceof Subscription2) {
          teardown._removeParent(this);
        }
      };
      Subscription2.EMPTY = function() {
        var empty = new Subscription2();
        empty.closed = true;
        return empty;
      }();
      return Subscription2;
    }();
    exports.Subscription = Subscription;
    exports.EMPTY_SUBSCRIPTION = Subscription.EMPTY;
    function isSubscription(value2) {
      return value2 instanceof Subscription || value2 && "closed" in value2 && isFunction_1.isFunction(value2.remove) && isFunction_1.isFunction(value2.add) && isFunction_1.isFunction(value2.unsubscribe);
    }
    exports.isSubscription = isSubscription;
    function execFinalizer(finalizer) {
      if (isFunction_1.isFunction(finalizer)) {
        finalizer();
      } else {
        finalizer.unsubscribe();
      }
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/config.js
var require_config = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/config.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.config = void 0;
    exports.config = {
      onUnhandledError: null,
      onStoppedNotification: null,
      Promise: void 0,
      useDeprecatedSynchronousErrorHandling: false,
      useDeprecatedNextContext: false
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/timeoutProvider.js
var require_timeoutProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/timeoutProvider.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.timeoutProvider = void 0;
    exports.timeoutProvider = {
      setTimeout: function(handler, timeout) {
        var args = [];
        for (var _i = 2; _i < arguments.length; _i++) {
          args[_i - 2] = arguments[_i];
        }
        var delegate = exports.timeoutProvider.delegate;
        if (delegate === null || delegate === void 0 ? void 0 : delegate.setTimeout) {
          return delegate.setTimeout.apply(delegate, __spreadArray([handler, timeout], __read(args)));
        }
        return setTimeout.apply(void 0, __spreadArray([handler, timeout], __read(args)));
      },
      clearTimeout: function(handle) {
        var delegate = exports.timeoutProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.clearTimeout) || clearTimeout)(handle);
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/reportUnhandledError.js
var require_reportUnhandledError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/reportUnhandledError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.reportUnhandledError = void 0;
    var config_1 = require_config();
    var timeoutProvider_1 = require_timeoutProvider();
    function reportUnhandledError(err) {
      timeoutProvider_1.timeoutProvider.setTimeout(function() {
        var onUnhandledError = config_1.config.onUnhandledError;
        if (onUnhandledError) {
          onUnhandledError(err);
        } else {
          throw err;
        }
      });
    }
    exports.reportUnhandledError = reportUnhandledError;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/noop.js
var require_noop = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/noop.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.noop = void 0;
    function noop() {
    }
    exports.noop = noop;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/NotificationFactories.js
var require_NotificationFactories = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/NotificationFactories.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createNotification = exports.nextNotification = exports.errorNotification = exports.COMPLETE_NOTIFICATION = void 0;
    exports.COMPLETE_NOTIFICATION = function() {
      return createNotification("C", void 0, void 0);
    }();
    function errorNotification(error) {
      return createNotification("E", void 0, error);
    }
    exports.errorNotification = errorNotification;
    function nextNotification(value2) {
      return createNotification("N", value2, void 0);
    }
    exports.nextNotification = nextNotification;
    function createNotification(kind, value2, error) {
      return {
        kind,
        value: value2,
        error
      };
    }
    exports.createNotification = createNotification;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/errorContext.js
var require_errorContext = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/errorContext.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.captureError = exports.errorContext = void 0;
    var config_1 = require_config();
    var context = null;
    function errorContext(cb) {
      if (config_1.config.useDeprecatedSynchronousErrorHandling) {
        var isRoot = !context;
        if (isRoot) {
          context = { errorThrown: false, error: null };
        }
        cb();
        if (isRoot) {
          var _a = context, errorThrown = _a.errorThrown, error = _a.error;
          context = null;
          if (errorThrown) {
            throw error;
          }
        }
      } else {
        cb();
      }
    }
    exports.errorContext = errorContext;
    function captureError(err) {
      if (config_1.config.useDeprecatedSynchronousErrorHandling && context) {
        context.errorThrown = true;
        context.error = err;
      }
    }
    exports.captureError = captureError;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subscriber.js
var require_Subscriber = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subscriber.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.EMPTY_OBSERVER = exports.SafeSubscriber = exports.Subscriber = void 0;
    var isFunction_1 = require_isFunction2();
    var Subscription_1 = require_Subscription();
    var config_1 = require_config();
    var reportUnhandledError_1 = require_reportUnhandledError();
    var noop_1 = require_noop();
    var NotificationFactories_1 = require_NotificationFactories();
    var timeoutProvider_1 = require_timeoutProvider();
    var errorContext_1 = require_errorContext();
    var Subscriber = function(_super) {
      __extends(Subscriber2, _super);
      function Subscriber2(destination) {
        var _this = _super.call(this) || this;
        _this.isStopped = false;
        if (destination) {
          _this.destination = destination;
          if (Subscription_1.isSubscription(destination)) {
            destination.add(_this);
          }
        } else {
          _this.destination = exports.EMPTY_OBSERVER;
        }
        return _this;
      }
      Subscriber2.create = function(next, error, complete) {
        return new SafeSubscriber(next, error, complete);
      };
      Subscriber2.prototype.next = function(value2) {
        if (this.isStopped) {
          handleStoppedNotification(NotificationFactories_1.nextNotification(value2), this);
        } else {
          this._next(value2);
        }
      };
      Subscriber2.prototype.error = function(err) {
        if (this.isStopped) {
          handleStoppedNotification(NotificationFactories_1.errorNotification(err), this);
        } else {
          this.isStopped = true;
          this._error(err);
        }
      };
      Subscriber2.prototype.complete = function() {
        if (this.isStopped) {
          handleStoppedNotification(NotificationFactories_1.COMPLETE_NOTIFICATION, this);
        } else {
          this.isStopped = true;
          this._complete();
        }
      };
      Subscriber2.prototype.unsubscribe = function() {
        if (!this.closed) {
          this.isStopped = true;
          _super.prototype.unsubscribe.call(this);
          this.destination = null;
        }
      };
      Subscriber2.prototype._next = function(value2) {
        this.destination.next(value2);
      };
      Subscriber2.prototype._error = function(err) {
        try {
          this.destination.error(err);
        } finally {
          this.unsubscribe();
        }
      };
      Subscriber2.prototype._complete = function() {
        try {
          this.destination.complete();
        } finally {
          this.unsubscribe();
        }
      };
      return Subscriber2;
    }(Subscription_1.Subscription);
    exports.Subscriber = Subscriber;
    var _bind = Function.prototype.bind;
    function bind(fn, thisArg) {
      return _bind.call(fn, thisArg);
    }
    var ConsumerObserver = function() {
      function ConsumerObserver2(partialObserver) {
        this.partialObserver = partialObserver;
      }
      ConsumerObserver2.prototype.next = function(value2) {
        var partialObserver = this.partialObserver;
        if (partialObserver.next) {
          try {
            partialObserver.next(value2);
          } catch (error) {
            handleUnhandledError(error);
          }
        }
      };
      ConsumerObserver2.prototype.error = function(err) {
        var partialObserver = this.partialObserver;
        if (partialObserver.error) {
          try {
            partialObserver.error(err);
          } catch (error) {
            handleUnhandledError(error);
          }
        } else {
          handleUnhandledError(err);
        }
      };
      ConsumerObserver2.prototype.complete = function() {
        var partialObserver = this.partialObserver;
        if (partialObserver.complete) {
          try {
            partialObserver.complete();
          } catch (error) {
            handleUnhandledError(error);
          }
        }
      };
      return ConsumerObserver2;
    }();
    var SafeSubscriber = function(_super) {
      __extends(SafeSubscriber2, _super);
      function SafeSubscriber2(observerOrNext, error, complete) {
        var _this = _super.call(this) || this;
        var partialObserver;
        if (isFunction_1.isFunction(observerOrNext) || !observerOrNext) {
          partialObserver = {
            next: observerOrNext !== null && observerOrNext !== void 0 ? observerOrNext : void 0,
            error: error !== null && error !== void 0 ? error : void 0,
            complete: complete !== null && complete !== void 0 ? complete : void 0
          };
        } else {
          var context_1;
          if (_this && config_1.config.useDeprecatedNextContext) {
            context_1 = Object.create(observerOrNext);
            context_1.unsubscribe = function() {
              return _this.unsubscribe();
            };
            partialObserver = {
              next: observerOrNext.next && bind(observerOrNext.next, context_1),
              error: observerOrNext.error && bind(observerOrNext.error, context_1),
              complete: observerOrNext.complete && bind(observerOrNext.complete, context_1)
            };
          } else {
            partialObserver = observerOrNext;
          }
        }
        _this.destination = new ConsumerObserver(partialObserver);
        return _this;
      }
      return SafeSubscriber2;
    }(Subscriber);
    exports.SafeSubscriber = SafeSubscriber;
    function handleUnhandledError(error) {
      if (config_1.config.useDeprecatedSynchronousErrorHandling) {
        errorContext_1.captureError(error);
      } else {
        reportUnhandledError_1.reportUnhandledError(error);
      }
    }
    function defaultErrorHandler(err) {
      throw err;
    }
    function handleStoppedNotification(notification, subscriber) {
      var onStoppedNotification = config_1.config.onStoppedNotification;
      onStoppedNotification && timeoutProvider_1.timeoutProvider.setTimeout(function() {
        return onStoppedNotification(notification, subscriber);
      });
    }
    exports.EMPTY_OBSERVER = {
      closed: true,
      next: noop_1.noop,
      error: defaultErrorHandler,
      complete: noop_1.noop
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/symbol/observable.js
var require_observable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/symbol/observable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.observable = void 0;
    exports.observable = function() {
      return typeof Symbol === "function" && Symbol.observable || "@@observable";
    }();
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/identity.js
var require_identity = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/identity.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.identity = void 0;
    function identity(x) {
      return x;
    }
    exports.identity = identity;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/pipe.js
var require_pipe = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/pipe.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.pipeFromArray = exports.pipe = void 0;
    var identity_1 = require_identity();
    function pipe() {
      var fns = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        fns[_i] = arguments[_i];
      }
      return pipeFromArray(fns);
    }
    exports.pipe = pipe;
    function pipeFromArray(fns) {
      if (fns.length === 0) {
        return identity_1.identity;
      }
      if (fns.length === 1) {
        return fns[0];
      }
      return function piped(input) {
        return fns.reduce(function(prev, fn) {
          return fn(prev);
        }, input);
      };
    }
    exports.pipeFromArray = pipeFromArray;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Observable.js
var require_Observable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Observable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Observable = void 0;
    var Subscriber_1 = require_Subscriber();
    var Subscription_1 = require_Subscription();
    var observable_1 = require_observable();
    var pipe_1 = require_pipe();
    var config_1 = require_config();
    var isFunction_1 = require_isFunction2();
    var errorContext_1 = require_errorContext();
    var Observable = function() {
      function Observable2(subscribe) {
        if (subscribe) {
          this._subscribe = subscribe;
        }
      }
      Observable2.prototype.lift = function(operator) {
        var observable = new Observable2();
        observable.source = this;
        observable.operator = operator;
        return observable;
      };
      Observable2.prototype.subscribe = function(observerOrNext, error, complete) {
        var _this = this;
        var subscriber = isSubscriber(observerOrNext) ? observerOrNext : new Subscriber_1.SafeSubscriber(observerOrNext, error, complete);
        errorContext_1.errorContext(function() {
          var _a = _this, operator = _a.operator, source = _a.source;
          subscriber.add(operator ? operator.call(subscriber, source) : source ? _this._subscribe(subscriber) : _this._trySubscribe(subscriber));
        });
        return subscriber;
      };
      Observable2.prototype._trySubscribe = function(sink) {
        try {
          return this._subscribe(sink);
        } catch (err) {
          sink.error(err);
        }
      };
      Observable2.prototype.forEach = function(next, promiseCtor) {
        var _this = this;
        promiseCtor = getPromiseCtor(promiseCtor);
        return new promiseCtor(function(resolve, reject) {
          var subscriber = new Subscriber_1.SafeSubscriber({
            next: function(value2) {
              try {
                next(value2);
              } catch (err) {
                reject(err);
                subscriber.unsubscribe();
              }
            },
            error: reject,
            complete: resolve
          });
          _this.subscribe(subscriber);
        });
      };
      Observable2.prototype._subscribe = function(subscriber) {
        var _a;
        return (_a = this.source) === null || _a === void 0 ? void 0 : _a.subscribe(subscriber);
      };
      Observable2.prototype[observable_1.observable] = function() {
        return this;
      };
      Observable2.prototype.pipe = function() {
        var operations = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          operations[_i] = arguments[_i];
        }
        return pipe_1.pipeFromArray(operations)(this);
      };
      Observable2.prototype.toPromise = function(promiseCtor) {
        var _this = this;
        promiseCtor = getPromiseCtor(promiseCtor);
        return new promiseCtor(function(resolve, reject) {
          var value2;
          _this.subscribe(function(x) {
            return value2 = x;
          }, function(err) {
            return reject(err);
          }, function() {
            return resolve(value2);
          });
        });
      };
      Observable2.create = function(subscribe) {
        return new Observable2(subscribe);
      };
      return Observable2;
    }();
    exports.Observable = Observable;
    function getPromiseCtor(promiseCtor) {
      var _a;
      return (_a = promiseCtor !== null && promiseCtor !== void 0 ? promiseCtor : config_1.config.Promise) !== null && _a !== void 0 ? _a : Promise;
    }
    function isObserver(value2) {
      return value2 && isFunction_1.isFunction(value2.next) && isFunction_1.isFunction(value2.error) && isFunction_1.isFunction(value2.complete);
    }
    function isSubscriber(value2) {
      return value2 && value2 instanceof Subscriber_1.Subscriber || isObserver(value2) && Subscription_1.isSubscription(value2);
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/lift.js
var require_lift = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/lift.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.operate = exports.hasLift = void 0;
    var isFunction_1 = require_isFunction2();
    function hasLift(source) {
      return isFunction_1.isFunction(source === null || source === void 0 ? void 0 : source.lift);
    }
    exports.hasLift = hasLift;
    function operate(init) {
      return function(source) {
        if (hasLift(source)) {
          return source.lift(function(liftedSource) {
            try {
              return init(liftedSource, this);
            } catch (err) {
              this.error(err);
            }
          });
        }
        throw new TypeError("Unable to lift unknown Observable type");
      };
    }
    exports.operate = operate;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/OperatorSubscriber.js
var require_OperatorSubscriber = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/OperatorSubscriber.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.OperatorSubscriber = exports.createOperatorSubscriber = void 0;
    var Subscriber_1 = require_Subscriber();
    function createOperatorSubscriber(destination, onNext, onComplete, onError, onFinalize) {
      return new OperatorSubscriber(destination, onNext, onComplete, onError, onFinalize);
    }
    exports.createOperatorSubscriber = createOperatorSubscriber;
    var OperatorSubscriber = function(_super) {
      __extends(OperatorSubscriber2, _super);
      function OperatorSubscriber2(destination, onNext, onComplete, onError, onFinalize, shouldUnsubscribe) {
        var _this = _super.call(this, destination) || this;
        _this.onFinalize = onFinalize;
        _this.shouldUnsubscribe = shouldUnsubscribe;
        _this._next = onNext ? function(value2) {
          try {
            onNext(value2);
          } catch (err) {
            destination.error(err);
          }
        } : _super.prototype._next;
        _this._error = onError ? function(err) {
          try {
            onError(err);
          } catch (err2) {
            destination.error(err2);
          } finally {
            this.unsubscribe();
          }
        } : _super.prototype._error;
        _this._complete = onComplete ? function() {
          try {
            onComplete();
          } catch (err) {
            destination.error(err);
          } finally {
            this.unsubscribe();
          }
        } : _super.prototype._complete;
        return _this;
      }
      OperatorSubscriber2.prototype.unsubscribe = function() {
        var _a;
        if (!this.shouldUnsubscribe || this.shouldUnsubscribe()) {
          var closed_1 = this.closed;
          _super.prototype.unsubscribe.call(this);
          !closed_1 && ((_a = this.onFinalize) === null || _a === void 0 ? void 0 : _a.call(this));
        }
      };
      return OperatorSubscriber2;
    }(Subscriber_1.Subscriber);
    exports.OperatorSubscriber = OperatorSubscriber;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/refCount.js
var require_refCount = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/refCount.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.refCount = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function refCount() {
      return lift_1.operate(function(source, subscriber) {
        var connection = null;
        source._refCount++;
        var refCounter = OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, void 0, void 0, function() {
          if (!source || source._refCount <= 0 || 0 < --source._refCount) {
            connection = null;
            return;
          }
          var sharedConnection = source._connection;
          var conn = connection;
          connection = null;
          if (sharedConnection && (!conn || sharedConnection === conn)) {
            sharedConnection.unsubscribe();
          }
          subscriber.unsubscribe();
        });
        source.subscribe(refCounter);
        if (!refCounter.closed) {
          connection = source.connect();
        }
      });
    }
    exports.refCount = refCount;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/ConnectableObservable.js
var require_ConnectableObservable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/ConnectableObservable.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ConnectableObservable = void 0;
    var Observable_1 = require_Observable();
    var Subscription_1 = require_Subscription();
    var refCount_1 = require_refCount();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var lift_1 = require_lift();
    var ConnectableObservable = function(_super) {
      __extends(ConnectableObservable2, _super);
      function ConnectableObservable2(source, subjectFactory) {
        var _this = _super.call(this) || this;
        _this.source = source;
        _this.subjectFactory = subjectFactory;
        _this._subject = null;
        _this._refCount = 0;
        _this._connection = null;
        if (lift_1.hasLift(source)) {
          _this.lift = source.lift;
        }
        return _this;
      }
      ConnectableObservable2.prototype._subscribe = function(subscriber) {
        return this.getSubject().subscribe(subscriber);
      };
      ConnectableObservable2.prototype.getSubject = function() {
        var subject = this._subject;
        if (!subject || subject.isStopped) {
          this._subject = this.subjectFactory();
        }
        return this._subject;
      };
      ConnectableObservable2.prototype._teardown = function() {
        this._refCount = 0;
        var _connection = this._connection;
        this._subject = this._connection = null;
        _connection === null || _connection === void 0 ? void 0 : _connection.unsubscribe();
      };
      ConnectableObservable2.prototype.connect = function() {
        var _this = this;
        var connection = this._connection;
        if (!connection) {
          connection = this._connection = new Subscription_1.Subscription();
          var subject_1 = this.getSubject();
          connection.add(this.source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subject_1, void 0, function() {
            _this._teardown();
            subject_1.complete();
          }, function(err) {
            _this._teardown();
            subject_1.error(err);
          }, function() {
            return _this._teardown();
          })));
          if (connection.closed) {
            this._connection = null;
            connection = Subscription_1.Subscription.EMPTY;
          }
        }
        return connection;
      };
      ConnectableObservable2.prototype.refCount = function() {
        return refCount_1.refCount()(this);
      };
      return ConnectableObservable2;
    }(Observable_1.Observable);
    exports.ConnectableObservable = ConnectableObservable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/performanceTimestampProvider.js
var require_performanceTimestampProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/performanceTimestampProvider.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.performanceTimestampProvider = void 0;
    exports.performanceTimestampProvider = {
      now: function() {
        return (exports.performanceTimestampProvider.delegate || performance).now();
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/animationFrameProvider.js
var require_animationFrameProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/animationFrameProvider.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.animationFrameProvider = void 0;
    var Subscription_1 = require_Subscription();
    exports.animationFrameProvider = {
      schedule: function(callback) {
        var request = requestAnimationFrame;
        var cancel = cancelAnimationFrame;
        var delegate = exports.animationFrameProvider.delegate;
        if (delegate) {
          request = delegate.requestAnimationFrame;
          cancel = delegate.cancelAnimationFrame;
        }
        var handle = request(function(timestamp) {
          cancel = void 0;
          callback(timestamp);
        });
        return new Subscription_1.Subscription(function() {
          return cancel === null || cancel === void 0 ? void 0 : cancel(handle);
        });
      },
      requestAnimationFrame: function() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var delegate = exports.animationFrameProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.requestAnimationFrame) || requestAnimationFrame).apply(void 0, __spreadArray([], __read(args)));
      },
      cancelAnimationFrame: function() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var delegate = exports.animationFrameProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.cancelAnimationFrame) || cancelAnimationFrame).apply(void 0, __spreadArray([], __read(args)));
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/dom/animationFrames.js
var require_animationFrames = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/dom/animationFrames.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.animationFrames = void 0;
    var Observable_1 = require_Observable();
    var performanceTimestampProvider_1 = require_performanceTimestampProvider();
    var animationFrameProvider_1 = require_animationFrameProvider();
    function animationFrames(timestampProvider) {
      return timestampProvider ? animationFramesFactory(timestampProvider) : DEFAULT_ANIMATION_FRAMES;
    }
    exports.animationFrames = animationFrames;
    function animationFramesFactory(timestampProvider) {
      return new Observable_1.Observable(function(subscriber) {
        var provider = timestampProvider || performanceTimestampProvider_1.performanceTimestampProvider;
        var start = provider.now();
        var id = 0;
        var run = function() {
          if (!subscriber.closed) {
            id = animationFrameProvider_1.animationFrameProvider.requestAnimationFrame(function(timestamp) {
              id = 0;
              var now = provider.now();
              subscriber.next({
                timestamp: timestampProvider ? now : timestamp,
                elapsed: now - start
              });
              run();
            });
          }
        };
        run();
        return function() {
          if (id) {
            animationFrameProvider_1.animationFrameProvider.cancelAnimationFrame(id);
          }
        };
      });
    }
    var DEFAULT_ANIMATION_FRAMES = animationFramesFactory();
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/ObjectUnsubscribedError.js
var require_ObjectUnsubscribedError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/ObjectUnsubscribedError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ObjectUnsubscribedError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.ObjectUnsubscribedError = createErrorClass_1.createErrorClass(function(_super) {
      return function ObjectUnsubscribedErrorImpl() {
        _super(this);
        this.name = "ObjectUnsubscribedError";
        this.message = "object unsubscribed";
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subject.js
var require_Subject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Subject.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AnonymousSubject = exports.Subject = void 0;
    var Observable_1 = require_Observable();
    var Subscription_1 = require_Subscription();
    var ObjectUnsubscribedError_1 = require_ObjectUnsubscribedError();
    var arrRemove_1 = require_arrRemove();
    var errorContext_1 = require_errorContext();
    var Subject = function(_super) {
      __extends(Subject2, _super);
      function Subject2() {
        var _this = _super.call(this) || this;
        _this.closed = false;
        _this.currentObservers = null;
        _this.observers = [];
        _this.isStopped = false;
        _this.hasError = false;
        _this.thrownError = null;
        return _this;
      }
      Subject2.prototype.lift = function(operator) {
        var subject = new AnonymousSubject(this, this);
        subject.operator = operator;
        return subject;
      };
      Subject2.prototype._throwIfClosed = function() {
        if (this.closed) {
          throw new ObjectUnsubscribedError_1.ObjectUnsubscribedError();
        }
      };
      Subject2.prototype.next = function(value2) {
        var _this = this;
        errorContext_1.errorContext(function() {
          var e_1, _a;
          _this._throwIfClosed();
          if (!_this.isStopped) {
            if (!_this.currentObservers) {
              _this.currentObservers = Array.from(_this.observers);
            }
            try {
              for (var _b = __values(_this.currentObservers), _c = _b.next(); !_c.done; _c = _b.next()) {
                var observer = _c.value;
                observer.next(value2);
              }
            } catch (e_1_1) {
              e_1 = { error: e_1_1 };
            } finally {
              try {
                if (_c && !_c.done && (_a = _b.return))
                  _a.call(_b);
              } finally {
                if (e_1)
                  throw e_1.error;
              }
            }
          }
        });
      };
      Subject2.prototype.error = function(err) {
        var _this = this;
        errorContext_1.errorContext(function() {
          _this._throwIfClosed();
          if (!_this.isStopped) {
            _this.hasError = _this.isStopped = true;
            _this.thrownError = err;
            var observers = _this.observers;
            while (observers.length) {
              observers.shift().error(err);
            }
          }
        });
      };
      Subject2.prototype.complete = function() {
        var _this = this;
        errorContext_1.errorContext(function() {
          _this._throwIfClosed();
          if (!_this.isStopped) {
            _this.isStopped = true;
            var observers = _this.observers;
            while (observers.length) {
              observers.shift().complete();
            }
          }
        });
      };
      Subject2.prototype.unsubscribe = function() {
        this.isStopped = this.closed = true;
        this.observers = this.currentObservers = null;
      };
      Object.defineProperty(Subject2.prototype, "observed", {
        get: function() {
          var _a;
          return ((_a = this.observers) === null || _a === void 0 ? void 0 : _a.length) > 0;
        },
        enumerable: false,
        configurable: true
      });
      Subject2.prototype._trySubscribe = function(subscriber) {
        this._throwIfClosed();
        return _super.prototype._trySubscribe.call(this, subscriber);
      };
      Subject2.prototype._subscribe = function(subscriber) {
        this._throwIfClosed();
        this._checkFinalizedStatuses(subscriber);
        return this._innerSubscribe(subscriber);
      };
      Subject2.prototype._innerSubscribe = function(subscriber) {
        var _this = this;
        var _a = this, hasError = _a.hasError, isStopped = _a.isStopped, observers = _a.observers;
        if (hasError || isStopped) {
          return Subscription_1.EMPTY_SUBSCRIPTION;
        }
        this.currentObservers = null;
        observers.push(subscriber);
        return new Subscription_1.Subscription(function() {
          _this.currentObservers = null;
          arrRemove_1.arrRemove(observers, subscriber);
        });
      };
      Subject2.prototype._checkFinalizedStatuses = function(subscriber) {
        var _a = this, hasError = _a.hasError, thrownError = _a.thrownError, isStopped = _a.isStopped;
        if (hasError) {
          subscriber.error(thrownError);
        } else if (isStopped) {
          subscriber.complete();
        }
      };
      Subject2.prototype.asObservable = function() {
        var observable = new Observable_1.Observable();
        observable.source = this;
        return observable;
      };
      Subject2.create = function(destination, source) {
        return new AnonymousSubject(destination, source);
      };
      return Subject2;
    }(Observable_1.Observable);
    exports.Subject = Subject;
    var AnonymousSubject = function(_super) {
      __extends(AnonymousSubject2, _super);
      function AnonymousSubject2(destination, source) {
        var _this = _super.call(this) || this;
        _this.destination = destination;
        _this.source = source;
        return _this;
      }
      AnonymousSubject2.prototype.next = function(value2) {
        var _a, _b;
        (_b = (_a = this.destination) === null || _a === void 0 ? void 0 : _a.next) === null || _b === void 0 ? void 0 : _b.call(_a, value2);
      };
      AnonymousSubject2.prototype.error = function(err) {
        var _a, _b;
        (_b = (_a = this.destination) === null || _a === void 0 ? void 0 : _a.error) === null || _b === void 0 ? void 0 : _b.call(_a, err);
      };
      AnonymousSubject2.prototype.complete = function() {
        var _a, _b;
        (_b = (_a = this.destination) === null || _a === void 0 ? void 0 : _a.complete) === null || _b === void 0 ? void 0 : _b.call(_a);
      };
      AnonymousSubject2.prototype._subscribe = function(subscriber) {
        var _a, _b;
        return (_b = (_a = this.source) === null || _a === void 0 ? void 0 : _a.subscribe(subscriber)) !== null && _b !== void 0 ? _b : Subscription_1.EMPTY_SUBSCRIPTION;
      };
      return AnonymousSubject2;
    }(Subject);
    exports.AnonymousSubject = AnonymousSubject;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/BehaviorSubject.js
var require_BehaviorSubject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/BehaviorSubject.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.BehaviorSubject = void 0;
    var Subject_1 = require_Subject();
    var BehaviorSubject = function(_super) {
      __extends(BehaviorSubject2, _super);
      function BehaviorSubject2(_value) {
        var _this = _super.call(this) || this;
        _this._value = _value;
        return _this;
      }
      Object.defineProperty(BehaviorSubject2.prototype, "value", {
        get: function() {
          return this.getValue();
        },
        enumerable: false,
        configurable: true
      });
      BehaviorSubject2.prototype._subscribe = function(subscriber) {
        var subscription = _super.prototype._subscribe.call(this, subscriber);
        !subscription.closed && subscriber.next(this._value);
        return subscription;
      };
      BehaviorSubject2.prototype.getValue = function() {
        var _a = this, hasError = _a.hasError, thrownError = _a.thrownError, _value = _a._value;
        if (hasError) {
          throw thrownError;
        }
        this._throwIfClosed();
        return _value;
      };
      BehaviorSubject2.prototype.next = function(value2) {
        _super.prototype.next.call(this, this._value = value2);
      };
      return BehaviorSubject2;
    }(Subject_1.Subject);
    exports.BehaviorSubject = BehaviorSubject;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/dateTimestampProvider.js
var require_dateTimestampProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/dateTimestampProvider.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.dateTimestampProvider = void 0;
    exports.dateTimestampProvider = {
      now: function() {
        return (exports.dateTimestampProvider.delegate || Date).now();
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/ReplaySubject.js
var require_ReplaySubject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/ReplaySubject.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ReplaySubject = void 0;
    var Subject_1 = require_Subject();
    var dateTimestampProvider_1 = require_dateTimestampProvider();
    var ReplaySubject = function(_super) {
      __extends(ReplaySubject2, _super);
      function ReplaySubject2(_bufferSize, _windowTime, _timestampProvider) {
        if (_bufferSize === void 0) {
          _bufferSize = Infinity;
        }
        if (_windowTime === void 0) {
          _windowTime = Infinity;
        }
        if (_timestampProvider === void 0) {
          _timestampProvider = dateTimestampProvider_1.dateTimestampProvider;
        }
        var _this = _super.call(this) || this;
        _this._bufferSize = _bufferSize;
        _this._windowTime = _windowTime;
        _this._timestampProvider = _timestampProvider;
        _this._buffer = [];
        _this._infiniteTimeWindow = true;
        _this._infiniteTimeWindow = _windowTime === Infinity;
        _this._bufferSize = Math.max(1, _bufferSize);
        _this._windowTime = Math.max(1, _windowTime);
        return _this;
      }
      ReplaySubject2.prototype.next = function(value2) {
        var _a = this, isStopped = _a.isStopped, _buffer = _a._buffer, _infiniteTimeWindow = _a._infiniteTimeWindow, _timestampProvider = _a._timestampProvider, _windowTime = _a._windowTime;
        if (!isStopped) {
          _buffer.push(value2);
          !_infiniteTimeWindow && _buffer.push(_timestampProvider.now() + _windowTime);
        }
        this._trimBuffer();
        _super.prototype.next.call(this, value2);
      };
      ReplaySubject2.prototype._subscribe = function(subscriber) {
        this._throwIfClosed();
        this._trimBuffer();
        var subscription = this._innerSubscribe(subscriber);
        var _a = this, _infiniteTimeWindow = _a._infiniteTimeWindow, _buffer = _a._buffer;
        var copy = _buffer.slice();
        for (var i = 0; i < copy.length && !subscriber.closed; i += _infiniteTimeWindow ? 1 : 2) {
          subscriber.next(copy[i]);
        }
        this._checkFinalizedStatuses(subscriber);
        return subscription;
      };
      ReplaySubject2.prototype._trimBuffer = function() {
        var _a = this, _bufferSize = _a._bufferSize, _timestampProvider = _a._timestampProvider, _buffer = _a._buffer, _infiniteTimeWindow = _a._infiniteTimeWindow;
        var adjustedBufferSize = (_infiniteTimeWindow ? 1 : 2) * _bufferSize;
        _bufferSize < Infinity && adjustedBufferSize < _buffer.length && _buffer.splice(0, _buffer.length - adjustedBufferSize);
        if (!_infiniteTimeWindow) {
          var now = _timestampProvider.now();
          var last2 = 0;
          for (var i = 1; i < _buffer.length && _buffer[i] <= now; i += 2) {
            last2 = i;
          }
          last2 && _buffer.splice(0, last2 + 1);
        }
      };
      return ReplaySubject2;
    }(Subject_1.Subject);
    exports.ReplaySubject = ReplaySubject;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/AsyncSubject.js
var require_AsyncSubject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/AsyncSubject.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AsyncSubject = void 0;
    var Subject_1 = require_Subject();
    var AsyncSubject = function(_super) {
      __extends(AsyncSubject2, _super);
      function AsyncSubject2() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._value = null;
        _this._hasValue = false;
        _this._isComplete = false;
        return _this;
      }
      AsyncSubject2.prototype._checkFinalizedStatuses = function(subscriber) {
        var _a = this, hasError = _a.hasError, _hasValue = _a._hasValue, _value = _a._value, thrownError = _a.thrownError, isStopped = _a.isStopped, _isComplete = _a._isComplete;
        if (hasError) {
          subscriber.error(thrownError);
        } else if (isStopped || _isComplete) {
          _hasValue && subscriber.next(_value);
          subscriber.complete();
        }
      };
      AsyncSubject2.prototype.next = function(value2) {
        if (!this.isStopped) {
          this._value = value2;
          this._hasValue = true;
        }
      };
      AsyncSubject2.prototype.complete = function() {
        var _a = this, _hasValue = _a._hasValue, _value = _a._value, _isComplete = _a._isComplete;
        if (!_isComplete) {
          this._isComplete = true;
          _hasValue && _super.prototype.next.call(this, _value);
          _super.prototype.complete.call(this);
        }
      };
      return AsyncSubject2;
    }(Subject_1.Subject);
    exports.AsyncSubject = AsyncSubject;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/Action.js
var require_Action = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/Action.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Action = void 0;
    var Subscription_1 = require_Subscription();
    var Action = function(_super) {
      __extends(Action2, _super);
      function Action2(scheduler, work) {
        return _super.call(this) || this;
      }
      Action2.prototype.schedule = function(state, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        return this;
      };
      return Action2;
    }(Subscription_1.Subscription);
    exports.Action = Action;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/intervalProvider.js
var require_intervalProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/intervalProvider.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.intervalProvider = void 0;
    exports.intervalProvider = {
      setInterval: function(handler, timeout) {
        var args = [];
        for (var _i = 2; _i < arguments.length; _i++) {
          args[_i - 2] = arguments[_i];
        }
        var delegate = exports.intervalProvider.delegate;
        if (delegate === null || delegate === void 0 ? void 0 : delegate.setInterval) {
          return delegate.setInterval.apply(delegate, __spreadArray([handler, timeout], __read(args)));
        }
        return setInterval.apply(void 0, __spreadArray([handler, timeout], __read(args)));
      },
      clearInterval: function(handle) {
        var delegate = exports.intervalProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.clearInterval) || clearInterval)(handle);
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsyncAction.js
var require_AsyncAction = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsyncAction.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AsyncAction = void 0;
    var Action_1 = require_Action();
    var intervalProvider_1 = require_intervalProvider();
    var arrRemove_1 = require_arrRemove();
    var AsyncAction = function(_super) {
      __extends(AsyncAction2, _super);
      function AsyncAction2(scheduler, work) {
        var _this = _super.call(this, scheduler, work) || this;
        _this.scheduler = scheduler;
        _this.work = work;
        _this.pending = false;
        return _this;
      }
      AsyncAction2.prototype.schedule = function(state, delay) {
        var _a;
        if (delay === void 0) {
          delay = 0;
        }
        if (this.closed) {
          return this;
        }
        this.state = state;
        var id = this.id;
        var scheduler = this.scheduler;
        if (id != null) {
          this.id = this.recycleAsyncId(scheduler, id, delay);
        }
        this.pending = true;
        this.delay = delay;
        this.id = (_a = this.id) !== null && _a !== void 0 ? _a : this.requestAsyncId(scheduler, this.id, delay);
        return this;
      };
      AsyncAction2.prototype.requestAsyncId = function(scheduler, _id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        return intervalProvider_1.intervalProvider.setInterval(scheduler.flush.bind(scheduler, this), delay);
      };
      AsyncAction2.prototype.recycleAsyncId = function(_scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (delay != null && this.delay === delay && this.pending === false) {
          return id;
        }
        if (id != null) {
          intervalProvider_1.intervalProvider.clearInterval(id);
        }
        return void 0;
      };
      AsyncAction2.prototype.execute = function(state, delay) {
        if (this.closed) {
          return new Error("executing a cancelled action");
        }
        this.pending = false;
        var error = this._execute(state, delay);
        if (error) {
          return error;
        } else if (this.pending === false && this.id != null) {
          this.id = this.recycleAsyncId(this.scheduler, this.id, null);
        }
      };
      AsyncAction2.prototype._execute = function(state, _delay) {
        var errored = false;
        var errorValue;
        try {
          this.work(state);
        } catch (e) {
          errored = true;
          errorValue = e ? e : new Error("Scheduled action threw falsy error");
        }
        if (errored) {
          this.unsubscribe();
          return errorValue;
        }
      };
      AsyncAction2.prototype.unsubscribe = function() {
        if (!this.closed) {
          var _a = this, id = _a.id, scheduler = _a.scheduler;
          var actions = scheduler.actions;
          this.work = this.state = this.scheduler = null;
          this.pending = false;
          arrRemove_1.arrRemove(actions, this);
          if (id != null) {
            this.id = this.recycleAsyncId(scheduler, id, null);
          }
          this.delay = null;
          _super.prototype.unsubscribe.call(this);
        }
      };
      return AsyncAction2;
    }(Action_1.Action);
    exports.AsyncAction = AsyncAction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/Immediate.js
var require_Immediate = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/Immediate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TestTools = exports.Immediate = void 0;
    var nextHandle = 1;
    var resolved;
    var activeHandles = {};
    function findAndClearHandle(handle) {
      if (handle in activeHandles) {
        delete activeHandles[handle];
        return true;
      }
      return false;
    }
    exports.Immediate = {
      setImmediate: function(cb) {
        var handle = nextHandle++;
        activeHandles[handle] = true;
        if (!resolved) {
          resolved = Promise.resolve();
        }
        resolved.then(function() {
          return findAndClearHandle(handle) && cb();
        });
        return handle;
      },
      clearImmediate: function(handle) {
        findAndClearHandle(handle);
      }
    };
    exports.TestTools = {
      pending: function() {
        return Object.keys(activeHandles).length;
      }
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/immediateProvider.js
var require_immediateProvider = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/immediateProvider.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.immediateProvider = void 0;
    var Immediate_1 = require_Immediate();
    var setImmediate2 = Immediate_1.Immediate.setImmediate;
    var clearImmediate = Immediate_1.Immediate.clearImmediate;
    exports.immediateProvider = {
      setImmediate: function() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var delegate = exports.immediateProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.setImmediate) || setImmediate2).apply(void 0, __spreadArray([], __read(args)));
      },
      clearImmediate: function(handle) {
        var delegate = exports.immediateProvider.delegate;
        return ((delegate === null || delegate === void 0 ? void 0 : delegate.clearImmediate) || clearImmediate)(handle);
      },
      delegate: void 0
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsapAction.js
var require_AsapAction = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsapAction.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AsapAction = void 0;
    var AsyncAction_1 = require_AsyncAction();
    var immediateProvider_1 = require_immediateProvider();
    var AsapAction = function(_super) {
      __extends(AsapAction2, _super);
      function AsapAction2(scheduler, work) {
        var _this = _super.call(this, scheduler, work) || this;
        _this.scheduler = scheduler;
        _this.work = work;
        return _this;
      }
      AsapAction2.prototype.requestAsyncId = function(scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (delay !== null && delay > 0) {
          return _super.prototype.requestAsyncId.call(this, scheduler, id, delay);
        }
        scheduler.actions.push(this);
        return scheduler._scheduled || (scheduler._scheduled = immediateProvider_1.immediateProvider.setImmediate(scheduler.flush.bind(scheduler, void 0)));
      };
      AsapAction2.prototype.recycleAsyncId = function(scheduler, id, delay) {
        var _a;
        if (delay === void 0) {
          delay = 0;
        }
        if (delay != null ? delay > 0 : this.delay > 0) {
          return _super.prototype.recycleAsyncId.call(this, scheduler, id, delay);
        }
        var actions = scheduler.actions;
        if (id != null && ((_a = actions[actions.length - 1]) === null || _a === void 0 ? void 0 : _a.id) !== id) {
          immediateProvider_1.immediateProvider.clearImmediate(id);
          scheduler._scheduled = void 0;
        }
        return void 0;
      };
      return AsapAction2;
    }(AsyncAction_1.AsyncAction);
    exports.AsapAction = AsapAction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Scheduler.js
var require_Scheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Scheduler.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Scheduler = void 0;
    var dateTimestampProvider_1 = require_dateTimestampProvider();
    var Scheduler = function() {
      function Scheduler2(schedulerActionCtor, now) {
        if (now === void 0) {
          now = Scheduler2.now;
        }
        this.schedulerActionCtor = schedulerActionCtor;
        this.now = now;
      }
      Scheduler2.prototype.schedule = function(work, delay, state) {
        if (delay === void 0) {
          delay = 0;
        }
        return new this.schedulerActionCtor(this, work).schedule(state, delay);
      };
      Scheduler2.now = dateTimestampProvider_1.dateTimestampProvider.now;
      return Scheduler2;
    }();
    exports.Scheduler = Scheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsyncScheduler.js
var require_AsyncScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsyncScheduler.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AsyncScheduler = void 0;
    var Scheduler_1 = require_Scheduler();
    var AsyncScheduler = function(_super) {
      __extends(AsyncScheduler2, _super);
      function AsyncScheduler2(SchedulerAction, now) {
        if (now === void 0) {
          now = Scheduler_1.Scheduler.now;
        }
        var _this = _super.call(this, SchedulerAction, now) || this;
        _this.actions = [];
        _this._active = false;
        return _this;
      }
      AsyncScheduler2.prototype.flush = function(action) {
        var actions = this.actions;
        if (this._active) {
          actions.push(action);
          return;
        }
        var error;
        this._active = true;
        do {
          if (error = action.execute(action.state, action.delay)) {
            break;
          }
        } while (action = actions.shift());
        this._active = false;
        if (error) {
          while (action = actions.shift()) {
            action.unsubscribe();
          }
          throw error;
        }
      };
      return AsyncScheduler2;
    }(Scheduler_1.Scheduler);
    exports.AsyncScheduler = AsyncScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsapScheduler.js
var require_AsapScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AsapScheduler.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AsapScheduler = void 0;
    var AsyncScheduler_1 = require_AsyncScheduler();
    var AsapScheduler = function(_super) {
      __extends(AsapScheduler2, _super);
      function AsapScheduler2() {
        return _super !== null && _super.apply(this, arguments) || this;
      }
      AsapScheduler2.prototype.flush = function(action) {
        this._active = true;
        var flushId = this._scheduled;
        this._scheduled = void 0;
        var actions = this.actions;
        var error;
        action = action || actions.shift();
        do {
          if (error = action.execute(action.state, action.delay)) {
            break;
          }
        } while ((action = actions[0]) && action.id === flushId && actions.shift());
        this._active = false;
        if (error) {
          while ((action = actions[0]) && action.id === flushId && actions.shift()) {
            action.unsubscribe();
          }
          throw error;
        }
      };
      return AsapScheduler2;
    }(AsyncScheduler_1.AsyncScheduler);
    exports.AsapScheduler = AsapScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/asap.js
var require_asap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/asap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.asap = exports.asapScheduler = void 0;
    var AsapAction_1 = require_AsapAction();
    var AsapScheduler_1 = require_AsapScheduler();
    exports.asapScheduler = new AsapScheduler_1.AsapScheduler(AsapAction_1.AsapAction);
    exports.asap = exports.asapScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/async.js
var require_async = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.async = exports.asyncScheduler = void 0;
    var AsyncAction_1 = require_AsyncAction();
    var AsyncScheduler_1 = require_AsyncScheduler();
    exports.asyncScheduler = new AsyncScheduler_1.AsyncScheduler(AsyncAction_1.AsyncAction);
    exports.async = exports.asyncScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/QueueAction.js
var require_QueueAction = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/QueueAction.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.QueueAction = void 0;
    var AsyncAction_1 = require_AsyncAction();
    var QueueAction = function(_super) {
      __extends(QueueAction2, _super);
      function QueueAction2(scheduler, work) {
        var _this = _super.call(this, scheduler, work) || this;
        _this.scheduler = scheduler;
        _this.work = work;
        return _this;
      }
      QueueAction2.prototype.schedule = function(state, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (delay > 0) {
          return _super.prototype.schedule.call(this, state, delay);
        }
        this.delay = delay;
        this.state = state;
        this.scheduler.flush(this);
        return this;
      };
      QueueAction2.prototype.execute = function(state, delay) {
        return delay > 0 || this.closed ? _super.prototype.execute.call(this, state, delay) : this._execute(state, delay);
      };
      QueueAction2.prototype.requestAsyncId = function(scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (delay != null && delay > 0 || delay == null && this.delay > 0) {
          return _super.prototype.requestAsyncId.call(this, scheduler, id, delay);
        }
        scheduler.flush(this);
        return 0;
      };
      return QueueAction2;
    }(AsyncAction_1.AsyncAction);
    exports.QueueAction = QueueAction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/QueueScheduler.js
var require_QueueScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/QueueScheduler.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.QueueScheduler = void 0;
    var AsyncScheduler_1 = require_AsyncScheduler();
    var QueueScheduler = function(_super) {
      __extends(QueueScheduler2, _super);
      function QueueScheduler2() {
        return _super !== null && _super.apply(this, arguments) || this;
      }
      return QueueScheduler2;
    }(AsyncScheduler_1.AsyncScheduler);
    exports.QueueScheduler = QueueScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/queue.js
var require_queue = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/queue.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.queue = exports.queueScheduler = void 0;
    var QueueAction_1 = require_QueueAction();
    var QueueScheduler_1 = require_QueueScheduler();
    exports.queueScheduler = new QueueScheduler_1.QueueScheduler(QueueAction_1.QueueAction);
    exports.queue = exports.queueScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AnimationFrameAction.js
var require_AnimationFrameAction = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AnimationFrameAction.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AnimationFrameAction = void 0;
    var AsyncAction_1 = require_AsyncAction();
    var animationFrameProvider_1 = require_animationFrameProvider();
    var AnimationFrameAction = function(_super) {
      __extends(AnimationFrameAction2, _super);
      function AnimationFrameAction2(scheduler, work) {
        var _this = _super.call(this, scheduler, work) || this;
        _this.scheduler = scheduler;
        _this.work = work;
        return _this;
      }
      AnimationFrameAction2.prototype.requestAsyncId = function(scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (delay !== null && delay > 0) {
          return _super.prototype.requestAsyncId.call(this, scheduler, id, delay);
        }
        scheduler.actions.push(this);
        return scheduler._scheduled || (scheduler._scheduled = animationFrameProvider_1.animationFrameProvider.requestAnimationFrame(function() {
          return scheduler.flush(void 0);
        }));
      };
      AnimationFrameAction2.prototype.recycleAsyncId = function(scheduler, id, delay) {
        var _a;
        if (delay === void 0) {
          delay = 0;
        }
        if (delay != null ? delay > 0 : this.delay > 0) {
          return _super.prototype.recycleAsyncId.call(this, scheduler, id, delay);
        }
        var actions = scheduler.actions;
        if (id != null && ((_a = actions[actions.length - 1]) === null || _a === void 0 ? void 0 : _a.id) !== id) {
          animationFrameProvider_1.animationFrameProvider.cancelAnimationFrame(id);
          scheduler._scheduled = void 0;
        }
        return void 0;
      };
      return AnimationFrameAction2;
    }(AsyncAction_1.AsyncAction);
    exports.AnimationFrameAction = AnimationFrameAction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AnimationFrameScheduler.js
var require_AnimationFrameScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/AnimationFrameScheduler.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.AnimationFrameScheduler = void 0;
    var AsyncScheduler_1 = require_AsyncScheduler();
    var AnimationFrameScheduler = function(_super) {
      __extends(AnimationFrameScheduler2, _super);
      function AnimationFrameScheduler2() {
        return _super !== null && _super.apply(this, arguments) || this;
      }
      AnimationFrameScheduler2.prototype.flush = function(action) {
        this._active = true;
        var flushId = this._scheduled;
        this._scheduled = void 0;
        var actions = this.actions;
        var error;
        action = action || actions.shift();
        do {
          if (error = action.execute(action.state, action.delay)) {
            break;
          }
        } while ((action = actions[0]) && action.id === flushId && actions.shift());
        this._active = false;
        if (error) {
          while ((action = actions[0]) && action.id === flushId && actions.shift()) {
            action.unsubscribe();
          }
          throw error;
        }
      };
      return AnimationFrameScheduler2;
    }(AsyncScheduler_1.AsyncScheduler);
    exports.AnimationFrameScheduler = AnimationFrameScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/animationFrame.js
var require_animationFrame = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/animationFrame.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.animationFrame = exports.animationFrameScheduler = void 0;
    var AnimationFrameAction_1 = require_AnimationFrameAction();
    var AnimationFrameScheduler_1 = require_AnimationFrameScheduler();
    exports.animationFrameScheduler = new AnimationFrameScheduler_1.AnimationFrameScheduler(AnimationFrameAction_1.AnimationFrameAction);
    exports.animationFrame = exports.animationFrameScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/VirtualTimeScheduler.js
var require_VirtualTimeScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduler/VirtualTimeScheduler.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (Object.prototype.hasOwnProperty.call(b2, p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        if (typeof b !== "function" && b !== null)
          throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.VirtualAction = exports.VirtualTimeScheduler = void 0;
    var AsyncAction_1 = require_AsyncAction();
    var Subscription_1 = require_Subscription();
    var AsyncScheduler_1 = require_AsyncScheduler();
    var VirtualTimeScheduler = function(_super) {
      __extends(VirtualTimeScheduler2, _super);
      function VirtualTimeScheduler2(schedulerActionCtor, maxFrames) {
        if (schedulerActionCtor === void 0) {
          schedulerActionCtor = VirtualAction;
        }
        if (maxFrames === void 0) {
          maxFrames = Infinity;
        }
        var _this = _super.call(this, schedulerActionCtor, function() {
          return _this.frame;
        }) || this;
        _this.maxFrames = maxFrames;
        _this.frame = 0;
        _this.index = -1;
        return _this;
      }
      VirtualTimeScheduler2.prototype.flush = function() {
        var _a = this, actions = _a.actions, maxFrames = _a.maxFrames;
        var error;
        var action;
        while ((action = actions[0]) && action.delay <= maxFrames) {
          actions.shift();
          this.frame = action.delay;
          if (error = action.execute(action.state, action.delay)) {
            break;
          }
        }
        if (error) {
          while (action = actions.shift()) {
            action.unsubscribe();
          }
          throw error;
        }
      };
      VirtualTimeScheduler2.frameTimeFactor = 10;
      return VirtualTimeScheduler2;
    }(AsyncScheduler_1.AsyncScheduler);
    exports.VirtualTimeScheduler = VirtualTimeScheduler;
    var VirtualAction = function(_super) {
      __extends(VirtualAction2, _super);
      function VirtualAction2(scheduler, work, index) {
        if (index === void 0) {
          index = scheduler.index += 1;
        }
        var _this = _super.call(this, scheduler, work) || this;
        _this.scheduler = scheduler;
        _this.work = work;
        _this.index = index;
        _this.active = true;
        _this.index = scheduler.index = index;
        return _this;
      }
      VirtualAction2.prototype.schedule = function(state, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        if (Number.isFinite(delay)) {
          if (!this.id) {
            return _super.prototype.schedule.call(this, state, delay);
          }
          this.active = false;
          var action = new VirtualAction2(this.scheduler, this.work);
          this.add(action);
          return action.schedule(state, delay);
        } else {
          return Subscription_1.Subscription.EMPTY;
        }
      };
      VirtualAction2.prototype.requestAsyncId = function(scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        this.delay = scheduler.frame + delay;
        var actions = scheduler.actions;
        actions.push(this);
        actions.sort(VirtualAction2.sortActions);
        return 1;
      };
      VirtualAction2.prototype.recycleAsyncId = function(scheduler, id, delay) {
        if (delay === void 0) {
          delay = 0;
        }
        return void 0;
      };
      VirtualAction2.prototype._execute = function(state, delay) {
        if (this.active === true) {
          return _super.prototype._execute.call(this, state, delay);
        }
      };
      VirtualAction2.sortActions = function(a, b) {
        if (a.delay === b.delay) {
          if (a.index === b.index) {
            return 0;
          } else if (a.index > b.index) {
            return 1;
          } else {
            return -1;
          }
        } else if (a.delay > b.delay) {
          return 1;
        } else {
          return -1;
        }
      };
      return VirtualAction2;
    }(AsyncAction_1.AsyncAction);
    exports.VirtualAction = VirtualAction;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/empty.js
var require_empty = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/empty.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.empty = exports.EMPTY = void 0;
    var Observable_1 = require_Observable();
    exports.EMPTY = new Observable_1.Observable(function(subscriber) {
      return subscriber.complete();
    });
    function empty(scheduler) {
      return scheduler ? emptyScheduled(scheduler) : exports.EMPTY;
    }
    exports.empty = empty;
    function emptyScheduled(scheduler) {
      return new Observable_1.Observable(function(subscriber) {
        return scheduler.schedule(function() {
          return subscriber.complete();
        });
      });
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isScheduler.js
var require_isScheduler = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isScheduler.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isScheduler = void 0;
    var isFunction_1 = require_isFunction2();
    function isScheduler(value2) {
      return value2 && isFunction_1.isFunction(value2.schedule);
    }
    exports.isScheduler = isScheduler;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/args.js
var require_args = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/args.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.popNumber = exports.popScheduler = exports.popResultSelector = void 0;
    var isFunction_1 = require_isFunction2();
    var isScheduler_1 = require_isScheduler();
    function last2(arr) {
      return arr[arr.length - 1];
    }
    function popResultSelector(args) {
      return isFunction_1.isFunction(last2(args)) ? args.pop() : void 0;
    }
    exports.popResultSelector = popResultSelector;
    function popScheduler(args) {
      return isScheduler_1.isScheduler(last2(args)) ? args.pop() : void 0;
    }
    exports.popScheduler = popScheduler;
    function popNumber(args, defaultValue) {
      return typeof last2(args) === "number" ? args.pop() : defaultValue;
    }
    exports.popNumber = popNumber;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isArrayLike.js
var require_isArrayLike = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isArrayLike.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isArrayLike = void 0;
    exports.isArrayLike = function(x) {
      return x && typeof x.length === "number" && typeof x !== "function";
    };
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isPromise.js
var require_isPromise = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isPromise.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isPromise = void 0;
    var isFunction_1 = require_isFunction2();
    function isPromise(value2) {
      return isFunction_1.isFunction(value2 === null || value2 === void 0 ? void 0 : value2.then);
    }
    exports.isPromise = isPromise;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isInteropObservable.js
var require_isInteropObservable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isInteropObservable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isInteropObservable = void 0;
    var observable_1 = require_observable();
    var isFunction_1 = require_isFunction2();
    function isInteropObservable(input) {
      return isFunction_1.isFunction(input[observable_1.observable]);
    }
    exports.isInteropObservable = isInteropObservable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isAsyncIterable.js
var require_isAsyncIterable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isAsyncIterable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isAsyncIterable = void 0;
    var isFunction_1 = require_isFunction2();
    function isAsyncIterable(obj) {
      return Symbol.asyncIterator && isFunction_1.isFunction(obj === null || obj === void 0 ? void 0 : obj[Symbol.asyncIterator]);
    }
    exports.isAsyncIterable = isAsyncIterable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/throwUnobservableError.js
var require_throwUnobservableError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/throwUnobservableError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createInvalidObservableTypeError = void 0;
    function createInvalidObservableTypeError(input) {
      return new TypeError("You provided " + (input !== null && typeof input === "object" ? "an invalid object" : "'" + input + "'") + " where a stream was expected. You can provide an Observable, Promise, ReadableStream, Array, AsyncIterable, or Iterable.");
    }
    exports.createInvalidObservableTypeError = createInvalidObservableTypeError;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/symbol/iterator.js
var require_iterator = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/symbol/iterator.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.iterator = exports.getSymbolIterator = void 0;
    function getSymbolIterator() {
      if (typeof Symbol !== "function" || !Symbol.iterator) {
        return "@@iterator";
      }
      return Symbol.iterator;
    }
    exports.getSymbolIterator = getSymbolIterator;
    exports.iterator = getSymbolIterator();
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isIterable.js
var require_isIterable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isIterable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isIterable = void 0;
    var iterator_1 = require_iterator();
    var isFunction_1 = require_isFunction2();
    function isIterable(input) {
      return isFunction_1.isFunction(input === null || input === void 0 ? void 0 : input[iterator_1.iterator]);
    }
    exports.isIterable = isIterable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isReadableStreamLike.js
var require_isReadableStreamLike = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isReadableStreamLike.js"(exports) {
    "use strict";
    var __generator = exports && exports.__generator || function(thisArg, body) {
      var _ = { label: 0, sent: function() {
        if (t3[0] & 1)
          throw t3[1];
        return t3[1];
      }, trys: [], ops: [] }, f, y, t3, g;
      return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
        return this;
      }), g;
      function verb(n) {
        return function(v) {
          return step([n, v]);
        };
      }
      function step(op) {
        if (f)
          throw new TypeError("Generator is already executing.");
        while (_)
          try {
            if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
              return t3;
            if (y = 0, t3)
              op = [op[0] & 2, t3.value];
            switch (op[0]) {
              case 0:
              case 1:
                t3 = op;
                break;
              case 4:
                _.label++;
                return { value: op[1], done: false };
              case 5:
                _.label++;
                y = op[1];
                op = [0];
                continue;
              case 7:
                op = _.ops.pop();
                _.trys.pop();
                continue;
              default:
                if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                  _ = 0;
                  continue;
                }
                if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                  _.label = op[1];
                  break;
                }
                if (op[0] === 6 && _.label < t3[1]) {
                  _.label = t3[1];
                  t3 = op;
                  break;
                }
                if (t3 && _.label < t3[2]) {
                  _.label = t3[2];
                  _.ops.push(op);
                  break;
                }
                if (t3[2])
                  _.ops.pop();
                _.trys.pop();
                continue;
            }
            op = body.call(thisArg, _);
          } catch (e) {
            op = [6, e];
            y = 0;
          } finally {
            f = t3 = 0;
          }
        if (op[0] & 5)
          throw op[1];
        return { value: op[0] ? op[1] : void 0, done: true };
      }
    };
    var __await = exports && exports.__await || function(v) {
      return this instanceof __await ? (this.v = v, this) : new __await(v);
    };
    var __asyncGenerator = exports && exports.__asyncGenerator || function(thisArg, _arguments, generator) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var g = generator.apply(thisArg, _arguments || []), i, q = [];
      return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i;
      function verb(n) {
        if (g[n])
          i[n] = function(v) {
            return new Promise(function(a, b) {
              q.push([n, v, a, b]) > 1 || resume(n, v);
            });
          };
      }
      function resume(n, v) {
        try {
          step(g[n](v));
        } catch (e) {
          settle(q[0][3], e);
        }
      }
      function step(r) {
        r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);
      }
      function fulfill(value2) {
        resume("next", value2);
      }
      function reject(value2) {
        resume("throw", value2);
      }
      function settle(f, v) {
        if (f(v), q.shift(), q.length)
          resume(q[0][0], q[0][1]);
      }
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isReadableStreamLike = exports.readableStreamLikeToAsyncGenerator = void 0;
    var isFunction_1 = require_isFunction2();
    function readableStreamLikeToAsyncGenerator(readableStream) {
      return __asyncGenerator(this, arguments, function readableStreamLikeToAsyncGenerator_1() {
        var reader, _a, value2, done;
        return __generator(this, function(_b) {
          switch (_b.label) {
            case 0:
              reader = readableStream.getReader();
              _b.label = 1;
            case 1:
              _b.trys.push([1, , 9, 10]);
              _b.label = 2;
            case 2:
              if (false)
                return [3, 8];
              return [4, __await(reader.read())];
            case 3:
              _a = _b.sent(), value2 = _a.value, done = _a.done;
              if (!done)
                return [3, 5];
              return [4, __await(void 0)];
            case 4:
              return [2, _b.sent()];
            case 5:
              return [4, __await(value2)];
            case 6:
              return [4, _b.sent()];
            case 7:
              _b.sent();
              return [3, 2];
            case 8:
              return [3, 10];
            case 9:
              reader.releaseLock();
              return [7];
            case 10:
              return [2];
          }
        });
      });
    }
    exports.readableStreamLikeToAsyncGenerator = readableStreamLikeToAsyncGenerator;
    function isReadableStreamLike(obj) {
      return isFunction_1.isFunction(obj === null || obj === void 0 ? void 0 : obj.getReader);
    }
    exports.isReadableStreamLike = isReadableStreamLike;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/innerFrom.js
var require_innerFrom = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/innerFrom.js"(exports) {
    "use strict";
    var __awaiter = exports && exports.__awaiter || function(thisArg, _arguments, P, generator) {
      function adopt(value2) {
        return value2 instanceof P ? value2 : new P(function(resolve) {
          resolve(value2);
        });
      }
      return new (P || (P = Promise))(function(resolve, reject) {
        function fulfilled(value2) {
          try {
            step(generator.next(value2));
          } catch (e) {
            reject(e);
          }
        }
        function rejected(value2) {
          try {
            step(generator["throw"](value2));
          } catch (e) {
            reject(e);
          }
        }
        function step(result) {
          result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
      });
    };
    var __generator = exports && exports.__generator || function(thisArg, body) {
      var _ = { label: 0, sent: function() {
        if (t3[0] & 1)
          throw t3[1];
        return t3[1];
      }, trys: [], ops: [] }, f, y, t3, g;
      return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
        return this;
      }), g;
      function verb(n) {
        return function(v) {
          return step([n, v]);
        };
      }
      function step(op) {
        if (f)
          throw new TypeError("Generator is already executing.");
        while (_)
          try {
            if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
              return t3;
            if (y = 0, t3)
              op = [op[0] & 2, t3.value];
            switch (op[0]) {
              case 0:
              case 1:
                t3 = op;
                break;
              case 4:
                _.label++;
                return { value: op[1], done: false };
              case 5:
                _.label++;
                y = op[1];
                op = [0];
                continue;
              case 7:
                op = _.ops.pop();
                _.trys.pop();
                continue;
              default:
                if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                  _ = 0;
                  continue;
                }
                if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                  _.label = op[1];
                  break;
                }
                if (op[0] === 6 && _.label < t3[1]) {
                  _.label = t3[1];
                  t3 = op;
                  break;
                }
                if (t3 && _.label < t3[2]) {
                  _.label = t3[2];
                  _.ops.push(op);
                  break;
                }
                if (t3[2])
                  _.ops.pop();
                _.trys.pop();
                continue;
            }
            op = body.call(thisArg, _);
          } catch (e) {
            op = [6, e];
            y = 0;
          } finally {
            f = t3 = 0;
          }
        if (op[0] & 5)
          throw op[1];
        return { value: op[0] ? op[1] : void 0, done: true };
      }
    };
    var __asyncValues = exports && exports.__asyncValues || function(o) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var m = o[Symbol.asyncIterator], i;
      return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i);
      function verb(n) {
        i[n] = o[n] && function(v) {
          return new Promise(function(resolve, reject) {
            v = o[n](v), settle(resolve, reject, v.done, v.value);
          });
        };
      }
      function settle(resolve, reject, d, v) {
        Promise.resolve(v).then(function(v2) {
          resolve({ value: v2, done: d });
        }, reject);
      }
    };
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fromReadableStreamLike = exports.fromAsyncIterable = exports.fromIterable = exports.fromPromise = exports.fromArrayLike = exports.fromInteropObservable = exports.innerFrom = void 0;
    var isArrayLike_1 = require_isArrayLike();
    var isPromise_1 = require_isPromise();
    var Observable_1 = require_Observable();
    var isInteropObservable_1 = require_isInteropObservable();
    var isAsyncIterable_1 = require_isAsyncIterable();
    var throwUnobservableError_1 = require_throwUnobservableError();
    var isIterable_1 = require_isIterable();
    var isReadableStreamLike_1 = require_isReadableStreamLike();
    var isFunction_1 = require_isFunction2();
    var reportUnhandledError_1 = require_reportUnhandledError();
    var observable_1 = require_observable();
    function innerFrom(input) {
      if (input instanceof Observable_1.Observable) {
        return input;
      }
      if (input != null) {
        if (isInteropObservable_1.isInteropObservable(input)) {
          return fromInteropObservable(input);
        }
        if (isArrayLike_1.isArrayLike(input)) {
          return fromArrayLike(input);
        }
        if (isPromise_1.isPromise(input)) {
          return fromPromise(input);
        }
        if (isAsyncIterable_1.isAsyncIterable(input)) {
          return fromAsyncIterable(input);
        }
        if (isIterable_1.isIterable(input)) {
          return fromIterable(input);
        }
        if (isReadableStreamLike_1.isReadableStreamLike(input)) {
          return fromReadableStreamLike(input);
        }
      }
      throw throwUnobservableError_1.createInvalidObservableTypeError(input);
    }
    exports.innerFrom = innerFrom;
    function fromInteropObservable(obj) {
      return new Observable_1.Observable(function(subscriber) {
        var obs = obj[observable_1.observable]();
        if (isFunction_1.isFunction(obs.subscribe)) {
          return obs.subscribe(subscriber);
        }
        throw new TypeError("Provided object does not correctly implement Symbol.observable");
      });
    }
    exports.fromInteropObservable = fromInteropObservable;
    function fromArrayLike(array) {
      return new Observable_1.Observable(function(subscriber) {
        for (var i = 0; i < array.length && !subscriber.closed; i++) {
          subscriber.next(array[i]);
        }
        subscriber.complete();
      });
    }
    exports.fromArrayLike = fromArrayLike;
    function fromPromise(promise) {
      return new Observable_1.Observable(function(subscriber) {
        promise.then(function(value2) {
          if (!subscriber.closed) {
            subscriber.next(value2);
            subscriber.complete();
          }
        }, function(err) {
          return subscriber.error(err);
        }).then(null, reportUnhandledError_1.reportUnhandledError);
      });
    }
    exports.fromPromise = fromPromise;
    function fromIterable(iterable) {
      return new Observable_1.Observable(function(subscriber) {
        var e_1, _a;
        try {
          for (var iterable_1 = __values(iterable), iterable_1_1 = iterable_1.next(); !iterable_1_1.done; iterable_1_1 = iterable_1.next()) {
            var value2 = iterable_1_1.value;
            subscriber.next(value2);
            if (subscriber.closed) {
              return;
            }
          }
        } catch (e_1_1) {
          e_1 = { error: e_1_1 };
        } finally {
          try {
            if (iterable_1_1 && !iterable_1_1.done && (_a = iterable_1.return))
              _a.call(iterable_1);
          } finally {
            if (e_1)
              throw e_1.error;
          }
        }
        subscriber.complete();
      });
    }
    exports.fromIterable = fromIterable;
    function fromAsyncIterable(asyncIterable) {
      return new Observable_1.Observable(function(subscriber) {
        process2(asyncIterable, subscriber).catch(function(err) {
          return subscriber.error(err);
        });
      });
    }
    exports.fromAsyncIterable = fromAsyncIterable;
    function fromReadableStreamLike(readableStream) {
      return fromAsyncIterable(isReadableStreamLike_1.readableStreamLikeToAsyncGenerator(readableStream));
    }
    exports.fromReadableStreamLike = fromReadableStreamLike;
    function process2(asyncIterable, subscriber) {
      var asyncIterable_1, asyncIterable_1_1;
      var e_2, _a;
      return __awaiter(this, void 0, void 0, function() {
        var value2, e_2_1;
        return __generator(this, function(_b) {
          switch (_b.label) {
            case 0:
              _b.trys.push([0, 5, 6, 11]);
              asyncIterable_1 = __asyncValues(asyncIterable);
              _b.label = 1;
            case 1:
              return [4, asyncIterable_1.next()];
            case 2:
              if (!(asyncIterable_1_1 = _b.sent(), !asyncIterable_1_1.done))
                return [3, 4];
              value2 = asyncIterable_1_1.value;
              subscriber.next(value2);
              if (subscriber.closed) {
                return [2];
              }
              _b.label = 3;
            case 3:
              return [3, 1];
            case 4:
              return [3, 11];
            case 5:
              e_2_1 = _b.sent();
              e_2 = { error: e_2_1 };
              return [3, 11];
            case 6:
              _b.trys.push([6, , 9, 10]);
              if (!(asyncIterable_1_1 && !asyncIterable_1_1.done && (_a = asyncIterable_1.return)))
                return [3, 8];
              return [4, _a.call(asyncIterable_1)];
            case 7:
              _b.sent();
              _b.label = 8;
            case 8:
              return [3, 10];
            case 9:
              if (e_2)
                throw e_2.error;
              return [7];
            case 10:
              return [7];
            case 11:
              subscriber.complete();
              return [2];
          }
        });
      });
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/executeSchedule.js
var require_executeSchedule = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/executeSchedule.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.executeSchedule = void 0;
    function executeSchedule(parentSubscription, scheduler, work, delay, repeat) {
      if (delay === void 0) {
        delay = 0;
      }
      if (repeat === void 0) {
        repeat = false;
      }
      var scheduleSubscription = scheduler.schedule(function() {
        work();
        if (repeat) {
          parentSubscription.add(this.schedule(null, delay));
        } else {
          this.unsubscribe();
        }
      }, delay);
      parentSubscription.add(scheduleSubscription);
      if (!repeat) {
        return scheduleSubscription;
      }
    }
    exports.executeSchedule = executeSchedule;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/observeOn.js
var require_observeOn = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/observeOn.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.observeOn = void 0;
    var executeSchedule_1 = require_executeSchedule();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function observeOn(scheduler, delay) {
      if (delay === void 0) {
        delay = 0;
      }
      return lift_1.operate(function(source, subscriber) {
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            return subscriber.next(value2);
          }, delay);
        }, function() {
          return executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            return subscriber.complete();
          }, delay);
        }, function(err) {
          return executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            return subscriber.error(err);
          }, delay);
        }));
      });
    }
    exports.observeOn = observeOn;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/subscribeOn.js
var require_subscribeOn = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/subscribeOn.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.subscribeOn = void 0;
    var lift_1 = require_lift();
    function subscribeOn(scheduler, delay) {
      if (delay === void 0) {
        delay = 0;
      }
      return lift_1.operate(function(source, subscriber) {
        subscriber.add(scheduler.schedule(function() {
          return source.subscribe(subscriber);
        }, delay));
      });
    }
    exports.subscribeOn = subscribeOn;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleObservable.js
var require_scheduleObservable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleObservable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduleObservable = void 0;
    var innerFrom_1 = require_innerFrom();
    var observeOn_1 = require_observeOn();
    var subscribeOn_1 = require_subscribeOn();
    function scheduleObservable(input, scheduler) {
      return innerFrom_1.innerFrom(input).pipe(subscribeOn_1.subscribeOn(scheduler), observeOn_1.observeOn(scheduler));
    }
    exports.scheduleObservable = scheduleObservable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/schedulePromise.js
var require_schedulePromise = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/schedulePromise.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.schedulePromise = void 0;
    var innerFrom_1 = require_innerFrom();
    var observeOn_1 = require_observeOn();
    var subscribeOn_1 = require_subscribeOn();
    function schedulePromise(input, scheduler) {
      return innerFrom_1.innerFrom(input).pipe(subscribeOn_1.subscribeOn(scheduler), observeOn_1.observeOn(scheduler));
    }
    exports.schedulePromise = schedulePromise;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleArray.js
var require_scheduleArray = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleArray.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduleArray = void 0;
    var Observable_1 = require_Observable();
    function scheduleArray(input, scheduler) {
      return new Observable_1.Observable(function(subscriber) {
        var i = 0;
        return scheduler.schedule(function() {
          if (i === input.length) {
            subscriber.complete();
          } else {
            subscriber.next(input[i++]);
            if (!subscriber.closed) {
              this.schedule();
            }
          }
        });
      });
    }
    exports.scheduleArray = scheduleArray;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleIterable.js
var require_scheduleIterable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleIterable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduleIterable = void 0;
    var Observable_1 = require_Observable();
    var iterator_1 = require_iterator();
    var isFunction_1 = require_isFunction2();
    var executeSchedule_1 = require_executeSchedule();
    function scheduleIterable(input, scheduler) {
      return new Observable_1.Observable(function(subscriber) {
        var iterator;
        executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
          iterator = input[iterator_1.iterator]();
          executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            var _a;
            var value2;
            var done;
            try {
              _a = iterator.next(), value2 = _a.value, done = _a.done;
            } catch (err) {
              subscriber.error(err);
              return;
            }
            if (done) {
              subscriber.complete();
            } else {
              subscriber.next(value2);
            }
          }, 0, true);
        });
        return function() {
          return isFunction_1.isFunction(iterator === null || iterator === void 0 ? void 0 : iterator.return) && iterator.return();
        };
      });
    }
    exports.scheduleIterable = scheduleIterable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleAsyncIterable.js
var require_scheduleAsyncIterable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleAsyncIterable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduleAsyncIterable = void 0;
    var Observable_1 = require_Observable();
    var executeSchedule_1 = require_executeSchedule();
    function scheduleAsyncIterable(input, scheduler) {
      if (!input) {
        throw new Error("Iterable cannot be null");
      }
      return new Observable_1.Observable(function(subscriber) {
        executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
          var iterator = input[Symbol.asyncIterator]();
          executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            iterator.next().then(function(result) {
              if (result.done) {
                subscriber.complete();
              } else {
                subscriber.next(result.value);
              }
            });
          }, 0, true);
        });
      });
    }
    exports.scheduleAsyncIterable = scheduleAsyncIterable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleReadableStreamLike.js
var require_scheduleReadableStreamLike = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduleReadableStreamLike.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduleReadableStreamLike = void 0;
    var scheduleAsyncIterable_1 = require_scheduleAsyncIterable();
    var isReadableStreamLike_1 = require_isReadableStreamLike();
    function scheduleReadableStreamLike(input, scheduler) {
      return scheduleAsyncIterable_1.scheduleAsyncIterable(isReadableStreamLike_1.readableStreamLikeToAsyncGenerator(input), scheduler);
    }
    exports.scheduleReadableStreamLike = scheduleReadableStreamLike;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduled.js
var require_scheduled = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/scheduled/scheduled.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scheduled = void 0;
    var scheduleObservable_1 = require_scheduleObservable();
    var schedulePromise_1 = require_schedulePromise();
    var scheduleArray_1 = require_scheduleArray();
    var scheduleIterable_1 = require_scheduleIterable();
    var scheduleAsyncIterable_1 = require_scheduleAsyncIterable();
    var isInteropObservable_1 = require_isInteropObservable();
    var isPromise_1 = require_isPromise();
    var isArrayLike_1 = require_isArrayLike();
    var isIterable_1 = require_isIterable();
    var isAsyncIterable_1 = require_isAsyncIterable();
    var throwUnobservableError_1 = require_throwUnobservableError();
    var isReadableStreamLike_1 = require_isReadableStreamLike();
    var scheduleReadableStreamLike_1 = require_scheduleReadableStreamLike();
    function scheduled(input, scheduler) {
      if (input != null) {
        if (isInteropObservable_1.isInteropObservable(input)) {
          return scheduleObservable_1.scheduleObservable(input, scheduler);
        }
        if (isArrayLike_1.isArrayLike(input)) {
          return scheduleArray_1.scheduleArray(input, scheduler);
        }
        if (isPromise_1.isPromise(input)) {
          return schedulePromise_1.schedulePromise(input, scheduler);
        }
        if (isAsyncIterable_1.isAsyncIterable(input)) {
          return scheduleAsyncIterable_1.scheduleAsyncIterable(input, scheduler);
        }
        if (isIterable_1.isIterable(input)) {
          return scheduleIterable_1.scheduleIterable(input, scheduler);
        }
        if (isReadableStreamLike_1.isReadableStreamLike(input)) {
          return scheduleReadableStreamLike_1.scheduleReadableStreamLike(input, scheduler);
        }
      }
      throw throwUnobservableError_1.createInvalidObservableTypeError(input);
    }
    exports.scheduled = scheduled;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/from.js
var require_from2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/from.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.from = void 0;
    var scheduled_1 = require_scheduled();
    var innerFrom_1 = require_innerFrom();
    function from(input, scheduler) {
      return scheduler ? scheduled_1.scheduled(input, scheduler) : innerFrom_1.innerFrom(input);
    }
    exports.from = from;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/of.js
var require_of = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/of.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.of = void 0;
    var args_1 = require_args();
    var from_1 = require_from2();
    function of() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(args);
      return from_1.from(args, scheduler);
    }
    exports.of = of;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/throwError.js
var require_throwError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/throwError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.throwError = void 0;
    var Observable_1 = require_Observable();
    var isFunction_1 = require_isFunction2();
    function throwError(errorOrErrorFactory, scheduler) {
      var errorFactory = isFunction_1.isFunction(errorOrErrorFactory) ? errorOrErrorFactory : function() {
        return errorOrErrorFactory;
      };
      var init = function(subscriber) {
        return subscriber.error(errorFactory());
      };
      return new Observable_1.Observable(scheduler ? function(subscriber) {
        return scheduler.schedule(init, 0, subscriber);
      } : init);
    }
    exports.throwError = throwError;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Notification.js
var require_Notification = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/Notification.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.observeNotification = exports.Notification = exports.NotificationKind = void 0;
    var empty_1 = require_empty();
    var of_1 = require_of();
    var throwError_1 = require_throwError();
    var isFunction_1 = require_isFunction2();
    var NotificationKind;
    (function(NotificationKind2) {
      NotificationKind2["NEXT"] = "N";
      NotificationKind2["ERROR"] = "E";
      NotificationKind2["COMPLETE"] = "C";
    })(NotificationKind = exports.NotificationKind || (exports.NotificationKind = {}));
    var Notification = function() {
      function Notification2(kind, value2, error) {
        this.kind = kind;
        this.value = value2;
        this.error = error;
        this.hasValue = kind === "N";
      }
      Notification2.prototype.observe = function(observer) {
        return observeNotification(this, observer);
      };
      Notification2.prototype.do = function(nextHandler, errorHandler, completeHandler) {
        var _a = this, kind = _a.kind, value2 = _a.value, error = _a.error;
        return kind === "N" ? nextHandler === null || nextHandler === void 0 ? void 0 : nextHandler(value2) : kind === "E" ? errorHandler === null || errorHandler === void 0 ? void 0 : errorHandler(error) : completeHandler === null || completeHandler === void 0 ? void 0 : completeHandler();
      };
      Notification2.prototype.accept = function(nextOrObserver, error, complete) {
        var _a;
        return isFunction_1.isFunction((_a = nextOrObserver) === null || _a === void 0 ? void 0 : _a.next) ? this.observe(nextOrObserver) : this.do(nextOrObserver, error, complete);
      };
      Notification2.prototype.toObservable = function() {
        var _a = this, kind = _a.kind, value2 = _a.value, error = _a.error;
        var result = kind === "N" ? of_1.of(value2) : kind === "E" ? throwError_1.throwError(function() {
          return error;
        }) : kind === "C" ? empty_1.EMPTY : 0;
        if (!result) {
          throw new TypeError("Unexpected notification kind " + kind);
        }
        return result;
      };
      Notification2.createNext = function(value2) {
        return new Notification2("N", value2);
      };
      Notification2.createError = function(err) {
        return new Notification2("E", void 0, err);
      };
      Notification2.createComplete = function() {
        return Notification2.completeNotification;
      };
      Notification2.completeNotification = new Notification2("C");
      return Notification2;
    }();
    exports.Notification = Notification;
    function observeNotification(notification, observer) {
      var _a, _b, _c;
      var _d = notification, kind = _d.kind, value2 = _d.value, error = _d.error;
      if (typeof kind !== "string") {
        throw new TypeError('Invalid notification, missing "kind"');
      }
      kind === "N" ? (_a = observer.next) === null || _a === void 0 ? void 0 : _a.call(observer, value2) : kind === "E" ? (_b = observer.error) === null || _b === void 0 ? void 0 : _b.call(observer, error) : (_c = observer.complete) === null || _c === void 0 ? void 0 : _c.call(observer);
    }
    exports.observeNotification = observeNotification;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isObservable.js
var require_isObservable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isObservable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isObservable = void 0;
    var Observable_1 = require_Observable();
    var isFunction_1 = require_isFunction2();
    function isObservable(obj) {
      return !!obj && (obj instanceof Observable_1.Observable || isFunction_1.isFunction(obj.lift) && isFunction_1.isFunction(obj.subscribe));
    }
    exports.isObservable = isObservable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/EmptyError.js
var require_EmptyError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/EmptyError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.EmptyError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.EmptyError = createErrorClass_1.createErrorClass(function(_super) {
      return function EmptyErrorImpl() {
        _super(this);
        this.name = "EmptyError";
        this.message = "no elements in sequence";
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/lastValueFrom.js
var require_lastValueFrom = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/lastValueFrom.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.lastValueFrom = void 0;
    var EmptyError_1 = require_EmptyError();
    function lastValueFrom(source, config) {
      var hasConfig = typeof config === "object";
      return new Promise(function(resolve, reject) {
        var _hasValue = false;
        var _value;
        source.subscribe({
          next: function(value2) {
            _value = value2;
            _hasValue = true;
          },
          error: reject,
          complete: function() {
            if (_hasValue) {
              resolve(_value);
            } else if (hasConfig) {
              resolve(config.defaultValue);
            } else {
              reject(new EmptyError_1.EmptyError());
            }
          }
        });
      });
    }
    exports.lastValueFrom = lastValueFrom;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/firstValueFrom.js
var require_firstValueFrom = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/firstValueFrom.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.firstValueFrom = void 0;
    var EmptyError_1 = require_EmptyError();
    var Subscriber_1 = require_Subscriber();
    function firstValueFrom(source, config) {
      var hasConfig = typeof config === "object";
      return new Promise(function(resolve, reject) {
        var subscriber = new Subscriber_1.SafeSubscriber({
          next: function(value2) {
            resolve(value2);
            subscriber.unsubscribe();
          },
          error: reject,
          complete: function() {
            if (hasConfig) {
              resolve(config.defaultValue);
            } else {
              reject(new EmptyError_1.EmptyError());
            }
          }
        });
        source.subscribe(subscriber);
      });
    }
    exports.firstValueFrom = firstValueFrom;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/ArgumentOutOfRangeError.js
var require_ArgumentOutOfRangeError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/ArgumentOutOfRangeError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ArgumentOutOfRangeError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.ArgumentOutOfRangeError = createErrorClass_1.createErrorClass(function(_super) {
      return function ArgumentOutOfRangeErrorImpl() {
        _super(this);
        this.name = "ArgumentOutOfRangeError";
        this.message = "argument out of range";
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/NotFoundError.js
var require_NotFoundError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/NotFoundError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.NotFoundError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.NotFoundError = createErrorClass_1.createErrorClass(function(_super) {
      return function NotFoundErrorImpl(message) {
        _super(this);
        this.name = "NotFoundError";
        this.message = message;
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/SequenceError.js
var require_SequenceError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/SequenceError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.SequenceError = void 0;
    var createErrorClass_1 = require_createErrorClass();
    exports.SequenceError = createErrorClass_1.createErrorClass(function(_super) {
      return function SequenceErrorImpl(message) {
        _super(this);
        this.name = "SequenceError";
        this.message = message;
      };
    });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isDate.js
var require_isDate = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/isDate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isValidDate = void 0;
    function isValidDate(value2) {
      return value2 instanceof Date && !isNaN(value2);
    }
    exports.isValidDate = isValidDate;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeout.js
var require_timeout = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeout.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.timeout = exports.TimeoutError = void 0;
    var async_1 = require_async();
    var isDate_1 = require_isDate();
    var lift_1 = require_lift();
    var innerFrom_1 = require_innerFrom();
    var createErrorClass_1 = require_createErrorClass();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var executeSchedule_1 = require_executeSchedule();
    exports.TimeoutError = createErrorClass_1.createErrorClass(function(_super) {
      return function TimeoutErrorImpl(info) {
        if (info === void 0) {
          info = null;
        }
        _super(this);
        this.message = "Timeout has occurred";
        this.name = "TimeoutError";
        this.info = info;
      };
    });
    function timeout(config, schedulerArg) {
      var _a = isDate_1.isValidDate(config) ? { first: config } : typeof config === "number" ? { each: config } : config, first2 = _a.first, each = _a.each, _b = _a.with, _with = _b === void 0 ? timeoutErrorFactory : _b, _c = _a.scheduler, scheduler = _c === void 0 ? schedulerArg !== null && schedulerArg !== void 0 ? schedulerArg : async_1.asyncScheduler : _c, _d = _a.meta, meta = _d === void 0 ? null : _d;
      if (first2 == null && each == null) {
        throw new TypeError("No timeout provided.");
      }
      return lift_1.operate(function(source, subscriber) {
        var originalSourceSubscription;
        var timerSubscription;
        var lastValue = null;
        var seen = 0;
        var startTimer = function(delay) {
          timerSubscription = executeSchedule_1.executeSchedule(subscriber, scheduler, function() {
            try {
              originalSourceSubscription.unsubscribe();
              innerFrom_1.innerFrom(_with({
                meta,
                lastValue,
                seen
              })).subscribe(subscriber);
            } catch (err) {
              subscriber.error(err);
            }
          }, delay);
        };
        originalSourceSubscription = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          timerSubscription === null || timerSubscription === void 0 ? void 0 : timerSubscription.unsubscribe();
          seen++;
          subscriber.next(lastValue = value2);
          each > 0 && startTimer(each);
        }, void 0, void 0, function() {
          if (!(timerSubscription === null || timerSubscription === void 0 ? void 0 : timerSubscription.closed)) {
            timerSubscription === null || timerSubscription === void 0 ? void 0 : timerSubscription.unsubscribe();
          }
          lastValue = null;
        }));
        !seen && startTimer(first2 != null ? typeof first2 === "number" ? first2 : +first2 - scheduler.now() : each);
      });
    }
    exports.timeout = timeout;
    function timeoutErrorFactory(info) {
      throw new exports.TimeoutError(info);
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/map.js
var require_map = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/map.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.map = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function map(project, thisArg) {
      return lift_1.operate(function(source, subscriber) {
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          subscriber.next(project.call(thisArg, value2, index++));
        }));
      });
    }
    exports.map = map;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/mapOneOrManyArgs.js
var require_mapOneOrManyArgs = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/mapOneOrManyArgs.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mapOneOrManyArgs = void 0;
    var map_1 = require_map();
    var isArray2 = Array.isArray;
    function callOrApply(fn, args) {
      return isArray2(args) ? fn.apply(void 0, __spreadArray([], __read(args))) : fn(args);
    }
    function mapOneOrManyArgs(fn) {
      return map_1.map(function(args) {
        return callOrApply(fn, args);
      });
    }
    exports.mapOneOrManyArgs = mapOneOrManyArgs;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindCallbackInternals.js
var require_bindCallbackInternals = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindCallbackInternals.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bindCallbackInternals = void 0;
    var isScheduler_1 = require_isScheduler();
    var Observable_1 = require_Observable();
    var subscribeOn_1 = require_subscribeOn();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var observeOn_1 = require_observeOn();
    var AsyncSubject_1 = require_AsyncSubject();
    function bindCallbackInternals(isNodeStyle, callbackFunc, resultSelector, scheduler) {
      if (resultSelector) {
        if (isScheduler_1.isScheduler(resultSelector)) {
          scheduler = resultSelector;
        } else {
          return function() {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
              args[_i] = arguments[_i];
            }
            return bindCallbackInternals(isNodeStyle, callbackFunc, scheduler).apply(this, args).pipe(mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector));
          };
        }
      }
      if (scheduler) {
        return function() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
          }
          return bindCallbackInternals(isNodeStyle, callbackFunc).apply(this, args).pipe(subscribeOn_1.subscribeOn(scheduler), observeOn_1.observeOn(scheduler));
        };
      }
      return function() {
        var _this = this;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var subject = new AsyncSubject_1.AsyncSubject();
        var uninitialized = true;
        return new Observable_1.Observable(function(subscriber) {
          var subs = subject.subscribe(subscriber);
          if (uninitialized) {
            uninitialized = false;
            var isAsync_1 = false;
            var isComplete_1 = false;
            callbackFunc.apply(_this, __spreadArray(__spreadArray([], __read(args)), [
              function() {
                var results = [];
                for (var _i2 = 0; _i2 < arguments.length; _i2++) {
                  results[_i2] = arguments[_i2];
                }
                if (isNodeStyle) {
                  var err = results.shift();
                  if (err != null) {
                    subject.error(err);
                    return;
                  }
                }
                subject.next(1 < results.length ? results : results[0]);
                isComplete_1 = true;
                if (isAsync_1) {
                  subject.complete();
                }
              }
            ]));
            if (isComplete_1) {
              subject.complete();
            }
            isAsync_1 = true;
          }
          return subs;
        });
      };
    }
    exports.bindCallbackInternals = bindCallbackInternals;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindCallback.js
var require_bindCallback = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindCallback.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bindCallback = void 0;
    var bindCallbackInternals_1 = require_bindCallbackInternals();
    function bindCallback(callbackFunc, resultSelector, scheduler) {
      return bindCallbackInternals_1.bindCallbackInternals(false, callbackFunc, resultSelector, scheduler);
    }
    exports.bindCallback = bindCallback;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindNodeCallback.js
var require_bindNodeCallback = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/bindNodeCallback.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bindNodeCallback = void 0;
    var bindCallbackInternals_1 = require_bindCallbackInternals();
    function bindNodeCallback(callbackFunc, resultSelector, scheduler) {
      return bindCallbackInternals_1.bindCallbackInternals(true, callbackFunc, resultSelector, scheduler);
    }
    exports.bindNodeCallback = bindNodeCallback;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/argsArgArrayOrObject.js
var require_argsArgArrayOrObject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/argsArgArrayOrObject.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.argsArgArrayOrObject = void 0;
    var isArray2 = Array.isArray;
    var getPrototypeOf = Object.getPrototypeOf;
    var objectProto = Object.prototype;
    var getKeys = Object.keys;
    function argsArgArrayOrObject(args) {
      if (args.length === 1) {
        var first_1 = args[0];
        if (isArray2(first_1)) {
          return { args: first_1, keys: null };
        }
        if (isPOJO(first_1)) {
          var keys3 = getKeys(first_1);
          return {
            args: keys3.map(function(key) {
              return first_1[key];
            }),
            keys: keys3
          };
        }
      }
      return { args, keys: null };
    }
    exports.argsArgArrayOrObject = argsArgArrayOrObject;
    function isPOJO(obj) {
      return obj && typeof obj === "object" && getPrototypeOf(obj) === objectProto;
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/createObject.js
var require_createObject = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/createObject.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createObject = void 0;
    function createObject(keys3, values2) {
      return keys3.reduce(function(result, key, i) {
        return result[key] = values2[i], result;
      }, {});
    }
    exports.createObject = createObject;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/combineLatest.js
var require_combineLatest = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/combineLatest.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.combineLatestInit = exports.combineLatest = void 0;
    var Observable_1 = require_Observable();
    var argsArgArrayOrObject_1 = require_argsArgArrayOrObject();
    var from_1 = require_from2();
    var identity_1 = require_identity();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var args_1 = require_args();
    var createObject_1 = require_createObject();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var executeSchedule_1 = require_executeSchedule();
    function combineLatest() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(args);
      var resultSelector = args_1.popResultSelector(args);
      var _a = argsArgArrayOrObject_1.argsArgArrayOrObject(args), observables = _a.args, keys3 = _a.keys;
      if (observables.length === 0) {
        return from_1.from([], scheduler);
      }
      var result = new Observable_1.Observable(combineLatestInit(observables, scheduler, keys3 ? function(values2) {
        return createObject_1.createObject(keys3, values2);
      } : identity_1.identity));
      return resultSelector ? result.pipe(mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector)) : result;
    }
    exports.combineLatest = combineLatest;
    function combineLatestInit(observables, scheduler, valueTransform) {
      if (valueTransform === void 0) {
        valueTransform = identity_1.identity;
      }
      return function(subscriber) {
        maybeSchedule(scheduler, function() {
          var length = observables.length;
          var values2 = new Array(length);
          var active = length;
          var remainingFirstValues = length;
          var _loop_1 = function(i2) {
            maybeSchedule(scheduler, function() {
              var source = from_1.from(observables[i2], scheduler);
              var hasFirstValue = false;
              source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
                values2[i2] = value2;
                if (!hasFirstValue) {
                  hasFirstValue = true;
                  remainingFirstValues--;
                }
                if (!remainingFirstValues) {
                  subscriber.next(valueTransform(values2.slice()));
                }
              }, function() {
                if (!--active) {
                  subscriber.complete();
                }
              }));
            }, subscriber);
          };
          for (var i = 0; i < length; i++) {
            _loop_1(i);
          }
        }, subscriber);
      };
    }
    exports.combineLatestInit = combineLatestInit;
    function maybeSchedule(scheduler, execute, subscription) {
      if (scheduler) {
        executeSchedule_1.executeSchedule(subscription, scheduler, execute);
      } else {
        execute();
      }
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeInternals.js
var require_mergeInternals = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeInternals.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeInternals = void 0;
    var innerFrom_1 = require_innerFrom();
    var executeSchedule_1 = require_executeSchedule();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function mergeInternals(source, subscriber, project, concurrent, onBeforeNext, expand, innerSubScheduler, additionalFinalizer) {
      var buffer = [];
      var active = 0;
      var index = 0;
      var isComplete = false;
      var checkComplete = function() {
        if (isComplete && !buffer.length && !active) {
          subscriber.complete();
        }
      };
      var outerNext = function(value2) {
        return active < concurrent ? doInnerSub(value2) : buffer.push(value2);
      };
      var doInnerSub = function(value2) {
        expand && subscriber.next(value2);
        active++;
        var innerComplete = false;
        innerFrom_1.innerFrom(project(value2, index++)).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(innerValue) {
          onBeforeNext === null || onBeforeNext === void 0 ? void 0 : onBeforeNext(innerValue);
          if (expand) {
            outerNext(innerValue);
          } else {
            subscriber.next(innerValue);
          }
        }, function() {
          innerComplete = true;
        }, void 0, function() {
          if (innerComplete) {
            try {
              active--;
              var _loop_1 = function() {
                var bufferedValue = buffer.shift();
                if (innerSubScheduler) {
                  executeSchedule_1.executeSchedule(subscriber, innerSubScheduler, function() {
                    return doInnerSub(bufferedValue);
                  });
                } else {
                  doInnerSub(bufferedValue);
                }
              };
              while (buffer.length && active < concurrent) {
                _loop_1();
              }
              checkComplete();
            } catch (err) {
              subscriber.error(err);
            }
          }
        }));
      };
      source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, outerNext, function() {
        isComplete = true;
        checkComplete();
      }));
      return function() {
        additionalFinalizer === null || additionalFinalizer === void 0 ? void 0 : additionalFinalizer();
      };
    }
    exports.mergeInternals = mergeInternals;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeMap.js
var require_mergeMap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeMap = void 0;
    var map_1 = require_map();
    var innerFrom_1 = require_innerFrom();
    var lift_1 = require_lift();
    var mergeInternals_1 = require_mergeInternals();
    var isFunction_1 = require_isFunction2();
    function mergeMap(project, resultSelector, concurrent) {
      if (concurrent === void 0) {
        concurrent = Infinity;
      }
      if (isFunction_1.isFunction(resultSelector)) {
        return mergeMap(function(a, i) {
          return map_1.map(function(b, ii) {
            return resultSelector(a, b, i, ii);
          })(innerFrom_1.innerFrom(project(a, i)));
        }, concurrent);
      } else if (typeof resultSelector === "number") {
        concurrent = resultSelector;
      }
      return lift_1.operate(function(source, subscriber) {
        return mergeInternals_1.mergeInternals(source, subscriber, project, concurrent);
      });
    }
    exports.mergeMap = mergeMap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeAll.js
var require_mergeAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeAll = void 0;
    var mergeMap_1 = require_mergeMap();
    var identity_1 = require_identity();
    function mergeAll(concurrent) {
      if (concurrent === void 0) {
        concurrent = Infinity;
      }
      return mergeMap_1.mergeMap(identity_1.identity, concurrent);
    }
    exports.mergeAll = mergeAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatAll.js
var require_concatAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concatAll = void 0;
    var mergeAll_1 = require_mergeAll();
    function concatAll() {
      return mergeAll_1.mergeAll(1);
    }
    exports.concatAll = concatAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/concat.js
var require_concat = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/concat.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concat = void 0;
    var concatAll_1 = require_concatAll();
    var args_1 = require_args();
    var from_1 = require_from2();
    function concat() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      return concatAll_1.concatAll()(from_1.from(args, args_1.popScheduler(args)));
    }
    exports.concat = concat;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/defer.js
var require_defer = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/defer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.defer = void 0;
    var Observable_1 = require_Observable();
    var innerFrom_1 = require_innerFrom();
    function defer(observableFactory) {
      return new Observable_1.Observable(function(subscriber) {
        innerFrom_1.innerFrom(observableFactory()).subscribe(subscriber);
      });
    }
    exports.defer = defer;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/connectable.js
var require_connectable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/connectable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.connectable = void 0;
    var Subject_1 = require_Subject();
    var Observable_1 = require_Observable();
    var defer_1 = require_defer();
    var DEFAULT_CONFIG = {
      connector: function() {
        return new Subject_1.Subject();
      },
      resetOnDisconnect: true
    };
    function connectable(source, config) {
      if (config === void 0) {
        config = DEFAULT_CONFIG;
      }
      var connection = null;
      var connector = config.connector, _a = config.resetOnDisconnect, resetOnDisconnect = _a === void 0 ? true : _a;
      var subject = connector();
      var result = new Observable_1.Observable(function(subscriber) {
        return subject.subscribe(subscriber);
      });
      result.connect = function() {
        if (!connection || connection.closed) {
          connection = defer_1.defer(function() {
            return source;
          }).subscribe(subject);
          if (resetOnDisconnect) {
            connection.add(function() {
              return subject = connector();
            });
          }
        }
        return connection;
      };
      return result;
    }
    exports.connectable = connectable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/forkJoin.js
var require_forkJoin = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/forkJoin.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.forkJoin = void 0;
    var Observable_1 = require_Observable();
    var argsArgArrayOrObject_1 = require_argsArgArrayOrObject();
    var innerFrom_1 = require_innerFrom();
    var args_1 = require_args();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var createObject_1 = require_createObject();
    function forkJoin() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var resultSelector = args_1.popResultSelector(args);
      var _a = argsArgArrayOrObject_1.argsArgArrayOrObject(args), sources = _a.args, keys3 = _a.keys;
      var result = new Observable_1.Observable(function(subscriber) {
        var length = sources.length;
        if (!length) {
          subscriber.complete();
          return;
        }
        var values2 = new Array(length);
        var remainingCompletions = length;
        var remainingEmissions = length;
        var _loop_1 = function(sourceIndex2) {
          var hasValue = false;
          innerFrom_1.innerFrom(sources[sourceIndex2]).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
            if (!hasValue) {
              hasValue = true;
              remainingEmissions--;
            }
            values2[sourceIndex2] = value2;
          }, function() {
            return remainingCompletions--;
          }, void 0, function() {
            if (!remainingCompletions || !hasValue) {
              if (!remainingEmissions) {
                subscriber.next(keys3 ? createObject_1.createObject(keys3, values2) : values2);
              }
              subscriber.complete();
            }
          }));
        };
        for (var sourceIndex = 0; sourceIndex < length; sourceIndex++) {
          _loop_1(sourceIndex);
        }
      });
      return resultSelector ? result.pipe(mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector)) : result;
    }
    exports.forkJoin = forkJoin;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromEvent.js
var require_fromEvent = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromEvent.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fromEvent = void 0;
    var innerFrom_1 = require_innerFrom();
    var Observable_1 = require_Observable();
    var mergeMap_1 = require_mergeMap();
    var isArrayLike_1 = require_isArrayLike();
    var isFunction_1 = require_isFunction2();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var nodeEventEmitterMethods = ["addListener", "removeListener"];
    var eventTargetMethods = ["addEventListener", "removeEventListener"];
    var jqueryMethods = ["on", "off"];
    function fromEvent(target, eventName, options, resultSelector) {
      if (isFunction_1.isFunction(options)) {
        resultSelector = options;
        options = void 0;
      }
      if (resultSelector) {
        return fromEvent(target, eventName, options).pipe(mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector));
      }
      var _a = __read(isEventTarget(target) ? eventTargetMethods.map(function(methodName) {
        return function(handler) {
          return target[methodName](eventName, handler, options);
        };
      }) : isNodeStyleEventEmitter(target) ? nodeEventEmitterMethods.map(toCommonHandlerRegistry(target, eventName)) : isJQueryStyleEventEmitter(target) ? jqueryMethods.map(toCommonHandlerRegistry(target, eventName)) : [], 2), add = _a[0], remove = _a[1];
      if (!add) {
        if (isArrayLike_1.isArrayLike(target)) {
          return mergeMap_1.mergeMap(function(subTarget) {
            return fromEvent(subTarget, eventName, options);
          })(innerFrom_1.innerFrom(target));
        }
      }
      if (!add) {
        throw new TypeError("Invalid event target");
      }
      return new Observable_1.Observable(function(subscriber) {
        var handler = function() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
          }
          return subscriber.next(1 < args.length ? args : args[0]);
        };
        add(handler);
        return function() {
          return remove(handler);
        };
      });
    }
    exports.fromEvent = fromEvent;
    function toCommonHandlerRegistry(target, eventName) {
      return function(methodName) {
        return function(handler) {
          return target[methodName](eventName, handler);
        };
      };
    }
    function isNodeStyleEventEmitter(target) {
      return isFunction_1.isFunction(target.addListener) && isFunction_1.isFunction(target.removeListener);
    }
    function isJQueryStyleEventEmitter(target) {
      return isFunction_1.isFunction(target.on) && isFunction_1.isFunction(target.off);
    }
    function isEventTarget(target) {
      return isFunction_1.isFunction(target.addEventListener) && isFunction_1.isFunction(target.removeEventListener);
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromEventPattern.js
var require_fromEventPattern = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromEventPattern.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fromEventPattern = void 0;
    var Observable_1 = require_Observable();
    var isFunction_1 = require_isFunction2();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    function fromEventPattern(addHandler, removeHandler, resultSelector) {
      if (resultSelector) {
        return fromEventPattern(addHandler, removeHandler).pipe(mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector));
      }
      return new Observable_1.Observable(function(subscriber) {
        var handler = function() {
          var e = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            e[_i] = arguments[_i];
          }
          return subscriber.next(e.length === 1 ? e[0] : e);
        };
        var retValue = addHandler(handler);
        return isFunction_1.isFunction(removeHandler) ? function() {
          return removeHandler(handler, retValue);
        } : void 0;
      });
    }
    exports.fromEventPattern = fromEventPattern;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/generate.js
var require_generate = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/generate.js"(exports) {
    "use strict";
    var __generator = exports && exports.__generator || function(thisArg, body) {
      var _ = { label: 0, sent: function() {
        if (t3[0] & 1)
          throw t3[1];
        return t3[1];
      }, trys: [], ops: [] }, f, y, t3, g;
      return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
        return this;
      }), g;
      function verb(n) {
        return function(v) {
          return step([n, v]);
        };
      }
      function step(op) {
        if (f)
          throw new TypeError("Generator is already executing.");
        while (_)
          try {
            if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
              return t3;
            if (y = 0, t3)
              op = [op[0] & 2, t3.value];
            switch (op[0]) {
              case 0:
              case 1:
                t3 = op;
                break;
              case 4:
                _.label++;
                return { value: op[1], done: false };
              case 5:
                _.label++;
                y = op[1];
                op = [0];
                continue;
              case 7:
                op = _.ops.pop();
                _.trys.pop();
                continue;
              default:
                if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                  _ = 0;
                  continue;
                }
                if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                  _.label = op[1];
                  break;
                }
                if (op[0] === 6 && _.label < t3[1]) {
                  _.label = t3[1];
                  t3 = op;
                  break;
                }
                if (t3 && _.label < t3[2]) {
                  _.label = t3[2];
                  _.ops.push(op);
                  break;
                }
                if (t3[2])
                  _.ops.pop();
                _.trys.pop();
                continue;
            }
            op = body.call(thisArg, _);
          } catch (e) {
            op = [6, e];
            y = 0;
          } finally {
            f = t3 = 0;
          }
        if (op[0] & 5)
          throw op[1];
        return { value: op[0] ? op[1] : void 0, done: true };
      }
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.generate = void 0;
    var identity_1 = require_identity();
    var isScheduler_1 = require_isScheduler();
    var defer_1 = require_defer();
    var scheduleIterable_1 = require_scheduleIterable();
    function generate2(initialStateOrOptions, condition, iterate, resultSelectorOrScheduler, scheduler) {
      var _a, _b;
      var resultSelector;
      var initialState;
      if (arguments.length === 1) {
        _a = initialStateOrOptions, initialState = _a.initialState, condition = _a.condition, iterate = _a.iterate, _b = _a.resultSelector, resultSelector = _b === void 0 ? identity_1.identity : _b, scheduler = _a.scheduler;
      } else {
        initialState = initialStateOrOptions;
        if (!resultSelectorOrScheduler || isScheduler_1.isScheduler(resultSelectorOrScheduler)) {
          resultSelector = identity_1.identity;
          scheduler = resultSelectorOrScheduler;
        } else {
          resultSelector = resultSelectorOrScheduler;
        }
      }
      function gen() {
        var state;
        return __generator(this, function(_a2) {
          switch (_a2.label) {
            case 0:
              state = initialState;
              _a2.label = 1;
            case 1:
              if (!(!condition || condition(state)))
                return [3, 4];
              return [4, resultSelector(state)];
            case 2:
              _a2.sent();
              _a2.label = 3;
            case 3:
              state = iterate(state);
              return [3, 1];
            case 4:
              return [2];
          }
        });
      }
      return defer_1.defer(scheduler ? function() {
        return scheduleIterable_1.scheduleIterable(gen(), scheduler);
      } : gen);
    }
    exports.generate = generate2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/iif.js
var require_iif = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/iif.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.iif = void 0;
    var defer_1 = require_defer();
    function iif(condition, trueResult, falseResult) {
      return defer_1.defer(function() {
        return condition() ? trueResult : falseResult;
      });
    }
    exports.iif = iif;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/timer.js
var require_timer = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/timer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.timer = void 0;
    var Observable_1 = require_Observable();
    var async_1 = require_async();
    var isScheduler_1 = require_isScheduler();
    var isDate_1 = require_isDate();
    function timer(dueTime, intervalOrScheduler, scheduler) {
      if (dueTime === void 0) {
        dueTime = 0;
      }
      if (scheduler === void 0) {
        scheduler = async_1.async;
      }
      var intervalDuration = -1;
      if (intervalOrScheduler != null) {
        if (isScheduler_1.isScheduler(intervalOrScheduler)) {
          scheduler = intervalOrScheduler;
        } else {
          intervalDuration = intervalOrScheduler;
        }
      }
      return new Observable_1.Observable(function(subscriber) {
        var due = isDate_1.isValidDate(dueTime) ? +dueTime - scheduler.now() : dueTime;
        if (due < 0) {
          due = 0;
        }
        var n = 0;
        return scheduler.schedule(function() {
          if (!subscriber.closed) {
            subscriber.next(n++);
            if (0 <= intervalDuration) {
              this.schedule(void 0, intervalDuration);
            } else {
              subscriber.complete();
            }
          }
        }, due);
      });
    }
    exports.timer = timer;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/interval.js
var require_interval = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/interval.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.interval = void 0;
    var async_1 = require_async();
    var timer_1 = require_timer();
    function interval(period, scheduler) {
      if (period === void 0) {
        period = 0;
      }
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      if (period < 0) {
        period = 0;
      }
      return timer_1.timer(period, period, scheduler);
    }
    exports.interval = interval;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/merge.js
var require_merge = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/merge.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.merge = void 0;
    var mergeAll_1 = require_mergeAll();
    var innerFrom_1 = require_innerFrom();
    var empty_1 = require_empty();
    var args_1 = require_args();
    var from_1 = require_from2();
    function merge4() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(args);
      var concurrent = args_1.popNumber(args, Infinity);
      var sources = args;
      return !sources.length ? empty_1.EMPTY : sources.length === 1 ? innerFrom_1.innerFrom(sources[0]) : mergeAll_1.mergeAll(concurrent)(from_1.from(sources, scheduler));
    }
    exports.merge = merge4;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/never.js
var require_never = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/never.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.never = exports.NEVER = void 0;
    var Observable_1 = require_Observable();
    var noop_1 = require_noop();
    exports.NEVER = new Observable_1.Observable(noop_1.noop);
    function never() {
      return exports.NEVER;
    }
    exports.never = never;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/argsOrArgArray.js
var require_argsOrArgArray = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/argsOrArgArray.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.argsOrArgArray = void 0;
    var isArray2 = Array.isArray;
    function argsOrArgArray(args) {
      return args.length === 1 && isArray2(args[0]) ? args[0] : args;
    }
    exports.argsOrArgArray = argsOrArgArray;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/onErrorResumeNext.js
var require_onErrorResumeNext = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/onErrorResumeNext.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.onErrorResumeNext = void 0;
    var Observable_1 = require_Observable();
    var argsOrArgArray_1 = require_argsOrArgArray();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    var innerFrom_1 = require_innerFrom();
    function onErrorResumeNext() {
      var sources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        sources[_i] = arguments[_i];
      }
      var nextSources = argsOrArgArray_1.argsOrArgArray(sources);
      return new Observable_1.Observable(function(subscriber) {
        var sourceIndex = 0;
        var subscribeNext = function() {
          if (sourceIndex < nextSources.length) {
            var nextSource = void 0;
            try {
              nextSource = innerFrom_1.innerFrom(nextSources[sourceIndex++]);
            } catch (err) {
              subscribeNext();
              return;
            }
            var innerSubscriber = new OperatorSubscriber_1.OperatorSubscriber(subscriber, void 0, noop_1.noop, noop_1.noop);
            nextSource.subscribe(innerSubscriber);
            innerSubscriber.add(subscribeNext);
          } else {
            subscriber.complete();
          }
        };
        subscribeNext();
      });
    }
    exports.onErrorResumeNext = onErrorResumeNext;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/pairs.js
var require_pairs = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/pairs.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.pairs = void 0;
    var from_1 = require_from2();
    function pairs(obj, scheduler) {
      return from_1.from(Object.entries(obj), scheduler);
    }
    exports.pairs = pairs;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/not.js
var require_not = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/util/not.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.not = void 0;
    function not(pred, thisArg) {
      return function(value2, index) {
        return !pred.call(thisArg, value2, index);
      };
    }
    exports.not = not;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/filter.js
var require_filter = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/filter.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.filter = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function filter(predicate, thisArg) {
      return lift_1.operate(function(source, subscriber) {
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return predicate.call(thisArg, value2, index++) && subscriber.next(value2);
        }));
      });
    }
    exports.filter = filter;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/partition.js
var require_partition = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/partition.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.partition = void 0;
    var not_1 = require_not();
    var filter_1 = require_filter();
    var innerFrom_1 = require_innerFrom();
    function partition(source, predicate, thisArg) {
      return [filter_1.filter(predicate, thisArg)(innerFrom_1.innerFrom(source)), filter_1.filter(not_1.not(predicate, thisArg))(innerFrom_1.innerFrom(source))];
    }
    exports.partition = partition;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/race.js
var require_race = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/race.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.raceInit = exports.race = void 0;
    var Observable_1 = require_Observable();
    var innerFrom_1 = require_innerFrom();
    var argsOrArgArray_1 = require_argsOrArgArray();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function race() {
      var sources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        sources[_i] = arguments[_i];
      }
      sources = argsOrArgArray_1.argsOrArgArray(sources);
      return sources.length === 1 ? innerFrom_1.innerFrom(sources[0]) : new Observable_1.Observable(raceInit(sources));
    }
    exports.race = race;
    function raceInit(sources) {
      return function(subscriber) {
        var subscriptions = [];
        var _loop_1 = function(i2) {
          subscriptions.push(innerFrom_1.innerFrom(sources[i2]).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
            if (subscriptions) {
              for (var s = 0; s < subscriptions.length; s++) {
                s !== i2 && subscriptions[s].unsubscribe();
              }
              subscriptions = null;
            }
            subscriber.next(value2);
          })));
        };
        for (var i = 0; subscriptions && !subscriber.closed && i < sources.length; i++) {
          _loop_1(i);
        }
      };
    }
    exports.raceInit = raceInit;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/range.js
var require_range = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/range.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.range = void 0;
    var Observable_1 = require_Observable();
    var empty_1 = require_empty();
    function range(start, count, scheduler) {
      if (count == null) {
        count = start;
        start = 0;
      }
      if (count <= 0) {
        return empty_1.EMPTY;
      }
      var end = count + start;
      return new Observable_1.Observable(scheduler ? function(subscriber) {
        var n = start;
        return scheduler.schedule(function() {
          if (n < end) {
            subscriber.next(n++);
            this.schedule();
          } else {
            subscriber.complete();
          }
        });
      } : function(subscriber) {
        var n = start;
        while (n < end && !subscriber.closed) {
          subscriber.next(n++);
        }
        subscriber.complete();
      });
    }
    exports.range = range;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/using.js
var require_using = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/using.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.using = void 0;
    var Observable_1 = require_Observable();
    var innerFrom_1 = require_innerFrom();
    var empty_1 = require_empty();
    function using(resourceFactory, observableFactory) {
      return new Observable_1.Observable(function(subscriber) {
        var resource = resourceFactory();
        var result = observableFactory(resource);
        var source = result ? innerFrom_1.innerFrom(result) : empty_1.EMPTY;
        source.subscribe(subscriber);
        return function() {
          if (resource) {
            resource.unsubscribe();
          }
        };
      });
    }
    exports.using = using;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/zip.js
var require_zip = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/zip.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.zip = void 0;
    var Observable_1 = require_Observable();
    var innerFrom_1 = require_innerFrom();
    var argsOrArgArray_1 = require_argsOrArgArray();
    var empty_1 = require_empty();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var args_1 = require_args();
    function zip() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var resultSelector = args_1.popResultSelector(args);
      var sources = argsOrArgArray_1.argsOrArgArray(args);
      return sources.length ? new Observable_1.Observable(function(subscriber) {
        var buffers = sources.map(function() {
          return [];
        });
        var completed = sources.map(function() {
          return false;
        });
        subscriber.add(function() {
          buffers = completed = null;
        });
        var _loop_1 = function(sourceIndex2) {
          innerFrom_1.innerFrom(sources[sourceIndex2]).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
            buffers[sourceIndex2].push(value2);
            if (buffers.every(function(buffer) {
              return buffer.length;
            })) {
              var result = buffers.map(function(buffer) {
                return buffer.shift();
              });
              subscriber.next(resultSelector ? resultSelector.apply(void 0, __spreadArray([], __read(result))) : result);
              if (buffers.some(function(buffer, i) {
                return !buffer.length && completed[i];
              })) {
                subscriber.complete();
              }
            }
          }, function() {
            completed[sourceIndex2] = true;
            !buffers[sourceIndex2].length && subscriber.complete();
          }));
        };
        for (var sourceIndex = 0; !subscriber.closed && sourceIndex < sources.length; sourceIndex++) {
          _loop_1(sourceIndex);
        }
        return function() {
          buffers = completed = null;
        };
      }) : empty_1.EMPTY;
    }
    exports.zip = zip;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/types.js
var require_types = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/types.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/audit.js
var require_audit = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/audit.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.audit = void 0;
    var lift_1 = require_lift();
    var innerFrom_1 = require_innerFrom();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function audit(durationSelector) {
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        var lastValue = null;
        var durationSubscriber = null;
        var isComplete = false;
        var endDuration = function() {
          durationSubscriber === null || durationSubscriber === void 0 ? void 0 : durationSubscriber.unsubscribe();
          durationSubscriber = null;
          if (hasValue) {
            hasValue = false;
            var value2 = lastValue;
            lastValue = null;
            subscriber.next(value2);
          }
          isComplete && subscriber.complete();
        };
        var cleanupDuration = function() {
          durationSubscriber = null;
          isComplete && subscriber.complete();
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          hasValue = true;
          lastValue = value2;
          if (!durationSubscriber) {
            innerFrom_1.innerFrom(durationSelector(value2)).subscribe(durationSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, endDuration, cleanupDuration));
          }
        }, function() {
          isComplete = true;
          (!hasValue || !durationSubscriber || durationSubscriber.closed) && subscriber.complete();
        }));
      });
    }
    exports.audit = audit;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/auditTime.js
var require_auditTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/auditTime.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.auditTime = void 0;
    var async_1 = require_async();
    var audit_1 = require_audit();
    var timer_1 = require_timer();
    function auditTime(duration, scheduler) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      return audit_1.audit(function() {
        return timer_1.timer(duration, scheduler);
      });
    }
    exports.auditTime = auditTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/buffer.js
var require_buffer = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/buffer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.buffer = void 0;
    var lift_1 = require_lift();
    var noop_1 = require_noop();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    function buffer(closingNotifier) {
      return lift_1.operate(function(source, subscriber) {
        var currentBuffer = [];
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return currentBuffer.push(value2);
        }, function() {
          subscriber.next(currentBuffer);
          subscriber.complete();
        }));
        innerFrom_1.innerFrom(closingNotifier).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          var b = currentBuffer;
          currentBuffer = [];
          subscriber.next(b);
        }, noop_1.noop));
        return function() {
          currentBuffer = null;
        };
      });
    }
    exports.buffer = buffer;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferCount.js
var require_bufferCount = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferCount.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bufferCount = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var arrRemove_1 = require_arrRemove();
    function bufferCount(bufferSize, startBufferEvery) {
      if (startBufferEvery === void 0) {
        startBufferEvery = null;
      }
      startBufferEvery = startBufferEvery !== null && startBufferEvery !== void 0 ? startBufferEvery : bufferSize;
      return lift_1.operate(function(source, subscriber) {
        var buffers = [];
        var count = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var e_1, _a, e_2, _b;
          var toEmit = null;
          if (count++ % startBufferEvery === 0) {
            buffers.push([]);
          }
          try {
            for (var buffers_1 = __values(buffers), buffers_1_1 = buffers_1.next(); !buffers_1_1.done; buffers_1_1 = buffers_1.next()) {
              var buffer = buffers_1_1.value;
              buffer.push(value2);
              if (bufferSize <= buffer.length) {
                toEmit = toEmit !== null && toEmit !== void 0 ? toEmit : [];
                toEmit.push(buffer);
              }
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (buffers_1_1 && !buffers_1_1.done && (_a = buffers_1.return))
                _a.call(buffers_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
          if (toEmit) {
            try {
              for (var toEmit_1 = __values(toEmit), toEmit_1_1 = toEmit_1.next(); !toEmit_1_1.done; toEmit_1_1 = toEmit_1.next()) {
                var buffer = toEmit_1_1.value;
                arrRemove_1.arrRemove(buffers, buffer);
                subscriber.next(buffer);
              }
            } catch (e_2_1) {
              e_2 = { error: e_2_1 };
            } finally {
              try {
                if (toEmit_1_1 && !toEmit_1_1.done && (_b = toEmit_1.return))
                  _b.call(toEmit_1);
              } finally {
                if (e_2)
                  throw e_2.error;
              }
            }
          }
        }, function() {
          var e_3, _a;
          try {
            for (var buffers_2 = __values(buffers), buffers_2_1 = buffers_2.next(); !buffers_2_1.done; buffers_2_1 = buffers_2.next()) {
              var buffer = buffers_2_1.value;
              subscriber.next(buffer);
            }
          } catch (e_3_1) {
            e_3 = { error: e_3_1 };
          } finally {
            try {
              if (buffers_2_1 && !buffers_2_1.done && (_a = buffers_2.return))
                _a.call(buffers_2);
            } finally {
              if (e_3)
                throw e_3.error;
            }
          }
          subscriber.complete();
        }, void 0, function() {
          buffers = null;
        }));
      });
    }
    exports.bufferCount = bufferCount;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferTime.js
var require_bufferTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferTime.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bufferTime = void 0;
    var Subscription_1 = require_Subscription();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var arrRemove_1 = require_arrRemove();
    var async_1 = require_async();
    var args_1 = require_args();
    var executeSchedule_1 = require_executeSchedule();
    function bufferTime(bufferTimeSpan) {
      var _a, _b;
      var otherArgs = [];
      for (var _i = 1; _i < arguments.length; _i++) {
        otherArgs[_i - 1] = arguments[_i];
      }
      var scheduler = (_a = args_1.popScheduler(otherArgs)) !== null && _a !== void 0 ? _a : async_1.asyncScheduler;
      var bufferCreationInterval = (_b = otherArgs[0]) !== null && _b !== void 0 ? _b : null;
      var maxBufferSize = otherArgs[1] || Infinity;
      return lift_1.operate(function(source, subscriber) {
        var bufferRecords = [];
        var restartOnEmit = false;
        var emit = function(record) {
          var buffer = record.buffer, subs = record.subs;
          subs.unsubscribe();
          arrRemove_1.arrRemove(bufferRecords, record);
          subscriber.next(buffer);
          restartOnEmit && startBuffer();
        };
        var startBuffer = function() {
          if (bufferRecords) {
            var subs = new Subscription_1.Subscription();
            subscriber.add(subs);
            var buffer = [];
            var record_1 = {
              buffer,
              subs
            };
            bufferRecords.push(record_1);
            executeSchedule_1.executeSchedule(subs, scheduler, function() {
              return emit(record_1);
            }, bufferTimeSpan);
          }
        };
        if (bufferCreationInterval !== null && bufferCreationInterval >= 0) {
          executeSchedule_1.executeSchedule(subscriber, scheduler, startBuffer, bufferCreationInterval, true);
        } else {
          restartOnEmit = true;
        }
        startBuffer();
        var bufferTimeSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var e_1, _a2;
          var recordsCopy = bufferRecords.slice();
          try {
            for (var recordsCopy_1 = __values(recordsCopy), recordsCopy_1_1 = recordsCopy_1.next(); !recordsCopy_1_1.done; recordsCopy_1_1 = recordsCopy_1.next()) {
              var record = recordsCopy_1_1.value;
              var buffer = record.buffer;
              buffer.push(value2);
              maxBufferSize <= buffer.length && emit(record);
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (recordsCopy_1_1 && !recordsCopy_1_1.done && (_a2 = recordsCopy_1.return))
                _a2.call(recordsCopy_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
        }, function() {
          while (bufferRecords === null || bufferRecords === void 0 ? void 0 : bufferRecords.length) {
            subscriber.next(bufferRecords.shift().buffer);
          }
          bufferTimeSubscriber === null || bufferTimeSubscriber === void 0 ? void 0 : bufferTimeSubscriber.unsubscribe();
          subscriber.complete();
          subscriber.unsubscribe();
        }, void 0, function() {
          return bufferRecords = null;
        });
        source.subscribe(bufferTimeSubscriber);
      });
    }
    exports.bufferTime = bufferTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferToggle.js
var require_bufferToggle = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferToggle.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bufferToggle = void 0;
    var Subscription_1 = require_Subscription();
    var lift_1 = require_lift();
    var innerFrom_1 = require_innerFrom();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    var arrRemove_1 = require_arrRemove();
    function bufferToggle(openings, closingSelector) {
      return lift_1.operate(function(source, subscriber) {
        var buffers = [];
        innerFrom_1.innerFrom(openings).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(openValue) {
          var buffer = [];
          buffers.push(buffer);
          var closingSubscription = new Subscription_1.Subscription();
          var emitBuffer = function() {
            arrRemove_1.arrRemove(buffers, buffer);
            subscriber.next(buffer);
            closingSubscription.unsubscribe();
          };
          closingSubscription.add(innerFrom_1.innerFrom(closingSelector(openValue)).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, emitBuffer, noop_1.noop)));
        }, noop_1.noop));
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var e_1, _a;
          try {
            for (var buffers_1 = __values(buffers), buffers_1_1 = buffers_1.next(); !buffers_1_1.done; buffers_1_1 = buffers_1.next()) {
              var buffer = buffers_1_1.value;
              buffer.push(value2);
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (buffers_1_1 && !buffers_1_1.done && (_a = buffers_1.return))
                _a.call(buffers_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
        }, function() {
          while (buffers.length > 0) {
            subscriber.next(buffers.shift());
          }
          subscriber.complete();
        }));
      });
    }
    exports.bufferToggle = bufferToggle;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferWhen.js
var require_bufferWhen = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/bufferWhen.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.bufferWhen = void 0;
    var lift_1 = require_lift();
    var noop_1 = require_noop();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    function bufferWhen(closingSelector) {
      return lift_1.operate(function(source, subscriber) {
        var buffer = null;
        var closingSubscriber = null;
        var openBuffer = function() {
          closingSubscriber === null || closingSubscriber === void 0 ? void 0 : closingSubscriber.unsubscribe();
          var b = buffer;
          buffer = [];
          b && subscriber.next(b);
          innerFrom_1.innerFrom(closingSelector()).subscribe(closingSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, openBuffer, noop_1.noop));
        };
        openBuffer();
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return buffer === null || buffer === void 0 ? void 0 : buffer.push(value2);
        }, function() {
          buffer && subscriber.next(buffer);
          subscriber.complete();
        }, void 0, function() {
          return buffer = closingSubscriber = null;
        }));
      });
    }
    exports.bufferWhen = bufferWhen;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/catchError.js
var require_catchError = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/catchError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.catchError = void 0;
    var innerFrom_1 = require_innerFrom();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var lift_1 = require_lift();
    function catchError(selector) {
      return lift_1.operate(function(source, subscriber) {
        var innerSub = null;
        var syncUnsub = false;
        var handledResult;
        innerSub = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, void 0, function(err) {
          handledResult = innerFrom_1.innerFrom(selector(err, catchError(selector)(source)));
          if (innerSub) {
            innerSub.unsubscribe();
            innerSub = null;
            handledResult.subscribe(subscriber);
          } else {
            syncUnsub = true;
          }
        }));
        if (syncUnsub) {
          innerSub.unsubscribe();
          innerSub = null;
          handledResult.subscribe(subscriber);
        }
      });
    }
    exports.catchError = catchError;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/scanInternals.js
var require_scanInternals = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/scanInternals.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scanInternals = void 0;
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function scanInternals(accumulator, seed, hasSeed, emitOnNext, emitBeforeComplete) {
      return function(source, subscriber) {
        var hasState = hasSeed;
        var state = seed;
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var i = index++;
          state = hasState ? accumulator(state, value2, i) : (hasState = true, value2);
          emitOnNext && subscriber.next(state);
        }, emitBeforeComplete && function() {
          hasState && subscriber.next(state);
          subscriber.complete();
        }));
      };
    }
    exports.scanInternals = scanInternals;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/reduce.js
var require_reduce = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/reduce.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.reduce = void 0;
    var scanInternals_1 = require_scanInternals();
    var lift_1 = require_lift();
    function reduce(accumulator, seed) {
      return lift_1.operate(scanInternals_1.scanInternals(accumulator, seed, arguments.length >= 2, false, true));
    }
    exports.reduce = reduce;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/toArray.js
var require_toArray = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/toArray.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.toArray = void 0;
    var reduce_1 = require_reduce();
    var lift_1 = require_lift();
    var arrReducer = function(arr, value2) {
      return arr.push(value2), arr;
    };
    function toArray() {
      return lift_1.operate(function(source, subscriber) {
        reduce_1.reduce(arrReducer, [])(source).subscribe(subscriber);
      });
    }
    exports.toArray = toArray;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/joinAllInternals.js
var require_joinAllInternals = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/joinAllInternals.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.joinAllInternals = void 0;
    var identity_1 = require_identity();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var pipe_1 = require_pipe();
    var mergeMap_1 = require_mergeMap();
    var toArray_1 = require_toArray();
    function joinAllInternals(joinFn, project) {
      return pipe_1.pipe(toArray_1.toArray(), mergeMap_1.mergeMap(function(sources) {
        return joinFn(sources);
      }), project ? mapOneOrManyArgs_1.mapOneOrManyArgs(project) : identity_1.identity);
    }
    exports.joinAllInternals = joinAllInternals;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatestAll.js
var require_combineLatestAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatestAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.combineLatestAll = void 0;
    var combineLatest_1 = require_combineLatest();
    var joinAllInternals_1 = require_joinAllInternals();
    function combineLatestAll(project) {
      return joinAllInternals_1.joinAllInternals(combineLatest_1.combineLatest, project);
    }
    exports.combineLatestAll = combineLatestAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineAll.js
var require_combineAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.combineAll = void 0;
    var combineLatestAll_1 = require_combineLatestAll();
    exports.combineAll = combineLatestAll_1.combineLatestAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatest.js
var require_combineLatest2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatest.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.combineLatest = void 0;
    var combineLatest_1 = require_combineLatest();
    var lift_1 = require_lift();
    var argsOrArgArray_1 = require_argsOrArgArray();
    var mapOneOrManyArgs_1 = require_mapOneOrManyArgs();
    var pipe_1 = require_pipe();
    var args_1 = require_args();
    function combineLatest() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var resultSelector = args_1.popResultSelector(args);
      return resultSelector ? pipe_1.pipe(combineLatest.apply(void 0, __spreadArray([], __read(args))), mapOneOrManyArgs_1.mapOneOrManyArgs(resultSelector)) : lift_1.operate(function(source, subscriber) {
        combineLatest_1.combineLatestInit(__spreadArray([source], __read(argsOrArgArray_1.argsOrArgArray(args))))(subscriber);
      });
    }
    exports.combineLatest = combineLatest;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatestWith.js
var require_combineLatestWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/combineLatestWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.combineLatestWith = void 0;
    var combineLatest_1 = require_combineLatest2();
    function combineLatestWith() {
      var otherSources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        otherSources[_i] = arguments[_i];
      }
      return combineLatest_1.combineLatest.apply(void 0, __spreadArray([], __read(otherSources)));
    }
    exports.combineLatestWith = combineLatestWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatMap.js
var require_concatMap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concatMap = void 0;
    var mergeMap_1 = require_mergeMap();
    var isFunction_1 = require_isFunction2();
    function concatMap(project, resultSelector) {
      return isFunction_1.isFunction(resultSelector) ? mergeMap_1.mergeMap(project, resultSelector, 1) : mergeMap_1.mergeMap(project, 1);
    }
    exports.concatMap = concatMap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatMapTo.js
var require_concatMapTo = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatMapTo.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concatMapTo = void 0;
    var concatMap_1 = require_concatMap();
    var isFunction_1 = require_isFunction2();
    function concatMapTo(innerObservable, resultSelector) {
      return isFunction_1.isFunction(resultSelector) ? concatMap_1.concatMap(function() {
        return innerObservable;
      }, resultSelector) : concatMap_1.concatMap(function() {
        return innerObservable;
      });
    }
    exports.concatMapTo = concatMapTo;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concat.js
var require_concat2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concat.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concat = void 0;
    var lift_1 = require_lift();
    var concatAll_1 = require_concatAll();
    var args_1 = require_args();
    var from_1 = require_from2();
    function concat() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(args);
      return lift_1.operate(function(source, subscriber) {
        concatAll_1.concatAll()(from_1.from(__spreadArray([source], __read(args)), scheduler)).subscribe(subscriber);
      });
    }
    exports.concat = concat;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatWith.js
var require_concatWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/concatWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.concatWith = void 0;
    var concat_1 = require_concat2();
    function concatWith() {
      var otherSources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        otherSources[_i] = arguments[_i];
      }
      return concat_1.concat.apply(void 0, __spreadArray([], __read(otherSources)));
    }
    exports.concatWith = concatWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromSubscribable.js
var require_fromSubscribable = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/observable/fromSubscribable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fromSubscribable = void 0;
    var Observable_1 = require_Observable();
    function fromSubscribable(subscribable) {
      return new Observable_1.Observable(function(subscriber) {
        return subscribable.subscribe(subscriber);
      });
    }
    exports.fromSubscribable = fromSubscribable;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/connect.js
var require_connect = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/connect.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.connect = void 0;
    var Subject_1 = require_Subject();
    var innerFrom_1 = require_innerFrom();
    var lift_1 = require_lift();
    var fromSubscribable_1 = require_fromSubscribable();
    var DEFAULT_CONFIG = {
      connector: function() {
        return new Subject_1.Subject();
      }
    };
    function connect(selector, config) {
      if (config === void 0) {
        config = DEFAULT_CONFIG;
      }
      var connector = config.connector;
      return lift_1.operate(function(source, subscriber) {
        var subject = connector();
        innerFrom_1.innerFrom(selector(fromSubscribable_1.fromSubscribable(subject))).subscribe(subscriber);
        subscriber.add(source.subscribe(subject));
      });
    }
    exports.connect = connect;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/count.js
var require_count = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/count.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.count = void 0;
    var reduce_1 = require_reduce();
    function count(predicate) {
      return reduce_1.reduce(function(total, value2, i) {
        return !predicate || predicate(value2, i) ? total + 1 : total;
      }, 0);
    }
    exports.count = count;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/debounce.js
var require_debounce = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/debounce.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.debounce = void 0;
    var lift_1 = require_lift();
    var noop_1 = require_noop();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    function debounce(durationSelector) {
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        var lastValue = null;
        var durationSubscriber = null;
        var emit = function() {
          durationSubscriber === null || durationSubscriber === void 0 ? void 0 : durationSubscriber.unsubscribe();
          durationSubscriber = null;
          if (hasValue) {
            hasValue = false;
            var value2 = lastValue;
            lastValue = null;
            subscriber.next(value2);
          }
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          durationSubscriber === null || durationSubscriber === void 0 ? void 0 : durationSubscriber.unsubscribe();
          hasValue = true;
          lastValue = value2;
          durationSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, emit, noop_1.noop);
          innerFrom_1.innerFrom(durationSelector(value2)).subscribe(durationSubscriber);
        }, function() {
          emit();
          subscriber.complete();
        }, void 0, function() {
          lastValue = durationSubscriber = null;
        }));
      });
    }
    exports.debounce = debounce;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/debounceTime.js
var require_debounceTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/debounceTime.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.debounceTime = void 0;
    var async_1 = require_async();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function debounceTime(dueTime, scheduler) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      return lift_1.operate(function(source, subscriber) {
        var activeTask = null;
        var lastValue = null;
        var lastTime = null;
        var emit = function() {
          if (activeTask) {
            activeTask.unsubscribe();
            activeTask = null;
            var value2 = lastValue;
            lastValue = null;
            subscriber.next(value2);
          }
        };
        function emitWhenIdle() {
          var targetTime = lastTime + dueTime;
          var now = scheduler.now();
          if (now < targetTime) {
            activeTask = this.schedule(void 0, targetTime - now);
            subscriber.add(activeTask);
            return;
          }
          emit();
        }
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          lastValue = value2;
          lastTime = scheduler.now();
          if (!activeTask) {
            activeTask = scheduler.schedule(emitWhenIdle, dueTime);
            subscriber.add(activeTask);
          }
        }, function() {
          emit();
          subscriber.complete();
        }, void 0, function() {
          lastValue = activeTask = null;
        }));
      });
    }
    exports.debounceTime = debounceTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/defaultIfEmpty.js
var require_defaultIfEmpty = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/defaultIfEmpty.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.defaultIfEmpty = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function defaultIfEmpty(defaultValue) {
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          hasValue = true;
          subscriber.next(value2);
        }, function() {
          if (!hasValue) {
            subscriber.next(defaultValue);
          }
          subscriber.complete();
        }));
      });
    }
    exports.defaultIfEmpty = defaultIfEmpty;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/take.js
var require_take = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/take.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.take = void 0;
    var empty_1 = require_empty();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function take(count) {
      return count <= 0 ? function() {
        return empty_1.EMPTY;
      } : lift_1.operate(function(source, subscriber) {
        var seen = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          if (++seen <= count) {
            subscriber.next(value2);
            if (count <= seen) {
              subscriber.complete();
            }
          }
        }));
      });
    }
    exports.take = take;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/ignoreElements.js
var require_ignoreElements = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/ignoreElements.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ignoreElements = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    function ignoreElements() {
      return lift_1.operate(function(source, subscriber) {
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, noop_1.noop));
      });
    }
    exports.ignoreElements = ignoreElements;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mapTo.js
var require_mapTo = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mapTo.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mapTo = void 0;
    var map_1 = require_map();
    function mapTo(value2) {
      return map_1.map(function() {
        return value2;
      });
    }
    exports.mapTo = mapTo;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/delayWhen.js
var require_delayWhen = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/delayWhen.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.delayWhen = void 0;
    var concat_1 = require_concat();
    var take_1 = require_take();
    var ignoreElements_1 = require_ignoreElements();
    var mapTo_1 = require_mapTo();
    var mergeMap_1 = require_mergeMap();
    var innerFrom_1 = require_innerFrom();
    function delayWhen(delayDurationSelector, subscriptionDelay) {
      if (subscriptionDelay) {
        return function(source) {
          return concat_1.concat(subscriptionDelay.pipe(take_1.take(1), ignoreElements_1.ignoreElements()), source.pipe(delayWhen(delayDurationSelector)));
        };
      }
      return mergeMap_1.mergeMap(function(value2, index) {
        return innerFrom_1.innerFrom(delayDurationSelector(value2, index)).pipe(take_1.take(1), mapTo_1.mapTo(value2));
      });
    }
    exports.delayWhen = delayWhen;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/delay.js
var require_delay = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/delay.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.delay = void 0;
    var async_1 = require_async();
    var delayWhen_1 = require_delayWhen();
    var timer_1 = require_timer();
    function delay(due, scheduler) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      var duration = timer_1.timer(due, scheduler);
      return delayWhen_1.delayWhen(function() {
        return duration;
      });
    }
    exports.delay = delay;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/dematerialize.js
var require_dematerialize = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/dematerialize.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.dematerialize = void 0;
    var Notification_1 = require_Notification();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function dematerialize() {
      return lift_1.operate(function(source, subscriber) {
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(notification) {
          return Notification_1.observeNotification(notification, subscriber);
        }));
      });
    }
    exports.dematerialize = dematerialize;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinct.js
var require_distinct = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinct.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.distinct = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    var innerFrom_1 = require_innerFrom();
    function distinct(keySelector, flushes) {
      return lift_1.operate(function(source, subscriber) {
        var distinctKeys = /* @__PURE__ */ new Set();
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var key = keySelector ? keySelector(value2) : value2;
          if (!distinctKeys.has(key)) {
            distinctKeys.add(key);
            subscriber.next(value2);
          }
        }));
        flushes && innerFrom_1.innerFrom(flushes).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          return distinctKeys.clear();
        }, noop_1.noop));
      });
    }
    exports.distinct = distinct;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinctUntilChanged.js
var require_distinctUntilChanged = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinctUntilChanged.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.distinctUntilChanged = void 0;
    var identity_1 = require_identity();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function distinctUntilChanged(comparator, keySelector) {
      if (keySelector === void 0) {
        keySelector = identity_1.identity;
      }
      comparator = comparator !== null && comparator !== void 0 ? comparator : defaultCompare;
      return lift_1.operate(function(source, subscriber) {
        var previousKey;
        var first2 = true;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var currentKey = keySelector(value2);
          if (first2 || !comparator(previousKey, currentKey)) {
            first2 = false;
            previousKey = currentKey;
            subscriber.next(value2);
          }
        }));
      });
    }
    exports.distinctUntilChanged = distinctUntilChanged;
    function defaultCompare(a, b) {
      return a === b;
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinctUntilKeyChanged.js
var require_distinctUntilKeyChanged = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/distinctUntilKeyChanged.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.distinctUntilKeyChanged = void 0;
    var distinctUntilChanged_1 = require_distinctUntilChanged();
    function distinctUntilKeyChanged(key, compare) {
      return distinctUntilChanged_1.distinctUntilChanged(function(x, y) {
        return compare ? compare(x[key], y[key]) : x[key] === y[key];
      });
    }
    exports.distinctUntilKeyChanged = distinctUntilKeyChanged;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throwIfEmpty.js
var require_throwIfEmpty = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throwIfEmpty.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.throwIfEmpty = void 0;
    var EmptyError_1 = require_EmptyError();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function throwIfEmpty(errorFactory) {
      if (errorFactory === void 0) {
        errorFactory = defaultErrorFactory;
      }
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          hasValue = true;
          subscriber.next(value2);
        }, function() {
          return hasValue ? subscriber.complete() : subscriber.error(errorFactory());
        }));
      });
    }
    exports.throwIfEmpty = throwIfEmpty;
    function defaultErrorFactory() {
      return new EmptyError_1.EmptyError();
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/elementAt.js
var require_elementAt = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/elementAt.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.elementAt = void 0;
    var ArgumentOutOfRangeError_1 = require_ArgumentOutOfRangeError();
    var filter_1 = require_filter();
    var throwIfEmpty_1 = require_throwIfEmpty();
    var defaultIfEmpty_1 = require_defaultIfEmpty();
    var take_1 = require_take();
    function elementAt(index, defaultValue) {
      if (index < 0) {
        throw new ArgumentOutOfRangeError_1.ArgumentOutOfRangeError();
      }
      var hasDefaultValue = arguments.length >= 2;
      return function(source) {
        return source.pipe(filter_1.filter(function(v, i) {
          return i === index;
        }), take_1.take(1), hasDefaultValue ? defaultIfEmpty_1.defaultIfEmpty(defaultValue) : throwIfEmpty_1.throwIfEmpty(function() {
          return new ArgumentOutOfRangeError_1.ArgumentOutOfRangeError();
        }));
      };
    }
    exports.elementAt = elementAt;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/endWith.js
var require_endWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/endWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.endWith = void 0;
    var concat_1 = require_concat();
    var of_1 = require_of();
    function endWith() {
      var values2 = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        values2[_i] = arguments[_i];
      }
      return function(source) {
        return concat_1.concat(source, of_1.of.apply(void 0, __spreadArray([], __read(values2))));
      };
    }
    exports.endWith = endWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/every.js
var require_every = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/every.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.every = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function every(predicate, thisArg) {
      return lift_1.operate(function(source, subscriber) {
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          if (!predicate.call(thisArg, value2, index++, source)) {
            subscriber.next(false);
            subscriber.complete();
          }
        }, function() {
          subscriber.next(true);
          subscriber.complete();
        }));
      });
    }
    exports.every = every;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaustMap.js
var require_exhaustMap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaustMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.exhaustMap = void 0;
    var map_1 = require_map();
    var innerFrom_1 = require_innerFrom();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function exhaustMap(project, resultSelector) {
      if (resultSelector) {
        return function(source) {
          return source.pipe(exhaustMap(function(a, i) {
            return innerFrom_1.innerFrom(project(a, i)).pipe(map_1.map(function(b, ii) {
              return resultSelector(a, b, i, ii);
            }));
          }));
        };
      }
      return lift_1.operate(function(source, subscriber) {
        var index = 0;
        var innerSub = null;
        var isComplete = false;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(outerValue) {
          if (!innerSub) {
            innerSub = OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, function() {
              innerSub = null;
              isComplete && subscriber.complete();
            });
            innerFrom_1.innerFrom(project(outerValue, index++)).subscribe(innerSub);
          }
        }, function() {
          isComplete = true;
          !innerSub && subscriber.complete();
        }));
      });
    }
    exports.exhaustMap = exhaustMap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaustAll.js
var require_exhaustAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaustAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.exhaustAll = void 0;
    var exhaustMap_1 = require_exhaustMap();
    var identity_1 = require_identity();
    function exhaustAll() {
      return exhaustMap_1.exhaustMap(identity_1.identity);
    }
    exports.exhaustAll = exhaustAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaust.js
var require_exhaust = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/exhaust.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.exhaust = void 0;
    var exhaustAll_1 = require_exhaustAll();
    exports.exhaust = exhaustAll_1.exhaustAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/expand.js
var require_expand = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/expand.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.expand = void 0;
    var lift_1 = require_lift();
    var mergeInternals_1 = require_mergeInternals();
    function expand(project, concurrent, scheduler) {
      if (concurrent === void 0) {
        concurrent = Infinity;
      }
      concurrent = (concurrent || 0) < 1 ? Infinity : concurrent;
      return lift_1.operate(function(source, subscriber) {
        return mergeInternals_1.mergeInternals(source, subscriber, project, concurrent, void 0, true, scheduler);
      });
    }
    exports.expand = expand;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/finalize.js
var require_finalize = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/finalize.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.finalize = void 0;
    var lift_1 = require_lift();
    function finalize(callback) {
      return lift_1.operate(function(source, subscriber) {
        try {
          source.subscribe(subscriber);
        } finally {
          subscriber.add(callback);
        }
      });
    }
    exports.finalize = finalize;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/find.js
var require_find = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/find.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createFind = exports.find = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function find(predicate, thisArg) {
      return lift_1.operate(createFind(predicate, thisArg, "value"));
    }
    exports.find = find;
    function createFind(predicate, thisArg, emit) {
      var findIndex = emit === "index";
      return function(source, subscriber) {
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var i = index++;
          if (predicate.call(thisArg, value2, i, source)) {
            subscriber.next(findIndex ? i : value2);
            subscriber.complete();
          }
        }, function() {
          subscriber.next(findIndex ? -1 : void 0);
          subscriber.complete();
        }));
      };
    }
    exports.createFind = createFind;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/findIndex.js
var require_findIndex = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/findIndex.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.findIndex = void 0;
    var lift_1 = require_lift();
    var find_1 = require_find();
    function findIndex(predicate, thisArg) {
      return lift_1.operate(find_1.createFind(predicate, thisArg, "index"));
    }
    exports.findIndex = findIndex;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/first.js
var require_first = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/first.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.first = void 0;
    var EmptyError_1 = require_EmptyError();
    var filter_1 = require_filter();
    var take_1 = require_take();
    var defaultIfEmpty_1 = require_defaultIfEmpty();
    var throwIfEmpty_1 = require_throwIfEmpty();
    var identity_1 = require_identity();
    function first2(predicate, defaultValue) {
      var hasDefaultValue = arguments.length >= 2;
      return function(source) {
        return source.pipe(predicate ? filter_1.filter(function(v, i) {
          return predicate(v, i, source);
        }) : identity_1.identity, take_1.take(1), hasDefaultValue ? defaultIfEmpty_1.defaultIfEmpty(defaultValue) : throwIfEmpty_1.throwIfEmpty(function() {
          return new EmptyError_1.EmptyError();
        }));
      };
    }
    exports.first = first2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/groupBy.js
var require_groupBy = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/groupBy.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.groupBy = void 0;
    var Observable_1 = require_Observable();
    var innerFrom_1 = require_innerFrom();
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function groupBy(keySelector, elementOrOptions, duration, connector) {
      return lift_1.operate(function(source, subscriber) {
        var element;
        if (!elementOrOptions || typeof elementOrOptions === "function") {
          element = elementOrOptions;
        } else {
          duration = elementOrOptions.duration, element = elementOrOptions.element, connector = elementOrOptions.connector;
        }
        var groups = /* @__PURE__ */ new Map();
        var notify = function(cb) {
          groups.forEach(cb);
          cb(subscriber);
        };
        var handleError = function(err) {
          return notify(function(consumer) {
            return consumer.error(err);
          });
        };
        var activeGroups = 0;
        var teardownAttempted = false;
        var groupBySourceSubscriber = new OperatorSubscriber_1.OperatorSubscriber(subscriber, function(value2) {
          try {
            var key_1 = keySelector(value2);
            var group_1 = groups.get(key_1);
            if (!group_1) {
              groups.set(key_1, group_1 = connector ? connector() : new Subject_1.Subject());
              var grouped = createGroupedObservable(key_1, group_1);
              subscriber.next(grouped);
              if (duration) {
                var durationSubscriber_1 = OperatorSubscriber_1.createOperatorSubscriber(group_1, function() {
                  group_1.complete();
                  durationSubscriber_1 === null || durationSubscriber_1 === void 0 ? void 0 : durationSubscriber_1.unsubscribe();
                }, void 0, void 0, function() {
                  return groups.delete(key_1);
                });
                groupBySourceSubscriber.add(innerFrom_1.innerFrom(duration(grouped)).subscribe(durationSubscriber_1));
              }
            }
            group_1.next(element ? element(value2) : value2);
          } catch (err) {
            handleError(err);
          }
        }, function() {
          return notify(function(consumer) {
            return consumer.complete();
          });
        }, handleError, function() {
          return groups.clear();
        }, function() {
          teardownAttempted = true;
          return activeGroups === 0;
        });
        source.subscribe(groupBySourceSubscriber);
        function createGroupedObservable(key, groupSubject) {
          var result = new Observable_1.Observable(function(groupSubscriber) {
            activeGroups++;
            var innerSub = groupSubject.subscribe(groupSubscriber);
            return function() {
              innerSub.unsubscribe();
              --activeGroups === 0 && teardownAttempted && groupBySourceSubscriber.unsubscribe();
            };
          });
          result.key = key;
          return result;
        }
      });
    }
    exports.groupBy = groupBy;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/isEmpty.js
var require_isEmpty = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/isEmpty.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isEmpty = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function isEmpty2() {
      return lift_1.operate(function(source, subscriber) {
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          subscriber.next(false);
          subscriber.complete();
        }, function() {
          subscriber.next(true);
          subscriber.complete();
        }));
      });
    }
    exports.isEmpty = isEmpty2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeLast.js
var require_takeLast = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeLast.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.takeLast = void 0;
    var empty_1 = require_empty();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function takeLast(count) {
      return count <= 0 ? function() {
        return empty_1.EMPTY;
      } : lift_1.operate(function(source, subscriber) {
        var buffer = [];
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          buffer.push(value2);
          count < buffer.length && buffer.shift();
        }, function() {
          var e_1, _a;
          try {
            for (var buffer_1 = __values(buffer), buffer_1_1 = buffer_1.next(); !buffer_1_1.done; buffer_1_1 = buffer_1.next()) {
              var value2 = buffer_1_1.value;
              subscriber.next(value2);
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (buffer_1_1 && !buffer_1_1.done && (_a = buffer_1.return))
                _a.call(buffer_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
          subscriber.complete();
        }, void 0, function() {
          buffer = null;
        }));
      });
    }
    exports.takeLast = takeLast;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/last.js
var require_last = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/last.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.last = void 0;
    var EmptyError_1 = require_EmptyError();
    var filter_1 = require_filter();
    var takeLast_1 = require_takeLast();
    var throwIfEmpty_1 = require_throwIfEmpty();
    var defaultIfEmpty_1 = require_defaultIfEmpty();
    var identity_1 = require_identity();
    function last2(predicate, defaultValue) {
      var hasDefaultValue = arguments.length >= 2;
      return function(source) {
        return source.pipe(predicate ? filter_1.filter(function(v, i) {
          return predicate(v, i, source);
        }) : identity_1.identity, takeLast_1.takeLast(1), hasDefaultValue ? defaultIfEmpty_1.defaultIfEmpty(defaultValue) : throwIfEmpty_1.throwIfEmpty(function() {
          return new EmptyError_1.EmptyError();
        }));
      };
    }
    exports.last = last2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/materialize.js
var require_materialize = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/materialize.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.materialize = void 0;
    var Notification_1 = require_Notification();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function materialize() {
      return lift_1.operate(function(source, subscriber) {
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          subscriber.next(Notification_1.Notification.createNext(value2));
        }, function() {
          subscriber.next(Notification_1.Notification.createComplete());
          subscriber.complete();
        }, function(err) {
          subscriber.next(Notification_1.Notification.createError(err));
          subscriber.complete();
        }));
      });
    }
    exports.materialize = materialize;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/max.js
var require_max = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/max.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.max = void 0;
    var reduce_1 = require_reduce();
    var isFunction_1 = require_isFunction2();
    function max2(comparer) {
      return reduce_1.reduce(isFunction_1.isFunction(comparer) ? function(x, y) {
        return comparer(x, y) > 0 ? x : y;
      } : function(x, y) {
        return x > y ? x : y;
      });
    }
    exports.max = max2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/flatMap.js
var require_flatMap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/flatMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.flatMap = void 0;
    var mergeMap_1 = require_mergeMap();
    exports.flatMap = mergeMap_1.mergeMap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeMapTo.js
var require_mergeMapTo = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeMapTo.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeMapTo = void 0;
    var mergeMap_1 = require_mergeMap();
    var isFunction_1 = require_isFunction2();
    function mergeMapTo(innerObservable, resultSelector, concurrent) {
      if (concurrent === void 0) {
        concurrent = Infinity;
      }
      if (isFunction_1.isFunction(resultSelector)) {
        return mergeMap_1.mergeMap(function() {
          return innerObservable;
        }, resultSelector, concurrent);
      }
      if (typeof resultSelector === "number") {
        concurrent = resultSelector;
      }
      return mergeMap_1.mergeMap(function() {
        return innerObservable;
      }, concurrent);
    }
    exports.mergeMapTo = mergeMapTo;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeScan.js
var require_mergeScan = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeScan.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeScan = void 0;
    var lift_1 = require_lift();
    var mergeInternals_1 = require_mergeInternals();
    function mergeScan(accumulator, seed, concurrent) {
      if (concurrent === void 0) {
        concurrent = Infinity;
      }
      return lift_1.operate(function(source, subscriber) {
        var state = seed;
        return mergeInternals_1.mergeInternals(source, subscriber, function(value2, index) {
          return accumulator(state, value2, index);
        }, concurrent, function(value2) {
          state = value2;
        }, false, void 0, function() {
          return state = null;
        });
      });
    }
    exports.mergeScan = mergeScan;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/merge.js
var require_merge2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/merge.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.merge = void 0;
    var lift_1 = require_lift();
    var argsOrArgArray_1 = require_argsOrArgArray();
    var mergeAll_1 = require_mergeAll();
    var args_1 = require_args();
    var from_1 = require_from2();
    function merge4() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(args);
      var concurrent = args_1.popNumber(args, Infinity);
      args = argsOrArgArray_1.argsOrArgArray(args);
      return lift_1.operate(function(source, subscriber) {
        mergeAll_1.mergeAll(concurrent)(from_1.from(__spreadArray([source], __read(args)), scheduler)).subscribe(subscriber);
      });
    }
    exports.merge = merge4;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeWith.js
var require_mergeWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/mergeWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeWith = void 0;
    var merge_1 = require_merge2();
    function mergeWith() {
      var otherSources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        otherSources[_i] = arguments[_i];
      }
      return merge_1.merge.apply(void 0, __spreadArray([], __read(otherSources)));
    }
    exports.mergeWith = mergeWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/min.js
var require_min = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/min.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.min = void 0;
    var reduce_1 = require_reduce();
    var isFunction_1 = require_isFunction2();
    function min2(comparer) {
      return reduce_1.reduce(isFunction_1.isFunction(comparer) ? function(x, y) {
        return comparer(x, y) < 0 ? x : y;
      } : function(x, y) {
        return x < y ? x : y;
      });
    }
    exports.min = min2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/multicast.js
var require_multicast = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/multicast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.multicast = void 0;
    var ConnectableObservable_1 = require_ConnectableObservable();
    var isFunction_1 = require_isFunction2();
    var connect_1 = require_connect();
    function multicast(subjectOrSubjectFactory, selector) {
      var subjectFactory = isFunction_1.isFunction(subjectOrSubjectFactory) ? subjectOrSubjectFactory : function() {
        return subjectOrSubjectFactory;
      };
      if (isFunction_1.isFunction(selector)) {
        return connect_1.connect(selector, {
          connector: subjectFactory
        });
      }
      return function(source) {
        return new ConnectableObservable_1.ConnectableObservable(source, subjectFactory);
      };
    }
    exports.multicast = multicast;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/onErrorResumeNextWith.js
var require_onErrorResumeNextWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/onErrorResumeNextWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.onErrorResumeNext = exports.onErrorResumeNextWith = void 0;
    var argsOrArgArray_1 = require_argsOrArgArray();
    var onErrorResumeNext_1 = require_onErrorResumeNext();
    function onErrorResumeNextWith() {
      var sources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        sources[_i] = arguments[_i];
      }
      var nextSources = argsOrArgArray_1.argsOrArgArray(sources);
      return function(source) {
        return onErrorResumeNext_1.onErrorResumeNext.apply(void 0, __spreadArray([source], __read(nextSources)));
      };
    }
    exports.onErrorResumeNextWith = onErrorResumeNextWith;
    exports.onErrorResumeNext = onErrorResumeNextWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/pairwise.js
var require_pairwise = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/pairwise.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.pairwise = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function pairwise() {
      return lift_1.operate(function(source, subscriber) {
        var prev;
        var hasPrev = false;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var p = prev;
          prev = value2;
          hasPrev && subscriber.next([p, value2]);
          hasPrev = true;
        }));
      });
    }
    exports.pairwise = pairwise;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/pluck.js
var require_pluck = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/pluck.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.pluck = void 0;
    var map_1 = require_map();
    function pluck() {
      var properties = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        properties[_i] = arguments[_i];
      }
      var length = properties.length;
      if (length === 0) {
        throw new Error("list of properties cannot be empty.");
      }
      return map_1.map(function(x) {
        var currentProp = x;
        for (var i = 0; i < length; i++) {
          var p = currentProp === null || currentProp === void 0 ? void 0 : currentProp[properties[i]];
          if (typeof p !== "undefined") {
            currentProp = p;
          } else {
            return void 0;
          }
        }
        return currentProp;
      });
    }
    exports.pluck = pluck;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publish.js
var require_publish = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publish.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.publish = void 0;
    var Subject_1 = require_Subject();
    var multicast_1 = require_multicast();
    var connect_1 = require_connect();
    function publish(selector) {
      return selector ? function(source) {
        return connect_1.connect(selector)(source);
      } : function(source) {
        return multicast_1.multicast(new Subject_1.Subject())(source);
      };
    }
    exports.publish = publish;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishBehavior.js
var require_publishBehavior = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishBehavior.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.publishBehavior = void 0;
    var BehaviorSubject_1 = require_BehaviorSubject();
    var ConnectableObservable_1 = require_ConnectableObservable();
    function publishBehavior(initialValue) {
      return function(source) {
        var subject = new BehaviorSubject_1.BehaviorSubject(initialValue);
        return new ConnectableObservable_1.ConnectableObservable(source, function() {
          return subject;
        });
      };
    }
    exports.publishBehavior = publishBehavior;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishLast.js
var require_publishLast = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishLast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.publishLast = void 0;
    var AsyncSubject_1 = require_AsyncSubject();
    var ConnectableObservable_1 = require_ConnectableObservable();
    function publishLast() {
      return function(source) {
        var subject = new AsyncSubject_1.AsyncSubject();
        return new ConnectableObservable_1.ConnectableObservable(source, function() {
          return subject;
        });
      };
    }
    exports.publishLast = publishLast;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishReplay.js
var require_publishReplay = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/publishReplay.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.publishReplay = void 0;
    var ReplaySubject_1 = require_ReplaySubject();
    var multicast_1 = require_multicast();
    var isFunction_1 = require_isFunction2();
    function publishReplay(bufferSize, windowTime, selectorOrScheduler, timestampProvider) {
      if (selectorOrScheduler && !isFunction_1.isFunction(selectorOrScheduler)) {
        timestampProvider = selectorOrScheduler;
      }
      var selector = isFunction_1.isFunction(selectorOrScheduler) ? selectorOrScheduler : void 0;
      return function(source) {
        return multicast_1.multicast(new ReplaySubject_1.ReplaySubject(bufferSize, windowTime, timestampProvider), selector)(source);
      };
    }
    exports.publishReplay = publishReplay;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/raceWith.js
var require_raceWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/raceWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.raceWith = void 0;
    var race_1 = require_race();
    var lift_1 = require_lift();
    var identity_1 = require_identity();
    function raceWith() {
      var otherSources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        otherSources[_i] = arguments[_i];
      }
      return !otherSources.length ? identity_1.identity : lift_1.operate(function(source, subscriber) {
        race_1.raceInit(__spreadArray([source], __read(otherSources)))(subscriber);
      });
    }
    exports.raceWith = raceWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/repeat.js
var require_repeat = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/repeat.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.repeat = void 0;
    var empty_1 = require_empty();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    var timer_1 = require_timer();
    function repeat(countOrConfig) {
      var _a;
      var count = Infinity;
      var delay;
      if (countOrConfig != null) {
        if (typeof countOrConfig === "object") {
          _a = countOrConfig.count, count = _a === void 0 ? Infinity : _a, delay = countOrConfig.delay;
        } else {
          count = countOrConfig;
        }
      }
      return count <= 0 ? function() {
        return empty_1.EMPTY;
      } : lift_1.operate(function(source, subscriber) {
        var soFar = 0;
        var sourceSub;
        var resubscribe = function() {
          sourceSub === null || sourceSub === void 0 ? void 0 : sourceSub.unsubscribe();
          sourceSub = null;
          if (delay != null) {
            var notifier = typeof delay === "number" ? timer_1.timer(delay) : innerFrom_1.innerFrom(delay(soFar));
            var notifierSubscriber_1 = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
              notifierSubscriber_1.unsubscribe();
              subscribeToSource();
            });
            notifier.subscribe(notifierSubscriber_1);
          } else {
            subscribeToSource();
          }
        };
        var subscribeToSource = function() {
          var syncUnsub = false;
          sourceSub = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, function() {
            if (++soFar < count) {
              if (sourceSub) {
                resubscribe();
              } else {
                syncUnsub = true;
              }
            } else {
              subscriber.complete();
            }
          }));
          if (syncUnsub) {
            resubscribe();
          }
        };
        subscribeToSource();
      });
    }
    exports.repeat = repeat;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/repeatWhen.js
var require_repeatWhen = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/repeatWhen.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.repeatWhen = void 0;
    var innerFrom_1 = require_innerFrom();
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function repeatWhen(notifier) {
      return lift_1.operate(function(source, subscriber) {
        var innerSub;
        var syncResub = false;
        var completions$;
        var isNotifierComplete = false;
        var isMainComplete = false;
        var checkComplete = function() {
          return isMainComplete && isNotifierComplete && (subscriber.complete(), true);
        };
        var getCompletionSubject = function() {
          if (!completions$) {
            completions$ = new Subject_1.Subject();
            innerFrom_1.innerFrom(notifier(completions$)).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
              if (innerSub) {
                subscribeForRepeatWhen();
              } else {
                syncResub = true;
              }
            }, function() {
              isNotifierComplete = true;
              checkComplete();
            }));
          }
          return completions$;
        };
        var subscribeForRepeatWhen = function() {
          isMainComplete = false;
          innerSub = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, function() {
            isMainComplete = true;
            !checkComplete() && getCompletionSubject().next();
          }));
          if (syncResub) {
            innerSub.unsubscribe();
            innerSub = null;
            syncResub = false;
            subscribeForRepeatWhen();
          }
        };
        subscribeForRepeatWhen();
      });
    }
    exports.repeatWhen = repeatWhen;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/retry.js
var require_retry = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/retry.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.retry = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var identity_1 = require_identity();
    var timer_1 = require_timer();
    var innerFrom_1 = require_innerFrom();
    function retry(configOrCount) {
      if (configOrCount === void 0) {
        configOrCount = Infinity;
      }
      var config;
      if (configOrCount && typeof configOrCount === "object") {
        config = configOrCount;
      } else {
        config = {
          count: configOrCount
        };
      }
      var _a = config.count, count = _a === void 0 ? Infinity : _a, delay = config.delay, _b = config.resetOnSuccess, resetOnSuccess = _b === void 0 ? false : _b;
      return count <= 0 ? identity_1.identity : lift_1.operate(function(source, subscriber) {
        var soFar = 0;
        var innerSub;
        var subscribeForRetry = function() {
          var syncUnsub = false;
          innerSub = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
            if (resetOnSuccess) {
              soFar = 0;
            }
            subscriber.next(value2);
          }, void 0, function(err) {
            if (soFar++ < count) {
              var resub_1 = function() {
                if (innerSub) {
                  innerSub.unsubscribe();
                  innerSub = null;
                  subscribeForRetry();
                } else {
                  syncUnsub = true;
                }
              };
              if (delay != null) {
                var notifier = typeof delay === "number" ? timer_1.timer(delay) : innerFrom_1.innerFrom(delay(err, soFar));
                var notifierSubscriber_1 = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
                  notifierSubscriber_1.unsubscribe();
                  resub_1();
                }, function() {
                  subscriber.complete();
                });
                notifier.subscribe(notifierSubscriber_1);
              } else {
                resub_1();
              }
            } else {
              subscriber.error(err);
            }
          }));
          if (syncUnsub) {
            innerSub.unsubscribe();
            innerSub = null;
            subscribeForRetry();
          }
        };
        subscribeForRetry();
      });
    }
    exports.retry = retry;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/retryWhen.js
var require_retryWhen = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/retryWhen.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.retryWhen = void 0;
    var innerFrom_1 = require_innerFrom();
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function retryWhen(notifier) {
      return lift_1.operate(function(source, subscriber) {
        var innerSub;
        var syncResub = false;
        var errors$;
        var subscribeForRetryWhen = function() {
          innerSub = source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, void 0, void 0, function(err) {
            if (!errors$) {
              errors$ = new Subject_1.Subject();
              innerFrom_1.innerFrom(notifier(errors$)).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
                return innerSub ? subscribeForRetryWhen() : syncResub = true;
              }));
            }
            if (errors$) {
              errors$.next(err);
            }
          }));
          if (syncResub) {
            innerSub.unsubscribe();
            innerSub = null;
            syncResub = false;
            subscribeForRetryWhen();
          }
        };
        subscribeForRetryWhen();
      });
    }
    exports.retryWhen = retryWhen;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sample.js
var require_sample = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sample.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.sample = void 0;
    var innerFrom_1 = require_innerFrom();
    var lift_1 = require_lift();
    var noop_1 = require_noop();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function sample2(notifier) {
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        var lastValue = null;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          hasValue = true;
          lastValue = value2;
        }));
        innerFrom_1.innerFrom(notifier).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          if (hasValue) {
            hasValue = false;
            var value2 = lastValue;
            lastValue = null;
            subscriber.next(value2);
          }
        }, noop_1.noop));
      });
    }
    exports.sample = sample2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sampleTime.js
var require_sampleTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sampleTime.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.sampleTime = void 0;
    var async_1 = require_async();
    var sample_1 = require_sample();
    var interval_1 = require_interval();
    function sampleTime(period, scheduler) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      return sample_1.sample(interval_1.interval(period, scheduler));
    }
    exports.sampleTime = sampleTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/scan.js
var require_scan = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/scan.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.scan = void 0;
    var lift_1 = require_lift();
    var scanInternals_1 = require_scanInternals();
    function scan(accumulator, seed) {
      return lift_1.operate(scanInternals_1.scanInternals(accumulator, seed, arguments.length >= 2, true));
    }
    exports.scan = scan;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sequenceEqual.js
var require_sequenceEqual = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/sequenceEqual.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.sequenceEqual = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    function sequenceEqual(compareTo, comparator) {
      if (comparator === void 0) {
        comparator = function(a, b) {
          return a === b;
        };
      }
      return lift_1.operate(function(source, subscriber) {
        var aState = createState();
        var bState = createState();
        var emit = function(isEqual) {
          subscriber.next(isEqual);
          subscriber.complete();
        };
        var createSubscriber = function(selfState, otherState) {
          var sequenceEqualSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(a) {
            var buffer = otherState.buffer, complete = otherState.complete;
            if (buffer.length === 0) {
              complete ? emit(false) : selfState.buffer.push(a);
            } else {
              !comparator(a, buffer.shift()) && emit(false);
            }
          }, function() {
            selfState.complete = true;
            var complete = otherState.complete, buffer = otherState.buffer;
            complete && emit(buffer.length === 0);
            sequenceEqualSubscriber === null || sequenceEqualSubscriber === void 0 ? void 0 : sequenceEqualSubscriber.unsubscribe();
          });
          return sequenceEqualSubscriber;
        };
        source.subscribe(createSubscriber(aState, bState));
        innerFrom_1.innerFrom(compareTo).subscribe(createSubscriber(bState, aState));
      });
    }
    exports.sequenceEqual = sequenceEqual;
    function createState() {
      return {
        buffer: [],
        complete: false
      };
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/share.js
var require_share = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/share.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.share = void 0;
    var innerFrom_1 = require_innerFrom();
    var Subject_1 = require_Subject();
    var Subscriber_1 = require_Subscriber();
    var lift_1 = require_lift();
    function share(options) {
      if (options === void 0) {
        options = {};
      }
      var _a = options.connector, connector = _a === void 0 ? function() {
        return new Subject_1.Subject();
      } : _a, _b = options.resetOnError, resetOnError = _b === void 0 ? true : _b, _c = options.resetOnComplete, resetOnComplete = _c === void 0 ? true : _c, _d = options.resetOnRefCountZero, resetOnRefCountZero = _d === void 0 ? true : _d;
      return function(wrapperSource) {
        var connection;
        var resetConnection;
        var subject;
        var refCount = 0;
        var hasCompleted = false;
        var hasErrored = false;
        var cancelReset = function() {
          resetConnection === null || resetConnection === void 0 ? void 0 : resetConnection.unsubscribe();
          resetConnection = void 0;
        };
        var reset = function() {
          cancelReset();
          connection = subject = void 0;
          hasCompleted = hasErrored = false;
        };
        var resetAndUnsubscribe = function() {
          var conn = connection;
          reset();
          conn === null || conn === void 0 ? void 0 : conn.unsubscribe();
        };
        return lift_1.operate(function(source, subscriber) {
          refCount++;
          if (!hasErrored && !hasCompleted) {
            cancelReset();
          }
          var dest = subject = subject !== null && subject !== void 0 ? subject : connector();
          subscriber.add(function() {
            refCount--;
            if (refCount === 0 && !hasErrored && !hasCompleted) {
              resetConnection = handleReset(resetAndUnsubscribe, resetOnRefCountZero);
            }
          });
          dest.subscribe(subscriber);
          if (!connection && refCount > 0) {
            connection = new Subscriber_1.SafeSubscriber({
              next: function(value2) {
                return dest.next(value2);
              },
              error: function(err) {
                hasErrored = true;
                cancelReset();
                resetConnection = handleReset(reset, resetOnError, err);
                dest.error(err);
              },
              complete: function() {
                hasCompleted = true;
                cancelReset();
                resetConnection = handleReset(reset, resetOnComplete);
                dest.complete();
              }
            });
            innerFrom_1.innerFrom(source).subscribe(connection);
          }
        })(wrapperSource);
      };
    }
    exports.share = share;
    function handleReset(reset, on) {
      var args = [];
      for (var _i = 2; _i < arguments.length; _i++) {
        args[_i - 2] = arguments[_i];
      }
      if (on === true) {
        reset();
        return;
      }
      if (on === false) {
        return;
      }
      var onSubscriber = new Subscriber_1.SafeSubscriber({
        next: function() {
          onSubscriber.unsubscribe();
          reset();
        }
      });
      return innerFrom_1.innerFrom(on.apply(void 0, __spreadArray([], __read(args)))).subscribe(onSubscriber);
    }
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/shareReplay.js
var require_shareReplay = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/shareReplay.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.shareReplay = void 0;
    var ReplaySubject_1 = require_ReplaySubject();
    var share_1 = require_share();
    function shareReplay(configOrBufferSize, windowTime, scheduler) {
      var _a, _b, _c;
      var bufferSize;
      var refCount = false;
      if (configOrBufferSize && typeof configOrBufferSize === "object") {
        _a = configOrBufferSize.bufferSize, bufferSize = _a === void 0 ? Infinity : _a, _b = configOrBufferSize.windowTime, windowTime = _b === void 0 ? Infinity : _b, _c = configOrBufferSize.refCount, refCount = _c === void 0 ? false : _c, scheduler = configOrBufferSize.scheduler;
      } else {
        bufferSize = configOrBufferSize !== null && configOrBufferSize !== void 0 ? configOrBufferSize : Infinity;
      }
      return share_1.share({
        connector: function() {
          return new ReplaySubject_1.ReplaySubject(bufferSize, windowTime, scheduler);
        },
        resetOnError: true,
        resetOnComplete: false,
        resetOnRefCountZero: refCount
      });
    }
    exports.shareReplay = shareReplay;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/single.js
var require_single = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/single.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.single = void 0;
    var EmptyError_1 = require_EmptyError();
    var SequenceError_1 = require_SequenceError();
    var NotFoundError_1 = require_NotFoundError();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function single(predicate) {
      return lift_1.operate(function(source, subscriber) {
        var hasValue = false;
        var singleValue;
        var seenValue = false;
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          seenValue = true;
          if (!predicate || predicate(value2, index++, source)) {
            hasValue && subscriber.error(new SequenceError_1.SequenceError("Too many matching values"));
            hasValue = true;
            singleValue = value2;
          }
        }, function() {
          if (hasValue) {
            subscriber.next(singleValue);
            subscriber.complete();
          } else {
            subscriber.error(seenValue ? new NotFoundError_1.NotFoundError("No matching values") : new EmptyError_1.EmptyError());
          }
        }));
      });
    }
    exports.single = single;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skip.js
var require_skip = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skip.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.skip = void 0;
    var filter_1 = require_filter();
    function skip(count) {
      return filter_1.filter(function(_, index) {
        return count <= index;
      });
    }
    exports.skip = skip;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipLast.js
var require_skipLast = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipLast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.skipLast = void 0;
    var identity_1 = require_identity();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function skipLast(skipCount) {
      return skipCount <= 0 ? identity_1.identity : lift_1.operate(function(source, subscriber) {
        var ring = new Array(skipCount);
        var seen = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var valueIndex = seen++;
          if (valueIndex < skipCount) {
            ring[valueIndex] = value2;
          } else {
            var index = valueIndex % skipCount;
            var oldValue = ring[index];
            ring[index] = value2;
            subscriber.next(oldValue);
          }
        }));
        return function() {
          ring = null;
        };
      });
    }
    exports.skipLast = skipLast;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipUntil.js
var require_skipUntil = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipUntil.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.skipUntil = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    var noop_1 = require_noop();
    function skipUntil(notifier) {
      return lift_1.operate(function(source, subscriber) {
        var taking = false;
        var skipSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          skipSubscriber === null || skipSubscriber === void 0 ? void 0 : skipSubscriber.unsubscribe();
          taking = true;
        }, noop_1.noop);
        innerFrom_1.innerFrom(notifier).subscribe(skipSubscriber);
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return taking && subscriber.next(value2);
        }));
      });
    }
    exports.skipUntil = skipUntil;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipWhile.js
var require_skipWhile = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/skipWhile.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.skipWhile = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function skipWhile(predicate) {
      return lift_1.operate(function(source, subscriber) {
        var taking = false;
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return (taking || (taking = !predicate(value2, index++))) && subscriber.next(value2);
        }));
      });
    }
    exports.skipWhile = skipWhile;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/startWith.js
var require_startWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/startWith.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.startWith = void 0;
    var concat_1 = require_concat();
    var args_1 = require_args();
    var lift_1 = require_lift();
    function startWith() {
      var values2 = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        values2[_i] = arguments[_i];
      }
      var scheduler = args_1.popScheduler(values2);
      return lift_1.operate(function(source, subscriber) {
        (scheduler ? concat_1.concat(values2, source, scheduler) : concat_1.concat(values2, source)).subscribe(subscriber);
      });
    }
    exports.startWith = startWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchMap.js
var require_switchMap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.switchMap = void 0;
    var innerFrom_1 = require_innerFrom();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function switchMap(project, resultSelector) {
      return lift_1.operate(function(source, subscriber) {
        var innerSubscriber = null;
        var index = 0;
        var isComplete = false;
        var checkComplete = function() {
          return isComplete && !innerSubscriber && subscriber.complete();
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          innerSubscriber === null || innerSubscriber === void 0 ? void 0 : innerSubscriber.unsubscribe();
          var innerIndex = 0;
          var outerIndex = index++;
          innerFrom_1.innerFrom(project(value2, outerIndex)).subscribe(innerSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(innerValue) {
            return subscriber.next(resultSelector ? resultSelector(value2, innerValue, outerIndex, innerIndex++) : innerValue);
          }, function() {
            innerSubscriber = null;
            checkComplete();
          }));
        }, function() {
          isComplete = true;
          checkComplete();
        }));
      });
    }
    exports.switchMap = switchMap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchAll.js
var require_switchAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.switchAll = void 0;
    var switchMap_1 = require_switchMap();
    var identity_1 = require_identity();
    function switchAll() {
      return switchMap_1.switchMap(identity_1.identity);
    }
    exports.switchAll = switchAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchMapTo.js
var require_switchMapTo = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchMapTo.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.switchMapTo = void 0;
    var switchMap_1 = require_switchMap();
    var isFunction_1 = require_isFunction2();
    function switchMapTo(innerObservable, resultSelector) {
      return isFunction_1.isFunction(resultSelector) ? switchMap_1.switchMap(function() {
        return innerObservable;
      }, resultSelector) : switchMap_1.switchMap(function() {
        return innerObservable;
      });
    }
    exports.switchMapTo = switchMapTo;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchScan.js
var require_switchScan = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/switchScan.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.switchScan = void 0;
    var switchMap_1 = require_switchMap();
    var lift_1 = require_lift();
    function switchScan(accumulator, seed) {
      return lift_1.operate(function(source, subscriber) {
        var state = seed;
        switchMap_1.switchMap(function(value2, index) {
          return accumulator(state, value2, index);
        }, function(_, innerValue) {
          return state = innerValue, innerValue;
        })(source).subscribe(subscriber);
        return function() {
          state = null;
        };
      });
    }
    exports.switchScan = switchScan;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeUntil.js
var require_takeUntil = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeUntil.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.takeUntil = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    var noop_1 = require_noop();
    function takeUntil(notifier) {
      return lift_1.operate(function(source, subscriber) {
        innerFrom_1.innerFrom(notifier).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          return subscriber.complete();
        }, noop_1.noop));
        !subscriber.closed && source.subscribe(subscriber);
      });
    }
    exports.takeUntil = takeUntil;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeWhile.js
var require_takeWhile = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/takeWhile.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.takeWhile = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function takeWhile(predicate, inclusive) {
      if (inclusive === void 0) {
        inclusive = false;
      }
      return lift_1.operate(function(source, subscriber) {
        var index = 0;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var result = predicate(value2, index++);
          (result || inclusive) && subscriber.next(value2);
          !result && subscriber.complete();
        }));
      });
    }
    exports.takeWhile = takeWhile;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/tap.js
var require_tap = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/tap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.tap = void 0;
    var isFunction_1 = require_isFunction2();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var identity_1 = require_identity();
    function tap(observerOrNext, error, complete) {
      var tapObserver = isFunction_1.isFunction(observerOrNext) || error || complete ? { next: observerOrNext, error, complete } : observerOrNext;
      return tapObserver ? lift_1.operate(function(source, subscriber) {
        var _a;
        (_a = tapObserver.subscribe) === null || _a === void 0 ? void 0 : _a.call(tapObserver);
        var isUnsub = true;
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var _a2;
          (_a2 = tapObserver.next) === null || _a2 === void 0 ? void 0 : _a2.call(tapObserver, value2);
          subscriber.next(value2);
        }, function() {
          var _a2;
          isUnsub = false;
          (_a2 = tapObserver.complete) === null || _a2 === void 0 ? void 0 : _a2.call(tapObserver);
          subscriber.complete();
        }, function(err) {
          var _a2;
          isUnsub = false;
          (_a2 = tapObserver.error) === null || _a2 === void 0 ? void 0 : _a2.call(tapObserver, err);
          subscriber.error(err);
        }, function() {
          var _a2, _b;
          if (isUnsub) {
            (_a2 = tapObserver.unsubscribe) === null || _a2 === void 0 ? void 0 : _a2.call(tapObserver);
          }
          (_b = tapObserver.finalize) === null || _b === void 0 ? void 0 : _b.call(tapObserver);
        }));
      }) : identity_1.identity;
    }
    exports.tap = tap;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throttle.js
var require_throttle = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throttle.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.throttle = exports.defaultThrottleConfig = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    exports.defaultThrottleConfig = {
      leading: true,
      trailing: false
    };
    function throttle(durationSelector, config) {
      if (config === void 0) {
        config = exports.defaultThrottleConfig;
      }
      return lift_1.operate(function(source, subscriber) {
        var leading = config.leading, trailing = config.trailing;
        var hasValue = false;
        var sendValue = null;
        var throttled = null;
        var isComplete = false;
        var endThrottling = function() {
          throttled === null || throttled === void 0 ? void 0 : throttled.unsubscribe();
          throttled = null;
          if (trailing) {
            send();
            isComplete && subscriber.complete();
          }
        };
        var cleanupThrottling = function() {
          throttled = null;
          isComplete && subscriber.complete();
        };
        var startThrottle = function(value2) {
          return throttled = innerFrom_1.innerFrom(durationSelector(value2)).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, endThrottling, cleanupThrottling));
        };
        var send = function() {
          if (hasValue) {
            hasValue = false;
            var value2 = sendValue;
            sendValue = null;
            subscriber.next(value2);
            !isComplete && startThrottle(value2);
          }
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          hasValue = true;
          sendValue = value2;
          !(throttled && !throttled.closed) && (leading ? send() : startThrottle(value2));
        }, function() {
          isComplete = true;
          !(trailing && hasValue && throttled && !throttled.closed) && subscriber.complete();
        }));
      });
    }
    exports.throttle = throttle;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throttleTime.js
var require_throttleTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/throttleTime.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.throttleTime = void 0;
    var async_1 = require_async();
    var throttle_1 = require_throttle();
    var timer_1 = require_timer();
    function throttleTime(duration, scheduler, config) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      if (config === void 0) {
        config = throttle_1.defaultThrottleConfig;
      }
      var duration$ = timer_1.timer(duration, scheduler);
      return throttle_1.throttle(function() {
        return duration$;
      }, config);
    }
    exports.throttleTime = throttleTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeInterval.js
var require_timeInterval = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeInterval.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.TimeInterval = exports.timeInterval = void 0;
    var async_1 = require_async();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function timeInterval(scheduler) {
      if (scheduler === void 0) {
        scheduler = async_1.asyncScheduler;
      }
      return lift_1.operate(function(source, subscriber) {
        var last2 = scheduler.now();
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var now = scheduler.now();
          var interval = now - last2;
          last2 = now;
          subscriber.next(new TimeInterval(value2, interval));
        }));
      });
    }
    exports.timeInterval = timeInterval;
    var TimeInterval = function() {
      function TimeInterval2(value2, interval) {
        this.value = value2;
        this.interval = interval;
      }
      return TimeInterval2;
    }();
    exports.TimeInterval = TimeInterval;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeoutWith.js
var require_timeoutWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timeoutWith.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.timeoutWith = void 0;
    var async_1 = require_async();
    var isDate_1 = require_isDate();
    var timeout_1 = require_timeout();
    function timeoutWith(due, withObservable, scheduler) {
      var first2;
      var each;
      var _with;
      scheduler = scheduler !== null && scheduler !== void 0 ? scheduler : async_1.async;
      if (isDate_1.isValidDate(due)) {
        first2 = due;
      } else if (typeof due === "number") {
        each = due;
      }
      if (withObservable) {
        _with = function() {
          return withObservable;
        };
      } else {
        throw new TypeError("No observable provided to switch to");
      }
      if (first2 == null && each == null) {
        throw new TypeError("No timeout provided.");
      }
      return timeout_1.timeout({
        first: first2,
        each,
        scheduler,
        with: _with
      });
    }
    exports.timeoutWith = timeoutWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timestamp.js
var require_timestamp = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/timestamp.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.timestamp = void 0;
    var dateTimestampProvider_1 = require_dateTimestampProvider();
    var map_1 = require_map();
    function timestamp(timestampProvider) {
      if (timestampProvider === void 0) {
        timestampProvider = dateTimestampProvider_1.dateTimestampProvider;
      }
      return map_1.map(function(value2) {
        return { value: value2, timestamp: timestampProvider.now() };
      });
    }
    exports.timestamp = timestamp;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/window.js
var require_window = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/window.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.window = void 0;
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    var innerFrom_1 = require_innerFrom();
    function window2(windowBoundaries) {
      return lift_1.operate(function(source, subscriber) {
        var windowSubject = new Subject_1.Subject();
        subscriber.next(windowSubject.asObservable());
        var errorHandler = function(err) {
          windowSubject.error(err);
          subscriber.error(err);
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return windowSubject === null || windowSubject === void 0 ? void 0 : windowSubject.next(value2);
        }, function() {
          windowSubject.complete();
          subscriber.complete();
        }, errorHandler));
        innerFrom_1.innerFrom(windowBoundaries).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function() {
          windowSubject.complete();
          subscriber.next(windowSubject = new Subject_1.Subject());
        }, noop_1.noop, errorHandler));
        return function() {
          windowSubject === null || windowSubject === void 0 ? void 0 : windowSubject.unsubscribe();
          windowSubject = null;
        };
      });
    }
    exports.window = window2;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowCount.js
var require_windowCount = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowCount.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.windowCount = void 0;
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    function windowCount(windowSize, startWindowEvery) {
      if (startWindowEvery === void 0) {
        startWindowEvery = 0;
      }
      var startEvery = startWindowEvery > 0 ? startWindowEvery : windowSize;
      return lift_1.operate(function(source, subscriber) {
        var windows = [new Subject_1.Subject()];
        var starts = [];
        var count = 0;
        subscriber.next(windows[0].asObservable());
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var e_1, _a;
          try {
            for (var windows_1 = __values(windows), windows_1_1 = windows_1.next(); !windows_1_1.done; windows_1_1 = windows_1.next()) {
              var window_1 = windows_1_1.value;
              window_1.next(value2);
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (windows_1_1 && !windows_1_1.done && (_a = windows_1.return))
                _a.call(windows_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
          var c = count - windowSize + 1;
          if (c >= 0 && c % startEvery === 0) {
            windows.shift().complete();
          }
          if (++count % startEvery === 0) {
            var window_2 = new Subject_1.Subject();
            windows.push(window_2);
            subscriber.next(window_2.asObservable());
          }
        }, function() {
          while (windows.length > 0) {
            windows.shift().complete();
          }
          subscriber.complete();
        }, function(err) {
          while (windows.length > 0) {
            windows.shift().error(err);
          }
          subscriber.error(err);
        }, function() {
          starts = null;
          windows = null;
        }));
      });
    }
    exports.windowCount = windowCount;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowTime.js
var require_windowTime = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowTime.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.windowTime = void 0;
    var Subject_1 = require_Subject();
    var async_1 = require_async();
    var Subscription_1 = require_Subscription();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var arrRemove_1 = require_arrRemove();
    var args_1 = require_args();
    var executeSchedule_1 = require_executeSchedule();
    function windowTime(windowTimeSpan) {
      var _a, _b;
      var otherArgs = [];
      for (var _i = 1; _i < arguments.length; _i++) {
        otherArgs[_i - 1] = arguments[_i];
      }
      var scheduler = (_a = args_1.popScheduler(otherArgs)) !== null && _a !== void 0 ? _a : async_1.asyncScheduler;
      var windowCreationInterval = (_b = otherArgs[0]) !== null && _b !== void 0 ? _b : null;
      var maxWindowSize = otherArgs[1] || Infinity;
      return lift_1.operate(function(source, subscriber) {
        var windowRecords = [];
        var restartOnClose = false;
        var closeWindow = function(record) {
          var window2 = record.window, subs = record.subs;
          window2.complete();
          subs.unsubscribe();
          arrRemove_1.arrRemove(windowRecords, record);
          restartOnClose && startWindow();
        };
        var startWindow = function() {
          if (windowRecords) {
            var subs = new Subscription_1.Subscription();
            subscriber.add(subs);
            var window_1 = new Subject_1.Subject();
            var record_1 = {
              window: window_1,
              subs,
              seen: 0
            };
            windowRecords.push(record_1);
            subscriber.next(window_1.asObservable());
            executeSchedule_1.executeSchedule(subs, scheduler, function() {
              return closeWindow(record_1);
            }, windowTimeSpan);
          }
        };
        if (windowCreationInterval !== null && windowCreationInterval >= 0) {
          executeSchedule_1.executeSchedule(subscriber, scheduler, startWindow, windowCreationInterval, true);
        } else {
          restartOnClose = true;
        }
        startWindow();
        var loop = function(cb) {
          return windowRecords.slice().forEach(cb);
        };
        var terminate = function(cb) {
          loop(function(_a2) {
            var window2 = _a2.window;
            return cb(window2);
          });
          cb(subscriber);
          subscriber.unsubscribe();
        };
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          loop(function(record) {
            record.window.next(value2);
            maxWindowSize <= ++record.seen && closeWindow(record);
          });
        }, function() {
          return terminate(function(consumer) {
            return consumer.complete();
          });
        }, function(err) {
          return terminate(function(consumer) {
            return consumer.error(err);
          });
        }));
        return function() {
          windowRecords = null;
        };
      });
    }
    exports.windowTime = windowTime;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowToggle.js
var require_windowToggle = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowToggle.js"(exports) {
    "use strict";
    var __values = exports && exports.__values || function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.windowToggle = void 0;
    var Subject_1 = require_Subject();
    var Subscription_1 = require_Subscription();
    var lift_1 = require_lift();
    var innerFrom_1 = require_innerFrom();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var noop_1 = require_noop();
    var arrRemove_1 = require_arrRemove();
    function windowToggle(openings, closingSelector) {
      return lift_1.operate(function(source, subscriber) {
        var windows = [];
        var handleError = function(err) {
          while (0 < windows.length) {
            windows.shift().error(err);
          }
          subscriber.error(err);
        };
        innerFrom_1.innerFrom(openings).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(openValue) {
          var window2 = new Subject_1.Subject();
          windows.push(window2);
          var closingSubscription = new Subscription_1.Subscription();
          var closeWindow = function() {
            arrRemove_1.arrRemove(windows, window2);
            window2.complete();
            closingSubscription.unsubscribe();
          };
          var closingNotifier;
          try {
            closingNotifier = innerFrom_1.innerFrom(closingSelector(openValue));
          } catch (err) {
            handleError(err);
            return;
          }
          subscriber.next(window2.asObservable());
          closingSubscription.add(closingNotifier.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, closeWindow, noop_1.noop, handleError)));
        }, noop_1.noop));
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          var e_1, _a;
          var windowsCopy = windows.slice();
          try {
            for (var windowsCopy_1 = __values(windowsCopy), windowsCopy_1_1 = windowsCopy_1.next(); !windowsCopy_1_1.done; windowsCopy_1_1 = windowsCopy_1.next()) {
              var window_1 = windowsCopy_1_1.value;
              window_1.next(value2);
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (windowsCopy_1_1 && !windowsCopy_1_1.done && (_a = windowsCopy_1.return))
                _a.call(windowsCopy_1);
            } finally {
              if (e_1)
                throw e_1.error;
            }
          }
        }, function() {
          while (0 < windows.length) {
            windows.shift().complete();
          }
          subscriber.complete();
        }, handleError, function() {
          while (0 < windows.length) {
            windows.shift().unsubscribe();
          }
        }));
      });
    }
    exports.windowToggle = windowToggle;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowWhen.js
var require_windowWhen = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/windowWhen.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.windowWhen = void 0;
    var Subject_1 = require_Subject();
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    function windowWhen(closingSelector) {
      return lift_1.operate(function(source, subscriber) {
        var window2;
        var closingSubscriber;
        var handleError = function(err) {
          window2.error(err);
          subscriber.error(err);
        };
        var openWindow = function() {
          closingSubscriber === null || closingSubscriber === void 0 ? void 0 : closingSubscriber.unsubscribe();
          window2 === null || window2 === void 0 ? void 0 : window2.complete();
          window2 = new Subject_1.Subject();
          subscriber.next(window2.asObservable());
          var closingNotifier;
          try {
            closingNotifier = innerFrom_1.innerFrom(closingSelector());
          } catch (err) {
            handleError(err);
            return;
          }
          closingNotifier.subscribe(closingSubscriber = OperatorSubscriber_1.createOperatorSubscriber(subscriber, openWindow, openWindow, handleError));
        };
        openWindow();
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          return window2.next(value2);
        }, function() {
          window2.complete();
          subscriber.complete();
        }, handleError, function() {
          closingSubscriber === null || closingSubscriber === void 0 ? void 0 : closingSubscriber.unsubscribe();
          window2 = null;
        }));
      });
    }
    exports.windowWhen = windowWhen;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/withLatestFrom.js
var require_withLatestFrom = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/withLatestFrom.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.withLatestFrom = void 0;
    var lift_1 = require_lift();
    var OperatorSubscriber_1 = require_OperatorSubscriber();
    var innerFrom_1 = require_innerFrom();
    var identity_1 = require_identity();
    var noop_1 = require_noop();
    var args_1 = require_args();
    function withLatestFrom() {
      var inputs = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        inputs[_i] = arguments[_i];
      }
      var project = args_1.popResultSelector(inputs);
      return lift_1.operate(function(source, subscriber) {
        var len = inputs.length;
        var otherValues = new Array(len);
        var hasValue = inputs.map(function() {
          return false;
        });
        var ready = false;
        var _loop_1 = function(i2) {
          innerFrom_1.innerFrom(inputs[i2]).subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
            otherValues[i2] = value2;
            if (!ready && !hasValue[i2]) {
              hasValue[i2] = true;
              (ready = hasValue.every(identity_1.identity)) && (hasValue = null);
            }
          }, noop_1.noop));
        };
        for (var i = 0; i < len; i++) {
          _loop_1(i);
        }
        source.subscribe(OperatorSubscriber_1.createOperatorSubscriber(subscriber, function(value2) {
          if (ready) {
            var values2 = __spreadArray([value2], __read(otherValues));
            subscriber.next(project ? project.apply(void 0, __spreadArray([], __read(values2))) : values2);
          }
        }));
      });
    }
    exports.withLatestFrom = withLatestFrom;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zipAll.js
var require_zipAll = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zipAll.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.zipAll = void 0;
    var zip_1 = require_zip();
    var joinAllInternals_1 = require_joinAllInternals();
    function zipAll(project) {
      return joinAllInternals_1.joinAllInternals(zip_1.zip, project);
    }
    exports.zipAll = zipAll;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zip.js
var require_zip2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zip.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.zip = void 0;
    var zip_1 = require_zip();
    var lift_1 = require_lift();
    function zip() {
      var sources = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        sources[_i] = arguments[_i];
      }
      return lift_1.operate(function(source, subscriber) {
        zip_1.zip.apply(void 0, __spreadArray([source], __read(sources))).subscribe(subscriber);
      });
    }
    exports.zip = zip;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zipWith.js
var require_zipWith = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/zipWith.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.zipWith = void 0;
    var zip_1 = require_zip2();
    function zipWith() {
      var otherInputs = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        otherInputs[_i] = arguments[_i];
      }
      return zip_1.zip.apply(void 0, __spreadArray([], __read(otherInputs)));
    }
    exports.zipWith = zipWith;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/index.js
var require_cjs = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/index.js"(exports) {
    "use strict";
    var __createBinding = exports && exports.__createBinding || (Object.create ? function(o, m, k, k2) {
      if (k2 === void 0)
        k2 = k;
      Object.defineProperty(o, k2, { enumerable: true, get: function() {
        return m[k];
      } });
    } : function(o, m, k, k2) {
      if (k2 === void 0)
        k2 = k;
      o[k2] = m[k];
    });
    var __exportStar = exports && exports.__exportStar || function(m, exports2) {
      for (var p in m)
        if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports2, p))
          __createBinding(exports2, m, p);
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.interval = exports.iif = exports.generate = exports.fromEventPattern = exports.fromEvent = exports.from = exports.forkJoin = exports.empty = exports.defer = exports.connectable = exports.concat = exports.combineLatest = exports.bindNodeCallback = exports.bindCallback = exports.UnsubscriptionError = exports.TimeoutError = exports.SequenceError = exports.ObjectUnsubscribedError = exports.NotFoundError = exports.EmptyError = exports.ArgumentOutOfRangeError = exports.firstValueFrom = exports.lastValueFrom = exports.isObservable = exports.identity = exports.noop = exports.pipe = exports.NotificationKind = exports.Notification = exports.Subscriber = exports.Subscription = exports.Scheduler = exports.VirtualAction = exports.VirtualTimeScheduler = exports.animationFrameScheduler = exports.animationFrame = exports.queueScheduler = exports.queue = exports.asyncScheduler = exports.async = exports.asapScheduler = exports.asap = exports.AsyncSubject = exports.ReplaySubject = exports.BehaviorSubject = exports.Subject = exports.animationFrames = exports.observable = exports.ConnectableObservable = exports.Observable = void 0;
    exports.filter = exports.expand = exports.exhaustMap = exports.exhaustAll = exports.exhaust = exports.every = exports.endWith = exports.elementAt = exports.distinctUntilKeyChanged = exports.distinctUntilChanged = exports.distinct = exports.dematerialize = exports.delayWhen = exports.delay = exports.defaultIfEmpty = exports.debounceTime = exports.debounce = exports.count = exports.connect = exports.concatWith = exports.concatMapTo = exports.concatMap = exports.concatAll = exports.combineLatestWith = exports.combineLatestAll = exports.combineAll = exports.catchError = exports.bufferWhen = exports.bufferToggle = exports.bufferTime = exports.bufferCount = exports.buffer = exports.auditTime = exports.audit = exports.config = exports.NEVER = exports.EMPTY = exports.scheduled = exports.zip = exports.using = exports.timer = exports.throwError = exports.range = exports.race = exports.partition = exports.pairs = exports.onErrorResumeNext = exports.of = exports.never = exports.merge = void 0;
    exports.switchMap = exports.switchAll = exports.subscribeOn = exports.startWith = exports.skipWhile = exports.skipUntil = exports.skipLast = exports.skip = exports.single = exports.shareReplay = exports.share = exports.sequenceEqual = exports.scan = exports.sampleTime = exports.sample = exports.refCount = exports.retryWhen = exports.retry = exports.repeatWhen = exports.repeat = exports.reduce = exports.raceWith = exports.publishReplay = exports.publishLast = exports.publishBehavior = exports.publish = exports.pluck = exports.pairwise = exports.onErrorResumeNextWith = exports.observeOn = exports.multicast = exports.min = exports.mergeWith = exports.mergeScan = exports.mergeMapTo = exports.mergeMap = exports.flatMap = exports.mergeAll = exports.max = exports.materialize = exports.mapTo = exports.map = exports.last = exports.isEmpty = exports.ignoreElements = exports.groupBy = exports.first = exports.findIndex = exports.find = exports.finalize = void 0;
    exports.zipWith = exports.zipAll = exports.withLatestFrom = exports.windowWhen = exports.windowToggle = exports.windowTime = exports.windowCount = exports.window = exports.toArray = exports.timestamp = exports.timeoutWith = exports.timeout = exports.timeInterval = exports.throwIfEmpty = exports.throttleTime = exports.throttle = exports.tap = exports.takeWhile = exports.takeUntil = exports.takeLast = exports.take = exports.switchScan = exports.switchMapTo = void 0;
    var Observable_1 = require_Observable();
    Object.defineProperty(exports, "Observable", { enumerable: true, get: function() {
      return Observable_1.Observable;
    } });
    var ConnectableObservable_1 = require_ConnectableObservable();
    Object.defineProperty(exports, "ConnectableObservable", { enumerable: true, get: function() {
      return ConnectableObservable_1.ConnectableObservable;
    } });
    var observable_1 = require_observable();
    Object.defineProperty(exports, "observable", { enumerable: true, get: function() {
      return observable_1.observable;
    } });
    var animationFrames_1 = require_animationFrames();
    Object.defineProperty(exports, "animationFrames", { enumerable: true, get: function() {
      return animationFrames_1.animationFrames;
    } });
    var Subject_1 = require_Subject();
    Object.defineProperty(exports, "Subject", { enumerable: true, get: function() {
      return Subject_1.Subject;
    } });
    var BehaviorSubject_1 = require_BehaviorSubject();
    Object.defineProperty(exports, "BehaviorSubject", { enumerable: true, get: function() {
      return BehaviorSubject_1.BehaviorSubject;
    } });
    var ReplaySubject_1 = require_ReplaySubject();
    Object.defineProperty(exports, "ReplaySubject", { enumerable: true, get: function() {
      return ReplaySubject_1.ReplaySubject;
    } });
    var AsyncSubject_1 = require_AsyncSubject();
    Object.defineProperty(exports, "AsyncSubject", { enumerable: true, get: function() {
      return AsyncSubject_1.AsyncSubject;
    } });
    var asap_1 = require_asap();
    Object.defineProperty(exports, "asap", { enumerable: true, get: function() {
      return asap_1.asap;
    } });
    Object.defineProperty(exports, "asapScheduler", { enumerable: true, get: function() {
      return asap_1.asapScheduler;
    } });
    var async_1 = require_async();
    Object.defineProperty(exports, "async", { enumerable: true, get: function() {
      return async_1.async;
    } });
    Object.defineProperty(exports, "asyncScheduler", { enumerable: true, get: function() {
      return async_1.asyncScheduler;
    } });
    var queue_1 = require_queue();
    Object.defineProperty(exports, "queue", { enumerable: true, get: function() {
      return queue_1.queue;
    } });
    Object.defineProperty(exports, "queueScheduler", { enumerable: true, get: function() {
      return queue_1.queueScheduler;
    } });
    var animationFrame_1 = require_animationFrame();
    Object.defineProperty(exports, "animationFrame", { enumerable: true, get: function() {
      return animationFrame_1.animationFrame;
    } });
    Object.defineProperty(exports, "animationFrameScheduler", { enumerable: true, get: function() {
      return animationFrame_1.animationFrameScheduler;
    } });
    var VirtualTimeScheduler_1 = require_VirtualTimeScheduler();
    Object.defineProperty(exports, "VirtualTimeScheduler", { enumerable: true, get: function() {
      return VirtualTimeScheduler_1.VirtualTimeScheduler;
    } });
    Object.defineProperty(exports, "VirtualAction", { enumerable: true, get: function() {
      return VirtualTimeScheduler_1.VirtualAction;
    } });
    var Scheduler_1 = require_Scheduler();
    Object.defineProperty(exports, "Scheduler", { enumerable: true, get: function() {
      return Scheduler_1.Scheduler;
    } });
    var Subscription_1 = require_Subscription();
    Object.defineProperty(exports, "Subscription", { enumerable: true, get: function() {
      return Subscription_1.Subscription;
    } });
    var Subscriber_1 = require_Subscriber();
    Object.defineProperty(exports, "Subscriber", { enumerable: true, get: function() {
      return Subscriber_1.Subscriber;
    } });
    var Notification_1 = require_Notification();
    Object.defineProperty(exports, "Notification", { enumerable: true, get: function() {
      return Notification_1.Notification;
    } });
    Object.defineProperty(exports, "NotificationKind", { enumerable: true, get: function() {
      return Notification_1.NotificationKind;
    } });
    var pipe_1 = require_pipe();
    Object.defineProperty(exports, "pipe", { enumerable: true, get: function() {
      return pipe_1.pipe;
    } });
    var noop_1 = require_noop();
    Object.defineProperty(exports, "noop", { enumerable: true, get: function() {
      return noop_1.noop;
    } });
    var identity_1 = require_identity();
    Object.defineProperty(exports, "identity", { enumerable: true, get: function() {
      return identity_1.identity;
    } });
    var isObservable_1 = require_isObservable();
    Object.defineProperty(exports, "isObservable", { enumerable: true, get: function() {
      return isObservable_1.isObservable;
    } });
    var lastValueFrom_1 = require_lastValueFrom();
    Object.defineProperty(exports, "lastValueFrom", { enumerable: true, get: function() {
      return lastValueFrom_1.lastValueFrom;
    } });
    var firstValueFrom_1 = require_firstValueFrom();
    Object.defineProperty(exports, "firstValueFrom", { enumerable: true, get: function() {
      return firstValueFrom_1.firstValueFrom;
    } });
    var ArgumentOutOfRangeError_1 = require_ArgumentOutOfRangeError();
    Object.defineProperty(exports, "ArgumentOutOfRangeError", { enumerable: true, get: function() {
      return ArgumentOutOfRangeError_1.ArgumentOutOfRangeError;
    } });
    var EmptyError_1 = require_EmptyError();
    Object.defineProperty(exports, "EmptyError", { enumerable: true, get: function() {
      return EmptyError_1.EmptyError;
    } });
    var NotFoundError_1 = require_NotFoundError();
    Object.defineProperty(exports, "NotFoundError", { enumerable: true, get: function() {
      return NotFoundError_1.NotFoundError;
    } });
    var ObjectUnsubscribedError_1 = require_ObjectUnsubscribedError();
    Object.defineProperty(exports, "ObjectUnsubscribedError", { enumerable: true, get: function() {
      return ObjectUnsubscribedError_1.ObjectUnsubscribedError;
    } });
    var SequenceError_1 = require_SequenceError();
    Object.defineProperty(exports, "SequenceError", { enumerable: true, get: function() {
      return SequenceError_1.SequenceError;
    } });
    var timeout_1 = require_timeout();
    Object.defineProperty(exports, "TimeoutError", { enumerable: true, get: function() {
      return timeout_1.TimeoutError;
    } });
    var UnsubscriptionError_1 = require_UnsubscriptionError();
    Object.defineProperty(exports, "UnsubscriptionError", { enumerable: true, get: function() {
      return UnsubscriptionError_1.UnsubscriptionError;
    } });
    var bindCallback_1 = require_bindCallback();
    Object.defineProperty(exports, "bindCallback", { enumerable: true, get: function() {
      return bindCallback_1.bindCallback;
    } });
    var bindNodeCallback_1 = require_bindNodeCallback();
    Object.defineProperty(exports, "bindNodeCallback", { enumerable: true, get: function() {
      return bindNodeCallback_1.bindNodeCallback;
    } });
    var combineLatest_1 = require_combineLatest();
    Object.defineProperty(exports, "combineLatest", { enumerable: true, get: function() {
      return combineLatest_1.combineLatest;
    } });
    var concat_1 = require_concat();
    Object.defineProperty(exports, "concat", { enumerable: true, get: function() {
      return concat_1.concat;
    } });
    var connectable_1 = require_connectable();
    Object.defineProperty(exports, "connectable", { enumerable: true, get: function() {
      return connectable_1.connectable;
    } });
    var defer_1 = require_defer();
    Object.defineProperty(exports, "defer", { enumerable: true, get: function() {
      return defer_1.defer;
    } });
    var empty_1 = require_empty();
    Object.defineProperty(exports, "empty", { enumerable: true, get: function() {
      return empty_1.empty;
    } });
    var forkJoin_1 = require_forkJoin();
    Object.defineProperty(exports, "forkJoin", { enumerable: true, get: function() {
      return forkJoin_1.forkJoin;
    } });
    var from_1 = require_from2();
    Object.defineProperty(exports, "from", { enumerable: true, get: function() {
      return from_1.from;
    } });
    var fromEvent_1 = require_fromEvent();
    Object.defineProperty(exports, "fromEvent", { enumerable: true, get: function() {
      return fromEvent_1.fromEvent;
    } });
    var fromEventPattern_1 = require_fromEventPattern();
    Object.defineProperty(exports, "fromEventPattern", { enumerable: true, get: function() {
      return fromEventPattern_1.fromEventPattern;
    } });
    var generate_1 = require_generate();
    Object.defineProperty(exports, "generate", { enumerable: true, get: function() {
      return generate_1.generate;
    } });
    var iif_1 = require_iif();
    Object.defineProperty(exports, "iif", { enumerable: true, get: function() {
      return iif_1.iif;
    } });
    var interval_1 = require_interval();
    Object.defineProperty(exports, "interval", { enumerable: true, get: function() {
      return interval_1.interval;
    } });
    var merge_1 = require_merge();
    Object.defineProperty(exports, "merge", { enumerable: true, get: function() {
      return merge_1.merge;
    } });
    var never_1 = require_never();
    Object.defineProperty(exports, "never", { enumerable: true, get: function() {
      return never_1.never;
    } });
    var of_1 = require_of();
    Object.defineProperty(exports, "of", { enumerable: true, get: function() {
      return of_1.of;
    } });
    var onErrorResumeNext_1 = require_onErrorResumeNext();
    Object.defineProperty(exports, "onErrorResumeNext", { enumerable: true, get: function() {
      return onErrorResumeNext_1.onErrorResumeNext;
    } });
    var pairs_1 = require_pairs();
    Object.defineProperty(exports, "pairs", { enumerable: true, get: function() {
      return pairs_1.pairs;
    } });
    var partition_1 = require_partition();
    Object.defineProperty(exports, "partition", { enumerable: true, get: function() {
      return partition_1.partition;
    } });
    var race_1 = require_race();
    Object.defineProperty(exports, "race", { enumerable: true, get: function() {
      return race_1.race;
    } });
    var range_1 = require_range();
    Object.defineProperty(exports, "range", { enumerable: true, get: function() {
      return range_1.range;
    } });
    var throwError_1 = require_throwError();
    Object.defineProperty(exports, "throwError", { enumerable: true, get: function() {
      return throwError_1.throwError;
    } });
    var timer_1 = require_timer();
    Object.defineProperty(exports, "timer", { enumerable: true, get: function() {
      return timer_1.timer;
    } });
    var using_1 = require_using();
    Object.defineProperty(exports, "using", { enumerable: true, get: function() {
      return using_1.using;
    } });
    var zip_1 = require_zip();
    Object.defineProperty(exports, "zip", { enumerable: true, get: function() {
      return zip_1.zip;
    } });
    var scheduled_1 = require_scheduled();
    Object.defineProperty(exports, "scheduled", { enumerable: true, get: function() {
      return scheduled_1.scheduled;
    } });
    var empty_2 = require_empty();
    Object.defineProperty(exports, "EMPTY", { enumerable: true, get: function() {
      return empty_2.EMPTY;
    } });
    var never_2 = require_never();
    Object.defineProperty(exports, "NEVER", { enumerable: true, get: function() {
      return never_2.NEVER;
    } });
    __exportStar(require_types(), exports);
    var config_1 = require_config();
    Object.defineProperty(exports, "config", { enumerable: true, get: function() {
      return config_1.config;
    } });
    var audit_1 = require_audit();
    Object.defineProperty(exports, "audit", { enumerable: true, get: function() {
      return audit_1.audit;
    } });
    var auditTime_1 = require_auditTime();
    Object.defineProperty(exports, "auditTime", { enumerable: true, get: function() {
      return auditTime_1.auditTime;
    } });
    var buffer_1 = require_buffer();
    Object.defineProperty(exports, "buffer", { enumerable: true, get: function() {
      return buffer_1.buffer;
    } });
    var bufferCount_1 = require_bufferCount();
    Object.defineProperty(exports, "bufferCount", { enumerable: true, get: function() {
      return bufferCount_1.bufferCount;
    } });
    var bufferTime_1 = require_bufferTime();
    Object.defineProperty(exports, "bufferTime", { enumerable: true, get: function() {
      return bufferTime_1.bufferTime;
    } });
    var bufferToggle_1 = require_bufferToggle();
    Object.defineProperty(exports, "bufferToggle", { enumerable: true, get: function() {
      return bufferToggle_1.bufferToggle;
    } });
    var bufferWhen_1 = require_bufferWhen();
    Object.defineProperty(exports, "bufferWhen", { enumerable: true, get: function() {
      return bufferWhen_1.bufferWhen;
    } });
    var catchError_1 = require_catchError();
    Object.defineProperty(exports, "catchError", { enumerable: true, get: function() {
      return catchError_1.catchError;
    } });
    var combineAll_1 = require_combineAll();
    Object.defineProperty(exports, "combineAll", { enumerable: true, get: function() {
      return combineAll_1.combineAll;
    } });
    var combineLatestAll_1 = require_combineLatestAll();
    Object.defineProperty(exports, "combineLatestAll", { enumerable: true, get: function() {
      return combineLatestAll_1.combineLatestAll;
    } });
    var combineLatestWith_1 = require_combineLatestWith();
    Object.defineProperty(exports, "combineLatestWith", { enumerable: true, get: function() {
      return combineLatestWith_1.combineLatestWith;
    } });
    var concatAll_1 = require_concatAll();
    Object.defineProperty(exports, "concatAll", { enumerable: true, get: function() {
      return concatAll_1.concatAll;
    } });
    var concatMap_1 = require_concatMap();
    Object.defineProperty(exports, "concatMap", { enumerable: true, get: function() {
      return concatMap_1.concatMap;
    } });
    var concatMapTo_1 = require_concatMapTo();
    Object.defineProperty(exports, "concatMapTo", { enumerable: true, get: function() {
      return concatMapTo_1.concatMapTo;
    } });
    var concatWith_1 = require_concatWith();
    Object.defineProperty(exports, "concatWith", { enumerable: true, get: function() {
      return concatWith_1.concatWith;
    } });
    var connect_1 = require_connect();
    Object.defineProperty(exports, "connect", { enumerable: true, get: function() {
      return connect_1.connect;
    } });
    var count_1 = require_count();
    Object.defineProperty(exports, "count", { enumerable: true, get: function() {
      return count_1.count;
    } });
    var debounce_1 = require_debounce();
    Object.defineProperty(exports, "debounce", { enumerable: true, get: function() {
      return debounce_1.debounce;
    } });
    var debounceTime_1 = require_debounceTime();
    Object.defineProperty(exports, "debounceTime", { enumerable: true, get: function() {
      return debounceTime_1.debounceTime;
    } });
    var defaultIfEmpty_1 = require_defaultIfEmpty();
    Object.defineProperty(exports, "defaultIfEmpty", { enumerable: true, get: function() {
      return defaultIfEmpty_1.defaultIfEmpty;
    } });
    var delay_1 = require_delay();
    Object.defineProperty(exports, "delay", { enumerable: true, get: function() {
      return delay_1.delay;
    } });
    var delayWhen_1 = require_delayWhen();
    Object.defineProperty(exports, "delayWhen", { enumerable: true, get: function() {
      return delayWhen_1.delayWhen;
    } });
    var dematerialize_1 = require_dematerialize();
    Object.defineProperty(exports, "dematerialize", { enumerable: true, get: function() {
      return dematerialize_1.dematerialize;
    } });
    var distinct_1 = require_distinct();
    Object.defineProperty(exports, "distinct", { enumerable: true, get: function() {
      return distinct_1.distinct;
    } });
    var distinctUntilChanged_1 = require_distinctUntilChanged();
    Object.defineProperty(exports, "distinctUntilChanged", { enumerable: true, get: function() {
      return distinctUntilChanged_1.distinctUntilChanged;
    } });
    var distinctUntilKeyChanged_1 = require_distinctUntilKeyChanged();
    Object.defineProperty(exports, "distinctUntilKeyChanged", { enumerable: true, get: function() {
      return distinctUntilKeyChanged_1.distinctUntilKeyChanged;
    } });
    var elementAt_1 = require_elementAt();
    Object.defineProperty(exports, "elementAt", { enumerable: true, get: function() {
      return elementAt_1.elementAt;
    } });
    var endWith_1 = require_endWith();
    Object.defineProperty(exports, "endWith", { enumerable: true, get: function() {
      return endWith_1.endWith;
    } });
    var every_1 = require_every();
    Object.defineProperty(exports, "every", { enumerable: true, get: function() {
      return every_1.every;
    } });
    var exhaust_1 = require_exhaust();
    Object.defineProperty(exports, "exhaust", { enumerable: true, get: function() {
      return exhaust_1.exhaust;
    } });
    var exhaustAll_1 = require_exhaustAll();
    Object.defineProperty(exports, "exhaustAll", { enumerable: true, get: function() {
      return exhaustAll_1.exhaustAll;
    } });
    var exhaustMap_1 = require_exhaustMap();
    Object.defineProperty(exports, "exhaustMap", { enumerable: true, get: function() {
      return exhaustMap_1.exhaustMap;
    } });
    var expand_1 = require_expand();
    Object.defineProperty(exports, "expand", { enumerable: true, get: function() {
      return expand_1.expand;
    } });
    var filter_1 = require_filter();
    Object.defineProperty(exports, "filter", { enumerable: true, get: function() {
      return filter_1.filter;
    } });
    var finalize_1 = require_finalize();
    Object.defineProperty(exports, "finalize", { enumerable: true, get: function() {
      return finalize_1.finalize;
    } });
    var find_1 = require_find();
    Object.defineProperty(exports, "find", { enumerable: true, get: function() {
      return find_1.find;
    } });
    var findIndex_1 = require_findIndex();
    Object.defineProperty(exports, "findIndex", { enumerable: true, get: function() {
      return findIndex_1.findIndex;
    } });
    var first_1 = require_first();
    Object.defineProperty(exports, "first", { enumerable: true, get: function() {
      return first_1.first;
    } });
    var groupBy_1 = require_groupBy();
    Object.defineProperty(exports, "groupBy", { enumerable: true, get: function() {
      return groupBy_1.groupBy;
    } });
    var ignoreElements_1 = require_ignoreElements();
    Object.defineProperty(exports, "ignoreElements", { enumerable: true, get: function() {
      return ignoreElements_1.ignoreElements;
    } });
    var isEmpty_1 = require_isEmpty();
    Object.defineProperty(exports, "isEmpty", { enumerable: true, get: function() {
      return isEmpty_1.isEmpty;
    } });
    var last_1 = require_last();
    Object.defineProperty(exports, "last", { enumerable: true, get: function() {
      return last_1.last;
    } });
    var map_1 = require_map();
    Object.defineProperty(exports, "map", { enumerable: true, get: function() {
      return map_1.map;
    } });
    var mapTo_1 = require_mapTo();
    Object.defineProperty(exports, "mapTo", { enumerable: true, get: function() {
      return mapTo_1.mapTo;
    } });
    var materialize_1 = require_materialize();
    Object.defineProperty(exports, "materialize", { enumerable: true, get: function() {
      return materialize_1.materialize;
    } });
    var max_1 = require_max();
    Object.defineProperty(exports, "max", { enumerable: true, get: function() {
      return max_1.max;
    } });
    var mergeAll_1 = require_mergeAll();
    Object.defineProperty(exports, "mergeAll", { enumerable: true, get: function() {
      return mergeAll_1.mergeAll;
    } });
    var flatMap_1 = require_flatMap();
    Object.defineProperty(exports, "flatMap", { enumerable: true, get: function() {
      return flatMap_1.flatMap;
    } });
    var mergeMap_1 = require_mergeMap();
    Object.defineProperty(exports, "mergeMap", { enumerable: true, get: function() {
      return mergeMap_1.mergeMap;
    } });
    var mergeMapTo_1 = require_mergeMapTo();
    Object.defineProperty(exports, "mergeMapTo", { enumerable: true, get: function() {
      return mergeMapTo_1.mergeMapTo;
    } });
    var mergeScan_1 = require_mergeScan();
    Object.defineProperty(exports, "mergeScan", { enumerable: true, get: function() {
      return mergeScan_1.mergeScan;
    } });
    var mergeWith_1 = require_mergeWith();
    Object.defineProperty(exports, "mergeWith", { enumerable: true, get: function() {
      return mergeWith_1.mergeWith;
    } });
    var min_1 = require_min();
    Object.defineProperty(exports, "min", { enumerable: true, get: function() {
      return min_1.min;
    } });
    var multicast_1 = require_multicast();
    Object.defineProperty(exports, "multicast", { enumerable: true, get: function() {
      return multicast_1.multicast;
    } });
    var observeOn_1 = require_observeOn();
    Object.defineProperty(exports, "observeOn", { enumerable: true, get: function() {
      return observeOn_1.observeOn;
    } });
    var onErrorResumeNextWith_1 = require_onErrorResumeNextWith();
    Object.defineProperty(exports, "onErrorResumeNextWith", { enumerable: true, get: function() {
      return onErrorResumeNextWith_1.onErrorResumeNextWith;
    } });
    var pairwise_1 = require_pairwise();
    Object.defineProperty(exports, "pairwise", { enumerable: true, get: function() {
      return pairwise_1.pairwise;
    } });
    var pluck_1 = require_pluck();
    Object.defineProperty(exports, "pluck", { enumerable: true, get: function() {
      return pluck_1.pluck;
    } });
    var publish_1 = require_publish();
    Object.defineProperty(exports, "publish", { enumerable: true, get: function() {
      return publish_1.publish;
    } });
    var publishBehavior_1 = require_publishBehavior();
    Object.defineProperty(exports, "publishBehavior", { enumerable: true, get: function() {
      return publishBehavior_1.publishBehavior;
    } });
    var publishLast_1 = require_publishLast();
    Object.defineProperty(exports, "publishLast", { enumerable: true, get: function() {
      return publishLast_1.publishLast;
    } });
    var publishReplay_1 = require_publishReplay();
    Object.defineProperty(exports, "publishReplay", { enumerable: true, get: function() {
      return publishReplay_1.publishReplay;
    } });
    var raceWith_1 = require_raceWith();
    Object.defineProperty(exports, "raceWith", { enumerable: true, get: function() {
      return raceWith_1.raceWith;
    } });
    var reduce_1 = require_reduce();
    Object.defineProperty(exports, "reduce", { enumerable: true, get: function() {
      return reduce_1.reduce;
    } });
    var repeat_1 = require_repeat();
    Object.defineProperty(exports, "repeat", { enumerable: true, get: function() {
      return repeat_1.repeat;
    } });
    var repeatWhen_1 = require_repeatWhen();
    Object.defineProperty(exports, "repeatWhen", { enumerable: true, get: function() {
      return repeatWhen_1.repeatWhen;
    } });
    var retry_1 = require_retry();
    Object.defineProperty(exports, "retry", { enumerable: true, get: function() {
      return retry_1.retry;
    } });
    var retryWhen_1 = require_retryWhen();
    Object.defineProperty(exports, "retryWhen", { enumerable: true, get: function() {
      return retryWhen_1.retryWhen;
    } });
    var refCount_1 = require_refCount();
    Object.defineProperty(exports, "refCount", { enumerable: true, get: function() {
      return refCount_1.refCount;
    } });
    var sample_1 = require_sample();
    Object.defineProperty(exports, "sample", { enumerable: true, get: function() {
      return sample_1.sample;
    } });
    var sampleTime_1 = require_sampleTime();
    Object.defineProperty(exports, "sampleTime", { enumerable: true, get: function() {
      return sampleTime_1.sampleTime;
    } });
    var scan_1 = require_scan();
    Object.defineProperty(exports, "scan", { enumerable: true, get: function() {
      return scan_1.scan;
    } });
    var sequenceEqual_1 = require_sequenceEqual();
    Object.defineProperty(exports, "sequenceEqual", { enumerable: true, get: function() {
      return sequenceEqual_1.sequenceEqual;
    } });
    var share_1 = require_share();
    Object.defineProperty(exports, "share", { enumerable: true, get: function() {
      return share_1.share;
    } });
    var shareReplay_1 = require_shareReplay();
    Object.defineProperty(exports, "shareReplay", { enumerable: true, get: function() {
      return shareReplay_1.shareReplay;
    } });
    var single_1 = require_single();
    Object.defineProperty(exports, "single", { enumerable: true, get: function() {
      return single_1.single;
    } });
    var skip_1 = require_skip();
    Object.defineProperty(exports, "skip", { enumerable: true, get: function() {
      return skip_1.skip;
    } });
    var skipLast_1 = require_skipLast();
    Object.defineProperty(exports, "skipLast", { enumerable: true, get: function() {
      return skipLast_1.skipLast;
    } });
    var skipUntil_1 = require_skipUntil();
    Object.defineProperty(exports, "skipUntil", { enumerable: true, get: function() {
      return skipUntil_1.skipUntil;
    } });
    var skipWhile_1 = require_skipWhile();
    Object.defineProperty(exports, "skipWhile", { enumerable: true, get: function() {
      return skipWhile_1.skipWhile;
    } });
    var startWith_1 = require_startWith();
    Object.defineProperty(exports, "startWith", { enumerable: true, get: function() {
      return startWith_1.startWith;
    } });
    var subscribeOn_1 = require_subscribeOn();
    Object.defineProperty(exports, "subscribeOn", { enumerable: true, get: function() {
      return subscribeOn_1.subscribeOn;
    } });
    var switchAll_1 = require_switchAll();
    Object.defineProperty(exports, "switchAll", { enumerable: true, get: function() {
      return switchAll_1.switchAll;
    } });
    var switchMap_1 = require_switchMap();
    Object.defineProperty(exports, "switchMap", { enumerable: true, get: function() {
      return switchMap_1.switchMap;
    } });
    var switchMapTo_1 = require_switchMapTo();
    Object.defineProperty(exports, "switchMapTo", { enumerable: true, get: function() {
      return switchMapTo_1.switchMapTo;
    } });
    var switchScan_1 = require_switchScan();
    Object.defineProperty(exports, "switchScan", { enumerable: true, get: function() {
      return switchScan_1.switchScan;
    } });
    var take_1 = require_take();
    Object.defineProperty(exports, "take", { enumerable: true, get: function() {
      return take_1.take;
    } });
    var takeLast_1 = require_takeLast();
    Object.defineProperty(exports, "takeLast", { enumerable: true, get: function() {
      return takeLast_1.takeLast;
    } });
    var takeUntil_1 = require_takeUntil();
    Object.defineProperty(exports, "takeUntil", { enumerable: true, get: function() {
      return takeUntil_1.takeUntil;
    } });
    var takeWhile_1 = require_takeWhile();
    Object.defineProperty(exports, "takeWhile", { enumerable: true, get: function() {
      return takeWhile_1.takeWhile;
    } });
    var tap_1 = require_tap();
    Object.defineProperty(exports, "tap", { enumerable: true, get: function() {
      return tap_1.tap;
    } });
    var throttle_1 = require_throttle();
    Object.defineProperty(exports, "throttle", { enumerable: true, get: function() {
      return throttle_1.throttle;
    } });
    var throttleTime_1 = require_throttleTime();
    Object.defineProperty(exports, "throttleTime", { enumerable: true, get: function() {
      return throttleTime_1.throttleTime;
    } });
    var throwIfEmpty_1 = require_throwIfEmpty();
    Object.defineProperty(exports, "throwIfEmpty", { enumerable: true, get: function() {
      return throwIfEmpty_1.throwIfEmpty;
    } });
    var timeInterval_1 = require_timeInterval();
    Object.defineProperty(exports, "timeInterval", { enumerable: true, get: function() {
      return timeInterval_1.timeInterval;
    } });
    var timeout_2 = require_timeout();
    Object.defineProperty(exports, "timeout", { enumerable: true, get: function() {
      return timeout_2.timeout;
    } });
    var timeoutWith_1 = require_timeoutWith();
    Object.defineProperty(exports, "timeoutWith", { enumerable: true, get: function() {
      return timeoutWith_1.timeoutWith;
    } });
    var timestamp_1 = require_timestamp();
    Object.defineProperty(exports, "timestamp", { enumerable: true, get: function() {
      return timestamp_1.timestamp;
    } });
    var toArray_1 = require_toArray();
    Object.defineProperty(exports, "toArray", { enumerable: true, get: function() {
      return toArray_1.toArray;
    } });
    var window_1 = require_window();
    Object.defineProperty(exports, "window", { enumerable: true, get: function() {
      return window_1.window;
    } });
    var windowCount_1 = require_windowCount();
    Object.defineProperty(exports, "windowCount", { enumerable: true, get: function() {
      return windowCount_1.windowCount;
    } });
    var windowTime_1 = require_windowTime();
    Object.defineProperty(exports, "windowTime", { enumerable: true, get: function() {
      return windowTime_1.windowTime;
    } });
    var windowToggle_1 = require_windowToggle();
    Object.defineProperty(exports, "windowToggle", { enumerable: true, get: function() {
      return windowToggle_1.windowToggle;
    } });
    var windowWhen_1 = require_windowWhen();
    Object.defineProperty(exports, "windowWhen", { enumerable: true, get: function() {
      return windowWhen_1.windowWhen;
    } });
    var withLatestFrom_1 = require_withLatestFrom();
    Object.defineProperty(exports, "withLatestFrom", { enumerable: true, get: function() {
      return withLatestFrom_1.withLatestFrom;
    } });
    var zipAll_1 = require_zipAll();
    Object.defineProperty(exports, "zipAll", { enumerable: true, get: function() {
      return zipAll_1.zipAll;
    } });
    var zipWith_1 = require_zipWith();
    Object.defineProperty(exports, "zipWith", { enumerable: true, get: function() {
      return zipWith_1.zipWith;
    } });
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/partition.js
var require_partition2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/partition.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.partition = void 0;
    var not_1 = require_not();
    var filter_1 = require_filter();
    function partition(predicate, thisArg) {
      return function(source) {
        return [filter_1.filter(predicate, thisArg)(source), filter_1.filter(not_1.not(predicate, thisArg))(source)];
      };
    }
    exports.partition = partition;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/race.js
var require_race2 = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/internal/operators/race.js"(exports) {
    "use strict";
    var __read = exports && exports.__read || function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    var __spreadArray = exports && exports.__spreadArray || function(to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
      return to;
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.race = void 0;
    var argsOrArgArray_1 = require_argsOrArgArray();
    var raceWith_1 = require_raceWith();
    function race() {
      var args = [];
      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }
      return raceWith_1.raceWith.apply(void 0, __spreadArray([], __read(argsOrArgArray_1.argsOrArgArray(args))));
    }
    exports.race = race;
  }
});

// node_modules/inquirer/node_modules/rxjs/dist/cjs/operators/index.js
var require_operators = __commonJS({
  "node_modules/inquirer/node_modules/rxjs/dist/cjs/operators/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.mergeAll = exports.merge = exports.max = exports.materialize = exports.mapTo = exports.map = exports.last = exports.isEmpty = exports.ignoreElements = exports.groupBy = exports.first = exports.findIndex = exports.find = exports.finalize = exports.filter = exports.expand = exports.exhaustMap = exports.exhaustAll = exports.exhaust = exports.every = exports.endWith = exports.elementAt = exports.distinctUntilKeyChanged = exports.distinctUntilChanged = exports.distinct = exports.dematerialize = exports.delayWhen = exports.delay = exports.defaultIfEmpty = exports.debounceTime = exports.debounce = exports.count = exports.connect = exports.concatWith = exports.concatMapTo = exports.concatMap = exports.concatAll = exports.concat = exports.combineLatestWith = exports.combineLatest = exports.combineLatestAll = exports.combineAll = exports.catchError = exports.bufferWhen = exports.bufferToggle = exports.bufferTime = exports.bufferCount = exports.buffer = exports.auditTime = exports.audit = void 0;
    exports.timeInterval = exports.throwIfEmpty = exports.throttleTime = exports.throttle = exports.tap = exports.takeWhile = exports.takeUntil = exports.takeLast = exports.take = exports.switchScan = exports.switchMapTo = exports.switchMap = exports.switchAll = exports.subscribeOn = exports.startWith = exports.skipWhile = exports.skipUntil = exports.skipLast = exports.skip = exports.single = exports.shareReplay = exports.share = exports.sequenceEqual = exports.scan = exports.sampleTime = exports.sample = exports.refCount = exports.retryWhen = exports.retry = exports.repeatWhen = exports.repeat = exports.reduce = exports.raceWith = exports.race = exports.publishReplay = exports.publishLast = exports.publishBehavior = exports.publish = exports.pluck = exports.partition = exports.pairwise = exports.onErrorResumeNext = exports.observeOn = exports.multicast = exports.min = exports.mergeWith = exports.mergeScan = exports.mergeMapTo = exports.mergeMap = exports.flatMap = void 0;
    exports.zipWith = exports.zipAll = exports.zip = exports.withLatestFrom = exports.windowWhen = exports.windowToggle = exports.windowTime = exports.windowCount = exports.window = exports.toArray = exports.timestamp = exports.timeoutWith = exports.timeout = void 0;
    var audit_1 = require_audit();
    Object.defineProperty(exports, "audit", { enumerable: true, get: function() {
      return audit_1.audit;
    } });
    var auditTime_1 = require_auditTime();
    Object.defineProperty(exports, "auditTime", { enumerable: true, get: function() {
      return auditTime_1.auditTime;
    } });
    var buffer_1 = require_buffer();
    Object.defineProperty(exports, "buffer", { enumerable: true, get: function() {
      return buffer_1.buffer;
    } });
    var bufferCount_1 = require_bufferCount();
    Object.defineProperty(exports, "bufferCount", { enumerable: true, get: function() {
      return bufferCount_1.bufferCount;
    } });
    var bufferTime_1 = require_bufferTime();
    Object.defineProperty(exports, "bufferTime", { enumerable: true, get: function() {
      return bufferTime_1.bufferTime;
    } });
    var bufferToggle_1 = require_bufferToggle();
    Object.defineProperty(exports, "bufferToggle", { enumerable: true, get: function() {
      return bufferToggle_1.bufferToggle;
    } });
    var bufferWhen_1 = require_bufferWhen();
    Object.defineProperty(exports, "bufferWhen", { enumerable: true, get: function() {
      return bufferWhen_1.bufferWhen;
    } });
    var catchError_1 = require_catchError();
    Object.defineProperty(exports, "catchError", { enumerable: true, get: function() {
      return catchError_1.catchError;
    } });
    var combineAll_1 = require_combineAll();
    Object.defineProperty(exports, "combineAll", { enumerable: true, get: function() {
      return combineAll_1.combineAll;
    } });
    var combineLatestAll_1 = require_combineLatestAll();
    Object.defineProperty(exports, "combineLatestAll", { enumerable: true, get: function() {
      return combineLatestAll_1.combineLatestAll;
    } });
    var combineLatest_1 = require_combineLatest2();
    Object.defineProperty(exports, "combineLatest", { enumerable: true, get: function() {
      return combineLatest_1.combineLatest;
    } });
    var combineLatestWith_1 = require_combineLatestWith();
    Object.defineProperty(exports, "combineLatestWith", { enumerable: true, get: function() {
      return combineLatestWith_1.combineLatestWith;
    } });
    var concat_1 = require_concat2();
    Object.defineProperty(exports, "concat", { enumerable: true, get: function() {
      return concat_1.concat;
    } });
    var concatAll_1 = require_concatAll();
    Object.defineProperty(exports, "concatAll", { enumerable: true, get: function() {
      return concatAll_1.concatAll;
    } });
    var concatMap_1 = require_concatMap();
    Object.defineProperty(exports, "concatMap", { enumerable: true, get: function() {
      return concatMap_1.concatMap;
    } });
    var concatMapTo_1 = require_concatMapTo();
    Object.defineProperty(exports, "concatMapTo", { enumerable: true, get: function() {
      return concatMapTo_1.concatMapTo;
    } });
    var concatWith_1 = require_concatWith();
    Object.defineProperty(exports, "concatWith", { enumerable: true, get: function() {
      return concatWith_1.concatWith;
    } });
    var connect_1 = require_connect();
    Object.defineProperty(exports, "connect", { enumerable: true, get: function() {
      return connect_1.connect;
    } });
    var count_1 = require_count();
    Object.defineProperty(exports, "count", { enumerable: true, get: function() {
      return count_1.count;
    } });
    var debounce_1 = require_debounce();
    Object.defineProperty(exports, "debounce", { enumerable: true, get: function() {
      return debounce_1.debounce;
    } });
    var debounceTime_1 = require_debounceTime();
    Object.defineProperty(exports, "debounceTime", { enumerable: true, get: function() {
      return debounceTime_1.debounceTime;
    } });
    var defaultIfEmpty_1 = require_defaultIfEmpty();
    Object.defineProperty(exports, "defaultIfEmpty", { enumerable: true, get: function() {
      return defaultIfEmpty_1.defaultIfEmpty;
    } });
    var delay_1 = require_delay();
    Object.defineProperty(exports, "delay", { enumerable: true, get: function() {
      return delay_1.delay;
    } });
    var delayWhen_1 = require_delayWhen();
    Object.defineProperty(exports, "delayWhen", { enumerable: true, get: function() {
      return delayWhen_1.delayWhen;
    } });
    var dematerialize_1 = require_dematerialize();
    Object.defineProperty(exports, "dematerialize", { enumerable: true, get: function() {
      return dematerialize_1.dematerialize;
    } });
    var distinct_1 = require_distinct();
    Object.defineProperty(exports, "distinct", { enumerable: true, get: function() {
      return distinct_1.distinct;
    } });
    var distinctUntilChanged_1 = require_distinctUntilChanged();
    Object.defineProperty(exports, "distinctUntilChanged", { enumerable: true, get: function() {
      return distinctUntilChanged_1.distinctUntilChanged;
    } });
    var distinctUntilKeyChanged_1 = require_distinctUntilKeyChanged();
    Object.defineProperty(exports, "distinctUntilKeyChanged", { enumerable: true, get: function() {
      return distinctUntilKeyChanged_1.distinctUntilKeyChanged;
    } });
    var elementAt_1 = require_elementAt();
    Object.defineProperty(exports, "elementAt", { enumerable: true, get: function() {
      return elementAt_1.elementAt;
    } });
    var endWith_1 = require_endWith();
    Object.defineProperty(exports, "endWith", { enumerable: true, get: function() {
      return endWith_1.endWith;
    } });
    var every_1 = require_every();
    Object.defineProperty(exports, "every", { enumerable: true, get: function() {
      return every_1.every;
    } });
    var exhaust_1 = require_exhaust();
    Object.defineProperty(exports, "exhaust", { enumerable: true, get: function() {
      return exhaust_1.exhaust;
    } });
    var exhaustAll_1 = require_exhaustAll();
    Object.defineProperty(exports, "exhaustAll", { enumerable: true, get: function() {
      return exhaustAll_1.exhaustAll;
    } });
    var exhaustMap_1 = require_exhaustMap();
    Object.defineProperty(exports, "exhaustMap", { enumerable: true, get: function() {
      return exhaustMap_1.exhaustMap;
    } });
    var expand_1 = require_expand();
    Object.defineProperty(exports, "expand", { enumerable: true, get: function() {
      return expand_1.expand;
    } });
    var filter_1 = require_filter();
    Object.defineProperty(exports, "filter", { enumerable: true, get: function() {
      return filter_1.filter;
    } });
    var finalize_1 = require_finalize();
    Object.defineProperty(exports, "finalize", { enumerable: true, get: function() {
      return finalize_1.finalize;
    } });
    var find_1 = require_find();
    Object.defineProperty(exports, "find", { enumerable: true, get: function() {
      return find_1.find;
    } });
    var findIndex_1 = require_findIndex();
    Object.defineProperty(exports, "findIndex", { enumerable: true, get: function() {
      return findIndex_1.findIndex;
    } });
    var first_1 = require_first();
    Object.defineProperty(exports, "first", { enumerable: true, get: function() {
      return first_1.first;
    } });
    var groupBy_1 = require_groupBy();
    Object.defineProperty(exports, "groupBy", { enumerable: true, get: function() {
      return groupBy_1.groupBy;
    } });
    var ignoreElements_1 = require_ignoreElements();
    Object.defineProperty(exports, "ignoreElements", { enumerable: true, get: function() {
      return ignoreElements_1.ignoreElements;
    } });
    var isEmpty_1 = require_isEmpty();
    Object.defineProperty(exports, "isEmpty", { enumerable: true, get: function() {
      return isEmpty_1.isEmpty;
    } });
    var last_1 = require_last();
    Object.defineProperty(exports, "last", { enumerable: true, get: function() {
      return last_1.last;
    } });
    var map_1 = require_map();
    Object.defineProperty(exports, "map", { enumerable: true, get: function() {
      return map_1.map;
    } });
    var mapTo_1 = require_mapTo();
    Object.defineProperty(exports, "mapTo", { enumerable: true, get: function() {
      return mapTo_1.mapTo;
    } });
    var materialize_1 = require_materialize();
    Object.defineProperty(exports, "materialize", { enumerable: true, get: function() {
      return materialize_1.materialize;
    } });
    var max_1 = require_max();
    Object.defineProperty(exports, "max", { enumerable: true, get: function() {
      return max_1.max;
    } });
    var merge_1 = require_merge2();
    Object.defineProperty(exports, "merge", { enumerable: true, get: function() {
      return merge_1.merge;
    } });
    var mergeAll_1 = require_mergeAll();
    Object.defineProperty(exports, "mergeAll", { enumerable: true, get: function() {
      return mergeAll_1.mergeAll;
    } });
    var flatMap_1 = require_flatMap();
    Object.defineProperty(exports, "flatMap", { enumerable: true, get: function() {
      return flatMap_1.flatMap;
    } });
    var mergeMap_1 = require_mergeMap();
    Object.defineProperty(exports, "mergeMap", { enumerable: true, get: function() {
      return mergeMap_1.mergeMap;
    } });
    var mergeMapTo_1 = require_mergeMapTo();
    Object.defineProperty(exports, "mergeMapTo", { enumerable: true, get: function() {
      return mergeMapTo_1.mergeMapTo;
    } });
    var mergeScan_1 = require_mergeScan();
    Object.defineProperty(exports, "mergeScan", { enumerable: true, get: function() {
      return mergeScan_1.mergeScan;
    } });
    var mergeWith_1 = require_mergeWith();
    Object.defineProperty(exports, "mergeWith", { enumerable: true, get: function() {
      return mergeWith_1.mergeWith;
    } });
    var min_1 = require_min();
    Object.defineProperty(exports, "min", { enumerable: true, get: function() {
      return min_1.min;
    } });
    var multicast_1 = require_multicast();
    Object.defineProperty(exports, "multicast", { enumerable: true, get: function() {
      return multicast_1.multicast;
    } });
    var observeOn_1 = require_observeOn();
    Object.defineProperty(exports, "observeOn", { enumerable: true, get: function() {
      return observeOn_1.observeOn;
    } });
    var onErrorResumeNextWith_1 = require_onErrorResumeNextWith();
    Object.defineProperty(exports, "onErrorResumeNext", { enumerable: true, get: function() {
      return onErrorResumeNextWith_1.onErrorResumeNext;
    } });
    var pairwise_1 = require_pairwise();
    Object.defineProperty(exports, "pairwise", { enumerable: true, get: function() {
      return pairwise_1.pairwise;
    } });
    var partition_1 = require_partition2();
    Object.defineProperty(exports, "partition", { enumerable: true, get: function() {
      return partition_1.partition;
    } });
    var pluck_1 = require_pluck();
    Object.defineProperty(exports, "pluck", { enumerable: true, get: function() {
      return pluck_1.pluck;
    } });
    var publish_1 = require_publish();
    Object.defineProperty(exports, "publish", { enumerable: true, get: function() {
      return publish_1.publish;
    } });
    var publishBehavior_1 = require_publishBehavior();
    Object.defineProperty(exports, "publishBehavior", { enumerable: true, get: function() {
      return publishBehavior_1.publishBehavior;
    } });
    var publishLast_1 = require_publishLast();
    Object.defineProperty(exports, "publishLast", { enumerable: true, get: function() {
      return publishLast_1.publishLast;
    } });
    var publishReplay_1 = require_publishReplay();
    Object.defineProperty(exports, "publishReplay", { enumerable: true, get: function() {
      return publishReplay_1.publishReplay;
    } });
    var race_1 = require_race2();
    Object.defineProperty(exports, "race", { enumerable: true, get: function() {
      return race_1.race;
    } });
    var raceWith_1 = require_raceWith();
    Object.defineProperty(exports, "raceWith", { enumerable: true, get: function() {
      return raceWith_1.raceWith;
    } });
    var reduce_1 = require_reduce();
    Object.defineProperty(exports, "reduce", { enumerable: true, get: function() {
      return reduce_1.reduce;
    } });
    var repeat_1 = require_repeat();
    Object.defineProperty(exports, "repeat", { enumerable: true, get: function() {
      return repeat_1.repeat;
    } });
    var repeatWhen_1 = require_repeatWhen();
    Object.defineProperty(exports, "repeatWhen", { enumerable: true, get: function() {
      return repeatWhen_1.repeatWhen;
    } });
    var retry_1 = require_retry();
    Object.defineProperty(exports, "retry", { enumerable: true, get: function() {
      return retry_1.retry;
    } });
    var retryWhen_1 = require_retryWhen();
    Object.defineProperty(exports, "retryWhen", { enumerable: true, get: function() {
      return retryWhen_1.retryWhen;
    } });
    var refCount_1 = require_refCount();
    Object.defineProperty(exports, "refCount", { enumerable: true, get: function() {
      return refCount_1.refCount;
    } });
    var sample_1 = require_sample();
    Object.defineProperty(exports, "sample", { enumerable: true, get: function() {
      return sample_1.sample;
    } });
    var sampleTime_1 = require_sampleTime();
    Object.defineProperty(exports, "sampleTime", { enumerable: true, get: function() {
      return sampleTime_1.sampleTime;
    } });
    var scan_1 = require_scan();
    Object.defineProperty(exports, "scan", { enumerable: true, get: function() {
      return scan_1.scan;
    } });
    var sequenceEqual_1 = require_sequenceEqual();
    Object.defineProperty(exports, "sequenceEqual", { enumerable: true, get: function() {
      return sequenceEqual_1.sequenceEqual;
    } });
    var share_1 = require_share();
    Object.defineProperty(exports, "share", { enumerable: true, get: function() {
      return share_1.share;
    } });
    var shareReplay_1 = require_shareReplay();
    Object.defineProperty(exports, "shareReplay", { enumerable: true, get: function() {
      return shareReplay_1.shareReplay;
    } });
    var single_1 = require_single();
    Object.defineProperty(exports, "single", { enumerable: true, get: function() {
      return single_1.single;
    } });
    var skip_1 = require_skip();
    Object.defineProperty(exports, "skip", { enumerable: true, get: function() {
      return skip_1.skip;
    } });
    var skipLast_1 = require_skipLast();
    Object.defineProperty(exports, "skipLast", { enumerable: true, get: function() {
      return skipLast_1.skipLast;
    } });
    var skipUntil_1 = require_skipUntil();
    Object.defineProperty(exports, "skipUntil", { enumerable: true, get: function() {
      return skipUntil_1.skipUntil;
    } });
    var skipWhile_1 = require_skipWhile();
    Object.defineProperty(exports, "skipWhile", { enumerable: true, get: function() {
      return skipWhile_1.skipWhile;
    } });
    var startWith_1 = require_startWith();
    Object.defineProperty(exports, "startWith", { enumerable: true, get: function() {
      return startWith_1.startWith;
    } });
    var subscribeOn_1 = require_subscribeOn();
    Object.defineProperty(exports, "subscribeOn", { enumerable: true, get: function() {
      return subscribeOn_1.subscribeOn;
    } });
    var switchAll_1 = require_switchAll();
    Object.defineProperty(exports, "switchAll", { enumerable: true, get: function() {
      return switchAll_1.switchAll;
    } });
    var switchMap_1 = require_switchMap();
    Object.defineProperty(exports, "switchMap", { enumerable: true, get: function() {
      return switchMap_1.switchMap;
    } });
    var switchMapTo_1 = require_switchMapTo();
    Object.defineProperty(exports, "switchMapTo", { enumerable: true, get: function() {
      return switchMapTo_1.switchMapTo;
    } });
    var switchScan_1 = require_switchScan();
    Object.defineProperty(exports, "switchScan", { enumerable: true, get: function() {
      return switchScan_1.switchScan;
    } });
    var take_1 = require_take();
    Object.defineProperty(exports, "take", { enumerable: true, get: function() {
      return take_1.take;
    } });
    var takeLast_1 = require_takeLast();
    Object.defineProperty(exports, "takeLast", { enumerable: true, get: function() {
      return takeLast_1.takeLast;
    } });
    var takeUntil_1 = require_takeUntil();
    Object.defineProperty(exports, "takeUntil", { enumerable: true, get: function() {
      return takeUntil_1.takeUntil;
    } });
    var takeWhile_1 = require_takeWhile();
    Object.defineProperty(exports, "takeWhile", { enumerable: true, get: function() {
      return takeWhile_1.takeWhile;
    } });
    var tap_1 = require_tap();
    Object.defineProperty(exports, "tap", { enumerable: true, get: function() {
      return tap_1.tap;
    } });
    var throttle_1 = require_throttle();
    Object.defineProperty(exports, "throttle", { enumerable: true, get: function() {
      return throttle_1.throttle;
    } });
    var throttleTime_1 = require_throttleTime();
    Object.defineProperty(exports, "throttleTime", { enumerable: true, get: function() {
      return throttleTime_1.throttleTime;
    } });
    var throwIfEmpty_1 = require_throwIfEmpty();
    Object.defineProperty(exports, "throwIfEmpty", { enumerable: true, get: function() {
      return throwIfEmpty_1.throwIfEmpty;
    } });
    var timeInterval_1 = require_timeInterval();
    Object.defineProperty(exports, "timeInterval", { enumerable: true, get: function() {
      return timeInterval_1.timeInterval;
    } });
    var timeout_1 = require_timeout();
    Object.defineProperty(exports, "timeout", { enumerable: true, get: function() {
      return timeout_1.timeout;
    } });
    var timeoutWith_1 = require_timeoutWith();
    Object.defineProperty(exports, "timeoutWith", { enumerable: true, get: function() {
      return timeoutWith_1.timeoutWith;
    } });
    var timestamp_1 = require_timestamp();
    Object.defineProperty(exports, "timestamp", { enumerable: true, get: function() {
      return timestamp_1.timestamp;
    } });
    var toArray_1 = require_toArray();
    Object.defineProperty(exports, "toArray", { enumerable: true, get: function() {
      return toArray_1.toArray;
    } });
    var window_1 = require_window();
    Object.defineProperty(exports, "window", { enumerable: true, get: function() {
      return window_1.window;
    } });
    var windowCount_1 = require_windowCount();
    Object.defineProperty(exports, "windowCount", { enumerable: true, get: function() {
      return windowCount_1.windowCount;
    } });
    var windowTime_1 = require_windowTime();
    Object.defineProperty(exports, "windowTime", { enumerable: true, get: function() {
      return windowTime_1.windowTime;
    } });
    var windowToggle_1 = require_windowToggle();
    Object.defineProperty(exports, "windowToggle", { enumerable: true, get: function() {
      return windowToggle_1.windowToggle;
    } });
    var windowWhen_1 = require_windowWhen();
    Object.defineProperty(exports, "windowWhen", { enumerable: true, get: function() {
      return windowWhen_1.windowWhen;
    } });
    var withLatestFrom_1 = require_withLatestFrom();
    Object.defineProperty(exports, "withLatestFrom", { enumerable: true, get: function() {
      return withLatestFrom_1.withLatestFrom;
    } });
    var zip_1 = require_zip2();
    Object.defineProperty(exports, "zip", { enumerable: true, get: function() {
      return zip_1.zip;
    } });
    var zipAll_1 = require_zipAll();
    Object.defineProperty(exports, "zipAll", { enumerable: true, get: function() {
      return zipAll_1.zipAll;
    } });
    var zipWith_1 = require_zipWith();
    Object.defineProperty(exports, "zipWith", { enumerable: true, get: function() {
      return zipWith_1.zipWith;
    } });
  }
});

// node_modules/run-async/index.js
var require_run_async = __commonJS({
  "node_modules/run-async/index.js"(exports, module2) {
    "use strict";
    function isPromise(obj) {
      return !!obj && (typeof obj === "object" || typeof obj === "function") && typeof obj.then === "function";
    }
    var runAsync = module2.exports = function(func, cb) {
      cb = cb || function() {
      };
      return function() {
        var args = arguments;
        var promise = new Promise(function(resolve, reject) {
          var resolved = false;
          const wrappedResolve = function(value2) {
            if (resolved) {
              console.warn("Run-async promise already resolved.");
            }
            resolved = true;
            resolve(value2);
          };
          var rejected = false;
          const wrappedReject = function(value2) {
            if (rejected) {
              console.warn("Run-async promise already rejected.");
            }
            rejected = true;
            reject(value2);
          };
          var usingCallback = false;
          var callbackConflict = false;
          var contextEnded = false;
          var answer = func.apply({
            async: function() {
              if (contextEnded) {
                console.warn("Run-async async() called outside a valid run-async context, callback will be ignored.");
                return function() {
                };
              }
              if (callbackConflict) {
                console.warn("Run-async wrapped function (async) returned a promise.\nCalls to async() callback can have unexpected results.");
              }
              usingCallback = true;
              return function(err, value2) {
                if (err) {
                  wrappedReject(err);
                } else {
                  wrappedResolve(value2);
                }
              };
            }
          }, Array.prototype.slice.call(args));
          if (usingCallback) {
            if (isPromise(answer)) {
              console.warn("Run-async wrapped function (sync) returned a promise but async() callback must be executed to resolve.");
            }
          } else {
            if (isPromise(answer)) {
              callbackConflict = true;
              answer.then(wrappedResolve, wrappedReject);
            } else {
              wrappedResolve(answer);
            }
          }
          contextEnded = true;
        });
        promise.then(cb.bind(null, null), cb);
        return promise;
      };
    };
    runAsync.cb = function(func, cb) {
      return runAsync(function() {
        var args = Array.prototype.slice.call(arguments);
        if (args.length === func.length - 1) {
          args.push(this.async());
        }
        return func.apply(this, args);
      }, cb);
    };
  }
});

// node_modules/inquirer/lib/utils/utils.js
var require_utils = __commonJS({
  "node_modules/inquirer/lib/utils/utils.js"(exports) {
    "use strict";
    var { from, of } = require_cjs();
    var runAsync = require_run_async();
    exports.fetchAsyncQuestionProperty = function(question, prop, answers) {
      if (typeof question[prop] !== "function") {
        return of(question);
      }
      return from(
        runAsync(question[prop])(answers).then((value2) => {
          question[prop] = value2;
          return question;
        })
      );
    };
  }
});

// node_modules/inquirer/lib/ui/prompt.js
var require_prompt = __commonJS({
  "node_modules/inquirer/lib/ui/prompt.js"(exports, module2) {
    "use strict";
    var _ = {
      isPlainObject: require_isPlainObject(),
      get: require_get(),
      set: require_set()
    };
    var { defer, empty, from, of } = require_cjs();
    var { concatMap, filter, publish, reduce } = require_operators();
    var runAsync = require_run_async();
    var utils2 = require_utils();
    var Base = require_baseUI();
    var PromptUI = class extends Base {
      constructor(prompts, opt) {
        super(opt);
        this.prompts = prompts;
      }
      run(questions, answers) {
        if (_.isPlainObject(answers)) {
          this.answers = { ...answers };
        } else {
          this.answers = {};
        }
        if (_.isPlainObject(questions)) {
          questions = Object.values(questions).every(
            (v) => _.isPlainObject(v) && v.name === void 0
          ) ? Object.entries(questions).map(([name, question]) => ({ name, ...question })) : [questions];
        }
        const obs = Array.isArray(questions) ? from(questions) : questions;
        this.process = obs.pipe(
          concatMap(this.processQuestion.bind(this)),
          publish()
          // Creates a hot Observable. It prevents duplicating prompts.
        );
        this.process.connect();
        return this.process.pipe(
          reduce((answers2, answer) => {
            _.set(answers2, answer.name, answer.answer);
            return answers2;
          }, this.answers)
        ).toPromise(Promise).then(this.onCompletion.bind(this), this.onError.bind(this));
      }
      /**
       * Once all prompt are over
       */
      onCompletion() {
        this.close();
        return this.answers;
      }
      onError(error) {
        this.close();
        return Promise.reject(error);
      }
      processQuestion(question) {
        question = { ...question };
        return defer(() => {
          const obs = of(question);
          return obs.pipe(
            concatMap(this.setDefaultType.bind(this)),
            concatMap(this.filterIfRunnable.bind(this)),
            concatMap(
              () => utils2.fetchAsyncQuestionProperty(question, "message", this.answers)
            ),
            concatMap(
              () => utils2.fetchAsyncQuestionProperty(question, "default", this.answers)
            ),
            concatMap(
              () => utils2.fetchAsyncQuestionProperty(question, "choices", this.answers)
            ),
            concatMap(this.fetchAnswer.bind(this))
          );
        });
      }
      fetchAnswer(question) {
        const Prompt = this.prompts[question.type];
        this.activePrompt = new Prompt(question, this.rl, this.answers);
        return defer(
          () => from(this.activePrompt.run().then((answer) => ({ name: question.name, answer })))
        );
      }
      setDefaultType(question) {
        if (!this.prompts[question.type]) {
          question.type = "input";
        }
        return defer(() => of(question));
      }
      filterIfRunnable(question) {
        if (question.askAnswered !== true && _.get(this.answers, question.name) !== void 0) {
          return empty();
        }
        if (question.when === false) {
          return empty();
        }
        if (typeof question.when !== "function") {
          return of(question);
        }
        const { answers } = this;
        return defer(
          () => from(
            runAsync(question.when)(answers).then((shouldRun) => {
              if (shouldRun) {
                return question;
              }
            })
          ).pipe(filter((val) => val != null))
        );
      }
    };
    module2.exports = PromptUI;
  }
});

// node_modules/lodash/identity.js
var require_identity2 = __commonJS({
  "node_modules/lodash/identity.js"(exports, module2) {
    function identity(value2) {
      return value2;
    }
    module2.exports = identity;
  }
});

// node_modules/lodash/_apply.js
var require_apply = __commonJS({
  "node_modules/lodash/_apply.js"(exports, module2) {
    function apply(func, thisArg, args) {
      switch (args.length) {
        case 0:
          return func.call(thisArg);
        case 1:
          return func.call(thisArg, args[0]);
        case 2:
          return func.call(thisArg, args[0], args[1]);
        case 3:
          return func.call(thisArg, args[0], args[1], args[2]);
      }
      return func.apply(thisArg, args);
    }
    module2.exports = apply;
  }
});

// node_modules/lodash/_overRest.js
var require_overRest = __commonJS({
  "node_modules/lodash/_overRest.js"(exports, module2) {
    var apply = require_apply();
    var nativeMax = Math.max;
    function overRest(func, start, transform) {
      start = nativeMax(start === void 0 ? func.length - 1 : start, 0);
      return function() {
        var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array(length);
        while (++index < length) {
          array[index] = args[start + index];
        }
        index = -1;
        var otherArgs = Array(start + 1);
        while (++index < start) {
          otherArgs[index] = args[index];
        }
        otherArgs[start] = transform(array);
        return apply(func, this, otherArgs);
      };
    }
    module2.exports = overRest;
  }
});

// node_modules/lodash/constant.js
var require_constant = __commonJS({
  "node_modules/lodash/constant.js"(exports, module2) {
    function constant(value2) {
      return function() {
        return value2;
      };
    }
    module2.exports = constant;
  }
});

// node_modules/lodash/_baseSetToString.js
var require_baseSetToString = __commonJS({
  "node_modules/lodash/_baseSetToString.js"(exports, module2) {
    var constant = require_constant();
    var defineProperty = require_defineProperty();
    var identity = require_identity2();
    var baseSetToString = !defineProperty ? identity : function(func, string) {
      return defineProperty(func, "toString", {
        "configurable": true,
        "enumerable": false,
        "value": constant(string),
        "writable": true
      });
    };
    module2.exports = baseSetToString;
  }
});

// node_modules/lodash/_shortOut.js
var require_shortOut = __commonJS({
  "node_modules/lodash/_shortOut.js"(exports, module2) {
    var HOT_COUNT = 800;
    var HOT_SPAN = 16;
    var nativeNow = Date.now;
    function shortOut(func) {
      var count = 0, lastCalled = 0;
      return function() {
        var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
        lastCalled = stamp;
        if (remaining > 0) {
          if (++count >= HOT_COUNT) {
            return arguments[0];
          }
        } else {
          count = 0;
        }
        return func.apply(void 0, arguments);
      };
    }
    module2.exports = shortOut;
  }
});

// node_modules/lodash/_setToString.js
var require_setToString = __commonJS({
  "node_modules/lodash/_setToString.js"(exports, module2) {
    var baseSetToString = require_baseSetToString();
    var shortOut = require_shortOut();
    var setToString = shortOut(baseSetToString);
    module2.exports = setToString;
  }
});

// node_modules/lodash/_baseRest.js
var require_baseRest = __commonJS({
  "node_modules/lodash/_baseRest.js"(exports, module2) {
    var identity = require_identity2();
    var overRest = require_overRest();
    var setToString = require_setToString();
    function baseRest(func, start) {
      return setToString(overRest(func, start, identity), func + "");
    }
    module2.exports = baseRest;
  }
});

// node_modules/lodash/isLength.js
var require_isLength = __commonJS({
  "node_modules/lodash/isLength.js"(exports, module2) {
    var MAX_SAFE_INTEGER = 9007199254740991;
    function isLength(value2) {
      return typeof value2 == "number" && value2 > -1 && value2 % 1 == 0 && value2 <= MAX_SAFE_INTEGER;
    }
    module2.exports = isLength;
  }
});

// node_modules/lodash/isArrayLike.js
var require_isArrayLike2 = __commonJS({
  "node_modules/lodash/isArrayLike.js"(exports, module2) {
    var isFunction = require_isFunction();
    var isLength = require_isLength();
    function isArrayLike(value2) {
      return value2 != null && isLength(value2.length) && !isFunction(value2);
    }
    module2.exports = isArrayLike;
  }
});

// node_modules/lodash/_isIterateeCall.js
var require_isIterateeCall = __commonJS({
  "node_modules/lodash/_isIterateeCall.js"(exports, module2) {
    var eq = require_eq();
    var isArrayLike = require_isArrayLike2();
    var isIndex = require_isIndex();
    var isObject = require_isObject();
    function isIterateeCall(value2, index, object) {
      if (!isObject(object)) {
        return false;
      }
      var type = typeof index;
      if (type == "number" ? isArrayLike(object) && isIndex(index, object.length) : type == "string" && index in object) {
        return eq(object[index], value2);
      }
      return false;
    }
    module2.exports = isIterateeCall;
  }
});

// node_modules/lodash/_baseTimes.js
var require_baseTimes = __commonJS({
  "node_modules/lodash/_baseTimes.js"(exports, module2) {
    function baseTimes(n, iteratee) {
      var index = -1, result = Array(n);
      while (++index < n) {
        result[index] = iteratee(index);
      }
      return result;
    }
    module2.exports = baseTimes;
  }
});

// node_modules/lodash/_baseIsArguments.js
var require_baseIsArguments = __commonJS({
  "node_modules/lodash/_baseIsArguments.js"(exports, module2) {
    var baseGetTag = require_baseGetTag();
    var isObjectLike = require_isObjectLike();
    var argsTag = "[object Arguments]";
    function baseIsArguments(value2) {
      return isObjectLike(value2) && baseGetTag(value2) == argsTag;
    }
    module2.exports = baseIsArguments;
  }
});

// node_modules/lodash/isArguments.js
var require_isArguments = __commonJS({
  "node_modules/lodash/isArguments.js"(exports, module2) {
    var baseIsArguments = require_baseIsArguments();
    var isObjectLike = require_isObjectLike();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var propertyIsEnumerable = objectProto.propertyIsEnumerable;
    var isArguments = baseIsArguments(function() {
      return arguments;
    }()) ? baseIsArguments : function(value2) {
      return isObjectLike(value2) && hasOwnProperty.call(value2, "callee") && !propertyIsEnumerable.call(value2, "callee");
    };
    module2.exports = isArguments;
  }
});

// node_modules/lodash/stubFalse.js
var require_stubFalse = __commonJS({
  "node_modules/lodash/stubFalse.js"(exports, module2) {
    function stubFalse() {
      return false;
    }
    module2.exports = stubFalse;
  }
});

// node_modules/lodash/isBuffer.js
var require_isBuffer = __commonJS({
  "node_modules/lodash/isBuffer.js"(exports, module2) {
    var root2 = require_root();
    var stubFalse = require_stubFalse();
    var freeExports = typeof exports == "object" && exports && !exports.nodeType && exports;
    var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var Buffer2 = moduleExports ? root2.Buffer : void 0;
    var nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0;
    var isBuffer = nativeIsBuffer || stubFalse;
    module2.exports = isBuffer;
  }
});

// node_modules/lodash/_baseIsTypedArray.js
var require_baseIsTypedArray = __commonJS({
  "node_modules/lodash/_baseIsTypedArray.js"(exports, module2) {
    var baseGetTag = require_baseGetTag();
    var isLength = require_isLength();
    var isObjectLike = require_isObjectLike();
    var argsTag = "[object Arguments]";
    var arrayTag = "[object Array]";
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var errorTag = "[object Error]";
    var funcTag = "[object Function]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var objectTag = "[object Object]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var weakMapTag = "[object WeakMap]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var float32Tag = "[object Float32Array]";
    var float64Tag = "[object Float64Array]";
    var int8Tag = "[object Int8Array]";
    var int16Tag = "[object Int16Array]";
    var int32Tag = "[object Int32Array]";
    var uint8Tag = "[object Uint8Array]";
    var uint8ClampedTag = "[object Uint8ClampedArray]";
    var uint16Tag = "[object Uint16Array]";
    var uint32Tag = "[object Uint32Array]";
    var typedArrayTags = {};
    typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
    typedArrayTags[argsTag] = typedArrayTags[arrayTag] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag] = typedArrayTags[mapTag] = typedArrayTags[numberTag] = typedArrayTags[objectTag] = typedArrayTags[regexpTag] = typedArrayTags[setTag] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;
    function baseIsTypedArray(value2) {
      return isObjectLike(value2) && isLength(value2.length) && !!typedArrayTags[baseGetTag(value2)];
    }
    module2.exports = baseIsTypedArray;
  }
});

// node_modules/lodash/_baseUnary.js
var require_baseUnary = __commonJS({
  "node_modules/lodash/_baseUnary.js"(exports, module2) {
    function baseUnary(func) {
      return function(value2) {
        return func(value2);
      };
    }
    module2.exports = baseUnary;
  }
});

// node_modules/lodash/_nodeUtil.js
var require_nodeUtil = __commonJS({
  "node_modules/lodash/_nodeUtil.js"(exports, module2) {
    var freeGlobal = require_freeGlobal();
    var freeExports = typeof exports == "object" && exports && !exports.nodeType && exports;
    var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var freeProcess = moduleExports && freeGlobal.process;
    var nodeUtil = function() {
      try {
        var types = freeModule && freeModule.require && freeModule.require("util").types;
        if (types) {
          return types;
        }
        return freeProcess && freeProcess.binding && freeProcess.binding("util");
      } catch (e) {
      }
    }();
    module2.exports = nodeUtil;
  }
});

// node_modules/lodash/isTypedArray.js
var require_isTypedArray = __commonJS({
  "node_modules/lodash/isTypedArray.js"(exports, module2) {
    var baseIsTypedArray = require_baseIsTypedArray();
    var baseUnary = require_baseUnary();
    var nodeUtil = require_nodeUtil();
    var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
    var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
    module2.exports = isTypedArray;
  }
});

// node_modules/lodash/_arrayLikeKeys.js
var require_arrayLikeKeys = __commonJS({
  "node_modules/lodash/_arrayLikeKeys.js"(exports, module2) {
    var baseTimes = require_baseTimes();
    var isArguments = require_isArguments();
    var isArray2 = require_isArray();
    var isBuffer = require_isBuffer();
    var isIndex = require_isIndex();
    var isTypedArray = require_isTypedArray();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function arrayLikeKeys(value2, inherited) {
      var isArr = isArray2(value2), isArg = !isArr && isArguments(value2), isBuff = !isArr && !isArg && isBuffer(value2), isType = !isArr && !isArg && !isBuff && isTypedArray(value2), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value2.length, String) : [], length = result.length;
      for (var key in value2) {
        if ((inherited || hasOwnProperty.call(value2, key)) && !(skipIndexes && // Safari 9 has enumerable `arguments.length` in strict mode.
        (key == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
        isBuff && (key == "offset" || key == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
        isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || // Skip index properties.
        isIndex(key, length)))) {
          result.push(key);
        }
      }
      return result;
    }
    module2.exports = arrayLikeKeys;
  }
});

// node_modules/lodash/_isPrototype.js
var require_isPrototype = __commonJS({
  "node_modules/lodash/_isPrototype.js"(exports, module2) {
    var objectProto = Object.prototype;
    function isPrototype(value2) {
      var Ctor = value2 && value2.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto;
      return value2 === proto;
    }
    module2.exports = isPrototype;
  }
});

// node_modules/lodash/_nativeKeysIn.js
var require_nativeKeysIn = __commonJS({
  "node_modules/lodash/_nativeKeysIn.js"(exports, module2) {
    function nativeKeysIn(object) {
      var result = [];
      if (object != null) {
        for (var key in Object(object)) {
          result.push(key);
        }
      }
      return result;
    }
    module2.exports = nativeKeysIn;
  }
});

// node_modules/lodash/_baseKeysIn.js
var require_baseKeysIn = __commonJS({
  "node_modules/lodash/_baseKeysIn.js"(exports, module2) {
    var isObject = require_isObject();
    var isPrototype = require_isPrototype();
    var nativeKeysIn = require_nativeKeysIn();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function baseKeysIn(object) {
      if (!isObject(object)) {
        return nativeKeysIn(object);
      }
      var isProto = isPrototype(object), result = [];
      for (var key in object) {
        if (!(key == "constructor" && (isProto || !hasOwnProperty.call(object, key)))) {
          result.push(key);
        }
      }
      return result;
    }
    module2.exports = baseKeysIn;
  }
});

// node_modules/lodash/keysIn.js
var require_keysIn = __commonJS({
  "node_modules/lodash/keysIn.js"(exports, module2) {
    var arrayLikeKeys = require_arrayLikeKeys();
    var baseKeysIn = require_baseKeysIn();
    var isArrayLike = require_isArrayLike2();
    function keysIn(object) {
      return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
    }
    module2.exports = keysIn;
  }
});

// node_modules/lodash/defaults.js
var require_defaults2 = __commonJS({
  "node_modules/lodash/defaults.js"(exports, module2) {
    var baseRest = require_baseRest();
    var eq = require_eq();
    var isIterateeCall = require_isIterateeCall();
    var keysIn = require_keysIn();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var defaults = baseRest(function(object, sources) {
      object = Object(object);
      var index = -1;
      var length = sources.length;
      var guard = length > 2 ? sources[2] : void 0;
      if (guard && isIterateeCall(sources[0], sources[1], guard)) {
        length = 1;
      }
      while (++index < length) {
        var source = sources[index];
        var props = keysIn(source);
        var propsIndex = -1;
        var propsLength = props.length;
        while (++propsIndex < propsLength) {
          var key = props[propsIndex];
          var value2 = object[key];
          if (value2 === void 0 || eq(value2, objectProto[key]) && !hasOwnProperty.call(object, key)) {
            object[key] = source[key];
          }
        }
      }
      return object;
    });
    module2.exports = defaults;
  }
});

// node_modules/lodash/_stackClear.js
var require_stackClear = __commonJS({
  "node_modules/lodash/_stackClear.js"(exports, module2) {
    var ListCache = require_ListCache();
    function stackClear() {
      this.__data__ = new ListCache();
      this.size = 0;
    }
    module2.exports = stackClear;
  }
});

// node_modules/lodash/_stackDelete.js
var require_stackDelete = __commonJS({
  "node_modules/lodash/_stackDelete.js"(exports, module2) {
    function stackDelete(key) {
      var data = this.__data__, result = data["delete"](key);
      this.size = data.size;
      return result;
    }
    module2.exports = stackDelete;
  }
});

// node_modules/lodash/_stackGet.js
var require_stackGet = __commonJS({
  "node_modules/lodash/_stackGet.js"(exports, module2) {
    function stackGet(key) {
      return this.__data__.get(key);
    }
    module2.exports = stackGet;
  }
});

// node_modules/lodash/_stackHas.js
var require_stackHas = __commonJS({
  "node_modules/lodash/_stackHas.js"(exports, module2) {
    function stackHas(key) {
      return this.__data__.has(key);
    }
    module2.exports = stackHas;
  }
});

// node_modules/lodash/_stackSet.js
var require_stackSet = __commonJS({
  "node_modules/lodash/_stackSet.js"(exports, module2) {
    var ListCache = require_ListCache();
    var Map2 = require_Map();
    var MapCache = require_MapCache();
    var LARGE_ARRAY_SIZE = 200;
    function stackSet(key, value2) {
      var data = this.__data__;
      if (data instanceof ListCache) {
        var pairs = data.__data__;
        if (!Map2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
          pairs.push([key, value2]);
          this.size = ++data.size;
          return this;
        }
        data = this.__data__ = new MapCache(pairs);
      }
      data.set(key, value2);
      this.size = data.size;
      return this;
    }
    module2.exports = stackSet;
  }
});

// node_modules/lodash/_Stack.js
var require_Stack = __commonJS({
  "node_modules/lodash/_Stack.js"(exports, module2) {
    var ListCache = require_ListCache();
    var stackClear = require_stackClear();
    var stackDelete = require_stackDelete();
    var stackGet = require_stackGet();
    var stackHas = require_stackHas();
    var stackSet = require_stackSet();
    function Stack(entries) {
      var data = this.__data__ = new ListCache(entries);
      this.size = data.size;
    }
    Stack.prototype.clear = stackClear;
    Stack.prototype["delete"] = stackDelete;
    Stack.prototype.get = stackGet;
    Stack.prototype.has = stackHas;
    Stack.prototype.set = stackSet;
    module2.exports = Stack;
  }
});

// node_modules/lodash/_arrayEach.js
var require_arrayEach = __commonJS({
  "node_modules/lodash/_arrayEach.js"(exports, module2) {
    function arrayEach(array, iteratee) {
      var index = -1, length = array == null ? 0 : array.length;
      while (++index < length) {
        if (iteratee(array[index], index, array) === false) {
          break;
        }
      }
      return array;
    }
    module2.exports = arrayEach;
  }
});

// node_modules/lodash/_copyObject.js
var require_copyObject = __commonJS({
  "node_modules/lodash/_copyObject.js"(exports, module2) {
    var assignValue = require_assignValue();
    var baseAssignValue = require_baseAssignValue();
    function copyObject(source, props, object, customizer) {
      var isNew = !object;
      object || (object = {});
      var index = -1, length = props.length;
      while (++index < length) {
        var key = props[index];
        var newValue = customizer ? customizer(object[key], source[key], key, object, source) : void 0;
        if (newValue === void 0) {
          newValue = source[key];
        }
        if (isNew) {
          baseAssignValue(object, key, newValue);
        } else {
          assignValue(object, key, newValue);
        }
      }
      return object;
    }
    module2.exports = copyObject;
  }
});

// node_modules/lodash/_nativeKeys.js
var require_nativeKeys = __commonJS({
  "node_modules/lodash/_nativeKeys.js"(exports, module2) {
    var overArg = require_overArg();
    var nativeKeys = overArg(Object.keys, Object);
    module2.exports = nativeKeys;
  }
});

// node_modules/lodash/_baseKeys.js
var require_baseKeys = __commonJS({
  "node_modules/lodash/_baseKeys.js"(exports, module2) {
    var isPrototype = require_isPrototype();
    var nativeKeys = require_nativeKeys();
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function baseKeys(object) {
      if (!isPrototype(object)) {
        return nativeKeys(object);
      }
      var result = [];
      for (var key in Object(object)) {
        if (hasOwnProperty.call(object, key) && key != "constructor") {
          result.push(key);
        }
      }
      return result;
    }
    module2.exports = baseKeys;
  }
});

// node_modules/lodash/keys.js
var require_keys = __commonJS({
  "node_modules/lodash/keys.js"(exports, module2) {
    var arrayLikeKeys = require_arrayLikeKeys();
    var baseKeys = require_baseKeys();
    var isArrayLike = require_isArrayLike2();
    function keys3(object) {
      return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
    }
    module2.exports = keys3;
  }
});

// node_modules/lodash/_baseAssign.js
var require_baseAssign = __commonJS({
  "node_modules/lodash/_baseAssign.js"(exports, module2) {
    var copyObject = require_copyObject();
    var keys3 = require_keys();
    function baseAssign(object, source) {
      return object && copyObject(source, keys3(source), object);
    }
    module2.exports = baseAssign;
  }
});

// node_modules/lodash/_baseAssignIn.js
var require_baseAssignIn = __commonJS({
  "node_modules/lodash/_baseAssignIn.js"(exports, module2) {
    var copyObject = require_copyObject();
    var keysIn = require_keysIn();
    function baseAssignIn(object, source) {
      return object && copyObject(source, keysIn(source), object);
    }
    module2.exports = baseAssignIn;
  }
});

// node_modules/lodash/_cloneBuffer.js
var require_cloneBuffer = __commonJS({
  "node_modules/lodash/_cloneBuffer.js"(exports, module2) {
    var root2 = require_root();
    var freeExports = typeof exports == "object" && exports && !exports.nodeType && exports;
    var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var Buffer2 = moduleExports ? root2.Buffer : void 0;
    var allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : void 0;
    function cloneBuffer(buffer, isDeep) {
      if (isDeep) {
        return buffer.slice();
      }
      var length = buffer.length, result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
      buffer.copy(result);
      return result;
    }
    module2.exports = cloneBuffer;
  }
});

// node_modules/lodash/_copyArray.js
var require_copyArray = __commonJS({
  "node_modules/lodash/_copyArray.js"(exports, module2) {
    function copyArray(source, array) {
      var index = -1, length = source.length;
      array || (array = Array(length));
      while (++index < length) {
        array[index] = source[index];
      }
      return array;
    }
    module2.exports = copyArray;
  }
});

// node_modules/lodash/_arrayFilter.js
var require_arrayFilter = __commonJS({
  "node_modules/lodash/_arrayFilter.js"(exports, module2) {
    function arrayFilter(array, predicate) {
      var index = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
      while (++index < length) {
        var value2 = array[index];
        if (predicate(value2, index, array)) {
          result[resIndex++] = value2;
        }
      }
      return result;
    }
    module2.exports = arrayFilter;
  }
});

// node_modules/lodash/stubArray.js
var require_stubArray = __commonJS({
  "node_modules/lodash/stubArray.js"(exports, module2) {
    function stubArray() {
      return [];
    }
    module2.exports = stubArray;
  }
});

// node_modules/lodash/_getSymbols.js
var require_getSymbols = __commonJS({
  "node_modules/lodash/_getSymbols.js"(exports, module2) {
    var arrayFilter = require_arrayFilter();
    var stubArray = require_stubArray();
    var objectProto = Object.prototype;
    var propertyIsEnumerable = objectProto.propertyIsEnumerable;
    var nativeGetSymbols = Object.getOwnPropertySymbols;
    var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
      if (object == null) {
        return [];
      }
      object = Object(object);
      return arrayFilter(nativeGetSymbols(object), function(symbol) {
        return propertyIsEnumerable.call(object, symbol);
      });
    };
    module2.exports = getSymbols;
  }
});

// node_modules/lodash/_copySymbols.js
var require_copySymbols = __commonJS({
  "node_modules/lodash/_copySymbols.js"(exports, module2) {
    var copyObject = require_copyObject();
    var getSymbols = require_getSymbols();
    function copySymbols(source, object) {
      return copyObject(source, getSymbols(source), object);
    }
    module2.exports = copySymbols;
  }
});

// node_modules/lodash/_arrayPush.js
var require_arrayPush = __commonJS({
  "node_modules/lodash/_arrayPush.js"(exports, module2) {
    function arrayPush(array, values2) {
      var index = -1, length = values2.length, offset = array.length;
      while (++index < length) {
        array[offset + index] = values2[index];
      }
      return array;
    }
    module2.exports = arrayPush;
  }
});

// node_modules/lodash/_getSymbolsIn.js
var require_getSymbolsIn = __commonJS({
  "node_modules/lodash/_getSymbolsIn.js"(exports, module2) {
    var arrayPush = require_arrayPush();
    var getPrototype = require_getPrototype();
    var getSymbols = require_getSymbols();
    var stubArray = require_stubArray();
    var nativeGetSymbols = Object.getOwnPropertySymbols;
    var getSymbolsIn = !nativeGetSymbols ? stubArray : function(object) {
      var result = [];
      while (object) {
        arrayPush(result, getSymbols(object));
        object = getPrototype(object);
      }
      return result;
    };
    module2.exports = getSymbolsIn;
  }
});

// node_modules/lodash/_copySymbolsIn.js
var require_copySymbolsIn = __commonJS({
  "node_modules/lodash/_copySymbolsIn.js"(exports, module2) {
    var copyObject = require_copyObject();
    var getSymbolsIn = require_getSymbolsIn();
    function copySymbolsIn(source, object) {
      return copyObject(source, getSymbolsIn(source), object);
    }
    module2.exports = copySymbolsIn;
  }
});

// node_modules/lodash/_baseGetAllKeys.js
var require_baseGetAllKeys = __commonJS({
  "node_modules/lodash/_baseGetAllKeys.js"(exports, module2) {
    var arrayPush = require_arrayPush();
    var isArray2 = require_isArray();
    function baseGetAllKeys(object, keysFunc, symbolsFunc) {
      var result = keysFunc(object);
      return isArray2(object) ? result : arrayPush(result, symbolsFunc(object));
    }
    module2.exports = baseGetAllKeys;
  }
});

// node_modules/lodash/_getAllKeys.js
var require_getAllKeys = __commonJS({
  "node_modules/lodash/_getAllKeys.js"(exports, module2) {
    var baseGetAllKeys = require_baseGetAllKeys();
    var getSymbols = require_getSymbols();
    var keys3 = require_keys();
    function getAllKeys(object) {
      return baseGetAllKeys(object, keys3, getSymbols);
    }
    module2.exports = getAllKeys;
  }
});

// node_modules/lodash/_getAllKeysIn.js
var require_getAllKeysIn = __commonJS({
  "node_modules/lodash/_getAllKeysIn.js"(exports, module2) {
    var baseGetAllKeys = require_baseGetAllKeys();
    var getSymbolsIn = require_getSymbolsIn();
    var keysIn = require_keysIn();
    function getAllKeysIn(object) {
      return baseGetAllKeys(object, keysIn, getSymbolsIn);
    }
    module2.exports = getAllKeysIn;
  }
});

// node_modules/lodash/_DataView.js
var require_DataView = __commonJS({
  "node_modules/lodash/_DataView.js"(exports, module2) {
    var getNative = require_getNative();
    var root2 = require_root();
    var DataView2 = getNative(root2, "DataView");
    module2.exports = DataView2;
  }
});

// node_modules/lodash/_Promise.js
var require_Promise = __commonJS({
  "node_modules/lodash/_Promise.js"(exports, module2) {
    var getNative = require_getNative();
    var root2 = require_root();
    var Promise2 = getNative(root2, "Promise");
    module2.exports = Promise2;
  }
});

// node_modules/lodash/_Set.js
var require_Set = __commonJS({
  "node_modules/lodash/_Set.js"(exports, module2) {
    var getNative = require_getNative();
    var root2 = require_root();
    var Set2 = getNative(root2, "Set");
    module2.exports = Set2;
  }
});

// node_modules/lodash/_WeakMap.js
var require_WeakMap = __commonJS({
  "node_modules/lodash/_WeakMap.js"(exports, module2) {
    var getNative = require_getNative();
    var root2 = require_root();
    var WeakMap2 = getNative(root2, "WeakMap");
    module2.exports = WeakMap2;
  }
});

// node_modules/lodash/_getTag.js
var require_getTag = __commonJS({
  "node_modules/lodash/_getTag.js"(exports, module2) {
    var DataView2 = require_DataView();
    var Map2 = require_Map();
    var Promise2 = require_Promise();
    var Set2 = require_Set();
    var WeakMap2 = require_WeakMap();
    var baseGetTag = require_baseGetTag();
    var toSource = require_toSource();
    var mapTag = "[object Map]";
    var objectTag = "[object Object]";
    var promiseTag = "[object Promise]";
    var setTag = "[object Set]";
    var weakMapTag = "[object WeakMap]";
    var dataViewTag = "[object DataView]";
    var dataViewCtorString = toSource(DataView2);
    var mapCtorString = toSource(Map2);
    var promiseCtorString = toSource(Promise2);
    var setCtorString = toSource(Set2);
    var weakMapCtorString = toSource(WeakMap2);
    var getTag = baseGetTag;
    if (DataView2 && getTag(new DataView2(new ArrayBuffer(1))) != dataViewTag || Map2 && getTag(new Map2()) != mapTag || Promise2 && getTag(Promise2.resolve()) != promiseTag || Set2 && getTag(new Set2()) != setTag || WeakMap2 && getTag(new WeakMap2()) != weakMapTag) {
      getTag = function(value2) {
        var result = baseGetTag(value2), Ctor = result == objectTag ? value2.constructor : void 0, ctorString = Ctor ? toSource(Ctor) : "";
        if (ctorString) {
          switch (ctorString) {
            case dataViewCtorString:
              return dataViewTag;
            case mapCtorString:
              return mapTag;
            case promiseCtorString:
              return promiseTag;
            case setCtorString:
              return setTag;
            case weakMapCtorString:
              return weakMapTag;
          }
        }
        return result;
      };
    }
    module2.exports = getTag;
  }
});

// node_modules/lodash/_initCloneArray.js
var require_initCloneArray = __commonJS({
  "node_modules/lodash/_initCloneArray.js"(exports, module2) {
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function initCloneArray(array) {
      var length = array.length, result = new array.constructor(length);
      if (length && typeof array[0] == "string" && hasOwnProperty.call(array, "index")) {
        result.index = array.index;
        result.input = array.input;
      }
      return result;
    }
    module2.exports = initCloneArray;
  }
});

// node_modules/lodash/_Uint8Array.js
var require_Uint8Array = __commonJS({
  "node_modules/lodash/_Uint8Array.js"(exports, module2) {
    var root2 = require_root();
    var Uint8Array2 = root2.Uint8Array;
    module2.exports = Uint8Array2;
  }
});

// node_modules/lodash/_cloneArrayBuffer.js
var require_cloneArrayBuffer = __commonJS({
  "node_modules/lodash/_cloneArrayBuffer.js"(exports, module2) {
    var Uint8Array2 = require_Uint8Array();
    function cloneArrayBuffer(arrayBuffer) {
      var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
      new Uint8Array2(result).set(new Uint8Array2(arrayBuffer));
      return result;
    }
    module2.exports = cloneArrayBuffer;
  }
});

// node_modules/lodash/_cloneDataView.js
var require_cloneDataView = __commonJS({
  "node_modules/lodash/_cloneDataView.js"(exports, module2) {
    var cloneArrayBuffer = require_cloneArrayBuffer();
    function cloneDataView(dataView, isDeep) {
      var buffer = isDeep ? cloneArrayBuffer(dataView.buffer) : dataView.buffer;
      return new dataView.constructor(buffer, dataView.byteOffset, dataView.byteLength);
    }
    module2.exports = cloneDataView;
  }
});

// node_modules/lodash/_cloneRegExp.js
var require_cloneRegExp = __commonJS({
  "node_modules/lodash/_cloneRegExp.js"(exports, module2) {
    var reFlags = /\w*$/;
    function cloneRegExp(regexp) {
      var result = new regexp.constructor(regexp.source, reFlags.exec(regexp));
      result.lastIndex = regexp.lastIndex;
      return result;
    }
    module2.exports = cloneRegExp;
  }
});

// node_modules/lodash/_cloneSymbol.js
var require_cloneSymbol = __commonJS({
  "node_modules/lodash/_cloneSymbol.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var symbolProto = Symbol2 ? Symbol2.prototype : void 0;
    var symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
    function cloneSymbol(symbol) {
      return symbolValueOf ? Object(symbolValueOf.call(symbol)) : {};
    }
    module2.exports = cloneSymbol;
  }
});

// node_modules/lodash/_cloneTypedArray.js
var require_cloneTypedArray = __commonJS({
  "node_modules/lodash/_cloneTypedArray.js"(exports, module2) {
    var cloneArrayBuffer = require_cloneArrayBuffer();
    function cloneTypedArray(typedArray, isDeep) {
      var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
      return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
    }
    module2.exports = cloneTypedArray;
  }
});

// node_modules/lodash/_initCloneByTag.js
var require_initCloneByTag = __commonJS({
  "node_modules/lodash/_initCloneByTag.js"(exports, module2) {
    var cloneArrayBuffer = require_cloneArrayBuffer();
    var cloneDataView = require_cloneDataView();
    var cloneRegExp = require_cloneRegExp();
    var cloneSymbol = require_cloneSymbol();
    var cloneTypedArray = require_cloneTypedArray();
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var symbolTag = "[object Symbol]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var float32Tag = "[object Float32Array]";
    var float64Tag = "[object Float64Array]";
    var int8Tag = "[object Int8Array]";
    var int16Tag = "[object Int16Array]";
    var int32Tag = "[object Int32Array]";
    var uint8Tag = "[object Uint8Array]";
    var uint8ClampedTag = "[object Uint8ClampedArray]";
    var uint16Tag = "[object Uint16Array]";
    var uint32Tag = "[object Uint32Array]";
    function initCloneByTag(object, tag, isDeep) {
      var Ctor = object.constructor;
      switch (tag) {
        case arrayBufferTag:
          return cloneArrayBuffer(object);
        case boolTag:
        case dateTag:
          return new Ctor(+object);
        case dataViewTag:
          return cloneDataView(object, isDeep);
        case float32Tag:
        case float64Tag:
        case int8Tag:
        case int16Tag:
        case int32Tag:
        case uint8Tag:
        case uint8ClampedTag:
        case uint16Tag:
        case uint32Tag:
          return cloneTypedArray(object, isDeep);
        case mapTag:
          return new Ctor();
        case numberTag:
        case stringTag:
          return new Ctor(object);
        case regexpTag:
          return cloneRegExp(object);
        case setTag:
          return new Ctor();
        case symbolTag:
          return cloneSymbol(object);
      }
    }
    module2.exports = initCloneByTag;
  }
});

// node_modules/lodash/_baseCreate.js
var require_baseCreate = __commonJS({
  "node_modules/lodash/_baseCreate.js"(exports, module2) {
    var isObject = require_isObject();
    var objectCreate = Object.create;
    var baseCreate = function() {
      function object() {
      }
      return function(proto) {
        if (!isObject(proto)) {
          return {};
        }
        if (objectCreate) {
          return objectCreate(proto);
        }
        object.prototype = proto;
        var result = new object();
        object.prototype = void 0;
        return result;
      };
    }();
    module2.exports = baseCreate;
  }
});

// node_modules/lodash/_initCloneObject.js
var require_initCloneObject = __commonJS({
  "node_modules/lodash/_initCloneObject.js"(exports, module2) {
    var baseCreate = require_baseCreate();
    var getPrototype = require_getPrototype();
    var isPrototype = require_isPrototype();
    function initCloneObject(object) {
      return typeof object.constructor == "function" && !isPrototype(object) ? baseCreate(getPrototype(object)) : {};
    }
    module2.exports = initCloneObject;
  }
});

// node_modules/lodash/_baseIsMap.js
var require_baseIsMap = __commonJS({
  "node_modules/lodash/_baseIsMap.js"(exports, module2) {
    var getTag = require_getTag();
    var isObjectLike = require_isObjectLike();
    var mapTag = "[object Map]";
    function baseIsMap(value2) {
      return isObjectLike(value2) && getTag(value2) == mapTag;
    }
    module2.exports = baseIsMap;
  }
});

// node_modules/lodash/isMap.js
var require_isMap = __commonJS({
  "node_modules/lodash/isMap.js"(exports, module2) {
    var baseIsMap = require_baseIsMap();
    var baseUnary = require_baseUnary();
    var nodeUtil = require_nodeUtil();
    var nodeIsMap = nodeUtil && nodeUtil.isMap;
    var isMap = nodeIsMap ? baseUnary(nodeIsMap) : baseIsMap;
    module2.exports = isMap;
  }
});

// node_modules/lodash/_baseIsSet.js
var require_baseIsSet = __commonJS({
  "node_modules/lodash/_baseIsSet.js"(exports, module2) {
    var getTag = require_getTag();
    var isObjectLike = require_isObjectLike();
    var setTag = "[object Set]";
    function baseIsSet(value2) {
      return isObjectLike(value2) && getTag(value2) == setTag;
    }
    module2.exports = baseIsSet;
  }
});

// node_modules/lodash/isSet.js
var require_isSet = __commonJS({
  "node_modules/lodash/isSet.js"(exports, module2) {
    var baseIsSet = require_baseIsSet();
    var baseUnary = require_baseUnary();
    var nodeUtil = require_nodeUtil();
    var nodeIsSet = nodeUtil && nodeUtil.isSet;
    var isSet = nodeIsSet ? baseUnary(nodeIsSet) : baseIsSet;
    module2.exports = isSet;
  }
});

// node_modules/lodash/_baseClone.js
var require_baseClone = __commonJS({
  "node_modules/lodash/_baseClone.js"(exports, module2) {
    var Stack = require_Stack();
    var arrayEach = require_arrayEach();
    var assignValue = require_assignValue();
    var baseAssign = require_baseAssign();
    var baseAssignIn = require_baseAssignIn();
    var cloneBuffer = require_cloneBuffer();
    var copyArray = require_copyArray();
    var copySymbols = require_copySymbols();
    var copySymbolsIn = require_copySymbolsIn();
    var getAllKeys = require_getAllKeys();
    var getAllKeysIn = require_getAllKeysIn();
    var getTag = require_getTag();
    var initCloneArray = require_initCloneArray();
    var initCloneByTag = require_initCloneByTag();
    var initCloneObject = require_initCloneObject();
    var isArray2 = require_isArray();
    var isBuffer = require_isBuffer();
    var isMap = require_isMap();
    var isObject = require_isObject();
    var isSet = require_isSet();
    var keys3 = require_keys();
    var keysIn = require_keysIn();
    var CLONE_DEEP_FLAG = 1;
    var CLONE_FLAT_FLAG = 2;
    var CLONE_SYMBOLS_FLAG = 4;
    var argsTag = "[object Arguments]";
    var arrayTag = "[object Array]";
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var errorTag = "[object Error]";
    var funcTag = "[object Function]";
    var genTag = "[object GeneratorFunction]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var objectTag = "[object Object]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var symbolTag = "[object Symbol]";
    var weakMapTag = "[object WeakMap]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var float32Tag = "[object Float32Array]";
    var float64Tag = "[object Float64Array]";
    var int8Tag = "[object Int8Array]";
    var int16Tag = "[object Int16Array]";
    var int32Tag = "[object Int32Array]";
    var uint8Tag = "[object Uint8Array]";
    var uint8ClampedTag = "[object Uint8ClampedArray]";
    var uint16Tag = "[object Uint16Array]";
    var uint32Tag = "[object Uint32Array]";
    var cloneableTags = {};
    cloneableTags[argsTag] = cloneableTags[arrayTag] = cloneableTags[arrayBufferTag] = cloneableTags[dataViewTag] = cloneableTags[boolTag] = cloneableTags[dateTag] = cloneableTags[float32Tag] = cloneableTags[float64Tag] = cloneableTags[int8Tag] = cloneableTags[int16Tag] = cloneableTags[int32Tag] = cloneableTags[mapTag] = cloneableTags[numberTag] = cloneableTags[objectTag] = cloneableTags[regexpTag] = cloneableTags[setTag] = cloneableTags[stringTag] = cloneableTags[symbolTag] = cloneableTags[uint8Tag] = cloneableTags[uint8ClampedTag] = cloneableTags[uint16Tag] = cloneableTags[uint32Tag] = true;
    cloneableTags[errorTag] = cloneableTags[funcTag] = cloneableTags[weakMapTag] = false;
    function baseClone(value2, bitmask, customizer, key, object, stack) {
      var result, isDeep = bitmask & CLONE_DEEP_FLAG, isFlat = bitmask & CLONE_FLAT_FLAG, isFull = bitmask & CLONE_SYMBOLS_FLAG;
      if (customizer) {
        result = object ? customizer(value2, key, object, stack) : customizer(value2);
      }
      if (result !== void 0) {
        return result;
      }
      if (!isObject(value2)) {
        return value2;
      }
      var isArr = isArray2(value2);
      if (isArr) {
        result = initCloneArray(value2);
        if (!isDeep) {
          return copyArray(value2, result);
        }
      } else {
        var tag = getTag(value2), isFunc = tag == funcTag || tag == genTag;
        if (isBuffer(value2)) {
          return cloneBuffer(value2, isDeep);
        }
        if (tag == objectTag || tag == argsTag || isFunc && !object) {
          result = isFlat || isFunc ? {} : initCloneObject(value2);
          if (!isDeep) {
            return isFlat ? copySymbolsIn(value2, baseAssignIn(result, value2)) : copySymbols(value2, baseAssign(result, value2));
          }
        } else {
          if (!cloneableTags[tag]) {
            return object ? value2 : {};
          }
          result = initCloneByTag(value2, tag, isDeep);
        }
      }
      stack || (stack = new Stack());
      var stacked = stack.get(value2);
      if (stacked) {
        return stacked;
      }
      stack.set(value2, result);
      if (isSet(value2)) {
        value2.forEach(function(subValue) {
          result.add(baseClone(subValue, bitmask, customizer, subValue, value2, stack));
        });
      } else if (isMap(value2)) {
        value2.forEach(function(subValue, key2) {
          result.set(key2, baseClone(subValue, bitmask, customizer, key2, value2, stack));
        });
      }
      var keysFunc = isFull ? isFlat ? getAllKeysIn : getAllKeys : isFlat ? keysIn : keys3;
      var props = isArr ? void 0 : keysFunc(value2);
      arrayEach(props || value2, function(subValue, key2) {
        if (props) {
          key2 = subValue;
          subValue = value2[key2];
        }
        assignValue(result, key2, baseClone(subValue, bitmask, customizer, key2, value2, stack));
      });
      return result;
    }
    module2.exports = baseClone;
  }
});

// node_modules/lodash/clone.js
var require_clone2 = __commonJS({
  "node_modules/lodash/clone.js"(exports, module2) {
    var baseClone = require_baseClone();
    var CLONE_SYMBOLS_FLAG = 4;
    function clone(value2) {
      return baseClone(value2, CLONE_SYMBOLS_FLAG);
    }
    module2.exports = clone;
  }
});

// node_modules/lodash/_createBaseFor.js
var require_createBaseFor = __commonJS({
  "node_modules/lodash/_createBaseFor.js"(exports, module2) {
    function createBaseFor(fromRight) {
      return function(object, iteratee, keysFunc) {
        var index = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
        while (length--) {
          var key = props[fromRight ? length : ++index];
          if (iteratee(iterable[key], key, iterable) === false) {
            break;
          }
        }
        return object;
      };
    }
    module2.exports = createBaseFor;
  }
});

// node_modules/lodash/_baseFor.js
var require_baseFor = __commonJS({
  "node_modules/lodash/_baseFor.js"(exports, module2) {
    var createBaseFor = require_createBaseFor();
    var baseFor = createBaseFor();
    module2.exports = baseFor;
  }
});

// node_modules/lodash/_baseForOwn.js
var require_baseForOwn = __commonJS({
  "node_modules/lodash/_baseForOwn.js"(exports, module2) {
    var baseFor = require_baseFor();
    var keys3 = require_keys();
    function baseForOwn(object, iteratee) {
      return object && baseFor(object, iteratee, keys3);
    }
    module2.exports = baseForOwn;
  }
});

// node_modules/lodash/_createBaseEach.js
var require_createBaseEach = __commonJS({
  "node_modules/lodash/_createBaseEach.js"(exports, module2) {
    var isArrayLike = require_isArrayLike2();
    function createBaseEach(eachFunc, fromRight) {
      return function(collection, iteratee) {
        if (collection == null) {
          return collection;
        }
        if (!isArrayLike(collection)) {
          return eachFunc(collection, iteratee);
        }
        var length = collection.length, index = fromRight ? length : -1, iterable = Object(collection);
        while (fromRight ? index-- : ++index < length) {
          if (iteratee(iterable[index], index, iterable) === false) {
            break;
          }
        }
        return collection;
      };
    }
    module2.exports = createBaseEach;
  }
});

// node_modules/lodash/_baseEach.js
var require_baseEach = __commonJS({
  "node_modules/lodash/_baseEach.js"(exports, module2) {
    var baseForOwn = require_baseForOwn();
    var createBaseEach = require_createBaseEach();
    var baseEach = createBaseEach(baseForOwn);
    module2.exports = baseEach;
  }
});

// node_modules/lodash/_baseFilter.js
var require_baseFilter = __commonJS({
  "node_modules/lodash/_baseFilter.js"(exports, module2) {
    var baseEach = require_baseEach();
    function baseFilter(collection, predicate) {
      var result = [];
      baseEach(collection, function(value2, index, collection2) {
        if (predicate(value2, index, collection2)) {
          result.push(value2);
        }
      });
      return result;
    }
    module2.exports = baseFilter;
  }
});

// node_modules/lodash/_setCacheAdd.js
var require_setCacheAdd = __commonJS({
  "node_modules/lodash/_setCacheAdd.js"(exports, module2) {
    var HASH_UNDEFINED = "__lodash_hash_undefined__";
    function setCacheAdd(value2) {
      this.__data__.set(value2, HASH_UNDEFINED);
      return this;
    }
    module2.exports = setCacheAdd;
  }
});

// node_modules/lodash/_setCacheHas.js
var require_setCacheHas = __commonJS({
  "node_modules/lodash/_setCacheHas.js"(exports, module2) {
    function setCacheHas(value2) {
      return this.__data__.has(value2);
    }
    module2.exports = setCacheHas;
  }
});

// node_modules/lodash/_SetCache.js
var require_SetCache = __commonJS({
  "node_modules/lodash/_SetCache.js"(exports, module2) {
    var MapCache = require_MapCache();
    var setCacheAdd = require_setCacheAdd();
    var setCacheHas = require_setCacheHas();
    function SetCache(values2) {
      var index = -1, length = values2 == null ? 0 : values2.length;
      this.__data__ = new MapCache();
      while (++index < length) {
        this.add(values2[index]);
      }
    }
    SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
    SetCache.prototype.has = setCacheHas;
    module2.exports = SetCache;
  }
});

// node_modules/lodash/_arraySome.js
var require_arraySome = __commonJS({
  "node_modules/lodash/_arraySome.js"(exports, module2) {
    function arraySome(array, predicate) {
      var index = -1, length = array == null ? 0 : array.length;
      while (++index < length) {
        if (predicate(array[index], index, array)) {
          return true;
        }
      }
      return false;
    }
    module2.exports = arraySome;
  }
});

// node_modules/lodash/_cacheHas.js
var require_cacheHas = __commonJS({
  "node_modules/lodash/_cacheHas.js"(exports, module2) {
    function cacheHas(cache, key) {
      return cache.has(key);
    }
    module2.exports = cacheHas;
  }
});

// node_modules/lodash/_equalArrays.js
var require_equalArrays = __commonJS({
  "node_modules/lodash/_equalArrays.js"(exports, module2) {
    var SetCache = require_SetCache();
    var arraySome = require_arraySome();
    var cacheHas = require_cacheHas();
    var COMPARE_PARTIAL_FLAG = 1;
    var COMPARE_UNORDERED_FLAG = 2;
    function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG, arrLength = array.length, othLength = other.length;
      if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
        return false;
      }
      var arrStacked = stack.get(array);
      var othStacked = stack.get(other);
      if (arrStacked && othStacked) {
        return arrStacked == other && othStacked == array;
      }
      var index = -1, result = true, seen = bitmask & COMPARE_UNORDERED_FLAG ? new SetCache() : void 0;
      stack.set(array, other);
      stack.set(other, array);
      while (++index < arrLength) {
        var arrValue = array[index], othValue = other[index];
        if (customizer) {
          var compared = isPartial ? customizer(othValue, arrValue, index, other, array, stack) : customizer(arrValue, othValue, index, array, other, stack);
        }
        if (compared !== void 0) {
          if (compared) {
            continue;
          }
          result = false;
          break;
        }
        if (seen) {
          if (!arraySome(other, function(othValue2, othIndex) {
            if (!cacheHas(seen, othIndex) && (arrValue === othValue2 || equalFunc(arrValue, othValue2, bitmask, customizer, stack))) {
              return seen.push(othIndex);
            }
          })) {
            result = false;
            break;
          }
        } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
          result = false;
          break;
        }
      }
      stack["delete"](array);
      stack["delete"](other);
      return result;
    }
    module2.exports = equalArrays;
  }
});

// node_modules/lodash/_mapToArray.js
var require_mapToArray = __commonJS({
  "node_modules/lodash/_mapToArray.js"(exports, module2) {
    function mapToArray(map) {
      var index = -1, result = Array(map.size);
      map.forEach(function(value2, key) {
        result[++index] = [key, value2];
      });
      return result;
    }
    module2.exports = mapToArray;
  }
});

// node_modules/lodash/_setToArray.js
var require_setToArray = __commonJS({
  "node_modules/lodash/_setToArray.js"(exports, module2) {
    function setToArray(set) {
      var index = -1, result = Array(set.size);
      set.forEach(function(value2) {
        result[++index] = value2;
      });
      return result;
    }
    module2.exports = setToArray;
  }
});

// node_modules/lodash/_equalByTag.js
var require_equalByTag = __commonJS({
  "node_modules/lodash/_equalByTag.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var Uint8Array2 = require_Uint8Array();
    var eq = require_eq();
    var equalArrays = require_equalArrays();
    var mapToArray = require_mapToArray();
    var setToArray = require_setToArray();
    var COMPARE_PARTIAL_FLAG = 1;
    var COMPARE_UNORDERED_FLAG = 2;
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var errorTag = "[object Error]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var symbolTag = "[object Symbol]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var symbolProto = Symbol2 ? Symbol2.prototype : void 0;
    var symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
    function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
      switch (tag) {
        case dataViewTag:
          if (object.byteLength != other.byteLength || object.byteOffset != other.byteOffset) {
            return false;
          }
          object = object.buffer;
          other = other.buffer;
        case arrayBufferTag:
          if (object.byteLength != other.byteLength || !equalFunc(new Uint8Array2(object), new Uint8Array2(other))) {
            return false;
          }
          return true;
        case boolTag:
        case dateTag:
        case numberTag:
          return eq(+object, +other);
        case errorTag:
          return object.name == other.name && object.message == other.message;
        case regexpTag:
        case stringTag:
          return object == other + "";
        case mapTag:
          var convert = mapToArray;
        case setTag:
          var isPartial = bitmask & COMPARE_PARTIAL_FLAG;
          convert || (convert = setToArray);
          if (object.size != other.size && !isPartial) {
            return false;
          }
          var stacked = stack.get(object);
          if (stacked) {
            return stacked == other;
          }
          bitmask |= COMPARE_UNORDERED_FLAG;
          stack.set(object, other);
          var result = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
          stack["delete"](object);
          return result;
        case symbolTag:
          if (symbolValueOf) {
            return symbolValueOf.call(object) == symbolValueOf.call(other);
          }
      }
      return false;
    }
    module2.exports = equalByTag;
  }
});

// node_modules/lodash/_equalObjects.js
var require_equalObjects = __commonJS({
  "node_modules/lodash/_equalObjects.js"(exports, module2) {
    var getAllKeys = require_getAllKeys();
    var COMPARE_PARTIAL_FLAG = 1;
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG, objProps = getAllKeys(object), objLength = objProps.length, othProps = getAllKeys(other), othLength = othProps.length;
      if (objLength != othLength && !isPartial) {
        return false;
      }
      var index = objLength;
      while (index--) {
        var key = objProps[index];
        if (!(isPartial ? key in other : hasOwnProperty.call(other, key))) {
          return false;
        }
      }
      var objStacked = stack.get(object);
      var othStacked = stack.get(other);
      if (objStacked && othStacked) {
        return objStacked == other && othStacked == object;
      }
      var result = true;
      stack.set(object, other);
      stack.set(other, object);
      var skipCtor = isPartial;
      while (++index < objLength) {
        key = objProps[index];
        var objValue = object[key], othValue = other[key];
        if (customizer) {
          var compared = isPartial ? customizer(othValue, objValue, key, other, object, stack) : customizer(objValue, othValue, key, object, other, stack);
        }
        if (!(compared === void 0 ? objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack) : compared)) {
          result = false;
          break;
        }
        skipCtor || (skipCtor = key == "constructor");
      }
      if (result && !skipCtor) {
        var objCtor = object.constructor, othCtor = other.constructor;
        if (objCtor != othCtor && ("constructor" in object && "constructor" in other) && !(typeof objCtor == "function" && objCtor instanceof objCtor && typeof othCtor == "function" && othCtor instanceof othCtor)) {
          result = false;
        }
      }
      stack["delete"](object);
      stack["delete"](other);
      return result;
    }
    module2.exports = equalObjects;
  }
});

// node_modules/lodash/_baseIsEqualDeep.js
var require_baseIsEqualDeep = __commonJS({
  "node_modules/lodash/_baseIsEqualDeep.js"(exports, module2) {
    var Stack = require_Stack();
    var equalArrays = require_equalArrays();
    var equalByTag = require_equalByTag();
    var equalObjects = require_equalObjects();
    var getTag = require_getTag();
    var isArray2 = require_isArray();
    var isBuffer = require_isBuffer();
    var isTypedArray = require_isTypedArray();
    var COMPARE_PARTIAL_FLAG = 1;
    var argsTag = "[object Arguments]";
    var arrayTag = "[object Array]";
    var objectTag = "[object Object]";
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
      var objIsArr = isArray2(object), othIsArr = isArray2(other), objTag = objIsArr ? arrayTag : getTag(object), othTag = othIsArr ? arrayTag : getTag(other);
      objTag = objTag == argsTag ? objectTag : objTag;
      othTag = othTag == argsTag ? objectTag : othTag;
      var objIsObj = objTag == objectTag, othIsObj = othTag == objectTag, isSameTag = objTag == othTag;
      if (isSameTag && isBuffer(object)) {
        if (!isBuffer(other)) {
          return false;
        }
        objIsArr = true;
        objIsObj = false;
      }
      if (isSameTag && !objIsObj) {
        stack || (stack = new Stack());
        return objIsArr || isTypedArray(object) ? equalArrays(object, other, bitmask, customizer, equalFunc, stack) : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
      }
      if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
        var objIsWrapped = objIsObj && hasOwnProperty.call(object, "__wrapped__"), othIsWrapped = othIsObj && hasOwnProperty.call(other, "__wrapped__");
        if (objIsWrapped || othIsWrapped) {
          var objUnwrapped = objIsWrapped ? object.value() : object, othUnwrapped = othIsWrapped ? other.value() : other;
          stack || (stack = new Stack());
          return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
        }
      }
      if (!isSameTag) {
        return false;
      }
      stack || (stack = new Stack());
      return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
    }
    module2.exports = baseIsEqualDeep;
  }
});

// node_modules/lodash/_baseIsEqual.js
var require_baseIsEqual = __commonJS({
  "node_modules/lodash/_baseIsEqual.js"(exports, module2) {
    var baseIsEqualDeep = require_baseIsEqualDeep();
    var isObjectLike = require_isObjectLike();
    function baseIsEqual(value2, other, bitmask, customizer, stack) {
      if (value2 === other) {
        return true;
      }
      if (value2 == null || other == null || !isObjectLike(value2) && !isObjectLike(other)) {
        return value2 !== value2 && other !== other;
      }
      return baseIsEqualDeep(value2, other, bitmask, customizer, baseIsEqual, stack);
    }
    module2.exports = baseIsEqual;
  }
});

// node_modules/lodash/_baseIsMatch.js
var require_baseIsMatch = __commonJS({
  "node_modules/lodash/_baseIsMatch.js"(exports, module2) {
    var Stack = require_Stack();
    var baseIsEqual = require_baseIsEqual();
    var COMPARE_PARTIAL_FLAG = 1;
    var COMPARE_UNORDERED_FLAG = 2;
    function baseIsMatch(object, source, matchData, customizer) {
      var index = matchData.length, length = index, noCustomizer = !customizer;
      if (object == null) {
        return !length;
      }
      object = Object(object);
      while (index--) {
        var data = matchData[index];
        if (noCustomizer && data[2] ? data[1] !== object[data[0]] : !(data[0] in object)) {
          return false;
        }
      }
      while (++index < length) {
        data = matchData[index];
        var key = data[0], objValue = object[key], srcValue = data[1];
        if (noCustomizer && data[2]) {
          if (objValue === void 0 && !(key in object)) {
            return false;
          }
        } else {
          var stack = new Stack();
          if (customizer) {
            var result = customizer(objValue, srcValue, key, object, source, stack);
          }
          if (!(result === void 0 ? baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG, customizer, stack) : result)) {
            return false;
          }
        }
      }
      return true;
    }
    module2.exports = baseIsMatch;
  }
});

// node_modules/lodash/_isStrictComparable.js
var require_isStrictComparable = __commonJS({
  "node_modules/lodash/_isStrictComparable.js"(exports, module2) {
    var isObject = require_isObject();
    function isStrictComparable(value2) {
      return value2 === value2 && !isObject(value2);
    }
    module2.exports = isStrictComparable;
  }
});

// node_modules/lodash/_getMatchData.js
var require_getMatchData = __commonJS({
  "node_modules/lodash/_getMatchData.js"(exports, module2) {
    var isStrictComparable = require_isStrictComparable();
    var keys3 = require_keys();
    function getMatchData(object) {
      var result = keys3(object), length = result.length;
      while (length--) {
        var key = result[length], value2 = object[key];
        result[length] = [key, value2, isStrictComparable(value2)];
      }
      return result;
    }
    module2.exports = getMatchData;
  }
});

// node_modules/lodash/_matchesStrictComparable.js
var require_matchesStrictComparable = __commonJS({
  "node_modules/lodash/_matchesStrictComparable.js"(exports, module2) {
    function matchesStrictComparable(key, srcValue) {
      return function(object) {
        if (object == null) {
          return false;
        }
        return object[key] === srcValue && (srcValue !== void 0 || key in Object(object));
      };
    }
    module2.exports = matchesStrictComparable;
  }
});

// node_modules/lodash/_baseMatches.js
var require_baseMatches = __commonJS({
  "node_modules/lodash/_baseMatches.js"(exports, module2) {
    var baseIsMatch = require_baseIsMatch();
    var getMatchData = require_getMatchData();
    var matchesStrictComparable = require_matchesStrictComparable();
    function baseMatches(source) {
      var matchData = getMatchData(source);
      if (matchData.length == 1 && matchData[0][2]) {
        return matchesStrictComparable(matchData[0][0], matchData[0][1]);
      }
      return function(object) {
        return object === source || baseIsMatch(object, source, matchData);
      };
    }
    module2.exports = baseMatches;
  }
});

// node_modules/lodash/_baseHasIn.js
var require_baseHasIn = __commonJS({
  "node_modules/lodash/_baseHasIn.js"(exports, module2) {
    function baseHasIn(object, key) {
      return object != null && key in Object(object);
    }
    module2.exports = baseHasIn;
  }
});

// node_modules/lodash/_hasPath.js
var require_hasPath = __commonJS({
  "node_modules/lodash/_hasPath.js"(exports, module2) {
    var castPath = require_castPath();
    var isArguments = require_isArguments();
    var isArray2 = require_isArray();
    var isIndex = require_isIndex();
    var isLength = require_isLength();
    var toKey = require_toKey();
    function hasPath(object, path2, hasFunc) {
      path2 = castPath(path2, object);
      var index = -1, length = path2.length, result = false;
      while (++index < length) {
        var key = toKey(path2[index]);
        if (!(result = object != null && hasFunc(object, key))) {
          break;
        }
        object = object[key];
      }
      if (result || ++index != length) {
        return result;
      }
      length = object == null ? 0 : object.length;
      return !!length && isLength(length) && isIndex(key, length) && (isArray2(object) || isArguments(object));
    }
    module2.exports = hasPath;
  }
});

// node_modules/lodash/hasIn.js
var require_hasIn = __commonJS({
  "node_modules/lodash/hasIn.js"(exports, module2) {
    var baseHasIn = require_baseHasIn();
    var hasPath = require_hasPath();
    function hasIn(object, path2) {
      return object != null && hasPath(object, path2, baseHasIn);
    }
    module2.exports = hasIn;
  }
});

// node_modules/lodash/_baseMatchesProperty.js
var require_baseMatchesProperty = __commonJS({
  "node_modules/lodash/_baseMatchesProperty.js"(exports, module2) {
    var baseIsEqual = require_baseIsEqual();
    var get = require_get();
    var hasIn = require_hasIn();
    var isKey = require_isKey();
    var isStrictComparable = require_isStrictComparable();
    var matchesStrictComparable = require_matchesStrictComparable();
    var toKey = require_toKey();
    var COMPARE_PARTIAL_FLAG = 1;
    var COMPARE_UNORDERED_FLAG = 2;
    function baseMatchesProperty(path2, srcValue) {
      if (isKey(path2) && isStrictComparable(srcValue)) {
        return matchesStrictComparable(toKey(path2), srcValue);
      }
      return function(object) {
        var objValue = get(object, path2);
        return objValue === void 0 && objValue === srcValue ? hasIn(object, path2) : baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG);
      };
    }
    module2.exports = baseMatchesProperty;
  }
});

// node_modules/lodash/_baseProperty.js
var require_baseProperty = __commonJS({
  "node_modules/lodash/_baseProperty.js"(exports, module2) {
    function baseProperty(key) {
      return function(object) {
        return object == null ? void 0 : object[key];
      };
    }
    module2.exports = baseProperty;
  }
});

// node_modules/lodash/_basePropertyDeep.js
var require_basePropertyDeep = __commonJS({
  "node_modules/lodash/_basePropertyDeep.js"(exports, module2) {
    var baseGet = require_baseGet();
    function basePropertyDeep(path2) {
      return function(object) {
        return baseGet(object, path2);
      };
    }
    module2.exports = basePropertyDeep;
  }
});

// node_modules/lodash/property.js
var require_property = __commonJS({
  "node_modules/lodash/property.js"(exports, module2) {
    var baseProperty = require_baseProperty();
    var basePropertyDeep = require_basePropertyDeep();
    var isKey = require_isKey();
    var toKey = require_toKey();
    function property(path2) {
      return isKey(path2) ? baseProperty(toKey(path2)) : basePropertyDeep(path2);
    }
    module2.exports = property;
  }
});

// node_modules/lodash/_baseIteratee.js
var require_baseIteratee = __commonJS({
  "node_modules/lodash/_baseIteratee.js"(exports, module2) {
    var baseMatches = require_baseMatches();
    var baseMatchesProperty = require_baseMatchesProperty();
    var identity = require_identity2();
    var isArray2 = require_isArray();
    var property = require_property();
    function baseIteratee(value2) {
      if (typeof value2 == "function") {
        return value2;
      }
      if (value2 == null) {
        return identity;
      }
      if (typeof value2 == "object") {
        return isArray2(value2) ? baseMatchesProperty(value2[0], value2[1]) : baseMatches(value2);
      }
      return property(value2);
    }
    module2.exports = baseIteratee;
  }
});

// node_modules/lodash/filter.js
var require_filter2 = __commonJS({
  "node_modules/lodash/filter.js"(exports, module2) {
    var arrayFilter = require_arrayFilter();
    var baseFilter = require_baseFilter();
    var baseIteratee = require_baseIteratee();
    var isArray2 = require_isArray();
    function filter(collection, predicate) {
      var func = isArray2(collection) ? arrayFilter : baseFilter;
      return func(collection, baseIteratee(predicate, 3));
    }
    module2.exports = filter;
  }
});

// node_modules/lodash/_baseMap.js
var require_baseMap = __commonJS({
  "node_modules/lodash/_baseMap.js"(exports, module2) {
    var baseEach = require_baseEach();
    var isArrayLike = require_isArrayLike2();
    function baseMap(collection, iteratee) {
      var index = -1, result = isArrayLike(collection) ? Array(collection.length) : [];
      baseEach(collection, function(value2, key, collection2) {
        result[++index] = iteratee(value2, key, collection2);
      });
      return result;
    }
    module2.exports = baseMap;
  }
});

// node_modules/lodash/map.js
var require_map2 = __commonJS({
  "node_modules/lodash/map.js"(exports, module2) {
    var arrayMap = require_arrayMap();
    var baseIteratee = require_baseIteratee();
    var baseMap = require_baseMap();
    var isArray2 = require_isArray();
    function map(collection, iteratee) {
      var func = isArray2(collection) ? arrayMap : baseMap;
      return func(collection, baseIteratee(iteratee, 3));
    }
    module2.exports = map;
  }
});

// node_modules/inquirer/lib/objects/choice.js
var require_choice = __commonJS({
  "node_modules/inquirer/lib/objects/choice.js"(exports, module2) {
    "use strict";
    module2.exports = class Choice {
      constructor(val, answers) {
        if (val instanceof Choice || val.type === "separator") {
          return val;
        }
        if (typeof val === "string" || typeof val === "number") {
          this.name = String(val);
          this.value = val;
          this.short = String(val);
        } else {
          Object.assign(this, val, {
            name: val.name || val.value,
            value: "value" in val ? val.value : val.name,
            short: val.short || val.name || val.value
          });
        }
        if (typeof val.disabled === "function") {
          this.disabled = val.disabled(answers);
        } else {
          this.disabled = val.disabled;
        }
      }
    };
  }
});

// node_modules/inquirer/lib/objects/choices.js
var require_choices = __commonJS({
  "node_modules/inquirer/lib/objects/choices.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var _ = {
      filter: require_filter2(),
      map: require_map2()
    };
    var Separator = require_separator();
    var Choice = require_choice();
    module2.exports = class Choices {
      /** @param {Array} choices  All `choice` to keep in the collection */
      constructor(choices, answers) {
        this.choices = choices.map((val) => {
          if (val.type === "separator") {
            if (!(val instanceof Separator)) {
              val = new Separator(val.line);
            }
            return val;
          }
          return new Choice(val, answers);
        });
        this.realChoices = this.choices.filter(Separator.exclude).filter((item) => !item.disabled);
        Object.defineProperty(this, "length", {
          get() {
            return this.choices.length;
          },
          set(val) {
            this.choices.length = val;
          }
        });
        Object.defineProperty(this, "realLength", {
          get() {
            return this.realChoices.length;
          },
          set() {
            throw new Error("Cannot set `realLength` of a Choices collection");
          }
        });
      }
      /**
       * Get a valid choice from the collection
       * @param  {Number} selector  The selected choice index
       * @return {Choice|Undefined} Return the matched choice or undefined
       */
      getChoice(selector) {
        assert(typeof selector === "number");
        return this.realChoices[selector];
      }
      /**
       * Get a raw element from the collection
       * @param  {Number} selector  The selected index value
       * @return {Choice|Undefined} Return the matched choice or undefined
       */
      get(selector) {
        assert(typeof selector === "number");
        return this.choices[selector];
      }
      /**
       * Match the valid choices against a where clause
       * @param  {Object} whereClause Lodash `where` clause
       * @return {Array}              Matching choices or empty array
       */
      where(whereClause) {
        return _.filter(this.realChoices, whereClause);
      }
      /**
       * Pluck a particular key from the choices
       * @param  {String} propertyName Property name to select
       * @return {Array}               Selected properties
       */
      pluck(propertyName) {
        return _.map(this.realChoices, propertyName);
      }
      // Expose usual Array methods
      indexOf(...args) {
        return this.choices.indexOf(...args);
      }
      forEach(...args) {
        return this.choices.forEach(...args);
      }
      filter(...args) {
        return this.choices.filter(...args);
      }
      reduce(...args) {
        return this.choices.reduce(...args);
      }
      find(func) {
        return this.choices.find(func);
      }
      push(...args) {
        const objs = args.map((val) => new Choice(val));
        this.choices.push(...objs);
        this.realChoices = this.choices.filter(Separator.exclude).filter((item) => !item.disabled);
        return this.choices;
      }
    };
  }
});

// node_modules/cli-width/index.js
var require_cli_width = __commonJS({
  "node_modules/cli-width/index.js"(exports, module2) {
    "use strict";
    exports = module2.exports = cliWidth;
    function normalizeOpts(options) {
      let defaultOpts = {
        defaultWidth: 0,
        output: process.stdout,
        tty: require("tty")
      };
      if (!options) {
        return defaultOpts;
      }
      Object.keys(defaultOpts).forEach(function(key) {
        if (!options[key]) {
          options[key] = defaultOpts[key];
        }
      });
      return options;
    }
    function cliWidth(options) {
      let opts = normalizeOpts(options);
      if (opts.output.getWindowSize) {
        return opts.output.getWindowSize()[0] || opts.defaultWidth;
      }
      if (opts.tty.getWindowSize) {
        return opts.tty.getWindowSize()[1] || opts.defaultWidth;
      }
      if (opts.output.columns) {
        return opts.output.columns;
      }
      if (process.env.CLI_WIDTH) {
        let width = parseInt(process.env.CLI_WIDTH, 10);
        if (!isNaN(width) && width !== 0) {
          return width;
        }
      }
      return opts.defaultWidth;
    }
  }
});

// node_modules/is-fullwidth-code-point/index.js
var require_is_fullwidth_code_point = __commonJS({
  "node_modules/is-fullwidth-code-point/index.js"(exports, module2) {
    "use strict";
    var isFullwidthCodePoint = (codePoint) => {
      if (Number.isNaN(codePoint)) {
        return false;
      }
      if (codePoint >= 4352 && (codePoint <= 4447 || // Hangul Jamo
      codePoint === 9001 || // LEFT-POINTING ANGLE BRACKET
      codePoint === 9002 || // RIGHT-POINTING ANGLE BRACKET
      // CJK Radicals Supplement .. Enclosed CJK Letters and Months
      11904 <= codePoint && codePoint <= 12871 && codePoint !== 12351 || // Enclosed CJK Letters and Months .. CJK Unified Ideographs Extension A
      12880 <= codePoint && codePoint <= 19903 || // CJK Unified Ideographs .. Yi Radicals
      19968 <= codePoint && codePoint <= 42182 || // Hangul Jamo Extended-A
      43360 <= codePoint && codePoint <= 43388 || // Hangul Syllables
      44032 <= codePoint && codePoint <= 55203 || // CJK Compatibility Ideographs
      63744 <= codePoint && codePoint <= 64255 || // Vertical Forms
      65040 <= codePoint && codePoint <= 65049 || // CJK Compatibility Forms .. Small Form Variants
      65072 <= codePoint && codePoint <= 65131 || // Halfwidth and Fullwidth Forms
      65281 <= codePoint && codePoint <= 65376 || 65504 <= codePoint && codePoint <= 65510 || // Kana Supplement
      110592 <= codePoint && codePoint <= 110593 || // Enclosed Ideographic Supplement
      127488 <= codePoint && codePoint <= 127569 || // CJK Unified Ideographs Extension B .. Tertiary Ideographic Plane
      131072 <= codePoint && codePoint <= 262141)) {
        return true;
      }
      return false;
    };
    module2.exports = isFullwidthCodePoint;
    module2.exports.default = isFullwidthCodePoint;
  }
});

// node_modules/emoji-regex/index.js
var require_emoji_regex = __commonJS({
  "node_modules/emoji-regex/index.js"(exports, module2) {
    "use strict";
    module2.exports = function() {
      return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73)\uDB40\uDC7F|\uD83D\uDC68(?:\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68\uD83C\uDFFB|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|[\u2695\u2696\u2708]\uFE0F|\uD83D[\uDC66\uDC67]|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708])\uFE0F|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C[\uDFFB-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)\uD83C\uDFFB|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB\uDFFC])|\uD83D\uDC69(?:\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB-\uDFFD])|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|(?:(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)\uFE0F|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\u200D[\u2640\u2642])|\uD83C\uDFF4\u200D\u2620)\uFE0F|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF4\uD83C\uDDF2|\uD83C\uDDF6\uD83C\uDDE6|[#\*0-9]\uFE0F\u20E3|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270A-\u270D]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC70\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDCAA\uDD74\uDD7A\uDD90\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD36\uDDB5\uDDB6\uDDBB\uDDD2-\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5\uDEEB\uDEEC\uDEF4-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
    };
  }
});

// node_modules/string-width/index.js
var require_string_width = __commonJS({
  "node_modules/string-width/index.js"(exports, module2) {
    "use strict";
    var stripAnsi = require_strip_ansi();
    var isFullwidthCodePoint = require_is_fullwidth_code_point();
    var emojiRegex = require_emoji_regex();
    var stringWidth = (string) => {
      if (typeof string !== "string" || string.length === 0) {
        return 0;
      }
      string = stripAnsi(string);
      if (string.length === 0) {
        return 0;
      }
      string = string.replace(emojiRegex(), "  ");
      let width = 0;
      for (let i = 0; i < string.length; i++) {
        const code = string.codePointAt(i);
        if (code <= 31 || code >= 127 && code <= 159) {
          continue;
        }
        if (code >= 768 && code <= 879) {
          continue;
        }
        if (code > 65535) {
          i++;
        }
        width += isFullwidthCodePoint(code) ? 2 : 1;
      }
      return width;
    };
    module2.exports = stringWidth;
    module2.exports.default = stringWidth;
  }
});

// node_modules/wrap-ansi/index.js
var require_wrap_ansi = __commonJS({
  "node_modules/wrap-ansi/index.js"(exports, module2) {
    "use strict";
    var stringWidth = require_string_width();
    var stripAnsi = require_strip_ansi();
    var ansiStyles = require_ansi_styles();
    var ESCAPES = /* @__PURE__ */ new Set([
      "\x1B",
      "\x9B"
    ]);
    var END_CODE = 39;
    var ANSI_ESCAPE_BELL = "\x07";
    var ANSI_CSI = "[";
    var ANSI_OSC = "]";
    var ANSI_SGR_TERMINATOR = "m";
    var ANSI_ESCAPE_LINK = `${ANSI_OSC}8;;`;
    var wrapAnsi = (code) => `${ESCAPES.values().next().value}${ANSI_CSI}${code}${ANSI_SGR_TERMINATOR}`;
    var wrapAnsiHyperlink = (uri) => `${ESCAPES.values().next().value}${ANSI_ESCAPE_LINK}${uri}${ANSI_ESCAPE_BELL}`;
    var wordLengths = (string) => string.split(" ").map((character) => stringWidth(character));
    var wrapWord = (rows, word, columns) => {
      const characters = [...word];
      let isInsideEscape = false;
      let isInsideLinkEscape = false;
      let visible = stringWidth(stripAnsi(rows[rows.length - 1]));
      for (const [index, character] of characters.entries()) {
        const characterLength = stringWidth(character);
        if (visible + characterLength <= columns) {
          rows[rows.length - 1] += character;
        } else {
          rows.push(character);
          visible = 0;
        }
        if (ESCAPES.has(character)) {
          isInsideEscape = true;
          isInsideLinkEscape = characters.slice(index + 1).join("").startsWith(ANSI_ESCAPE_LINK);
        }
        if (isInsideEscape) {
          if (isInsideLinkEscape) {
            if (character === ANSI_ESCAPE_BELL) {
              isInsideEscape = false;
              isInsideLinkEscape = false;
            }
          } else if (character === ANSI_SGR_TERMINATOR) {
            isInsideEscape = false;
          }
          continue;
        }
        visible += characterLength;
        if (visible === columns && index < characters.length - 1) {
          rows.push("");
          visible = 0;
        }
      }
      if (!visible && rows[rows.length - 1].length > 0 && rows.length > 1) {
        rows[rows.length - 2] += rows.pop();
      }
    };
    var stringVisibleTrimSpacesRight = (string) => {
      const words = string.split(" ");
      let last2 = words.length;
      while (last2 > 0) {
        if (stringWidth(words[last2 - 1]) > 0) {
          break;
        }
        last2--;
      }
      if (last2 === words.length) {
        return string;
      }
      return words.slice(0, last2).join(" ") + words.slice(last2).join("");
    };
    var exec2 = (string, columns, options = {}) => {
      if (options.trim !== false && string.trim() === "") {
        return "";
      }
      let returnValue = "";
      let escapeCode;
      let escapeUrl;
      const lengths = wordLengths(string);
      let rows = [""];
      for (const [index, word] of string.split(" ").entries()) {
        if (options.trim !== false) {
          rows[rows.length - 1] = rows[rows.length - 1].trimStart();
        }
        let rowLength = stringWidth(rows[rows.length - 1]);
        if (index !== 0) {
          if (rowLength >= columns && (options.wordWrap === false || options.trim === false)) {
            rows.push("");
            rowLength = 0;
          }
          if (rowLength > 0 || options.trim === false) {
            rows[rows.length - 1] += " ";
            rowLength++;
          }
        }
        if (options.hard && lengths[index] > columns) {
          const remainingColumns = columns - rowLength;
          const breaksStartingThisLine = 1 + Math.floor((lengths[index] - remainingColumns - 1) / columns);
          const breaksStartingNextLine = Math.floor((lengths[index] - 1) / columns);
          if (breaksStartingNextLine < breaksStartingThisLine) {
            rows.push("");
          }
          wrapWord(rows, word, columns);
          continue;
        }
        if (rowLength + lengths[index] > columns && rowLength > 0 && lengths[index] > 0) {
          if (options.wordWrap === false && rowLength < columns) {
            wrapWord(rows, word, columns);
            continue;
          }
          rows.push("");
        }
        if (rowLength + lengths[index] > columns && options.wordWrap === false) {
          wrapWord(rows, word, columns);
          continue;
        }
        rows[rows.length - 1] += word;
      }
      if (options.trim !== false) {
        rows = rows.map(stringVisibleTrimSpacesRight);
      }
      const pre = [...rows.join("\n")];
      for (const [index, character] of pre.entries()) {
        returnValue += character;
        if (ESCAPES.has(character)) {
          const { groups } = new RegExp(`(?:\\${ANSI_CSI}(?<code>\\d+)m|\\${ANSI_ESCAPE_LINK}(?<uri>.*)${ANSI_ESCAPE_BELL})`).exec(pre.slice(index).join("")) || { groups: {} };
          if (groups.code !== void 0) {
            const code2 = Number.parseFloat(groups.code);
            escapeCode = code2 === END_CODE ? void 0 : code2;
          } else if (groups.uri !== void 0) {
            escapeUrl = groups.uri.length === 0 ? void 0 : groups.uri;
          }
        }
        const code = ansiStyles.codes.get(Number(escapeCode));
        if (pre[index + 1] === "\n") {
          if (escapeUrl) {
            returnValue += wrapAnsiHyperlink("");
          }
          if (escapeCode && code) {
            returnValue += wrapAnsi(code);
          }
        } else if (character === "\n") {
          if (escapeCode && code) {
            returnValue += wrapAnsi(escapeCode);
          }
          if (escapeUrl) {
            returnValue += wrapAnsiHyperlink(escapeUrl);
          }
        }
      }
      return returnValue;
    };
    module2.exports = (string, columns, options) => {
      return String(string).normalize().replace(/\r\n/g, "\n").split("\n").map((line) => exec2(line, columns, options)).join("\n");
    };
  }
});

// node_modules/inquirer/lib/utils/screen-manager.js
var require_screen_manager = __commonJS({
  "node_modules/inquirer/lib/utils/screen-manager.js"(exports, module2) {
    "use strict";
    var util = require_readline();
    var cliWidth = require_cli_width();
    var wrapAnsi = require_wrap_ansi();
    var stripAnsi = require_strip_ansi();
    var stringWidth = require_string_width();
    var ora2 = require_ora();
    function height(content) {
      return content.split("\n").length;
    }
    function lastLine(content) {
      return content.split("\n").pop();
    }
    var ScreenManager = class {
      constructor(rl) {
        this.height = 0;
        this.extraLinesUnderPrompt = 0;
        this.rl = rl;
      }
      renderWithSpinner(content, bottomContent) {
        if (this.spinnerId) {
          clearInterval(this.spinnerId);
        }
        let spinner2;
        let contentFunc;
        let bottomContentFunc;
        if (bottomContent) {
          spinner2 = ora2(bottomContent);
          contentFunc = () => content;
          bottomContentFunc = () => spinner2.frame();
        } else {
          spinner2 = ora2(content);
          contentFunc = () => spinner2.frame();
          bottomContentFunc = () => "";
        }
        this.spinnerId = setInterval(
          () => this.render(contentFunc(), bottomContentFunc(), true),
          spinner2.interval
        );
      }
      render(content, bottomContent, spinning = false) {
        if (this.spinnerId && !spinning) {
          clearInterval(this.spinnerId);
        }
        this.rl.output.unmute();
        this.clean(this.extraLinesUnderPrompt);
        const promptLine = lastLine(content);
        const rawPromptLine = stripAnsi(promptLine);
        let prompt = rawPromptLine;
        if (this.rl.line.length) {
          prompt = prompt.slice(0, -this.rl.line.length);
        }
        this.rl.setPrompt(prompt);
        const cursorPos = this.rl._getCursorPos();
        const width = this.normalizedCliWidth();
        content = this.forceLineReturn(content, width);
        if (bottomContent) {
          bottomContent = this.forceLineReturn(bottomContent, width);
        }
        if (rawPromptLine.length % width === 0) {
          content += "\n";
        }
        const fullContent = content + (bottomContent ? "\n" + bottomContent : "");
        this.rl.output.write(fullContent);
        const promptLineUpDiff = Math.floor(rawPromptLine.length / width) - cursorPos.rows;
        const bottomContentHeight = promptLineUpDiff + (bottomContent ? height(bottomContent) : 0);
        if (bottomContentHeight > 0) {
          util.up(this.rl, bottomContentHeight);
        }
        util.left(this.rl, stringWidth(lastLine(fullContent)));
        if (cursorPos.cols > 0) {
          util.right(this.rl, cursorPos.cols);
        }
        this.extraLinesUnderPrompt = bottomContentHeight;
        this.height = height(fullContent);
        this.rl.output.mute();
      }
      clean(extraLines) {
        if (extraLines > 0) {
          util.down(this.rl, extraLines);
        }
        util.clearLine(this.rl, this.height);
      }
      done() {
        this.rl.setPrompt("");
        this.rl.output.unmute();
        this.rl.output.write("\n");
      }
      releaseCursor() {
        if (this.extraLinesUnderPrompt > 0) {
          util.down(this.rl, this.extraLinesUnderPrompt);
        }
      }
      normalizedCliWidth() {
        const width = cliWidth({
          defaultWidth: 80,
          output: this.rl.output
        });
        return width;
      }
      /**
       * @param {string[]} lines
       */
      breakLines(lines, width = this.normalizedCliWidth()) {
        return lines.map(
          (line) => wrapAnsi(line, width, { trim: false, hard: true }).split("\n")
        );
      }
      /**
       * @param {string} content
       */
      forceLineReturn(content, width = this.normalizedCliWidth()) {
        return this.breakLines(content.split("\n"), width).flat().join("\n");
      }
    };
    module2.exports = ScreenManager;
  }
});

// node_modules/inquirer/lib/prompts/base.js
var require_base = __commonJS({
  "node_modules/inquirer/lib/prompts/base.js"(exports, module2) {
    "use strict";
    var _ = {
      defaults: require_defaults2(),
      clone: require_clone2()
    };
    var chalk3 = require_source();
    var runAsync = require_run_async();
    var { filter, flatMap, share, take, takeUntil } = require_operators();
    var Choices = require_choices();
    var ScreenManager = require_screen_manager();
    var Prompt = class {
      constructor(question, rl, answers) {
        Object.assign(this, {
          answers,
          status: "pending"
        });
        this.opt = _.defaults(_.clone(question), {
          validate: () => true,
          validatingText: "",
          filter: (val) => val,
          filteringText: "",
          when: () => true,
          suffix: "",
          prefix: chalk3.green("?")
        });
        if (!this.opt.name) {
          this.throwParamError("name");
        }
        if (!this.opt.message) {
          this.opt.message = this.opt.name + ":";
        }
        if (Array.isArray(this.opt.choices)) {
          this.opt.choices = new Choices(this.opt.choices, answers);
        }
        this.rl = rl;
        this.screen = new ScreenManager(this.rl);
      }
      /**
       * Start the Inquiry session and manage output value filtering
       * @return {Promise}
       */
      run() {
        return new Promise((resolve, reject) => {
          this._run(
            (value2) => resolve(value2),
            (error) => reject(error)
          );
        });
      }
      // Default noop (this one should be overwritten in prompts)
      _run(cb) {
        cb();
      }
      /**
       * Throw an error telling a required parameter is missing
       * @param  {String} name Name of the missing param
       * @return {Throw Error}
       */
      throwParamError(name) {
        throw new Error("You must provide a `" + name + "` parameter");
      }
      /**
       * Called when the UI closes. Override to do any specific cleanup necessary
       */
      close() {
        this.screen.releaseCursor();
      }
      /**
       * Run the provided validation method each time a submit event occur.
       * @param  {Rx.Observable} submit - submit event flow
       * @return {Object}        Object containing two observables: `success` and `error`
       */
      handleSubmitEvents(submit) {
        const self2 = this;
        const validate = runAsync(this.opt.validate);
        const asyncFilter = runAsync(this.opt.filter);
        const validation = submit.pipe(
          flatMap((value2) => {
            this.startSpinner(value2, this.opt.filteringText);
            return asyncFilter(value2, self2.answers).then(
              (filteredValue) => {
                this.startSpinner(filteredValue, this.opt.validatingText);
                return validate(filteredValue, self2.answers).then(
                  (isValid) => ({ isValid, value: filteredValue }),
                  (err) => ({ isValid: err, value: filteredValue })
                );
              },
              (err) => ({ isValid: err })
            );
          }),
          share()
        );
        const success = validation.pipe(
          filter((state) => state.isValid === true),
          take(1)
        );
        const error = validation.pipe(
          filter((state) => state.isValid !== true),
          takeUntil(success)
        );
        return {
          success,
          error
        };
      }
      startSpinner(value2, bottomContent) {
        value2 = this.getSpinningValue(value2);
        const content = bottomContent ? this.getQuestion() + value2 : this.getQuestion().slice(this.opt.prefix.length + 1) + value2;
        this.screen.renderWithSpinner(content, bottomContent);
      }
      /**
       * Allow override, e.g. for password prompts
       * See: https://github.com/SBoudrias/Inquirer.js/issues/1022
       *
       * @return {String} value to display while spinning
       */
      getSpinningValue(value2) {
        return value2;
      }
      /**
       * Generate the prompt question string
       * @return {String} prompt question string
       */
      getQuestion() {
        let message = (this.opt.prefix ? this.opt.prefix + " " : "") + chalk3.bold(this.opt.message) + this.opt.suffix + chalk3.reset(" ");
        if (this.opt.default != null && this.status !== "touched" && this.status !== "answered") {
          if (this.opt.type === "password") {
            message += chalk3.italic.dim("[hidden] ");
          } else {
            message += chalk3.dim("(" + this.opt.default + ") ");
          }
        }
        return message;
      }
    };
    module2.exports = Prompt;
  }
});

// node_modules/inquirer/lib/utils/events.js
var require_events = __commonJS({
  "node_modules/inquirer/lib/utils/events.js"(exports, module2) {
    "use strict";
    var { fromEvent } = require_cjs();
    var { filter, map, share, takeUntil } = require_operators();
    function normalizeKeypressEvents(value2, key) {
      return { value: value2, key: key || {} };
    }
    module2.exports = function(rl) {
      const keypress = fromEvent(rl.input, "keypress", normalizeKeypressEvents).pipe(takeUntil(fromEvent(rl, "close"))).pipe(filter(({ key }) => key.name !== "enter" && key.name !== "return"));
      return {
        line: fromEvent(rl, "line"),
        keypress,
        normalizedUpKey: keypress.pipe(
          filter(
            ({ key }) => key.name === "up" || key.name === "k" || key.name === "p" && key.ctrl
          ),
          share()
        ),
        normalizedDownKey: keypress.pipe(
          filter(
            ({ key }) => key.name === "down" || key.name === "j" || key.name === "n" && key.ctrl
          ),
          share()
        ),
        numberKey: keypress.pipe(
          filter((e) => e.value && "123456789".indexOf(e.value) >= 0),
          map((e) => Number(e.value)),
          share()
        ),
        spaceKey: keypress.pipe(
          filter(({ key }) => key && key.name === "space"),
          share()
        ),
        aKey: keypress.pipe(
          filter(({ key }) => key && key.name === "a"),
          share()
        ),
        iKey: keypress.pipe(
          filter(({ key }) => key && key.name === "i"),
          share()
        )
      };
    };
  }
});

// node_modules/inquirer/lib/utils/paginator.js
var require_paginator = __commonJS({
  "node_modules/inquirer/lib/utils/paginator.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var Paginator = class {
      /**
       * @param {import("./screen-manager")} [screen]
       * @param {{isInfinite?: boolean}} [options]
       */
      constructor(screen, options = {}) {
        const { isInfinite = true } = options;
        this.lastIndex = 0;
        this.screen = screen;
        this.isInfinite = isInfinite;
      }
      paginate(output, active, pageSize) {
        pageSize = pageSize || 7;
        let lines = output.split("\n");
        if (this.screen) {
          lines = this.screen.breakLines(lines);
          active = lines.map((lineParts) => lineParts.length).splice(0, active).reduce((a, b) => a + b, 0);
          lines = lines.flat();
        }
        if (lines.length <= pageSize) {
          return output;
        }
        const visibleLines = this.isInfinite ? this.getInfiniteLines(lines, active, pageSize) : this.getFiniteLines(lines, active, pageSize);
        this.lastIndex = active;
        return visibleLines.join("\n") + "\n" + chalk3.dim("(Move up and down to reveal more choices)");
      }
      getInfiniteLines(lines, active, pageSize) {
        if (this.pointer === void 0) {
          this.pointer = 0;
        }
        const middleOfList = Math.floor(pageSize / 2);
        if (this.pointer < middleOfList && this.lastIndex < active && active - this.lastIndex < pageSize) {
          this.pointer = Math.min(middleOfList, this.pointer + active - this.lastIndex);
        }
        const infinite = [lines, lines, lines].flat();
        const topIndex = Math.max(0, active + lines.length - this.pointer);
        return infinite.splice(topIndex, pageSize);
      }
      getFiniteLines(lines, active, pageSize) {
        let topIndex = active - pageSize / 2;
        if (topIndex < 0) {
          topIndex = 0;
        } else if (topIndex + pageSize > lines.length) {
          topIndex = lines.length - pageSize;
        }
        return lines.splice(topIndex, pageSize);
      }
    };
    module2.exports = Paginator;
  }
});

// node_modules/inquirer/lib/utils/incrementListIndex.js
var require_incrementListIndex = __commonJS({
  "node_modules/inquirer/lib/utils/incrementListIndex.js"(exports, module2) {
    function incrementListIndex(current, dir, opt) {
      const len = opt.choices.realLength;
      const shouldLoop = "loop" in opt ? Boolean(opt.loop) : true;
      if (dir === "up") {
        if (current > 0) {
          return current - 1;
        }
        return shouldLoop ? len - 1 : current;
      }
      if (dir === "down") {
        if (current < len - 1) {
          return current + 1;
        }
        return shouldLoop ? 0 : current;
      }
      throw new Error("dir must be up or down");
    }
    module2.exports = incrementListIndex;
  }
});

// node_modules/inquirer/lib/prompts/list.js
var require_list = __commonJS({
  "node_modules/inquirer/lib/prompts/list.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var figures = require_figures();
    var cliCursor = require_cli_cursor();
    var runAsync = require_run_async();
    var { flatMap, map, take, takeUntil } = require_operators();
    var Base = require_base();
    var observe = require_events();
    var Paginator = require_paginator();
    var incrementListIndex = require_incrementListIndex();
    var ListPrompt = class extends Base {
      constructor(questions, rl, answers) {
        super(questions, rl, answers);
        if (!this.opt.choices) {
          this.throwParamError("choices");
        }
        this.firstRender = true;
        this.selected = 0;
        const def = this.opt.default;
        if (typeof def === "number" && def >= 0 && def < this.opt.choices.realLength) {
          this.selected = def;
        } else if (typeof def !== "number" && def != null) {
          const index = this.opt.choices.realChoices.findIndex(({ value: value2 }) => value2 === def);
          this.selected = Math.max(index, 0);
        }
        this.opt.default = null;
        const shouldLoop = this.opt.loop === void 0 ? true : this.opt.loop;
        this.paginator = new Paginator(this.screen, { isInfinite: shouldLoop });
      }
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const self2 = this;
        const events = observe(this.rl);
        events.normalizedUpKey.pipe(takeUntil(events.line)).forEach(this.onUpKey.bind(this));
        events.normalizedDownKey.pipe(takeUntil(events.line)).forEach(this.onDownKey.bind(this));
        events.numberKey.pipe(takeUntil(events.line)).forEach(this.onNumberKey.bind(this));
        events.line.pipe(
          take(1),
          map(this.getCurrentValue.bind(this)),
          flatMap(
            (value2) => runAsync(self2.opt.filter)(value2, self2.answers).catch((err) => err)
          )
        ).forEach(this.onSubmit.bind(this));
        cliCursor.hide();
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {ListPrompt} self
       */
      render() {
        let message = this.getQuestion();
        if (this.firstRender) {
          message += chalk3.dim("(Use arrow keys)");
        }
        if (this.status === "answered") {
          message += chalk3.cyan(this.opt.choices.getChoice(this.selected).short);
        } else {
          const choicesStr = listRender(this.opt.choices, this.selected);
          const indexPosition = this.opt.choices.indexOf(
            this.opt.choices.getChoice(this.selected)
          );
          const realIndexPosition = this.opt.choices.reduce((acc, value2, i) => {
            if (i > indexPosition) {
              return acc;
            }
            if (value2.type === "separator") {
              return acc + 1;
            }
            let l = value2.name;
            if (typeof l !== "string") {
              return acc + 1;
            }
            l = l.split("\n");
            return acc + l.length;
          }, 0) - 1;
          message += "\n" + this.paginator.paginate(choicesStr, realIndexPosition, this.opt.pageSize);
        }
        this.firstRender = false;
        this.screen.render(message);
      }
      /**
       * When user press `enter` key
       */
      onSubmit(value2) {
        this.status = "answered";
        this.render();
        this.screen.done();
        cliCursor.show();
        this.done(value2);
      }
      getCurrentValue() {
        return this.opt.choices.getChoice(this.selected).value;
      }
      /**
       * When user press a key
       */
      onUpKey() {
        this.selected = incrementListIndex(this.selected, "up", this.opt);
        this.render();
      }
      onDownKey() {
        this.selected = incrementListIndex(this.selected, "down", this.opt);
        this.render();
      }
      onNumberKey(input) {
        if (input <= this.opt.choices.realLength) {
          this.selected = input - 1;
        }
        this.render();
      }
    };
    function listRender(choices, pointer) {
      let output = "";
      let separatorOffset = 0;
      choices.forEach((choice, i) => {
        if (choice.type === "separator") {
          separatorOffset++;
          output += "  " + choice + "\n";
          return;
        }
        if (choice.disabled) {
          separatorOffset++;
          output += "  - " + choice.name;
          output += ` (${typeof choice.disabled === "string" ? choice.disabled : "Disabled"})`;
          output += "\n";
          return;
        }
        const isSelected = i - separatorOffset === pointer;
        let line = (isSelected ? figures.pointer + " " : "  ") + choice.name;
        if (isSelected) {
          line = chalk3.cyan(line);
        }
        output += line + " \n";
      });
      return output.replace(/\n$/, "");
    }
    module2.exports = ListPrompt;
  }
});

// node_modules/inquirer/lib/prompts/input.js
var require_input = __commonJS({
  "node_modules/inquirer/lib/prompts/input.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { map, takeUntil } = require_operators();
    var Base = require_base();
    var observe = require_events();
    var InputPrompt = class extends Base {
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        const submit = events.line.pipe(map(this.filterInput.bind(this)));
        const validation = this.handleSubmitEvents(submit);
        validation.success.forEach(this.onEnd.bind(this));
        validation.error.forEach(this.onError.bind(this));
        events.keypress.pipe(takeUntil(validation.success)).forEach(this.onKeypress.bind(this));
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {InputPrompt} self
       */
      render(error) {
        let bottomContent = "";
        let appendContent = "";
        let message = this.getQuestion();
        const { transformer } = this.opt;
        const isFinal = this.status === "answered";
        if (isFinal) {
          appendContent = this.answer;
        } else {
          appendContent = this.rl.line;
        }
        if (transformer) {
          message += transformer(appendContent, this.answers, { isFinal });
        } else {
          message += isFinal ? chalk3.cyan(appendContent) : appendContent;
        }
        if (error) {
          bottomContent = chalk3.red(">> ") + error;
        }
        this.screen.render(message, bottomContent);
      }
      /**
       * When user press `enter` key
       */
      filterInput(input) {
        if (!input) {
          return this.opt.default == null ? "" : this.opt.default;
        }
        return input;
      }
      onEnd(state) {
        this.answer = state.value;
        this.status = "answered";
        this.render();
        this.screen.done();
        this.done(state.value);
      }
      onError({ value: value2 = "", isValid }) {
        this.rl.line += value2;
        this.rl.cursor += value2.length;
        this.render(isValid);
      }
      /**
       * When user press a key
       */
      onKeypress() {
        this.status = "touched";
        this.render();
      }
    };
    module2.exports = InputPrompt;
  }
});

// node_modules/inquirer/lib/prompts/number.js
var require_number = __commonJS({
  "node_modules/inquirer/lib/prompts/number.js"(exports, module2) {
    "use strict";
    var Input = require_input();
    var NumberPrompt = class extends Input {
      filterInput(input) {
        if (input && typeof input === "string") {
          input = input.trim();
          const numberMatch = input.match(/(^-?\d+|^-?\d+\.\d*|^\d*\.\d+)(e\d+)?$/);
          if (numberMatch) {
            return Number(numberMatch[0]);
          }
        }
        return this.opt.default == null ? NaN : this.opt.default;
      }
    };
    module2.exports = NumberPrompt;
  }
});

// node_modules/inquirer/lib/prompts/confirm.js
var require_confirm = __commonJS({
  "node_modules/inquirer/lib/prompts/confirm.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { take, takeUntil } = require_operators();
    var Base = require_base();
    var observe = require_events();
    var ConfirmPrompt = class extends Base {
      constructor(questions, rl, answers) {
        super(questions, rl, answers);
        let rawDefault = true;
        Object.assign(this.opt, {
          filter(input) {
            let value2 = rawDefault;
            if (input != null && input !== "") {
              value2 = /^y(es)?/i.test(input);
            }
            return value2;
          }
        });
        if (this.opt.default != null) {
          rawDefault = Boolean(this.opt.default);
        }
        this.opt.default = rawDefault ? "Y/n" : "y/N";
      }
      /**
       * Start the Inquiry session
       * @param  {Function} cb   Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        events.keypress.pipe(takeUntil(events.line)).forEach(this.onKeypress.bind(this));
        events.line.pipe(take(1)).forEach(this.onEnd.bind(this));
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {ConfirmPrompt} self
       */
      render(answer) {
        let message = this.getQuestion();
        if (typeof answer === "boolean") {
          message += chalk3.cyan(answer ? "Yes" : "No");
        } else {
          message += this.rl.line;
        }
        this.screen.render(message);
        return this;
      }
      /**
       * When user press `enter` key
       */
      onEnd(input) {
        this.status = "answered";
        const output = this.opt.filter(input);
        this.render(output);
        this.screen.done();
        this.done(output);
      }
      /**
       * When user press a key
       */
      onKeypress() {
        this.render();
      }
    };
    module2.exports = ConfirmPrompt;
  }
});

// node_modules/inquirer/lib/prompts/rawlist.js
var require_rawlist = __commonJS({
  "node_modules/inquirer/lib/prompts/rawlist.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { map, takeUntil } = require_operators();
    var Base = require_base();
    var Separator = require_separator();
    var observe = require_events();
    var Paginator = require_paginator();
    var incrementListIndex = require_incrementListIndex();
    var RawListPrompt = class extends Base {
      constructor(questions, rl, answers) {
        super(questions, rl, answers);
        this.hiddenLine = "";
        this.lastKey = "";
        if (!this.opt.choices) {
          this.throwParamError("choices");
        }
        this.opt.validChoices = this.opt.choices.filter(Separator.exclude);
        this.selected = 0;
        this.rawDefault = 0;
        Object.assign(this.opt, {
          validate(val) {
            return val != null;
          }
        });
        const def = this.opt.default;
        if (typeof def === "number" && def >= 0 && def < this.opt.choices.realLength) {
          this.selected = def;
          this.rawDefault = def;
        } else if (typeof def !== "number" && def != null) {
          const index = this.opt.choices.realChoices.findIndex(({ value: value2 }) => value2 === def);
          const safeIndex = Math.max(index, 0);
          this.selected = safeIndex;
          this.rawDefault = safeIndex;
        }
        this.opt.default = null;
        const shouldLoop = this.opt.loop === void 0 ? true : this.opt.loop;
        this.paginator = new Paginator(void 0, { isInfinite: shouldLoop });
      }
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        const submit = events.line.pipe(map(this.getCurrentValue.bind(this)));
        const validation = this.handleSubmitEvents(submit);
        validation.success.forEach(this.onEnd.bind(this));
        validation.error.forEach(this.onError.bind(this));
        events.normalizedUpKey.pipe(takeUntil(validation.success)).forEach(this.onUpKey.bind(this));
        events.normalizedDownKey.pipe(takeUntil(validation.success)).forEach(this.onDownKey.bind(this));
        events.keypress.pipe(takeUntil(validation.success)).forEach(this.onKeypress.bind(this));
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {RawListPrompt} self
       */
      render(error) {
        let message = this.getQuestion();
        let bottomContent = "";
        if (this.status === "answered") {
          message += chalk3.cyan(this.opt.choices.getChoice(this.selected).short);
        } else {
          const choicesStr = renderChoices(this.opt.choices, this.selected);
          message += "\n" + this.paginator.paginate(choicesStr, this.selected, this.opt.pageSize);
          message += "\n  Answer: ";
        }
        message += this.rl.line;
        if (error) {
          bottomContent = "\n" + chalk3.red(">> ") + error;
        }
        this.screen.render(message, bottomContent);
      }
      /**
       * When user press `enter` key
       */
      getCurrentValue(index) {
        if (index == null) {
          index = this.rawDefault;
        } else if (index === "") {
          this.selected = this.selected === void 0 ? -1 : this.selected;
          index = this.selected;
        } else {
          index -= 1;
        }
        const choice = this.opt.choices.getChoice(index);
        return choice ? choice.value : null;
      }
      onEnd(state) {
        this.status = "answered";
        this.answer = state.value;
        this.render();
        this.screen.done();
        this.done(state.value);
      }
      onError() {
        this.render("Please enter a valid index");
      }
      /**
       * When user press a key
       */
      onKeypress() {
        let index;
        if (this.lastKey === "arrow") {
          index = this.hiddenLine.length ? Number(this.hiddenLine) - 1 : 0;
        } else {
          index = this.rl.line.length ? Number(this.rl.line) - 1 : 0;
        }
        this.lastKey = "";
        if (this.opt.choices.getChoice(index)) {
          this.selected = index;
        } else {
          this.selected = void 0;
        }
        this.render();
      }
      /**
       * When user press up key
       */
      onUpKey() {
        this.onArrowKey("up");
      }
      /**
       * When user press down key
       */
      onDownKey() {
        this.onArrowKey("down");
      }
      /**
       * When user press up or down key
       * @param {String} type Arrow type: up or down
       */
      onArrowKey(type) {
        this.selected = incrementListIndex(this.selected, type, this.opt) || 0;
        this.hiddenLine = String(this.selected + 1);
        this.rl.line = "";
        this.lastKey = "arrow";
      }
    };
    function renderChoices(choices, pointer) {
      let output = "";
      let separatorOffset = 0;
      choices.forEach((choice, i) => {
        output += output ? "\n  " : "  ";
        if (choice.type === "separator") {
          separatorOffset++;
          output += " " + choice;
          return;
        }
        const index = i - separatorOffset;
        let display = index + 1 + ") " + choice.name;
        if (index === pointer) {
          display = chalk3.cyan(display);
        }
        output += display;
      });
      return output;
    }
    module2.exports = RawListPrompt;
  }
});

// node_modules/inquirer/lib/prompts/expand.js
var require_expand2 = __commonJS({
  "node_modules/inquirer/lib/prompts/expand.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { map, takeUntil } = require_operators();
    var Base = require_base();
    var Separator = require_separator();
    var observe = require_events();
    var Paginator = require_paginator();
    var ExpandPrompt = class extends Base {
      constructor(questions, rl, answers) {
        super(questions, rl, answers);
        if (!this.opt.choices) {
          this.throwParamError("choices");
        }
        this.validateChoices(this.opt.choices);
        this.opt.choices.push({
          key: "h",
          name: "Help, list all options",
          value: "help"
        });
        this.opt.validate = (choice) => {
          if (choice == null) {
            return "Please enter a valid command";
          }
          return choice !== "help";
        };
        this.opt.default = this.generateChoicesString(this.opt.choices, this.opt.default);
        this.paginator = new Paginator(this.screen);
      }
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        const validation = this.handleSubmitEvents(
          events.line.pipe(map(this.getCurrentValue.bind(this)))
        );
        validation.success.forEach(this.onSubmit.bind(this));
        validation.error.forEach(this.onError.bind(this));
        this.keypressObs = events.keypress.pipe(takeUntil(validation.success)).forEach(this.onKeypress.bind(this));
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {ExpandPrompt} self
       */
      render(error, hint) {
        let message = this.getQuestion();
        let bottomContent = "";
        if (this.status === "answered") {
          message += chalk3.cyan(this.answer);
        } else if (this.status === "expanded") {
          const choicesStr = renderChoices(this.opt.choices, this.selectedKey);
          message += this.paginator.paginate(choicesStr, this.selectedKey, this.opt.pageSize);
          message += "\n  Answer: ";
        }
        message += this.rl.line;
        if (error) {
          bottomContent = chalk3.red(">> ") + error;
        }
        if (hint) {
          bottomContent = chalk3.cyan(">> ") + hint;
        }
        this.screen.render(message, bottomContent);
      }
      getCurrentValue(input) {
        if (!input) {
          input = this.rawDefault;
        }
        const selected = this.opt.choices.where({ key: input.toLowerCase().trim() })[0];
        if (!selected) {
          return null;
        }
        return selected.value;
      }
      /**
       * Generate the prompt choices string
       * @return {String}  Choices string
       */
      getChoices() {
        let output = "";
        this.opt.choices.forEach((choice) => {
          output += "\n  ";
          if (choice.type === "separator") {
            output += " " + choice;
            return;
          }
          let choiceStr = choice.key + ") " + choice.name;
          if (this.selectedKey === choice.key) {
            choiceStr = chalk3.cyan(choiceStr);
          }
          output += choiceStr;
        });
        return output;
      }
      onError(state) {
        if (state.value === "help") {
          this.selectedKey = "";
          this.status = "expanded";
          this.render();
          return;
        }
        this.render(state.isValid);
      }
      /**
       * When user press `enter` key
       */
      onSubmit(state) {
        this.status = "answered";
        const choice = this.opt.choices.where({ value: state.value })[0];
        this.answer = choice.short || choice.name;
        this.render();
        this.screen.done();
        this.done(state.value);
      }
      /**
       * When user press a key
       */
      onKeypress() {
        this.selectedKey = this.rl.line.toLowerCase();
        const selected = this.opt.choices.where({ key: this.selectedKey })[0];
        if (this.status === "expanded") {
          this.render();
        } else {
          this.render(null, selected ? selected.name : null);
        }
      }
      /**
       * Validate the choices
       * @param {Array} choices
       */
      validateChoices(choices) {
        let formatError;
        const errors = [];
        const keymap = {};
        choices.filter(Separator.exclude).forEach((choice) => {
          if (!choice.key || choice.key.length !== 1) {
            formatError = true;
          }
          choice.key = String(choice.key).toLowerCase();
          if (keymap[choice.key]) {
            errors.push(choice.key);
          }
          keymap[choice.key] = true;
        });
        if (formatError) {
          throw new Error(
            "Format error: `key` param must be a single letter and is required."
          );
        }
        if (keymap.h) {
          throw new Error(
            "Reserved key error: `key` param cannot be `h` - this value is reserved."
          );
        }
        if (errors.length) {
          throw new Error(
            "Duplicate key error: `key` param must be unique. Duplicates: " + [...new Set(errors)].join(",")
          );
        }
      }
      /**
       * Generate a string out of the choices keys
       * @param  {Array}  choices
       * @param  {Number|String} default - the choice index or name to capitalize
       * @return {String} The rendered choices key string
       */
      generateChoicesString(choices, defaultChoice) {
        let defIndex = choices.realLength - 1;
        if (typeof defaultChoice === "number" && this.opt.choices.getChoice(defaultChoice)) {
          defIndex = defaultChoice;
        } else if (typeof defaultChoice === "string") {
          const index = choices.realChoices.findIndex(({ value: value2 }) => value2 === defaultChoice);
          defIndex = index === -1 ? defIndex : index;
        }
        const defStr = this.opt.choices.pluck("key");
        this.rawDefault = defStr[defIndex];
        defStr[defIndex] = String(defStr[defIndex]).toUpperCase();
        return defStr.join("");
      }
    };
    function renderChoices(choices, pointer) {
      let output = "";
      choices.forEach((choice) => {
        output += "\n  ";
        if (choice.type === "separator") {
          output += " " + choice;
          return;
        }
        let choiceStr = choice.key + ") " + choice.name;
        if (pointer === choice.key) {
          choiceStr = chalk3.cyan(choiceStr);
        }
        output += choiceStr;
      });
      return output;
    }
    module2.exports = ExpandPrompt;
  }
});

// node_modules/inquirer/lib/prompts/checkbox.js
var require_checkbox = __commonJS({
  "node_modules/inquirer/lib/prompts/checkbox.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var cliCursor = require_cli_cursor();
    var figures = require_figures();
    var { map, takeUntil } = require_operators();
    var Base = require_base();
    var observe = require_events();
    var Paginator = require_paginator();
    var incrementListIndex = require_incrementListIndex();
    var CheckboxPrompt = class extends Base {
      constructor(questions, rl, answers) {
        super(questions, rl, answers);
        if (!this.opt.choices) {
          this.throwParamError("choices");
        }
        if (Array.isArray(this.opt.default)) {
          this.opt.choices.forEach(function(choice) {
            if (this.opt.default.indexOf(choice.value) >= 0) {
              choice.checked = true;
            }
          }, this);
        }
        this.pointer = 0;
        this.opt.default = null;
        const shouldLoop = this.opt.loop === void 0 ? true : this.opt.loop;
        this.paginator = new Paginator(this.screen, { isInfinite: shouldLoop });
      }
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        const validation = this.handleSubmitEvents(
          events.line.pipe(map(this.getCurrentValue.bind(this)))
        );
        validation.success.forEach(this.onEnd.bind(this));
        validation.error.forEach(this.onError.bind(this));
        events.normalizedUpKey.pipe(takeUntil(validation.success)).forEach(this.onUpKey.bind(this));
        events.normalizedDownKey.pipe(takeUntil(validation.success)).forEach(this.onDownKey.bind(this));
        events.numberKey.pipe(takeUntil(validation.success)).forEach(this.onNumberKey.bind(this));
        events.spaceKey.pipe(takeUntil(validation.success)).forEach(this.onSpaceKey.bind(this));
        events.aKey.pipe(takeUntil(validation.success)).forEach(this.onAllKey.bind(this));
        events.iKey.pipe(takeUntil(validation.success)).forEach(this.onInverseKey.bind(this));
        cliCursor.hide();
        this.render();
        this.firstRender = false;
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {CheckboxPrompt} self
       */
      render(error) {
        let message = this.getQuestion();
        let bottomContent = "";
        if (!this.dontShowHints) {
          message += "(Press " + chalk3.cyan.bold("<space>") + " to select, " + chalk3.cyan.bold("<a>") + " to toggle all, " + chalk3.cyan.bold("<i>") + " to invert selection, and " + chalk3.cyan.bold("<enter>") + " to proceed)";
        }
        if (this.status === "answered") {
          message += chalk3.cyan(this.selection.join(", "));
        } else {
          const choicesStr = renderChoices(this.opt.choices, this.pointer);
          const indexPosition = this.opt.choices.indexOf(
            this.opt.choices.getChoice(this.pointer)
          );
          const realIndexPosition = this.opt.choices.reduce((acc, value2, i) => {
            if (i > indexPosition) {
              return acc;
            }
            if (value2.type === "separator") {
              return acc + 1;
            }
            let l = value2.name;
            if (typeof l !== "string") {
              return acc + 1;
            }
            l = l.split("\n");
            return acc + l.length;
          }, 0) - 1;
          message += "\n" + this.paginator.paginate(choicesStr, realIndexPosition, this.opt.pageSize);
        }
        if (error) {
          bottomContent = chalk3.red(">> ") + error;
        }
        this.screen.render(message, bottomContent);
      }
      /**
       * When user press `enter` key
       */
      onEnd(state) {
        this.status = "answered";
        this.dontShowHints = true;
        this.render();
        this.screen.done();
        cliCursor.show();
        this.done(state.value);
      }
      onError(state) {
        this.render(state.isValid);
      }
      getCurrentValue() {
        const choices = this.opt.choices.filter(
          (choice) => Boolean(choice.checked) && !choice.disabled
        );
        this.selection = choices.map((choice) => choice.short);
        return choices.map((choice) => choice.value);
      }
      onUpKey() {
        this.pointer = incrementListIndex(this.pointer, "up", this.opt);
        this.render();
      }
      onDownKey() {
        this.pointer = incrementListIndex(this.pointer, "down", this.opt);
        this.render();
      }
      onNumberKey(input) {
        if (input <= this.opt.choices.realLength) {
          this.pointer = input - 1;
          this.toggleChoice(this.pointer);
        }
        this.render();
      }
      onSpaceKey() {
        this.toggleChoice(this.pointer);
        this.render();
      }
      onAllKey() {
        const shouldBeChecked = Boolean(
          this.opt.choices.find((choice) => choice.type !== "separator" && !choice.checked)
        );
        this.opt.choices.forEach((choice) => {
          if (choice.type !== "separator") {
            choice.checked = shouldBeChecked;
          }
        });
        this.render();
      }
      onInverseKey() {
        this.opt.choices.forEach((choice) => {
          if (choice.type !== "separator") {
            choice.checked = !choice.checked;
          }
        });
        this.render();
      }
      toggleChoice(index) {
        const item = this.opt.choices.getChoice(index);
        if (item !== void 0) {
          this.opt.choices.getChoice(index).checked = !item.checked;
        }
      }
    };
    function renderChoices(choices, pointer) {
      let output = "";
      let separatorOffset = 0;
      choices.forEach((choice, i) => {
        if (choice.type === "separator") {
          separatorOffset++;
          output += " " + choice + "\n";
          return;
        }
        if (choice.disabled) {
          separatorOffset++;
          output += " - " + choice.name;
          output += ` (${typeof choice.disabled === "string" ? choice.disabled : "Disabled"})`;
        } else {
          const line = getCheckbox(choice.checked) + " " + choice.name;
          if (i - separatorOffset === pointer) {
            output += chalk3.cyan(figures.pointer + line);
          } else {
            output += " " + line;
          }
        }
        output += "\n";
      });
      return output.replace(/\n$/, "");
    }
    function getCheckbox(checked) {
      return checked ? chalk3.green(figures.radioOn) : figures.radioOff;
    }
    module2.exports = CheckboxPrompt;
  }
});

// node_modules/inquirer/lib/prompts/password.js
var require_password = __commonJS({
  "node_modules/inquirer/lib/prompts/password.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { map, takeUntil } = require_operators();
    var Base = require_base();
    var observe = require_events();
    function mask(input, maskChar) {
      input = String(input);
      maskChar = typeof maskChar === "string" ? maskChar : "*";
      if (input.length === 0) {
        return "";
      }
      return new Array(input.length + 1).join(maskChar);
    }
    var PasswordPrompt = class extends Base {
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        const events = observe(this.rl);
        const submit = events.line.pipe(map(this.filterInput.bind(this)));
        const validation = this.handleSubmitEvents(submit);
        validation.success.forEach(this.onEnd.bind(this));
        validation.error.forEach(this.onError.bind(this));
        events.keypress.pipe(takeUntil(validation.success)).forEach(this.onKeypress.bind(this));
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {PasswordPrompt} self
       */
      render(error) {
        let message = this.getQuestion();
        let bottomContent = "";
        if (this.status === "answered") {
          message += this.getMaskedValue(this.answer);
        } else {
          message += this.getMaskedValue(this.rl.line || "");
        }
        if (error) {
          bottomContent = "\n" + chalk3.red(">> ") + error;
        }
        this.screen.render(message, bottomContent);
      }
      getMaskedValue(value2) {
        if (this.status === "answered") {
          return this.opt.mask ? chalk3.cyan(mask(value2, this.opt.mask)) : chalk3.italic.dim("[hidden]");
        }
        return this.opt.mask ? mask(value2, this.opt.mask) : chalk3.italic.dim("[input is hidden] ");
      }
      /**
       * Mask value during async filter/validation.
       */
      getSpinningValue(value2) {
        return this.getMaskedValue(value2);
      }
      /**
       * When user press `enter` key
       */
      filterInput(input) {
        if (!input) {
          return this.opt.default == null ? "" : this.opt.default;
        }
        return input;
      }
      onEnd(state) {
        this.status = "answered";
        this.answer = state.value;
        this.render();
        this.screen.done();
        this.done(state.value);
      }
      onError(state) {
        this.render(state.isValid);
      }
      onKeypress() {
        if (this.opt.default) {
          this.opt.default = void 0;
        }
        this.render();
      }
    };
    module2.exports = PasswordPrompt;
  }
});

// node_modules/chardet/match.js
var require_match = __commonJS({
  "node_modules/chardet/match.js"(exports, module2) {
    module2.exports = function(det, rec, confidence, name, lang) {
      this.confidence = confidence;
      this.name = name || rec.name(det);
      this.lang = lang;
    };
  }
});

// node_modules/chardet/encoding/utf8.js
var require_utf8 = __commonJS({
  "node_modules/chardet/encoding/utf8.js"(exports, module2) {
    var Match = require_match();
    module2.exports = function() {
      this.name = function() {
        return "UTF-8";
      };
      this.match = function(det) {
        var hasBOM = false, numValid = 0, numInvalid = 0, input = det.fRawInput, trailBytes = 0, confidence;
        if (det.fRawLength >= 3 && (input[0] & 255) == 239 && (input[1] & 255) == 187 && (input[2] & 255) == 191) {
          hasBOM = true;
        }
        for (var i = 0; i < det.fRawLength; i++) {
          var b = input[i];
          if ((b & 128) == 0)
            continue;
          if ((b & 224) == 192) {
            trailBytes = 1;
          } else if ((b & 240) == 224) {
            trailBytes = 2;
          } else if ((b & 248) == 240) {
            trailBytes = 3;
          } else {
            numInvalid++;
            if (numInvalid > 5)
              break;
            trailBytes = 0;
          }
          for (; ; ) {
            i++;
            if (i >= det.fRawLength)
              break;
            if ((input[i] & 192) != 128) {
              numInvalid++;
              break;
            }
            if (--trailBytes == 0) {
              numValid++;
              break;
            }
          }
        }
        confidence = 0;
        if (hasBOM && numInvalid == 0)
          confidence = 100;
        else if (hasBOM && numValid > numInvalid * 10)
          confidence = 80;
        else if (numValid > 3 && numInvalid == 0)
          confidence = 100;
        else if (numValid > 0 && numInvalid == 0)
          confidence = 80;
        else if (numValid == 0 && numInvalid == 0)
          confidence = 10;
        else if (numValid > numInvalid * 10)
          confidence = 25;
        else
          return null;
        return new Match(det, this, confidence);
      };
    };
  }
});

// node_modules/chardet/encoding/unicode.js
var require_unicode = __commonJS({
  "node_modules/chardet/encoding/unicode.js"(exports, module2) {
    "use strict";
    var util = require("util");
    var Match = require_match();
    module2.exports.UTF_16BE = function() {
      this.name = function() {
        return "UTF-16BE";
      };
      this.match = function(det) {
        var input = det.fRawInput;
        if (input.length >= 2 && ((input[0] & 255) == 254 && (input[1] & 255) == 255)) {
          return new Match(det, this, 100);
        }
        return null;
      };
    };
    module2.exports.UTF_16LE = function() {
      this.name = function() {
        return "UTF-16LE";
      };
      this.match = function(det) {
        var input = det.fRawInput;
        if (input.length >= 2 && ((input[0] & 255) == 255 && (input[1] & 255) == 254)) {
          if (input.length >= 4 && input[2] == 0 && input[3] == 0) {
            return null;
          }
          return new Match(det, this, 100);
        }
        return null;
      };
    };
    function UTF_32() {
    }
    UTF_32.prototype.match = function(det) {
      var input = det.fRawInput, limit = det.fRawLength / 4 * 4, numValid = 0, numInvalid = 0, hasBOM = false, confidence = 0;
      if (limit == 0) {
        return null;
      }
      if (this.getChar(input, 0) == 65279) {
        hasBOM = true;
      }
      for (var i = 0; i < limit; i += 4) {
        var ch = this.getChar(input, i);
        if (ch < 0 || ch >= 1114111 || ch >= 55296 && ch <= 57343) {
          numInvalid += 1;
        } else {
          numValid += 1;
        }
      }
      if (hasBOM && numInvalid == 0) {
        confidence = 100;
      } else if (hasBOM && numValid > numInvalid * 10) {
        confidence = 80;
      } else if (numValid > 3 && numInvalid == 0) {
        confidence = 100;
      } else if (numValid > 0 && numInvalid == 0) {
        confidence = 80;
      } else if (numValid > numInvalid * 10) {
        confidence = 25;
      }
      return confidence == 0 ? null : new Match(det, this, confidence);
    };
    module2.exports.UTF_32BE = function() {
      this.name = function() {
        return "UTF-32BE";
      };
      this.getChar = function(input, index) {
        return (input[index + 0] & 255) << 24 | (input[index + 1] & 255) << 16 | (input[index + 2] & 255) << 8 | input[index + 3] & 255;
      };
    };
    util.inherits(module2.exports.UTF_32BE, UTF_32);
    module2.exports.UTF_32LE = function() {
      this.name = function() {
        return "UTF-32LE";
      };
      this.getChar = function(input, index) {
        return (input[index + 3] & 255) << 24 | (input[index + 2] & 255) << 16 | (input[index + 1] & 255) << 8 | input[index + 0] & 255;
      };
    };
    util.inherits(module2.exports.UTF_32LE, UTF_32);
  }
});

// node_modules/chardet/encoding/mbcs.js
var require_mbcs = __commonJS({
  "node_modules/chardet/encoding/mbcs.js"(exports, module2) {
    var util = require("util");
    var Match = require_match();
    function binarySearch(arr, searchValue) {
      function find(arr2, searchValue2, left, right) {
        if (right < left)
          return -1;
        var mid = Math.floor(left + right >>> 1);
        if (searchValue2 > arr2[mid])
          return find(arr2, searchValue2, mid + 1, right);
        if (searchValue2 < arr2[mid])
          return find(arr2, searchValue2, left, mid - 1);
        return mid;
      }
      ;
      return find(arr, searchValue, 0, arr.length - 1);
    }
    function IteratedChar() {
      this.charValue = 0;
      this.index = 0;
      this.nextIndex = 0;
      this.error = false;
      this.done = false;
      this.reset = function() {
        this.charValue = 0;
        this.index = -1;
        this.nextIndex = 0;
        this.error = false;
        this.done = false;
      };
      this.nextByte = function(det) {
        if (this.nextIndex >= det.fRawLength) {
          this.done = true;
          return -1;
        }
        var byteValue = det.fRawInput[this.nextIndex++] & 255;
        return byteValue;
      };
    }
    function mbcs() {
    }
    mbcs.prototype.match = function(det) {
      var singleByteCharCount = 0, doubleByteCharCount = 0, commonCharCount = 0, badCharCount = 0, totalCharCount = 0, confidence = 0;
      var iter = new IteratedChar();
      detectBlock: {
        for (iter.reset(); this.nextChar(iter, det); ) {
          totalCharCount++;
          if (iter.error) {
            badCharCount++;
          } else {
            var cv = iter.charValue & 4294967295;
            if (cv <= 255) {
              singleByteCharCount++;
            } else {
              doubleByteCharCount++;
              if (this.commonChars != null) {
                if (binarySearch(this.commonChars, cv) >= 0) {
                  commonCharCount++;
                }
              }
            }
          }
          if (badCharCount >= 2 && badCharCount * 5 >= doubleByteCharCount) {
            break detectBlock;
          }
        }
        if (doubleByteCharCount <= 10 && badCharCount == 0) {
          if (doubleByteCharCount == 0 && totalCharCount < 10) {
            confidence = 0;
          } else {
            confidence = 10;
          }
          break detectBlock;
        }
        if (doubleByteCharCount < 20 * badCharCount) {
          confidence = 0;
          break detectBlock;
        }
        if (this.commonChars == null) {
          confidence = 30 + doubleByteCharCount - 20 * badCharCount;
          if (confidence > 100) {
            confidence = 100;
          }
        } else {
          var maxVal = Math.log(parseFloat(doubleByteCharCount) / 4);
          var scaleFactor = 90 / maxVal;
          confidence = Math.floor(Math.log(commonCharCount + 1) * scaleFactor + 10);
          confidence = Math.min(confidence, 100);
        }
      }
      return confidence == 0 ? null : new Match(det, this, confidence);
    };
    mbcs.prototype.nextChar = function(iter, det) {
    };
    module2.exports.sjis = function() {
      this.name = function() {
        return "Shift-JIS";
      };
      this.language = function() {
        return "ja";
      };
      this.commonChars = [
        33088,
        33089,
        33090,
        33093,
        33115,
        33129,
        33130,
        33141,
        33142,
        33440,
        33442,
        33444,
        33449,
        33450,
        33451,
        33453,
        33455,
        33457,
        33459,
        33461,
        33463,
        33469,
        33470,
        33473,
        33476,
        33477,
        33478,
        33480,
        33481,
        33484,
        33485,
        33500,
        33504,
        33511,
        33512,
        33513,
        33514,
        33520,
        33521,
        33601,
        33603,
        33614,
        33615,
        33624,
        33630,
        33634,
        33639,
        33653,
        33654,
        33673,
        33674,
        33675,
        33677,
        33683,
        36502,
        37882,
        38314
      ];
      this.nextChar = function(iter, det) {
        iter.index = iter.nextIndex;
        iter.error = false;
        var firstByte;
        firstByte = iter.charValue = iter.nextByte(det);
        if (firstByte < 0)
          return false;
        if (firstByte <= 127 || firstByte > 160 && firstByte <= 223)
          return true;
        var secondByte = iter.nextByte(det);
        if (secondByte < 0)
          return false;
        iter.charValue = firstByte << 8 | secondByte;
        if (!(secondByte >= 64 && secondByte <= 127 || secondByte >= 128 && secondByte <= 255)) {
          iter.error = true;
        }
        return true;
      };
    };
    util.inherits(module2.exports.sjis, mbcs);
    module2.exports.big5 = function() {
      this.name = function() {
        return "Big5";
      };
      this.language = function() {
        return "zh";
      };
      this.commonChars = [
        41280,
        41281,
        41282,
        41283,
        41287,
        41289,
        41333,
        41334,
        42048,
        42054,
        42055,
        42056,
        42065,
        42068,
        42071,
        42084,
        42090,
        42092,
        42103,
        42147,
        42148,
        42151,
        42177,
        42190,
        42193,
        42207,
        42216,
        42237,
        42304,
        42312,
        42328,
        42345,
        42445,
        42471,
        42583,
        42593,
        42594,
        42600,
        42608,
        42664,
        42675,
        42681,
        42707,
        42715,
        42726,
        42738,
        42816,
        42833,
        42841,
        42970,
        43171,
        43173,
        43181,
        43217,
        43219,
        43236,
        43260,
        43456,
        43474,
        43507,
        43627,
        43706,
        43710,
        43724,
        43772,
        44103,
        44111,
        44208,
        44242,
        44377,
        44745,
        45024,
        45290,
        45423,
        45747,
        45764,
        45935,
        46156,
        46158,
        46412,
        46501,
        46525,
        46544,
        46552,
        46705,
        47085,
        47207,
        47428,
        47832,
        47940,
        48033,
        48593,
        49860,
        50105,
        50240,
        50271
      ];
      this.nextChar = function(iter, det) {
        iter.index = iter.nextIndex;
        iter.error = false;
        var firstByte = iter.charValue = iter.nextByte(det);
        if (firstByte < 0)
          return false;
        if (firstByte <= 127 || firstByte == 255)
          return true;
        var secondByte = iter.nextByte(det);
        if (secondByte < 0)
          return false;
        iter.charValue = iter.charValue << 8 | secondByte;
        if (secondByte < 64 || secondByte == 127 || secondByte == 255)
          iter.error = true;
        return true;
      };
    };
    util.inherits(module2.exports.big5, mbcs);
    function eucNextChar(iter, det) {
      iter.index = iter.nextIndex;
      iter.error = false;
      var firstByte = 0;
      var secondByte = 0;
      var thirdByte = 0;
      buildChar: {
        firstByte = iter.charValue = iter.nextByte(det);
        if (firstByte < 0) {
          iter.done = true;
          break buildChar;
        }
        if (firstByte <= 141) {
          break buildChar;
        }
        secondByte = iter.nextByte(det);
        iter.charValue = iter.charValue << 8 | secondByte;
        if (firstByte >= 161 && firstByte <= 254) {
          if (secondByte < 161) {
            iter.error = true;
          }
          break buildChar;
        }
        if (firstByte == 142) {
          if (secondByte < 161) {
            iter.error = true;
          }
          break buildChar;
        }
        if (firstByte == 143) {
          thirdByte = iter.nextByte(det);
          iter.charValue = iter.charValue << 8 | thirdByte;
          if (thirdByte < 161) {
            iter.error = true;
          }
        }
      }
      return iter.done == false;
    }
    module2.exports.euc_jp = function() {
      this.name = function() {
        return "EUC-JP";
      };
      this.language = function() {
        return "ja";
      };
      this.commonChars = [
        41377,
        41378,
        41379,
        41382,
        41404,
        41418,
        41419,
        41430,
        41431,
        42146,
        42148,
        42150,
        42152,
        42154,
        42155,
        42156,
        42157,
        42159,
        42161,
        42163,
        42165,
        42167,
        42169,
        42171,
        42173,
        42175,
        42176,
        42177,
        42179,
        42180,
        42182,
        42183,
        42184,
        42185,
        42186,
        42187,
        42190,
        42191,
        42192,
        42206,
        42207,
        42209,
        42210,
        42212,
        42216,
        42217,
        42218,
        42219,
        42220,
        42223,
        42226,
        42227,
        42402,
        42403,
        42404,
        42406,
        42407,
        42410,
        42413,
        42415,
        42416,
        42419,
        42421,
        42423,
        42424,
        42425,
        42431,
        42435,
        42438,
        42439,
        42440,
        42441,
        42443,
        42448,
        42453,
        42454,
        42455,
        42462,
        42464,
        42465,
        42469,
        42473,
        42474,
        42475,
        42476,
        42477,
        42483,
        47273,
        47572,
        47854,
        48072,
        48880,
        49079,
        50410,
        50940,
        51133,
        51896,
        51955,
        52188,
        52689
      ];
      this.nextChar = eucNextChar;
    };
    util.inherits(module2.exports.euc_jp, mbcs);
    module2.exports.euc_kr = function() {
      this.name = function() {
        return "EUC-KR";
      };
      this.language = function() {
        return "ko";
      };
      this.commonChars = [
        45217,
        45235,
        45253,
        45261,
        45268,
        45286,
        45293,
        45304,
        45306,
        45308,
        45496,
        45497,
        45511,
        45527,
        45538,
        45994,
        46011,
        46274,
        46287,
        46297,
        46315,
        46501,
        46517,
        46527,
        46535,
        46569,
        46835,
        47023,
        47042,
        47054,
        47270,
        47278,
        47286,
        47288,
        47291,
        47337,
        47531,
        47534,
        47564,
        47566,
        47613,
        47800,
        47822,
        47824,
        47857,
        48103,
        48115,
        48125,
        48301,
        48314,
        48338,
        48374,
        48570,
        48576,
        48579,
        48581,
        48838,
        48840,
        48863,
        48878,
        48888,
        48890,
        49057,
        49065,
        49088,
        49124,
        49131,
        49132,
        49144,
        49319,
        49327,
        49336,
        49338,
        49339,
        49341,
        49351,
        49356,
        49358,
        49359,
        49366,
        49370,
        49381,
        49403,
        49404,
        49572,
        49574,
        49590,
        49622,
        49631,
        49654,
        49656,
        50337,
        50637,
        50862,
        51151,
        51153,
        51154,
        51160,
        51173,
        51373
      ];
      this.nextChar = eucNextChar;
    };
    util.inherits(module2.exports.euc_kr, mbcs);
    module2.exports.gb_18030 = function() {
      this.name = function() {
        return "GB18030";
      };
      this.language = function() {
        return "zh";
      };
      this.nextChar = function(iter, det) {
        iter.index = iter.nextIndex;
        iter.error = false;
        var firstByte = 0;
        var secondByte = 0;
        var thirdByte = 0;
        var fourthByte = 0;
        buildChar: {
          firstByte = iter.charValue = iter.nextByte(det);
          if (firstByte < 0) {
            iter.done = true;
            break buildChar;
          }
          if (firstByte <= 128) {
            break buildChar;
          }
          secondByte = iter.nextByte(det);
          iter.charValue = iter.charValue << 8 | secondByte;
          if (firstByte >= 129 && firstByte <= 254) {
            if (secondByte >= 64 && secondByte <= 126 || secondByte >= 80 && secondByte <= 254) {
              break buildChar;
            }
            if (secondByte >= 48 && secondByte <= 57) {
              thirdByte = iter.nextByte(det);
              if (thirdByte >= 129 && thirdByte <= 254) {
                fourthByte = iter.nextByte(det);
                if (fourthByte >= 48 && fourthByte <= 57) {
                  iter.charValue = iter.charValue << 16 | thirdByte << 8 | fourthByte;
                  break buildChar;
                }
              }
            }
            iter.error = true;
            break buildChar;
          }
        }
        return iter.done == false;
      };
      this.commonChars = [
        41377,
        41378,
        41379,
        41380,
        41392,
        41393,
        41457,
        41459,
        41889,
        41900,
        41914,
        45480,
        45496,
        45502,
        45755,
        46025,
        46070,
        46323,
        46525,
        46532,
        46563,
        46767,
        46804,
        46816,
        47010,
        47016,
        47037,
        47062,
        47069,
        47284,
        47327,
        47350,
        47531,
        47561,
        47576,
        47610,
        47613,
        47821,
        48039,
        48086,
        48097,
        48122,
        48316,
        48347,
        48382,
        48588,
        48845,
        48861,
        49076,
        49094,
        49097,
        49332,
        49389,
        49611,
        49883,
        50119,
        50396,
        50410,
        50636,
        50935,
        51192,
        51371,
        51403,
        51413,
        51431,
        51663,
        51706,
        51889,
        51893,
        51911,
        51920,
        51926,
        51957,
        51965,
        52460,
        52728,
        52906,
        52932,
        52946,
        52965,
        53173,
        53186,
        53206,
        53442,
        53445,
        53456,
        53460,
        53671,
        53930,
        53938,
        53941,
        53947,
        53972,
        54211,
        54224,
        54269,
        54466,
        54490,
        54754,
        54992
      ];
    };
    util.inherits(module2.exports.gb_18030, mbcs);
  }
});

// node_modules/chardet/encoding/sbcs.js
var require_sbcs = __commonJS({
  "node_modules/chardet/encoding/sbcs.js"(exports, module2) {
    var util = require("util");
    var Match = require_match();
    function NGramParser(theNgramList, theByteMap) {
      var N_GRAM_MASK = 16777215;
      this.byteIndex = 0;
      this.ngram = 0;
      this.ngramList = theNgramList;
      this.byteMap = theByteMap;
      this.ngramCount = 0;
      this.hitCount = 0;
      this.spaceChar;
      this.search = function(table, value2) {
        var index = 0;
        if (table[index + 32] <= value2)
          index += 32;
        if (table[index + 16] <= value2)
          index += 16;
        if (table[index + 8] <= value2)
          index += 8;
        if (table[index + 4] <= value2)
          index += 4;
        if (table[index + 2] <= value2)
          index += 2;
        if (table[index + 1] <= value2)
          index += 1;
        if (table[index] > value2)
          index -= 1;
        if (index < 0 || table[index] != value2)
          return -1;
        return index;
      };
      this.lookup = function(thisNgram) {
        this.ngramCount += 1;
        if (this.search(this.ngramList, thisNgram) >= 0) {
          this.hitCount += 1;
        }
      };
      this.addByte = function(b) {
        this.ngram = (this.ngram << 8) + (b & 255) & N_GRAM_MASK;
        this.lookup(this.ngram);
      };
      this.nextByte = function(det) {
        if (this.byteIndex >= det.fInputLen)
          return -1;
        return det.fInputBytes[this.byteIndex++] & 255;
      };
      this.parse = function(det, spaceCh) {
        var b, ignoreSpace = false;
        this.spaceChar = spaceCh;
        while ((b = this.nextByte(det)) >= 0) {
          var mb = this.byteMap[b];
          if (mb != 0) {
            if (!(mb == this.spaceChar && ignoreSpace)) {
              this.addByte(mb);
            }
            ignoreSpace = mb == this.spaceChar;
          }
        }
        this.addByte(this.spaceChar);
        var rawPercent = this.hitCount / this.ngramCount;
        if (rawPercent > 0.33)
          return 98;
        return Math.floor(rawPercent * 300);
      };
    }
    function NGramsPlusLang(la, ng) {
      this.fLang = la;
      this.fNGrams = ng;
    }
    function sbcs() {
    }
    sbcs.prototype.spaceChar = 32;
    sbcs.prototype.ngrams = function() {
    };
    sbcs.prototype.byteMap = function() {
    };
    sbcs.prototype.match = function(det) {
      var ngrams = this.ngrams();
      var multiple = Array.isArray(ngrams) && ngrams[0] instanceof NGramsPlusLang;
      if (!multiple) {
        var parser = new NGramParser(ngrams, this.byteMap());
        var confidence = parser.parse(det, this.spaceChar);
        return confidence <= 0 ? null : new Match(det, this, confidence);
      }
      var bestConfidenceSoFar = -1;
      var lang = null;
      for (var i = ngrams.length - 1; i >= 0; i--) {
        var ngl = ngrams[i];
        var parser = new NGramParser(ngl.fNGrams, this.byteMap());
        var confidence = parser.parse(det, this.spaceChar);
        if (confidence > bestConfidenceSoFar) {
          bestConfidenceSoFar = confidence;
          lang = ngl.fLang;
        }
      }
      var name = this.name(det);
      return bestConfidenceSoFar <= 0 ? null : new Match(det, this, bestConfidenceSoFar, name, lang);
    };
    module2.exports.ISO_8859_1 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          170,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          181,
          32,
          32,
          32,
          32,
          186,
          32,
          32,
          32,
          32,
          32,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          255
        ];
      };
      this.ngrams = function() {
        return [
          new NGramsPlusLang("da", [
            2122086,
            2122100,
            2122853,
            2123118,
            2123122,
            2123375,
            2123873,
            2124064,
            2125157,
            2125671,
            2126053,
            2126697,
            2126708,
            2126953,
            2127465,
            6383136,
            6385184,
            6385252,
            6386208,
            6386720,
            6579488,
            6579566,
            6579570,
            6579572,
            6627443,
            6644768,
            6644837,
            6647328,
            6647396,
            6648352,
            6648421,
            6648608,
            6648864,
            6713202,
            6776096,
            6776174,
            6776178,
            6907749,
            6908960,
            6909543,
            7038240,
            7039845,
            7103858,
            7104871,
            7105637,
            7169380,
            7234661,
            7234848,
            7235360,
            7235429,
            7300896,
            7302432,
            7303712,
            7398688,
            7479396,
            7479397,
            7479411,
            7496992,
            7566437,
            7610483,
            7628064,
            7628146,
            7629164,
            7759218
          ]),
          new NGramsPlusLang("de", [
            2122094,
            2122101,
            2122341,
            2122849,
            2122853,
            2122857,
            2123113,
            2123621,
            2123873,
            2124142,
            2125161,
            2126691,
            2126693,
            2127214,
            2127461,
            2127471,
            2127717,
            2128501,
            6448498,
            6514720,
            6514789,
            6514804,
            6578547,
            6579566,
            6579570,
            6580581,
            6627428,
            6627443,
            6646126,
            6646132,
            6647328,
            6648352,
            6648608,
            6776174,
            6841710,
            6845472,
            6906728,
            6907168,
            6909472,
            6909541,
            6911008,
            7104867,
            7105637,
            7217249,
            7217252,
            7217267,
            7234592,
            7234661,
            7234848,
            7235360,
            7235429,
            7238757,
            7479396,
            7496805,
            7497065,
            7562088,
            7566437,
            7610468,
            7628064,
            7628142,
            7628146,
            7695972,
            7695975,
            7759218
          ]),
          new NGramsPlusLang("en", [
            2122016,
            2122094,
            2122341,
            2122607,
            2123375,
            2123873,
            2123877,
            2124142,
            2125153,
            2125670,
            2125938,
            2126437,
            2126689,
            2126708,
            2126952,
            2126959,
            2127720,
            6383972,
            6384672,
            6385184,
            6385252,
            6386464,
            6386720,
            6386789,
            6386793,
            6561889,
            6561908,
            6627425,
            6627443,
            6627444,
            6644768,
            6647412,
            6648352,
            6648608,
            6713202,
            6840692,
            6841632,
            6841714,
            6906912,
            6909472,
            6909543,
            6909806,
            6910752,
            7217249,
            7217268,
            7234592,
            7235360,
            7238688,
            7300640,
            7302688,
            7303712,
            7496992,
            7500576,
            7544929,
            7544948,
            7561577,
            7566368,
            7610484,
            7628146,
            7628897,
            7628901,
            7629167,
            7630624,
            7631648
          ]),
          new NGramsPlusLang("es", [
            2122016,
            2122593,
            2122607,
            2122853,
            2123116,
            2123118,
            2123123,
            2124142,
            2124897,
            2124911,
            2125921,
            2125935,
            2125938,
            2126197,
            2126437,
            2126693,
            2127214,
            2128160,
            6365283,
            6365284,
            6365285,
            6365292,
            6365296,
            6382441,
            6382703,
            6384672,
            6386208,
            6386464,
            6515187,
            6516590,
            6579488,
            6579564,
            6582048,
            6627428,
            6627429,
            6627436,
            6646816,
            6647328,
            6647412,
            6648608,
            6648692,
            6907246,
            6943598,
            7102752,
            7106419,
            7217253,
            7238757,
            7282788,
            7282789,
            7302688,
            7303712,
            7303968,
            7364978,
            7435621,
            7495968,
            7497075,
            7544932,
            7544933,
            7544944,
            7562528,
            7628064,
            7630624,
            7693600,
            15953440
          ]),
          new NGramsPlusLang("fr", [
            2122101,
            2122607,
            2122849,
            2122853,
            2122869,
            2123118,
            2123124,
            2124897,
            2124901,
            2125921,
            2125935,
            2125938,
            2126197,
            2126693,
            2126703,
            2127214,
            2154528,
            6385268,
            6386793,
            6513952,
            6516590,
            6579488,
            6579571,
            6583584,
            6627425,
            6627427,
            6627428,
            6627429,
            6627436,
            6627440,
            6627443,
            6647328,
            6647412,
            6648352,
            6648608,
            6648864,
            6649202,
            6909806,
            6910752,
            6911008,
            7102752,
            7103776,
            7103859,
            7169390,
            7217252,
            7234848,
            7238432,
            7238688,
            7302688,
            7302772,
            7304562,
            7435621,
            7479404,
            7496992,
            7544929,
            7544932,
            7544933,
            7544940,
            7544944,
            7610468,
            7628064,
            7629167,
            7693600,
            7696928
          ]),
          new NGramsPlusLang("it", [
            2122092,
            2122600,
            2122607,
            2122853,
            2122857,
            2123040,
            2124140,
            2124142,
            2124897,
            2125925,
            2125938,
            2127214,
            6365283,
            6365284,
            6365296,
            6365299,
            6386799,
            6514789,
            6516590,
            6579564,
            6580512,
            6627425,
            6627427,
            6627428,
            6627433,
            6627436,
            6627440,
            6627443,
            6646816,
            6646892,
            6647412,
            6648352,
            6841632,
            6889569,
            6889571,
            6889572,
            6889587,
            6906144,
            6908960,
            6909472,
            6909806,
            7102752,
            7103776,
            7104800,
            7105633,
            7234848,
            7235872,
            7237408,
            7238757,
            7282785,
            7282788,
            7282793,
            7282803,
            7302688,
            7302757,
            7366002,
            7495968,
            7496992,
            7563552,
            7627040,
            7628064,
            7629088,
            7630624,
            8022383
          ]),
          new NGramsPlusLang("nl", [
            2122092,
            2122341,
            2122849,
            2122853,
            2122857,
            2123109,
            2123118,
            2123621,
            2123877,
            2124142,
            2125153,
            2125157,
            2125680,
            2126949,
            2127457,
            2127461,
            2127471,
            2127717,
            2128489,
            6381934,
            6381938,
            6385184,
            6385252,
            6386208,
            6386720,
            6514804,
            6579488,
            6579566,
            6579570,
            6627426,
            6627446,
            6645102,
            6645106,
            6647328,
            6648352,
            6648435,
            6648864,
            6776174,
            6841716,
            6907168,
            6909472,
            6909543,
            6910752,
            7217250,
            7217252,
            7217253,
            7217256,
            7217263,
            7217270,
            7234661,
            7235360,
            7302756,
            7303026,
            7303200,
            7303712,
            7562088,
            7566437,
            7610468,
            7628064,
            7628142,
            7628146,
            7758190,
            7759218,
            7761775
          ]),
          new NGramsPlusLang("no", [
            2122100,
            2122102,
            2122853,
            2123118,
            2123122,
            2123375,
            2123873,
            2124064,
            2125157,
            2125671,
            2126053,
            2126693,
            2126699,
            2126703,
            2126708,
            2126953,
            2127465,
            2155808,
            6385252,
            6386208,
            6386720,
            6579488,
            6579566,
            6579572,
            6627443,
            6644768,
            6647328,
            6647397,
            6648352,
            6648421,
            6648864,
            6648948,
            6713202,
            6776174,
            6908779,
            6908960,
            6909543,
            7038240,
            7039845,
            7103776,
            7105637,
            7169380,
            7169390,
            7217267,
            7234848,
            7235360,
            7235429,
            7237221,
            7300896,
            7302432,
            7303712,
            7398688,
            7479411,
            7496992,
            7565165,
            7566437,
            7610483,
            7628064,
            7628142,
            7628146,
            7629164,
            7631904,
            7631973,
            7759218
          ]),
          new NGramsPlusLang("pt", [
            2122016,
            2122607,
            2122849,
            2122853,
            2122863,
            2123040,
            2123123,
            2125153,
            2125423,
            2125600,
            2125921,
            2125935,
            2125938,
            2126197,
            2126437,
            2126693,
            2127213,
            6365281,
            6365283,
            6365284,
            6365296,
            6382693,
            6382703,
            6384672,
            6386208,
            6386273,
            6386464,
            6516589,
            6516590,
            6578464,
            6579488,
            6582048,
            6582131,
            6627425,
            6627428,
            6647072,
            6647412,
            6648608,
            6648692,
            6906144,
            6906721,
            7169390,
            7238757,
            7238767,
            7282785,
            7282787,
            7282788,
            7282789,
            7282800,
            7303968,
            7364978,
            7435621,
            7495968,
            7497075,
            7544929,
            7544932,
            7544933,
            7544944,
            7566433,
            7628064,
            7630624,
            7693600,
            14905120,
            15197039
          ]),
          new NGramsPlusLang("sv", [
            2122100,
            2122102,
            2122853,
            2123118,
            2123510,
            2123873,
            2124064,
            2124142,
            2124655,
            2125157,
            2125667,
            2126053,
            2126699,
            2126703,
            2126708,
            2126953,
            2127457,
            2127465,
            2155634,
            6382693,
            6385184,
            6385252,
            6386208,
            6386804,
            6514720,
            6579488,
            6579566,
            6579570,
            6579572,
            6644768,
            6647328,
            6648352,
            6648864,
            6747762,
            6776174,
            6909036,
            6909543,
            7037216,
            7105568,
            7169380,
            7217267,
            7233824,
            7234661,
            7235360,
            7235429,
            7235950,
            7299944,
            7302432,
            7302688,
            7398688,
            7479393,
            7479411,
            7495968,
            7564129,
            7565165,
            7610483,
            7627040,
            7628064,
            7628146,
            7629164,
            7631904,
            7758194,
            14971424,
            16151072
          ])
        ];
      };
      this.name = function(det) {
        return det && det.fC1Bytes ? "windows-1252" : "ISO-8859-1";
      };
    };
    util.inherits(module2.exports.ISO_8859_1, sbcs);
    module2.exports.ISO_8859_2 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          177,
          32,
          179,
          32,
          181,
          182,
          32,
          32,
          185,
          186,
          187,
          188,
          32,
          190,
          191,
          32,
          177,
          32,
          179,
          32,
          181,
          182,
          183,
          32,
          185,
          186,
          187,
          188,
          32,
          190,
          191,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          32
        ];
      };
      this.ngrams = function() {
        return [
          new NGramsPlusLang("cs", [
            2122016,
            2122361,
            2122863,
            2124389,
            2125409,
            2125413,
            2125600,
            2125668,
            2125935,
            2125938,
            2126072,
            2126447,
            2126693,
            2126703,
            2126708,
            2126959,
            2127392,
            2127481,
            2128481,
            6365296,
            6513952,
            6514720,
            6627440,
            6627443,
            6627446,
            6647072,
            6647533,
            6844192,
            6844260,
            6910836,
            6972704,
            7042149,
            7103776,
            7104800,
            7233824,
            7268640,
            7269408,
            7269664,
            7282800,
            7300206,
            7301737,
            7304052,
            7304480,
            7304801,
            7368548,
            7368554,
            7369327,
            7403621,
            7562528,
            7565173,
            7566433,
            7566441,
            7566446,
            7628146,
            7630573,
            7630624,
            7676016,
            12477728,
            14773997,
            15296623,
            15540336,
            15540339,
            15559968,
            16278884
          ]),
          new NGramsPlusLang("hu", [
            2122016,
            2122106,
            2122341,
            2123111,
            2123116,
            2123365,
            2123873,
            2123887,
            2124147,
            2124645,
            2124649,
            2124790,
            2124901,
            2125153,
            2125157,
            2125161,
            2125413,
            2126714,
            2126949,
            2156915,
            6365281,
            6365291,
            6365293,
            6365299,
            6384416,
            6385184,
            6388256,
            6447470,
            6448494,
            6645625,
            6646560,
            6646816,
            6646885,
            6647072,
            6647328,
            6648421,
            6648864,
            6648933,
            6648948,
            6781216,
            6844263,
            6909556,
            6910752,
            7020641,
            7075450,
            7169383,
            7170414,
            7217249,
            7233899,
            7234923,
            7234925,
            7238688,
            7300985,
            7544929,
            7567973,
            7567988,
            7568097,
            7596391,
            7610465,
            7631904,
            7659891,
            8021362,
            14773792,
            15299360
          ]),
          new NGramsPlusLang("pl", [
            2122618,
            2122863,
            2124064,
            2124389,
            2124655,
            2125153,
            2125161,
            2125409,
            2125417,
            2125668,
            2125935,
            2125938,
            2126697,
            2127648,
            2127721,
            2127737,
            2128416,
            2128481,
            6365296,
            6365303,
            6385257,
            6514720,
            6519397,
            6519417,
            6582048,
            6584937,
            6627440,
            6627443,
            6627447,
            6627450,
            6645615,
            6646304,
            6647072,
            6647401,
            6778656,
            6906144,
            6907168,
            6907242,
            7037216,
            7039264,
            7039333,
            7170405,
            7233824,
            7235937,
            7235941,
            7282800,
            7305057,
            7305065,
            7368556,
            7369313,
            7369327,
            7369338,
            7502437,
            7502457,
            7563754,
            7564137,
            7566433,
            7825765,
            7955304,
            7957792,
            8021280,
            8022373,
            8026400,
            15955744
          ]),
          new NGramsPlusLang("ro", [
            2122016,
            2122083,
            2122593,
            2122597,
            2122607,
            2122613,
            2122853,
            2122857,
            2124897,
            2125153,
            2125925,
            2125938,
            2126693,
            2126819,
            2127214,
            2144873,
            2158190,
            6365283,
            6365284,
            6386277,
            6386720,
            6386789,
            6386976,
            6513010,
            6516590,
            6518048,
            6546208,
            6579488,
            6627425,
            6627427,
            6627428,
            6627440,
            6627443,
            6644e3,
            6646048,
            6646885,
            6647412,
            6648692,
            6889569,
            6889571,
            6889572,
            6889584,
            6907168,
            6908192,
            6909472,
            7102752,
            7103776,
            7106418,
            7107945,
            7234848,
            7238770,
            7303712,
            7365998,
            7496992,
            7497057,
            7501088,
            7594784,
            7628064,
            7631477,
            7660320,
            7694624,
            7695392,
            12216608,
            15625760
          ])
        ];
      };
      this.name = function(det) {
        return det && det.fC1Bytes ? "windows-1250" : "ISO-8859-2";
      };
    };
    util.inherits(module2.exports.ISO_8859_2, sbcs);
    module2.exports.ISO_8859_5 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          252,
          32,
          254,
          255,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          215,
          216,
          217,
          218,
          219,
          220,
          221,
          222,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          215,
          216,
          217,
          218,
          219,
          220,
          221,
          222,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          32,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          252,
          32,
          254,
          255
        ];
      };
      this.ngrams = function() {
        return [
          2150944,
          2151134,
          2151646,
          2152400,
          2152480,
          2153168,
          2153182,
          2153936,
          2153941,
          2154193,
          2154462,
          2154464,
          2154704,
          2154974,
          2154978,
          2155230,
          2156514,
          2158050,
          13688280,
          13689580,
          13884960,
          14015468,
          14015960,
          14016994,
          14017056,
          14164191,
          14210336,
          14211104,
          14216992,
          14407133,
          14407712,
          14413021,
          14536736,
          14538016,
          14538965,
          14538991,
          14540320,
          14540498,
          14557394,
          14557407,
          14557409,
          14602784,
          14602960,
          14603230,
          14604576,
          14605292,
          14605344,
          14606818,
          14671579,
          14672085,
          14672088,
          14672094,
          14733522,
          14734804,
          14803664,
          14803666,
          14803672,
          14806816,
          14865883,
          14868e3,
          14868192,
          14871584,
          15196894,
          15459616
        ];
      };
      this.name = function(det) {
        return "ISO-8859-5";
      };
      this.language = function() {
        return "ru";
      };
    };
    util.inherits(module2.exports.ISO_8859_5, sbcs);
    module2.exports.ISO_8859_6 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          193,
          194,
          195,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          215,
          216,
          217,
          218,
          32,
          32,
          32,
          32,
          32,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32
        ];
      };
      this.ngrams = function() {
        return [
          2148324,
          2148326,
          2148551,
          2152932,
          2154986,
          2155748,
          2156006,
          2156743,
          13050055,
          13091104,
          13093408,
          13095200,
          13100064,
          13100227,
          13100231,
          13100232,
          13100234,
          13100236,
          13100237,
          13100239,
          13100243,
          13100249,
          13100258,
          13100261,
          13100264,
          13100266,
          13100320,
          13100576,
          13100746,
          13115591,
          13181127,
          13181153,
          13181156,
          13181157,
          13181160,
          13246663,
          13574343,
          13617440,
          13705415,
          13748512,
          13836487,
          14229703,
          14279913,
          14805536,
          14950599,
          14993696,
          15001888,
          15002144,
          15016135,
          15058720,
          15059232,
          15066656,
          15081671,
          15147207,
          15189792,
          15255524,
          15263264,
          15278279,
          15343815,
          15343845,
          15343848,
          15386912,
          15388960,
          15394336
        ];
      };
      this.name = function(det) {
        return "ISO-8859-6";
      };
      this.language = function() {
        return "ar";
      };
    };
    util.inherits(module2.exports.ISO_8859_6, sbcs);
    module2.exports.ISO_8859_7 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          161,
          162,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          220,
          32,
          221,
          222,
          223,
          32,
          252,
          32,
          253,
          254,
          192,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          32,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          220,
          221,
          222,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          32
        ];
      };
      this.ngrams = function() {
        return [
          2154989,
          2154992,
          2155497,
          2155753,
          2156016,
          2156320,
          2157281,
          2157797,
          2158049,
          2158368,
          2158817,
          2158831,
          2158833,
          2159604,
          2159605,
          2159847,
          2159855,
          14672160,
          14754017,
          14754036,
          14805280,
          14806304,
          14807292,
          14807584,
          14936545,
          15067424,
          15069728,
          15147252,
          15199520,
          15200800,
          15278324,
          15327520,
          15330014,
          15331872,
          15393257,
          15393268,
          15525152,
          15540449,
          15540453,
          15540464,
          15589664,
          15725088,
          15725856,
          15790069,
          15790575,
          15793184,
          15868129,
          15868133,
          15868138,
          15868144,
          15868148,
          15983904,
          15984416,
          15987951,
          16048416,
          16048617,
          16050157,
          16050162,
          16050666,
          16052e3,
          16052213,
          16054765,
          16379168,
          16706848
        ];
      };
      this.name = function(det) {
        return det && det.fC1Bytes ? "windows-1253" : "ISO-8859-7";
      };
      this.language = function() {
        return "el";
      };
    };
    util.inherits(module2.exports.ISO_8859_7, sbcs);
    module2.exports.ISO_8859_8 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          181,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          32,
          32,
          32,
          32,
          32
        ];
      };
      this.ngrams = function() {
        return [
          new NGramsPlusLang("he", [
            2154725,
            2154727,
            2154729,
            2154746,
            2154985,
            2154990,
            2155744,
            2155749,
            2155753,
            2155758,
            2155762,
            2155769,
            2155770,
            2157792,
            2157796,
            2158304,
            2159340,
            2161132,
            14744096,
            14950624,
            14950625,
            14950628,
            14950636,
            14950638,
            14950649,
            15001056,
            15065120,
            15068448,
            15068960,
            15071264,
            15071776,
            15278308,
            15328288,
            15328762,
            15329773,
            15330592,
            15331104,
            15333408,
            15333920,
            15474912,
            15474916,
            15523872,
            15524896,
            15540448,
            15540449,
            15540452,
            15540460,
            15540462,
            15540473,
            15655968,
            15671524,
            15787040,
            15788320,
            15788525,
            15920160,
            16261348,
            16312813,
            16378912,
            16392416,
            16392417,
            16392420,
            16392428,
            16392430,
            16392441
          ]),
          new NGramsPlusLang("he", [
            2154725,
            2154732,
            2155753,
            2155756,
            2155758,
            2155760,
            2157040,
            2157810,
            2157817,
            2158053,
            2158057,
            2158565,
            2158569,
            2160869,
            2160873,
            2161376,
            2161381,
            2161385,
            14688484,
            14688492,
            14688493,
            14688506,
            14738464,
            14738916,
            14740512,
            14741024,
            14754020,
            14754029,
            14754042,
            14950628,
            14950633,
            14950636,
            14950637,
            14950639,
            14950648,
            14950650,
            15002656,
            15065120,
            15066144,
            15196192,
            15327264,
            15327520,
            15328288,
            15474916,
            15474925,
            15474938,
            15528480,
            15530272,
            15591913,
            15591920,
            15591928,
            15605988,
            15605997,
            15606010,
            15655200,
            15655968,
            15918112,
            16326884,
            16326893,
            16326906,
            16376864,
            16441376,
            16442400,
            16442857
          ])
        ];
      };
      this.name = function(det) {
        return det && det.fC1Bytes ? "windows-1255" : "ISO-8859-8";
      };
      this.language = function() {
        return "he";
      };
    };
    util.inherits(module2.exports.ISO_8859_8, sbcs);
    module2.exports.ISO_8859_9 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          170,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          181,
          32,
          32,
          32,
          32,
          186,
          32,
          32,
          32,
          32,
          32,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          105,
          254,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          32,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          255
        ];
      };
      this.ngrams = function() {
        return [
          2122337,
          2122345,
          2122357,
          2122849,
          2122853,
          2123621,
          2123873,
          2124140,
          2124641,
          2124655,
          2125153,
          2125676,
          2126689,
          2126945,
          2127461,
          2128225,
          6365282,
          6384416,
          6384737,
          6384993,
          6385184,
          6385405,
          6386208,
          6386273,
          6386429,
          6386685,
          6388065,
          6449522,
          6578464,
          6579488,
          6580512,
          6627426,
          6627435,
          6644841,
          6647328,
          6648352,
          6648425,
          6648681,
          6909029,
          6909472,
          6909545,
          6910496,
          7102830,
          7102834,
          7103776,
          7103858,
          7217249,
          7217250,
          7217259,
          7234657,
          7234661,
          7234848,
          7235872,
          7235950,
          7273760,
          7498094,
          7535982,
          7759136,
          7954720,
          7958386,
          16608800,
          16608868,
          16609021,
          16642301
        ];
      };
      this.name = function(det) {
        return det && det.fC1Bytes ? "windows-1254" : "ISO-8859-9";
      };
      this.language = function() {
        return "tr";
      };
    };
    util.inherits(module2.exports.ISO_8859_9, sbcs);
    module2.exports.windows_1251 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          144,
          131,
          32,
          131,
          32,
          32,
          32,
          32,
          32,
          32,
          154,
          32,
          156,
          157,
          158,
          159,
          144,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          154,
          32,
          156,
          157,
          158,
          159,
          32,
          162,
          162,
          188,
          32,
          180,
          32,
          32,
          184,
          32,
          186,
          32,
          32,
          32,
          32,
          191,
          32,
          32,
          179,
          179,
          180,
          181,
          32,
          32,
          184,
          32,
          186,
          32,
          188,
          190,
          190,
          191,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          255,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          240,
          241,
          242,
          243,
          244,
          245,
          246,
          247,
          248,
          249,
          250,
          251,
          252,
          253,
          254,
          255
        ];
      };
      this.ngrams = function() {
        return [
          2155040,
          2155246,
          2155758,
          2156512,
          2156576,
          2157280,
          2157294,
          2158048,
          2158053,
          2158305,
          2158574,
          2158576,
          2158816,
          2159086,
          2159090,
          2159342,
          2160626,
          2162162,
          14740968,
          14742268,
          14937632,
          15068156,
          15068648,
          15069682,
          15069728,
          15212783,
          15263008,
          15263776,
          15269664,
          15459821,
          15460384,
          15465709,
          15589408,
          15590688,
          15591653,
          15591679,
          15592992,
          15593186,
          15605986,
          15605999,
          15606001,
          15655456,
          15655648,
          15655918,
          15657248,
          15657980,
          15658016,
          15659506,
          15724267,
          15724773,
          15724776,
          15724782,
          15786210,
          15787492,
          15856352,
          15856354,
          15856360,
          15859488,
          15918571,
          15920672,
          15920880,
          15924256,
          16249582,
          16512288
        ];
      };
      this.name = function(det) {
        return "windows-1251";
      };
      this.language = function() {
        return "ru";
      };
    };
    util.inherits(module2.exports.windows_1251, sbcs);
    module2.exports.windows_1256 = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          129,
          32,
          131,
          32,
          32,
          32,
          32,
          136,
          32,
          138,
          32,
          156,
          141,
          142,
          143,
          144,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          152,
          32,
          154,
          32,
          156,
          32,
          32,
          159,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          170,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          181,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          192,
          193,
          194,
          195,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          32,
          216,
          217,
          218,
          219,
          220,
          221,
          222,
          223,
          224,
          225,
          226,
          227,
          228,
          229,
          230,
          231,
          232,
          233,
          234,
          235,
          236,
          237,
          238,
          239,
          32,
          32,
          32,
          32,
          244,
          32,
          32,
          32,
          32,
          249,
          32,
          251,
          252,
          32,
          32,
          255
        ];
      };
      this.ngrams = function() {
        return [
          2148321,
          2148324,
          2148551,
          2153185,
          2153965,
          2154977,
          2155492,
          2156231,
          13050055,
          13091104,
          13093408,
          13095200,
          13099296,
          13099459,
          13099463,
          13099464,
          13099466,
          13099468,
          13099469,
          13099471,
          13099475,
          13099482,
          13099486,
          13099491,
          13099494,
          13099501,
          13099808,
          13100064,
          13100234,
          13115591,
          13181127,
          13181149,
          13181153,
          13181155,
          13181158,
          13246663,
          13574343,
          13617440,
          13705415,
          13748512,
          13836487,
          14295239,
          14344684,
          14544160,
          14753991,
          14797088,
          14806048,
          14806304,
          14885063,
          14927648,
          14928160,
          14935072,
          14950599,
          15016135,
          15058720,
          15124449,
          15131680,
          15474887,
          15540423,
          15540451,
          15540454,
          15583520,
          15585568,
          15590432
        ];
      };
      this.name = function(det) {
        return "windows-1256";
      };
      this.language = function() {
        return "ar";
      };
    };
    util.inherits(module2.exports.windows_1256, sbcs);
    module2.exports.KOI8_R = function() {
      this.byteMap = function() {
        return [
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          0,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          97,
          98,
          99,
          100,
          101,
          102,
          103,
          104,
          105,
          106,
          107,
          108,
          109,
          110,
          111,
          112,
          113,
          114,
          115,
          116,
          117,
          118,
          119,
          120,
          121,
          122,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          163,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          163,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          32,
          192,
          193,
          194,
          195,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          215,
          216,
          217,
          218,
          219,
          220,
          221,
          222,
          223,
          192,
          193,
          194,
          195,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          210,
          211,
          212,
          213,
          214,
          215,
          216,
          217,
          218,
          219,
          220,
          221,
          222,
          223
        ];
      };
      this.ngrams = function() {
        return [
          2147535,
          2148640,
          2149313,
          2149327,
          2150081,
          2150085,
          2150338,
          2150607,
          2150610,
          2151105,
          2151375,
          2151380,
          2151631,
          2152224,
          2152399,
          2153153,
          2153684,
          2154196,
          12701385,
          12702936,
          12963032,
          12963529,
          12964820,
          12964896,
          13094688,
          13181136,
          13223200,
          13224224,
          13226272,
          13419982,
          13420832,
          13424846,
          13549856,
          13550880,
          13552069,
          13552081,
          13553440,
          13553623,
          13574352,
          13574355,
          13574359,
          13617103,
          13617696,
          13618392,
          13618464,
          13620180,
          13621024,
          13621185,
          13684684,
          13685445,
          13685449,
          13685455,
          13812183,
          13813188,
          13881632,
          13882561,
          13882569,
          13882583,
          13944268,
          13946656,
          13946834,
          13948960,
          14272544,
          14603471
        ];
      };
      this.name = function(det) {
        return "KOI8-R";
      };
      this.language = function() {
        return "ru";
      };
    };
    util.inherits(module2.exports.KOI8_R, sbcs);
  }
});

// node_modules/chardet/encoding/iso2022.js
var require_iso2022 = __commonJS({
  "node_modules/chardet/encoding/iso2022.js"(exports, module2) {
    var util = require("util");
    var Match = require_match();
    function ISO_2022() {
    }
    ISO_2022.prototype.match = function(det) {
      var i, j;
      var escN;
      var hits = 0;
      var misses = 0;
      var shifts = 0;
      var quality;
      var text = det.fInputBytes;
      var textLen = det.fInputLen;
      scanInput:
        for (i = 0; i < textLen; i++) {
          if (text[i] == 27) {
            checkEscapes:
              for (escN = 0; escN < this.escapeSequences.length; escN++) {
                var seq = this.escapeSequences[escN];
                if (textLen - i < seq.length)
                  continue checkEscapes;
                for (j = 1; j < seq.length; j++)
                  if (seq[j] != text[i + j])
                    continue checkEscapes;
                hits++;
                i += seq.length - 1;
                continue scanInput;
              }
            misses++;
          }
          if (text[i] == 14 || text[i] == 15)
            shifts++;
        }
      if (hits == 0)
        return null;
      quality = (100 * hits - 100 * misses) / (hits + misses);
      if (hits + shifts < 5)
        quality -= (5 - (hits + shifts)) * 10;
      return quality <= 0 ? null : new Match(det, this, quality);
    };
    module2.exports.ISO_2022_JP = function() {
      this.name = function() {
        return "ISO-2022-JP";
      };
      this.escapeSequences = [
        [27, 36, 40, 67],
        // KS X 1001:1992
        [27, 36, 40, 68],
        // JIS X 212-1990
        [27, 36, 64],
        // JIS C 6226-1978
        [27, 36, 65],
        // GB 2312-80
        [27, 36, 66],
        // JIS X 208-1983
        [27, 38, 64],
        // JIS X 208 1990, 1997
        [27, 40, 66],
        // ASCII
        [27, 40, 72],
        // JIS-Roman
        [27, 40, 73],
        // Half-width katakana
        [27, 40, 74],
        // JIS-Roman
        [27, 46, 65],
        // ISO 8859-1
        [27, 46, 70]
        // ISO 8859-7
      ];
    };
    util.inherits(module2.exports.ISO_2022_JP, ISO_2022);
    module2.exports.ISO_2022_KR = function() {
      this.name = function() {
        return "ISO-2022-KR";
      };
      this.escapeSequences = [
        [27, 36, 41, 67]
      ];
    };
    util.inherits(module2.exports.ISO_2022_KR, ISO_2022);
    module2.exports.ISO_2022_CN = function() {
      this.name = function() {
        return "ISO-2022-CN";
      };
      this.escapeSequences = [
        [27, 36, 41, 65],
        // GB 2312-80
        [27, 36, 41, 71],
        // CNS 11643-1992 Plane 1
        [27, 36, 42, 72],
        // CNS 11643-1992 Plane 2
        [27, 36, 41, 69],
        // ISO-IR-165
        [27, 36, 43, 73],
        // CNS 11643-1992 Plane 3
        [27, 36, 43, 74],
        // CNS 11643-1992 Plane 4
        [27, 36, 43, 75],
        // CNS 11643-1992 Plane 5
        [27, 36, 43, 76],
        // CNS 11643-1992 Plane 6
        [27, 36, 43, 77],
        // CNS 11643-1992 Plane 7
        [27, 78],
        // SS2
        [27, 79]
        // SS3
      ];
    };
    util.inherits(module2.exports.ISO_2022_CN, ISO_2022);
  }
});

// node_modules/chardet/index.js
var require_chardet = __commonJS({
  "node_modules/chardet/index.js"(exports, module2) {
    var fs2 = require("fs");
    var utf8 = require_utf8();
    var unicode = require_unicode();
    var mbcs = require_mbcs();
    var sbcs = require_sbcs();
    var iso2022 = require_iso2022();
    var self2 = exports;
    var recognisers = [
      new utf8(),
      new unicode.UTF_16BE(),
      new unicode.UTF_16LE(),
      new unicode.UTF_32BE(),
      new unicode.UTF_32LE(),
      new mbcs.sjis(),
      new mbcs.big5(),
      new mbcs.euc_jp(),
      new mbcs.euc_kr(),
      new mbcs.gb_18030(),
      new iso2022.ISO_2022_JP(),
      new iso2022.ISO_2022_KR(),
      new iso2022.ISO_2022_CN(),
      new sbcs.ISO_8859_1(),
      new sbcs.ISO_8859_2(),
      new sbcs.ISO_8859_5(),
      new sbcs.ISO_8859_6(),
      new sbcs.ISO_8859_7(),
      new sbcs.ISO_8859_8(),
      new sbcs.ISO_8859_9(),
      new sbcs.windows_1251(),
      new sbcs.windows_1256(),
      new sbcs.KOI8_R()
    ];
    module2.exports.detect = function(buffer, opts) {
      var fByteStats = [];
      for (var i = 0; i < 256; i++)
        fByteStats[i] = 0;
      for (var i = buffer.length - 1; i >= 0; i--)
        fByteStats[buffer[i] & 255]++;
      var fC1Bytes = false;
      for (var i = 128; i <= 159; i += 1) {
        if (fByteStats[i] != 0) {
          fC1Bytes = true;
          break;
        }
      }
      var context = {
        fByteStats,
        fC1Bytes,
        fRawInput: buffer,
        fRawLength: buffer.length,
        fInputBytes: buffer,
        fInputLen: buffer.length
      };
      var matches = recognisers.map(function(rec) {
        return rec.match(context);
      }).filter(function(match) {
        return !!match;
      }).sort(function(a, b) {
        return b.confidence - a.confidence;
      });
      if (opts && opts.returnAllMatches === true) {
        return matches;
      } else {
        return matches.length > 0 ? matches[0].name : null;
      }
    };
    module2.exports.detectFile = function(filepath, opts, cb) {
      if (typeof opts === "function") {
        cb = opts;
        opts = void 0;
      }
      var fd;
      var handler = function(err, buffer) {
        if (fd) {
          fs2.closeSync(fd);
        }
        if (err)
          return cb(err, null);
        cb(null, self2.detect(buffer, opts));
      };
      if (opts && opts.sampleSize) {
        fd = fs2.openSync(filepath, "r"), sample = Buffer.allocUnsafe(opts.sampleSize);
        fs2.read(fd, sample, 0, opts.sampleSize, null, function(err) {
          handler(err, sample);
        });
        return;
      }
      fs2.readFile(filepath, handler);
    };
    module2.exports.detectFileSync = function(filepath, opts) {
      if (opts && opts.sampleSize) {
        var fd = fs2.openSync(filepath, "r"), sample2 = Buffer.allocUnsafe(opts.sampleSize);
        fs2.readSync(fd, sample2, 0, opts.sampleSize);
        fs2.closeSync(fd);
        return self2.detect(sample2, opts);
      }
      return self2.detect(fs2.readFileSync(filepath), opts);
    };
    module2.exports.detectAll = function(buffer, opts) {
      if (typeof opts !== "object") {
        opts = {};
      }
      opts.returnAllMatches = true;
      return self2.detect(buffer, opts);
    };
    module2.exports.detectFileAll = function(filepath, opts, cb) {
      if (typeof opts === "function") {
        cb = opts;
        opts = void 0;
      }
      if (typeof opts !== "object") {
        opts = {};
      }
      opts.returnAllMatches = true;
      self2.detectFile(filepath, opts, cb);
    };
    module2.exports.detectFileAllSync = function(filepath, opts) {
      if (typeof opts !== "object") {
        opts = {};
      }
      opts.returnAllMatches = true;
      return self2.detectFileSync(filepath, opts);
    };
  }
});

// node_modules/safer-buffer/safer.js
var require_safer = __commonJS({
  "node_modules/safer-buffer/safer.js"(exports, module2) {
    "use strict";
    var buffer = require("buffer");
    var Buffer2 = buffer.Buffer;
    var safer = {};
    var key;
    for (key in buffer) {
      if (!buffer.hasOwnProperty(key))
        continue;
      if (key === "SlowBuffer" || key === "Buffer")
        continue;
      safer[key] = buffer[key];
    }
    var Safer = safer.Buffer = {};
    for (key in Buffer2) {
      if (!Buffer2.hasOwnProperty(key))
        continue;
      if (key === "allocUnsafe" || key === "allocUnsafeSlow")
        continue;
      Safer[key] = Buffer2[key];
    }
    safer.Buffer.prototype = Buffer2.prototype;
    if (!Safer.from || Safer.from === Uint8Array.from) {
      Safer.from = function(value2, encodingOrOffset, length) {
        if (typeof value2 === "number") {
          throw new TypeError('The "value" argument must not be of type number. Received type ' + typeof value2);
        }
        if (value2 && typeof value2.length === "undefined") {
          throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type " + typeof value2);
        }
        return Buffer2(value2, encodingOrOffset, length);
      };
    }
    if (!Safer.alloc) {
      Safer.alloc = function(size, fill, encoding) {
        if (typeof size !== "number") {
          throw new TypeError('The "size" argument must be of type number. Received type ' + typeof size);
        }
        if (size < 0 || size >= 2 * (1 << 30)) {
          throw new RangeError('The value "' + size + '" is invalid for option "size"');
        }
        var buf = Buffer2(size);
        if (!fill || fill.length === 0) {
          buf.fill(0);
        } else if (typeof encoding === "string") {
          buf.fill(fill, encoding);
        } else {
          buf.fill(fill);
        }
        return buf;
      };
    }
    if (!safer.kStringMaxLength) {
      try {
        safer.kStringMaxLength = process.binding("buffer").kStringMaxLength;
      } catch (e) {
      }
    }
    if (!safer.constants) {
      safer.constants = {
        MAX_LENGTH: safer.kMaxLength
      };
      if (safer.kStringMaxLength) {
        safer.constants.MAX_STRING_LENGTH = safer.kStringMaxLength;
      }
    }
    module2.exports = safer;
  }
});

// node_modules/iconv-lite/lib/bom-handling.js
var require_bom_handling = __commonJS({
  "node_modules/iconv-lite/lib/bom-handling.js"(exports) {
    "use strict";
    var BOMChar = "\uFEFF";
    exports.PrependBOM = PrependBOMWrapper;
    function PrependBOMWrapper(encoder, options) {
      this.encoder = encoder;
      this.addBOM = true;
    }
    PrependBOMWrapper.prototype.write = function(str) {
      if (this.addBOM) {
        str = BOMChar + str;
        this.addBOM = false;
      }
      return this.encoder.write(str);
    };
    PrependBOMWrapper.prototype.end = function() {
      return this.encoder.end();
    };
    exports.StripBOM = StripBOMWrapper;
    function StripBOMWrapper(decoder, options) {
      this.decoder = decoder;
      this.pass = false;
      this.options = options || {};
    }
    StripBOMWrapper.prototype.write = function(buf) {
      var res = this.decoder.write(buf);
      if (this.pass || !res)
        return res;
      if (res[0] === BOMChar) {
        res = res.slice(1);
        if (typeof this.options.stripBOM === "function")
          this.options.stripBOM();
      }
      this.pass = true;
      return res;
    };
    StripBOMWrapper.prototype.end = function() {
      return this.decoder.end();
    };
  }
});

// node_modules/iconv-lite/encodings/internal.js
var require_internal = __commonJS({
  "node_modules/iconv-lite/encodings/internal.js"(exports, module2) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    module2.exports = {
      // Encodings
      utf8: { type: "_internal", bomAware: true },
      cesu8: { type: "_internal", bomAware: true },
      unicode11utf8: "utf8",
      ucs2: { type: "_internal", bomAware: true },
      utf16le: "ucs2",
      binary: { type: "_internal" },
      base64: { type: "_internal" },
      hex: { type: "_internal" },
      // Codec.
      _internal: InternalCodec
    };
    function InternalCodec(codecOptions, iconv) {
      this.enc = codecOptions.encodingName;
      this.bomAware = codecOptions.bomAware;
      if (this.enc === "base64")
        this.encoder = InternalEncoderBase64;
      else if (this.enc === "cesu8") {
        this.enc = "utf8";
        this.encoder = InternalEncoderCesu8;
        if (Buffer2.from("eda0bdedb2a9", "hex").toString() !== "\u{1F4A9}") {
          this.decoder = InternalDecoderCesu8;
          this.defaultCharUnicode = iconv.defaultCharUnicode;
        }
      }
    }
    InternalCodec.prototype.encoder = InternalEncoder;
    InternalCodec.prototype.decoder = InternalDecoder;
    var StringDecoder = require("string_decoder").StringDecoder;
    if (!StringDecoder.prototype.end)
      StringDecoder.prototype.end = function() {
      };
    function InternalDecoder(options, codec) {
      StringDecoder.call(this, codec.enc);
    }
    InternalDecoder.prototype = StringDecoder.prototype;
    function InternalEncoder(options, codec) {
      this.enc = codec.enc;
    }
    InternalEncoder.prototype.write = function(str) {
      return Buffer2.from(str, this.enc);
    };
    InternalEncoder.prototype.end = function() {
    };
    function InternalEncoderBase64(options, codec) {
      this.prevStr = "";
    }
    InternalEncoderBase64.prototype.write = function(str) {
      str = this.prevStr + str;
      var completeQuads = str.length - str.length % 4;
      this.prevStr = str.slice(completeQuads);
      str = str.slice(0, completeQuads);
      return Buffer2.from(str, "base64");
    };
    InternalEncoderBase64.prototype.end = function() {
      return Buffer2.from(this.prevStr, "base64");
    };
    function InternalEncoderCesu8(options, codec) {
    }
    InternalEncoderCesu8.prototype.write = function(str) {
      var buf = Buffer2.alloc(str.length * 3), bufIdx = 0;
      for (var i = 0; i < str.length; i++) {
        var charCode = str.charCodeAt(i);
        if (charCode < 128)
          buf[bufIdx++] = charCode;
        else if (charCode < 2048) {
          buf[bufIdx++] = 192 + (charCode >>> 6);
          buf[bufIdx++] = 128 + (charCode & 63);
        } else {
          buf[bufIdx++] = 224 + (charCode >>> 12);
          buf[bufIdx++] = 128 + (charCode >>> 6 & 63);
          buf[bufIdx++] = 128 + (charCode & 63);
        }
      }
      return buf.slice(0, bufIdx);
    };
    InternalEncoderCesu8.prototype.end = function() {
    };
    function InternalDecoderCesu8(options, codec) {
      this.acc = 0;
      this.contBytes = 0;
      this.accBytes = 0;
      this.defaultCharUnicode = codec.defaultCharUnicode;
    }
    InternalDecoderCesu8.prototype.write = function(buf) {
      var acc = this.acc, contBytes = this.contBytes, accBytes = this.accBytes, res = "";
      for (var i = 0; i < buf.length; i++) {
        var curByte = buf[i];
        if ((curByte & 192) !== 128) {
          if (contBytes > 0) {
            res += this.defaultCharUnicode;
            contBytes = 0;
          }
          if (curByte < 128) {
            res += String.fromCharCode(curByte);
          } else if (curByte < 224) {
            acc = curByte & 31;
            contBytes = 1;
            accBytes = 1;
          } else if (curByte < 240) {
            acc = curByte & 15;
            contBytes = 2;
            accBytes = 1;
          } else {
            res += this.defaultCharUnicode;
          }
        } else {
          if (contBytes > 0) {
            acc = acc << 6 | curByte & 63;
            contBytes--;
            accBytes++;
            if (contBytes === 0) {
              if (accBytes === 2 && acc < 128 && acc > 0)
                res += this.defaultCharUnicode;
              else if (accBytes === 3 && acc < 2048)
                res += this.defaultCharUnicode;
              else
                res += String.fromCharCode(acc);
            }
          } else {
            res += this.defaultCharUnicode;
          }
        }
      }
      this.acc = acc;
      this.contBytes = contBytes;
      this.accBytes = accBytes;
      return res;
    };
    InternalDecoderCesu8.prototype.end = function() {
      var res = 0;
      if (this.contBytes > 0)
        res += this.defaultCharUnicode;
      return res;
    };
  }
});

// node_modules/iconv-lite/encodings/utf16.js
var require_utf16 = __commonJS({
  "node_modules/iconv-lite/encodings/utf16.js"(exports) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    exports.utf16be = Utf16BECodec;
    function Utf16BECodec() {
    }
    Utf16BECodec.prototype.encoder = Utf16BEEncoder;
    Utf16BECodec.prototype.decoder = Utf16BEDecoder;
    Utf16BECodec.prototype.bomAware = true;
    function Utf16BEEncoder() {
    }
    Utf16BEEncoder.prototype.write = function(str) {
      var buf = Buffer2.from(str, "ucs2");
      for (var i = 0; i < buf.length; i += 2) {
        var tmp = buf[i];
        buf[i] = buf[i + 1];
        buf[i + 1] = tmp;
      }
      return buf;
    };
    Utf16BEEncoder.prototype.end = function() {
    };
    function Utf16BEDecoder() {
      this.overflowByte = -1;
    }
    Utf16BEDecoder.prototype.write = function(buf) {
      if (buf.length == 0)
        return "";
      var buf2 = Buffer2.alloc(buf.length + 1), i = 0, j = 0;
      if (this.overflowByte !== -1) {
        buf2[0] = buf[0];
        buf2[1] = this.overflowByte;
        i = 1;
        j = 2;
      }
      for (; i < buf.length - 1; i += 2, j += 2) {
        buf2[j] = buf[i + 1];
        buf2[j + 1] = buf[i];
      }
      this.overflowByte = i == buf.length - 1 ? buf[buf.length - 1] : -1;
      return buf2.slice(0, j).toString("ucs2");
    };
    Utf16BEDecoder.prototype.end = function() {
    };
    exports.utf16 = Utf16Codec;
    function Utf16Codec(codecOptions, iconv) {
      this.iconv = iconv;
    }
    Utf16Codec.prototype.encoder = Utf16Encoder;
    Utf16Codec.prototype.decoder = Utf16Decoder;
    function Utf16Encoder(options, codec) {
      options = options || {};
      if (options.addBOM === void 0)
        options.addBOM = true;
      this.encoder = codec.iconv.getEncoder("utf-16le", options);
    }
    Utf16Encoder.prototype.write = function(str) {
      return this.encoder.write(str);
    };
    Utf16Encoder.prototype.end = function() {
      return this.encoder.end();
    };
    function Utf16Decoder(options, codec) {
      this.decoder = null;
      this.initialBytes = [];
      this.initialBytesLen = 0;
      this.options = options || {};
      this.iconv = codec.iconv;
    }
    Utf16Decoder.prototype.write = function(buf) {
      if (!this.decoder) {
        this.initialBytes.push(buf);
        this.initialBytesLen += buf.length;
        if (this.initialBytesLen < 16)
          return "";
        var buf = Buffer2.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
        this.decoder = this.iconv.getDecoder(encoding, this.options);
        this.initialBytes.length = this.initialBytesLen = 0;
      }
      return this.decoder.write(buf);
    };
    Utf16Decoder.prototype.end = function() {
      if (!this.decoder) {
        var buf = Buffer2.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
        this.decoder = this.iconv.getDecoder(encoding, this.options);
        var res = this.decoder.write(buf), trail = this.decoder.end();
        return trail ? res + trail : res;
      }
      return this.decoder.end();
    };
    function detectEncoding(buf, defaultEncoding) {
      var enc = defaultEncoding || "utf-16le";
      if (buf.length >= 2) {
        if (buf[0] == 254 && buf[1] == 255)
          enc = "utf-16be";
        else if (buf[0] == 255 && buf[1] == 254)
          enc = "utf-16le";
        else {
          var asciiCharsLE = 0, asciiCharsBE = 0, _len = Math.min(buf.length - buf.length % 2, 64);
          for (var i = 0; i < _len; i += 2) {
            if (buf[i] === 0 && buf[i + 1] !== 0)
              asciiCharsBE++;
            if (buf[i] !== 0 && buf[i + 1] === 0)
              asciiCharsLE++;
          }
          if (asciiCharsBE > asciiCharsLE)
            enc = "utf-16be";
          else if (asciiCharsBE < asciiCharsLE)
            enc = "utf-16le";
        }
      }
      return enc;
    }
  }
});

// node_modules/iconv-lite/encodings/utf7.js
var require_utf7 = __commonJS({
  "node_modules/iconv-lite/encodings/utf7.js"(exports) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    exports.utf7 = Utf7Codec;
    exports.unicode11utf7 = "utf7";
    function Utf7Codec(codecOptions, iconv) {
      this.iconv = iconv;
    }
    Utf7Codec.prototype.encoder = Utf7Encoder;
    Utf7Codec.prototype.decoder = Utf7Decoder;
    Utf7Codec.prototype.bomAware = true;
    var nonDirectChars = /[^A-Za-z0-9'\(\),-\.\/:\? \n\r\t]+/g;
    function Utf7Encoder(options, codec) {
      this.iconv = codec.iconv;
    }
    Utf7Encoder.prototype.write = function(str) {
      return Buffer2.from(str.replace(nonDirectChars, function(chunk) {
        return "+" + (chunk === "+" ? "" : this.iconv.encode(chunk, "utf16-be").toString("base64").replace(/=+$/, "")) + "-";
      }.bind(this)));
    };
    Utf7Encoder.prototype.end = function() {
    };
    function Utf7Decoder(options, codec) {
      this.iconv = codec.iconv;
      this.inBase64 = false;
      this.base64Accum = "";
    }
    var base64Regex = /[A-Za-z0-9\/+]/;
    var base64Chars = [];
    for (i = 0; i < 256; i++)
      base64Chars[i] = base64Regex.test(String.fromCharCode(i));
    var i;
    var plusChar = "+".charCodeAt(0);
    var minusChar = "-".charCodeAt(0);
    var andChar = "&".charCodeAt(0);
    Utf7Decoder.prototype.write = function(buf) {
      var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
      for (var i2 = 0; i2 < buf.length; i2++) {
        if (!inBase64) {
          if (buf[i2] == plusChar) {
            res += this.iconv.decode(buf.slice(lastI, i2), "ascii");
            lastI = i2 + 1;
            inBase64 = true;
          }
        } else {
          if (!base64Chars[buf[i2]]) {
            if (i2 == lastI && buf[i2] == minusChar) {
              res += "+";
            } else {
              var b64str = base64Accum + buf.slice(lastI, i2).toString();
              res += this.iconv.decode(Buffer2.from(b64str, "base64"), "utf16-be");
            }
            if (buf[i2] != minusChar)
              i2--;
            lastI = i2 + 1;
            inBase64 = false;
            base64Accum = "";
          }
        }
      }
      if (!inBase64) {
        res += this.iconv.decode(buf.slice(lastI), "ascii");
      } else {
        var b64str = base64Accum + buf.slice(lastI).toString();
        var canBeDecoded = b64str.length - b64str.length % 8;
        base64Accum = b64str.slice(canBeDecoded);
        b64str = b64str.slice(0, canBeDecoded);
        res += this.iconv.decode(Buffer2.from(b64str, "base64"), "utf16-be");
      }
      this.inBase64 = inBase64;
      this.base64Accum = base64Accum;
      return res;
    };
    Utf7Decoder.prototype.end = function() {
      var res = "";
      if (this.inBase64 && this.base64Accum.length > 0)
        res = this.iconv.decode(Buffer2.from(this.base64Accum, "base64"), "utf16-be");
      this.inBase64 = false;
      this.base64Accum = "";
      return res;
    };
    exports.utf7imap = Utf7IMAPCodec;
    function Utf7IMAPCodec(codecOptions, iconv) {
      this.iconv = iconv;
    }
    Utf7IMAPCodec.prototype.encoder = Utf7IMAPEncoder;
    Utf7IMAPCodec.prototype.decoder = Utf7IMAPDecoder;
    Utf7IMAPCodec.prototype.bomAware = true;
    function Utf7IMAPEncoder(options, codec) {
      this.iconv = codec.iconv;
      this.inBase64 = false;
      this.base64Accum = Buffer2.alloc(6);
      this.base64AccumIdx = 0;
    }
    Utf7IMAPEncoder.prototype.write = function(str) {
      var inBase64 = this.inBase64, base64Accum = this.base64Accum, base64AccumIdx = this.base64AccumIdx, buf = Buffer2.alloc(str.length * 5 + 10), bufIdx = 0;
      for (var i2 = 0; i2 < str.length; i2++) {
        var uChar = str.charCodeAt(i2);
        if (32 <= uChar && uChar <= 126) {
          if (inBase64) {
            if (base64AccumIdx > 0) {
              bufIdx += buf.write(base64Accum.slice(0, base64AccumIdx).toString("base64").replace(/\//g, ",").replace(/=+$/, ""), bufIdx);
              base64AccumIdx = 0;
            }
            buf[bufIdx++] = minusChar;
            inBase64 = false;
          }
          if (!inBase64) {
            buf[bufIdx++] = uChar;
            if (uChar === andChar)
              buf[bufIdx++] = minusChar;
          }
        } else {
          if (!inBase64) {
            buf[bufIdx++] = andChar;
            inBase64 = true;
          }
          if (inBase64) {
            base64Accum[base64AccumIdx++] = uChar >> 8;
            base64Accum[base64AccumIdx++] = uChar & 255;
            if (base64AccumIdx == base64Accum.length) {
              bufIdx += buf.write(base64Accum.toString("base64").replace(/\//g, ","), bufIdx);
              base64AccumIdx = 0;
            }
          }
        }
      }
      this.inBase64 = inBase64;
      this.base64AccumIdx = base64AccumIdx;
      return buf.slice(0, bufIdx);
    };
    Utf7IMAPEncoder.prototype.end = function() {
      var buf = Buffer2.alloc(10), bufIdx = 0;
      if (this.inBase64) {
        if (this.base64AccumIdx > 0) {
          bufIdx += buf.write(this.base64Accum.slice(0, this.base64AccumIdx).toString("base64").replace(/\//g, ",").replace(/=+$/, ""), bufIdx);
          this.base64AccumIdx = 0;
        }
        buf[bufIdx++] = minusChar;
        this.inBase64 = false;
      }
      return buf.slice(0, bufIdx);
    };
    function Utf7IMAPDecoder(options, codec) {
      this.iconv = codec.iconv;
      this.inBase64 = false;
      this.base64Accum = "";
    }
    var base64IMAPChars = base64Chars.slice();
    base64IMAPChars[",".charCodeAt(0)] = true;
    Utf7IMAPDecoder.prototype.write = function(buf) {
      var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
      for (var i2 = 0; i2 < buf.length; i2++) {
        if (!inBase64) {
          if (buf[i2] == andChar) {
            res += this.iconv.decode(buf.slice(lastI, i2), "ascii");
            lastI = i2 + 1;
            inBase64 = true;
          }
        } else {
          if (!base64IMAPChars[buf[i2]]) {
            if (i2 == lastI && buf[i2] == minusChar) {
              res += "&";
            } else {
              var b64str = base64Accum + buf.slice(lastI, i2).toString().replace(/,/g, "/");
              res += this.iconv.decode(Buffer2.from(b64str, "base64"), "utf16-be");
            }
            if (buf[i2] != minusChar)
              i2--;
            lastI = i2 + 1;
            inBase64 = false;
            base64Accum = "";
          }
        }
      }
      if (!inBase64) {
        res += this.iconv.decode(buf.slice(lastI), "ascii");
      } else {
        var b64str = base64Accum + buf.slice(lastI).toString().replace(/,/g, "/");
        var canBeDecoded = b64str.length - b64str.length % 8;
        base64Accum = b64str.slice(canBeDecoded);
        b64str = b64str.slice(0, canBeDecoded);
        res += this.iconv.decode(Buffer2.from(b64str, "base64"), "utf16-be");
      }
      this.inBase64 = inBase64;
      this.base64Accum = base64Accum;
      return res;
    };
    Utf7IMAPDecoder.prototype.end = function() {
      var res = "";
      if (this.inBase64 && this.base64Accum.length > 0)
        res = this.iconv.decode(Buffer2.from(this.base64Accum, "base64"), "utf16-be");
      this.inBase64 = false;
      this.base64Accum = "";
      return res;
    };
  }
});

// node_modules/iconv-lite/encodings/sbcs-codec.js
var require_sbcs_codec = __commonJS({
  "node_modules/iconv-lite/encodings/sbcs-codec.js"(exports) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    exports._sbcs = SBCSCodec;
    function SBCSCodec(codecOptions, iconv) {
      if (!codecOptions)
        throw new Error("SBCS codec is called without the data.");
      if (!codecOptions.chars || codecOptions.chars.length !== 128 && codecOptions.chars.length !== 256)
        throw new Error("Encoding '" + codecOptions.type + "' has incorrect 'chars' (must be of len 128 or 256)");
      if (codecOptions.chars.length === 128) {
        var asciiString = "";
        for (var i = 0; i < 128; i++)
          asciiString += String.fromCharCode(i);
        codecOptions.chars = asciiString + codecOptions.chars;
      }
      this.decodeBuf = Buffer2.from(codecOptions.chars, "ucs2");
      var encodeBuf = Buffer2.alloc(65536, iconv.defaultCharSingleByte.charCodeAt(0));
      for (var i = 0; i < codecOptions.chars.length; i++)
        encodeBuf[codecOptions.chars.charCodeAt(i)] = i;
      this.encodeBuf = encodeBuf;
    }
    SBCSCodec.prototype.encoder = SBCSEncoder;
    SBCSCodec.prototype.decoder = SBCSDecoder;
    function SBCSEncoder(options, codec) {
      this.encodeBuf = codec.encodeBuf;
    }
    SBCSEncoder.prototype.write = function(str) {
      var buf = Buffer2.alloc(str.length);
      for (var i = 0; i < str.length; i++)
        buf[i] = this.encodeBuf[str.charCodeAt(i)];
      return buf;
    };
    SBCSEncoder.prototype.end = function() {
    };
    function SBCSDecoder(options, codec) {
      this.decodeBuf = codec.decodeBuf;
    }
    SBCSDecoder.prototype.write = function(buf) {
      var decodeBuf = this.decodeBuf;
      var newBuf = Buffer2.alloc(buf.length * 2);
      var idx1 = 0, idx2 = 0;
      for (var i = 0; i < buf.length; i++) {
        idx1 = buf[i] * 2;
        idx2 = i * 2;
        newBuf[idx2] = decodeBuf[idx1];
        newBuf[idx2 + 1] = decodeBuf[idx1 + 1];
      }
      return newBuf.toString("ucs2");
    };
    SBCSDecoder.prototype.end = function() {
    };
  }
});

// node_modules/iconv-lite/encodings/sbcs-data.js
var require_sbcs_data = __commonJS({
  "node_modules/iconv-lite/encodings/sbcs-data.js"(exports, module2) {
    "use strict";
    module2.exports = {
      // Not supported by iconv, not sure why.
      "10029": "maccenteuro",
      "maccenteuro": {
        "type": "_sbcs",
        "chars": "\xC4\u0100\u0101\xC9\u0104\xD6\xDC\xE1\u0105\u010C\xE4\u010D\u0106\u0107\xE9\u0179\u017A\u010E\xED\u010F\u0112\u0113\u0116\xF3\u0117\xF4\xF6\xF5\xFA\u011A\u011B\xFC\u2020\xB0\u0118\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\u0119\xA8\u2260\u0123\u012E\u012F\u012A\u2264\u2265\u012B\u0136\u2202\u2211\u0142\u013B\u013C\u013D\u013E\u0139\u013A\u0145\u0146\u0143\xAC\u221A\u0144\u0147\u2206\xAB\xBB\u2026\xA0\u0148\u0150\xD5\u0151\u014C\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\u014D\u0154\u0155\u0158\u2039\u203A\u0159\u0156\u0157\u0160\u201A\u201E\u0161\u015A\u015B\xC1\u0164\u0165\xCD\u017D\u017E\u016A\xD3\xD4\u016B\u016E\xDA\u016F\u0170\u0171\u0172\u0173\xDD\xFD\u0137\u017B\u0141\u017C\u0122\u02C7"
      },
      "808": "cp808",
      "ibm808": "cp808",
      "cp808": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u0401\u0451\u0404\u0454\u0407\u0457\u040E\u045E\xB0\u2219\xB7\u221A\u2116\u20AC\u25A0\xA0"
      },
      "mik": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u2514\u2534\u252C\u251C\u2500\u253C\u2563\u2551\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2510\u2591\u2592\u2593\u2502\u2524\u2116\xA7\u2557\u255D\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      // Aliases of generated encodings.
      "ascii8bit": "ascii",
      "usascii": "ascii",
      "ansix34": "ascii",
      "ansix341968": "ascii",
      "ansix341986": "ascii",
      "csascii": "ascii",
      "cp367": "ascii",
      "ibm367": "ascii",
      "isoir6": "ascii",
      "iso646us": "ascii",
      "iso646irv": "ascii",
      "us": "ascii",
      "latin1": "iso88591",
      "latin2": "iso88592",
      "latin3": "iso88593",
      "latin4": "iso88594",
      "latin5": "iso88599",
      "latin6": "iso885910",
      "latin7": "iso885913",
      "latin8": "iso885914",
      "latin9": "iso885915",
      "latin10": "iso885916",
      "csisolatin1": "iso88591",
      "csisolatin2": "iso88592",
      "csisolatin3": "iso88593",
      "csisolatin4": "iso88594",
      "csisolatincyrillic": "iso88595",
      "csisolatinarabic": "iso88596",
      "csisolatingreek": "iso88597",
      "csisolatinhebrew": "iso88598",
      "csisolatin5": "iso88599",
      "csisolatin6": "iso885910",
      "l1": "iso88591",
      "l2": "iso88592",
      "l3": "iso88593",
      "l4": "iso88594",
      "l5": "iso88599",
      "l6": "iso885910",
      "l7": "iso885913",
      "l8": "iso885914",
      "l9": "iso885915",
      "l10": "iso885916",
      "isoir14": "iso646jp",
      "isoir57": "iso646cn",
      "isoir100": "iso88591",
      "isoir101": "iso88592",
      "isoir109": "iso88593",
      "isoir110": "iso88594",
      "isoir144": "iso88595",
      "isoir127": "iso88596",
      "isoir126": "iso88597",
      "isoir138": "iso88598",
      "isoir148": "iso88599",
      "isoir157": "iso885910",
      "isoir166": "tis620",
      "isoir179": "iso885913",
      "isoir199": "iso885914",
      "isoir203": "iso885915",
      "isoir226": "iso885916",
      "cp819": "iso88591",
      "ibm819": "iso88591",
      "cyrillic": "iso88595",
      "arabic": "iso88596",
      "arabic8": "iso88596",
      "ecma114": "iso88596",
      "asmo708": "iso88596",
      "greek": "iso88597",
      "greek8": "iso88597",
      "ecma118": "iso88597",
      "elot928": "iso88597",
      "hebrew": "iso88598",
      "hebrew8": "iso88598",
      "turkish": "iso88599",
      "turkish8": "iso88599",
      "thai": "iso885911",
      "thai8": "iso885911",
      "celtic": "iso885914",
      "celtic8": "iso885914",
      "isoceltic": "iso885914",
      "tis6200": "tis620",
      "tis62025291": "tis620",
      "tis62025330": "tis620",
      "10000": "macroman",
      "10006": "macgreek",
      "10007": "maccyrillic",
      "10079": "maciceland",
      "10081": "macturkish",
      "cspc8codepage437": "cp437",
      "cspc775baltic": "cp775",
      "cspc850multilingual": "cp850",
      "cspcp852": "cp852",
      "cspc862latinhebrew": "cp862",
      "cpgr": "cp869",
      "msee": "cp1250",
      "mscyrl": "cp1251",
      "msansi": "cp1252",
      "msgreek": "cp1253",
      "msturk": "cp1254",
      "mshebr": "cp1255",
      "msarab": "cp1256",
      "winbaltrim": "cp1257",
      "cp20866": "koi8r",
      "20866": "koi8r",
      "ibm878": "koi8r",
      "cskoi8r": "koi8r",
      "cp21866": "koi8u",
      "21866": "koi8u",
      "ibm1168": "koi8u",
      "strk10482002": "rk1048",
      "tcvn5712": "tcvn",
      "tcvn57121": "tcvn",
      "gb198880": "iso646cn",
      "cn": "iso646cn",
      "csiso14jisc6220ro": "iso646jp",
      "jisc62201969ro": "iso646jp",
      "jp": "iso646jp",
      "cshproman8": "hproman8",
      "r8": "hproman8",
      "roman8": "hproman8",
      "xroman8": "hproman8",
      "ibm1051": "hproman8",
      "mac": "macintosh",
      "csmacintosh": "macintosh"
    };
  }
});

// node_modules/iconv-lite/encodings/sbcs-data-generated.js
var require_sbcs_data_generated = __commonJS({
  "node_modules/iconv-lite/encodings/sbcs-data-generated.js"(exports, module2) {
    "use strict";
    module2.exports = {
      "437": "cp437",
      "737": "cp737",
      "775": "cp775",
      "850": "cp850",
      "852": "cp852",
      "855": "cp855",
      "856": "cp856",
      "857": "cp857",
      "858": "cp858",
      "860": "cp860",
      "861": "cp861",
      "862": "cp862",
      "863": "cp863",
      "864": "cp864",
      "865": "cp865",
      "866": "cp866",
      "869": "cp869",
      "874": "windows874",
      "922": "cp922",
      "1046": "cp1046",
      "1124": "cp1124",
      "1125": "cp1125",
      "1129": "cp1129",
      "1133": "cp1133",
      "1161": "cp1161",
      "1162": "cp1162",
      "1163": "cp1163",
      "1250": "windows1250",
      "1251": "windows1251",
      "1252": "windows1252",
      "1253": "windows1253",
      "1254": "windows1254",
      "1255": "windows1255",
      "1256": "windows1256",
      "1257": "windows1257",
      "1258": "windows1258",
      "28591": "iso88591",
      "28592": "iso88592",
      "28593": "iso88593",
      "28594": "iso88594",
      "28595": "iso88595",
      "28596": "iso88596",
      "28597": "iso88597",
      "28598": "iso88598",
      "28599": "iso88599",
      "28600": "iso885910",
      "28601": "iso885911",
      "28603": "iso885913",
      "28604": "iso885914",
      "28605": "iso885915",
      "28606": "iso885916",
      "windows874": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\uFFFD\uFFFD\uFFFD\u2026\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\xA0\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFFFD\uFFFD\uFFFD\uFFFD\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "win874": "windows874",
      "cp874": "windows874",
      "windows1250": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\uFFFD\u201E\u2026\u2020\u2021\uFFFD\u2030\u0160\u2039\u015A\u0164\u017D\u0179\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\u0161\u203A\u015B\u0165\u017E\u017A\xA0\u02C7\u02D8\u0141\xA4\u0104\xA6\xA7\xA8\xA9\u015E\xAB\xAC\xAD\xAE\u017B\xB0\xB1\u02DB\u0142\xB4\xB5\xB6\xB7\xB8\u0105\u015F\xBB\u013D\u02DD\u013E\u017C\u0154\xC1\xC2\u0102\xC4\u0139\u0106\xC7\u010C\xC9\u0118\xCB\u011A\xCD\xCE\u010E\u0110\u0143\u0147\xD3\xD4\u0150\xD6\xD7\u0158\u016E\xDA\u0170\xDC\xDD\u0162\xDF\u0155\xE1\xE2\u0103\xE4\u013A\u0107\xE7\u010D\xE9\u0119\xEB\u011B\xED\xEE\u010F\u0111\u0144\u0148\xF3\xF4\u0151\xF6\xF7\u0159\u016F\xFA\u0171\xFC\xFD\u0163\u02D9"
      },
      "win1250": "windows1250",
      "cp1250": "windows1250",
      "windows1251": {
        "type": "_sbcs",
        "chars": "\u0402\u0403\u201A\u0453\u201E\u2026\u2020\u2021\u20AC\u2030\u0409\u2039\u040A\u040C\u040B\u040F\u0452\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\u0459\u203A\u045A\u045C\u045B\u045F\xA0\u040E\u045E\u0408\xA4\u0490\xA6\xA7\u0401\xA9\u0404\xAB\xAC\xAD\xAE\u0407\xB0\xB1\u0406\u0456\u0491\xB5\xB6\xB7\u0451\u2116\u0454\xBB\u0458\u0405\u0455\u0457\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F"
      },
      "win1251": "windows1251",
      "cp1251": "windows1251",
      "windows1252": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\uFFFD\u017D\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\uFFFD\u017E\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
      },
      "win1252": "windows1252",
      "cp1252": "windows1252",
      "windows1253": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\uFFFD\u2030\uFFFD\u2039\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\uFFFD\u203A\uFFFD\uFFFD\uFFFD\uFFFD\xA0\u0385\u0386\xA3\xA4\xA5\xA6\xA7\xA8\xA9\uFFFD\xAB\xAC\xAD\xAE\u2015\xB0\xB1\xB2\xB3\u0384\xB5\xB6\xB7\u0388\u0389\u038A\xBB\u038C\xBD\u038E\u038F\u0390\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\uFFFD\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03AA\u03AB\u03AC\u03AD\u03AE\u03AF\u03B0\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C2\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\u03CA\u03CB\u03CC\u03CD\u03CE\uFFFD"
      },
      "win1253": "windows1253",
      "cp1253": "windows1253",
      "windows1254": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\uFFFD\uFFFD\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u011E\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u0130\u015E\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u011F\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u0131\u015F\xFF"
      },
      "win1254": "windows1254",
      "cp1254": "windows1254",
      "windows1255": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\uFFFD\u2039\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\uFFFD\u203A\uFFFD\uFFFD\uFFFD\uFFFD\xA0\xA1\xA2\xA3\u20AA\xA5\xA6\xA7\xA8\xA9\xD7\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xF7\xBB\xBC\xBD\xBE\xBF\u05B0\u05B1\u05B2\u05B3\u05B4\u05B5\u05B6\u05B7\u05B8\u05B9\u05BA\u05BB\u05BC\u05BD\u05BE\u05BF\u05C0\u05C1\u05C2\u05C3\u05F0\u05F1\u05F2\u05F3\u05F4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u05D0\u05D1\u05D2\u05D3\u05D4\u05D5\u05D6\u05D7\u05D8\u05D9\u05DA\u05DB\u05DC\u05DD\u05DE\u05DF\u05E0\u05E1\u05E2\u05E3\u05E4\u05E5\u05E6\u05E7\u05E8\u05E9\u05EA\uFFFD\uFFFD\u200E\u200F\uFFFD"
      },
      "win1255": "windows1255",
      "cp1255": "windows1255",
      "windows1256": {
        "type": "_sbcs",
        "chars": "\u20AC\u067E\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0679\u2039\u0152\u0686\u0698\u0688\u06AF\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u06A9\u2122\u0691\u203A\u0153\u200C\u200D\u06BA\xA0\u060C\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\u06BE\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\u061B\xBB\xBC\xBD\xBE\u061F\u06C1\u0621\u0622\u0623\u0624\u0625\u0626\u0627\u0628\u0629\u062A\u062B\u062C\u062D\u062E\u062F\u0630\u0631\u0632\u0633\u0634\u0635\u0636\xD7\u0637\u0638\u0639\u063A\u0640\u0641\u0642\u0643\xE0\u0644\xE2\u0645\u0646\u0647\u0648\xE7\xE8\xE9\xEA\xEB\u0649\u064A\xEE\xEF\u064B\u064C\u064D\u064E\xF4\u064F\u0650\xF7\u0651\xF9\u0652\xFB\xFC\u200E\u200F\u06D2"
      },
      "win1256": "windows1256",
      "cp1256": "windows1256",
      "windows1257": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\uFFFD\u201E\u2026\u2020\u2021\uFFFD\u2030\uFFFD\u2039\uFFFD\xA8\u02C7\xB8\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\uFFFD\u203A\uFFFD\xAF\u02DB\uFFFD\xA0\uFFFD\xA2\xA3\xA4\uFFFD\xA6\xA7\xD8\xA9\u0156\xAB\xAC\xAD\xAE\xC6\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xF8\xB9\u0157\xBB\xBC\xBD\xBE\xE6\u0104\u012E\u0100\u0106\xC4\xC5\u0118\u0112\u010C\xC9\u0179\u0116\u0122\u0136\u012A\u013B\u0160\u0143\u0145\xD3\u014C\xD5\xD6\xD7\u0172\u0141\u015A\u016A\xDC\u017B\u017D\xDF\u0105\u012F\u0101\u0107\xE4\xE5\u0119\u0113\u010D\xE9\u017A\u0117\u0123\u0137\u012B\u013C\u0161\u0144\u0146\xF3\u014D\xF5\xF6\xF7\u0173\u0142\u015B\u016B\xFC\u017C\u017E\u02D9"
      },
      "win1257": "windows1257",
      "cp1257": "windows1257",
      "windows1258": {
        "type": "_sbcs",
        "chars": "\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\uFFFD\u2039\u0152\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\uFFFD\u203A\u0153\uFFFD\uFFFD\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\u0102\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\u0300\xCD\xCE\xCF\u0110\xD1\u0309\xD3\xD4\u01A0\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u01AF\u0303\xDF\xE0\xE1\xE2\u0103\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\u0301\xED\xEE\xEF\u0111\xF1\u0323\xF3\xF4\u01A1\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u01B0\u20AB\xFF"
      },
      "win1258": "windows1258",
      "cp1258": "windows1258",
      "iso88591": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
      },
      "cp28591": "iso88591",
      "iso88592": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0104\u02D8\u0141\xA4\u013D\u015A\xA7\xA8\u0160\u015E\u0164\u0179\xAD\u017D\u017B\xB0\u0105\u02DB\u0142\xB4\u013E\u015B\u02C7\xB8\u0161\u015F\u0165\u017A\u02DD\u017E\u017C\u0154\xC1\xC2\u0102\xC4\u0139\u0106\xC7\u010C\xC9\u0118\xCB\u011A\xCD\xCE\u010E\u0110\u0143\u0147\xD3\xD4\u0150\xD6\xD7\u0158\u016E\xDA\u0170\xDC\xDD\u0162\xDF\u0155\xE1\xE2\u0103\xE4\u013A\u0107\xE7\u010D\xE9\u0119\xEB\u011B\xED\xEE\u010F\u0111\u0144\u0148\xF3\xF4\u0151\xF6\xF7\u0159\u016F\xFA\u0171\xFC\xFD\u0163\u02D9"
      },
      "cp28592": "iso88592",
      "iso88593": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0126\u02D8\xA3\xA4\uFFFD\u0124\xA7\xA8\u0130\u015E\u011E\u0134\xAD\uFFFD\u017B\xB0\u0127\xB2\xB3\xB4\xB5\u0125\xB7\xB8\u0131\u015F\u011F\u0135\xBD\uFFFD\u017C\xC0\xC1\xC2\uFFFD\xC4\u010A\u0108\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\uFFFD\xD1\xD2\xD3\xD4\u0120\xD6\xD7\u011C\xD9\xDA\xDB\xDC\u016C\u015C\xDF\xE0\xE1\xE2\uFFFD\xE4\u010B\u0109\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\uFFFD\xF1\xF2\xF3\xF4\u0121\xF6\xF7\u011D\xF9\xFA\xFB\xFC\u016D\u015D\u02D9"
      },
      "cp28593": "iso88593",
      "iso88594": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0104\u0138\u0156\xA4\u0128\u013B\xA7\xA8\u0160\u0112\u0122\u0166\xAD\u017D\xAF\xB0\u0105\u02DB\u0157\xB4\u0129\u013C\u02C7\xB8\u0161\u0113\u0123\u0167\u014A\u017E\u014B\u0100\xC1\xC2\xC3\xC4\xC5\xC6\u012E\u010C\xC9\u0118\xCB\u0116\xCD\xCE\u012A\u0110\u0145\u014C\u0136\xD4\xD5\xD6\xD7\xD8\u0172\xDA\xDB\xDC\u0168\u016A\xDF\u0101\xE1\xE2\xE3\xE4\xE5\xE6\u012F\u010D\xE9\u0119\xEB\u0117\xED\xEE\u012B\u0111\u0146\u014D\u0137\xF4\xF5\xF6\xF7\xF8\u0173\xFA\xFB\xFC\u0169\u016B\u02D9"
      },
      "cp28594": "iso88594",
      "iso88595": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0401\u0402\u0403\u0404\u0405\u0406\u0407\u0408\u0409\u040A\u040B\u040C\xAD\u040E\u040F\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u2116\u0451\u0452\u0453\u0454\u0455\u0456\u0457\u0458\u0459\u045A\u045B\u045C\xA7\u045E\u045F"
      },
      "cp28595": "iso88595",
      "iso88596": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\uFFFD\uFFFD\uFFFD\xA4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u060C\xAD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u061B\uFFFD\uFFFD\uFFFD\u061F\uFFFD\u0621\u0622\u0623\u0624\u0625\u0626\u0627\u0628\u0629\u062A\u062B\u062C\u062D\u062E\u062F\u0630\u0631\u0632\u0633\u0634\u0635\u0636\u0637\u0638\u0639\u063A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0640\u0641\u0642\u0643\u0644\u0645\u0646\u0647\u0648\u0649\u064A\u064B\u064C\u064D\u064E\u064F\u0650\u0651\u0652\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "cp28596": "iso88596",
      "iso88597": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u2018\u2019\xA3\u20AC\u20AF\xA6\xA7\xA8\xA9\u037A\xAB\xAC\xAD\uFFFD\u2015\xB0\xB1\xB2\xB3\u0384\u0385\u0386\xB7\u0388\u0389\u038A\xBB\u038C\xBD\u038E\u038F\u0390\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\uFFFD\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03AA\u03AB\u03AC\u03AD\u03AE\u03AF\u03B0\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C2\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\u03CA\u03CB\u03CC\u03CD\u03CE\uFFFD"
      },
      "cp28597": "iso88597",
      "iso88598": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\uFFFD\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xD7\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xF7\xBB\xBC\xBD\xBE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2017\u05D0\u05D1\u05D2\u05D3\u05D4\u05D5\u05D6\u05D7\u05D8\u05D9\u05DA\u05DB\u05DC\u05DD\u05DE\u05DF\u05E0\u05E1\u05E2\u05E3\u05E4\u05E5\u05E6\u05E7\u05E8\u05E9\u05EA\uFFFD\uFFFD\u200E\u200F\uFFFD"
      },
      "cp28598": "iso88598",
      "iso88599": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u011E\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u0130\u015E\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u011F\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u0131\u015F\xFF"
      },
      "cp28599": "iso88599",
      "iso885910": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0104\u0112\u0122\u012A\u0128\u0136\xA7\u013B\u0110\u0160\u0166\u017D\xAD\u016A\u014A\xB0\u0105\u0113\u0123\u012B\u0129\u0137\xB7\u013C\u0111\u0161\u0167\u017E\u2015\u016B\u014B\u0100\xC1\xC2\xC3\xC4\xC5\xC6\u012E\u010C\xC9\u0118\xCB\u0116\xCD\xCE\xCF\xD0\u0145\u014C\xD3\xD4\xD5\xD6\u0168\xD8\u0172\xDA\xDB\xDC\xDD\xDE\xDF\u0101\xE1\xE2\xE3\xE4\xE5\xE6\u012F\u010D\xE9\u0119\xEB\u0117\xED\xEE\xEF\xF0\u0146\u014D\xF3\xF4\xF5\xF6\u0169\xF8\u0173\xFA\xFB\xFC\xFD\xFE\u0138"
      },
      "cp28600": "iso885910",
      "iso885911": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFFFD\uFFFD\uFFFD\uFFFD\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "cp28601": "iso885911",
      "iso885913": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u201D\xA2\xA3\xA4\u201E\xA6\xA7\xD8\xA9\u0156\xAB\xAC\xAD\xAE\xC6\xB0\xB1\xB2\xB3\u201C\xB5\xB6\xB7\xF8\xB9\u0157\xBB\xBC\xBD\xBE\xE6\u0104\u012E\u0100\u0106\xC4\xC5\u0118\u0112\u010C\xC9\u0179\u0116\u0122\u0136\u012A\u013B\u0160\u0143\u0145\xD3\u014C\xD5\xD6\xD7\u0172\u0141\u015A\u016A\xDC\u017B\u017D\xDF\u0105\u012F\u0101\u0107\xE4\xE5\u0119\u0113\u010D\xE9\u017A\u0117\u0123\u0137\u012B\u013C\u0161\u0144\u0146\xF3\u014D\xF5\xF6\xF7\u0173\u0142\u015B\u016B\xFC\u017C\u017E\u2019"
      },
      "cp28603": "iso885913",
      "iso885914": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u1E02\u1E03\xA3\u010A\u010B\u1E0A\xA7\u1E80\xA9\u1E82\u1E0B\u1EF2\xAD\xAE\u0178\u1E1E\u1E1F\u0120\u0121\u1E40\u1E41\xB6\u1E56\u1E81\u1E57\u1E83\u1E60\u1EF3\u1E84\u1E85\u1E61\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u0174\xD1\xD2\xD3\xD4\xD5\xD6\u1E6A\xD8\xD9\xDA\xDB\xDC\xDD\u0176\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u0175\xF1\xF2\xF3\xF4\xF5\xF6\u1E6B\xF8\xF9\xFA\xFB\xFC\xFD\u0177\xFF"
      },
      "cp28604": "iso885914",
      "iso885915": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\u20AC\xA5\u0160\xA7\u0161\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\u017D\xB5\xB6\xB7\u017E\xB9\xBA\xBB\u0152\u0153\u0178\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
      },
      "cp28605": "iso885915",
      "iso885916": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0104\u0105\u0141\u20AC\u201E\u0160\xA7\u0161\xA9\u0218\xAB\u0179\xAD\u017A\u017B\xB0\xB1\u010C\u0142\u017D\u201D\xB6\xB7\u017E\u010D\u0219\xBB\u0152\u0153\u0178\u017C\xC0\xC1\xC2\u0102\xC4\u0106\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u0110\u0143\xD2\xD3\xD4\u0150\xD6\u015A\u0170\xD9\xDA\xDB\xDC\u0118\u021A\xDF\xE0\xE1\xE2\u0103\xE4\u0107\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u0111\u0144\xF2\xF3\xF4\u0151\xF6\u015B\u0171\xF9\xFA\xFB\xFC\u0119\u021B\xFF"
      },
      "cp28606": "iso885916",
      "cp437": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xA2\xA3\xA5\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm437": "cp437",
      "csibm437": "cp437",
      "cp737": {
        "type": "_sbcs",
        "chars": "\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C2\u03C4\u03C5\u03C6\u03C7\u03C8\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03C9\u03AC\u03AD\u03AE\u03CA\u03AF\u03CC\u03CD\u03CB\u03CE\u0386\u0388\u0389\u038A\u038C\u038E\u038F\xB1\u2265\u2264\u03AA\u03AB\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm737": "cp737",
      "csibm737": "cp737",
      "cp775": {
        "type": "_sbcs",
        "chars": "\u0106\xFC\xE9\u0101\xE4\u0123\xE5\u0107\u0142\u0113\u0156\u0157\u012B\u0179\xC4\xC5\xC9\xE6\xC6\u014D\xF6\u0122\xA2\u015A\u015B\xD6\xDC\xF8\xA3\xD8\xD7\xA4\u0100\u012A\xF3\u017B\u017C\u017A\u201D\xA6\xA9\xAE\xAC\xBD\xBC\u0141\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u0104\u010C\u0118\u0116\u2563\u2551\u2557\u255D\u012E\u0160\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u0172\u016A\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u017D\u0105\u010D\u0119\u0117\u012F\u0161\u0173\u016B\u017E\u2518\u250C\u2588\u2584\u258C\u2590\u2580\xD3\xDF\u014C\u0143\xF5\xD5\xB5\u0144\u0136\u0137\u013B\u013C\u0146\u0112\u0145\u2019\xAD\xB1\u201C\xBE\xB6\xA7\xF7\u201E\xB0\u2219\xB7\xB9\xB3\xB2\u25A0\xA0"
      },
      "ibm775": "cp775",
      "csibm775": "cp775",
      "cp850": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xF8\xA3\xD8\xD7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\xAE\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\xC0\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\xE3\xC3\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\xF0\xD0\xCA\xCB\xC8\u0131\xCD\xCE\xCF\u2518\u250C\u2588\u2584\xA6\xCC\u2580\xD3\xDF\xD4\xD2\xF5\xD5\xB5\xFE\xDE\xDA\xDB\xD9\xFD\xDD\xAF\xB4\xAD\xB1\u2017\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0"
      },
      "ibm850": "cp850",
      "csibm850": "cp850",
      "cp852": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\u016F\u0107\xE7\u0142\xEB\u0150\u0151\xEE\u0179\xC4\u0106\xC9\u0139\u013A\xF4\xF6\u013D\u013E\u015A\u015B\xD6\xDC\u0164\u0165\u0141\xD7\u010D\xE1\xED\xF3\xFA\u0104\u0105\u017D\u017E\u0118\u0119\xAC\u017A\u010C\u015F\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\u011A\u015E\u2563\u2551\u2557\u255D\u017B\u017C\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u0102\u0103\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\u0111\u0110\u010E\xCB\u010F\u0147\xCD\xCE\u011B\u2518\u250C\u2588\u2584\u0162\u016E\u2580\xD3\xDF\xD4\u0143\u0144\u0148\u0160\u0161\u0154\xDA\u0155\u0170\xFD\xDD\u0163\xB4\xAD\u02DD\u02DB\u02C7\u02D8\xA7\xF7\xB8\xB0\xA8\u02D9\u0171\u0158\u0159\u25A0\xA0"
      },
      "ibm852": "cp852",
      "csibm852": "cp852",
      "cp855": {
        "type": "_sbcs",
        "chars": "\u0452\u0402\u0453\u0403\u0451\u0401\u0454\u0404\u0455\u0405\u0456\u0406\u0457\u0407\u0458\u0408\u0459\u0409\u045A\u040A\u045B\u040B\u045C\u040C\u045E\u040E\u045F\u040F\u044E\u042E\u044A\u042A\u0430\u0410\u0431\u0411\u0446\u0426\u0434\u0414\u0435\u0415\u0444\u0424\u0433\u0413\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u0445\u0425\u0438\u0418\u2563\u2551\u2557\u255D\u0439\u0419\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u043A\u041A\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\u043B\u041B\u043C\u041C\u043D\u041D\u043E\u041E\u043F\u2518\u250C\u2588\u2584\u041F\u044F\u2580\u042F\u0440\u0420\u0441\u0421\u0442\u0422\u0443\u0423\u0436\u0416\u0432\u0412\u044C\u042C\u2116\xAD\u044B\u042B\u0437\u0417\u0448\u0428\u044D\u042D\u0449\u0429\u0447\u0427\xA7\u25A0\xA0"
      },
      "ibm855": "cp855",
      "csibm855": "cp855",
      "cp856": {
        "type": "_sbcs",
        "chars": "\u05D0\u05D1\u05D2\u05D3\u05D4\u05D5\u05D6\u05D7\u05D8\u05D9\u05DA\u05DB\u05DC\u05DD\u05DE\u05DF\u05E0\u05E1\u05E2\u05E3\u05E4\u05E5\u05E6\u05E7\u05E8\u05E9\u05EA\uFFFD\xA3\uFFFD\xD7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\xAE\xAC\xBD\xBC\uFFFD\xAB\xBB\u2591\u2592\u2593\u2502\u2524\uFFFD\uFFFD\uFFFD\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\uFFFD\uFFFD\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2518\u250C\u2588\u2584\xA6\uFFFD\u2580\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\xB5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\xAF\xB4\xAD\xB1\u2017\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0"
      },
      "ibm856": "cp856",
      "csibm856": "cp856",
      "cp857": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\u0131\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\u0130\xD6\xDC\xF8\xA3\xD8\u015E\u015F\xE1\xED\xF3\xFA\xF1\xD1\u011E\u011F\xBF\xAE\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\xC0\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\xE3\xC3\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\xBA\xAA\xCA\xCB\xC8\uFFFD\xCD\xCE\xCF\u2518\u250C\u2588\u2584\xA6\xCC\u2580\xD3\xDF\xD4\xD2\xF5\xD5\xB5\uFFFD\xD7\xDA\xDB\xD9\xEC\xFF\xAF\xB4\xAD\xB1\uFFFD\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0"
      },
      "ibm857": "cp857",
      "csibm857": "cp857",
      "cp858": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xF8\xA3\xD8\xD7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\xAE\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\xC0\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\xE3\xC3\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\xF0\xD0\xCA\xCB\xC8\u20AC\xCD\xCE\xCF\u2518\u250C\u2588\u2584\xA6\xCC\u2580\xD3\xDF\xD4\xD2\xF5\xD5\xB5\xFE\xDE\xDA\xDB\xD9\xFD\xDD\xAF\xB4\xAD\xB1\u2017\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0"
      },
      "ibm858": "cp858",
      "csibm858": "cp858",
      "cp860": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE3\xE0\xC1\xE7\xEA\xCA\xE8\xCD\xD4\xEC\xC3\xC2\xC9\xC0\xC8\xF4\xF5\xF2\xDA\xF9\xCC\xD5\xDC\xA2\xA3\xD9\u20A7\xD3\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\xD2\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm860": "cp860",
      "csibm860": "cp860",
      "cp861": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xD0\xF0\xDE\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xFE\xFB\xDD\xFD\xD6\xDC\xF8\xA3\xD8\u20A7\u0192\xE1\xED\xF3\xFA\xC1\xCD\xD3\xDA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm861": "cp861",
      "csibm861": "cp861",
      "cp862": {
        "type": "_sbcs",
        "chars": "\u05D0\u05D1\u05D2\u05D3\u05D4\u05D5\u05D6\u05D7\u05D8\u05D9\u05DA\u05DB\u05DC\u05DD\u05DE\u05DF\u05E0\u05E1\u05E2\u05E3\u05E4\u05E5\u05E6\u05E7\u05E8\u05E9\u05EA\xA2\xA3\xA5\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm862": "cp862",
      "csibm862": "cp862",
      "cp863": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xC2\xE0\xB6\xE7\xEA\xEB\xE8\xEF\xEE\u2017\xC0\xA7\xC9\xC8\xCA\xF4\xCB\xCF\xFB\xF9\xA4\xD4\xDC\xA2\xA3\xD9\xDB\u0192\xA6\xB4\xF3\xFA\xA8\xB8\xB3\xAF\xCE\u2310\xAC\xBD\xBC\xBE\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm863": "cp863",
      "csibm863": "cp863",
      "cp864": {
        "type": "_sbcs",
        "chars": "\0\x07\b	\n\v\f\r\x1B !\"#$\u066A&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xB0\xB7\u2219\u221A\u2592\u2500\u2502\u253C\u2524\u252C\u251C\u2534\u2510\u250C\u2514\u2518\u03B2\u221E\u03C6\xB1\xBD\xBC\u2248\xAB\xBB\uFEF7\uFEF8\uFFFD\uFFFD\uFEFB\uFEFC\uFFFD\xA0\xAD\uFE82\xA3\xA4\uFE84\uFFFD\uFFFD\uFE8E\uFE8F\uFE95\uFE99\u060C\uFE9D\uFEA1\uFEA5\u0660\u0661\u0662\u0663\u0664\u0665\u0666\u0667\u0668\u0669\uFED1\u061B\uFEB1\uFEB5\uFEB9\u061F\xA2\uFE80\uFE81\uFE83\uFE85\uFECA\uFE8B\uFE8D\uFE91\uFE93\uFE97\uFE9B\uFE9F\uFEA3\uFEA7\uFEA9\uFEAB\uFEAD\uFEAF\uFEB3\uFEB7\uFEBB\uFEBF\uFEC1\uFEC5\uFECB\uFECF\xA6\xAC\xF7\xD7\uFEC9\u0640\uFED3\uFED7\uFEDB\uFEDF\uFEE3\uFEE7\uFEEB\uFEED\uFEEF\uFEF3\uFEBD\uFECC\uFECE\uFECD\uFEE1\uFE7D\u0651\uFEE5\uFEE9\uFEEC\uFEF0\uFEF2\uFED0\uFED5\uFEF5\uFEF6\uFEDD\uFED9\uFEF1\u25A0\uFFFD"
      },
      "ibm864": "cp864",
      "csibm864": "cp864",
      "cp865": {
        "type": "_sbcs",
        "chars": "\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xF8\xA3\xD8\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xA4\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0"
      },
      "ibm865": "cp865",
      "csibm865": "cp865",
      "cp866": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u0401\u0451\u0404\u0454\u0407\u0457\u040E\u045E\xB0\u2219\xB7\u221A\u2116\xA4\u25A0\xA0"
      },
      "ibm866": "cp866",
      "csibm866": "cp866",
      "cp869": {
        "type": "_sbcs",
        "chars": "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0386\uFFFD\xB7\xAC\xA6\u2018\u2019\u0388\u2015\u0389\u038A\u03AA\u038C\uFFFD\uFFFD\u038E\u03AB\xA9\u038F\xB2\xB3\u03AC\xA3\u03AD\u03AE\u03AF\u03CA\u0390\u03CC\u03CD\u0391\u0392\u0393\u0394\u0395\u0396\u0397\xBD\u0398\u0399\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u039A\u039B\u039C\u039D\u2563\u2551\u2557\u255D\u039E\u039F\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u03A0\u03A1\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03B1\u03B2\u03B3\u2518\u250C\u2588\u2584\u03B4\u03B5\u2580\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C2\u03C4\u0384\xAD\xB1\u03C5\u03C6\u03C7\xA7\u03C8\u0385\xB0\xA8\u03C9\u03CB\u03B0\u03CE\u25A0\xA0"
      },
      "ibm869": "cp869",
      "csibm869": "cp869",
      "cp922": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\u203E\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u0160\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\u017D\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u0161\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\u017E\xFF"
      },
      "ibm922": "cp922",
      "csibm922": "cp922",
      "cp1046": {
        "type": "_sbcs",
        "chars": "\uFE88\xD7\xF7\uF8F6\uF8F5\uF8F4\uF8F7\uFE71\x88\u25A0\u2502\u2500\u2510\u250C\u2514\u2518\uFE79\uFE7B\uFE7D\uFE7F\uFE77\uFE8A\uFEF0\uFEF3\uFEF2\uFECE\uFECF\uFED0\uFEF6\uFEF8\uFEFA\uFEFC\xA0\uF8FA\uF8F9\uF8F8\xA4\uF8FB\uFE8B\uFE91\uFE97\uFE9B\uFE9F\uFEA3\u060C\xAD\uFEA7\uFEB3\u0660\u0661\u0662\u0663\u0664\u0665\u0666\u0667\u0668\u0669\uFEB7\u061B\uFEBB\uFEBF\uFECA\u061F\uFECB\u0621\u0622\u0623\u0624\u0625\u0626\u0627\u0628\u0629\u062A\u062B\u062C\u062D\u062E\u062F\u0630\u0631\u0632\u0633\u0634\u0635\u0636\u0637\uFEC7\u0639\u063A\uFECC\uFE82\uFE84\uFE8E\uFED3\u0640\u0641\u0642\u0643\u0644\u0645\u0646\u0647\u0648\u0649\u064A\u064B\u064C\u064D\u064E\u064F\u0650\u0651\u0652\uFED7\uFEDB\uFEDF\uF8FC\uFEF5\uFEF7\uFEF9\uFEFB\uFEE3\uFEE7\uFEEC\uFEE9\uFFFD"
      },
      "ibm1046": "cp1046",
      "csibm1046": "cp1046",
      "cp1124": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0401\u0402\u0490\u0404\u0405\u0406\u0407\u0408\u0409\u040A\u040B\u040C\xAD\u040E\u040F\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u2116\u0451\u0452\u0491\u0454\u0455\u0456\u0457\u0458\u0459\u045A\u045B\u045C\xA7\u045E\u045F"
      },
      "ibm1124": "cp1124",
      "csibm1124": "cp1124",
      "cp1125": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u0401\u0451\u0490\u0491\u0404\u0454\u0406\u0456\u0407\u0457\xB7\u221A\u2116\xA4\u25A0\xA0"
      },
      "ibm1125": "cp1125",
      "csibm1125": "cp1125",
      "cp1129": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\u0153\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\u0178\xB5\xB6\xB7\u0152\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\u0102\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\u0300\xCD\xCE\xCF\u0110\xD1\u0309\xD3\xD4\u01A0\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u01AF\u0303\xDF\xE0\xE1\xE2\u0103\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\u0301\xED\xEE\xEF\u0111\xF1\u0323\xF3\xF4\u01A1\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u01B0\u20AB\xFF"
      },
      "ibm1129": "cp1129",
      "csibm1129": "cp1129",
      "cp1133": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0E81\u0E82\u0E84\u0E87\u0E88\u0EAA\u0E8A\u0E8D\u0E94\u0E95\u0E96\u0E97\u0E99\u0E9A\u0E9B\u0E9C\u0E9D\u0E9E\u0E9F\u0EA1\u0EA2\u0EA3\u0EA5\u0EA7\u0EAB\u0EAD\u0EAE\uFFFD\uFFFD\uFFFD\u0EAF\u0EB0\u0EB2\u0EB3\u0EB4\u0EB5\u0EB6\u0EB7\u0EB8\u0EB9\u0EBC\u0EB1\u0EBB\u0EBD\uFFFD\uFFFD\uFFFD\u0EC0\u0EC1\u0EC2\u0EC3\u0EC4\u0EC8\u0EC9\u0ECA\u0ECB\u0ECC\u0ECD\u0EC6\uFFFD\u0EDC\u0EDD\u20AD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0ED0\u0ED1\u0ED2\u0ED3\u0ED4\u0ED5\u0ED6\u0ED7\u0ED8\u0ED9\uFFFD\uFFFD\xA2\xAC\xA6\uFFFD"
      },
      "ibm1133": "cp1133",
      "csibm1133": "cp1133",
      "cp1161": {
        "type": "_sbcs",
        "chars": "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0E48\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\u0E49\u0E4A\u0E4B\u20AC\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\xA2\xAC\xA6\xA0"
      },
      "ibm1161": "cp1161",
      "csibm1161": "cp1161",
      "cp1162": {
        "type": "_sbcs",
        "chars": "\u20AC\x81\x82\x83\x84\u2026\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\u2018\u2019\u201C\u201D\u2022\u2013\u2014\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFFFD\uFFFD\uFFFD\uFFFD\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "ibm1162": "cp1162",
      "csibm1162": "cp1162",
      "cp1163": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\u20AC\xA5\xA6\xA7\u0153\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\u0178\xB5\xB6\xB7\u0152\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\u0102\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\u0300\xCD\xCE\xCF\u0110\xD1\u0309\xD3\xD4\u01A0\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u01AF\u0303\xDF\xE0\xE1\xE2\u0103\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\u0301\xED\xEE\xEF\u0111\xF1\u0323\xF3\xF4\u01A1\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u01B0\u20AB\xFF"
      },
      "ibm1163": "cp1163",
      "csibm1163": "cp1163",
      "maccroatian": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\u0160\u2122\xB4\xA8\u2260\u017D\xD8\u221E\xB1\u2264\u2265\u2206\xB5\u2202\u2211\u220F\u0161\u222B\xAA\xBA\u2126\u017E\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u0106\xAB\u010C\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u0110\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\uFFFD\xA9\u2044\xA4\u2039\u203A\xC6\xBB\u2013\xB7\u201A\u201E\u2030\xC2\u0107\xC1\u010D\xC8\xCD\xCE\xCF\xCC\xD3\xD4\u0111\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u03C0\xCB\u02DA\xB8\xCA\xE6\u02C7"
      },
      "maccyrillic": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u2020\xB0\xA2\xA3\xA7\u2022\xB6\u0406\xAE\xA9\u2122\u0402\u0452\u2260\u0403\u0453\u221E\xB1\u2264\u2265\u0456\xB5\u2202\u0408\u0404\u0454\u0407\u0457\u0409\u0459\u040A\u045A\u0458\u0405\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\u040B\u045B\u040C\u045C\u0455\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u201E\u040E\u045E\u040F\u045F\u2116\u0401\u0451\u044F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\xA4"
      },
      "macgreek": {
        "type": "_sbcs",
        "chars": "\xC4\xB9\xB2\xC9\xB3\xD6\xDC\u0385\xE0\xE2\xE4\u0384\xA8\xE7\xE9\xE8\xEA\xEB\xA3\u2122\xEE\xEF\u2022\xBD\u2030\xF4\xF6\xA6\xAD\xF9\xFB\xFC\u2020\u0393\u0394\u0398\u039B\u039E\u03A0\xDF\xAE\xA9\u03A3\u03AA\xA7\u2260\xB0\u0387\u0391\xB1\u2264\u2265\xA5\u0392\u0395\u0396\u0397\u0399\u039A\u039C\u03A6\u03AB\u03A8\u03A9\u03AC\u039D\xAC\u039F\u03A1\u2248\u03A4\xAB\xBB\u2026\xA0\u03A5\u03A7\u0386\u0388\u0153\u2013\u2015\u201C\u201D\u2018\u2019\xF7\u0389\u038A\u038C\u038E\u03AD\u03AE\u03AF\u03CC\u038F\u03CD\u03B1\u03B2\u03C8\u03B4\u03B5\u03C6\u03B3\u03B7\u03B9\u03BE\u03BA\u03BB\u03BC\u03BD\u03BF\u03C0\u03CE\u03C1\u03C3\u03C4\u03B8\u03C9\u03C2\u03C7\u03C5\u03B6\u03CA\u03CB\u0390\u03B0\uFFFD"
      },
      "maciceland": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\xDD\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\xD0\xF0\xDE\xFE\xFD\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7"
      },
      "macroman": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\u2039\u203A\uFB01\uFB02\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7"
      },
      "macromania": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\u0102\u015E\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\u0103\u015F\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\u2039\u203A\u0162\u0163\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7"
      },
      "macthai": {
        "type": "_sbcs",
        "chars": "\xAB\xBB\u2026\uF88C\uF88F\uF892\uF895\uF898\uF88B\uF88E\uF891\uF894\uF897\u201C\u201D\uF899\uFFFD\u2022\uF884\uF889\uF885\uF886\uF887\uF888\uF88A\uF88D\uF890\uF893\uF896\u2018\u2019\uFFFD\xA0\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFEFF\u200B\u2013\u2014\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u2122\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\xAE\xA9\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "macturkish": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u011E\u011F\u0130\u0131\u015E\u015F\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\uFFFD\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7"
      },
      "macukraine": {
        "type": "_sbcs",
        "chars": "\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u2020\xB0\u0490\xA3\xA7\u2022\xB6\u0406\xAE\xA9\u2122\u0402\u0452\u2260\u0403\u0453\u221E\xB1\u2264\u2265\u0456\xB5\u0491\u0408\u0404\u0454\u0407\u0457\u0409\u0459\u040A\u045A\u0458\u0405\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\u040B\u045B\u040C\u045C\u0455\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u201E\u040E\u045E\u040F\u045F\u2116\u0401\u0451\u044F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\xA4"
      },
      "koi8r": {
        "type": "_sbcs",
        "chars": "\u2500\u2502\u250C\u2510\u2514\u2518\u251C\u2524\u252C\u2534\u253C\u2580\u2584\u2588\u258C\u2590\u2591\u2592\u2593\u2320\u25A0\u2219\u221A\u2248\u2264\u2265\xA0\u2321\xB0\xB2\xB7\xF7\u2550\u2551\u2552\u0451\u2553\u2554\u2555\u2556\u2557\u2558\u2559\u255A\u255B\u255C\u255D\u255E\u255F\u2560\u2561\u0401\u2562\u2563\u2564\u2565\u2566\u2567\u2568\u2569\u256A\u256B\u256C\xA9\u044E\u0430\u0431\u0446\u0434\u0435\u0444\u0433\u0445\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u044F\u0440\u0441\u0442\u0443\u0436\u0432\u044C\u044B\u0437\u0448\u044D\u0449\u0447\u044A\u042E\u0410\u0411\u0426\u0414\u0415\u0424\u0413\u0425\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u042F\u0420\u0421\u0422\u0423\u0416\u0412\u042C\u042B\u0417\u0428\u042D\u0429\u0427\u042A"
      },
      "koi8u": {
        "type": "_sbcs",
        "chars": "\u2500\u2502\u250C\u2510\u2514\u2518\u251C\u2524\u252C\u2534\u253C\u2580\u2584\u2588\u258C\u2590\u2591\u2592\u2593\u2320\u25A0\u2219\u221A\u2248\u2264\u2265\xA0\u2321\xB0\xB2\xB7\xF7\u2550\u2551\u2552\u0451\u0454\u2554\u0456\u0457\u2557\u2558\u2559\u255A\u255B\u0491\u255D\u255E\u255F\u2560\u2561\u0401\u0404\u2563\u0406\u0407\u2566\u2567\u2568\u2569\u256A\u0490\u256C\xA9\u044E\u0430\u0431\u0446\u0434\u0435\u0444\u0433\u0445\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u044F\u0440\u0441\u0442\u0443\u0436\u0432\u044C\u044B\u0437\u0448\u044D\u0449\u0447\u044A\u042E\u0410\u0411\u0426\u0414\u0415\u0424\u0413\u0425\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u042F\u0420\u0421\u0422\u0423\u0416\u0412\u042C\u042B\u0417\u0428\u042D\u0429\u0427\u042A"
      },
      "koi8ru": {
        "type": "_sbcs",
        "chars": "\u2500\u2502\u250C\u2510\u2514\u2518\u251C\u2524\u252C\u2534\u253C\u2580\u2584\u2588\u258C\u2590\u2591\u2592\u2593\u2320\u25A0\u2219\u221A\u2248\u2264\u2265\xA0\u2321\xB0\xB2\xB7\xF7\u2550\u2551\u2552\u0451\u0454\u2554\u0456\u0457\u2557\u2558\u2559\u255A\u255B\u0491\u045E\u255E\u255F\u2560\u2561\u0401\u0404\u2563\u0406\u0407\u2566\u2567\u2568\u2569\u256A\u0490\u040E\xA9\u044E\u0430\u0431\u0446\u0434\u0435\u0444\u0433\u0445\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u044F\u0440\u0441\u0442\u0443\u0436\u0432\u044C\u044B\u0437\u0448\u044D\u0449\u0447\u044A\u042E\u0410\u0411\u0426\u0414\u0415\u0424\u0413\u0425\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u042F\u0420\u0421\u0422\u0423\u0416\u0412\u042C\u042B\u0417\u0428\u042D\u0429\u0427\u042A"
      },
      "koi8t": {
        "type": "_sbcs",
        "chars": "\u049B\u0493\u201A\u0492\u201E\u2026\u2020\u2021\uFFFD\u2030\u04B3\u2039\u04B2\u04B7\u04B6\uFFFD\u049A\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\uFFFD\u203A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u04EF\u04EE\u0451\xA4\u04E3\xA6\xA7\uFFFD\uFFFD\uFFFD\xAB\xAC\xAD\xAE\uFFFD\xB0\xB1\xB2\u0401\uFFFD\u04E2\xB6\xB7\uFFFD\u2116\uFFFD\xBB\uFFFD\uFFFD\uFFFD\xA9\u044E\u0430\u0431\u0446\u0434\u0435\u0444\u0433\u0445\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u044F\u0440\u0441\u0442\u0443\u0436\u0432\u044C\u044B\u0437\u0448\u044D\u0449\u0447\u044A\u042E\u0410\u0411\u0426\u0414\u0415\u0424\u0413\u0425\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u042F\u0420\u0421\u0422\u0423\u0416\u0412\u042C\u042B\u0417\u0428\u042D\u0429\u0427\u042A"
      },
      "armscii8": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\uFFFD\u0587\u0589)(\xBB\xAB\u2014.\u055D,-\u058A\u2026\u055C\u055B\u055E\u0531\u0561\u0532\u0562\u0533\u0563\u0534\u0564\u0535\u0565\u0536\u0566\u0537\u0567\u0538\u0568\u0539\u0569\u053A\u056A\u053B\u056B\u053C\u056C\u053D\u056D\u053E\u056E\u053F\u056F\u0540\u0570\u0541\u0571\u0542\u0572\u0543\u0573\u0544\u0574\u0545\u0575\u0546\u0576\u0547\u0577\u0548\u0578\u0549\u0579\u054A\u057A\u054B\u057B\u054C\u057C\u054D\u057D\u054E\u057E\u054F\u057F\u0550\u0580\u0551\u0581\u0552\u0582\u0553\u0583\u0554\u0584\u0555\u0585\u0556\u0586\u055A\uFFFD"
      },
      "rk1048": {
        "type": "_sbcs",
        "chars": "\u0402\u0403\u201A\u0453\u201E\u2026\u2020\u2021\u20AC\u2030\u0409\u2039\u040A\u049A\u04BA\u040F\u0452\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\u0459\u203A\u045A\u049B\u04BB\u045F\xA0\u04B0\u04B1\u04D8\xA4\u04E8\xA6\xA7\u0401\xA9\u0492\xAB\xAC\xAD\xAE\u04AE\xB0\xB1\u0406\u0456\u04E9\xB5\xB6\xB7\u0451\u2116\u0493\xBB\u04D9\u04A2\u04A3\u04AF\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F"
      },
      "tcvn": {
        "type": "_sbcs",
        "chars": "\0\xDA\u1EE4\u1EEA\u1EEC\u1EEE\x07\b	\n\v\f\r\u1EE8\u1EF0\u1EF2\u1EF6\u1EF8\xDD\u1EF4\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC0\u1EA2\xC3\xC1\u1EA0\u1EB6\u1EAC\xC8\u1EBA\u1EBC\xC9\u1EB8\u1EC6\xCC\u1EC8\u0128\xCD\u1ECA\xD2\u1ECE\xD5\xD3\u1ECC\u1ED8\u1EDC\u1EDE\u1EE0\u1EDA\u1EE2\xD9\u1EE6\u0168\xA0\u0102\xC2\xCA\xD4\u01A0\u01AF\u0110\u0103\xE2\xEA\xF4\u01A1\u01B0\u0111\u1EB0\u0300\u0309\u0303\u0301\u0323\xE0\u1EA3\xE3\xE1\u1EA1\u1EB2\u1EB1\u1EB3\u1EB5\u1EAF\u1EB4\u1EAE\u1EA6\u1EA8\u1EAA\u1EA4\u1EC0\u1EB7\u1EA7\u1EA9\u1EAB\u1EA5\u1EAD\xE8\u1EC2\u1EBB\u1EBD\xE9\u1EB9\u1EC1\u1EC3\u1EC5\u1EBF\u1EC7\xEC\u1EC9\u1EC4\u1EBE\u1ED2\u0129\xED\u1ECB\xF2\u1ED4\u1ECF\xF5\xF3\u1ECD\u1ED3\u1ED5\u1ED7\u1ED1\u1ED9\u1EDD\u1EDF\u1EE1\u1EDB\u1EE3\xF9\u1ED6\u1EE7\u0169\xFA\u1EE5\u1EEB\u1EED\u1EEF\u1EE9\u1EF1\u1EF3\u1EF7\u1EF9\xFD\u1EF5\u1ED0"
      },
      "georgianacademy": {
        "type": "_sbcs",
        "chars": "\x80\x81\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\x8D\x8E\x8F\x90\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\x9D\x9E\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\u10D0\u10D1\u10D2\u10D3\u10D4\u10D5\u10D6\u10D7\u10D8\u10D9\u10DA\u10DB\u10DC\u10DD\u10DE\u10DF\u10E0\u10E1\u10E2\u10E3\u10E4\u10E5\u10E6\u10E7\u10E8\u10E9\u10EA\u10EB\u10EC\u10ED\u10EE\u10EF\u10F0\u10F1\u10F2\u10F3\u10F4\u10F5\u10F6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
      },
      "georgianps": {
        "type": "_sbcs",
        "chars": "\x80\x81\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\x8D\x8E\x8F\x90\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\x9D\x9E\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\u10D0\u10D1\u10D2\u10D3\u10D4\u10D5\u10D6\u10F1\u10D7\u10D8\u10D9\u10DA\u10DB\u10DC\u10F2\u10DD\u10DE\u10DF\u10E0\u10E1\u10E2\u10F3\u10E3\u10E4\u10E5\u10E6\u10E7\u10E8\u10E9\u10EA\u10EB\u10EC\u10ED\u10EE\u10F4\u10EF\u10F0\u10F5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
      },
      "pt154": {
        "type": "_sbcs",
        "chars": "\u0496\u0492\u04EE\u0493\u201E\u2026\u04B6\u04AE\u04B2\u04AF\u04A0\u04E2\u04A2\u049A\u04BA\u04B8\u0497\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u04B3\u04B7\u04A1\u04E3\u04A3\u049B\u04BB\u04B9\xA0\u040E\u045E\u0408\u04E8\u0498\u04B0\xA7\u0401\xA9\u04D8\xAB\xAC\u04EF\xAE\u049C\xB0\u04B1\u0406\u0456\u0499\u04E9\xB6\xB7\u0451\u2116\u04D9\xBB\u0458\u04AA\u04AB\u049D\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F"
      },
      "viscii": {
        "type": "_sbcs",
        "chars": "\0\u1EB2\u1EB4\u1EAA\x07\b	\n\v\f\r\u1EF6\u1EF8\x1B\u1EF4 !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u1EA0\u1EAE\u1EB0\u1EB6\u1EA4\u1EA6\u1EA8\u1EAC\u1EBC\u1EB8\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EE2\u1EDA\u1EDC\u1EDE\u1ECA\u1ECE\u1ECC\u1EC8\u1EE6\u0168\u1EE4\u1EF2\xD5\u1EAF\u1EB1\u1EB7\u1EA5\u1EA7\u1EA9\u1EAD\u1EBD\u1EB9\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1ED1\u1ED3\u1ED5\u1ED7\u1EE0\u01A0\u1ED9\u1EDD\u1EDF\u1ECB\u1EF0\u1EE8\u1EEA\u1EEC\u01A1\u1EDB\u01AF\xC0\xC1\xC2\xC3\u1EA2\u0102\u1EB3\u1EB5\xC8\xC9\xCA\u1EBA\xCC\xCD\u0128\u1EF3\u0110\u1EE9\xD2\xD3\xD4\u1EA1\u1EF7\u1EEB\u1EED\xD9\xDA\u1EF9\u1EF5\xDD\u1EE1\u01B0\xE0\xE1\xE2\xE3\u1EA3\u0103\u1EEF\u1EAB\xE8\xE9\xEA\u1EBB\xEC\xED\u0129\u1EC9\u0111\u1EF1\xF2\xF3\xF4\xF5\u1ECF\u1ECD\u1EE5\xF9\xFA\u0169\u1EE7\xFD\u1EE3\u1EEE"
      },
      "iso646cn": {
        "type": "_sbcs",
        "chars": "\0\x07\b	\n\v\f\r\x1B !\"#\xA5%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}\u203E\x7F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "iso646jp": {
        "type": "_sbcs",
        "chars": "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\xA5]^_`abcdefghijklmnopqrstuvwxyz{|}\u203E\x7F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "hproman8": {
        "type": "_sbcs",
        "chars": "\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xC0\xC2\xC8\xCA\xCB\xCE\xCF\xB4\u02CB\u02C6\xA8\u02DC\xD9\xDB\u20A4\xAF\xDD\xFD\xB0\xC7\xE7\xD1\xF1\xA1\xBF\xA4\xA3\xA5\xA7\u0192\xA2\xE2\xEA\xF4\xFB\xE1\xE9\xF3\xFA\xE0\xE8\xF2\xF9\xE4\xEB\xF6\xFC\xC5\xEE\xD8\xC6\xE5\xED\xF8\xE6\xC4\xEC\xD6\xDC\xC9\xEF\xDF\xD4\xC1\xC3\xE3\xD0\xF0\xCD\xCC\xD3\xD2\xD5\xF5\u0160\u0161\xDA\u0178\xFF\xDE\xFE\xB7\xB5\xB6\xBE\u2014\xBC\xBD\xAA\xBA\xAB\u25A0\xBB\xB1\uFFFD"
      },
      "macintosh": {
        "type": "_sbcs",
        "chars": "\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\u2039\u203A\uFB01\uFB02\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7"
      },
      "ascii": {
        "type": "_sbcs",
        "chars": "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD"
      },
      "tis620": {
        "type": "_sbcs",
        "chars": "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFFFD\uFFFD\uFFFD\uFFFD\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\uFFFD\uFFFD\uFFFD\uFFFD"
      }
    };
  }
});

// node_modules/iconv-lite/encodings/dbcs-codec.js
var require_dbcs_codec = __commonJS({
  "node_modules/iconv-lite/encodings/dbcs-codec.js"(exports) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    exports._dbcs = DBCSCodec;
    var UNASSIGNED = -1;
    var GB18030_CODE = -2;
    var SEQ_START = -10;
    var NODE_START = -1e3;
    var UNASSIGNED_NODE = new Array(256);
    var DEF_CHAR = -1;
    for (i = 0; i < 256; i++)
      UNASSIGNED_NODE[i] = UNASSIGNED;
    var i;
    function DBCSCodec(codecOptions, iconv) {
      this.encodingName = codecOptions.encodingName;
      if (!codecOptions)
        throw new Error("DBCS codec is called without the data.");
      if (!codecOptions.table)
        throw new Error("Encoding '" + this.encodingName + "' has no data.");
      var mappingTable = codecOptions.table();
      this.decodeTables = [];
      this.decodeTables[0] = UNASSIGNED_NODE.slice(0);
      this.decodeTableSeq = [];
      for (var i2 = 0; i2 < mappingTable.length; i2++)
        this._addDecodeChunk(mappingTable[i2]);
      this.defaultCharUnicode = iconv.defaultCharUnicode;
      this.encodeTable = [];
      this.encodeTableSeq = [];
      var skipEncodeChars = {};
      if (codecOptions.encodeSkipVals)
        for (var i2 = 0; i2 < codecOptions.encodeSkipVals.length; i2++) {
          var val = codecOptions.encodeSkipVals[i2];
          if (typeof val === "number")
            skipEncodeChars[val] = true;
          else
            for (var j = val.from; j <= val.to; j++)
              skipEncodeChars[j] = true;
        }
      this._fillEncodeTable(0, 0, skipEncodeChars);
      if (codecOptions.encodeAdd) {
        for (var uChar in codecOptions.encodeAdd)
          if (Object.prototype.hasOwnProperty.call(codecOptions.encodeAdd, uChar))
            this._setEncodeChar(uChar.charCodeAt(0), codecOptions.encodeAdd[uChar]);
      }
      this.defCharSB = this.encodeTable[0][iconv.defaultCharSingleByte.charCodeAt(0)];
      if (this.defCharSB === UNASSIGNED)
        this.defCharSB = this.encodeTable[0]["?"];
      if (this.defCharSB === UNASSIGNED)
        this.defCharSB = "?".charCodeAt(0);
      if (typeof codecOptions.gb18030 === "function") {
        this.gb18030 = codecOptions.gb18030();
        var thirdByteNodeIdx = this.decodeTables.length;
        var thirdByteNode = this.decodeTables[thirdByteNodeIdx] = UNASSIGNED_NODE.slice(0);
        var fourthByteNodeIdx = this.decodeTables.length;
        var fourthByteNode = this.decodeTables[fourthByteNodeIdx] = UNASSIGNED_NODE.slice(0);
        for (var i2 = 129; i2 <= 254; i2++) {
          var secondByteNodeIdx = NODE_START - this.decodeTables[0][i2];
          var secondByteNode = this.decodeTables[secondByteNodeIdx];
          for (var j = 48; j <= 57; j++)
            secondByteNode[j] = NODE_START - thirdByteNodeIdx;
        }
        for (var i2 = 129; i2 <= 254; i2++)
          thirdByteNode[i2] = NODE_START - fourthByteNodeIdx;
        for (var i2 = 48; i2 <= 57; i2++)
          fourthByteNode[i2] = GB18030_CODE;
      }
    }
    DBCSCodec.prototype.encoder = DBCSEncoder;
    DBCSCodec.prototype.decoder = DBCSDecoder;
    DBCSCodec.prototype._getDecodeTrieNode = function(addr) {
      var bytes = [];
      for (; addr > 0; addr >>= 8)
        bytes.push(addr & 255);
      if (bytes.length == 0)
        bytes.push(0);
      var node = this.decodeTables[0];
      for (var i2 = bytes.length - 1; i2 > 0; i2--) {
        var val = node[bytes[i2]];
        if (val == UNASSIGNED) {
          node[bytes[i2]] = NODE_START - this.decodeTables.length;
          this.decodeTables.push(node = UNASSIGNED_NODE.slice(0));
        } else if (val <= NODE_START) {
          node = this.decodeTables[NODE_START - val];
        } else
          throw new Error("Overwrite byte in " + this.encodingName + ", addr: " + addr.toString(16));
      }
      return node;
    };
    DBCSCodec.prototype._addDecodeChunk = function(chunk) {
      var curAddr = parseInt(chunk[0], 16);
      var writeTable = this._getDecodeTrieNode(curAddr);
      curAddr = curAddr & 255;
      for (var k = 1; k < chunk.length; k++) {
        var part = chunk[k];
        if (typeof part === "string") {
          for (var l = 0; l < part.length; ) {
            var code = part.charCodeAt(l++);
            if (55296 <= code && code < 56320) {
              var codeTrail = part.charCodeAt(l++);
              if (56320 <= codeTrail && codeTrail < 57344)
                writeTable[curAddr++] = 65536 + (code - 55296) * 1024 + (codeTrail - 56320);
              else
                throw new Error("Incorrect surrogate pair in " + this.encodingName + " at chunk " + chunk[0]);
            } else if (4080 < code && code <= 4095) {
              var len = 4095 - code + 2;
              var seq = [];
              for (var m = 0; m < len; m++)
                seq.push(part.charCodeAt(l++));
              writeTable[curAddr++] = SEQ_START - this.decodeTableSeq.length;
              this.decodeTableSeq.push(seq);
            } else
              writeTable[curAddr++] = code;
          }
        } else if (typeof part === "number") {
          var charCode = writeTable[curAddr - 1] + 1;
          for (var l = 0; l < part; l++)
            writeTable[curAddr++] = charCode++;
        } else
          throw new Error("Incorrect type '" + typeof part + "' given in " + this.encodingName + " at chunk " + chunk[0]);
      }
      if (curAddr > 255)
        throw new Error("Incorrect chunk in " + this.encodingName + " at addr " + chunk[0] + ": too long" + curAddr);
    };
    DBCSCodec.prototype._getEncodeBucket = function(uCode) {
      var high = uCode >> 8;
      if (this.encodeTable[high] === void 0)
        this.encodeTable[high] = UNASSIGNED_NODE.slice(0);
      return this.encodeTable[high];
    };
    DBCSCodec.prototype._setEncodeChar = function(uCode, dbcsCode) {
      var bucket = this._getEncodeBucket(uCode);
      var low = uCode & 255;
      if (bucket[low] <= SEQ_START)
        this.encodeTableSeq[SEQ_START - bucket[low]][DEF_CHAR] = dbcsCode;
      else if (bucket[low] == UNASSIGNED)
        bucket[low] = dbcsCode;
    };
    DBCSCodec.prototype._setEncodeSequence = function(seq, dbcsCode) {
      var uCode = seq[0];
      var bucket = this._getEncodeBucket(uCode);
      var low = uCode & 255;
      var node;
      if (bucket[low] <= SEQ_START) {
        node = this.encodeTableSeq[SEQ_START - bucket[low]];
      } else {
        node = {};
        if (bucket[low] !== UNASSIGNED)
          node[DEF_CHAR] = bucket[low];
        bucket[low] = SEQ_START - this.encodeTableSeq.length;
        this.encodeTableSeq.push(node);
      }
      for (var j = 1; j < seq.length - 1; j++) {
        var oldVal = node[uCode];
        if (typeof oldVal === "object")
          node = oldVal;
        else {
          node = node[uCode] = {};
          if (oldVal !== void 0)
            node[DEF_CHAR] = oldVal;
        }
      }
      uCode = seq[seq.length - 1];
      node[uCode] = dbcsCode;
    };
    DBCSCodec.prototype._fillEncodeTable = function(nodeIdx, prefix, skipEncodeChars) {
      var node = this.decodeTables[nodeIdx];
      for (var i2 = 0; i2 < 256; i2++) {
        var uCode = node[i2];
        var mbCode = prefix + i2;
        if (skipEncodeChars[mbCode])
          continue;
        if (uCode >= 0)
          this._setEncodeChar(uCode, mbCode);
        else if (uCode <= NODE_START)
          this._fillEncodeTable(NODE_START - uCode, mbCode << 8, skipEncodeChars);
        else if (uCode <= SEQ_START)
          this._setEncodeSequence(this.decodeTableSeq[SEQ_START - uCode], mbCode);
      }
    };
    function DBCSEncoder(options, codec) {
      this.leadSurrogate = -1;
      this.seqObj = void 0;
      this.encodeTable = codec.encodeTable;
      this.encodeTableSeq = codec.encodeTableSeq;
      this.defaultCharSingleByte = codec.defCharSB;
      this.gb18030 = codec.gb18030;
    }
    DBCSEncoder.prototype.write = function(str) {
      var newBuf = Buffer2.alloc(str.length * (this.gb18030 ? 4 : 3)), leadSurrogate = this.leadSurrogate, seqObj = this.seqObj, nextChar = -1, i2 = 0, j = 0;
      while (true) {
        if (nextChar === -1) {
          if (i2 == str.length)
            break;
          var uCode = str.charCodeAt(i2++);
        } else {
          var uCode = nextChar;
          nextChar = -1;
        }
        if (55296 <= uCode && uCode < 57344) {
          if (uCode < 56320) {
            if (leadSurrogate === -1) {
              leadSurrogate = uCode;
              continue;
            } else {
              leadSurrogate = uCode;
              uCode = UNASSIGNED;
            }
          } else {
            if (leadSurrogate !== -1) {
              uCode = 65536 + (leadSurrogate - 55296) * 1024 + (uCode - 56320);
              leadSurrogate = -1;
            } else {
              uCode = UNASSIGNED;
            }
          }
        } else if (leadSurrogate !== -1) {
          nextChar = uCode;
          uCode = UNASSIGNED;
          leadSurrogate = -1;
        }
        var dbcsCode = UNASSIGNED;
        if (seqObj !== void 0 && uCode != UNASSIGNED) {
          var resCode = seqObj[uCode];
          if (typeof resCode === "object") {
            seqObj = resCode;
            continue;
          } else if (typeof resCode == "number") {
            dbcsCode = resCode;
          } else if (resCode == void 0) {
            resCode = seqObj[DEF_CHAR];
            if (resCode !== void 0) {
              dbcsCode = resCode;
              nextChar = uCode;
            } else {
            }
          }
          seqObj = void 0;
        } else if (uCode >= 0) {
          var subtable = this.encodeTable[uCode >> 8];
          if (subtable !== void 0)
            dbcsCode = subtable[uCode & 255];
          if (dbcsCode <= SEQ_START) {
            seqObj = this.encodeTableSeq[SEQ_START - dbcsCode];
            continue;
          }
          if (dbcsCode == UNASSIGNED && this.gb18030) {
            var idx = findIdx(this.gb18030.uChars, uCode);
            if (idx != -1) {
              var dbcsCode = this.gb18030.gbChars[idx] + (uCode - this.gb18030.uChars[idx]);
              newBuf[j++] = 129 + Math.floor(dbcsCode / 12600);
              dbcsCode = dbcsCode % 12600;
              newBuf[j++] = 48 + Math.floor(dbcsCode / 1260);
              dbcsCode = dbcsCode % 1260;
              newBuf[j++] = 129 + Math.floor(dbcsCode / 10);
              dbcsCode = dbcsCode % 10;
              newBuf[j++] = 48 + dbcsCode;
              continue;
            }
          }
        }
        if (dbcsCode === UNASSIGNED)
          dbcsCode = this.defaultCharSingleByte;
        if (dbcsCode < 256) {
          newBuf[j++] = dbcsCode;
        } else if (dbcsCode < 65536) {
          newBuf[j++] = dbcsCode >> 8;
          newBuf[j++] = dbcsCode & 255;
        } else {
          newBuf[j++] = dbcsCode >> 16;
          newBuf[j++] = dbcsCode >> 8 & 255;
          newBuf[j++] = dbcsCode & 255;
        }
      }
      this.seqObj = seqObj;
      this.leadSurrogate = leadSurrogate;
      return newBuf.slice(0, j);
    };
    DBCSEncoder.prototype.end = function() {
      if (this.leadSurrogate === -1 && this.seqObj === void 0)
        return;
      var newBuf = Buffer2.alloc(10), j = 0;
      if (this.seqObj) {
        var dbcsCode = this.seqObj[DEF_CHAR];
        if (dbcsCode !== void 0) {
          if (dbcsCode < 256) {
            newBuf[j++] = dbcsCode;
          } else {
            newBuf[j++] = dbcsCode >> 8;
            newBuf[j++] = dbcsCode & 255;
          }
        } else {
        }
        this.seqObj = void 0;
      }
      if (this.leadSurrogate !== -1) {
        newBuf[j++] = this.defaultCharSingleByte;
        this.leadSurrogate = -1;
      }
      return newBuf.slice(0, j);
    };
    DBCSEncoder.prototype.findIdx = findIdx;
    function DBCSDecoder(options, codec) {
      this.nodeIdx = 0;
      this.prevBuf = Buffer2.alloc(0);
      this.decodeTables = codec.decodeTables;
      this.decodeTableSeq = codec.decodeTableSeq;
      this.defaultCharUnicode = codec.defaultCharUnicode;
      this.gb18030 = codec.gb18030;
    }
    DBCSDecoder.prototype.write = function(buf) {
      var newBuf = Buffer2.alloc(buf.length * 2), nodeIdx = this.nodeIdx, prevBuf = this.prevBuf, prevBufOffset = this.prevBuf.length, seqStart = -this.prevBuf.length, uCode;
      if (prevBufOffset > 0)
        prevBuf = Buffer2.concat([prevBuf, buf.slice(0, 10)]);
      for (var i2 = 0, j = 0; i2 < buf.length; i2++) {
        var curByte = i2 >= 0 ? buf[i2] : prevBuf[i2 + prevBufOffset];
        var uCode = this.decodeTables[nodeIdx][curByte];
        if (uCode >= 0) {
        } else if (uCode === UNASSIGNED) {
          i2 = seqStart;
          uCode = this.defaultCharUnicode.charCodeAt(0);
        } else if (uCode === GB18030_CODE) {
          var curSeq = seqStart >= 0 ? buf.slice(seqStart, i2 + 1) : prevBuf.slice(seqStart + prevBufOffset, i2 + 1 + prevBufOffset);
          var ptr = (curSeq[0] - 129) * 12600 + (curSeq[1] - 48) * 1260 + (curSeq[2] - 129) * 10 + (curSeq[3] - 48);
          var idx = findIdx(this.gb18030.gbChars, ptr);
          uCode = this.gb18030.uChars[idx] + ptr - this.gb18030.gbChars[idx];
        } else if (uCode <= NODE_START) {
          nodeIdx = NODE_START - uCode;
          continue;
        } else if (uCode <= SEQ_START) {
          var seq = this.decodeTableSeq[SEQ_START - uCode];
          for (var k = 0; k < seq.length - 1; k++) {
            uCode = seq[k];
            newBuf[j++] = uCode & 255;
            newBuf[j++] = uCode >> 8;
          }
          uCode = seq[seq.length - 1];
        } else
          throw new Error("iconv-lite internal error: invalid decoding table value " + uCode + " at " + nodeIdx + "/" + curByte);
        if (uCode > 65535) {
          uCode -= 65536;
          var uCodeLead = 55296 + Math.floor(uCode / 1024);
          newBuf[j++] = uCodeLead & 255;
          newBuf[j++] = uCodeLead >> 8;
          uCode = 56320 + uCode % 1024;
        }
        newBuf[j++] = uCode & 255;
        newBuf[j++] = uCode >> 8;
        nodeIdx = 0;
        seqStart = i2 + 1;
      }
      this.nodeIdx = nodeIdx;
      this.prevBuf = seqStart >= 0 ? buf.slice(seqStart) : prevBuf.slice(seqStart + prevBufOffset);
      return newBuf.slice(0, j).toString("ucs2");
    };
    DBCSDecoder.prototype.end = function() {
      var ret = "";
      while (this.prevBuf.length > 0) {
        ret += this.defaultCharUnicode;
        var buf = this.prevBuf.slice(1);
        this.prevBuf = Buffer2.alloc(0);
        this.nodeIdx = 0;
        if (buf.length > 0)
          ret += this.write(buf);
      }
      this.nodeIdx = 0;
      return ret;
    };
    function findIdx(table, val) {
      if (table[0] > val)
        return -1;
      var l = 0, r = table.length;
      while (l < r - 1) {
        var mid = l + Math.floor((r - l + 1) / 2);
        if (table[mid] <= val)
          l = mid;
        else
          r = mid;
      }
      return l;
    }
  }
});

// node_modules/iconv-lite/encodings/tables/shiftjis.json
var require_shiftjis = __commonJS({
  "node_modules/iconv-lite/encodings/tables/shiftjis.json"(exports, module2) {
    module2.exports = [
      ["0", "\0", 128],
      ["a1", "\uFF61", 62],
      ["8140", "\u3000\u3001\u3002\uFF0C\uFF0E\u30FB\uFF1A\uFF1B\uFF1F\uFF01\u309B\u309C\xB4\uFF40\xA8\uFF3E\uFFE3\uFF3F\u30FD\u30FE\u309D\u309E\u3003\u4EDD\u3005\u3006\u3007\u30FC\u2015\u2010\uFF0F\uFF3C\uFF5E\u2225\uFF5C\u2026\u2025\u2018\u2019\u201C\u201D\uFF08\uFF09\u3014\u3015\uFF3B\uFF3D\uFF5B\uFF5D\u3008", 9, "\uFF0B\uFF0D\xB1\xD7"],
      ["8180", "\xF7\uFF1D\u2260\uFF1C\uFF1E\u2266\u2267\u221E\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFFE5\uFF04\uFFE0\uFFE1\uFF05\uFF03\uFF06\uFF0A\uFF20\xA7\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u25BD\u25BC\u203B\u3012\u2192\u2190\u2191\u2193\u3013"],
      ["81b8", "\u2208\u220B\u2286\u2287\u2282\u2283\u222A\u2229"],
      ["81c8", "\u2227\u2228\uFFE2\u21D2\u21D4\u2200\u2203"],
      ["81da", "\u2220\u22A5\u2312\u2202\u2207\u2261\u2252\u226A\u226B\u221A\u223D\u221D\u2235\u222B\u222C"],
      ["81f0", "\u212B\u2030\u266F\u266D\u266A\u2020\u2021\xB6"],
      ["81fc", "\u25EF"],
      ["824f", "\uFF10", 9],
      ["8260", "\uFF21", 25],
      ["8281", "\uFF41", 25],
      ["829f", "\u3041", 82],
      ["8340", "\u30A1", 62],
      ["8380", "\u30E0", 22],
      ["839f", "\u0391", 16, "\u03A3", 6],
      ["83bf", "\u03B1", 16, "\u03C3", 6],
      ["8440", "\u0410", 5, "\u0401\u0416", 25],
      ["8470", "\u0430", 5, "\u0451\u0436", 7],
      ["8480", "\u043E", 17],
      ["849f", "\u2500\u2502\u250C\u2510\u2518\u2514\u251C\u252C\u2524\u2534\u253C\u2501\u2503\u250F\u2513\u251B\u2517\u2523\u2533\u252B\u253B\u254B\u2520\u252F\u2528\u2537\u253F\u251D\u2530\u2525\u2538\u2542"],
      ["8740", "\u2460", 19, "\u2160", 9],
      ["875f", "\u3349\u3314\u3322\u334D\u3318\u3327\u3303\u3336\u3351\u3357\u330D\u3326\u3323\u332B\u334A\u333B\u339C\u339D\u339E\u338E\u338F\u33C4\u33A1"],
      ["877e", "\u337B"],
      ["8780", "\u301D\u301F\u2116\u33CD\u2121\u32A4", 4, "\u3231\u3232\u3239\u337E\u337D\u337C\u2252\u2261\u222B\u222E\u2211\u221A\u22A5\u2220\u221F\u22BF\u2235\u2229\u222A"],
      ["889f", "\u4E9C\u5516\u5A03\u963F\u54C0\u611B\u6328\u59F6\u9022\u8475\u831C\u7A50\u60AA\u63E1\u6E25\u65ED\u8466\u82A6\u9BF5\u6893\u5727\u65A1\u6271\u5B9B\u59D0\u867B\u98F4\u7D62\u7DBE\u9B8E\u6216\u7C9F\u88B7\u5B89\u5EB5\u6309\u6697\u6848\u95C7\u978D\u674F\u4EE5\u4F0A\u4F4D\u4F9D\u5049\u56F2\u5937\u59D4\u5A01\u5C09\u60DF\u610F\u6170\u6613\u6905\u70BA\u754F\u7570\u79FB\u7DAD\u7DEF\u80C3\u840E\u8863\u8B02\u9055\u907A\u533B\u4E95\u4EA5\u57DF\u80B2\u90C1\u78EF\u4E00\u58F1\u6EA2\u9038\u7A32\u8328\u828B\u9C2F\u5141\u5370\u54BD\u54E1\u56E0\u59FB\u5F15\u98F2\u6DEB\u80E4\u852D"],
      ["8940", "\u9662\u9670\u96A0\u97FB\u540B\u53F3\u5B87\u70CF\u7FBD\u8FC2\u96E8\u536F\u9D5C\u7ABA\u4E11\u7893\u81FC\u6E26\u5618\u5504\u6B1D\u851A\u9C3B\u59E5\u53A9\u6D66\u74DC\u958F\u5642\u4E91\u904B\u96F2\u834F\u990C\u53E1\u55B6\u5B30\u5F71\u6620\u66F3\u6804\u6C38\u6CF3\u6D29\u745B\u76C8\u7A4E\u9834\u82F1\u885B\u8A60\u92ED\u6DB2\u75AB\u76CA\u99C5\u60A6\u8B01\u8D8A\u95B2\u698E\u53AD\u5186"],
      ["8980", "\u5712\u5830\u5944\u5BB4\u5EF6\u6028\u63A9\u63F4\u6CBF\u6F14\u708E\u7114\u7159\u71D5\u733F\u7E01\u8276\u82D1\u8597\u9060\u925B\u9D1B\u5869\u65BC\u6C5A\u7525\u51F9\u592E\u5965\u5F80\u5FDC\u62BC\u65FA\u6A2A\u6B27\u6BB4\u738B\u7FC1\u8956\u9D2C\u9D0E\u9EC4\u5CA1\u6C96\u837B\u5104\u5C4B\u61B6\u81C6\u6876\u7261\u4E59\u4FFA\u5378\u6069\u6E29\u7A4F\u97F3\u4E0B\u5316\u4EEE\u4F55\u4F3D\u4FA1\u4F73\u52A0\u53EF\u5609\u590F\u5AC1\u5BB6\u5BE1\u79D1\u6687\u679C\u67B6\u6B4C\u6CB3\u706B\u73C2\u798D\u79BE\u7A3C\u7B87\u82B1\u82DB\u8304\u8377\u83EF\u83D3\u8766\u8AB2\u5629\u8CA8\u8FE6\u904E\u971E\u868A\u4FC4\u5CE8\u6211\u7259\u753B\u81E5\u82BD\u86FE\u8CC0\u96C5\u9913\u99D5\u4ECB\u4F1A\u89E3\u56DE\u584A\u58CA\u5EFB\u5FEB\u602A\u6094\u6062\u61D0\u6212\u62D0\u6539"],
      ["8a40", "\u9B41\u6666\u68B0\u6D77\u7070\u754C\u7686\u7D75\u82A5\u87F9\u958B\u968E\u8C9D\u51F1\u52BE\u5916\u54B3\u5BB3\u5D16\u6168\u6982\u6DAF\u788D\u84CB\u8857\u8A72\u93A7\u9AB8\u6D6C\u99A8\u86D9\u57A3\u67FF\u86CE\u920E\u5283\u5687\u5404\u5ED3\u62E1\u64B9\u683C\u6838\u6BBB\u7372\u78BA\u7A6B\u899A\u89D2\u8D6B\u8F03\u90ED\u95A3\u9694\u9769\u5B66\u5CB3\u697D\u984D\u984E\u639B\u7B20\u6A2B"],
      ["8a80", "\u6A7F\u68B6\u9C0D\u6F5F\u5272\u559D\u6070\u62EC\u6D3B\u6E07\u6ED1\u845B\u8910\u8F44\u4E14\u9C39\u53F6\u691B\u6A3A\u9784\u682A\u515C\u7AC3\u84B2\u91DC\u938C\u565B\u9D28\u6822\u8305\u8431\u7CA5\u5208\u82C5\u74E6\u4E7E\u4F83\u51A0\u5BD2\u520A\u52D8\u52E7\u5DFB\u559A\u582A\u59E6\u5B8C\u5B98\u5BDB\u5E72\u5E79\u60A3\u611F\u6163\u61BE\u63DB\u6562\u67D1\u6853\u68FA\u6B3E\u6B53\u6C57\u6F22\u6F97\u6F45\u74B0\u7518\u76E3\u770B\u7AFF\u7BA1\u7C21\u7DE9\u7F36\u7FF0\u809D\u8266\u839E\u89B3\u8ACC\u8CAB\u9084\u9451\u9593\u9591\u95A2\u9665\u97D3\u9928\u8218\u4E38\u542B\u5CB8\u5DCC\u73A9\u764C\u773C\u5CA9\u7FEB\u8D0B\u96C1\u9811\u9854\u9858\u4F01\u4F0E\u5371\u559C\u5668\u57FA\u5947\u5B09\u5BC4\u5C90\u5E0C\u5E7E\u5FCC\u63EE\u673A\u65D7\u65E2\u671F\u68CB\u68C4"],
      ["8b40", "\u6A5F\u5E30\u6BC5\u6C17\u6C7D\u757F\u7948\u5B63\u7A00\u7D00\u5FBD\u898F\u8A18\u8CB4\u8D77\u8ECC\u8F1D\u98E2\u9A0E\u9B3C\u4E80\u507D\u5100\u5993\u5B9C\u622F\u6280\u64EC\u6B3A\u72A0\u7591\u7947\u7FA9\u87FB\u8ABC\u8B70\u63AC\u83CA\u97A0\u5409\u5403\u55AB\u6854\u6A58\u8A70\u7827\u6775\u9ECD\u5374\u5BA2\u811A\u8650\u9006\u4E18\u4E45\u4EC7\u4F11\u53CA\u5438\u5BAE\u5F13\u6025\u6551"],
      ["8b80", "\u673D\u6C42\u6C72\u6CE3\u7078\u7403\u7A76\u7AAE\u7B08\u7D1A\u7CFE\u7D66\u65E7\u725B\u53BB\u5C45\u5DE8\u62D2\u62E0\u6319\u6E20\u865A\u8A31\u8DDD\u92F8\u6F01\u79A6\u9B5A\u4EA8\u4EAB\u4EAC\u4F9B\u4FA0\u50D1\u5147\u7AF6\u5171\u51F6\u5354\u5321\u537F\u53EB\u55AC\u5883\u5CE1\u5F37\u5F4A\u602F\u6050\u606D\u631F\u6559\u6A4B\u6CC1\u72C2\u72ED\u77EF\u80F8\u8105\u8208\u854E\u90F7\u93E1\u97FF\u9957\u9A5A\u4EF0\u51DD\u5C2D\u6681\u696D\u5C40\u66F2\u6975\u7389\u6850\u7C81\u50C5\u52E4\u5747\u5DFE\u9326\u65A4\u6B23\u6B3D\u7434\u7981\u79BD\u7B4B\u7DCA\u82B9\u83CC\u887F\u895F\u8B39\u8FD1\u91D1\u541F\u9280\u4E5D\u5036\u53E5\u533A\u72D7\u7396\u77E9\u82E6\u8EAF\u99C6\u99C8\u99D2\u5177\u611A\u865E\u55B0\u7A7A\u5076\u5BD3\u9047\u9685\u4E32\u6ADB\u91E7\u5C51\u5C48"],
      ["8c40", "\u6398\u7A9F\u6C93\u9774\u8F61\u7AAA\u718A\u9688\u7C82\u6817\u7E70\u6851\u936C\u52F2\u541B\u85AB\u8A13\u7FA4\u8ECD\u90E1\u5366\u8888\u7941\u4FC2\u50BE\u5211\u5144\u5553\u572D\u73EA\u578B\u5951\u5F62\u5F84\u6075\u6176\u6167\u61A9\u63B2\u643A\u656C\u666F\u6842\u6E13\u7566\u7A3D\u7CFB\u7D4C\u7D99\u7E4B\u7F6B\u830E\u834A\u86CD\u8A08\u8A63\u8B66\u8EFD\u981A\u9D8F\u82B8\u8FCE\u9BE8"],
      ["8c80", "\u5287\u621F\u6483\u6FC0\u9699\u6841\u5091\u6B20\u6C7A\u6F54\u7A74\u7D50\u8840\u8A23\u6708\u4EF6\u5039\u5026\u5065\u517C\u5238\u5263\u55A7\u570F\u5805\u5ACC\u5EFA\u61B2\u61F8\u62F3\u6372\u691C\u6A29\u727D\u72AC\u732E\u7814\u786F\u7D79\u770C\u80A9\u898B\u8B19\u8CE2\u8ED2\u9063\u9375\u967A\u9855\u9A13\u9E78\u5143\u539F\u53B3\u5E7B\u5F26\u6E1B\u6E90\u7384\u73FE\u7D43\u8237\u8A00\u8AFA\u9650\u4E4E\u500B\u53E4\u547C\u56FA\u59D1\u5B64\u5DF1\u5EAB\u5F27\u6238\u6545\u67AF\u6E56\u72D0\u7CCA\u88B4\u80A1\u80E1\u83F0\u864E\u8A87\u8DE8\u9237\u96C7\u9867\u9F13\u4E94\u4E92\u4F0D\u5348\u5449\u543E\u5A2F\u5F8C\u5FA1\u609F\u68A7\u6A8E\u745A\u7881\u8A9E\u8AA4\u8B77\u9190\u4E5E\u9BC9\u4EA4\u4F7C\u4FAF\u5019\u5016\u5149\u516C\u529F\u52B9\u52FE\u539A\u53E3\u5411"],
      ["8d40", "\u540E\u5589\u5751\u57A2\u597D\u5B54\u5B5D\u5B8F\u5DE5\u5DE7\u5DF7\u5E78\u5E83\u5E9A\u5EB7\u5F18\u6052\u614C\u6297\u62D8\u63A7\u653B\u6602\u6643\u66F4\u676D\u6821\u6897\u69CB\u6C5F\u6D2A\u6D69\u6E2F\u6E9D\u7532\u7687\u786C\u7A3F\u7CE0\u7D05\u7D18\u7D5E\u7DB1\u8015\u8003\u80AF\u80B1\u8154\u818F\u822A\u8352\u884C\u8861\u8B1B\u8CA2\u8CFC\u90CA\u9175\u9271\u783F\u92FC\u95A4\u964D"],
      ["8d80", "\u9805\u9999\u9AD8\u9D3B\u525B\u52AB\u53F7\u5408\u58D5\u62F7\u6FE0\u8C6A\u8F5F\u9EB9\u514B\u523B\u544A\u56FD\u7A40\u9177\u9D60\u9ED2\u7344\u6F09\u8170\u7511\u5FFD\u60DA\u9AA8\u72DB\u8FBC\u6B64\u9803\u4ECA\u56F0\u5764\u58BE\u5A5A\u6068\u61C7\u660F\u6606\u6839\u68B1\u6DF7\u75D5\u7D3A\u826E\u9B42\u4E9B\u4F50\u53C9\u5506\u5D6F\u5DE6\u5DEE\u67FB\u6C99\u7473\u7802\u8A50\u9396\u88DF\u5750\u5EA7\u632B\u50B5\u50AC\u518D\u6700\u54C9\u585E\u59BB\u5BB0\u5F69\u624D\u63A1\u683D\u6B73\u6E08\u707D\u91C7\u7280\u7815\u7826\u796D\u658E\u7D30\u83DC\u88C1\u8F09\u969B\u5264\u5728\u6750\u7F6A\u8CA1\u51B4\u5742\u962A\u583A\u698A\u80B4\u54B2\u5D0E\u57FC\u7895\u9DFA\u4F5C\u524A\u548B\u643E\u6628\u6714\u67F5\u7A84\u7B56\u7D22\u932F\u685C\u9BAD\u7B39\u5319\u518A\u5237"],
      ["8e40", "\u5BDF\u62F6\u64AE\u64E6\u672D\u6BBA\u85A9\u96D1\u7690\u9BD6\u634C\u9306\u9BAB\u76BF\u6652\u4E09\u5098\u53C2\u5C71\u60E8\u6492\u6563\u685F\u71E6\u73CA\u7523\u7B97\u7E82\u8695\u8B83\u8CDB\u9178\u9910\u65AC\u66AB\u6B8B\u4ED5\u4ED4\u4F3A\u4F7F\u523A\u53F8\u53F2\u55E3\u56DB\u58EB\u59CB\u59C9\u59FF\u5B50\u5C4D\u5E02\u5E2B\u5FD7\u601D\u6307\u652F\u5B5C\u65AF\u65BD\u65E8\u679D\u6B62"],
      ["8e80", "\u6B7B\u6C0F\u7345\u7949\u79C1\u7CF8\u7D19\u7D2B\u80A2\u8102\u81F3\u8996\u8A5E\u8A69\u8A66\u8A8C\u8AEE\u8CC7\u8CDC\u96CC\u98FC\u6B6F\u4E8B\u4F3C\u4F8D\u5150\u5B57\u5BFA\u6148\u6301\u6642\u6B21\u6ECB\u6CBB\u723E\u74BD\u75D4\u78C1\u793A\u800C\u8033\u81EA\u8494\u8F9E\u6C50\u9E7F\u5F0F\u8B58\u9D2B\u7AFA\u8EF8\u5B8D\u96EB\u4E03\u53F1\u57F7\u5931\u5AC9\u5BA4\u6089\u6E7F\u6F06\u75BE\u8CEA\u5B9F\u8500\u7BE0\u5072\u67F4\u829D\u5C61\u854A\u7E1E\u820E\u5199\u5C04\u6368\u8D66\u659C\u716E\u793E\u7D17\u8005\u8B1D\u8ECA\u906E\u86C7\u90AA\u501F\u52FA\u5C3A\u6753\u707C\u7235\u914C\u91C8\u932B\u82E5\u5BC2\u5F31\u60F9\u4E3B\u53D6\u5B88\u624B\u6731\u6B8A\u72E9\u73E0\u7A2E\u816B\u8DA3\u9152\u9996\u5112\u53D7\u546A\u5BFF\u6388\u6A39\u7DAC\u9700\u56DA\u53CE\u5468"],
      ["8f40", "\u5B97\u5C31\u5DDE\u4FEE\u6101\u62FE\u6D32\u79C0\u79CB\u7D42\u7E4D\u7FD2\u81ED\u821F\u8490\u8846\u8972\u8B90\u8E74\u8F2F\u9031\u914B\u916C\u96C6\u919C\u4EC0\u4F4F\u5145\u5341\u5F93\u620E\u67D4\u6C41\u6E0B\u7363\u7E26\u91CD\u9283\u53D4\u5919\u5BBF\u6DD1\u795D\u7E2E\u7C9B\u587E\u719F\u51FA\u8853\u8FF0\u4FCA\u5CFB\u6625\u77AC\u7AE3\u821C\u99FF\u51C6\u5FAA\u65EC\u696F\u6B89\u6DF3"],
      ["8f80", "\u6E96\u6F64\u76FE\u7D14\u5DE1\u9075\u9187\u9806\u51E6\u521D\u6240\u6691\u66D9\u6E1A\u5EB6\u7DD2\u7F72\u66F8\u85AF\u85F7\u8AF8\u52A9\u53D9\u5973\u5E8F\u5F90\u6055\u92E4\u9664\u50B7\u511F\u52DD\u5320\u5347\u53EC\u54E8\u5546\u5531\u5617\u5968\u59BE\u5A3C\u5BB5\u5C06\u5C0F\u5C11\u5C1A\u5E84\u5E8A\u5EE0\u5F70\u627F\u6284\u62DB\u638C\u6377\u6607\u660C\u662D\u6676\u677E\u68A2\u6A1F\u6A35\u6CBC\u6D88\u6E09\u6E58\u713C\u7126\u7167\u75C7\u7701\u785D\u7901\u7965\u79F0\u7AE0\u7B11\u7CA7\u7D39\u8096\u83D6\u848B\u8549\u885D\u88F3\u8A1F\u8A3C\u8A54\u8A73\u8C61\u8CDE\u91A4\u9266\u937E\u9418\u969C\u9798\u4E0A\u4E08\u4E1E\u4E57\u5197\u5270\u57CE\u5834\u58CC\u5B22\u5E38\u60C5\u64FE\u6761\u6756\u6D44\u72B6\u7573\u7A63\u84B8\u8B72\u91B8\u9320\u5631\u57F4\u98FE"],
      ["9040", "\u62ED\u690D\u6B96\u71ED\u7E54\u8077\u8272\u89E6\u98DF\u8755\u8FB1\u5C3B\u4F38\u4FE1\u4FB5\u5507\u5A20\u5BDD\u5BE9\u5FC3\u614E\u632F\u65B0\u664B\u68EE\u699B\u6D78\u6DF1\u7533\u75B9\u771F\u795E\u79E6\u7D33\u81E3\u82AF\u85AA\u89AA\u8A3A\u8EAB\u8F9B\u9032\u91DD\u9707\u4EBA\u4EC1\u5203\u5875\u58EC\u5C0B\u751A\u5C3D\u814E\u8A0A\u8FC5\u9663\u976D\u7B25\u8ACF\u9808\u9162\u56F3\u53A8"],
      ["9080", "\u9017\u5439\u5782\u5E25\u63A8\u6C34\u708A\u7761\u7C8B\u7FE0\u8870\u9042\u9154\u9310\u9318\u968F\u745E\u9AC4\u5D07\u5D69\u6570\u67A2\u8DA8\u96DB\u636E\u6749\u6919\u83C5\u9817\u96C0\u88FE\u6F84\u647A\u5BF8\u4E16\u702C\u755D\u662F\u51C4\u5236\u52E2\u59D3\u5F81\u6027\u6210\u653F\u6574\u661F\u6674\u68F2\u6816\u6B63\u6E05\u7272\u751F\u76DB\u7CBE\u8056\u58F0\u88FD\u897F\u8AA0\u8A93\u8ACB\u901D\u9192\u9752\u9759\u6589\u7A0E\u8106\u96BB\u5E2D\u60DC\u621A\u65A5\u6614\u6790\u77F3\u7A4D\u7C4D\u7E3E\u810A\u8CAC\u8D64\u8DE1\u8E5F\u78A9\u5207\u62D9\u63A5\u6442\u6298\u8A2D\u7A83\u7BC0\u8AAC\u96EA\u7D76\u820C\u8749\u4ED9\u5148\u5343\u5360\u5BA3\u5C02\u5C16\u5DDD\u6226\u6247\u64B0\u6813\u6834\u6CC9\u6D45\u6D17\u67D3\u6F5C\u714E\u717D\u65CB\u7A7F\u7BAD\u7DDA"],
      ["9140", "\u7E4A\u7FA8\u817A\u821B\u8239\u85A6\u8A6E\u8CCE\u8DF5\u9078\u9077\u92AD\u9291\u9583\u9BAE\u524D\u5584\u6F38\u7136\u5168\u7985\u7E55\u81B3\u7CCE\u564C\u5851\u5CA8\u63AA\u66FE\u66FD\u695A\u72D9\u758F\u758E\u790E\u7956\u79DF\u7C97\u7D20\u7D44\u8607\u8A34\u963B\u9061\u9F20\u50E7\u5275\u53CC\u53E2\u5009\u55AA\u58EE\u594F\u723D\u5B8B\u5C64\u531D\u60E3\u60F3\u635C\u6383\u633F\u63BB"],
      ["9180", "\u64CD\u65E9\u66F9\u5DE3\u69CD\u69FD\u6F15\u71E5\u4E89\u75E9\u76F8\u7A93\u7CDF\u7DCF\u7D9C\u8061\u8349\u8358\u846C\u84BC\u85FB\u88C5\u8D70\u9001\u906D\u9397\u971C\u9A12\u50CF\u5897\u618E\u81D3\u8535\u8D08\u9020\u4FC3\u5074\u5247\u5373\u606F\u6349\u675F\u6E2C\u8DB3\u901F\u4FD7\u5C5E\u8CCA\u65CF\u7D9A\u5352\u8896\u5176\u63C3\u5B58\u5B6B\u5C0A\u640D\u6751\u905C\u4ED6\u591A\u592A\u6C70\u8A51\u553E\u5815\u59A5\u60F0\u6253\u67C1\u8235\u6955\u9640\u99C4\u9A28\u4F53\u5806\u5BFE\u8010\u5CB1\u5E2F\u5F85\u6020\u614B\u6234\u66FF\u6CF0\u6EDE\u80CE\u817F\u82D4\u888B\u8CB8\u9000\u902E\u968A\u9EDB\u9BDB\u4EE3\u53F0\u5927\u7B2C\u918D\u984C\u9DF9\u6EDD\u7027\u5353\u5544\u5B85\u6258\u629E\u62D3\u6CA2\u6FEF\u7422\u8A17\u9438\u6FC1\u8AFE\u8338\u51E7\u86F8\u53EA"],
      ["9240", "\u53E9\u4F46\u9054\u8FB0\u596A\u8131\u5DFD\u7AEA\u8FBF\u68DA\u8C37\u72F8\u9C48\u6A3D\u8AB0\u4E39\u5358\u5606\u5766\u62C5\u63A2\u65E6\u6B4E\u6DE1\u6E5B\u70AD\u77ED\u7AEF\u7BAA\u7DBB\u803D\u80C6\u86CB\u8A95\u935B\u56E3\u58C7\u5F3E\u65AD\u6696\u6A80\u6BB5\u7537\u8AC7\u5024\u77E5\u5730\u5F1B\u6065\u667A\u6C60\u75F4\u7A1A\u7F6E\u81F4\u8718\u9045\u99B3\u7BC9\u755C\u7AF9\u7B51\u84C4"],
      ["9280", "\u9010\u79E9\u7A92\u8336\u5AE1\u7740\u4E2D\u4EF2\u5B99\u5FE0\u62BD\u663C\u67F1\u6CE8\u866B\u8877\u8A3B\u914E\u92F3\u99D0\u6A17\u7026\u732A\u82E7\u8457\u8CAF\u4E01\u5146\u51CB\u558B\u5BF5\u5E16\u5E33\u5E81\u5F14\u5F35\u5F6B\u5FB4\u61F2\u6311\u66A2\u671D\u6F6E\u7252\u753A\u773A\u8074\u8139\u8178\u8776\u8ABF\u8ADC\u8D85\u8DF3\u929A\u9577\u9802\u9CE5\u52C5\u6357\u76F4\u6715\u6C88\u73CD\u8CC3\u93AE\u9673\u6D25\u589C\u690E\u69CC\u8FFD\u939A\u75DB\u901A\u585A\u6802\u63B4\u69FB\u4F43\u6F2C\u67D8\u8FBB\u8526\u7DB4\u9354\u693F\u6F70\u576A\u58F7\u5B2C\u7D2C\u722A\u540A\u91E3\u9DB4\u4EAD\u4F4E\u505C\u5075\u5243\u8C9E\u5448\u5824\u5B9A\u5E1D\u5E95\u5EAD\u5EF7\u5F1F\u608C\u62B5\u633A\u63D0\u68AF\u6C40\u7887\u798E\u7A0B\u7DE0\u8247\u8A02\u8AE6\u8E44\u9013"],
      ["9340", "\u90B8\u912D\u91D8\u9F0E\u6CE5\u6458\u64E2\u6575\u6EF4\u7684\u7B1B\u9069\u93D1\u6EBA\u54F2\u5FB9\u64A4\u8F4D\u8FED\u9244\u5178\u586B\u5929\u5C55\u5E97\u6DFB\u7E8F\u751C\u8CBC\u8EE2\u985B\u70B9\u4F1D\u6BBF\u6FB1\u7530\u96FB\u514E\u5410\u5835\u5857\u59AC\u5C60\u5F92\u6597\u675C\u6E21\u767B\u83DF\u8CED\u9014\u90FD\u934D\u7825\u783A\u52AA\u5EA6\u571F\u5974\u6012\u5012\u515A\u51AC"],
      ["9380", "\u51CD\u5200\u5510\u5854\u5858\u5957\u5B95\u5CF6\u5D8B\u60BC\u6295\u642D\u6771\u6843\u68BC\u68DF\u76D7\u6DD8\u6E6F\u6D9B\u706F\u71C8\u5F53\u75D8\u7977\u7B49\u7B54\u7B52\u7CD6\u7D71\u5230\u8463\u8569\u85E4\u8A0E\u8B04\u8C46\u8E0F\u9003\u900F\u9419\u9676\u982D\u9A30\u95D8\u50CD\u52D5\u540C\u5802\u5C0E\u61A7\u649E\u6D1E\u77B3\u7AE5\u80F4\u8404\u9053\u9285\u5CE0\u9D07\u533F\u5F97\u5FB3\u6D9C\u7279\u7763\u79BF\u7BE4\u6BD2\u72EC\u8AAD\u6803\u6A61\u51F8\u7A81\u6934\u5C4A\u9CF6\u82EB\u5BC5\u9149\u701E\u5678\u5C6F\u60C7\u6566\u6C8C\u8C5A\u9041\u9813\u5451\u66C7\u920D\u5948\u90A3\u5185\u4E4D\u51EA\u8599\u8B0E\u7058\u637A\u934B\u6962\u99B4\u7E04\u7577\u5357\u6960\u8EDF\u96E3\u6C5D\u4E8C\u5C3C\u5F10\u8FE9\u5302\u8CD1\u8089\u8679\u5EFF\u65E5\u4E73\u5165"],
      ["9440", "\u5982\u5C3F\u97EE\u4EFB\u598A\u5FCD\u8A8D\u6FE1\u79B0\u7962\u5BE7\u8471\u732B\u71B1\u5E74\u5FF5\u637B\u649A\u71C3\u7C98\u4E43\u5EFC\u4E4B\u57DC\u56A2\u60A9\u6FC3\u7D0D\u80FD\u8133\u81BF\u8FB2\u8997\u86A4\u5DF4\u628A\u64AD\u8987\u6777\u6CE2\u6D3E\u7436\u7834\u5A46\u7F75\u82AD\u99AC\u4FF3\u5EC3\u62DD\u6392\u6557\u676F\u76C3\u724C\u80CC\u80BA\u8F29\u914D\u500D\u57F9\u5A92\u6885"],
      ["9480", "\u6973\u7164\u72FD\u8CB7\u58F2\u8CE0\u966A\u9019\u877F\u79E4\u77E7\u8429\u4F2F\u5265\u535A\u62CD\u67CF\u6CCA\u767D\u7B94\u7C95\u8236\u8584\u8FEB\u66DD\u6F20\u7206\u7E1B\u83AB\u99C1\u9EA6\u51FD\u7BB1\u7872\u7BB8\u8087\u7B48\u6AE8\u5E61\u808C\u7551\u7560\u516B\u9262\u6E8C\u767A\u9197\u9AEA\u4F10\u7F70\u629C\u7B4F\u95A5\u9CE9\u567A\u5859\u86E4\u96BC\u4F34\u5224\u534A\u53CD\u53DB\u5E06\u642C\u6591\u677F\u6C3E\u6C4E\u7248\u72AF\u73ED\u7554\u7E41\u822C\u85E9\u8CA9\u7BC4\u91C6\u7169\u9812\u98EF\u633D\u6669\u756A\u76E4\u78D0\u8543\u86EE\u532A\u5351\u5426\u5983\u5E87\u5F7C\u60B2\u6249\u6279\u62AB\u6590\u6BD4\u6CCC\u75B2\u76AE\u7891\u79D8\u7DCB\u7F77\u80A5\u88AB\u8AB9\u8CBB\u907F\u975E\u98DB\u6A0B\u7C38\u5099\u5C3E\u5FAE\u6787\u6BD8\u7435\u7709\u7F8E"],
      ["9540", "\u9F3B\u67CA\u7A17\u5339\u758B\u9AED\u5F66\u819D\u83F1\u8098\u5F3C\u5FC5\u7562\u7B46\u903C\u6867\u59EB\u5A9B\u7D10\u767E\u8B2C\u4FF5\u5F6A\u6A19\u6C37\u6F02\u74E2\u7968\u8868\u8A55\u8C79\u5EDF\u63CF\u75C5\u79D2\u82D7\u9328\u92F2\u849C\u86ED\u9C2D\u54C1\u5F6C\u658C\u6D5C\u7015\u8CA7\u8CD3\u983B\u654F\u74F6\u4E0D\u4ED8\u57E0\u592B\u5A66\u5BCC\u51A8\u5E03\u5E9C\u6016\u6276\u6577"],
      ["9580", "\u65A7\u666E\u6D6E\u7236\u7B26\u8150\u819A\u8299\u8B5C\u8CA0\u8CE6\u8D74\u961C\u9644\u4FAE\u64AB\u6B66\u821E\u8461\u856A\u90E8\u5C01\u6953\u98A8\u847A\u8557\u4F0F\u526F\u5FA9\u5E45\u670D\u798F\u8179\u8907\u8986\u6DF5\u5F17\u6255\u6CB8\u4ECF\u7269\u9B92\u5206\u543B\u5674\u58B3\u61A4\u626E\u711A\u596E\u7C89\u7CDE\u7D1B\u96F0\u6587\u805E\u4E19\u4F75\u5175\u5840\u5E63\u5E73\u5F0A\u67C4\u4E26\u853D\u9589\u965B\u7C73\u9801\u50FB\u58C1\u7656\u78A7\u5225\u77A5\u8511\u7B86\u504F\u5909\u7247\u7BC7\u7DE8\u8FBA\u8FD4\u904D\u4FBF\u52C9\u5A29\u5F01\u97AD\u4FDD\u8217\u92EA\u5703\u6355\u6B69\u752B\u88DC\u8F14\u7A42\u52DF\u5893\u6155\u620A\u66AE\u6BCD\u7C3F\u83E9\u5023\u4FF8\u5305\u5446\u5831\u5949\u5B9D\u5CF0\u5CEF\u5D29\u5E96\u62B1\u6367\u653E\u65B9\u670B"],
      ["9640", "\u6CD5\u6CE1\u70F9\u7832\u7E2B\u80DE\u82B3\u840C\u84EC\u8702\u8912\u8A2A\u8C4A\u90A6\u92D2\u98FD\u9CF3\u9D6C\u4E4F\u4EA1\u508D\u5256\u574A\u59A8\u5E3D\u5FD8\u5FD9\u623F\u66B4\u671B\u67D0\u68D2\u5192\u7D21\u80AA\u81A8\u8B00\u8C8C\u8CBF\u927E\u9632\u5420\u982C\u5317\u50D5\u535C\u58A8\u64B2\u6734\u7267\u7766\u7A46\u91E6\u52C3\u6CA1\u6B86\u5800\u5E4C\u5954\u672C\u7FFB\u51E1\u76C6"],
      ["9680", "\u6469\u78E8\u9B54\u9EBB\u57CB\u59B9\u6627\u679A\u6BCE\u54E9\u69D9\u5E55\u819C\u6795\u9BAA\u67FE\u9C52\u685D\u4EA6\u4FE3\u53C8\u62B9\u672B\u6CAB\u8FC4\u4FAD\u7E6D\u9EBF\u4E07\u6162\u6E80\u6F2B\u8513\u5473\u672A\u9B45\u5DF3\u7B95\u5CAC\u5BC6\u871C\u6E4A\u84D1\u7A14\u8108\u5999\u7C8D\u6C11\u7720\u52D9\u5922\u7121\u725F\u77DB\u9727\u9D61\u690B\u5A7F\u5A18\u51A5\u540D\u547D\u660E\u76DF\u8FF7\u9298\u9CF4\u59EA\u725D\u6EC5\u514D\u68C9\u7DBF\u7DEC\u9762\u9EBA\u6478\u6A21\u8302\u5984\u5B5F\u6BDB\u731B\u76F2\u7DB2\u8017\u8499\u5132\u6728\u9ED9\u76EE\u6762\u52FF\u9905\u5C24\u623B\u7C7E\u8CB0\u554F\u60B6\u7D0B\u9580\u5301\u4E5F\u51B6\u591C\u723A\u8036\u91CE\u5F25\u77E2\u5384\u5F79\u7D04\u85AC\u8A33\u8E8D\u9756\u67F3\u85AE\u9453\u6109\u6108\u6CB9\u7652"],
      ["9740", "\u8AED\u8F38\u552F\u4F51\u512A\u52C7\u53CB\u5BA5\u5E7D\u60A0\u6182\u63D6\u6709\u67DA\u6E67\u6D8C\u7336\u7337\u7531\u7950\u88D5\u8A98\u904A\u9091\u90F5\u96C4\u878D\u5915\u4E88\u4F59\u4E0E\u8A89\u8F3F\u9810\u50AD\u5E7C\u5996\u5BB9\u5EB8\u63DA\u63FA\u64C1\u66DC\u694A\u69D8\u6D0B\u6EB6\u7194\u7528\u7AAF\u7F8A\u8000\u8449\u84C9\u8981\u8B21\u8E0A\u9065\u967D\u990A\u617E\u6291\u6B32"],
      ["9780", "\u6C83\u6D74\u7FCC\u7FFC\u6DC0\u7F85\u87BA\u88F8\u6765\u83B1\u983C\u96F7\u6D1B\u7D61\u843D\u916A\u4E71\u5375\u5D50\u6B04\u6FEB\u85CD\u862D\u89A7\u5229\u540F\u5C65\u674E\u68A8\u7406\u7483\u75E2\u88CF\u88E1\u91CC\u96E2\u9678\u5F8B\u7387\u7ACB\u844E\u63A0\u7565\u5289\u6D41\u6E9C\u7409\u7559\u786B\u7C92\u9686\u7ADC\u9F8D\u4FB6\u616E\u65C5\u865C\u4E86\u4EAE\u50DA\u4E21\u51CC\u5BEE\u6599\u6881\u6DBC\u731F\u7642\u77AD\u7A1C\u7CE7\u826F\u8AD2\u907C\u91CF\u9675\u9818\u529B\u7DD1\u502B\u5398\u6797\u6DCB\u71D0\u7433\u81E8\u8F2A\u96A3\u9C57\u9E9F\u7460\u5841\u6D99\u7D2F\u985E\u4EE4\u4F36\u4F8B\u51B7\u52B1\u5DBA\u601C\u73B2\u793C\u82D3\u9234\u96B7\u96F6\u970A\u9E97\u9F62\u66A6\u6B74\u5217\u52A3\u70C8\u88C2\u5EC9\u604B\u6190\u6F23\u7149\u7C3E\u7DF4\u806F"],
      ["9840", "\u84EE\u9023\u932C\u5442\u9B6F\u6AD3\u7089\u8CC2\u8DEF\u9732\u52B4\u5A41\u5ECA\u5F04\u6717\u697C\u6994\u6D6A\u6F0F\u7262\u72FC\u7BED\u8001\u807E\u874B\u90CE\u516D\u9E93\u7984\u808B\u9332\u8AD6\u502D\u548C\u8A71\u6B6A\u8CC4\u8107\u60D1\u67A0\u9DF2\u4E99\u4E98\u9C10\u8A6B\u85C1\u8568\u6900\u6E7E\u7897\u8155"],
      ["989f", "\u5F0C\u4E10\u4E15\u4E2A\u4E31\u4E36\u4E3C\u4E3F\u4E42\u4E56\u4E58\u4E82\u4E85\u8C6B\u4E8A\u8212\u5F0D\u4E8E\u4E9E\u4E9F\u4EA0\u4EA2\u4EB0\u4EB3\u4EB6\u4ECE\u4ECD\u4EC4\u4EC6\u4EC2\u4ED7\u4EDE\u4EED\u4EDF\u4EF7\u4F09\u4F5A\u4F30\u4F5B\u4F5D\u4F57\u4F47\u4F76\u4F88\u4F8F\u4F98\u4F7B\u4F69\u4F70\u4F91\u4F6F\u4F86\u4F96\u5118\u4FD4\u4FDF\u4FCE\u4FD8\u4FDB\u4FD1\u4FDA\u4FD0\u4FE4\u4FE5\u501A\u5028\u5014\u502A\u5025\u5005\u4F1C\u4FF6\u5021\u5029\u502C\u4FFE\u4FEF\u5011\u5006\u5043\u5047\u6703\u5055\u5050\u5048\u505A\u5056\u506C\u5078\u5080\u509A\u5085\u50B4\u50B2"],
      ["9940", "\u50C9\u50CA\u50B3\u50C2\u50D6\u50DE\u50E5\u50ED\u50E3\u50EE\u50F9\u50F5\u5109\u5101\u5102\u5116\u5115\u5114\u511A\u5121\u513A\u5137\u513C\u513B\u513F\u5140\u5152\u514C\u5154\u5162\u7AF8\u5169\u516A\u516E\u5180\u5182\u56D8\u518C\u5189\u518F\u5191\u5193\u5195\u5196\u51A4\u51A6\u51A2\u51A9\u51AA\u51AB\u51B3\u51B1\u51B2\u51B0\u51B5\u51BD\u51C5\u51C9\u51DB\u51E0\u8655\u51E9\u51ED"],
      ["9980", "\u51F0\u51F5\u51FE\u5204\u520B\u5214\u520E\u5227\u522A\u522E\u5233\u5239\u524F\u5244\u524B\u524C\u525E\u5254\u526A\u5274\u5269\u5273\u527F\u527D\u528D\u5294\u5292\u5271\u5288\u5291\u8FA8\u8FA7\u52AC\u52AD\u52BC\u52B5\u52C1\u52CD\u52D7\u52DE\u52E3\u52E6\u98ED\u52E0\u52F3\u52F5\u52F8\u52F9\u5306\u5308\u7538\u530D\u5310\u530F\u5315\u531A\u5323\u532F\u5331\u5333\u5338\u5340\u5346\u5345\u4E17\u5349\u534D\u51D6\u535E\u5369\u536E\u5918\u537B\u5377\u5382\u5396\u53A0\u53A6\u53A5\u53AE\u53B0\u53B6\u53C3\u7C12\u96D9\u53DF\u66FC\u71EE\u53EE\u53E8\u53ED\u53FA\u5401\u543D\u5440\u542C\u542D\u543C\u542E\u5436\u5429\u541D\u544E\u548F\u5475\u548E\u545F\u5471\u5477\u5470\u5492\u547B\u5480\u5476\u5484\u5490\u5486\u54C7\u54A2\u54B8\u54A5\u54AC\u54C4\u54C8\u54A8"],
      ["9a40", "\u54AB\u54C2\u54A4\u54BE\u54BC\u54D8\u54E5\u54E6\u550F\u5514\u54FD\u54EE\u54ED\u54FA\u54E2\u5539\u5540\u5563\u554C\u552E\u555C\u5545\u5556\u5557\u5538\u5533\u555D\u5599\u5580\u54AF\u558A\u559F\u557B\u557E\u5598\u559E\u55AE\u557C\u5583\u55A9\u5587\u55A8\u55DA\u55C5\u55DF\u55C4\u55DC\u55E4\u55D4\u5614\u55F7\u5616\u55FE\u55FD\u561B\u55F9\u564E\u5650\u71DF\u5634\u5636\u5632\u5638"],
      ["9a80", "\u566B\u5664\u562F\u566C\u566A\u5686\u5680\u568A\u56A0\u5694\u568F\u56A5\u56AE\u56B6\u56B4\u56C2\u56BC\u56C1\u56C3\u56C0\u56C8\u56CE\u56D1\u56D3\u56D7\u56EE\u56F9\u5700\u56FF\u5704\u5709\u5708\u570B\u570D\u5713\u5718\u5716\u55C7\u571C\u5726\u5737\u5738\u574E\u573B\u5740\u574F\u5769\u57C0\u5788\u5761\u577F\u5789\u5793\u57A0\u57B3\u57A4\u57AA\u57B0\u57C3\u57C6\u57D4\u57D2\u57D3\u580A\u57D6\u57E3\u580B\u5819\u581D\u5872\u5821\u5862\u584B\u5870\u6BC0\u5852\u583D\u5879\u5885\u58B9\u589F\u58AB\u58BA\u58DE\u58BB\u58B8\u58AE\u58C5\u58D3\u58D1\u58D7\u58D9\u58D8\u58E5\u58DC\u58E4\u58DF\u58EF\u58FA\u58F9\u58FB\u58FC\u58FD\u5902\u590A\u5910\u591B\u68A6\u5925\u592C\u592D\u5932\u5938\u593E\u7AD2\u5955\u5950\u594E\u595A\u5958\u5962\u5960\u5967\u596C\u5969"],
      ["9b40", "\u5978\u5981\u599D\u4F5E\u4FAB\u59A3\u59B2\u59C6\u59E8\u59DC\u598D\u59D9\u59DA\u5A25\u5A1F\u5A11\u5A1C\u5A09\u5A1A\u5A40\u5A6C\u5A49\u5A35\u5A36\u5A62\u5A6A\u5A9A\u5ABC\u5ABE\u5ACB\u5AC2\u5ABD\u5AE3\u5AD7\u5AE6\u5AE9\u5AD6\u5AFA\u5AFB\u5B0C\u5B0B\u5B16\u5B32\u5AD0\u5B2A\u5B36\u5B3E\u5B43\u5B45\u5B40\u5B51\u5B55\u5B5A\u5B5B\u5B65\u5B69\u5B70\u5B73\u5B75\u5B78\u6588\u5B7A\u5B80"],
      ["9b80", "\u5B83\u5BA6\u5BB8\u5BC3\u5BC7\u5BC9\u5BD4\u5BD0\u5BE4\u5BE6\u5BE2\u5BDE\u5BE5\u5BEB\u5BF0\u5BF6\u5BF3\u5C05\u5C07\u5C08\u5C0D\u5C13\u5C20\u5C22\u5C28\u5C38\u5C39\u5C41\u5C46\u5C4E\u5C53\u5C50\u5C4F\u5B71\u5C6C\u5C6E\u4E62\u5C76\u5C79\u5C8C\u5C91\u5C94\u599B\u5CAB\u5CBB\u5CB6\u5CBC\u5CB7\u5CC5\u5CBE\u5CC7\u5CD9\u5CE9\u5CFD\u5CFA\u5CED\u5D8C\u5CEA\u5D0B\u5D15\u5D17\u5D5C\u5D1F\u5D1B\u5D11\u5D14\u5D22\u5D1A\u5D19\u5D18\u5D4C\u5D52\u5D4E\u5D4B\u5D6C\u5D73\u5D76\u5D87\u5D84\u5D82\u5DA2\u5D9D\u5DAC\u5DAE\u5DBD\u5D90\u5DB7\u5DBC\u5DC9\u5DCD\u5DD3\u5DD2\u5DD6\u5DDB\u5DEB\u5DF2\u5DF5\u5E0B\u5E1A\u5E19\u5E11\u5E1B\u5E36\u5E37\u5E44\u5E43\u5E40\u5E4E\u5E57\u5E54\u5E5F\u5E62\u5E64\u5E47\u5E75\u5E76\u5E7A\u9EBC\u5E7F\u5EA0\u5EC1\u5EC2\u5EC8\u5ED0\u5ECF"],
      ["9c40", "\u5ED6\u5EE3\u5EDD\u5EDA\u5EDB\u5EE2\u5EE1\u5EE8\u5EE9\u5EEC\u5EF1\u5EF3\u5EF0\u5EF4\u5EF8\u5EFE\u5F03\u5F09\u5F5D\u5F5C\u5F0B\u5F11\u5F16\u5F29\u5F2D\u5F38\u5F41\u5F48\u5F4C\u5F4E\u5F2F\u5F51\u5F56\u5F57\u5F59\u5F61\u5F6D\u5F73\u5F77\u5F83\u5F82\u5F7F\u5F8A\u5F88\u5F91\u5F87\u5F9E\u5F99\u5F98\u5FA0\u5FA8\u5FAD\u5FBC\u5FD6\u5FFB\u5FE4\u5FF8\u5FF1\u5FDD\u60B3\u5FFF\u6021\u6060"],
      ["9c80", "\u6019\u6010\u6029\u600E\u6031\u601B\u6015\u602B\u6026\u600F\u603A\u605A\u6041\u606A\u6077\u605F\u604A\u6046\u604D\u6063\u6043\u6064\u6042\u606C\u606B\u6059\u6081\u608D\u60E7\u6083\u609A\u6084\u609B\u6096\u6097\u6092\u60A7\u608B\u60E1\u60B8\u60E0\u60D3\u60B4\u5FF0\u60BD\u60C6\u60B5\u60D8\u614D\u6115\u6106\u60F6\u60F7\u6100\u60F4\u60FA\u6103\u6121\u60FB\u60F1\u610D\u610E\u6147\u613E\u6128\u6127\u614A\u613F\u613C\u612C\u6134\u613D\u6142\u6144\u6173\u6177\u6158\u6159\u615A\u616B\u6174\u616F\u6165\u6171\u615F\u615D\u6153\u6175\u6199\u6196\u6187\u61AC\u6194\u619A\u618A\u6191\u61AB\u61AE\u61CC\u61CA\u61C9\u61F7\u61C8\u61C3\u61C6\u61BA\u61CB\u7F79\u61CD\u61E6\u61E3\u61F6\u61FA\u61F4\u61FF\u61FD\u61FC\u61FE\u6200\u6208\u6209\u620D\u620C\u6214\u621B"],
      ["9d40", "\u621E\u6221\u622A\u622E\u6230\u6232\u6233\u6241\u624E\u625E\u6263\u625B\u6260\u6268\u627C\u6282\u6289\u627E\u6292\u6293\u6296\u62D4\u6283\u6294\u62D7\u62D1\u62BB\u62CF\u62FF\u62C6\u64D4\u62C8\u62DC\u62CC\u62CA\u62C2\u62C7\u629B\u62C9\u630C\u62EE\u62F1\u6327\u6302\u6308\u62EF\u62F5\u6350\u633E\u634D\u641C\u634F\u6396\u638E\u6380\u63AB\u6376\u63A3\u638F\u6389\u639F\u63B5\u636B"],
      ["9d80", "\u6369\u63BE\u63E9\u63C0\u63C6\u63E3\u63C9\u63D2\u63F6\u63C4\u6416\u6434\u6406\u6413\u6426\u6436\u651D\u6417\u6428\u640F\u6467\u646F\u6476\u644E\u652A\u6495\u6493\u64A5\u64A9\u6488\u64BC\u64DA\u64D2\u64C5\u64C7\u64BB\u64D8\u64C2\u64F1\u64E7\u8209\u64E0\u64E1\u62AC\u64E3\u64EF\u652C\u64F6\u64F4\u64F2\u64FA\u6500\u64FD\u6518\u651C\u6505\u6524\u6523\u652B\u6534\u6535\u6537\u6536\u6538\u754B\u6548\u6556\u6555\u654D\u6558\u655E\u655D\u6572\u6578\u6582\u6583\u8B8A\u659B\u659F\u65AB\u65B7\u65C3\u65C6\u65C1\u65C4\u65CC\u65D2\u65DB\u65D9\u65E0\u65E1\u65F1\u6772\u660A\u6603\u65FB\u6773\u6635\u6636\u6634\u661C\u664F\u6644\u6649\u6641\u665E\u665D\u6664\u6667\u6668\u665F\u6662\u6670\u6683\u6688\u668E\u6689\u6684\u6698\u669D\u66C1\u66B9\u66C9\u66BE\u66BC"],
      ["9e40", "\u66C4\u66B8\u66D6\u66DA\u66E0\u663F\u66E6\u66E9\u66F0\u66F5\u66F7\u670F\u6716\u671E\u6726\u6727\u9738\u672E\u673F\u6736\u6741\u6738\u6737\u6746\u675E\u6760\u6759\u6763\u6764\u6789\u6770\u67A9\u677C\u676A\u678C\u678B\u67A6\u67A1\u6785\u67B7\u67EF\u67B4\u67EC\u67B3\u67E9\u67B8\u67E4\u67DE\u67DD\u67E2\u67EE\u67B9\u67CE\u67C6\u67E7\u6A9C\u681E\u6846\u6829\u6840\u684D\u6832\u684E"],
      ["9e80", "\u68B3\u682B\u6859\u6863\u6877\u687F\u689F\u688F\u68AD\u6894\u689D\u689B\u6883\u6AAE\u68B9\u6874\u68B5\u68A0\u68BA\u690F\u688D\u687E\u6901\u68CA\u6908\u68D8\u6922\u6926\u68E1\u690C\u68CD\u68D4\u68E7\u68D5\u6936\u6912\u6904\u68D7\u68E3\u6925\u68F9\u68E0\u68EF\u6928\u692A\u691A\u6923\u6921\u68C6\u6979\u6977\u695C\u6978\u696B\u6954\u697E\u696E\u6939\u6974\u693D\u6959\u6930\u6961\u695E\u695D\u6981\u696A\u69B2\u69AE\u69D0\u69BF\u69C1\u69D3\u69BE\u69CE\u5BE8\u69CA\u69DD\u69BB\u69C3\u69A7\u6A2E\u6991\u69A0\u699C\u6995\u69B4\u69DE\u69E8\u6A02\u6A1B\u69FF\u6B0A\u69F9\u69F2\u69E7\u6A05\u69B1\u6A1E\u69ED\u6A14\u69EB\u6A0A\u6A12\u6AC1\u6A23\u6A13\u6A44\u6A0C\u6A72\u6A36\u6A78\u6A47\u6A62\u6A59\u6A66\u6A48\u6A38\u6A22\u6A90\u6A8D\u6AA0\u6A84\u6AA2\u6AA3"],
      ["9f40", "\u6A97\u8617\u6ABB\u6AC3\u6AC2\u6AB8\u6AB3\u6AAC\u6ADE\u6AD1\u6ADF\u6AAA\u6ADA\u6AEA\u6AFB\u6B05\u8616\u6AFA\u6B12\u6B16\u9B31\u6B1F\u6B38\u6B37\u76DC\u6B39\u98EE\u6B47\u6B43\u6B49\u6B50\u6B59\u6B54\u6B5B\u6B5F\u6B61\u6B78\u6B79\u6B7F\u6B80\u6B84\u6B83\u6B8D\u6B98\u6B95\u6B9E\u6BA4\u6BAA\u6BAB\u6BAF\u6BB2\u6BB1\u6BB3\u6BB7\u6BBC\u6BC6\u6BCB\u6BD3\u6BDF\u6BEC\u6BEB\u6BF3\u6BEF"],
      ["9f80", "\u9EBE\u6C08\u6C13\u6C14\u6C1B\u6C24\u6C23\u6C5E\u6C55\u6C62\u6C6A\u6C82\u6C8D\u6C9A\u6C81\u6C9B\u6C7E\u6C68\u6C73\u6C92\u6C90\u6CC4\u6CF1\u6CD3\u6CBD\u6CD7\u6CC5\u6CDD\u6CAE\u6CB1\u6CBE\u6CBA\u6CDB\u6CEF\u6CD9\u6CEA\u6D1F\u884D\u6D36\u6D2B\u6D3D\u6D38\u6D19\u6D35\u6D33\u6D12\u6D0C\u6D63\u6D93\u6D64\u6D5A\u6D79\u6D59\u6D8E\u6D95\u6FE4\u6D85\u6DF9\u6E15\u6E0A\u6DB5\u6DC7\u6DE6\u6DB8\u6DC6\u6DEC\u6DDE\u6DCC\u6DE8\u6DD2\u6DC5\u6DFA\u6DD9\u6DE4\u6DD5\u6DEA\u6DEE\u6E2D\u6E6E\u6E2E\u6E19\u6E72\u6E5F\u6E3E\u6E23\u6E6B\u6E2B\u6E76\u6E4D\u6E1F\u6E43\u6E3A\u6E4E\u6E24\u6EFF\u6E1D\u6E38\u6E82\u6EAA\u6E98\u6EC9\u6EB7\u6ED3\u6EBD\u6EAF\u6EC4\u6EB2\u6ED4\u6ED5\u6E8F\u6EA5\u6EC2\u6E9F\u6F41\u6F11\u704C\u6EEC\u6EF8\u6EFE\u6F3F\u6EF2\u6F31\u6EEF\u6F32\u6ECC"],
      ["e040", "\u6F3E\u6F13\u6EF7\u6F86\u6F7A\u6F78\u6F81\u6F80\u6F6F\u6F5B\u6FF3\u6F6D\u6F82\u6F7C\u6F58\u6F8E\u6F91\u6FC2\u6F66\u6FB3\u6FA3\u6FA1\u6FA4\u6FB9\u6FC6\u6FAA\u6FDF\u6FD5\u6FEC\u6FD4\u6FD8\u6FF1\u6FEE\u6FDB\u7009\u700B\u6FFA\u7011\u7001\u700F\u6FFE\u701B\u701A\u6F74\u701D\u7018\u701F\u7030\u703E\u7032\u7051\u7063\u7099\u7092\u70AF\u70F1\u70AC\u70B8\u70B3\u70AE\u70DF\u70CB\u70DD"],
      ["e080", "\u70D9\u7109\u70FD\u711C\u7119\u7165\u7155\u7188\u7166\u7162\u714C\u7156\u716C\u718F\u71FB\u7184\u7195\u71A8\u71AC\u71D7\u71B9\u71BE\u71D2\u71C9\u71D4\u71CE\u71E0\u71EC\u71E7\u71F5\u71FC\u71F9\u71FF\u720D\u7210\u721B\u7228\u722D\u722C\u7230\u7232\u723B\u723C\u723F\u7240\u7246\u724B\u7258\u7274\u727E\u7282\u7281\u7287\u7292\u7296\u72A2\u72A7\u72B9\u72B2\u72C3\u72C6\u72C4\u72CE\u72D2\u72E2\u72E0\u72E1\u72F9\u72F7\u500F\u7317\u730A\u731C\u7316\u731D\u7334\u732F\u7329\u7325\u733E\u734E\u734F\u9ED8\u7357\u736A\u7368\u7370\u7378\u7375\u737B\u737A\u73C8\u73B3\u73CE\u73BB\u73C0\u73E5\u73EE\u73DE\u74A2\u7405\u746F\u7425\u73F8\u7432\u743A\u7455\u743F\u745F\u7459\u7441\u745C\u7469\u7470\u7463\u746A\u7476\u747E\u748B\u749E\u74A7\u74CA\u74CF\u74D4\u73F1"],
      ["e140", "\u74E0\u74E3\u74E7\u74E9\u74EE\u74F2\u74F0\u74F1\u74F8\u74F7\u7504\u7503\u7505\u750C\u750E\u750D\u7515\u7513\u751E\u7526\u752C\u753C\u7544\u754D\u754A\u7549\u755B\u7546\u755A\u7569\u7564\u7567\u756B\u756D\u7578\u7576\u7586\u7587\u7574\u758A\u7589\u7582\u7594\u759A\u759D\u75A5\u75A3\u75C2\u75B3\u75C3\u75B5\u75BD\u75B8\u75BC\u75B1\u75CD\u75CA\u75D2\u75D9\u75E3\u75DE\u75FE\u75FF"],
      ["e180", "\u75FC\u7601\u75F0\u75FA\u75F2\u75F3\u760B\u760D\u7609\u761F\u7627\u7620\u7621\u7622\u7624\u7634\u7630\u763B\u7647\u7648\u7646\u765C\u7658\u7661\u7662\u7668\u7669\u766A\u7667\u766C\u7670\u7672\u7676\u7678\u767C\u7680\u7683\u7688\u768B\u768E\u7696\u7693\u7699\u769A\u76B0\u76B4\u76B8\u76B9\u76BA\u76C2\u76CD\u76D6\u76D2\u76DE\u76E1\u76E5\u76E7\u76EA\u862F\u76FB\u7708\u7707\u7704\u7729\u7724\u771E\u7725\u7726\u771B\u7737\u7738\u7747\u775A\u7768\u776B\u775B\u7765\u777F\u777E\u7779\u778E\u778B\u7791\u77A0\u779E\u77B0\u77B6\u77B9\u77BF\u77BC\u77BD\u77BB\u77C7\u77CD\u77D7\u77DA\u77DC\u77E3\u77EE\u77FC\u780C\u7812\u7926\u7820\u792A\u7845\u788E\u7874\u7886\u787C\u789A\u788C\u78A3\u78B5\u78AA\u78AF\u78D1\u78C6\u78CB\u78D4\u78BE\u78BC\u78C5\u78CA\u78EC"],
      ["e240", "\u78E7\u78DA\u78FD\u78F4\u7907\u7912\u7911\u7919\u792C\u792B\u7940\u7960\u7957\u795F\u795A\u7955\u7953\u797A\u797F\u798A\u799D\u79A7\u9F4B\u79AA\u79AE\u79B3\u79B9\u79BA\u79C9\u79D5\u79E7\u79EC\u79E1\u79E3\u7A08\u7A0D\u7A18\u7A19\u7A20\u7A1F\u7980\u7A31\u7A3B\u7A3E\u7A37\u7A43\u7A57\u7A49\u7A61\u7A62\u7A69\u9F9D\u7A70\u7A79\u7A7D\u7A88\u7A97\u7A95\u7A98\u7A96\u7AA9\u7AC8\u7AB0"],
      ["e280", "\u7AB6\u7AC5\u7AC4\u7ABF\u9083\u7AC7\u7ACA\u7ACD\u7ACF\u7AD5\u7AD3\u7AD9\u7ADA\u7ADD\u7AE1\u7AE2\u7AE6\u7AED\u7AF0\u7B02\u7B0F\u7B0A\u7B06\u7B33\u7B18\u7B19\u7B1E\u7B35\u7B28\u7B36\u7B50\u7B7A\u7B04\u7B4D\u7B0B\u7B4C\u7B45\u7B75\u7B65\u7B74\u7B67\u7B70\u7B71\u7B6C\u7B6E\u7B9D\u7B98\u7B9F\u7B8D\u7B9C\u7B9A\u7B8B\u7B92\u7B8F\u7B5D\u7B99\u7BCB\u7BC1\u7BCC\u7BCF\u7BB4\u7BC6\u7BDD\u7BE9\u7C11\u7C14\u7BE6\u7BE5\u7C60\u7C00\u7C07\u7C13\u7BF3\u7BF7\u7C17\u7C0D\u7BF6\u7C23\u7C27\u7C2A\u7C1F\u7C37\u7C2B\u7C3D\u7C4C\u7C43\u7C54\u7C4F\u7C40\u7C50\u7C58\u7C5F\u7C64\u7C56\u7C65\u7C6C\u7C75\u7C83\u7C90\u7CA4\u7CAD\u7CA2\u7CAB\u7CA1\u7CA8\u7CB3\u7CB2\u7CB1\u7CAE\u7CB9\u7CBD\u7CC0\u7CC5\u7CC2\u7CD8\u7CD2\u7CDC\u7CE2\u9B3B\u7CEF\u7CF2\u7CF4\u7CF6\u7CFA\u7D06"],
      ["e340", "\u7D02\u7D1C\u7D15\u7D0A\u7D45\u7D4B\u7D2E\u7D32\u7D3F\u7D35\u7D46\u7D73\u7D56\u7D4E\u7D72\u7D68\u7D6E\u7D4F\u7D63\u7D93\u7D89\u7D5B\u7D8F\u7D7D\u7D9B\u7DBA\u7DAE\u7DA3\u7DB5\u7DC7\u7DBD\u7DAB\u7E3D\u7DA2\u7DAF\u7DDC\u7DB8\u7D9F\u7DB0\u7DD8\u7DDD\u7DE4\u7DDE\u7DFB\u7DF2\u7DE1\u7E05\u7E0A\u7E23\u7E21\u7E12\u7E31\u7E1F\u7E09\u7E0B\u7E22\u7E46\u7E66\u7E3B\u7E35\u7E39\u7E43\u7E37"],
      ["e380", "\u7E32\u7E3A\u7E67\u7E5D\u7E56\u7E5E\u7E59\u7E5A\u7E79\u7E6A\u7E69\u7E7C\u7E7B\u7E83\u7DD5\u7E7D\u8FAE\u7E7F\u7E88\u7E89\u7E8C\u7E92\u7E90\u7E93\u7E94\u7E96\u7E8E\u7E9B\u7E9C\u7F38\u7F3A\u7F45\u7F4C\u7F4D\u7F4E\u7F50\u7F51\u7F55\u7F54\u7F58\u7F5F\u7F60\u7F68\u7F69\u7F67\u7F78\u7F82\u7F86\u7F83\u7F88\u7F87\u7F8C\u7F94\u7F9E\u7F9D\u7F9A\u7FA3\u7FAF\u7FB2\u7FB9\u7FAE\u7FB6\u7FB8\u8B71\u7FC5\u7FC6\u7FCA\u7FD5\u7FD4\u7FE1\u7FE6\u7FE9\u7FF3\u7FF9\u98DC\u8006\u8004\u800B\u8012\u8018\u8019\u801C\u8021\u8028\u803F\u803B\u804A\u8046\u8052\u8058\u805A\u805F\u8062\u8068\u8073\u8072\u8070\u8076\u8079\u807D\u807F\u8084\u8086\u8085\u809B\u8093\u809A\u80AD\u5190\u80AC\u80DB\u80E5\u80D9\u80DD\u80C4\u80DA\u80D6\u8109\u80EF\u80F1\u811B\u8129\u8123\u812F\u814B"],
      ["e440", "\u968B\u8146\u813E\u8153\u8151\u80FC\u8171\u816E\u8165\u8166\u8174\u8183\u8188\u818A\u8180\u8182\u81A0\u8195\u81A4\u81A3\u815F\u8193\u81A9\u81B0\u81B5\u81BE\u81B8\u81BD\u81C0\u81C2\u81BA\u81C9\u81CD\u81D1\u81D9\u81D8\u81C8\u81DA\u81DF\u81E0\u81E7\u81FA\u81FB\u81FE\u8201\u8202\u8205\u8207\u820A\u820D\u8210\u8216\u8229\u822B\u8238\u8233\u8240\u8259\u8258\u825D\u825A\u825F\u8264"],
      ["e480", "\u8262\u8268\u826A\u826B\u822E\u8271\u8277\u8278\u827E\u828D\u8292\u82AB\u829F\u82BB\u82AC\u82E1\u82E3\u82DF\u82D2\u82F4\u82F3\u82FA\u8393\u8303\u82FB\u82F9\u82DE\u8306\u82DC\u8309\u82D9\u8335\u8334\u8316\u8332\u8331\u8340\u8339\u8350\u8345\u832F\u832B\u8317\u8318\u8385\u839A\u83AA\u839F\u83A2\u8396\u8323\u838E\u8387\u838A\u837C\u83B5\u8373\u8375\u83A0\u8389\u83A8\u83F4\u8413\u83EB\u83CE\u83FD\u8403\u83D8\u840B\u83C1\u83F7\u8407\u83E0\u83F2\u840D\u8422\u8420\u83BD\u8438\u8506\u83FB\u846D\u842A\u843C\u855A\u8484\u8477\u846B\u84AD\u846E\u8482\u8469\u8446\u842C\u846F\u8479\u8435\u84CA\u8462\u84B9\u84BF\u849F\u84D9\u84CD\u84BB\u84DA\u84D0\u84C1\u84C6\u84D6\u84A1\u8521\u84FF\u84F4\u8517\u8518\u852C\u851F\u8515\u8514\u84FC\u8540\u8563\u8558\u8548"],
      ["e540", "\u8541\u8602\u854B\u8555\u8580\u85A4\u8588\u8591\u858A\u85A8\u856D\u8594\u859B\u85EA\u8587\u859C\u8577\u857E\u8590\u85C9\u85BA\u85CF\u85B9\u85D0\u85D5\u85DD\u85E5\u85DC\u85F9\u860A\u8613\u860B\u85FE\u85FA\u8606\u8622\u861A\u8630\u863F\u864D\u4E55\u8654\u865F\u8667\u8671\u8693\u86A3\u86A9\u86AA\u868B\u868C\u86B6\u86AF\u86C4\u86C6\u86B0\u86C9\u8823\u86AB\u86D4\u86DE\u86E9\u86EC"],
      ["e580", "\u86DF\u86DB\u86EF\u8712\u8706\u8708\u8700\u8703\u86FB\u8711\u8709\u870D\u86F9\u870A\u8734\u873F\u8737\u873B\u8725\u8729\u871A\u8760\u875F\u8778\u874C\u874E\u8774\u8757\u8768\u876E\u8759\u8753\u8763\u876A\u8805\u87A2\u879F\u8782\u87AF\u87CB\u87BD\u87C0\u87D0\u96D6\u87AB\u87C4\u87B3\u87C7\u87C6\u87BB\u87EF\u87F2\u87E0\u880F\u880D\u87FE\u87F6\u87F7\u880E\u87D2\u8811\u8816\u8815\u8822\u8821\u8831\u8836\u8839\u8827\u883B\u8844\u8842\u8852\u8859\u885E\u8862\u886B\u8881\u887E\u889E\u8875\u887D\u88B5\u8872\u8882\u8897\u8892\u88AE\u8899\u88A2\u888D\u88A4\u88B0\u88BF\u88B1\u88C3\u88C4\u88D4\u88D8\u88D9\u88DD\u88F9\u8902\u88FC\u88F4\u88E8\u88F2\u8904\u890C\u890A\u8913\u8943\u891E\u8925\u892A\u892B\u8941\u8944\u893B\u8936\u8938\u894C\u891D\u8960\u895E"],
      ["e640", "\u8966\u8964\u896D\u896A\u896F\u8974\u8977\u897E\u8983\u8988\u898A\u8993\u8998\u89A1\u89A9\u89A6\u89AC\u89AF\u89B2\u89BA\u89BD\u89BF\u89C0\u89DA\u89DC\u89DD\u89E7\u89F4\u89F8\u8A03\u8A16\u8A10\u8A0C\u8A1B\u8A1D\u8A25\u8A36\u8A41\u8A5B\u8A52\u8A46\u8A48\u8A7C\u8A6D\u8A6C\u8A62\u8A85\u8A82\u8A84\u8AA8\u8AA1\u8A91\u8AA5\u8AA6\u8A9A\u8AA3\u8AC4\u8ACD\u8AC2\u8ADA\u8AEB\u8AF3\u8AE7"],
      ["e680", "\u8AE4\u8AF1\u8B14\u8AE0\u8AE2\u8AF7\u8ADE\u8ADB\u8B0C\u8B07\u8B1A\u8AE1\u8B16\u8B10\u8B17\u8B20\u8B33\u97AB\u8B26\u8B2B\u8B3E\u8B28\u8B41\u8B4C\u8B4F\u8B4E\u8B49\u8B56\u8B5B\u8B5A\u8B6B\u8B5F\u8B6C\u8B6F\u8B74\u8B7D\u8B80\u8B8C\u8B8E\u8B92\u8B93\u8B96\u8B99\u8B9A\u8C3A\u8C41\u8C3F\u8C48\u8C4C\u8C4E\u8C50\u8C55\u8C62\u8C6C\u8C78\u8C7A\u8C82\u8C89\u8C85\u8C8A\u8C8D\u8C8E\u8C94\u8C7C\u8C98\u621D\u8CAD\u8CAA\u8CBD\u8CB2\u8CB3\u8CAE\u8CB6\u8CC8\u8CC1\u8CE4\u8CE3\u8CDA\u8CFD\u8CFA\u8CFB\u8D04\u8D05\u8D0A\u8D07\u8D0F\u8D0D\u8D10\u9F4E\u8D13\u8CCD\u8D14\u8D16\u8D67\u8D6D\u8D71\u8D73\u8D81\u8D99\u8DC2\u8DBE\u8DBA\u8DCF\u8DDA\u8DD6\u8DCC\u8DDB\u8DCB\u8DEA\u8DEB\u8DDF\u8DE3\u8DFC\u8E08\u8E09\u8DFF\u8E1D\u8E1E\u8E10\u8E1F\u8E42\u8E35\u8E30\u8E34\u8E4A"],
      ["e740", "\u8E47\u8E49\u8E4C\u8E50\u8E48\u8E59\u8E64\u8E60\u8E2A\u8E63\u8E55\u8E76\u8E72\u8E7C\u8E81\u8E87\u8E85\u8E84\u8E8B\u8E8A\u8E93\u8E91\u8E94\u8E99\u8EAA\u8EA1\u8EAC\u8EB0\u8EC6\u8EB1\u8EBE\u8EC5\u8EC8\u8ECB\u8EDB\u8EE3\u8EFC\u8EFB\u8EEB\u8EFE\u8F0A\u8F05\u8F15\u8F12\u8F19\u8F13\u8F1C\u8F1F\u8F1B\u8F0C\u8F26\u8F33\u8F3B\u8F39\u8F45\u8F42\u8F3E\u8F4C\u8F49\u8F46\u8F4E\u8F57\u8F5C"],
      ["e780", "\u8F62\u8F63\u8F64\u8F9C\u8F9F\u8FA3\u8FAD\u8FAF\u8FB7\u8FDA\u8FE5\u8FE2\u8FEA\u8FEF\u9087\u8FF4\u9005\u8FF9\u8FFA\u9011\u9015\u9021\u900D\u901E\u9016\u900B\u9027\u9036\u9035\u9039\u8FF8\u904F\u9050\u9051\u9052\u900E\u9049\u903E\u9056\u9058\u905E\u9068\u906F\u9076\u96A8\u9072\u9082\u907D\u9081\u9080\u908A\u9089\u908F\u90A8\u90AF\u90B1\u90B5\u90E2\u90E4\u6248\u90DB\u9102\u9112\u9119\u9132\u9130\u914A\u9156\u9158\u9163\u9165\u9169\u9173\u9172\u918B\u9189\u9182\u91A2\u91AB\u91AF\u91AA\u91B5\u91B4\u91BA\u91C0\u91C1\u91C9\u91CB\u91D0\u91D6\u91DF\u91E1\u91DB\u91FC\u91F5\u91F6\u921E\u91FF\u9214\u922C\u9215\u9211\u925E\u9257\u9245\u9249\u9264\u9248\u9295\u923F\u924B\u9250\u929C\u9296\u9293\u929B\u925A\u92CF\u92B9\u92B7\u92E9\u930F\u92FA\u9344\u932E"],
      ["e840", "\u9319\u9322\u931A\u9323\u933A\u9335\u933B\u935C\u9360\u937C\u936E\u9356\u93B0\u93AC\u93AD\u9394\u93B9\u93D6\u93D7\u93E8\u93E5\u93D8\u93C3\u93DD\u93D0\u93C8\u93E4\u941A\u9414\u9413\u9403\u9407\u9410\u9436\u942B\u9435\u9421\u943A\u9441\u9452\u9444\u945B\u9460\u9462\u945E\u946A\u9229\u9470\u9475\u9477\u947D\u945A\u947C\u947E\u9481\u947F\u9582\u9587\u958A\u9594\u9596\u9598\u9599"],
      ["e880", "\u95A0\u95A8\u95A7\u95AD\u95BC\u95BB\u95B9\u95BE\u95CA\u6FF6\u95C3\u95CD\u95CC\u95D5\u95D4\u95D6\u95DC\u95E1\u95E5\u95E2\u9621\u9628\u962E\u962F\u9642\u964C\u964F\u964B\u9677\u965C\u965E\u965D\u965F\u9666\u9672\u966C\u968D\u9698\u9695\u9697\u96AA\u96A7\u96B1\u96B2\u96B0\u96B4\u96B6\u96B8\u96B9\u96CE\u96CB\u96C9\u96CD\u894D\u96DC\u970D\u96D5\u96F9\u9704\u9706\u9708\u9713\u970E\u9711\u970F\u9716\u9719\u9724\u972A\u9730\u9739\u973D\u973E\u9744\u9746\u9748\u9742\u9749\u975C\u9760\u9764\u9766\u9768\u52D2\u976B\u9771\u9779\u9785\u977C\u9781\u977A\u9786\u978B\u978F\u9790\u979C\u97A8\u97A6\u97A3\u97B3\u97B4\u97C3\u97C6\u97C8\u97CB\u97DC\u97ED\u9F4F\u97F2\u7ADF\u97F6\u97F5\u980F\u980C\u9838\u9824\u9821\u9837\u983D\u9846\u984F\u984B\u986B\u986F\u9870"],
      ["e940", "\u9871\u9874\u9873\u98AA\u98AF\u98B1\u98B6\u98C4\u98C3\u98C6\u98E9\u98EB\u9903\u9909\u9912\u9914\u9918\u9921\u991D\u991E\u9924\u9920\u992C\u992E\u993D\u993E\u9942\u9949\u9945\u9950\u994B\u9951\u9952\u994C\u9955\u9997\u9998\u99A5\u99AD\u99AE\u99BC\u99DF\u99DB\u99DD\u99D8\u99D1\u99ED\u99EE\u99F1\u99F2\u99FB\u99F8\u9A01\u9A0F\u9A05\u99E2\u9A19\u9A2B\u9A37\u9A45\u9A42\u9A40\u9A43"],
      ["e980", "\u9A3E\u9A55\u9A4D\u9A5B\u9A57\u9A5F\u9A62\u9A65\u9A64\u9A69\u9A6B\u9A6A\u9AAD\u9AB0\u9ABC\u9AC0\u9ACF\u9AD1\u9AD3\u9AD4\u9ADE\u9ADF\u9AE2\u9AE3\u9AE6\u9AEF\u9AEB\u9AEE\u9AF4\u9AF1\u9AF7\u9AFB\u9B06\u9B18\u9B1A\u9B1F\u9B22\u9B23\u9B25\u9B27\u9B28\u9B29\u9B2A\u9B2E\u9B2F\u9B32\u9B44\u9B43\u9B4F\u9B4D\u9B4E\u9B51\u9B58\u9B74\u9B93\u9B83\u9B91\u9B96\u9B97\u9B9F\u9BA0\u9BA8\u9BB4\u9BC0\u9BCA\u9BB9\u9BC6\u9BCF\u9BD1\u9BD2\u9BE3\u9BE2\u9BE4\u9BD4\u9BE1\u9C3A\u9BF2\u9BF1\u9BF0\u9C15\u9C14\u9C09\u9C13\u9C0C\u9C06\u9C08\u9C12\u9C0A\u9C04\u9C2E\u9C1B\u9C25\u9C24\u9C21\u9C30\u9C47\u9C32\u9C46\u9C3E\u9C5A\u9C60\u9C67\u9C76\u9C78\u9CE7\u9CEC\u9CF0\u9D09\u9D08\u9CEB\u9D03\u9D06\u9D2A\u9D26\u9DAF\u9D23\u9D1F\u9D44\u9D15\u9D12\u9D41\u9D3F\u9D3E\u9D46\u9D48"],
      ["ea40", "\u9D5D\u9D5E\u9D64\u9D51\u9D50\u9D59\u9D72\u9D89\u9D87\u9DAB\u9D6F\u9D7A\u9D9A\u9DA4\u9DA9\u9DB2\u9DC4\u9DC1\u9DBB\u9DB8\u9DBA\u9DC6\u9DCF\u9DC2\u9DD9\u9DD3\u9DF8\u9DE6\u9DED\u9DEF\u9DFD\u9E1A\u9E1B\u9E1E\u9E75\u9E79\u9E7D\u9E81\u9E88\u9E8B\u9E8C\u9E92\u9E95\u9E91\u9E9D\u9EA5\u9EA9\u9EB8\u9EAA\u9EAD\u9761\u9ECC\u9ECE\u9ECF\u9ED0\u9ED4\u9EDC\u9EDE\u9EDD\u9EE0\u9EE5\u9EE8\u9EEF"],
      ["ea80", "\u9EF4\u9EF6\u9EF7\u9EF9\u9EFB\u9EFC\u9EFD\u9F07\u9F08\u76B7\u9F15\u9F21\u9F2C\u9F3E\u9F4A\u9F52\u9F54\u9F63\u9F5F\u9F60\u9F61\u9F66\u9F67\u9F6C\u9F6A\u9F77\u9F72\u9F76\u9F95\u9F9C\u9FA0\u582F\u69C7\u9059\u7464\u51DC\u7199"],
      ["ed40", "\u7E8A\u891C\u9348\u9288\u84DC\u4FC9\u70BB\u6631\u68C8\u92F9\u66FB\u5F45\u4E28\u4EE1\u4EFC\u4F00\u4F03\u4F39\u4F56\u4F92\u4F8A\u4F9A\u4F94\u4FCD\u5040\u5022\u4FFF\u501E\u5046\u5070\u5042\u5094\u50F4\u50D8\u514A\u5164\u519D\u51BE\u51EC\u5215\u529C\u52A6\u52C0\u52DB\u5300\u5307\u5324\u5372\u5393\u53B2\u53DD\uFA0E\u549C\u548A\u54A9\u54FF\u5586\u5759\u5765\u57AC\u57C8\u57C7\uFA0F"],
      ["ed80", "\uFA10\u589E\u58B2\u590B\u5953\u595B\u595D\u5963\u59A4\u59BA\u5B56\u5BC0\u752F\u5BD8\u5BEC\u5C1E\u5CA6\u5CBA\u5CF5\u5D27\u5D53\uFA11\u5D42\u5D6D\u5DB8\u5DB9\u5DD0\u5F21\u5F34\u5F67\u5FB7\u5FDE\u605D\u6085\u608A\u60DE\u60D5\u6120\u60F2\u6111\u6137\u6130\u6198\u6213\u62A6\u63F5\u6460\u649D\u64CE\u654E\u6600\u6615\u663B\u6609\u662E\u661E\u6624\u6665\u6657\u6659\uFA12\u6673\u6699\u66A0\u66B2\u66BF\u66FA\u670E\uF929\u6766\u67BB\u6852\u67C0\u6801\u6844\u68CF\uFA13\u6968\uFA14\u6998\u69E2\u6A30\u6A6B\u6A46\u6A73\u6A7E\u6AE2\u6AE4\u6BD6\u6C3F\u6C5C\u6C86\u6C6F\u6CDA\u6D04\u6D87\u6D6F\u6D96\u6DAC\u6DCF\u6DF8\u6DF2\u6DFC\u6E39\u6E5C\u6E27\u6E3C\u6EBF\u6F88\u6FB5\u6FF5\u7005\u7007\u7028\u7085\u70AB\u710F\u7104\u715C\u7146\u7147\uFA15\u71C1\u71FE\u72B1"],
      ["ee40", "\u72BE\u7324\uFA16\u7377\u73BD\u73C9\u73D6\u73E3\u73D2\u7407\u73F5\u7426\u742A\u7429\u742E\u7462\u7489\u749F\u7501\u756F\u7682\u769C\u769E\u769B\u76A6\uFA17\u7746\u52AF\u7821\u784E\u7864\u787A\u7930\uFA18\uFA19\uFA1A\u7994\uFA1B\u799B\u7AD1\u7AE7\uFA1C\u7AEB\u7B9E\uFA1D\u7D48\u7D5C\u7DB7\u7DA0\u7DD6\u7E52\u7F47\u7FA1\uFA1E\u8301\u8362\u837F\u83C7\u83F6\u8448\u84B4\u8553\u8559"],
      ["ee80", "\u856B\uFA1F\u85B0\uFA20\uFA21\u8807\u88F5\u8A12\u8A37\u8A79\u8AA7\u8ABE\u8ADF\uFA22\u8AF6\u8B53\u8B7F\u8CF0\u8CF4\u8D12\u8D76\uFA23\u8ECF\uFA24\uFA25\u9067\u90DE\uFA26\u9115\u9127\u91DA\u91D7\u91DE\u91ED\u91EE\u91E4\u91E5\u9206\u9210\u920A\u923A\u9240\u923C\u924E\u9259\u9251\u9239\u9267\u92A7\u9277\u9278\u92E7\u92D7\u92D9\u92D0\uFA27\u92D5\u92E0\u92D3\u9325\u9321\u92FB\uFA28\u931E\u92FF\u931D\u9302\u9370\u9357\u93A4\u93C6\u93DE\u93F8\u9431\u9445\u9448\u9592\uF9DC\uFA29\u969D\u96AF\u9733\u973B\u9743\u974D\u974F\u9751\u9755\u9857\u9865\uFA2A\uFA2B\u9927\uFA2C\u999E\u9A4E\u9AD9\u9ADC\u9B75\u9B72\u9B8F\u9BB1\u9BBB\u9C00\u9D70\u9D6B\uFA2D\u9E19\u9ED1"],
      ["eeef", "\u2170", 9, "\uFFE2\uFFE4\uFF07\uFF02"],
      ["f040", "\uE000", 62],
      ["f080", "\uE03F", 124],
      ["f140", "\uE0BC", 62],
      ["f180", "\uE0FB", 124],
      ["f240", "\uE178", 62],
      ["f280", "\uE1B7", 124],
      ["f340", "\uE234", 62],
      ["f380", "\uE273", 124],
      ["f440", "\uE2F0", 62],
      ["f480", "\uE32F", 124],
      ["f540", "\uE3AC", 62],
      ["f580", "\uE3EB", 124],
      ["f640", "\uE468", 62],
      ["f680", "\uE4A7", 124],
      ["f740", "\uE524", 62],
      ["f780", "\uE563", 124],
      ["f840", "\uE5E0", 62],
      ["f880", "\uE61F", 124],
      ["f940", "\uE69C"],
      ["fa40", "\u2170", 9, "\u2160", 9, "\uFFE2\uFFE4\uFF07\uFF02\u3231\u2116\u2121\u2235\u7E8A\u891C\u9348\u9288\u84DC\u4FC9\u70BB\u6631\u68C8\u92F9\u66FB\u5F45\u4E28\u4EE1\u4EFC\u4F00\u4F03\u4F39\u4F56\u4F92\u4F8A\u4F9A\u4F94\u4FCD\u5040\u5022\u4FFF\u501E\u5046\u5070\u5042\u5094\u50F4\u50D8\u514A"],
      ["fa80", "\u5164\u519D\u51BE\u51EC\u5215\u529C\u52A6\u52C0\u52DB\u5300\u5307\u5324\u5372\u5393\u53B2\u53DD\uFA0E\u549C\u548A\u54A9\u54FF\u5586\u5759\u5765\u57AC\u57C8\u57C7\uFA0F\uFA10\u589E\u58B2\u590B\u5953\u595B\u595D\u5963\u59A4\u59BA\u5B56\u5BC0\u752F\u5BD8\u5BEC\u5C1E\u5CA6\u5CBA\u5CF5\u5D27\u5D53\uFA11\u5D42\u5D6D\u5DB8\u5DB9\u5DD0\u5F21\u5F34\u5F67\u5FB7\u5FDE\u605D\u6085\u608A\u60DE\u60D5\u6120\u60F2\u6111\u6137\u6130\u6198\u6213\u62A6\u63F5\u6460\u649D\u64CE\u654E\u6600\u6615\u663B\u6609\u662E\u661E\u6624\u6665\u6657\u6659\uFA12\u6673\u6699\u66A0\u66B2\u66BF\u66FA\u670E\uF929\u6766\u67BB\u6852\u67C0\u6801\u6844\u68CF\uFA13\u6968\uFA14\u6998\u69E2\u6A30\u6A6B\u6A46\u6A73\u6A7E\u6AE2\u6AE4\u6BD6\u6C3F\u6C5C\u6C86\u6C6F\u6CDA\u6D04\u6D87\u6D6F"],
      ["fb40", "\u6D96\u6DAC\u6DCF\u6DF8\u6DF2\u6DFC\u6E39\u6E5C\u6E27\u6E3C\u6EBF\u6F88\u6FB5\u6FF5\u7005\u7007\u7028\u7085\u70AB\u710F\u7104\u715C\u7146\u7147\uFA15\u71C1\u71FE\u72B1\u72BE\u7324\uFA16\u7377\u73BD\u73C9\u73D6\u73E3\u73D2\u7407\u73F5\u7426\u742A\u7429\u742E\u7462\u7489\u749F\u7501\u756F\u7682\u769C\u769E\u769B\u76A6\uFA17\u7746\u52AF\u7821\u784E\u7864\u787A\u7930\uFA18\uFA19"],
      ["fb80", "\uFA1A\u7994\uFA1B\u799B\u7AD1\u7AE7\uFA1C\u7AEB\u7B9E\uFA1D\u7D48\u7D5C\u7DB7\u7DA0\u7DD6\u7E52\u7F47\u7FA1\uFA1E\u8301\u8362\u837F\u83C7\u83F6\u8448\u84B4\u8553\u8559\u856B\uFA1F\u85B0\uFA20\uFA21\u8807\u88F5\u8A12\u8A37\u8A79\u8AA7\u8ABE\u8ADF\uFA22\u8AF6\u8B53\u8B7F\u8CF0\u8CF4\u8D12\u8D76\uFA23\u8ECF\uFA24\uFA25\u9067\u90DE\uFA26\u9115\u9127\u91DA\u91D7\u91DE\u91ED\u91EE\u91E4\u91E5\u9206\u9210\u920A\u923A\u9240\u923C\u924E\u9259\u9251\u9239\u9267\u92A7\u9277\u9278\u92E7\u92D7\u92D9\u92D0\uFA27\u92D5\u92E0\u92D3\u9325\u9321\u92FB\uFA28\u931E\u92FF\u931D\u9302\u9370\u9357\u93A4\u93C6\u93DE\u93F8\u9431\u9445\u9448\u9592\uF9DC\uFA29\u969D\u96AF\u9733\u973B\u9743\u974D\u974F\u9751\u9755\u9857\u9865\uFA2A\uFA2B\u9927\uFA2C\u999E\u9A4E\u9AD9"],
      ["fc40", "\u9ADC\u9B75\u9B72\u9B8F\u9BB1\u9BBB\u9C00\u9D70\u9D6B\uFA2D\u9E19\u9ED1"]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/eucjp.json
var require_eucjp = __commonJS({
  "node_modules/iconv-lite/encodings/tables/eucjp.json"(exports, module2) {
    module2.exports = [
      ["0", "\0", 127],
      ["8ea1", "\uFF61", 62],
      ["a1a1", "\u3000\u3001\u3002\uFF0C\uFF0E\u30FB\uFF1A\uFF1B\uFF1F\uFF01\u309B\u309C\xB4\uFF40\xA8\uFF3E\uFFE3\uFF3F\u30FD\u30FE\u309D\u309E\u3003\u4EDD\u3005\u3006\u3007\u30FC\u2015\u2010\uFF0F\uFF3C\uFF5E\u2225\uFF5C\u2026\u2025\u2018\u2019\u201C\u201D\uFF08\uFF09\u3014\u3015\uFF3B\uFF3D\uFF5B\uFF5D\u3008", 9, "\uFF0B\uFF0D\xB1\xD7\xF7\uFF1D\u2260\uFF1C\uFF1E\u2266\u2267\u221E\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFFE5\uFF04\uFFE0\uFFE1\uFF05\uFF03\uFF06\uFF0A\uFF20\xA7\u2606\u2605\u25CB\u25CF\u25CE\u25C7"],
      ["a2a1", "\u25C6\u25A1\u25A0\u25B3\u25B2\u25BD\u25BC\u203B\u3012\u2192\u2190\u2191\u2193\u3013"],
      ["a2ba", "\u2208\u220B\u2286\u2287\u2282\u2283\u222A\u2229"],
      ["a2ca", "\u2227\u2228\uFFE2\u21D2\u21D4\u2200\u2203"],
      ["a2dc", "\u2220\u22A5\u2312\u2202\u2207\u2261\u2252\u226A\u226B\u221A\u223D\u221D\u2235\u222B\u222C"],
      ["a2f2", "\u212B\u2030\u266F\u266D\u266A\u2020\u2021\xB6"],
      ["a2fe", "\u25EF"],
      ["a3b0", "\uFF10", 9],
      ["a3c1", "\uFF21", 25],
      ["a3e1", "\uFF41", 25],
      ["a4a1", "\u3041", 82],
      ["a5a1", "\u30A1", 85],
      ["a6a1", "\u0391", 16, "\u03A3", 6],
      ["a6c1", "\u03B1", 16, "\u03C3", 6],
      ["a7a1", "\u0410", 5, "\u0401\u0416", 25],
      ["a7d1", "\u0430", 5, "\u0451\u0436", 25],
      ["a8a1", "\u2500\u2502\u250C\u2510\u2518\u2514\u251C\u252C\u2524\u2534\u253C\u2501\u2503\u250F\u2513\u251B\u2517\u2523\u2533\u252B\u253B\u254B\u2520\u252F\u2528\u2537\u253F\u251D\u2530\u2525\u2538\u2542"],
      ["ada1", "\u2460", 19, "\u2160", 9],
      ["adc0", "\u3349\u3314\u3322\u334D\u3318\u3327\u3303\u3336\u3351\u3357\u330D\u3326\u3323\u332B\u334A\u333B\u339C\u339D\u339E\u338E\u338F\u33C4\u33A1"],
      ["addf", "\u337B\u301D\u301F\u2116\u33CD\u2121\u32A4", 4, "\u3231\u3232\u3239\u337E\u337D\u337C\u2252\u2261\u222B\u222E\u2211\u221A\u22A5\u2220\u221F\u22BF\u2235\u2229\u222A"],
      ["b0a1", "\u4E9C\u5516\u5A03\u963F\u54C0\u611B\u6328\u59F6\u9022\u8475\u831C\u7A50\u60AA\u63E1\u6E25\u65ED\u8466\u82A6\u9BF5\u6893\u5727\u65A1\u6271\u5B9B\u59D0\u867B\u98F4\u7D62\u7DBE\u9B8E\u6216\u7C9F\u88B7\u5B89\u5EB5\u6309\u6697\u6848\u95C7\u978D\u674F\u4EE5\u4F0A\u4F4D\u4F9D\u5049\u56F2\u5937\u59D4\u5A01\u5C09\u60DF\u610F\u6170\u6613\u6905\u70BA\u754F\u7570\u79FB\u7DAD\u7DEF\u80C3\u840E\u8863\u8B02\u9055\u907A\u533B\u4E95\u4EA5\u57DF\u80B2\u90C1\u78EF\u4E00\u58F1\u6EA2\u9038\u7A32\u8328\u828B\u9C2F\u5141\u5370\u54BD\u54E1\u56E0\u59FB\u5F15\u98F2\u6DEB\u80E4\u852D"],
      ["b1a1", "\u9662\u9670\u96A0\u97FB\u540B\u53F3\u5B87\u70CF\u7FBD\u8FC2\u96E8\u536F\u9D5C\u7ABA\u4E11\u7893\u81FC\u6E26\u5618\u5504\u6B1D\u851A\u9C3B\u59E5\u53A9\u6D66\u74DC\u958F\u5642\u4E91\u904B\u96F2\u834F\u990C\u53E1\u55B6\u5B30\u5F71\u6620\u66F3\u6804\u6C38\u6CF3\u6D29\u745B\u76C8\u7A4E\u9834\u82F1\u885B\u8A60\u92ED\u6DB2\u75AB\u76CA\u99C5\u60A6\u8B01\u8D8A\u95B2\u698E\u53AD\u5186\u5712\u5830\u5944\u5BB4\u5EF6\u6028\u63A9\u63F4\u6CBF\u6F14\u708E\u7114\u7159\u71D5\u733F\u7E01\u8276\u82D1\u8597\u9060\u925B\u9D1B\u5869\u65BC\u6C5A\u7525\u51F9\u592E\u5965\u5F80\u5FDC"],
      ["b2a1", "\u62BC\u65FA\u6A2A\u6B27\u6BB4\u738B\u7FC1\u8956\u9D2C\u9D0E\u9EC4\u5CA1\u6C96\u837B\u5104\u5C4B\u61B6\u81C6\u6876\u7261\u4E59\u4FFA\u5378\u6069\u6E29\u7A4F\u97F3\u4E0B\u5316\u4EEE\u4F55\u4F3D\u4FA1\u4F73\u52A0\u53EF\u5609\u590F\u5AC1\u5BB6\u5BE1\u79D1\u6687\u679C\u67B6\u6B4C\u6CB3\u706B\u73C2\u798D\u79BE\u7A3C\u7B87\u82B1\u82DB\u8304\u8377\u83EF\u83D3\u8766\u8AB2\u5629\u8CA8\u8FE6\u904E\u971E\u868A\u4FC4\u5CE8\u6211\u7259\u753B\u81E5\u82BD\u86FE\u8CC0\u96C5\u9913\u99D5\u4ECB\u4F1A\u89E3\u56DE\u584A\u58CA\u5EFB\u5FEB\u602A\u6094\u6062\u61D0\u6212\u62D0\u6539"],
      ["b3a1", "\u9B41\u6666\u68B0\u6D77\u7070\u754C\u7686\u7D75\u82A5\u87F9\u958B\u968E\u8C9D\u51F1\u52BE\u5916\u54B3\u5BB3\u5D16\u6168\u6982\u6DAF\u788D\u84CB\u8857\u8A72\u93A7\u9AB8\u6D6C\u99A8\u86D9\u57A3\u67FF\u86CE\u920E\u5283\u5687\u5404\u5ED3\u62E1\u64B9\u683C\u6838\u6BBB\u7372\u78BA\u7A6B\u899A\u89D2\u8D6B\u8F03\u90ED\u95A3\u9694\u9769\u5B66\u5CB3\u697D\u984D\u984E\u639B\u7B20\u6A2B\u6A7F\u68B6\u9C0D\u6F5F\u5272\u559D\u6070\u62EC\u6D3B\u6E07\u6ED1\u845B\u8910\u8F44\u4E14\u9C39\u53F6\u691B\u6A3A\u9784\u682A\u515C\u7AC3\u84B2\u91DC\u938C\u565B\u9D28\u6822\u8305\u8431"],
      ["b4a1", "\u7CA5\u5208\u82C5\u74E6\u4E7E\u4F83\u51A0\u5BD2\u520A\u52D8\u52E7\u5DFB\u559A\u582A\u59E6\u5B8C\u5B98\u5BDB\u5E72\u5E79\u60A3\u611F\u6163\u61BE\u63DB\u6562\u67D1\u6853\u68FA\u6B3E\u6B53\u6C57\u6F22\u6F97\u6F45\u74B0\u7518\u76E3\u770B\u7AFF\u7BA1\u7C21\u7DE9\u7F36\u7FF0\u809D\u8266\u839E\u89B3\u8ACC\u8CAB\u9084\u9451\u9593\u9591\u95A2\u9665\u97D3\u9928\u8218\u4E38\u542B\u5CB8\u5DCC\u73A9\u764C\u773C\u5CA9\u7FEB\u8D0B\u96C1\u9811\u9854\u9858\u4F01\u4F0E\u5371\u559C\u5668\u57FA\u5947\u5B09\u5BC4\u5C90\u5E0C\u5E7E\u5FCC\u63EE\u673A\u65D7\u65E2\u671F\u68CB\u68C4"],
      ["b5a1", "\u6A5F\u5E30\u6BC5\u6C17\u6C7D\u757F\u7948\u5B63\u7A00\u7D00\u5FBD\u898F\u8A18\u8CB4\u8D77\u8ECC\u8F1D\u98E2\u9A0E\u9B3C\u4E80\u507D\u5100\u5993\u5B9C\u622F\u6280\u64EC\u6B3A\u72A0\u7591\u7947\u7FA9\u87FB\u8ABC\u8B70\u63AC\u83CA\u97A0\u5409\u5403\u55AB\u6854\u6A58\u8A70\u7827\u6775\u9ECD\u5374\u5BA2\u811A\u8650\u9006\u4E18\u4E45\u4EC7\u4F11\u53CA\u5438\u5BAE\u5F13\u6025\u6551\u673D\u6C42\u6C72\u6CE3\u7078\u7403\u7A76\u7AAE\u7B08\u7D1A\u7CFE\u7D66\u65E7\u725B\u53BB\u5C45\u5DE8\u62D2\u62E0\u6319\u6E20\u865A\u8A31\u8DDD\u92F8\u6F01\u79A6\u9B5A\u4EA8\u4EAB\u4EAC"],
      ["b6a1", "\u4F9B\u4FA0\u50D1\u5147\u7AF6\u5171\u51F6\u5354\u5321\u537F\u53EB\u55AC\u5883\u5CE1\u5F37\u5F4A\u602F\u6050\u606D\u631F\u6559\u6A4B\u6CC1\u72C2\u72ED\u77EF\u80F8\u8105\u8208\u854E\u90F7\u93E1\u97FF\u9957\u9A5A\u4EF0\u51DD\u5C2D\u6681\u696D\u5C40\u66F2\u6975\u7389\u6850\u7C81\u50C5\u52E4\u5747\u5DFE\u9326\u65A4\u6B23\u6B3D\u7434\u7981\u79BD\u7B4B\u7DCA\u82B9\u83CC\u887F\u895F\u8B39\u8FD1\u91D1\u541F\u9280\u4E5D\u5036\u53E5\u533A\u72D7\u7396\u77E9\u82E6\u8EAF\u99C6\u99C8\u99D2\u5177\u611A\u865E\u55B0\u7A7A\u5076\u5BD3\u9047\u9685\u4E32\u6ADB\u91E7\u5C51\u5C48"],
      ["b7a1", "\u6398\u7A9F\u6C93\u9774\u8F61\u7AAA\u718A\u9688\u7C82\u6817\u7E70\u6851\u936C\u52F2\u541B\u85AB\u8A13\u7FA4\u8ECD\u90E1\u5366\u8888\u7941\u4FC2\u50BE\u5211\u5144\u5553\u572D\u73EA\u578B\u5951\u5F62\u5F84\u6075\u6176\u6167\u61A9\u63B2\u643A\u656C\u666F\u6842\u6E13\u7566\u7A3D\u7CFB\u7D4C\u7D99\u7E4B\u7F6B\u830E\u834A\u86CD\u8A08\u8A63\u8B66\u8EFD\u981A\u9D8F\u82B8\u8FCE\u9BE8\u5287\u621F\u6483\u6FC0\u9699\u6841\u5091\u6B20\u6C7A\u6F54\u7A74\u7D50\u8840\u8A23\u6708\u4EF6\u5039\u5026\u5065\u517C\u5238\u5263\u55A7\u570F\u5805\u5ACC\u5EFA\u61B2\u61F8\u62F3\u6372"],
      ["b8a1", "\u691C\u6A29\u727D\u72AC\u732E\u7814\u786F\u7D79\u770C\u80A9\u898B\u8B19\u8CE2\u8ED2\u9063\u9375\u967A\u9855\u9A13\u9E78\u5143\u539F\u53B3\u5E7B\u5F26\u6E1B\u6E90\u7384\u73FE\u7D43\u8237\u8A00\u8AFA\u9650\u4E4E\u500B\u53E4\u547C\u56FA\u59D1\u5B64\u5DF1\u5EAB\u5F27\u6238\u6545\u67AF\u6E56\u72D0\u7CCA\u88B4\u80A1\u80E1\u83F0\u864E\u8A87\u8DE8\u9237\u96C7\u9867\u9F13\u4E94\u4E92\u4F0D\u5348\u5449\u543E\u5A2F\u5F8C\u5FA1\u609F\u68A7\u6A8E\u745A\u7881\u8A9E\u8AA4\u8B77\u9190\u4E5E\u9BC9\u4EA4\u4F7C\u4FAF\u5019\u5016\u5149\u516C\u529F\u52B9\u52FE\u539A\u53E3\u5411"],
      ["b9a1", "\u540E\u5589\u5751\u57A2\u597D\u5B54\u5B5D\u5B8F\u5DE5\u5DE7\u5DF7\u5E78\u5E83\u5E9A\u5EB7\u5F18\u6052\u614C\u6297\u62D8\u63A7\u653B\u6602\u6643\u66F4\u676D\u6821\u6897\u69CB\u6C5F\u6D2A\u6D69\u6E2F\u6E9D\u7532\u7687\u786C\u7A3F\u7CE0\u7D05\u7D18\u7D5E\u7DB1\u8015\u8003\u80AF\u80B1\u8154\u818F\u822A\u8352\u884C\u8861\u8B1B\u8CA2\u8CFC\u90CA\u9175\u9271\u783F\u92FC\u95A4\u964D\u9805\u9999\u9AD8\u9D3B\u525B\u52AB\u53F7\u5408\u58D5\u62F7\u6FE0\u8C6A\u8F5F\u9EB9\u514B\u523B\u544A\u56FD\u7A40\u9177\u9D60\u9ED2\u7344\u6F09\u8170\u7511\u5FFD\u60DA\u9AA8\u72DB\u8FBC"],
      ["baa1", "\u6B64\u9803\u4ECA\u56F0\u5764\u58BE\u5A5A\u6068\u61C7\u660F\u6606\u6839\u68B1\u6DF7\u75D5\u7D3A\u826E\u9B42\u4E9B\u4F50\u53C9\u5506\u5D6F\u5DE6\u5DEE\u67FB\u6C99\u7473\u7802\u8A50\u9396\u88DF\u5750\u5EA7\u632B\u50B5\u50AC\u518D\u6700\u54C9\u585E\u59BB\u5BB0\u5F69\u624D\u63A1\u683D\u6B73\u6E08\u707D\u91C7\u7280\u7815\u7826\u796D\u658E\u7D30\u83DC\u88C1\u8F09\u969B\u5264\u5728\u6750\u7F6A\u8CA1\u51B4\u5742\u962A\u583A\u698A\u80B4\u54B2\u5D0E\u57FC\u7895\u9DFA\u4F5C\u524A\u548B\u643E\u6628\u6714\u67F5\u7A84\u7B56\u7D22\u932F\u685C\u9BAD\u7B39\u5319\u518A\u5237"],
      ["bba1", "\u5BDF\u62F6\u64AE\u64E6\u672D\u6BBA\u85A9\u96D1\u7690\u9BD6\u634C\u9306\u9BAB\u76BF\u6652\u4E09\u5098\u53C2\u5C71\u60E8\u6492\u6563\u685F\u71E6\u73CA\u7523\u7B97\u7E82\u8695\u8B83\u8CDB\u9178\u9910\u65AC\u66AB\u6B8B\u4ED5\u4ED4\u4F3A\u4F7F\u523A\u53F8\u53F2\u55E3\u56DB\u58EB\u59CB\u59C9\u59FF\u5B50\u5C4D\u5E02\u5E2B\u5FD7\u601D\u6307\u652F\u5B5C\u65AF\u65BD\u65E8\u679D\u6B62\u6B7B\u6C0F\u7345\u7949\u79C1\u7CF8\u7D19\u7D2B\u80A2\u8102\u81F3\u8996\u8A5E\u8A69\u8A66\u8A8C\u8AEE\u8CC7\u8CDC\u96CC\u98FC\u6B6F\u4E8B\u4F3C\u4F8D\u5150\u5B57\u5BFA\u6148\u6301\u6642"],
      ["bca1", "\u6B21\u6ECB\u6CBB\u723E\u74BD\u75D4\u78C1\u793A\u800C\u8033\u81EA\u8494\u8F9E\u6C50\u9E7F\u5F0F\u8B58\u9D2B\u7AFA\u8EF8\u5B8D\u96EB\u4E03\u53F1\u57F7\u5931\u5AC9\u5BA4\u6089\u6E7F\u6F06\u75BE\u8CEA\u5B9F\u8500\u7BE0\u5072\u67F4\u829D\u5C61\u854A\u7E1E\u820E\u5199\u5C04\u6368\u8D66\u659C\u716E\u793E\u7D17\u8005\u8B1D\u8ECA\u906E\u86C7\u90AA\u501F\u52FA\u5C3A\u6753\u707C\u7235\u914C\u91C8\u932B\u82E5\u5BC2\u5F31\u60F9\u4E3B\u53D6\u5B88\u624B\u6731\u6B8A\u72E9\u73E0\u7A2E\u816B\u8DA3\u9152\u9996\u5112\u53D7\u546A\u5BFF\u6388\u6A39\u7DAC\u9700\u56DA\u53CE\u5468"],
      ["bda1", "\u5B97\u5C31\u5DDE\u4FEE\u6101\u62FE\u6D32\u79C0\u79CB\u7D42\u7E4D\u7FD2\u81ED\u821F\u8490\u8846\u8972\u8B90\u8E74\u8F2F\u9031\u914B\u916C\u96C6\u919C\u4EC0\u4F4F\u5145\u5341\u5F93\u620E\u67D4\u6C41\u6E0B\u7363\u7E26\u91CD\u9283\u53D4\u5919\u5BBF\u6DD1\u795D\u7E2E\u7C9B\u587E\u719F\u51FA\u8853\u8FF0\u4FCA\u5CFB\u6625\u77AC\u7AE3\u821C\u99FF\u51C6\u5FAA\u65EC\u696F\u6B89\u6DF3\u6E96\u6F64\u76FE\u7D14\u5DE1\u9075\u9187\u9806\u51E6\u521D\u6240\u6691\u66D9\u6E1A\u5EB6\u7DD2\u7F72\u66F8\u85AF\u85F7\u8AF8\u52A9\u53D9\u5973\u5E8F\u5F90\u6055\u92E4\u9664\u50B7\u511F"],
      ["bea1", "\u52DD\u5320\u5347\u53EC\u54E8\u5546\u5531\u5617\u5968\u59BE\u5A3C\u5BB5\u5C06\u5C0F\u5C11\u5C1A\u5E84\u5E8A\u5EE0\u5F70\u627F\u6284\u62DB\u638C\u6377\u6607\u660C\u662D\u6676\u677E\u68A2\u6A1F\u6A35\u6CBC\u6D88\u6E09\u6E58\u713C\u7126\u7167\u75C7\u7701\u785D\u7901\u7965\u79F0\u7AE0\u7B11\u7CA7\u7D39\u8096\u83D6\u848B\u8549\u885D\u88F3\u8A1F\u8A3C\u8A54\u8A73\u8C61\u8CDE\u91A4\u9266\u937E\u9418\u969C\u9798\u4E0A\u4E08\u4E1E\u4E57\u5197\u5270\u57CE\u5834\u58CC\u5B22\u5E38\u60C5\u64FE\u6761\u6756\u6D44\u72B6\u7573\u7A63\u84B8\u8B72\u91B8\u9320\u5631\u57F4\u98FE"],
      ["bfa1", "\u62ED\u690D\u6B96\u71ED\u7E54\u8077\u8272\u89E6\u98DF\u8755\u8FB1\u5C3B\u4F38\u4FE1\u4FB5\u5507\u5A20\u5BDD\u5BE9\u5FC3\u614E\u632F\u65B0\u664B\u68EE\u699B\u6D78\u6DF1\u7533\u75B9\u771F\u795E\u79E6\u7D33\u81E3\u82AF\u85AA\u89AA\u8A3A\u8EAB\u8F9B\u9032\u91DD\u9707\u4EBA\u4EC1\u5203\u5875\u58EC\u5C0B\u751A\u5C3D\u814E\u8A0A\u8FC5\u9663\u976D\u7B25\u8ACF\u9808\u9162\u56F3\u53A8\u9017\u5439\u5782\u5E25\u63A8\u6C34\u708A\u7761\u7C8B\u7FE0\u8870\u9042\u9154\u9310\u9318\u968F\u745E\u9AC4\u5D07\u5D69\u6570\u67A2\u8DA8\u96DB\u636E\u6749\u6919\u83C5\u9817\u96C0\u88FE"],
      ["c0a1", "\u6F84\u647A\u5BF8\u4E16\u702C\u755D\u662F\u51C4\u5236\u52E2\u59D3\u5F81\u6027\u6210\u653F\u6574\u661F\u6674\u68F2\u6816\u6B63\u6E05\u7272\u751F\u76DB\u7CBE\u8056\u58F0\u88FD\u897F\u8AA0\u8A93\u8ACB\u901D\u9192\u9752\u9759\u6589\u7A0E\u8106\u96BB\u5E2D\u60DC\u621A\u65A5\u6614\u6790\u77F3\u7A4D\u7C4D\u7E3E\u810A\u8CAC\u8D64\u8DE1\u8E5F\u78A9\u5207\u62D9\u63A5\u6442\u6298\u8A2D\u7A83\u7BC0\u8AAC\u96EA\u7D76\u820C\u8749\u4ED9\u5148\u5343\u5360\u5BA3\u5C02\u5C16\u5DDD\u6226\u6247\u64B0\u6813\u6834\u6CC9\u6D45\u6D17\u67D3\u6F5C\u714E\u717D\u65CB\u7A7F\u7BAD\u7DDA"],
      ["c1a1", "\u7E4A\u7FA8\u817A\u821B\u8239\u85A6\u8A6E\u8CCE\u8DF5\u9078\u9077\u92AD\u9291\u9583\u9BAE\u524D\u5584\u6F38\u7136\u5168\u7985\u7E55\u81B3\u7CCE\u564C\u5851\u5CA8\u63AA\u66FE\u66FD\u695A\u72D9\u758F\u758E\u790E\u7956\u79DF\u7C97\u7D20\u7D44\u8607\u8A34\u963B\u9061\u9F20\u50E7\u5275\u53CC\u53E2\u5009\u55AA\u58EE\u594F\u723D\u5B8B\u5C64\u531D\u60E3\u60F3\u635C\u6383\u633F\u63BB\u64CD\u65E9\u66F9\u5DE3\u69CD\u69FD\u6F15\u71E5\u4E89\u75E9\u76F8\u7A93\u7CDF\u7DCF\u7D9C\u8061\u8349\u8358\u846C\u84BC\u85FB\u88C5\u8D70\u9001\u906D\u9397\u971C\u9A12\u50CF\u5897\u618E"],
      ["c2a1", "\u81D3\u8535\u8D08\u9020\u4FC3\u5074\u5247\u5373\u606F\u6349\u675F\u6E2C\u8DB3\u901F\u4FD7\u5C5E\u8CCA\u65CF\u7D9A\u5352\u8896\u5176\u63C3\u5B58\u5B6B\u5C0A\u640D\u6751\u905C\u4ED6\u591A\u592A\u6C70\u8A51\u553E\u5815\u59A5\u60F0\u6253\u67C1\u8235\u6955\u9640\u99C4\u9A28\u4F53\u5806\u5BFE\u8010\u5CB1\u5E2F\u5F85\u6020\u614B\u6234\u66FF\u6CF0\u6EDE\u80CE\u817F\u82D4\u888B\u8CB8\u9000\u902E\u968A\u9EDB\u9BDB\u4EE3\u53F0\u5927\u7B2C\u918D\u984C\u9DF9\u6EDD\u7027\u5353\u5544\u5B85\u6258\u629E\u62D3\u6CA2\u6FEF\u7422\u8A17\u9438\u6FC1\u8AFE\u8338\u51E7\u86F8\u53EA"],
      ["c3a1", "\u53E9\u4F46\u9054\u8FB0\u596A\u8131\u5DFD\u7AEA\u8FBF\u68DA\u8C37\u72F8\u9C48\u6A3D\u8AB0\u4E39\u5358\u5606\u5766\u62C5\u63A2\u65E6\u6B4E\u6DE1\u6E5B\u70AD\u77ED\u7AEF\u7BAA\u7DBB\u803D\u80C6\u86CB\u8A95\u935B\u56E3\u58C7\u5F3E\u65AD\u6696\u6A80\u6BB5\u7537\u8AC7\u5024\u77E5\u5730\u5F1B\u6065\u667A\u6C60\u75F4\u7A1A\u7F6E\u81F4\u8718\u9045\u99B3\u7BC9\u755C\u7AF9\u7B51\u84C4\u9010\u79E9\u7A92\u8336\u5AE1\u7740\u4E2D\u4EF2\u5B99\u5FE0\u62BD\u663C\u67F1\u6CE8\u866B\u8877\u8A3B\u914E\u92F3\u99D0\u6A17\u7026\u732A\u82E7\u8457\u8CAF\u4E01\u5146\u51CB\u558B\u5BF5"],
      ["c4a1", "\u5E16\u5E33\u5E81\u5F14\u5F35\u5F6B\u5FB4\u61F2\u6311\u66A2\u671D\u6F6E\u7252\u753A\u773A\u8074\u8139\u8178\u8776\u8ABF\u8ADC\u8D85\u8DF3\u929A\u9577\u9802\u9CE5\u52C5\u6357\u76F4\u6715\u6C88\u73CD\u8CC3\u93AE\u9673\u6D25\u589C\u690E\u69CC\u8FFD\u939A\u75DB\u901A\u585A\u6802\u63B4\u69FB\u4F43\u6F2C\u67D8\u8FBB\u8526\u7DB4\u9354\u693F\u6F70\u576A\u58F7\u5B2C\u7D2C\u722A\u540A\u91E3\u9DB4\u4EAD\u4F4E\u505C\u5075\u5243\u8C9E\u5448\u5824\u5B9A\u5E1D\u5E95\u5EAD\u5EF7\u5F1F\u608C\u62B5\u633A\u63D0\u68AF\u6C40\u7887\u798E\u7A0B\u7DE0\u8247\u8A02\u8AE6\u8E44\u9013"],
      ["c5a1", "\u90B8\u912D\u91D8\u9F0E\u6CE5\u6458\u64E2\u6575\u6EF4\u7684\u7B1B\u9069\u93D1\u6EBA\u54F2\u5FB9\u64A4\u8F4D\u8FED\u9244\u5178\u586B\u5929\u5C55\u5E97\u6DFB\u7E8F\u751C\u8CBC\u8EE2\u985B\u70B9\u4F1D\u6BBF\u6FB1\u7530\u96FB\u514E\u5410\u5835\u5857\u59AC\u5C60\u5F92\u6597\u675C\u6E21\u767B\u83DF\u8CED\u9014\u90FD\u934D\u7825\u783A\u52AA\u5EA6\u571F\u5974\u6012\u5012\u515A\u51AC\u51CD\u5200\u5510\u5854\u5858\u5957\u5B95\u5CF6\u5D8B\u60BC\u6295\u642D\u6771\u6843\u68BC\u68DF\u76D7\u6DD8\u6E6F\u6D9B\u706F\u71C8\u5F53\u75D8\u7977\u7B49\u7B54\u7B52\u7CD6\u7D71\u5230"],
      ["c6a1", "\u8463\u8569\u85E4\u8A0E\u8B04\u8C46\u8E0F\u9003\u900F\u9419\u9676\u982D\u9A30\u95D8\u50CD\u52D5\u540C\u5802\u5C0E\u61A7\u649E\u6D1E\u77B3\u7AE5\u80F4\u8404\u9053\u9285\u5CE0\u9D07\u533F\u5F97\u5FB3\u6D9C\u7279\u7763\u79BF\u7BE4\u6BD2\u72EC\u8AAD\u6803\u6A61\u51F8\u7A81\u6934\u5C4A\u9CF6\u82EB\u5BC5\u9149\u701E\u5678\u5C6F\u60C7\u6566\u6C8C\u8C5A\u9041\u9813\u5451\u66C7\u920D\u5948\u90A3\u5185\u4E4D\u51EA\u8599\u8B0E\u7058\u637A\u934B\u6962\u99B4\u7E04\u7577\u5357\u6960\u8EDF\u96E3\u6C5D\u4E8C\u5C3C\u5F10\u8FE9\u5302\u8CD1\u8089\u8679\u5EFF\u65E5\u4E73\u5165"],
      ["c7a1", "\u5982\u5C3F\u97EE\u4EFB\u598A\u5FCD\u8A8D\u6FE1\u79B0\u7962\u5BE7\u8471\u732B\u71B1\u5E74\u5FF5\u637B\u649A\u71C3\u7C98\u4E43\u5EFC\u4E4B\u57DC\u56A2\u60A9\u6FC3\u7D0D\u80FD\u8133\u81BF\u8FB2\u8997\u86A4\u5DF4\u628A\u64AD\u8987\u6777\u6CE2\u6D3E\u7436\u7834\u5A46\u7F75\u82AD\u99AC\u4FF3\u5EC3\u62DD\u6392\u6557\u676F\u76C3\u724C\u80CC\u80BA\u8F29\u914D\u500D\u57F9\u5A92\u6885\u6973\u7164\u72FD\u8CB7\u58F2\u8CE0\u966A\u9019\u877F\u79E4\u77E7\u8429\u4F2F\u5265\u535A\u62CD\u67CF\u6CCA\u767D\u7B94\u7C95\u8236\u8584\u8FEB\u66DD\u6F20\u7206\u7E1B\u83AB\u99C1\u9EA6"],
      ["c8a1", "\u51FD\u7BB1\u7872\u7BB8\u8087\u7B48\u6AE8\u5E61\u808C\u7551\u7560\u516B\u9262\u6E8C\u767A\u9197\u9AEA\u4F10\u7F70\u629C\u7B4F\u95A5\u9CE9\u567A\u5859\u86E4\u96BC\u4F34\u5224\u534A\u53CD\u53DB\u5E06\u642C\u6591\u677F\u6C3E\u6C4E\u7248\u72AF\u73ED\u7554\u7E41\u822C\u85E9\u8CA9\u7BC4\u91C6\u7169\u9812\u98EF\u633D\u6669\u756A\u76E4\u78D0\u8543\u86EE\u532A\u5351\u5426\u5983\u5E87\u5F7C\u60B2\u6249\u6279\u62AB\u6590\u6BD4\u6CCC\u75B2\u76AE\u7891\u79D8\u7DCB\u7F77\u80A5\u88AB\u8AB9\u8CBB\u907F\u975E\u98DB\u6A0B\u7C38\u5099\u5C3E\u5FAE\u6787\u6BD8\u7435\u7709\u7F8E"],
      ["c9a1", "\u9F3B\u67CA\u7A17\u5339\u758B\u9AED\u5F66\u819D\u83F1\u8098\u5F3C\u5FC5\u7562\u7B46\u903C\u6867\u59EB\u5A9B\u7D10\u767E\u8B2C\u4FF5\u5F6A\u6A19\u6C37\u6F02\u74E2\u7968\u8868\u8A55\u8C79\u5EDF\u63CF\u75C5\u79D2\u82D7\u9328\u92F2\u849C\u86ED\u9C2D\u54C1\u5F6C\u658C\u6D5C\u7015\u8CA7\u8CD3\u983B\u654F\u74F6\u4E0D\u4ED8\u57E0\u592B\u5A66\u5BCC\u51A8\u5E03\u5E9C\u6016\u6276\u6577\u65A7\u666E\u6D6E\u7236\u7B26\u8150\u819A\u8299\u8B5C\u8CA0\u8CE6\u8D74\u961C\u9644\u4FAE\u64AB\u6B66\u821E\u8461\u856A\u90E8\u5C01\u6953\u98A8\u847A\u8557\u4F0F\u526F\u5FA9\u5E45\u670D"],
      ["caa1", "\u798F\u8179\u8907\u8986\u6DF5\u5F17\u6255\u6CB8\u4ECF\u7269\u9B92\u5206\u543B\u5674\u58B3\u61A4\u626E\u711A\u596E\u7C89\u7CDE\u7D1B\u96F0\u6587\u805E\u4E19\u4F75\u5175\u5840\u5E63\u5E73\u5F0A\u67C4\u4E26\u853D\u9589\u965B\u7C73\u9801\u50FB\u58C1\u7656\u78A7\u5225\u77A5\u8511\u7B86\u504F\u5909\u7247\u7BC7\u7DE8\u8FBA\u8FD4\u904D\u4FBF\u52C9\u5A29\u5F01\u97AD\u4FDD\u8217\u92EA\u5703\u6355\u6B69\u752B\u88DC\u8F14\u7A42\u52DF\u5893\u6155\u620A\u66AE\u6BCD\u7C3F\u83E9\u5023\u4FF8\u5305\u5446\u5831\u5949\u5B9D\u5CF0\u5CEF\u5D29\u5E96\u62B1\u6367\u653E\u65B9\u670B"],
      ["cba1", "\u6CD5\u6CE1\u70F9\u7832\u7E2B\u80DE\u82B3\u840C\u84EC\u8702\u8912\u8A2A\u8C4A\u90A6\u92D2\u98FD\u9CF3\u9D6C\u4E4F\u4EA1\u508D\u5256\u574A\u59A8\u5E3D\u5FD8\u5FD9\u623F\u66B4\u671B\u67D0\u68D2\u5192\u7D21\u80AA\u81A8\u8B00\u8C8C\u8CBF\u927E\u9632\u5420\u982C\u5317\u50D5\u535C\u58A8\u64B2\u6734\u7267\u7766\u7A46\u91E6\u52C3\u6CA1\u6B86\u5800\u5E4C\u5954\u672C\u7FFB\u51E1\u76C6\u6469\u78E8\u9B54\u9EBB\u57CB\u59B9\u6627\u679A\u6BCE\u54E9\u69D9\u5E55\u819C\u6795\u9BAA\u67FE\u9C52\u685D\u4EA6\u4FE3\u53C8\u62B9\u672B\u6CAB\u8FC4\u4FAD\u7E6D\u9EBF\u4E07\u6162\u6E80"],
      ["cca1", "\u6F2B\u8513\u5473\u672A\u9B45\u5DF3\u7B95\u5CAC\u5BC6\u871C\u6E4A\u84D1\u7A14\u8108\u5999\u7C8D\u6C11\u7720\u52D9\u5922\u7121\u725F\u77DB\u9727\u9D61\u690B\u5A7F\u5A18\u51A5\u540D\u547D\u660E\u76DF\u8FF7\u9298\u9CF4\u59EA\u725D\u6EC5\u514D\u68C9\u7DBF\u7DEC\u9762\u9EBA\u6478\u6A21\u8302\u5984\u5B5F\u6BDB\u731B\u76F2\u7DB2\u8017\u8499\u5132\u6728\u9ED9\u76EE\u6762\u52FF\u9905\u5C24\u623B\u7C7E\u8CB0\u554F\u60B6\u7D0B\u9580\u5301\u4E5F\u51B6\u591C\u723A\u8036\u91CE\u5F25\u77E2\u5384\u5F79\u7D04\u85AC\u8A33\u8E8D\u9756\u67F3\u85AE\u9453\u6109\u6108\u6CB9\u7652"],
      ["cda1", "\u8AED\u8F38\u552F\u4F51\u512A\u52C7\u53CB\u5BA5\u5E7D\u60A0\u6182\u63D6\u6709\u67DA\u6E67\u6D8C\u7336\u7337\u7531\u7950\u88D5\u8A98\u904A\u9091\u90F5\u96C4\u878D\u5915\u4E88\u4F59\u4E0E\u8A89\u8F3F\u9810\u50AD\u5E7C\u5996\u5BB9\u5EB8\u63DA\u63FA\u64C1\u66DC\u694A\u69D8\u6D0B\u6EB6\u7194\u7528\u7AAF\u7F8A\u8000\u8449\u84C9\u8981\u8B21\u8E0A\u9065\u967D\u990A\u617E\u6291\u6B32\u6C83\u6D74\u7FCC\u7FFC\u6DC0\u7F85\u87BA\u88F8\u6765\u83B1\u983C\u96F7\u6D1B\u7D61\u843D\u916A\u4E71\u5375\u5D50\u6B04\u6FEB\u85CD\u862D\u89A7\u5229\u540F\u5C65\u674E\u68A8\u7406\u7483"],
      ["cea1", "\u75E2\u88CF\u88E1\u91CC\u96E2\u9678\u5F8B\u7387\u7ACB\u844E\u63A0\u7565\u5289\u6D41\u6E9C\u7409\u7559\u786B\u7C92\u9686\u7ADC\u9F8D\u4FB6\u616E\u65C5\u865C\u4E86\u4EAE\u50DA\u4E21\u51CC\u5BEE\u6599\u6881\u6DBC\u731F\u7642\u77AD\u7A1C\u7CE7\u826F\u8AD2\u907C\u91CF\u9675\u9818\u529B\u7DD1\u502B\u5398\u6797\u6DCB\u71D0\u7433\u81E8\u8F2A\u96A3\u9C57\u9E9F\u7460\u5841\u6D99\u7D2F\u985E\u4EE4\u4F36\u4F8B\u51B7\u52B1\u5DBA\u601C\u73B2\u793C\u82D3\u9234\u96B7\u96F6\u970A\u9E97\u9F62\u66A6\u6B74\u5217\u52A3\u70C8\u88C2\u5EC9\u604B\u6190\u6F23\u7149\u7C3E\u7DF4\u806F"],
      ["cfa1", "\u84EE\u9023\u932C\u5442\u9B6F\u6AD3\u7089\u8CC2\u8DEF\u9732\u52B4\u5A41\u5ECA\u5F04\u6717\u697C\u6994\u6D6A\u6F0F\u7262\u72FC\u7BED\u8001\u807E\u874B\u90CE\u516D\u9E93\u7984\u808B\u9332\u8AD6\u502D\u548C\u8A71\u6B6A\u8CC4\u8107\u60D1\u67A0\u9DF2\u4E99\u4E98\u9C10\u8A6B\u85C1\u8568\u6900\u6E7E\u7897\u8155"],
      ["d0a1", "\u5F0C\u4E10\u4E15\u4E2A\u4E31\u4E36\u4E3C\u4E3F\u4E42\u4E56\u4E58\u4E82\u4E85\u8C6B\u4E8A\u8212\u5F0D\u4E8E\u4E9E\u4E9F\u4EA0\u4EA2\u4EB0\u4EB3\u4EB6\u4ECE\u4ECD\u4EC4\u4EC6\u4EC2\u4ED7\u4EDE\u4EED\u4EDF\u4EF7\u4F09\u4F5A\u4F30\u4F5B\u4F5D\u4F57\u4F47\u4F76\u4F88\u4F8F\u4F98\u4F7B\u4F69\u4F70\u4F91\u4F6F\u4F86\u4F96\u5118\u4FD4\u4FDF\u4FCE\u4FD8\u4FDB\u4FD1\u4FDA\u4FD0\u4FE4\u4FE5\u501A\u5028\u5014\u502A\u5025\u5005\u4F1C\u4FF6\u5021\u5029\u502C\u4FFE\u4FEF\u5011\u5006\u5043\u5047\u6703\u5055\u5050\u5048\u505A\u5056\u506C\u5078\u5080\u509A\u5085\u50B4\u50B2"],
      ["d1a1", "\u50C9\u50CA\u50B3\u50C2\u50D6\u50DE\u50E5\u50ED\u50E3\u50EE\u50F9\u50F5\u5109\u5101\u5102\u5116\u5115\u5114\u511A\u5121\u513A\u5137\u513C\u513B\u513F\u5140\u5152\u514C\u5154\u5162\u7AF8\u5169\u516A\u516E\u5180\u5182\u56D8\u518C\u5189\u518F\u5191\u5193\u5195\u5196\u51A4\u51A6\u51A2\u51A9\u51AA\u51AB\u51B3\u51B1\u51B2\u51B0\u51B5\u51BD\u51C5\u51C9\u51DB\u51E0\u8655\u51E9\u51ED\u51F0\u51F5\u51FE\u5204\u520B\u5214\u520E\u5227\u522A\u522E\u5233\u5239\u524F\u5244\u524B\u524C\u525E\u5254\u526A\u5274\u5269\u5273\u527F\u527D\u528D\u5294\u5292\u5271\u5288\u5291\u8FA8"],
      ["d2a1", "\u8FA7\u52AC\u52AD\u52BC\u52B5\u52C1\u52CD\u52D7\u52DE\u52E3\u52E6\u98ED\u52E0\u52F3\u52F5\u52F8\u52F9\u5306\u5308\u7538\u530D\u5310\u530F\u5315\u531A\u5323\u532F\u5331\u5333\u5338\u5340\u5346\u5345\u4E17\u5349\u534D\u51D6\u535E\u5369\u536E\u5918\u537B\u5377\u5382\u5396\u53A0\u53A6\u53A5\u53AE\u53B0\u53B6\u53C3\u7C12\u96D9\u53DF\u66FC\u71EE\u53EE\u53E8\u53ED\u53FA\u5401\u543D\u5440\u542C\u542D\u543C\u542E\u5436\u5429\u541D\u544E\u548F\u5475\u548E\u545F\u5471\u5477\u5470\u5492\u547B\u5480\u5476\u5484\u5490\u5486\u54C7\u54A2\u54B8\u54A5\u54AC\u54C4\u54C8\u54A8"],
      ["d3a1", "\u54AB\u54C2\u54A4\u54BE\u54BC\u54D8\u54E5\u54E6\u550F\u5514\u54FD\u54EE\u54ED\u54FA\u54E2\u5539\u5540\u5563\u554C\u552E\u555C\u5545\u5556\u5557\u5538\u5533\u555D\u5599\u5580\u54AF\u558A\u559F\u557B\u557E\u5598\u559E\u55AE\u557C\u5583\u55A9\u5587\u55A8\u55DA\u55C5\u55DF\u55C4\u55DC\u55E4\u55D4\u5614\u55F7\u5616\u55FE\u55FD\u561B\u55F9\u564E\u5650\u71DF\u5634\u5636\u5632\u5638\u566B\u5664\u562F\u566C\u566A\u5686\u5680\u568A\u56A0\u5694\u568F\u56A5\u56AE\u56B6\u56B4\u56C2\u56BC\u56C1\u56C3\u56C0\u56C8\u56CE\u56D1\u56D3\u56D7\u56EE\u56F9\u5700\u56FF\u5704\u5709"],
      ["d4a1", "\u5708\u570B\u570D\u5713\u5718\u5716\u55C7\u571C\u5726\u5737\u5738\u574E\u573B\u5740\u574F\u5769\u57C0\u5788\u5761\u577F\u5789\u5793\u57A0\u57B3\u57A4\u57AA\u57B0\u57C3\u57C6\u57D4\u57D2\u57D3\u580A\u57D6\u57E3\u580B\u5819\u581D\u5872\u5821\u5862\u584B\u5870\u6BC0\u5852\u583D\u5879\u5885\u58B9\u589F\u58AB\u58BA\u58DE\u58BB\u58B8\u58AE\u58C5\u58D3\u58D1\u58D7\u58D9\u58D8\u58E5\u58DC\u58E4\u58DF\u58EF\u58FA\u58F9\u58FB\u58FC\u58FD\u5902\u590A\u5910\u591B\u68A6\u5925\u592C\u592D\u5932\u5938\u593E\u7AD2\u5955\u5950\u594E\u595A\u5958\u5962\u5960\u5967\u596C\u5969"],
      ["d5a1", "\u5978\u5981\u599D\u4F5E\u4FAB\u59A3\u59B2\u59C6\u59E8\u59DC\u598D\u59D9\u59DA\u5A25\u5A1F\u5A11\u5A1C\u5A09\u5A1A\u5A40\u5A6C\u5A49\u5A35\u5A36\u5A62\u5A6A\u5A9A\u5ABC\u5ABE\u5ACB\u5AC2\u5ABD\u5AE3\u5AD7\u5AE6\u5AE9\u5AD6\u5AFA\u5AFB\u5B0C\u5B0B\u5B16\u5B32\u5AD0\u5B2A\u5B36\u5B3E\u5B43\u5B45\u5B40\u5B51\u5B55\u5B5A\u5B5B\u5B65\u5B69\u5B70\u5B73\u5B75\u5B78\u6588\u5B7A\u5B80\u5B83\u5BA6\u5BB8\u5BC3\u5BC7\u5BC9\u5BD4\u5BD0\u5BE4\u5BE6\u5BE2\u5BDE\u5BE5\u5BEB\u5BF0\u5BF6\u5BF3\u5C05\u5C07\u5C08\u5C0D\u5C13\u5C20\u5C22\u5C28\u5C38\u5C39\u5C41\u5C46\u5C4E\u5C53"],
      ["d6a1", "\u5C50\u5C4F\u5B71\u5C6C\u5C6E\u4E62\u5C76\u5C79\u5C8C\u5C91\u5C94\u599B\u5CAB\u5CBB\u5CB6\u5CBC\u5CB7\u5CC5\u5CBE\u5CC7\u5CD9\u5CE9\u5CFD\u5CFA\u5CED\u5D8C\u5CEA\u5D0B\u5D15\u5D17\u5D5C\u5D1F\u5D1B\u5D11\u5D14\u5D22\u5D1A\u5D19\u5D18\u5D4C\u5D52\u5D4E\u5D4B\u5D6C\u5D73\u5D76\u5D87\u5D84\u5D82\u5DA2\u5D9D\u5DAC\u5DAE\u5DBD\u5D90\u5DB7\u5DBC\u5DC9\u5DCD\u5DD3\u5DD2\u5DD6\u5DDB\u5DEB\u5DF2\u5DF5\u5E0B\u5E1A\u5E19\u5E11\u5E1B\u5E36\u5E37\u5E44\u5E43\u5E40\u5E4E\u5E57\u5E54\u5E5F\u5E62\u5E64\u5E47\u5E75\u5E76\u5E7A\u9EBC\u5E7F\u5EA0\u5EC1\u5EC2\u5EC8\u5ED0\u5ECF"],
      ["d7a1", "\u5ED6\u5EE3\u5EDD\u5EDA\u5EDB\u5EE2\u5EE1\u5EE8\u5EE9\u5EEC\u5EF1\u5EF3\u5EF0\u5EF4\u5EF8\u5EFE\u5F03\u5F09\u5F5D\u5F5C\u5F0B\u5F11\u5F16\u5F29\u5F2D\u5F38\u5F41\u5F48\u5F4C\u5F4E\u5F2F\u5F51\u5F56\u5F57\u5F59\u5F61\u5F6D\u5F73\u5F77\u5F83\u5F82\u5F7F\u5F8A\u5F88\u5F91\u5F87\u5F9E\u5F99\u5F98\u5FA0\u5FA8\u5FAD\u5FBC\u5FD6\u5FFB\u5FE4\u5FF8\u5FF1\u5FDD\u60B3\u5FFF\u6021\u6060\u6019\u6010\u6029\u600E\u6031\u601B\u6015\u602B\u6026\u600F\u603A\u605A\u6041\u606A\u6077\u605F\u604A\u6046\u604D\u6063\u6043\u6064\u6042\u606C\u606B\u6059\u6081\u608D\u60E7\u6083\u609A"],
      ["d8a1", "\u6084\u609B\u6096\u6097\u6092\u60A7\u608B\u60E1\u60B8\u60E0\u60D3\u60B4\u5FF0\u60BD\u60C6\u60B5\u60D8\u614D\u6115\u6106\u60F6\u60F7\u6100\u60F4\u60FA\u6103\u6121\u60FB\u60F1\u610D\u610E\u6147\u613E\u6128\u6127\u614A\u613F\u613C\u612C\u6134\u613D\u6142\u6144\u6173\u6177\u6158\u6159\u615A\u616B\u6174\u616F\u6165\u6171\u615F\u615D\u6153\u6175\u6199\u6196\u6187\u61AC\u6194\u619A\u618A\u6191\u61AB\u61AE\u61CC\u61CA\u61C9\u61F7\u61C8\u61C3\u61C6\u61BA\u61CB\u7F79\u61CD\u61E6\u61E3\u61F6\u61FA\u61F4\u61FF\u61FD\u61FC\u61FE\u6200\u6208\u6209\u620D\u620C\u6214\u621B"],
      ["d9a1", "\u621E\u6221\u622A\u622E\u6230\u6232\u6233\u6241\u624E\u625E\u6263\u625B\u6260\u6268\u627C\u6282\u6289\u627E\u6292\u6293\u6296\u62D4\u6283\u6294\u62D7\u62D1\u62BB\u62CF\u62FF\u62C6\u64D4\u62C8\u62DC\u62CC\u62CA\u62C2\u62C7\u629B\u62C9\u630C\u62EE\u62F1\u6327\u6302\u6308\u62EF\u62F5\u6350\u633E\u634D\u641C\u634F\u6396\u638E\u6380\u63AB\u6376\u63A3\u638F\u6389\u639F\u63B5\u636B\u6369\u63BE\u63E9\u63C0\u63C6\u63E3\u63C9\u63D2\u63F6\u63C4\u6416\u6434\u6406\u6413\u6426\u6436\u651D\u6417\u6428\u640F\u6467\u646F\u6476\u644E\u652A\u6495\u6493\u64A5\u64A9\u6488\u64BC"],
      ["daa1", "\u64DA\u64D2\u64C5\u64C7\u64BB\u64D8\u64C2\u64F1\u64E7\u8209\u64E0\u64E1\u62AC\u64E3\u64EF\u652C\u64F6\u64F4\u64F2\u64FA\u6500\u64FD\u6518\u651C\u6505\u6524\u6523\u652B\u6534\u6535\u6537\u6536\u6538\u754B\u6548\u6556\u6555\u654D\u6558\u655E\u655D\u6572\u6578\u6582\u6583\u8B8A\u659B\u659F\u65AB\u65B7\u65C3\u65C6\u65C1\u65C4\u65CC\u65D2\u65DB\u65D9\u65E0\u65E1\u65F1\u6772\u660A\u6603\u65FB\u6773\u6635\u6636\u6634\u661C\u664F\u6644\u6649\u6641\u665E\u665D\u6664\u6667\u6668\u665F\u6662\u6670\u6683\u6688\u668E\u6689\u6684\u6698\u669D\u66C1\u66B9\u66C9\u66BE\u66BC"],
      ["dba1", "\u66C4\u66B8\u66D6\u66DA\u66E0\u663F\u66E6\u66E9\u66F0\u66F5\u66F7\u670F\u6716\u671E\u6726\u6727\u9738\u672E\u673F\u6736\u6741\u6738\u6737\u6746\u675E\u6760\u6759\u6763\u6764\u6789\u6770\u67A9\u677C\u676A\u678C\u678B\u67A6\u67A1\u6785\u67B7\u67EF\u67B4\u67EC\u67B3\u67E9\u67B8\u67E4\u67DE\u67DD\u67E2\u67EE\u67B9\u67CE\u67C6\u67E7\u6A9C\u681E\u6846\u6829\u6840\u684D\u6832\u684E\u68B3\u682B\u6859\u6863\u6877\u687F\u689F\u688F\u68AD\u6894\u689D\u689B\u6883\u6AAE\u68B9\u6874\u68B5\u68A0\u68BA\u690F\u688D\u687E\u6901\u68CA\u6908\u68D8\u6922\u6926\u68E1\u690C\u68CD"],
      ["dca1", "\u68D4\u68E7\u68D5\u6936\u6912\u6904\u68D7\u68E3\u6925\u68F9\u68E0\u68EF\u6928\u692A\u691A\u6923\u6921\u68C6\u6979\u6977\u695C\u6978\u696B\u6954\u697E\u696E\u6939\u6974\u693D\u6959\u6930\u6961\u695E\u695D\u6981\u696A\u69B2\u69AE\u69D0\u69BF\u69C1\u69D3\u69BE\u69CE\u5BE8\u69CA\u69DD\u69BB\u69C3\u69A7\u6A2E\u6991\u69A0\u699C\u6995\u69B4\u69DE\u69E8\u6A02\u6A1B\u69FF\u6B0A\u69F9\u69F2\u69E7\u6A05\u69B1\u6A1E\u69ED\u6A14\u69EB\u6A0A\u6A12\u6AC1\u6A23\u6A13\u6A44\u6A0C\u6A72\u6A36\u6A78\u6A47\u6A62\u6A59\u6A66\u6A48\u6A38\u6A22\u6A90\u6A8D\u6AA0\u6A84\u6AA2\u6AA3"],
      ["dda1", "\u6A97\u8617\u6ABB\u6AC3\u6AC2\u6AB8\u6AB3\u6AAC\u6ADE\u6AD1\u6ADF\u6AAA\u6ADA\u6AEA\u6AFB\u6B05\u8616\u6AFA\u6B12\u6B16\u9B31\u6B1F\u6B38\u6B37\u76DC\u6B39\u98EE\u6B47\u6B43\u6B49\u6B50\u6B59\u6B54\u6B5B\u6B5F\u6B61\u6B78\u6B79\u6B7F\u6B80\u6B84\u6B83\u6B8D\u6B98\u6B95\u6B9E\u6BA4\u6BAA\u6BAB\u6BAF\u6BB2\u6BB1\u6BB3\u6BB7\u6BBC\u6BC6\u6BCB\u6BD3\u6BDF\u6BEC\u6BEB\u6BF3\u6BEF\u9EBE\u6C08\u6C13\u6C14\u6C1B\u6C24\u6C23\u6C5E\u6C55\u6C62\u6C6A\u6C82\u6C8D\u6C9A\u6C81\u6C9B\u6C7E\u6C68\u6C73\u6C92\u6C90\u6CC4\u6CF1\u6CD3\u6CBD\u6CD7\u6CC5\u6CDD\u6CAE\u6CB1\u6CBE"],
      ["dea1", "\u6CBA\u6CDB\u6CEF\u6CD9\u6CEA\u6D1F\u884D\u6D36\u6D2B\u6D3D\u6D38\u6D19\u6D35\u6D33\u6D12\u6D0C\u6D63\u6D93\u6D64\u6D5A\u6D79\u6D59\u6D8E\u6D95\u6FE4\u6D85\u6DF9\u6E15\u6E0A\u6DB5\u6DC7\u6DE6\u6DB8\u6DC6\u6DEC\u6DDE\u6DCC\u6DE8\u6DD2\u6DC5\u6DFA\u6DD9\u6DE4\u6DD5\u6DEA\u6DEE\u6E2D\u6E6E\u6E2E\u6E19\u6E72\u6E5F\u6E3E\u6E23\u6E6B\u6E2B\u6E76\u6E4D\u6E1F\u6E43\u6E3A\u6E4E\u6E24\u6EFF\u6E1D\u6E38\u6E82\u6EAA\u6E98\u6EC9\u6EB7\u6ED3\u6EBD\u6EAF\u6EC4\u6EB2\u6ED4\u6ED5\u6E8F\u6EA5\u6EC2\u6E9F\u6F41\u6F11\u704C\u6EEC\u6EF8\u6EFE\u6F3F\u6EF2\u6F31\u6EEF\u6F32\u6ECC"],
      ["dfa1", "\u6F3E\u6F13\u6EF7\u6F86\u6F7A\u6F78\u6F81\u6F80\u6F6F\u6F5B\u6FF3\u6F6D\u6F82\u6F7C\u6F58\u6F8E\u6F91\u6FC2\u6F66\u6FB3\u6FA3\u6FA1\u6FA4\u6FB9\u6FC6\u6FAA\u6FDF\u6FD5\u6FEC\u6FD4\u6FD8\u6FF1\u6FEE\u6FDB\u7009\u700B\u6FFA\u7011\u7001\u700F\u6FFE\u701B\u701A\u6F74\u701D\u7018\u701F\u7030\u703E\u7032\u7051\u7063\u7099\u7092\u70AF\u70F1\u70AC\u70B8\u70B3\u70AE\u70DF\u70CB\u70DD\u70D9\u7109\u70FD\u711C\u7119\u7165\u7155\u7188\u7166\u7162\u714C\u7156\u716C\u718F\u71FB\u7184\u7195\u71A8\u71AC\u71D7\u71B9\u71BE\u71D2\u71C9\u71D4\u71CE\u71E0\u71EC\u71E7\u71F5\u71FC"],
      ["e0a1", "\u71F9\u71FF\u720D\u7210\u721B\u7228\u722D\u722C\u7230\u7232\u723B\u723C\u723F\u7240\u7246\u724B\u7258\u7274\u727E\u7282\u7281\u7287\u7292\u7296\u72A2\u72A7\u72B9\u72B2\u72C3\u72C6\u72C4\u72CE\u72D2\u72E2\u72E0\u72E1\u72F9\u72F7\u500F\u7317\u730A\u731C\u7316\u731D\u7334\u732F\u7329\u7325\u733E\u734E\u734F\u9ED8\u7357\u736A\u7368\u7370\u7378\u7375\u737B\u737A\u73C8\u73B3\u73CE\u73BB\u73C0\u73E5\u73EE\u73DE\u74A2\u7405\u746F\u7425\u73F8\u7432\u743A\u7455\u743F\u745F\u7459\u7441\u745C\u7469\u7470\u7463\u746A\u7476\u747E\u748B\u749E\u74A7\u74CA\u74CF\u74D4\u73F1"],
      ["e1a1", "\u74E0\u74E3\u74E7\u74E9\u74EE\u74F2\u74F0\u74F1\u74F8\u74F7\u7504\u7503\u7505\u750C\u750E\u750D\u7515\u7513\u751E\u7526\u752C\u753C\u7544\u754D\u754A\u7549\u755B\u7546\u755A\u7569\u7564\u7567\u756B\u756D\u7578\u7576\u7586\u7587\u7574\u758A\u7589\u7582\u7594\u759A\u759D\u75A5\u75A3\u75C2\u75B3\u75C3\u75B5\u75BD\u75B8\u75BC\u75B1\u75CD\u75CA\u75D2\u75D9\u75E3\u75DE\u75FE\u75FF\u75FC\u7601\u75F0\u75FA\u75F2\u75F3\u760B\u760D\u7609\u761F\u7627\u7620\u7621\u7622\u7624\u7634\u7630\u763B\u7647\u7648\u7646\u765C\u7658\u7661\u7662\u7668\u7669\u766A\u7667\u766C\u7670"],
      ["e2a1", "\u7672\u7676\u7678\u767C\u7680\u7683\u7688\u768B\u768E\u7696\u7693\u7699\u769A\u76B0\u76B4\u76B8\u76B9\u76BA\u76C2\u76CD\u76D6\u76D2\u76DE\u76E1\u76E5\u76E7\u76EA\u862F\u76FB\u7708\u7707\u7704\u7729\u7724\u771E\u7725\u7726\u771B\u7737\u7738\u7747\u775A\u7768\u776B\u775B\u7765\u777F\u777E\u7779\u778E\u778B\u7791\u77A0\u779E\u77B0\u77B6\u77B9\u77BF\u77BC\u77BD\u77BB\u77C7\u77CD\u77D7\u77DA\u77DC\u77E3\u77EE\u77FC\u780C\u7812\u7926\u7820\u792A\u7845\u788E\u7874\u7886\u787C\u789A\u788C\u78A3\u78B5\u78AA\u78AF\u78D1\u78C6\u78CB\u78D4\u78BE\u78BC\u78C5\u78CA\u78EC"],
      ["e3a1", "\u78E7\u78DA\u78FD\u78F4\u7907\u7912\u7911\u7919\u792C\u792B\u7940\u7960\u7957\u795F\u795A\u7955\u7953\u797A\u797F\u798A\u799D\u79A7\u9F4B\u79AA\u79AE\u79B3\u79B9\u79BA\u79C9\u79D5\u79E7\u79EC\u79E1\u79E3\u7A08\u7A0D\u7A18\u7A19\u7A20\u7A1F\u7980\u7A31\u7A3B\u7A3E\u7A37\u7A43\u7A57\u7A49\u7A61\u7A62\u7A69\u9F9D\u7A70\u7A79\u7A7D\u7A88\u7A97\u7A95\u7A98\u7A96\u7AA9\u7AC8\u7AB0\u7AB6\u7AC5\u7AC4\u7ABF\u9083\u7AC7\u7ACA\u7ACD\u7ACF\u7AD5\u7AD3\u7AD9\u7ADA\u7ADD\u7AE1\u7AE2\u7AE6\u7AED\u7AF0\u7B02\u7B0F\u7B0A\u7B06\u7B33\u7B18\u7B19\u7B1E\u7B35\u7B28\u7B36\u7B50"],
      ["e4a1", "\u7B7A\u7B04\u7B4D\u7B0B\u7B4C\u7B45\u7B75\u7B65\u7B74\u7B67\u7B70\u7B71\u7B6C\u7B6E\u7B9D\u7B98\u7B9F\u7B8D\u7B9C\u7B9A\u7B8B\u7B92\u7B8F\u7B5D\u7B99\u7BCB\u7BC1\u7BCC\u7BCF\u7BB4\u7BC6\u7BDD\u7BE9\u7C11\u7C14\u7BE6\u7BE5\u7C60\u7C00\u7C07\u7C13\u7BF3\u7BF7\u7C17\u7C0D\u7BF6\u7C23\u7C27\u7C2A\u7C1F\u7C37\u7C2B\u7C3D\u7C4C\u7C43\u7C54\u7C4F\u7C40\u7C50\u7C58\u7C5F\u7C64\u7C56\u7C65\u7C6C\u7C75\u7C83\u7C90\u7CA4\u7CAD\u7CA2\u7CAB\u7CA1\u7CA8\u7CB3\u7CB2\u7CB1\u7CAE\u7CB9\u7CBD\u7CC0\u7CC5\u7CC2\u7CD8\u7CD2\u7CDC\u7CE2\u9B3B\u7CEF\u7CF2\u7CF4\u7CF6\u7CFA\u7D06"],
      ["e5a1", "\u7D02\u7D1C\u7D15\u7D0A\u7D45\u7D4B\u7D2E\u7D32\u7D3F\u7D35\u7D46\u7D73\u7D56\u7D4E\u7D72\u7D68\u7D6E\u7D4F\u7D63\u7D93\u7D89\u7D5B\u7D8F\u7D7D\u7D9B\u7DBA\u7DAE\u7DA3\u7DB5\u7DC7\u7DBD\u7DAB\u7E3D\u7DA2\u7DAF\u7DDC\u7DB8\u7D9F\u7DB0\u7DD8\u7DDD\u7DE4\u7DDE\u7DFB\u7DF2\u7DE1\u7E05\u7E0A\u7E23\u7E21\u7E12\u7E31\u7E1F\u7E09\u7E0B\u7E22\u7E46\u7E66\u7E3B\u7E35\u7E39\u7E43\u7E37\u7E32\u7E3A\u7E67\u7E5D\u7E56\u7E5E\u7E59\u7E5A\u7E79\u7E6A\u7E69\u7E7C\u7E7B\u7E83\u7DD5\u7E7D\u8FAE\u7E7F\u7E88\u7E89\u7E8C\u7E92\u7E90\u7E93\u7E94\u7E96\u7E8E\u7E9B\u7E9C\u7F38\u7F3A"],
      ["e6a1", "\u7F45\u7F4C\u7F4D\u7F4E\u7F50\u7F51\u7F55\u7F54\u7F58\u7F5F\u7F60\u7F68\u7F69\u7F67\u7F78\u7F82\u7F86\u7F83\u7F88\u7F87\u7F8C\u7F94\u7F9E\u7F9D\u7F9A\u7FA3\u7FAF\u7FB2\u7FB9\u7FAE\u7FB6\u7FB8\u8B71\u7FC5\u7FC6\u7FCA\u7FD5\u7FD4\u7FE1\u7FE6\u7FE9\u7FF3\u7FF9\u98DC\u8006\u8004\u800B\u8012\u8018\u8019\u801C\u8021\u8028\u803F\u803B\u804A\u8046\u8052\u8058\u805A\u805F\u8062\u8068\u8073\u8072\u8070\u8076\u8079\u807D\u807F\u8084\u8086\u8085\u809B\u8093\u809A\u80AD\u5190\u80AC\u80DB\u80E5\u80D9\u80DD\u80C4\u80DA\u80D6\u8109\u80EF\u80F1\u811B\u8129\u8123\u812F\u814B"],
      ["e7a1", "\u968B\u8146\u813E\u8153\u8151\u80FC\u8171\u816E\u8165\u8166\u8174\u8183\u8188\u818A\u8180\u8182\u81A0\u8195\u81A4\u81A3\u815F\u8193\u81A9\u81B0\u81B5\u81BE\u81B8\u81BD\u81C0\u81C2\u81BA\u81C9\u81CD\u81D1\u81D9\u81D8\u81C8\u81DA\u81DF\u81E0\u81E7\u81FA\u81FB\u81FE\u8201\u8202\u8205\u8207\u820A\u820D\u8210\u8216\u8229\u822B\u8238\u8233\u8240\u8259\u8258\u825D\u825A\u825F\u8264\u8262\u8268\u826A\u826B\u822E\u8271\u8277\u8278\u827E\u828D\u8292\u82AB\u829F\u82BB\u82AC\u82E1\u82E3\u82DF\u82D2\u82F4\u82F3\u82FA\u8393\u8303\u82FB\u82F9\u82DE\u8306\u82DC\u8309\u82D9"],
      ["e8a1", "\u8335\u8334\u8316\u8332\u8331\u8340\u8339\u8350\u8345\u832F\u832B\u8317\u8318\u8385\u839A\u83AA\u839F\u83A2\u8396\u8323\u838E\u8387\u838A\u837C\u83B5\u8373\u8375\u83A0\u8389\u83A8\u83F4\u8413\u83EB\u83CE\u83FD\u8403\u83D8\u840B\u83C1\u83F7\u8407\u83E0\u83F2\u840D\u8422\u8420\u83BD\u8438\u8506\u83FB\u846D\u842A\u843C\u855A\u8484\u8477\u846B\u84AD\u846E\u8482\u8469\u8446\u842C\u846F\u8479\u8435\u84CA\u8462\u84B9\u84BF\u849F\u84D9\u84CD\u84BB\u84DA\u84D0\u84C1\u84C6\u84D6\u84A1\u8521\u84FF\u84F4\u8517\u8518\u852C\u851F\u8515\u8514\u84FC\u8540\u8563\u8558\u8548"],
      ["e9a1", "\u8541\u8602\u854B\u8555\u8580\u85A4\u8588\u8591\u858A\u85A8\u856D\u8594\u859B\u85EA\u8587\u859C\u8577\u857E\u8590\u85C9\u85BA\u85CF\u85B9\u85D0\u85D5\u85DD\u85E5\u85DC\u85F9\u860A\u8613\u860B\u85FE\u85FA\u8606\u8622\u861A\u8630\u863F\u864D\u4E55\u8654\u865F\u8667\u8671\u8693\u86A3\u86A9\u86AA\u868B\u868C\u86B6\u86AF\u86C4\u86C6\u86B0\u86C9\u8823\u86AB\u86D4\u86DE\u86E9\u86EC\u86DF\u86DB\u86EF\u8712\u8706\u8708\u8700\u8703\u86FB\u8711\u8709\u870D\u86F9\u870A\u8734\u873F\u8737\u873B\u8725\u8729\u871A\u8760\u875F\u8778\u874C\u874E\u8774\u8757\u8768\u876E\u8759"],
      ["eaa1", "\u8753\u8763\u876A\u8805\u87A2\u879F\u8782\u87AF\u87CB\u87BD\u87C0\u87D0\u96D6\u87AB\u87C4\u87B3\u87C7\u87C6\u87BB\u87EF\u87F2\u87E0\u880F\u880D\u87FE\u87F6\u87F7\u880E\u87D2\u8811\u8816\u8815\u8822\u8821\u8831\u8836\u8839\u8827\u883B\u8844\u8842\u8852\u8859\u885E\u8862\u886B\u8881\u887E\u889E\u8875\u887D\u88B5\u8872\u8882\u8897\u8892\u88AE\u8899\u88A2\u888D\u88A4\u88B0\u88BF\u88B1\u88C3\u88C4\u88D4\u88D8\u88D9\u88DD\u88F9\u8902\u88FC\u88F4\u88E8\u88F2\u8904\u890C\u890A\u8913\u8943\u891E\u8925\u892A\u892B\u8941\u8944\u893B\u8936\u8938\u894C\u891D\u8960\u895E"],
      ["eba1", "\u8966\u8964\u896D\u896A\u896F\u8974\u8977\u897E\u8983\u8988\u898A\u8993\u8998\u89A1\u89A9\u89A6\u89AC\u89AF\u89B2\u89BA\u89BD\u89BF\u89C0\u89DA\u89DC\u89DD\u89E7\u89F4\u89F8\u8A03\u8A16\u8A10\u8A0C\u8A1B\u8A1D\u8A25\u8A36\u8A41\u8A5B\u8A52\u8A46\u8A48\u8A7C\u8A6D\u8A6C\u8A62\u8A85\u8A82\u8A84\u8AA8\u8AA1\u8A91\u8AA5\u8AA6\u8A9A\u8AA3\u8AC4\u8ACD\u8AC2\u8ADA\u8AEB\u8AF3\u8AE7\u8AE4\u8AF1\u8B14\u8AE0\u8AE2\u8AF7\u8ADE\u8ADB\u8B0C\u8B07\u8B1A\u8AE1\u8B16\u8B10\u8B17\u8B20\u8B33\u97AB\u8B26\u8B2B\u8B3E\u8B28\u8B41\u8B4C\u8B4F\u8B4E\u8B49\u8B56\u8B5B\u8B5A\u8B6B"],
      ["eca1", "\u8B5F\u8B6C\u8B6F\u8B74\u8B7D\u8B80\u8B8C\u8B8E\u8B92\u8B93\u8B96\u8B99\u8B9A\u8C3A\u8C41\u8C3F\u8C48\u8C4C\u8C4E\u8C50\u8C55\u8C62\u8C6C\u8C78\u8C7A\u8C82\u8C89\u8C85\u8C8A\u8C8D\u8C8E\u8C94\u8C7C\u8C98\u621D\u8CAD\u8CAA\u8CBD\u8CB2\u8CB3\u8CAE\u8CB6\u8CC8\u8CC1\u8CE4\u8CE3\u8CDA\u8CFD\u8CFA\u8CFB\u8D04\u8D05\u8D0A\u8D07\u8D0F\u8D0D\u8D10\u9F4E\u8D13\u8CCD\u8D14\u8D16\u8D67\u8D6D\u8D71\u8D73\u8D81\u8D99\u8DC2\u8DBE\u8DBA\u8DCF\u8DDA\u8DD6\u8DCC\u8DDB\u8DCB\u8DEA\u8DEB\u8DDF\u8DE3\u8DFC\u8E08\u8E09\u8DFF\u8E1D\u8E1E\u8E10\u8E1F\u8E42\u8E35\u8E30\u8E34\u8E4A"],
      ["eda1", "\u8E47\u8E49\u8E4C\u8E50\u8E48\u8E59\u8E64\u8E60\u8E2A\u8E63\u8E55\u8E76\u8E72\u8E7C\u8E81\u8E87\u8E85\u8E84\u8E8B\u8E8A\u8E93\u8E91\u8E94\u8E99\u8EAA\u8EA1\u8EAC\u8EB0\u8EC6\u8EB1\u8EBE\u8EC5\u8EC8\u8ECB\u8EDB\u8EE3\u8EFC\u8EFB\u8EEB\u8EFE\u8F0A\u8F05\u8F15\u8F12\u8F19\u8F13\u8F1C\u8F1F\u8F1B\u8F0C\u8F26\u8F33\u8F3B\u8F39\u8F45\u8F42\u8F3E\u8F4C\u8F49\u8F46\u8F4E\u8F57\u8F5C\u8F62\u8F63\u8F64\u8F9C\u8F9F\u8FA3\u8FAD\u8FAF\u8FB7\u8FDA\u8FE5\u8FE2\u8FEA\u8FEF\u9087\u8FF4\u9005\u8FF9\u8FFA\u9011\u9015\u9021\u900D\u901E\u9016\u900B\u9027\u9036\u9035\u9039\u8FF8"],
      ["eea1", "\u904F\u9050\u9051\u9052\u900E\u9049\u903E\u9056\u9058\u905E\u9068\u906F\u9076\u96A8\u9072\u9082\u907D\u9081\u9080\u908A\u9089\u908F\u90A8\u90AF\u90B1\u90B5\u90E2\u90E4\u6248\u90DB\u9102\u9112\u9119\u9132\u9130\u914A\u9156\u9158\u9163\u9165\u9169\u9173\u9172\u918B\u9189\u9182\u91A2\u91AB\u91AF\u91AA\u91B5\u91B4\u91BA\u91C0\u91C1\u91C9\u91CB\u91D0\u91D6\u91DF\u91E1\u91DB\u91FC\u91F5\u91F6\u921E\u91FF\u9214\u922C\u9215\u9211\u925E\u9257\u9245\u9249\u9264\u9248\u9295\u923F\u924B\u9250\u929C\u9296\u9293\u929B\u925A\u92CF\u92B9\u92B7\u92E9\u930F\u92FA\u9344\u932E"],
      ["efa1", "\u9319\u9322\u931A\u9323\u933A\u9335\u933B\u935C\u9360\u937C\u936E\u9356\u93B0\u93AC\u93AD\u9394\u93B9\u93D6\u93D7\u93E8\u93E5\u93D8\u93C3\u93DD\u93D0\u93C8\u93E4\u941A\u9414\u9413\u9403\u9407\u9410\u9436\u942B\u9435\u9421\u943A\u9441\u9452\u9444\u945B\u9460\u9462\u945E\u946A\u9229\u9470\u9475\u9477\u947D\u945A\u947C\u947E\u9481\u947F\u9582\u9587\u958A\u9594\u9596\u9598\u9599\u95A0\u95A8\u95A7\u95AD\u95BC\u95BB\u95B9\u95BE\u95CA\u6FF6\u95C3\u95CD\u95CC\u95D5\u95D4\u95D6\u95DC\u95E1\u95E5\u95E2\u9621\u9628\u962E\u962F\u9642\u964C\u964F\u964B\u9677\u965C\u965E"],
      ["f0a1", "\u965D\u965F\u9666\u9672\u966C\u968D\u9698\u9695\u9697\u96AA\u96A7\u96B1\u96B2\u96B0\u96B4\u96B6\u96B8\u96B9\u96CE\u96CB\u96C9\u96CD\u894D\u96DC\u970D\u96D5\u96F9\u9704\u9706\u9708\u9713\u970E\u9711\u970F\u9716\u9719\u9724\u972A\u9730\u9739\u973D\u973E\u9744\u9746\u9748\u9742\u9749\u975C\u9760\u9764\u9766\u9768\u52D2\u976B\u9771\u9779\u9785\u977C\u9781\u977A\u9786\u978B\u978F\u9790\u979C\u97A8\u97A6\u97A3\u97B3\u97B4\u97C3\u97C6\u97C8\u97CB\u97DC\u97ED\u9F4F\u97F2\u7ADF\u97F6\u97F5\u980F\u980C\u9838\u9824\u9821\u9837\u983D\u9846\u984F\u984B\u986B\u986F\u9870"],
      ["f1a1", "\u9871\u9874\u9873\u98AA\u98AF\u98B1\u98B6\u98C4\u98C3\u98C6\u98E9\u98EB\u9903\u9909\u9912\u9914\u9918\u9921\u991D\u991E\u9924\u9920\u992C\u992E\u993D\u993E\u9942\u9949\u9945\u9950\u994B\u9951\u9952\u994C\u9955\u9997\u9998\u99A5\u99AD\u99AE\u99BC\u99DF\u99DB\u99DD\u99D8\u99D1\u99ED\u99EE\u99F1\u99F2\u99FB\u99F8\u9A01\u9A0F\u9A05\u99E2\u9A19\u9A2B\u9A37\u9A45\u9A42\u9A40\u9A43\u9A3E\u9A55\u9A4D\u9A5B\u9A57\u9A5F\u9A62\u9A65\u9A64\u9A69\u9A6B\u9A6A\u9AAD\u9AB0\u9ABC\u9AC0\u9ACF\u9AD1\u9AD3\u9AD4\u9ADE\u9ADF\u9AE2\u9AE3\u9AE6\u9AEF\u9AEB\u9AEE\u9AF4\u9AF1\u9AF7"],
      ["f2a1", "\u9AFB\u9B06\u9B18\u9B1A\u9B1F\u9B22\u9B23\u9B25\u9B27\u9B28\u9B29\u9B2A\u9B2E\u9B2F\u9B32\u9B44\u9B43\u9B4F\u9B4D\u9B4E\u9B51\u9B58\u9B74\u9B93\u9B83\u9B91\u9B96\u9B97\u9B9F\u9BA0\u9BA8\u9BB4\u9BC0\u9BCA\u9BB9\u9BC6\u9BCF\u9BD1\u9BD2\u9BE3\u9BE2\u9BE4\u9BD4\u9BE1\u9C3A\u9BF2\u9BF1\u9BF0\u9C15\u9C14\u9C09\u9C13\u9C0C\u9C06\u9C08\u9C12\u9C0A\u9C04\u9C2E\u9C1B\u9C25\u9C24\u9C21\u9C30\u9C47\u9C32\u9C46\u9C3E\u9C5A\u9C60\u9C67\u9C76\u9C78\u9CE7\u9CEC\u9CF0\u9D09\u9D08\u9CEB\u9D03\u9D06\u9D2A\u9D26\u9DAF\u9D23\u9D1F\u9D44\u9D15\u9D12\u9D41\u9D3F\u9D3E\u9D46\u9D48"],
      ["f3a1", "\u9D5D\u9D5E\u9D64\u9D51\u9D50\u9D59\u9D72\u9D89\u9D87\u9DAB\u9D6F\u9D7A\u9D9A\u9DA4\u9DA9\u9DB2\u9DC4\u9DC1\u9DBB\u9DB8\u9DBA\u9DC6\u9DCF\u9DC2\u9DD9\u9DD3\u9DF8\u9DE6\u9DED\u9DEF\u9DFD\u9E1A\u9E1B\u9E1E\u9E75\u9E79\u9E7D\u9E81\u9E88\u9E8B\u9E8C\u9E92\u9E95\u9E91\u9E9D\u9EA5\u9EA9\u9EB8\u9EAA\u9EAD\u9761\u9ECC\u9ECE\u9ECF\u9ED0\u9ED4\u9EDC\u9EDE\u9EDD\u9EE0\u9EE5\u9EE8\u9EEF\u9EF4\u9EF6\u9EF7\u9EF9\u9EFB\u9EFC\u9EFD\u9F07\u9F08\u76B7\u9F15\u9F21\u9F2C\u9F3E\u9F4A\u9F52\u9F54\u9F63\u9F5F\u9F60\u9F61\u9F66\u9F67\u9F6C\u9F6A\u9F77\u9F72\u9F76\u9F95\u9F9C\u9FA0"],
      ["f4a1", "\u582F\u69C7\u9059\u7464\u51DC\u7199"],
      ["f9a1", "\u7E8A\u891C\u9348\u9288\u84DC\u4FC9\u70BB\u6631\u68C8\u92F9\u66FB\u5F45\u4E28\u4EE1\u4EFC\u4F00\u4F03\u4F39\u4F56\u4F92\u4F8A\u4F9A\u4F94\u4FCD\u5040\u5022\u4FFF\u501E\u5046\u5070\u5042\u5094\u50F4\u50D8\u514A\u5164\u519D\u51BE\u51EC\u5215\u529C\u52A6\u52C0\u52DB\u5300\u5307\u5324\u5372\u5393\u53B2\u53DD\uFA0E\u549C\u548A\u54A9\u54FF\u5586\u5759\u5765\u57AC\u57C8\u57C7\uFA0F\uFA10\u589E\u58B2\u590B\u5953\u595B\u595D\u5963\u59A4\u59BA\u5B56\u5BC0\u752F\u5BD8\u5BEC\u5C1E\u5CA6\u5CBA\u5CF5\u5D27\u5D53\uFA11\u5D42\u5D6D\u5DB8\u5DB9\u5DD0\u5F21\u5F34\u5F67\u5FB7"],
      ["faa1", "\u5FDE\u605D\u6085\u608A\u60DE\u60D5\u6120\u60F2\u6111\u6137\u6130\u6198\u6213\u62A6\u63F5\u6460\u649D\u64CE\u654E\u6600\u6615\u663B\u6609\u662E\u661E\u6624\u6665\u6657\u6659\uFA12\u6673\u6699\u66A0\u66B2\u66BF\u66FA\u670E\uF929\u6766\u67BB\u6852\u67C0\u6801\u6844\u68CF\uFA13\u6968\uFA14\u6998\u69E2\u6A30\u6A6B\u6A46\u6A73\u6A7E\u6AE2\u6AE4\u6BD6\u6C3F\u6C5C\u6C86\u6C6F\u6CDA\u6D04\u6D87\u6D6F\u6D96\u6DAC\u6DCF\u6DF8\u6DF2\u6DFC\u6E39\u6E5C\u6E27\u6E3C\u6EBF\u6F88\u6FB5\u6FF5\u7005\u7007\u7028\u7085\u70AB\u710F\u7104\u715C\u7146\u7147\uFA15\u71C1\u71FE\u72B1"],
      ["fba1", "\u72BE\u7324\uFA16\u7377\u73BD\u73C9\u73D6\u73E3\u73D2\u7407\u73F5\u7426\u742A\u7429\u742E\u7462\u7489\u749F\u7501\u756F\u7682\u769C\u769E\u769B\u76A6\uFA17\u7746\u52AF\u7821\u784E\u7864\u787A\u7930\uFA18\uFA19\uFA1A\u7994\uFA1B\u799B\u7AD1\u7AE7\uFA1C\u7AEB\u7B9E\uFA1D\u7D48\u7D5C\u7DB7\u7DA0\u7DD6\u7E52\u7F47\u7FA1\uFA1E\u8301\u8362\u837F\u83C7\u83F6\u8448\u84B4\u8553\u8559\u856B\uFA1F\u85B0\uFA20\uFA21\u8807\u88F5\u8A12\u8A37\u8A79\u8AA7\u8ABE\u8ADF\uFA22\u8AF6\u8B53\u8B7F\u8CF0\u8CF4\u8D12\u8D76\uFA23\u8ECF\uFA24\uFA25\u9067\u90DE\uFA26\u9115\u9127\u91DA"],
      ["fca1", "\u91D7\u91DE\u91ED\u91EE\u91E4\u91E5\u9206\u9210\u920A\u923A\u9240\u923C\u924E\u9259\u9251\u9239\u9267\u92A7\u9277\u9278\u92E7\u92D7\u92D9\u92D0\uFA27\u92D5\u92E0\u92D3\u9325\u9321\u92FB\uFA28\u931E\u92FF\u931D\u9302\u9370\u9357\u93A4\u93C6\u93DE\u93F8\u9431\u9445\u9448\u9592\uF9DC\uFA29\u969D\u96AF\u9733\u973B\u9743\u974D\u974F\u9751\u9755\u9857\u9865\uFA2A\uFA2B\u9927\uFA2C\u999E\u9A4E\u9AD9\u9ADC\u9B75\u9B72\u9B8F\u9BB1\u9BBB\u9C00\u9D70\u9D6B\uFA2D\u9E19\u9ED1"],
      ["fcf1", "\u2170", 9, "\uFFE2\uFFE4\uFF07\uFF02"],
      ["8fa2af", "\u02D8\u02C7\xB8\u02D9\u02DD\xAF\u02DB\u02DA\uFF5E\u0384\u0385"],
      ["8fa2c2", "\xA1\xA6\xBF"],
      ["8fa2eb", "\xBA\xAA\xA9\xAE\u2122\xA4\u2116"],
      ["8fa6e1", "\u0386\u0388\u0389\u038A\u03AA"],
      ["8fa6e7", "\u038C"],
      ["8fa6e9", "\u038E\u03AB"],
      ["8fa6ec", "\u038F"],
      ["8fa6f1", "\u03AC\u03AD\u03AE\u03AF\u03CA\u0390\u03CC\u03C2\u03CD\u03CB\u03B0\u03CE"],
      ["8fa7c2", "\u0402", 10, "\u040E\u040F"],
      ["8fa7f2", "\u0452", 10, "\u045E\u045F"],
      ["8fa9a1", "\xC6\u0110"],
      ["8fa9a4", "\u0126"],
      ["8fa9a6", "\u0132"],
      ["8fa9a8", "\u0141\u013F"],
      ["8fa9ab", "\u014A\xD8\u0152"],
      ["8fa9af", "\u0166\xDE"],
      ["8fa9c1", "\xE6\u0111\xF0\u0127\u0131\u0133\u0138\u0142\u0140\u0149\u014B\xF8\u0153\xDF\u0167\xFE"],
      ["8faaa1", "\xC1\xC0\xC4\xC2\u0102\u01CD\u0100\u0104\xC5\xC3\u0106\u0108\u010C\xC7\u010A\u010E\xC9\xC8\xCB\xCA\u011A\u0116\u0112\u0118"],
      ["8faaba", "\u011C\u011E\u0122\u0120\u0124\xCD\xCC\xCF\xCE\u01CF\u0130\u012A\u012E\u0128\u0134\u0136\u0139\u013D\u013B\u0143\u0147\u0145\xD1\xD3\xD2\xD6\xD4\u01D1\u0150\u014C\xD5\u0154\u0158\u0156\u015A\u015C\u0160\u015E\u0164\u0162\xDA\xD9\xDC\xDB\u016C\u01D3\u0170\u016A\u0172\u016E\u0168\u01D7\u01DB\u01D9\u01D5\u0174\xDD\u0178\u0176\u0179\u017D\u017B"],
      ["8faba1", "\xE1\xE0\xE4\xE2\u0103\u01CE\u0101\u0105\xE5\xE3\u0107\u0109\u010D\xE7\u010B\u010F\xE9\xE8\xEB\xEA\u011B\u0117\u0113\u0119\u01F5\u011D\u011F"],
      ["8fabbd", "\u0121\u0125\xED\xEC\xEF\xEE\u01D0"],
      ["8fabc5", "\u012B\u012F\u0129\u0135\u0137\u013A\u013E\u013C\u0144\u0148\u0146\xF1\xF3\xF2\xF6\xF4\u01D2\u0151\u014D\xF5\u0155\u0159\u0157\u015B\u015D\u0161\u015F\u0165\u0163\xFA\xF9\xFC\xFB\u016D\u01D4\u0171\u016B\u0173\u016F\u0169\u01D8\u01DC\u01DA\u01D6\u0175\xFD\xFF\u0177\u017A\u017E\u017C"],
      ["8fb0a1", "\u4E02\u4E04\u4E05\u4E0C\u4E12\u4E1F\u4E23\u4E24\u4E28\u4E2B\u4E2E\u4E2F\u4E30\u4E35\u4E40\u4E41\u4E44\u4E47\u4E51\u4E5A\u4E5C\u4E63\u4E68\u4E69\u4E74\u4E75\u4E79\u4E7F\u4E8D\u4E96\u4E97\u4E9D\u4EAF\u4EB9\u4EC3\u4ED0\u4EDA\u4EDB\u4EE0\u4EE1\u4EE2\u4EE8\u4EEF\u4EF1\u4EF3\u4EF5\u4EFD\u4EFE\u4EFF\u4F00\u4F02\u4F03\u4F08\u4F0B\u4F0C\u4F12\u4F15\u4F16\u4F17\u4F19\u4F2E\u4F31\u4F60\u4F33\u4F35\u4F37\u4F39\u4F3B\u4F3E\u4F40\u4F42\u4F48\u4F49\u4F4B\u4F4C\u4F52\u4F54\u4F56\u4F58\u4F5F\u4F63\u4F6A\u4F6C\u4F6E\u4F71\u4F77\u4F78\u4F79\u4F7A\u4F7D\u4F7E\u4F81\u4F82\u4F84"],
      ["8fb1a1", "\u4F85\u4F89\u4F8A\u4F8C\u4F8E\u4F90\u4F92\u4F93\u4F94\u4F97\u4F99\u4F9A\u4F9E\u4F9F\u4FB2\u4FB7\u4FB9\u4FBB\u4FBC\u4FBD\u4FBE\u4FC0\u4FC1\u4FC5\u4FC6\u4FC8\u4FC9\u4FCB\u4FCC\u4FCD\u4FCF\u4FD2\u4FDC\u4FE0\u4FE2\u4FF0\u4FF2\u4FFC\u4FFD\u4FFF\u5000\u5001\u5004\u5007\u500A\u500C\u500E\u5010\u5013\u5017\u5018\u501B\u501C\u501D\u501E\u5022\u5027\u502E\u5030\u5032\u5033\u5035\u5040\u5041\u5042\u5045\u5046\u504A\u504C\u504E\u5051\u5052\u5053\u5057\u5059\u505F\u5060\u5062\u5063\u5066\u5067\u506A\u506D\u5070\u5071\u503B\u5081\u5083\u5084\u5086\u508A\u508E\u508F\u5090"],
      ["8fb2a1", "\u5092\u5093\u5094\u5096\u509B\u509C\u509E", 4, "\u50AA\u50AF\u50B0\u50B9\u50BA\u50BD\u50C0\u50C3\u50C4\u50C7\u50CC\u50CE\u50D0\u50D3\u50D4\u50D8\u50DC\u50DD\u50DF\u50E2\u50E4\u50E6\u50E8\u50E9\u50EF\u50F1\u50F6\u50FA\u50FE\u5103\u5106\u5107\u5108\u510B\u510C\u510D\u510E\u50F2\u5110\u5117\u5119\u511B\u511C\u511D\u511E\u5123\u5127\u5128\u512C\u512D\u512F\u5131\u5133\u5134\u5135\u5138\u5139\u5142\u514A\u514F\u5153\u5155\u5157\u5158\u515F\u5164\u5166\u517E\u5183\u5184\u518B\u518E\u5198\u519D\u51A1\u51A3\u51AD\u51B8\u51BA\u51BC\u51BE\u51BF\u51C2"],
      ["8fb3a1", "\u51C8\u51CF\u51D1\u51D2\u51D3\u51D5\u51D8\u51DE\u51E2\u51E5\u51EE\u51F2\u51F3\u51F4\u51F7\u5201\u5202\u5205\u5212\u5213\u5215\u5216\u5218\u5222\u5228\u5231\u5232\u5235\u523C\u5245\u5249\u5255\u5257\u5258\u525A\u525C\u525F\u5260\u5261\u5266\u526E\u5277\u5278\u5279\u5280\u5282\u5285\u528A\u528C\u5293\u5295\u5296\u5297\u5298\u529A\u529C\u52A4\u52A5\u52A6\u52A7\u52AF\u52B0\u52B6\u52B7\u52B8\u52BA\u52BB\u52BD\u52C0\u52C4\u52C6\u52C8\u52CC\u52CF\u52D1\u52D4\u52D6\u52DB\u52DC\u52E1\u52E5\u52E8\u52E9\u52EA\u52EC\u52F0\u52F1\u52F4\u52F6\u52F7\u5300\u5303\u530A\u530B"],
      ["8fb4a1", "\u530C\u5311\u5313\u5318\u531B\u531C\u531E\u531F\u5325\u5327\u5328\u5329\u532B\u532C\u532D\u5330\u5332\u5335\u533C\u533D\u533E\u5342\u534C\u534B\u5359\u535B\u5361\u5363\u5365\u536C\u536D\u5372\u5379\u537E\u5383\u5387\u5388\u538E\u5393\u5394\u5399\u539D\u53A1\u53A4\u53AA\u53AB\u53AF\u53B2\u53B4\u53B5\u53B7\u53B8\u53BA\u53BD\u53C0\u53C5\u53CF\u53D2\u53D3\u53D5\u53DA\u53DD\u53DE\u53E0\u53E6\u53E7\u53F5\u5402\u5413\u541A\u5421\u5427\u5428\u542A\u542F\u5431\u5434\u5435\u5443\u5444\u5447\u544D\u544F\u545E\u5462\u5464\u5466\u5467\u5469\u546B\u546D\u546E\u5474\u547F"],
      ["8fb5a1", "\u5481\u5483\u5485\u5488\u5489\u548D\u5491\u5495\u5496\u549C\u549F\u54A1\u54A6\u54A7\u54A9\u54AA\u54AD\u54AE\u54B1\u54B7\u54B9\u54BA\u54BB\u54BF\u54C6\u54CA\u54CD\u54CE\u54E0\u54EA\u54EC\u54EF\u54F6\u54FC\u54FE\u54FF\u5500\u5501\u5505\u5508\u5509\u550C\u550D\u550E\u5515\u552A\u552B\u5532\u5535\u5536\u553B\u553C\u553D\u5541\u5547\u5549\u554A\u554D\u5550\u5551\u5558\u555A\u555B\u555E\u5560\u5561\u5564\u5566\u557F\u5581\u5582\u5586\u5588\u558E\u558F\u5591\u5592\u5593\u5594\u5597\u55A3\u55A4\u55AD\u55B2\u55BF\u55C1\u55C3\u55C6\u55C9\u55CB\u55CC\u55CE\u55D1\u55D2"],
      ["8fb6a1", "\u55D3\u55D7\u55D8\u55DB\u55DE\u55E2\u55E9\u55F6\u55FF\u5605\u5608\u560A\u560D", 5, "\u5619\u562C\u5630\u5633\u5635\u5637\u5639\u563B\u563C\u563D\u563F\u5640\u5641\u5643\u5644\u5646\u5649\u564B\u564D\u564F\u5654\u565E\u5660\u5661\u5662\u5663\u5666\u5669\u566D\u566F\u5671\u5672\u5675\u5684\u5685\u5688\u568B\u568C\u5695\u5699\u569A\u569D\u569E\u569F\u56A6\u56A7\u56A8\u56A9\u56AB\u56AC\u56AD\u56B1\u56B3\u56B7\u56BE\u56C5\u56C9\u56CA\u56CB\u56CF\u56D0\u56CC\u56CD\u56D9\u56DC\u56DD\u56DF\u56E1\u56E4", 4, "\u56F1\u56EB\u56ED"],
      ["8fb7a1", "\u56F6\u56F7\u5701\u5702\u5707\u570A\u570C\u5711\u5715\u571A\u571B\u571D\u5720\u5722\u5723\u5724\u5725\u5729\u572A\u572C\u572E\u572F\u5733\u5734\u573D\u573E\u573F\u5745\u5746\u574C\u574D\u5752\u5762\u5765\u5767\u5768\u576B\u576D", 4, "\u5773\u5774\u5775\u5777\u5779\u577A\u577B\u577C\u577E\u5781\u5783\u578C\u5794\u5797\u5799\u579A\u579C\u579D\u579E\u579F\u57A1\u5795\u57A7\u57A8\u57A9\u57AC\u57B8\u57BD\u57C7\u57C8\u57CC\u57CF\u57D5\u57DD\u57DE\u57E4\u57E6\u57E7\u57E9\u57ED\u57F0\u57F5\u57F6\u57F8\u57FD\u57FE\u57FF\u5803\u5804\u5808\u5809\u57E1"],
      ["8fb8a1", "\u580C\u580D\u581B\u581E\u581F\u5820\u5826\u5827\u582D\u5832\u5839\u583F\u5849\u584C\u584D\u584F\u5850\u5855\u585F\u5861\u5864\u5867\u5868\u5878\u587C\u587F\u5880\u5881\u5887\u5888\u5889\u588A\u588C\u588D\u588F\u5890\u5894\u5896\u589D\u58A0\u58A1\u58A2\u58A6\u58A9\u58B1\u58B2\u58C4\u58BC\u58C2\u58C8\u58CD\u58CE\u58D0\u58D2\u58D4\u58D6\u58DA\u58DD\u58E1\u58E2\u58E9\u58F3\u5905\u5906\u590B\u590C\u5912\u5913\u5914\u8641\u591D\u5921\u5923\u5924\u5928\u592F\u5930\u5933\u5935\u5936\u593F\u5943\u5946\u5952\u5953\u5959\u595B\u595D\u595E\u595F\u5961\u5963\u596B\u596D"],
      ["8fb9a1", "\u596F\u5972\u5975\u5976\u5979\u597B\u597C\u598B\u598C\u598E\u5992\u5995\u5997\u599F\u59A4\u59A7\u59AD\u59AE\u59AF\u59B0\u59B3\u59B7\u59BA\u59BC\u59C1\u59C3\u59C4\u59C8\u59CA\u59CD\u59D2\u59DD\u59DE\u59DF\u59E3\u59E4\u59E7\u59EE\u59EF\u59F1\u59F2\u59F4\u59F7\u5A00\u5A04\u5A0C\u5A0D\u5A0E\u5A12\u5A13\u5A1E\u5A23\u5A24\u5A27\u5A28\u5A2A\u5A2D\u5A30\u5A44\u5A45\u5A47\u5A48\u5A4C\u5A50\u5A55\u5A5E\u5A63\u5A65\u5A67\u5A6D\u5A77\u5A7A\u5A7B\u5A7E\u5A8B\u5A90\u5A93\u5A96\u5A99\u5A9C\u5A9E\u5A9F\u5AA0\u5AA2\u5AA7\u5AAC\u5AB1\u5AB2\u5AB3\u5AB5\u5AB8\u5ABA\u5ABB\u5ABF"],
      ["8fbaa1", "\u5AC4\u5AC6\u5AC8\u5ACF\u5ADA\u5ADC\u5AE0\u5AE5\u5AEA\u5AEE\u5AF5\u5AF6\u5AFD\u5B00\u5B01\u5B08\u5B17\u5B34\u5B19\u5B1B\u5B1D\u5B21\u5B25\u5B2D\u5B38\u5B41\u5B4B\u5B4C\u5B52\u5B56\u5B5E\u5B68\u5B6E\u5B6F\u5B7C\u5B7D\u5B7E\u5B7F\u5B81\u5B84\u5B86\u5B8A\u5B8E\u5B90\u5B91\u5B93\u5B94\u5B96\u5BA8\u5BA9\u5BAC\u5BAD\u5BAF\u5BB1\u5BB2\u5BB7\u5BBA\u5BBC\u5BC0\u5BC1\u5BCD\u5BCF\u5BD6", 4, "\u5BE0\u5BEF\u5BF1\u5BF4\u5BFD\u5C0C\u5C17\u5C1E\u5C1F\u5C23\u5C26\u5C29\u5C2B\u5C2C\u5C2E\u5C30\u5C32\u5C35\u5C36\u5C59\u5C5A\u5C5C\u5C62\u5C63\u5C67\u5C68\u5C69"],
      ["8fbba1", "\u5C6D\u5C70\u5C74\u5C75\u5C7A\u5C7B\u5C7C\u5C7D\u5C87\u5C88\u5C8A\u5C8F\u5C92\u5C9D\u5C9F\u5CA0\u5CA2\u5CA3\u5CA6\u5CAA\u5CB2\u5CB4\u5CB5\u5CBA\u5CC9\u5CCB\u5CD2\u5CDD\u5CD7\u5CEE\u5CF1\u5CF2\u5CF4\u5D01\u5D06\u5D0D\u5D12\u5D2B\u5D23\u5D24\u5D26\u5D27\u5D31\u5D34\u5D39\u5D3D\u5D3F\u5D42\u5D43\u5D46\u5D48\u5D55\u5D51\u5D59\u5D4A\u5D5F\u5D60\u5D61\u5D62\u5D64\u5D6A\u5D6D\u5D70\u5D79\u5D7A\u5D7E\u5D7F\u5D81\u5D83\u5D88\u5D8A\u5D92\u5D93\u5D94\u5D95\u5D99\u5D9B\u5D9F\u5DA0\u5DA7\u5DAB\u5DB0\u5DB4\u5DB8\u5DB9\u5DC3\u5DC7\u5DCB\u5DD0\u5DCE\u5DD8\u5DD9\u5DE0\u5DE4"],
      ["8fbca1", "\u5DE9\u5DF8\u5DF9\u5E00\u5E07\u5E0D\u5E12\u5E14\u5E15\u5E18\u5E1F\u5E20\u5E2E\u5E28\u5E32\u5E35\u5E3E\u5E4B\u5E50\u5E49\u5E51\u5E56\u5E58\u5E5B\u5E5C\u5E5E\u5E68\u5E6A", 4, "\u5E70\u5E80\u5E8B\u5E8E\u5EA2\u5EA4\u5EA5\u5EA8\u5EAA\u5EAC\u5EB1\u5EB3\u5EBD\u5EBE\u5EBF\u5EC6\u5ECC\u5ECB\u5ECE\u5ED1\u5ED2\u5ED4\u5ED5\u5EDC\u5EDE\u5EE5\u5EEB\u5F02\u5F06\u5F07\u5F08\u5F0E\u5F19\u5F1C\u5F1D\u5F21\u5F22\u5F23\u5F24\u5F28\u5F2B\u5F2C\u5F2E\u5F30\u5F34\u5F36\u5F3B\u5F3D\u5F3F\u5F40\u5F44\u5F45\u5F47\u5F4D\u5F50\u5F54\u5F58\u5F5B\u5F60\u5F63\u5F64\u5F67"],
      ["8fbda1", "\u5F6F\u5F72\u5F74\u5F75\u5F78\u5F7A\u5F7D\u5F7E\u5F89\u5F8D\u5F8F\u5F96\u5F9C\u5F9D\u5FA2\u5FA7\u5FAB\u5FA4\u5FAC\u5FAF\u5FB0\u5FB1\u5FB8\u5FC4\u5FC7\u5FC8\u5FC9\u5FCB\u5FD0", 4, "\u5FDE\u5FE1\u5FE2\u5FE8\u5FE9\u5FEA\u5FEC\u5FED\u5FEE\u5FEF\u5FF2\u5FF3\u5FF6\u5FFA\u5FFC\u6007\u600A\u600D\u6013\u6014\u6017\u6018\u601A\u601F\u6024\u602D\u6033\u6035\u6040\u6047\u6048\u6049\u604C\u6051\u6054\u6056\u6057\u605D\u6061\u6067\u6071\u607E\u607F\u6082\u6086\u6088\u608A\u608E\u6091\u6093\u6095\u6098\u609D\u609E\u60A2\u60A4\u60A5\u60A8\u60B0\u60B1\u60B7"],
      ["8fbea1", "\u60BB\u60BE\u60C2\u60C4\u60C8\u60C9\u60CA\u60CB\u60CE\u60CF\u60D4\u60D5\u60D9\u60DB\u60DD\u60DE\u60E2\u60E5\u60F2\u60F5\u60F8\u60FC\u60FD\u6102\u6107\u610A\u610C\u6110", 4, "\u6116\u6117\u6119\u611C\u611E\u6122\u612A\u612B\u6130\u6131\u6135\u6136\u6137\u6139\u6141\u6145\u6146\u6149\u615E\u6160\u616C\u6172\u6178\u617B\u617C\u617F\u6180\u6181\u6183\u6184\u618B\u618D\u6192\u6193\u6197\u6198\u619C\u619D\u619F\u61A0\u61A5\u61A8\u61AA\u61AD\u61B8\u61B9\u61BC\u61C0\u61C1\u61C2\u61CE\u61CF\u61D5\u61DC\u61DD\u61DE\u61DF\u61E1\u61E2\u61E7\u61E9\u61E5"],
      ["8fbfa1", "\u61EC\u61ED\u61EF\u6201\u6203\u6204\u6207\u6213\u6215\u621C\u6220\u6222\u6223\u6227\u6229\u622B\u6239\u623D\u6242\u6243\u6244\u6246\u624C\u6250\u6251\u6252\u6254\u6256\u625A\u625C\u6264\u626D\u626F\u6273\u627A\u627D\u628D\u628E\u628F\u6290\u62A6\u62A8\u62B3\u62B6\u62B7\u62BA\u62BE\u62BF\u62C4\u62CE\u62D5\u62D6\u62DA\u62EA\u62F2\u62F4\u62FC\u62FD\u6303\u6304\u630A\u630B\u630D\u6310\u6313\u6316\u6318\u6329\u632A\u632D\u6335\u6336\u6339\u633C\u6341\u6342\u6343\u6344\u6346\u634A\u634B\u634E\u6352\u6353\u6354\u6358\u635B\u6365\u6366\u636C\u636D\u6371\u6374\u6375"],
      ["8fc0a1", "\u6378\u637C\u637D\u637F\u6382\u6384\u6387\u638A\u6390\u6394\u6395\u6399\u639A\u639E\u63A4\u63A6\u63AD\u63AE\u63AF\u63BD\u63C1\u63C5\u63C8\u63CE\u63D1\u63D3\u63D4\u63D5\u63DC\u63E0\u63E5\u63EA\u63EC\u63F2\u63F3\u63F5\u63F8\u63F9\u6409\u640A\u6410\u6412\u6414\u6418\u641E\u6420\u6422\u6424\u6425\u6429\u642A\u642F\u6430\u6435\u643D\u643F\u644B\u644F\u6451\u6452\u6453\u6454\u645A\u645B\u645C\u645D\u645F\u6460\u6461\u6463\u646D\u6473\u6474\u647B\u647D\u6485\u6487\u648F\u6490\u6491\u6498\u6499\u649B\u649D\u649F\u64A1\u64A3\u64A6\u64A8\u64AC\u64B3\u64BD\u64BE\u64BF"],
      ["8fc1a1", "\u64C4\u64C9\u64CA\u64CB\u64CC\u64CE\u64D0\u64D1\u64D5\u64D7\u64E4\u64E5\u64E9\u64EA\u64ED\u64F0\u64F5\u64F7\u64FB\u64FF\u6501\u6504\u6508\u6509\u650A\u650F\u6513\u6514\u6516\u6519\u651B\u651E\u651F\u6522\u6526\u6529\u652E\u6531\u653A\u653C\u653D\u6543\u6547\u6549\u6550\u6552\u6554\u655F\u6560\u6567\u656B\u657A\u657D\u6581\u6585\u658A\u6592\u6595\u6598\u659D\u65A0\u65A3\u65A6\u65AE\u65B2\u65B3\u65B4\u65BF\u65C2\u65C8\u65C9\u65CE\u65D0\u65D4\u65D6\u65D8\u65DF\u65F0\u65F2\u65F4\u65F5\u65F9\u65FE\u65FF\u6600\u6604\u6608\u6609\u660D\u6611\u6612\u6615\u6616\u661D"],
      ["8fc2a1", "\u661E\u6621\u6622\u6623\u6624\u6626\u6629\u662A\u662B\u662C\u662E\u6630\u6631\u6633\u6639\u6637\u6640\u6645\u6646\u664A\u664C\u6651\u664E\u6657\u6658\u6659\u665B\u665C\u6660\u6661\u66FB\u666A\u666B\u666C\u667E\u6673\u6675\u667F\u6677\u6678\u6679\u667B\u6680\u667C\u668B\u668C\u668D\u6690\u6692\u6699\u669A\u669B\u669C\u669F\u66A0\u66A4\u66AD\u66B1\u66B2\u66B5\u66BB\u66BF\u66C0\u66C2\u66C3\u66C8\u66CC\u66CE\u66CF\u66D4\u66DB\u66DF\u66E8\u66EB\u66EC\u66EE\u66FA\u6705\u6707\u670E\u6713\u6719\u671C\u6720\u6722\u6733\u673E\u6745\u6747\u6748\u674C\u6754\u6755\u675D"],
      ["8fc3a1", "\u6766\u676C\u676E\u6774\u6776\u677B\u6781\u6784\u678E\u678F\u6791\u6793\u6796\u6798\u6799\u679B\u67B0\u67B1\u67B2\u67B5\u67BB\u67BC\u67BD\u67F9\u67C0\u67C2\u67C3\u67C5\u67C8\u67C9\u67D2\u67D7\u67D9\u67DC\u67E1\u67E6\u67F0\u67F2\u67F6\u67F7\u6852\u6814\u6819\u681D\u681F\u6828\u6827\u682C\u682D\u682F\u6830\u6831\u6833\u683B\u683F\u6844\u6845\u684A\u684C\u6855\u6857\u6858\u685B\u686B\u686E", 4, "\u6875\u6879\u687A\u687B\u687C\u6882\u6884\u6886\u6888\u6896\u6898\u689A\u689C\u68A1\u68A3\u68A5\u68A9\u68AA\u68AE\u68B2\u68BB\u68C5\u68C8\u68CC\u68CF"],
      ["8fc4a1", "\u68D0\u68D1\u68D3\u68D6\u68D9\u68DC\u68DD\u68E5\u68E8\u68EA\u68EB\u68EC\u68ED\u68F0\u68F1\u68F5\u68F6\u68FB\u68FC\u68FD\u6906\u6909\u690A\u6910\u6911\u6913\u6916\u6917\u6931\u6933\u6935\u6938\u693B\u6942\u6945\u6949\u694E\u6957\u695B\u6963\u6964\u6965\u6966\u6968\u6969\u696C\u6970\u6971\u6972\u697A\u697B\u697F\u6980\u698D\u6992\u6996\u6998\u69A1\u69A5\u69A6\u69A8\u69AB\u69AD\u69AF\u69B7\u69B8\u69BA\u69BC\u69C5\u69C8\u69D1\u69D6\u69D7\u69E2\u69E5\u69EE\u69EF\u69F1\u69F3\u69F5\u69FE\u6A00\u6A01\u6A03\u6A0F\u6A11\u6A15\u6A1A\u6A1D\u6A20\u6A24\u6A28\u6A30\u6A32"],
      ["8fc5a1", "\u6A34\u6A37\u6A3B\u6A3E\u6A3F\u6A45\u6A46\u6A49\u6A4A\u6A4E\u6A50\u6A51\u6A52\u6A55\u6A56\u6A5B\u6A64\u6A67\u6A6A\u6A71\u6A73\u6A7E\u6A81\u6A83\u6A86\u6A87\u6A89\u6A8B\u6A91\u6A9B\u6A9D\u6A9E\u6A9F\u6AA5\u6AAB\u6AAF\u6AB0\u6AB1\u6AB4\u6ABD\u6ABE\u6ABF\u6AC6\u6AC9\u6AC8\u6ACC\u6AD0\u6AD4\u6AD5\u6AD6\u6ADC\u6ADD\u6AE4\u6AE7\u6AEC\u6AF0\u6AF1\u6AF2\u6AFC\u6AFD\u6B02\u6B03\u6B06\u6B07\u6B09\u6B0F\u6B10\u6B11\u6B17\u6B1B\u6B1E\u6B24\u6B28\u6B2B\u6B2C\u6B2F\u6B35\u6B36\u6B3B\u6B3F\u6B46\u6B4A\u6B4D\u6B52\u6B56\u6B58\u6B5D\u6B60\u6B67\u6B6B\u6B6E\u6B70\u6B75\u6B7D"],
      ["8fc6a1", "\u6B7E\u6B82\u6B85\u6B97\u6B9B\u6B9F\u6BA0\u6BA2\u6BA3\u6BA8\u6BA9\u6BAC\u6BAD\u6BAE\u6BB0\u6BB8\u6BB9\u6BBD\u6BBE\u6BC3\u6BC4\u6BC9\u6BCC\u6BD6\u6BDA\u6BE1\u6BE3\u6BE6\u6BE7\u6BEE\u6BF1\u6BF7\u6BF9\u6BFF\u6C02\u6C04\u6C05\u6C09\u6C0D\u6C0E\u6C10\u6C12\u6C19\u6C1F\u6C26\u6C27\u6C28\u6C2C\u6C2E\u6C33\u6C35\u6C36\u6C3A\u6C3B\u6C3F\u6C4A\u6C4B\u6C4D\u6C4F\u6C52\u6C54\u6C59\u6C5B\u6C5C\u6C6B\u6C6D\u6C6F\u6C74\u6C76\u6C78\u6C79\u6C7B\u6C85\u6C86\u6C87\u6C89\u6C94\u6C95\u6C97\u6C98\u6C9C\u6C9F\u6CB0\u6CB2\u6CB4\u6CC2\u6CC6\u6CCD\u6CCF\u6CD0\u6CD1\u6CD2\u6CD4\u6CD6"],
      ["8fc7a1", "\u6CDA\u6CDC\u6CE0\u6CE7\u6CE9\u6CEB\u6CEC\u6CEE\u6CF2\u6CF4\u6D04\u6D07\u6D0A\u6D0E\u6D0F\u6D11\u6D13\u6D1A\u6D26\u6D27\u6D28\u6C67\u6D2E\u6D2F\u6D31\u6D39\u6D3C\u6D3F\u6D57\u6D5E\u6D5F\u6D61\u6D65\u6D67\u6D6F\u6D70\u6D7C\u6D82\u6D87\u6D91\u6D92\u6D94\u6D96\u6D97\u6D98\u6DAA\u6DAC\u6DB4\u6DB7\u6DB9\u6DBD\u6DBF\u6DC4\u6DC8\u6DCA\u6DCE\u6DCF\u6DD6\u6DDB\u6DDD\u6DDF\u6DE0\u6DE2\u6DE5\u6DE9\u6DEF\u6DF0\u6DF4\u6DF6\u6DFC\u6E00\u6E04\u6E1E\u6E22\u6E27\u6E32\u6E36\u6E39\u6E3B\u6E3C\u6E44\u6E45\u6E48\u6E49\u6E4B\u6E4F\u6E51\u6E52\u6E53\u6E54\u6E57\u6E5C\u6E5D\u6E5E"],
      ["8fc8a1", "\u6E62\u6E63\u6E68\u6E73\u6E7B\u6E7D\u6E8D\u6E93\u6E99\u6EA0\u6EA7\u6EAD\u6EAE\u6EB1\u6EB3\u6EBB\u6EBF\u6EC0\u6EC1\u6EC3\u6EC7\u6EC8\u6ECA\u6ECD\u6ECE\u6ECF\u6EEB\u6EED\u6EEE\u6EF9\u6EFB\u6EFD\u6F04\u6F08\u6F0A\u6F0C\u6F0D\u6F16\u6F18\u6F1A\u6F1B\u6F26\u6F29\u6F2A\u6F2F\u6F30\u6F33\u6F36\u6F3B\u6F3C\u6F2D\u6F4F\u6F51\u6F52\u6F53\u6F57\u6F59\u6F5A\u6F5D\u6F5E\u6F61\u6F62\u6F68\u6F6C\u6F7D\u6F7E\u6F83\u6F87\u6F88\u6F8B\u6F8C\u6F8D\u6F90\u6F92\u6F93\u6F94\u6F96\u6F9A\u6F9F\u6FA0\u6FA5\u6FA6\u6FA7\u6FA8\u6FAE\u6FAF\u6FB0\u6FB5\u6FB6\u6FBC\u6FC5\u6FC7\u6FC8\u6FCA"],
      ["8fc9a1", "\u6FDA\u6FDE\u6FE8\u6FE9\u6FF0\u6FF5\u6FF9\u6FFC\u6FFD\u7000\u7005\u7006\u7007\u700D\u7017\u7020\u7023\u702F\u7034\u7037\u7039\u703C\u7043\u7044\u7048\u7049\u704A\u704B\u7054\u7055\u705D\u705E\u704E\u7064\u7065\u706C\u706E\u7075\u7076\u707E\u7081\u7085\u7086\u7094", 4, "\u709B\u70A4\u70AB\u70B0\u70B1\u70B4\u70B7\u70CA\u70D1\u70D3\u70D4\u70D5\u70D6\u70D8\u70DC\u70E4\u70FA\u7103", 4, "\u710B\u710C\u710F\u711E\u7120\u712B\u712D\u712F\u7130\u7131\u7138\u7141\u7145\u7146\u7147\u714A\u714B\u7150\u7152\u7157\u715A\u715C\u715E\u7160"],
      ["8fcaa1", "\u7168\u7179\u7180\u7185\u7187\u718C\u7192\u719A\u719B\u71A0\u71A2\u71AF\u71B0\u71B2\u71B3\u71BA\u71BF\u71C0\u71C1\u71C4\u71CB\u71CC\u71D3\u71D6\u71D9\u71DA\u71DC\u71F8\u71FE\u7200\u7207\u7208\u7209\u7213\u7217\u721A\u721D\u721F\u7224\u722B\u722F\u7234\u7238\u7239\u7241\u7242\u7243\u7245\u724E\u724F\u7250\u7253\u7255\u7256\u725A\u725C\u725E\u7260\u7263\u7268\u726B\u726E\u726F\u7271\u7277\u7278\u727B\u727C\u727F\u7284\u7289\u728D\u728E\u7293\u729B\u72A8\u72AD\u72AE\u72B1\u72B4\u72BE\u72C1\u72C7\u72C9\u72CC\u72D5\u72D6\u72D8\u72DF\u72E5\u72F3\u72F4\u72FA\u72FB"],
      ["8fcba1", "\u72FE\u7302\u7304\u7305\u7307\u730B\u730D\u7312\u7313\u7318\u7319\u731E\u7322\u7324\u7327\u7328\u732C\u7331\u7332\u7335\u733A\u733B\u733D\u7343\u734D\u7350\u7352\u7356\u7358\u735D\u735E\u735F\u7360\u7366\u7367\u7369\u736B\u736C\u736E\u736F\u7371\u7377\u7379\u737C\u7380\u7381\u7383\u7385\u7386\u738E\u7390\u7393\u7395\u7397\u7398\u739C\u739E\u739F\u73A0\u73A2\u73A5\u73A6\u73AA\u73AB\u73AD\u73B5\u73B7\u73B9\u73BC\u73BD\u73BF\u73C5\u73C6\u73C9\u73CB\u73CC\u73CF\u73D2\u73D3\u73D6\u73D9\u73DD\u73E1\u73E3\u73E6\u73E7\u73E9\u73F4\u73F5\u73F7\u73F9\u73FA\u73FB\u73FD"],
      ["8fcca1", "\u73FF\u7400\u7401\u7404\u7407\u740A\u7411\u741A\u741B\u7424\u7426\u7428", 9, "\u7439\u7440\u7443\u7444\u7446\u7447\u744B\u744D\u7451\u7452\u7457\u745D\u7462\u7466\u7467\u7468\u746B\u746D\u746E\u7471\u7472\u7480\u7481\u7485\u7486\u7487\u7489\u748F\u7490\u7491\u7492\u7498\u7499\u749A\u749C\u749F\u74A0\u74A1\u74A3\u74A6\u74A8\u74A9\u74AA\u74AB\u74AE\u74AF\u74B1\u74B2\u74B5\u74B9\u74BB\u74BF\u74C8\u74C9\u74CC\u74D0\u74D3\u74D8\u74DA\u74DB\u74DE\u74DF\u74E4\u74E8\u74EA\u74EB\u74EF\u74F4\u74FA\u74FB\u74FC\u74FF\u7506"],
      ["8fcda1", "\u7512\u7516\u7517\u7520\u7521\u7524\u7527\u7529\u752A\u752F\u7536\u7539\u753D\u753E\u753F\u7540\u7543\u7547\u7548\u754E\u7550\u7552\u7557\u755E\u755F\u7561\u756F\u7571\u7579", 5, "\u7581\u7585\u7590\u7592\u7593\u7595\u7599\u759C\u75A2\u75A4\u75B4\u75BA\u75BF\u75C0\u75C1\u75C4\u75C6\u75CC\u75CE\u75CF\u75D7\u75DC\u75DF\u75E0\u75E1\u75E4\u75E7\u75EC\u75EE\u75EF\u75F1\u75F9\u7600\u7602\u7603\u7604\u7607\u7608\u760A\u760C\u760F\u7612\u7613\u7615\u7616\u7619\u761B\u761C\u761D\u761E\u7623\u7625\u7626\u7629\u762D\u7632\u7633\u7635\u7638\u7639"],
      ["8fcea1", "\u763A\u763C\u764A\u7640\u7641\u7643\u7644\u7645\u7649\u764B\u7655\u7659\u765F\u7664\u7665\u766D\u766E\u766F\u7671\u7674\u7681\u7685\u768C\u768D\u7695\u769B\u769C\u769D\u769F\u76A0\u76A2", 6, "\u76AA\u76AD\u76BD\u76C1\u76C5\u76C9\u76CB\u76CC\u76CE\u76D4\u76D9\u76E0\u76E6\u76E8\u76EC\u76F0\u76F1\u76F6\u76F9\u76FC\u7700\u7706\u770A\u770E\u7712\u7714\u7715\u7717\u7719\u771A\u771C\u7722\u7728\u772D\u772E\u772F\u7734\u7735\u7736\u7739\u773D\u773E\u7742\u7745\u7746\u774A\u774D\u774E\u774F\u7752\u7756\u7757\u775C\u775E\u775F\u7760\u7762"],
      ["8fcfa1", "\u7764\u7767\u776A\u776C\u7770\u7772\u7773\u7774\u777A\u777D\u7780\u7784\u778C\u778D\u7794\u7795\u7796\u779A\u779F\u77A2\u77A7\u77AA\u77AE\u77AF\u77B1\u77B5\u77BE\u77C3\u77C9\u77D1\u77D2\u77D5\u77D9\u77DE\u77DF\u77E0\u77E4\u77E6\u77EA\u77EC\u77F0\u77F1\u77F4\u77F8\u77FB\u7805\u7806\u7809\u780D\u780E\u7811\u781D\u7821\u7822\u7823\u782D\u782E\u7830\u7835\u7837\u7843\u7844\u7847\u7848\u784C\u784E\u7852\u785C\u785E\u7860\u7861\u7863\u7864\u7868\u786A\u786E\u787A\u787E\u788A\u788F\u7894\u7898\u78A1\u789D\u789E\u789F\u78A4\u78A8\u78AC\u78AD\u78B0\u78B1\u78B2\u78B3"],
      ["8fd0a1", "\u78BB\u78BD\u78BF\u78C7\u78C8\u78C9\u78CC\u78CE\u78D2\u78D3\u78D5\u78D6\u78E4\u78DB\u78DF\u78E0\u78E1\u78E6\u78EA\u78F2\u78F3\u7900\u78F6\u78F7\u78FA\u78FB\u78FF\u7906\u790C\u7910\u791A\u791C\u791E\u791F\u7920\u7925\u7927\u7929\u792D\u7931\u7934\u7935\u793B\u793D\u793F\u7944\u7945\u7946\u794A\u794B\u794F\u7951\u7954\u7958\u795B\u795C\u7967\u7969\u796B\u7972\u7979\u797B\u797C\u797E\u798B\u798C\u7991\u7993\u7994\u7995\u7996\u7998\u799B\u799C\u79A1\u79A8\u79A9\u79AB\u79AF\u79B1\u79B4\u79B8\u79BB\u79C2\u79C4\u79C7\u79C8\u79CA\u79CF\u79D4\u79D6\u79DA\u79DD\u79DE"],
      ["8fd1a1", "\u79E0\u79E2\u79E5\u79EA\u79EB\u79ED\u79F1\u79F8\u79FC\u7A02\u7A03\u7A07\u7A09\u7A0A\u7A0C\u7A11\u7A15\u7A1B\u7A1E\u7A21\u7A27\u7A2B\u7A2D\u7A2F\u7A30\u7A34\u7A35\u7A38\u7A39\u7A3A\u7A44\u7A45\u7A47\u7A48\u7A4C\u7A55\u7A56\u7A59\u7A5C\u7A5D\u7A5F\u7A60\u7A65\u7A67\u7A6A\u7A6D\u7A75\u7A78\u7A7E\u7A80\u7A82\u7A85\u7A86\u7A8A\u7A8B\u7A90\u7A91\u7A94\u7A9E\u7AA0\u7AA3\u7AAC\u7AB3\u7AB5\u7AB9\u7ABB\u7ABC\u7AC6\u7AC9\u7ACC\u7ACE\u7AD1\u7ADB\u7AE8\u7AE9\u7AEB\u7AEC\u7AF1\u7AF4\u7AFB\u7AFD\u7AFE\u7B07\u7B14\u7B1F\u7B23\u7B27\u7B29\u7B2A\u7B2B\u7B2D\u7B2E\u7B2F\u7B30"],
      ["8fd2a1", "\u7B31\u7B34\u7B3D\u7B3F\u7B40\u7B41\u7B47\u7B4E\u7B55\u7B60\u7B64\u7B66\u7B69\u7B6A\u7B6D\u7B6F\u7B72\u7B73\u7B77\u7B84\u7B89\u7B8E\u7B90\u7B91\u7B96\u7B9B\u7B9E\u7BA0\u7BA5\u7BAC\u7BAF\u7BB0\u7BB2\u7BB5\u7BB6\u7BBA\u7BBB\u7BBC\u7BBD\u7BC2\u7BC5\u7BC8\u7BCA\u7BD4\u7BD6\u7BD7\u7BD9\u7BDA\u7BDB\u7BE8\u7BEA\u7BF2\u7BF4\u7BF5\u7BF8\u7BF9\u7BFA\u7BFC\u7BFE\u7C01\u7C02\u7C03\u7C04\u7C06\u7C09\u7C0B\u7C0C\u7C0E\u7C0F\u7C19\u7C1B\u7C20\u7C25\u7C26\u7C28\u7C2C\u7C31\u7C33\u7C34\u7C36\u7C39\u7C3A\u7C46\u7C4A\u7C55\u7C51\u7C52\u7C53\u7C59", 5],
      ["8fd3a1", "\u7C61\u7C63\u7C67\u7C69\u7C6D\u7C6E\u7C70\u7C72\u7C79\u7C7C\u7C7D\u7C86\u7C87\u7C8F\u7C94\u7C9E\u7CA0\u7CA6\u7CB0\u7CB6\u7CB7\u7CBA\u7CBB\u7CBC\u7CBF\u7CC4\u7CC7\u7CC8\u7CC9\u7CCD\u7CCF\u7CD3\u7CD4\u7CD5\u7CD7\u7CD9\u7CDA\u7CDD\u7CE6\u7CE9\u7CEB\u7CF5\u7D03\u7D07\u7D08\u7D09\u7D0F\u7D11\u7D12\u7D13\u7D16\u7D1D\u7D1E\u7D23\u7D26\u7D2A\u7D2D\u7D31\u7D3C\u7D3D\u7D3E\u7D40\u7D41\u7D47\u7D48\u7D4D\u7D51\u7D53\u7D57\u7D59\u7D5A\u7D5C\u7D5D\u7D65\u7D67\u7D6A\u7D70\u7D78\u7D7A\u7D7B\u7D7F\u7D81\u7D82\u7D83\u7D85\u7D86\u7D88\u7D8B\u7D8C\u7D8D\u7D91\u7D96\u7D97\u7D9D"],
      ["8fd4a1", "\u7D9E\u7DA6\u7DA7\u7DAA\u7DB3\u7DB6\u7DB7\u7DB9\u7DC2", 4, "\u7DCC\u7DCD\u7DCE\u7DD7\u7DD9\u7E00\u7DE2\u7DE5\u7DE6\u7DEA\u7DEB\u7DED\u7DF1\u7DF5\u7DF6\u7DF9\u7DFA\u7E08\u7E10\u7E11\u7E15\u7E17\u7E1C\u7E1D\u7E20\u7E27\u7E28\u7E2C\u7E2D\u7E2F\u7E33\u7E36\u7E3F\u7E44\u7E45\u7E47\u7E4E\u7E50\u7E52\u7E58\u7E5F\u7E61\u7E62\u7E65\u7E6B\u7E6E\u7E6F\u7E73\u7E78\u7E7E\u7E81\u7E86\u7E87\u7E8A\u7E8D\u7E91\u7E95\u7E98\u7E9A\u7E9D\u7E9E\u7F3C\u7F3B\u7F3D\u7F3E\u7F3F\u7F43\u7F44\u7F47\u7F4F\u7F52\u7F53\u7F5B\u7F5C\u7F5D\u7F61\u7F63\u7F64\u7F65\u7F66\u7F6D"],
      ["8fd5a1", "\u7F71\u7F7D\u7F7E\u7F7F\u7F80\u7F8B\u7F8D\u7F8F\u7F90\u7F91\u7F96\u7F97\u7F9C\u7FA1\u7FA2\u7FA6\u7FAA\u7FAD\u7FB4\u7FBC\u7FBF\u7FC0\u7FC3\u7FC8\u7FCE\u7FCF\u7FDB\u7FDF\u7FE3\u7FE5\u7FE8\u7FEC\u7FEE\u7FEF\u7FF2\u7FFA\u7FFD\u7FFE\u7FFF\u8007\u8008\u800A\u800D\u800E\u800F\u8011\u8013\u8014\u8016\u801D\u801E\u801F\u8020\u8024\u8026\u802C\u802E\u8030\u8034\u8035\u8037\u8039\u803A\u803C\u803E\u8040\u8044\u8060\u8064\u8066\u806D\u8071\u8075\u8081\u8088\u808E\u809C\u809E\u80A6\u80A7\u80AB\u80B8\u80B9\u80C8\u80CD\u80CF\u80D2\u80D4\u80D5\u80D7\u80D8\u80E0\u80ED\u80EE"],
      ["8fd6a1", "\u80F0\u80F2\u80F3\u80F6\u80F9\u80FA\u80FE\u8103\u810B\u8116\u8117\u8118\u811C\u811E\u8120\u8124\u8127\u812C\u8130\u8135\u813A\u813C\u8145\u8147\u814A\u814C\u8152\u8157\u8160\u8161\u8167\u8168\u8169\u816D\u816F\u8177\u8181\u8190\u8184\u8185\u8186\u818B\u818E\u8196\u8198\u819B\u819E\u81A2\u81AE\u81B2\u81B4\u81BB\u81CB\u81C3\u81C5\u81CA\u81CE\u81CF\u81D5\u81D7\u81DB\u81DD\u81DE\u81E1\u81E4\u81EB\u81EC\u81F0\u81F1\u81F2\u81F5\u81F6\u81F8\u81F9\u81FD\u81FF\u8200\u8203\u820F\u8213\u8214\u8219\u821A\u821D\u8221\u8222\u8228\u8232\u8234\u823A\u8243\u8244\u8245\u8246"],
      ["8fd7a1", "\u824B\u824E\u824F\u8251\u8256\u825C\u8260\u8263\u8267\u826D\u8274\u827B\u827D\u827F\u8280\u8281\u8283\u8284\u8287\u8289\u828A\u828E\u8291\u8294\u8296\u8298\u829A\u829B\u82A0\u82A1\u82A3\u82A4\u82A7\u82A8\u82A9\u82AA\u82AE\u82B0\u82B2\u82B4\u82B7\u82BA\u82BC\u82BE\u82BF\u82C6\u82D0\u82D5\u82DA\u82E0\u82E2\u82E4\u82E8\u82EA\u82ED\u82EF\u82F6\u82F7\u82FD\u82FE\u8300\u8301\u8307\u8308\u830A\u830B\u8354\u831B\u831D\u831E\u831F\u8321\u8322\u832C\u832D\u832E\u8330\u8333\u8337\u833A\u833C\u833D\u8342\u8343\u8344\u8347\u834D\u834E\u8351\u8355\u8356\u8357\u8370\u8378"],
      ["8fd8a1", "\u837D\u837F\u8380\u8382\u8384\u8386\u838D\u8392\u8394\u8395\u8398\u8399\u839B\u839C\u839D\u83A6\u83A7\u83A9\u83AC\u83BE\u83BF\u83C0\u83C7\u83C9\u83CF\u83D0\u83D1\u83D4\u83DD\u8353\u83E8\u83EA\u83F6\u83F8\u83F9\u83FC\u8401\u8406\u840A\u840F\u8411\u8415\u8419\u83AD\u842F\u8439\u8445\u8447\u8448\u844A\u844D\u844F\u8451\u8452\u8456\u8458\u8459\u845A\u845C\u8460\u8464\u8465\u8467\u846A\u8470\u8473\u8474\u8476\u8478\u847C\u847D\u8481\u8485\u8492\u8493\u8495\u849E\u84A6\u84A8\u84A9\u84AA\u84AF\u84B1\u84B4\u84BA\u84BD\u84BE\u84C0\u84C2\u84C7\u84C8\u84CC\u84CF\u84D3"],
      ["8fd9a1", "\u84DC\u84E7\u84EA\u84EF\u84F0\u84F1\u84F2\u84F7\u8532\u84FA\u84FB\u84FD\u8502\u8503\u8507\u850C\u850E\u8510\u851C\u851E\u8522\u8523\u8524\u8525\u8527\u852A\u852B\u852F\u8533\u8534\u8536\u853F\u8546\u854F", 4, "\u8556\u8559\u855C", 6, "\u8564\u856B\u856F\u8579\u857A\u857B\u857D\u857F\u8581\u8585\u8586\u8589\u858B\u858C\u858F\u8593\u8598\u859D\u859F\u85A0\u85A2\u85A5\u85A7\u85B4\u85B6\u85B7\u85B8\u85BC\u85BD\u85BE\u85BF\u85C2\u85C7\u85CA\u85CB\u85CE\u85AD\u85D8\u85DA\u85DF\u85E0\u85E6\u85E8\u85ED\u85F3\u85F6\u85FC"],
      ["8fdaa1", "\u85FF\u8600\u8604\u8605\u860D\u860E\u8610\u8611\u8612\u8618\u8619\u861B\u861E\u8621\u8627\u8629\u8636\u8638\u863A\u863C\u863D\u8640\u8642\u8646\u8652\u8653\u8656\u8657\u8658\u8659\u865D\u8660", 4, "\u8669\u866C\u866F\u8675\u8676\u8677\u867A\u868D\u8691\u8696\u8698\u869A\u869C\u86A1\u86A6\u86A7\u86A8\u86AD\u86B1\u86B3\u86B4\u86B5\u86B7\u86B8\u86B9\u86BF\u86C0\u86C1\u86C3\u86C5\u86D1\u86D2\u86D5\u86D7\u86DA\u86DC\u86E0\u86E3\u86E5\u86E7\u8688\u86FA\u86FC\u86FD\u8704\u8705\u8707\u870B\u870E\u870F\u8710\u8713\u8714\u8719\u871E\u871F\u8721\u8723"],
      ["8fdba1", "\u8728\u872E\u872F\u8731\u8732\u8739\u873A\u873C\u873D\u873E\u8740\u8743\u8745\u874D\u8758\u875D\u8761\u8764\u8765\u876F\u8771\u8772\u877B\u8783", 6, "\u878B\u878C\u8790\u8793\u8795\u8797\u8798\u8799\u879E\u87A0\u87A3\u87A7\u87AC\u87AD\u87AE\u87B1\u87B5\u87BE\u87BF\u87C1\u87C8\u87C9\u87CA\u87CE\u87D5\u87D6\u87D9\u87DA\u87DC\u87DF\u87E2\u87E3\u87E4\u87EA\u87EB\u87ED\u87F1\u87F3\u87F8\u87FA\u87FF\u8801\u8803\u8806\u8809\u880A\u880B\u8810\u8819\u8812\u8813\u8814\u8818\u881A\u881B\u881C\u881E\u881F\u8828\u882D\u882E\u8830\u8832\u8835"],
      ["8fdca1", "\u883A\u883C\u8841\u8843\u8845\u8848\u8849\u884A\u884B\u884E\u8851\u8855\u8856\u8858\u885A\u885C\u885F\u8860\u8864\u8869\u8871\u8879\u887B\u8880\u8898\u889A\u889B\u889C\u889F\u88A0\u88A8\u88AA\u88BA\u88BD\u88BE\u88C0\u88CA", 4, "\u88D1\u88D2\u88D3\u88DB\u88DE\u88E7\u88EF\u88F0\u88F1\u88F5\u88F7\u8901\u8906\u890D\u890E\u890F\u8915\u8916\u8918\u8919\u891A\u891C\u8920\u8926\u8927\u8928\u8930\u8931\u8932\u8935\u8939\u893A\u893E\u8940\u8942\u8945\u8946\u8949\u894F\u8952\u8957\u895A\u895B\u895C\u8961\u8962\u8963\u896B\u896E\u8970\u8973\u8975\u897A"],
      ["8fdda1", "\u897B\u897C\u897D\u8989\u898D\u8990\u8994\u8995\u899B\u899C\u899F\u89A0\u89A5\u89B0\u89B4\u89B5\u89B6\u89B7\u89BC\u89D4", 4, "\u89E5\u89E9\u89EB\u89ED\u89F1\u89F3\u89F6\u89F9\u89FD\u89FF\u8A04\u8A05\u8A07\u8A0F\u8A11\u8A12\u8A14\u8A15\u8A1E\u8A20\u8A22\u8A24\u8A26\u8A2B\u8A2C\u8A2F\u8A35\u8A37\u8A3D\u8A3E\u8A40\u8A43\u8A45\u8A47\u8A49\u8A4D\u8A4E\u8A53\u8A56\u8A57\u8A58\u8A5C\u8A5D\u8A61\u8A65\u8A67\u8A75\u8A76\u8A77\u8A79\u8A7A\u8A7B\u8A7E\u8A7F\u8A80\u8A83\u8A86\u8A8B\u8A8F\u8A90\u8A92\u8A96\u8A97\u8A99\u8A9F\u8AA7\u8AA9\u8AAE\u8AAF\u8AB3"],
      ["8fdea1", "\u8AB6\u8AB7\u8ABB\u8ABE\u8AC3\u8AC6\u8AC8\u8AC9\u8ACA\u8AD1\u8AD3\u8AD4\u8AD5\u8AD7\u8ADD\u8ADF\u8AEC\u8AF0\u8AF4\u8AF5\u8AF6\u8AFC\u8AFF\u8B05\u8B06\u8B0B\u8B11\u8B1C\u8B1E\u8B1F\u8B0A\u8B2D\u8B30\u8B37\u8B3C\u8B42", 4, "\u8B48\u8B52\u8B53\u8B54\u8B59\u8B4D\u8B5E\u8B63\u8B6D\u8B76\u8B78\u8B79\u8B7C\u8B7E\u8B81\u8B84\u8B85\u8B8B\u8B8D\u8B8F\u8B94\u8B95\u8B9C\u8B9E\u8B9F\u8C38\u8C39\u8C3D\u8C3E\u8C45\u8C47\u8C49\u8C4B\u8C4F\u8C51\u8C53\u8C54\u8C57\u8C58\u8C5B\u8C5D\u8C59\u8C63\u8C64\u8C66\u8C68\u8C69\u8C6D\u8C73\u8C75\u8C76\u8C7B\u8C7E\u8C86"],
      ["8fdfa1", "\u8C87\u8C8B\u8C90\u8C92\u8C93\u8C99\u8C9B\u8C9C\u8CA4\u8CB9\u8CBA\u8CC5\u8CC6\u8CC9\u8CCB\u8CCF\u8CD6\u8CD5\u8CD9\u8CDD\u8CE1\u8CE8\u8CEC\u8CEF\u8CF0\u8CF2\u8CF5\u8CF7\u8CF8\u8CFE\u8CFF\u8D01\u8D03\u8D09\u8D12\u8D17\u8D1B\u8D65\u8D69\u8D6C\u8D6E\u8D7F\u8D82\u8D84\u8D88\u8D8D\u8D90\u8D91\u8D95\u8D9E\u8D9F\u8DA0\u8DA6\u8DAB\u8DAC\u8DAF\u8DB2\u8DB5\u8DB7\u8DB9\u8DBB\u8DC0\u8DC5\u8DC6\u8DC7\u8DC8\u8DCA\u8DCE\u8DD1\u8DD4\u8DD5\u8DD7\u8DD9\u8DE4\u8DE5\u8DE7\u8DEC\u8DF0\u8DBC\u8DF1\u8DF2\u8DF4\u8DFD\u8E01\u8E04\u8E05\u8E06\u8E0B\u8E11\u8E14\u8E16\u8E20\u8E21\u8E22"],
      ["8fe0a1", "\u8E23\u8E26\u8E27\u8E31\u8E33\u8E36\u8E37\u8E38\u8E39\u8E3D\u8E40\u8E41\u8E4B\u8E4D\u8E4E\u8E4F\u8E54\u8E5B\u8E5C\u8E5D\u8E5E\u8E61\u8E62\u8E69\u8E6C\u8E6D\u8E6F\u8E70\u8E71\u8E79\u8E7A\u8E7B\u8E82\u8E83\u8E89\u8E90\u8E92\u8E95\u8E9A\u8E9B\u8E9D\u8E9E\u8EA2\u8EA7\u8EA9\u8EAD\u8EAE\u8EB3\u8EB5\u8EBA\u8EBB\u8EC0\u8EC1\u8EC3\u8EC4\u8EC7\u8ECF\u8ED1\u8ED4\u8EDC\u8EE8\u8EEE\u8EF0\u8EF1\u8EF7\u8EF9\u8EFA\u8EED\u8F00\u8F02\u8F07\u8F08\u8F0F\u8F10\u8F16\u8F17\u8F18\u8F1E\u8F20\u8F21\u8F23\u8F25\u8F27\u8F28\u8F2C\u8F2D\u8F2E\u8F34\u8F35\u8F36\u8F37\u8F3A\u8F40\u8F41"],
      ["8fe1a1", "\u8F43\u8F47\u8F4F\u8F51", 4, "\u8F58\u8F5D\u8F5E\u8F65\u8F9D\u8FA0\u8FA1\u8FA4\u8FA5\u8FA6\u8FB5\u8FB6\u8FB8\u8FBE\u8FC0\u8FC1\u8FC6\u8FCA\u8FCB\u8FCD\u8FD0\u8FD2\u8FD3\u8FD5\u8FE0\u8FE3\u8FE4\u8FE8\u8FEE\u8FF1\u8FF5\u8FF6\u8FFB\u8FFE\u9002\u9004\u9008\u900C\u9018\u901B\u9028\u9029\u902F\u902A\u902C\u902D\u9033\u9034\u9037\u903F\u9043\u9044\u904C\u905B\u905D\u9062\u9066\u9067\u906C\u9070\u9074\u9079\u9085\u9088\u908B\u908C\u908E\u9090\u9095\u9097\u9098\u9099\u909B\u90A0\u90A1\u90A2\u90A5\u90B0\u90B2\u90B3\u90B4\u90B6\u90BD\u90CC\u90BE\u90C3"],
      ["8fe2a1", "\u90C4\u90C5\u90C7\u90C8\u90D5\u90D7\u90D8\u90D9\u90DC\u90DD\u90DF\u90E5\u90D2\u90F6\u90EB\u90EF\u90F0\u90F4\u90FE\u90FF\u9100\u9104\u9105\u9106\u9108\u910D\u9110\u9114\u9116\u9117\u9118\u911A\u911C\u911E\u9120\u9125\u9122\u9123\u9127\u9129\u912E\u912F\u9131\u9134\u9136\u9137\u9139\u913A\u913C\u913D\u9143\u9147\u9148\u914F\u9153\u9157\u9159\u915A\u915B\u9161\u9164\u9167\u916D\u9174\u9179\u917A\u917B\u9181\u9183\u9185\u9186\u918A\u918E\u9191\u9193\u9194\u9195\u9198\u919E\u91A1\u91A6\u91A8\u91AC\u91AD\u91AE\u91B0\u91B1\u91B2\u91B3\u91B6\u91BB\u91BC\u91BD\u91BF"],
      ["8fe3a1", "\u91C2\u91C3\u91C5\u91D3\u91D4\u91D7\u91D9\u91DA\u91DE\u91E4\u91E5\u91E9\u91EA\u91EC", 5, "\u91F7\u91F9\u91FB\u91FD\u9200\u9201\u9204\u9205\u9206\u9207\u9209\u920A\u920C\u9210\u9212\u9213\u9216\u9218\u921C\u921D\u9223\u9224\u9225\u9226\u9228\u922E\u922F\u9230\u9233\u9235\u9236\u9238\u9239\u923A\u923C\u923E\u9240\u9242\u9243\u9246\u9247\u924A\u924D\u924E\u924F\u9251\u9258\u9259\u925C\u925D\u9260\u9261\u9265\u9267\u9268\u9269\u926E\u926F\u9270\u9275", 4, "\u927B\u927C\u927D\u927F\u9288\u9289\u928A\u928D\u928E\u9292\u9297"],
      ["8fe4a1", "\u9299\u929F\u92A0\u92A4\u92A5\u92A7\u92A8\u92AB\u92AF\u92B2\u92B6\u92B8\u92BA\u92BB\u92BC\u92BD\u92BF", 4, "\u92C5\u92C6\u92C7\u92C8\u92CB\u92CC\u92CD\u92CE\u92D0\u92D3\u92D5\u92D7\u92D8\u92D9\u92DC\u92DD\u92DF\u92E0\u92E1\u92E3\u92E5\u92E7\u92E8\u92EC\u92EE\u92F0\u92F9\u92FB\u92FF\u9300\u9302\u9308\u930D\u9311\u9314\u9315\u931C\u931D\u931E\u931F\u9321\u9324\u9325\u9327\u9329\u932A\u9333\u9334\u9336\u9337\u9347\u9348\u9349\u9350\u9351\u9352\u9355\u9357\u9358\u935A\u935E\u9364\u9365\u9367\u9369\u936A\u936D\u936F\u9370\u9371\u9373\u9374\u9376"],
      ["8fe5a1", "\u937A\u937D\u937F\u9380\u9381\u9382\u9388\u938A\u938B\u938D\u938F\u9392\u9395\u9398\u939B\u939E\u93A1\u93A3\u93A4\u93A6\u93A8\u93AB\u93B4\u93B5\u93B6\u93BA\u93A9\u93C1\u93C4\u93C5\u93C6\u93C7\u93C9", 4, "\u93D3\u93D9\u93DC\u93DE\u93DF\u93E2\u93E6\u93E7\u93F9\u93F7\u93F8\u93FA\u93FB\u93FD\u9401\u9402\u9404\u9408\u9409\u940D\u940E\u940F\u9415\u9416\u9417\u941F\u942E\u942F\u9431\u9432\u9433\u9434\u943B\u943F\u943D\u9443\u9445\u9448\u944A\u944C\u9455\u9459\u945C\u945F\u9461\u9463\u9468\u946B\u946D\u946E\u946F\u9471\u9472\u9484\u9483\u9578\u9579"],
      ["8fe6a1", "\u957E\u9584\u9588\u958C\u958D\u958E\u959D\u959E\u959F\u95A1\u95A6\u95A9\u95AB\u95AC\u95B4\u95B6\u95BA\u95BD\u95BF\u95C6\u95C8\u95C9\u95CB\u95D0\u95D1\u95D2\u95D3\u95D9\u95DA\u95DD\u95DE\u95DF\u95E0\u95E4\u95E6\u961D\u961E\u9622\u9624\u9625\u9626\u962C\u9631\u9633\u9637\u9638\u9639\u963A\u963C\u963D\u9641\u9652\u9654\u9656\u9657\u9658\u9661\u966E\u9674\u967B\u967C\u967E\u967F\u9681\u9682\u9683\u9684\u9689\u9691\u9696\u969A\u969D\u969F\u96A4\u96A5\u96A6\u96A9\u96AE\u96AF\u96B3\u96BA\u96CA\u96D2\u5DB2\u96D8\u96DA\u96DD\u96DE\u96DF\u96E9\u96EF\u96F1\u96FA\u9702"],
      ["8fe7a1", "\u9703\u9705\u9709\u971A\u971B\u971D\u9721\u9722\u9723\u9728\u9731\u9733\u9741\u9743\u974A\u974E\u974F\u9755\u9757\u9758\u975A\u975B\u9763\u9767\u976A\u976E\u9773\u9776\u9777\u9778\u977B\u977D\u977F\u9780\u9789\u9795\u9796\u9797\u9799\u979A\u979E\u979F\u97A2\u97AC\u97AE\u97B1\u97B2\u97B5\u97B6\u97B8\u97B9\u97BA\u97BC\u97BE\u97BF\u97C1\u97C4\u97C5\u97C7\u97C9\u97CA\u97CC\u97CD\u97CE\u97D0\u97D1\u97D4\u97D7\u97D8\u97D9\u97DD\u97DE\u97E0\u97DB\u97E1\u97E4\u97EF\u97F1\u97F4\u97F7\u97F8\u97FA\u9807\u980A\u9819\u980D\u980E\u9814\u9816\u981C\u981E\u9820\u9823\u9826"],
      ["8fe8a1", "\u982B\u982E\u982F\u9830\u9832\u9833\u9835\u9825\u983E\u9844\u9847\u984A\u9851\u9852\u9853\u9856\u9857\u9859\u985A\u9862\u9863\u9865\u9866\u986A\u986C\u98AB\u98AD\u98AE\u98B0\u98B4\u98B7\u98B8\u98BA\u98BB\u98BF\u98C2\u98C5\u98C8\u98CC\u98E1\u98E3\u98E5\u98E6\u98E7\u98EA\u98F3\u98F6\u9902\u9907\u9908\u9911\u9915\u9916\u9917\u991A\u991B\u991C\u991F\u9922\u9926\u9927\u992B\u9931", 4, "\u9939\u993A\u993B\u993C\u9940\u9941\u9946\u9947\u9948\u994D\u994E\u9954\u9958\u9959\u995B\u995C\u995E\u995F\u9960\u999B\u999D\u999F\u99A6\u99B0\u99B1\u99B2\u99B5"],
      ["8fe9a1", "\u99B9\u99BA\u99BD\u99BF\u99C3\u99C9\u99D3\u99D4\u99D9\u99DA\u99DC\u99DE\u99E7\u99EA\u99EB\u99EC\u99F0\u99F4\u99F5\u99F9\u99FD\u99FE\u9A02\u9A03\u9A04\u9A0B\u9A0C\u9A10\u9A11\u9A16\u9A1E\u9A20\u9A22\u9A23\u9A24\u9A27\u9A2D\u9A2E\u9A33\u9A35\u9A36\u9A38\u9A47\u9A41\u9A44\u9A4A\u9A4B\u9A4C\u9A4E\u9A51\u9A54\u9A56\u9A5D\u9AAA\u9AAC\u9AAE\u9AAF\u9AB2\u9AB4\u9AB5\u9AB6\u9AB9\u9ABB\u9ABE\u9ABF\u9AC1\u9AC3\u9AC6\u9AC8\u9ACE\u9AD0\u9AD2\u9AD5\u9AD6\u9AD7\u9ADB\u9ADC\u9AE0\u9AE4\u9AE5\u9AE7\u9AE9\u9AEC\u9AF2\u9AF3\u9AF5\u9AF9\u9AFA\u9AFD\u9AFF", 4],
      ["8feaa1", "\u9B04\u9B05\u9B08\u9B09\u9B0B\u9B0C\u9B0D\u9B0E\u9B10\u9B12\u9B16\u9B19\u9B1B\u9B1C\u9B20\u9B26\u9B2B\u9B2D\u9B33\u9B34\u9B35\u9B37\u9B39\u9B3A\u9B3D\u9B48\u9B4B\u9B4C\u9B55\u9B56\u9B57\u9B5B\u9B5E\u9B61\u9B63\u9B65\u9B66\u9B68\u9B6A", 4, "\u9B73\u9B75\u9B77\u9B78\u9B79\u9B7F\u9B80\u9B84\u9B85\u9B86\u9B87\u9B89\u9B8A\u9B8B\u9B8D\u9B8F\u9B90\u9B94\u9B9A\u9B9D\u9B9E\u9BA6\u9BA7\u9BA9\u9BAC\u9BB0\u9BB1\u9BB2\u9BB7\u9BB8\u9BBB\u9BBC\u9BBE\u9BBF\u9BC1\u9BC7\u9BC8\u9BCE\u9BD0\u9BD7\u9BD8\u9BDD\u9BDF\u9BE5\u9BE7\u9BEA\u9BEB\u9BEF\u9BF3\u9BF7\u9BF8"],
      ["8feba1", "\u9BF9\u9BFA\u9BFD\u9BFF\u9C00\u9C02\u9C0B\u9C0F\u9C11\u9C16\u9C18\u9C19\u9C1A\u9C1C\u9C1E\u9C22\u9C23\u9C26", 4, "\u9C31\u9C35\u9C36\u9C37\u9C3D\u9C41\u9C43\u9C44\u9C45\u9C49\u9C4A\u9C4E\u9C4F\u9C50\u9C53\u9C54\u9C56\u9C58\u9C5B\u9C5D\u9C5E\u9C5F\u9C63\u9C69\u9C6A\u9C5C\u9C6B\u9C68\u9C6E\u9C70\u9C72\u9C75\u9C77\u9C7B\u9CE6\u9CF2\u9CF7\u9CF9\u9D0B\u9D02\u9D11\u9D17\u9D18\u9D1C\u9D1D\u9D1E\u9D2F\u9D30\u9D32\u9D33\u9D34\u9D3A\u9D3C\u9D45\u9D3D\u9D42\u9D43\u9D47\u9D4A\u9D53\u9D54\u9D5F\u9D63\u9D62\u9D65\u9D69\u9D6A\u9D6B\u9D70\u9D76\u9D77\u9D7B"],
      ["8feca1", "\u9D7C\u9D7E\u9D83\u9D84\u9D86\u9D8A\u9D8D\u9D8E\u9D92\u9D93\u9D95\u9D96\u9D97\u9D98\u9DA1\u9DAA\u9DAC\u9DAE\u9DB1\u9DB5\u9DB9\u9DBC\u9DBF\u9DC3\u9DC7\u9DC9\u9DCA\u9DD4\u9DD5\u9DD6\u9DD7\u9DDA\u9DDE\u9DDF\u9DE0\u9DE5\u9DE7\u9DE9\u9DEB\u9DEE\u9DF0\u9DF3\u9DF4\u9DFE\u9E0A\u9E02\u9E07\u9E0E\u9E10\u9E11\u9E12\u9E15\u9E16\u9E19\u9E1C\u9E1D\u9E7A\u9E7B\u9E7C\u9E80\u9E82\u9E83\u9E84\u9E85\u9E87\u9E8E\u9E8F\u9E96\u9E98\u9E9B\u9E9E\u9EA4\u9EA8\u9EAC\u9EAE\u9EAF\u9EB0\u9EB3\u9EB4\u9EB5\u9EC6\u9EC8\u9ECB\u9ED5\u9EDF\u9EE4\u9EE7\u9EEC\u9EED\u9EEE\u9EF0\u9EF1\u9EF2\u9EF5"],
      ["8feda1", "\u9EF8\u9EFF\u9F02\u9F03\u9F09\u9F0F\u9F10\u9F11\u9F12\u9F14\u9F16\u9F17\u9F19\u9F1A\u9F1B\u9F1F\u9F22\u9F26\u9F2A\u9F2B\u9F2F\u9F31\u9F32\u9F34\u9F37\u9F39\u9F3A\u9F3C\u9F3D\u9F3F\u9F41\u9F43", 4, "\u9F53\u9F55\u9F56\u9F57\u9F58\u9F5A\u9F5D\u9F5E\u9F68\u9F69\u9F6D", 4, "\u9F73\u9F75\u9F7A\u9F7D\u9F8F\u9F90\u9F91\u9F92\u9F94\u9F96\u9F97\u9F9E\u9FA1\u9FA2\u9FA3\u9FA5"]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/cp936.json
var require_cp936 = __commonJS({
  "node_modules/iconv-lite/encodings/tables/cp936.json"(exports, module2) {
    module2.exports = [
      ["0", "\0", 127, "\u20AC"],
      ["8140", "\u4E02\u4E04\u4E05\u4E06\u4E0F\u4E12\u4E17\u4E1F\u4E20\u4E21\u4E23\u4E26\u4E29\u4E2E\u4E2F\u4E31\u4E33\u4E35\u4E37\u4E3C\u4E40\u4E41\u4E42\u4E44\u4E46\u4E4A\u4E51\u4E55\u4E57\u4E5A\u4E5B\u4E62\u4E63\u4E64\u4E65\u4E67\u4E68\u4E6A", 5, "\u4E72\u4E74", 9, "\u4E7F", 6, "\u4E87\u4E8A"],
      ["8180", "\u4E90\u4E96\u4E97\u4E99\u4E9C\u4E9D\u4E9E\u4EA3\u4EAA\u4EAF\u4EB0\u4EB1\u4EB4\u4EB6\u4EB7\u4EB8\u4EB9\u4EBC\u4EBD\u4EBE\u4EC8\u4ECC\u4ECF\u4ED0\u4ED2\u4EDA\u4EDB\u4EDC\u4EE0\u4EE2\u4EE6\u4EE7\u4EE9\u4EED\u4EEE\u4EEF\u4EF1\u4EF4\u4EF8\u4EF9\u4EFA\u4EFC\u4EFE\u4F00\u4F02", 6, "\u4F0B\u4F0C\u4F12", 4, "\u4F1C\u4F1D\u4F21\u4F23\u4F28\u4F29\u4F2C\u4F2D\u4F2E\u4F31\u4F33\u4F35\u4F37\u4F39\u4F3B\u4F3E", 4, "\u4F44\u4F45\u4F47", 5, "\u4F52\u4F54\u4F56\u4F61\u4F62\u4F66\u4F68\u4F6A\u4F6B\u4F6D\u4F6E\u4F71\u4F72\u4F75\u4F77\u4F78\u4F79\u4F7A\u4F7D\u4F80\u4F81\u4F82\u4F85\u4F86\u4F87\u4F8A\u4F8C\u4F8E\u4F90\u4F92\u4F93\u4F95\u4F96\u4F98\u4F99\u4F9A\u4F9C\u4F9E\u4F9F\u4FA1\u4FA2"],
      ["8240", "\u4FA4\u4FAB\u4FAD\u4FB0", 4, "\u4FB6", 8, "\u4FC0\u4FC1\u4FC2\u4FC6\u4FC7\u4FC8\u4FC9\u4FCB\u4FCC\u4FCD\u4FD2", 4, "\u4FD9\u4FDB\u4FE0\u4FE2\u4FE4\u4FE5\u4FE7\u4FEB\u4FEC\u4FF0\u4FF2\u4FF4\u4FF5\u4FF6\u4FF7\u4FF9\u4FFB\u4FFC\u4FFD\u4FFF", 11],
      ["8280", "\u500B\u500E\u5010\u5011\u5013\u5015\u5016\u5017\u501B\u501D\u501E\u5020\u5022\u5023\u5024\u5027\u502B\u502F", 10, "\u503B\u503D\u503F\u5040\u5041\u5042\u5044\u5045\u5046\u5049\u504A\u504B\u504D\u5050", 4, "\u5056\u5057\u5058\u5059\u505B\u505D", 7, "\u5066", 5, "\u506D", 8, "\u5078\u5079\u507A\u507C\u507D\u5081\u5082\u5083\u5084\u5086\u5087\u5089\u508A\u508B\u508C\u508E", 20, "\u50A4\u50A6\u50AA\u50AB\u50AD", 4, "\u50B3", 6, "\u50BC"],
      ["8340", "\u50BD", 17, "\u50D0", 5, "\u50D7\u50D8\u50D9\u50DB", 10, "\u50E8\u50E9\u50EA\u50EB\u50EF\u50F0\u50F1\u50F2\u50F4\u50F6", 4, "\u50FC", 9, "\u5108"],
      ["8380", "\u5109\u510A\u510C", 5, "\u5113", 13, "\u5122", 28, "\u5142\u5147\u514A\u514C\u514E\u514F\u5150\u5152\u5153\u5157\u5158\u5159\u515B\u515D", 4, "\u5163\u5164\u5166\u5167\u5169\u516A\u516F\u5172\u517A\u517E\u517F\u5183\u5184\u5186\u5187\u518A\u518B\u518E\u518F\u5190\u5191\u5193\u5194\u5198\u519A\u519D\u519E\u519F\u51A1\u51A3\u51A6", 4, "\u51AD\u51AE\u51B4\u51B8\u51B9\u51BA\u51BE\u51BF\u51C1\u51C2\u51C3\u51C5\u51C8\u51CA\u51CD\u51CE\u51D0\u51D2", 5],
      ["8440", "\u51D8\u51D9\u51DA\u51DC\u51DE\u51DF\u51E2\u51E3\u51E5", 5, "\u51EC\u51EE\u51F1\u51F2\u51F4\u51F7\u51FE\u5204\u5205\u5209\u520B\u520C\u520F\u5210\u5213\u5214\u5215\u521C\u521E\u521F\u5221\u5222\u5223\u5225\u5226\u5227\u522A\u522C\u522F\u5231\u5232\u5234\u5235\u523C\u523E\u5244", 5, "\u524B\u524E\u524F\u5252\u5253\u5255\u5257\u5258"],
      ["8480", "\u5259\u525A\u525B\u525D\u525F\u5260\u5262\u5263\u5264\u5266\u5268\u526B\u526C\u526D\u526E\u5270\u5271\u5273", 9, "\u527E\u5280\u5283", 4, "\u5289", 6, "\u5291\u5292\u5294", 6, "\u529C\u52A4\u52A5\u52A6\u52A7\u52AE\u52AF\u52B0\u52B4", 9, "\u52C0\u52C1\u52C2\u52C4\u52C5\u52C6\u52C8\u52CA\u52CC\u52CD\u52CE\u52CF\u52D1\u52D3\u52D4\u52D5\u52D7\u52D9", 5, "\u52E0\u52E1\u52E2\u52E3\u52E5", 10, "\u52F1", 7, "\u52FB\u52FC\u52FD\u5301\u5302\u5303\u5304\u5307\u5309\u530A\u530B\u530C\u530E"],
      ["8540", "\u5311\u5312\u5313\u5314\u5318\u531B\u531C\u531E\u531F\u5322\u5324\u5325\u5327\u5328\u5329\u532B\u532C\u532D\u532F", 9, "\u533C\u533D\u5340\u5342\u5344\u5346\u534B\u534C\u534D\u5350\u5354\u5358\u5359\u535B\u535D\u5365\u5368\u536A\u536C\u536D\u5372\u5376\u5379\u537B\u537C\u537D\u537E\u5380\u5381\u5383\u5387\u5388\u538A\u538E\u538F"],
      ["8580", "\u5390", 4, "\u5396\u5397\u5399\u539B\u539C\u539E\u53A0\u53A1\u53A4\u53A7\u53AA\u53AB\u53AC\u53AD\u53AF", 6, "\u53B7\u53B8\u53B9\u53BA\u53BC\u53BD\u53BE\u53C0\u53C3", 4, "\u53CE\u53CF\u53D0\u53D2\u53D3\u53D5\u53DA\u53DC\u53DD\u53DE\u53E1\u53E2\u53E7\u53F4\u53FA\u53FE\u53FF\u5400\u5402\u5405\u5407\u540B\u5414\u5418\u5419\u541A\u541C\u5422\u5424\u5425\u542A\u5430\u5433\u5436\u5437\u543A\u543D\u543F\u5441\u5442\u5444\u5445\u5447\u5449\u544C\u544D\u544E\u544F\u5451\u545A\u545D", 4, "\u5463\u5465\u5467\u5469", 7, "\u5474\u5479\u547A\u547E\u547F\u5481\u5483\u5485\u5487\u5488\u5489\u548A\u548D\u5491\u5493\u5497\u5498\u549C\u549E\u549F\u54A0\u54A1"],
      ["8640", "\u54A2\u54A5\u54AE\u54B0\u54B2\u54B5\u54B6\u54B7\u54B9\u54BA\u54BC\u54BE\u54C3\u54C5\u54CA\u54CB\u54D6\u54D8\u54DB\u54E0", 4, "\u54EB\u54EC\u54EF\u54F0\u54F1\u54F4", 5, "\u54FB\u54FE\u5500\u5502\u5503\u5504\u5505\u5508\u550A", 4, "\u5512\u5513\u5515", 5, "\u551C\u551D\u551E\u551F\u5521\u5525\u5526"],
      ["8680", "\u5528\u5529\u552B\u552D\u5532\u5534\u5535\u5536\u5538\u5539\u553A\u553B\u553D\u5540\u5542\u5545\u5547\u5548\u554B", 4, "\u5551\u5552\u5553\u5554\u5557", 4, "\u555D\u555E\u555F\u5560\u5562\u5563\u5568\u5569\u556B\u556F", 5, "\u5579\u557A\u557D\u557F\u5585\u5586\u558C\u558D\u558E\u5590\u5592\u5593\u5595\u5596\u5597\u559A\u559B\u559E\u55A0", 6, "\u55A8", 8, "\u55B2\u55B4\u55B6\u55B8\u55BA\u55BC\u55BF", 4, "\u55C6\u55C7\u55C8\u55CA\u55CB\u55CE\u55CF\u55D0\u55D5\u55D7", 4, "\u55DE\u55E0\u55E2\u55E7\u55E9\u55ED\u55EE\u55F0\u55F1\u55F4\u55F6\u55F8", 4, "\u55FF\u5602\u5603\u5604\u5605"],
      ["8740", "\u5606\u5607\u560A\u560B\u560D\u5610", 7, "\u5619\u561A\u561C\u561D\u5620\u5621\u5622\u5625\u5626\u5628\u5629\u562A\u562B\u562E\u562F\u5630\u5633\u5635\u5637\u5638\u563A\u563C\u563D\u563E\u5640", 11, "\u564F", 4, "\u5655\u5656\u565A\u565B\u565D", 4],
      ["8780", "\u5663\u5665\u5666\u5667\u566D\u566E\u566F\u5670\u5672\u5673\u5674\u5675\u5677\u5678\u5679\u567A\u567D", 7, "\u5687", 6, "\u5690\u5691\u5692\u5694", 14, "\u56A4", 10, "\u56B0", 6, "\u56B8\u56B9\u56BA\u56BB\u56BD", 12, "\u56CB", 8, "\u56D5\u56D6\u56D8\u56D9\u56DC\u56E3\u56E5", 5, "\u56EC\u56EE\u56EF\u56F2\u56F3\u56F6\u56F7\u56F8\u56FB\u56FC\u5700\u5701\u5702\u5705\u5707\u570B", 6],
      ["8840", "\u5712", 9, "\u571D\u571E\u5720\u5721\u5722\u5724\u5725\u5726\u5727\u572B\u5731\u5732\u5734", 4, "\u573C\u573D\u573F\u5741\u5743\u5744\u5745\u5746\u5748\u5749\u574B\u5752", 4, "\u5758\u5759\u5762\u5763\u5765\u5767\u576C\u576E\u5770\u5771\u5772\u5774\u5775\u5778\u5779\u577A\u577D\u577E\u577F\u5780"],
      ["8880", "\u5781\u5787\u5788\u5789\u578A\u578D", 4, "\u5794", 6, "\u579C\u579D\u579E\u579F\u57A5\u57A8\u57AA\u57AC\u57AF\u57B0\u57B1\u57B3\u57B5\u57B6\u57B7\u57B9", 8, "\u57C4", 6, "\u57CC\u57CD\u57D0\u57D1\u57D3\u57D6\u57D7\u57DB\u57DC\u57DE\u57E1\u57E2\u57E3\u57E5", 7, "\u57EE\u57F0\u57F1\u57F2\u57F3\u57F5\u57F6\u57F7\u57FB\u57FC\u57FE\u57FF\u5801\u5803\u5804\u5805\u5808\u5809\u580A\u580C\u580E\u580F\u5810\u5812\u5813\u5814\u5816\u5817\u5818\u581A\u581B\u581C\u581D\u581F\u5822\u5823\u5825", 4, "\u582B", 4, "\u5831\u5832\u5833\u5834\u5836", 7],
      ["8940", "\u583E", 5, "\u5845", 6, "\u584E\u584F\u5850\u5852\u5853\u5855\u5856\u5857\u5859", 4, "\u585F", 5, "\u5866", 4, "\u586D", 16, "\u587F\u5882\u5884\u5886\u5887\u5888\u588A\u588B\u588C"],
      ["8980", "\u588D", 4, "\u5894", 4, "\u589B\u589C\u589D\u58A0", 7, "\u58AA", 17, "\u58BD\u58BE\u58BF\u58C0\u58C2\u58C3\u58C4\u58C6", 10, "\u58D2\u58D3\u58D4\u58D6", 13, "\u58E5", 5, "\u58ED\u58EF\u58F1\u58F2\u58F4\u58F5\u58F7\u58F8\u58FA", 7, "\u5903\u5905\u5906\u5908", 4, "\u590E\u5910\u5911\u5912\u5913\u5917\u5918\u591B\u591D\u591E\u5920\u5921\u5922\u5923\u5926\u5928\u592C\u5930\u5932\u5933\u5935\u5936\u593B"],
      ["8a40", "\u593D\u593E\u593F\u5940\u5943\u5945\u5946\u594A\u594C\u594D\u5950\u5952\u5953\u5959\u595B", 4, "\u5961\u5963\u5964\u5966", 12, "\u5975\u5977\u597A\u597B\u597C\u597E\u597F\u5980\u5985\u5989\u598B\u598C\u598E\u598F\u5990\u5991\u5994\u5995\u5998\u599A\u599B\u599C\u599D\u599F\u59A0\u59A1\u59A2\u59A6"],
      ["8a80", "\u59A7\u59AC\u59AD\u59B0\u59B1\u59B3", 5, "\u59BA\u59BC\u59BD\u59BF", 6, "\u59C7\u59C8\u59C9\u59CC\u59CD\u59CE\u59CF\u59D5\u59D6\u59D9\u59DB\u59DE", 4, "\u59E4\u59E6\u59E7\u59E9\u59EA\u59EB\u59ED", 11, "\u59FA\u59FC\u59FD\u59FE\u5A00\u5A02\u5A0A\u5A0B\u5A0D\u5A0E\u5A0F\u5A10\u5A12\u5A14\u5A15\u5A16\u5A17\u5A19\u5A1A\u5A1B\u5A1D\u5A1E\u5A21\u5A22\u5A24\u5A26\u5A27\u5A28\u5A2A", 6, "\u5A33\u5A35\u5A37", 4, "\u5A3D\u5A3E\u5A3F\u5A41", 4, "\u5A47\u5A48\u5A4B", 9, "\u5A56\u5A57\u5A58\u5A59\u5A5B", 5],
      ["8b40", "\u5A61\u5A63\u5A64\u5A65\u5A66\u5A68\u5A69\u5A6B", 8, "\u5A78\u5A79\u5A7B\u5A7C\u5A7D\u5A7E\u5A80", 17, "\u5A93", 6, "\u5A9C", 13, "\u5AAB\u5AAC"],
      ["8b80", "\u5AAD", 4, "\u5AB4\u5AB6\u5AB7\u5AB9", 4, "\u5ABF\u5AC0\u5AC3", 5, "\u5ACA\u5ACB\u5ACD", 4, "\u5AD3\u5AD5\u5AD7\u5AD9\u5ADA\u5ADB\u5ADD\u5ADE\u5ADF\u5AE2\u5AE4\u5AE5\u5AE7\u5AE8\u5AEA\u5AEC", 4, "\u5AF2", 22, "\u5B0A", 11, "\u5B18", 25, "\u5B33\u5B35\u5B36\u5B38", 7, "\u5B41", 6],
      ["8c40", "\u5B48", 7, "\u5B52\u5B56\u5B5E\u5B60\u5B61\u5B67\u5B68\u5B6B\u5B6D\u5B6E\u5B6F\u5B72\u5B74\u5B76\u5B77\u5B78\u5B79\u5B7B\u5B7C\u5B7E\u5B7F\u5B82\u5B86\u5B8A\u5B8D\u5B8E\u5B90\u5B91\u5B92\u5B94\u5B96\u5B9F\u5BA7\u5BA8\u5BA9\u5BAC\u5BAD\u5BAE\u5BAF\u5BB1\u5BB2\u5BB7\u5BBA\u5BBB\u5BBC\u5BC0\u5BC1\u5BC3\u5BC8\u5BC9\u5BCA\u5BCB\u5BCD\u5BCE\u5BCF"],
      ["8c80", "\u5BD1\u5BD4", 8, "\u5BE0\u5BE2\u5BE3\u5BE6\u5BE7\u5BE9", 4, "\u5BEF\u5BF1", 6, "\u5BFD\u5BFE\u5C00\u5C02\u5C03\u5C05\u5C07\u5C08\u5C0B\u5C0C\u5C0D\u5C0E\u5C10\u5C12\u5C13\u5C17\u5C19\u5C1B\u5C1E\u5C1F\u5C20\u5C21\u5C23\u5C26\u5C28\u5C29\u5C2A\u5C2B\u5C2D\u5C2E\u5C2F\u5C30\u5C32\u5C33\u5C35\u5C36\u5C37\u5C43\u5C44\u5C46\u5C47\u5C4C\u5C4D\u5C52\u5C53\u5C54\u5C56\u5C57\u5C58\u5C5A\u5C5B\u5C5C\u5C5D\u5C5F\u5C62\u5C64\u5C67", 6, "\u5C70\u5C72", 6, "\u5C7B\u5C7C\u5C7D\u5C7E\u5C80\u5C83", 4, "\u5C89\u5C8A\u5C8B\u5C8E\u5C8F\u5C92\u5C93\u5C95\u5C9D", 4, "\u5CA4", 4],
      ["8d40", "\u5CAA\u5CAE\u5CAF\u5CB0\u5CB2\u5CB4\u5CB6\u5CB9\u5CBA\u5CBB\u5CBC\u5CBE\u5CC0\u5CC2\u5CC3\u5CC5", 5, "\u5CCC", 5, "\u5CD3", 5, "\u5CDA", 6, "\u5CE2\u5CE3\u5CE7\u5CE9\u5CEB\u5CEC\u5CEE\u5CEF\u5CF1", 9, "\u5CFC", 4],
      ["8d80", "\u5D01\u5D04\u5D05\u5D08", 5, "\u5D0F", 4, "\u5D15\u5D17\u5D18\u5D19\u5D1A\u5D1C\u5D1D\u5D1F", 4, "\u5D25\u5D28\u5D2A\u5D2B\u5D2C\u5D2F", 4, "\u5D35", 7, "\u5D3F", 7, "\u5D48\u5D49\u5D4D", 10, "\u5D59\u5D5A\u5D5C\u5D5E", 10, "\u5D6A\u5D6D\u5D6E\u5D70\u5D71\u5D72\u5D73\u5D75", 12, "\u5D83", 21, "\u5D9A\u5D9B\u5D9C\u5D9E\u5D9F\u5DA0"],
      ["8e40", "\u5DA1", 21, "\u5DB8", 12, "\u5DC6", 6, "\u5DCE", 12, "\u5DDC\u5DDF\u5DE0\u5DE3\u5DE4\u5DEA\u5DEC\u5DED"],
      ["8e80", "\u5DF0\u5DF5\u5DF6\u5DF8", 4, "\u5DFF\u5E00\u5E04\u5E07\u5E09\u5E0A\u5E0B\u5E0D\u5E0E\u5E12\u5E13\u5E17\u5E1E", 7, "\u5E28", 4, "\u5E2F\u5E30\u5E32", 4, "\u5E39\u5E3A\u5E3E\u5E3F\u5E40\u5E41\u5E43\u5E46", 5, "\u5E4D", 6, "\u5E56", 4, "\u5E5C\u5E5D\u5E5F\u5E60\u5E63", 14, "\u5E75\u5E77\u5E79\u5E7E\u5E81\u5E82\u5E83\u5E85\u5E88\u5E89\u5E8C\u5E8D\u5E8E\u5E92\u5E98\u5E9B\u5E9D\u5EA1\u5EA2\u5EA3\u5EA4\u5EA8", 4, "\u5EAE", 4, "\u5EB4\u5EBA\u5EBB\u5EBC\u5EBD\u5EBF", 6],
      ["8f40", "\u5EC6\u5EC7\u5EC8\u5ECB", 5, "\u5ED4\u5ED5\u5ED7\u5ED8\u5ED9\u5EDA\u5EDC", 11, "\u5EE9\u5EEB", 8, "\u5EF5\u5EF8\u5EF9\u5EFB\u5EFC\u5EFD\u5F05\u5F06\u5F07\u5F09\u5F0C\u5F0D\u5F0E\u5F10\u5F12\u5F14\u5F16\u5F19\u5F1A\u5F1C\u5F1D\u5F1E\u5F21\u5F22\u5F23\u5F24"],
      ["8f80", "\u5F28\u5F2B\u5F2C\u5F2E\u5F30\u5F32", 6, "\u5F3B\u5F3D\u5F3E\u5F3F\u5F41", 14, "\u5F51\u5F54\u5F59\u5F5A\u5F5B\u5F5C\u5F5E\u5F5F\u5F60\u5F63\u5F65\u5F67\u5F68\u5F6B\u5F6E\u5F6F\u5F72\u5F74\u5F75\u5F76\u5F78\u5F7A\u5F7D\u5F7E\u5F7F\u5F83\u5F86\u5F8D\u5F8E\u5F8F\u5F91\u5F93\u5F94\u5F96\u5F9A\u5F9B\u5F9D\u5F9E\u5F9F\u5FA0\u5FA2", 5, "\u5FA9\u5FAB\u5FAC\u5FAF", 5, "\u5FB6\u5FB8\u5FB9\u5FBA\u5FBB\u5FBE", 4, "\u5FC7\u5FC8\u5FCA\u5FCB\u5FCE\u5FD3\u5FD4\u5FD5\u5FDA\u5FDB\u5FDC\u5FDE\u5FDF\u5FE2\u5FE3\u5FE5\u5FE6\u5FE8\u5FE9\u5FEC\u5FEF\u5FF0\u5FF2\u5FF3\u5FF4\u5FF6\u5FF7\u5FF9\u5FFA\u5FFC\u6007"],
      ["9040", "\u6008\u6009\u600B\u600C\u6010\u6011\u6013\u6017\u6018\u601A\u601E\u601F\u6022\u6023\u6024\u602C\u602D\u602E\u6030", 4, "\u6036", 4, "\u603D\u603E\u6040\u6044", 6, "\u604C\u604E\u604F\u6051\u6053\u6054\u6056\u6057\u6058\u605B\u605C\u605E\u605F\u6060\u6061\u6065\u6066\u606E\u6071\u6072\u6074\u6075\u6077\u607E\u6080"],
      ["9080", "\u6081\u6082\u6085\u6086\u6087\u6088\u608A\u608B\u608E\u608F\u6090\u6091\u6093\u6095\u6097\u6098\u6099\u609C\u609E\u60A1\u60A2\u60A4\u60A5\u60A7\u60A9\u60AA\u60AE\u60B0\u60B3\u60B5\u60B6\u60B7\u60B9\u60BA\u60BD", 7, "\u60C7\u60C8\u60C9\u60CC", 4, "\u60D2\u60D3\u60D4\u60D6\u60D7\u60D9\u60DB\u60DE\u60E1", 4, "\u60EA\u60F1\u60F2\u60F5\u60F7\u60F8\u60FB", 4, "\u6102\u6103\u6104\u6105\u6107\u610A\u610B\u610C\u6110", 4, "\u6116\u6117\u6118\u6119\u611B\u611C\u611D\u611E\u6121\u6122\u6125\u6128\u6129\u612A\u612C", 18, "\u6140", 6],
      ["9140", "\u6147\u6149\u614B\u614D\u614F\u6150\u6152\u6153\u6154\u6156", 6, "\u615E\u615F\u6160\u6161\u6163\u6164\u6165\u6166\u6169", 6, "\u6171\u6172\u6173\u6174\u6176\u6178", 18, "\u618C\u618D\u618F", 4, "\u6195"],
      ["9180", "\u6196", 6, "\u619E", 8, "\u61AA\u61AB\u61AD", 9, "\u61B8", 5, "\u61BF\u61C0\u61C1\u61C3", 4, "\u61C9\u61CC", 4, "\u61D3\u61D5", 16, "\u61E7", 13, "\u61F6", 8, "\u6200", 5, "\u6207\u6209\u6213\u6214\u6219\u621C\u621D\u621E\u6220\u6223\u6226\u6227\u6228\u6229\u622B\u622D\u622F\u6230\u6231\u6232\u6235\u6236\u6238", 4, "\u6242\u6244\u6245\u6246\u624A"],
      ["9240", "\u624F\u6250\u6255\u6256\u6257\u6259\u625A\u625C", 6, "\u6264\u6265\u6268\u6271\u6272\u6274\u6275\u6277\u6278\u627A\u627B\u627D\u6281\u6282\u6283\u6285\u6286\u6287\u6288\u628B", 5, "\u6294\u6299\u629C\u629D\u629E\u62A3\u62A6\u62A7\u62A9\u62AA\u62AD\u62AE\u62AF\u62B0\u62B2\u62B3\u62B4\u62B6\u62B7\u62B8\u62BA\u62BE\u62C0\u62C1"],
      ["9280", "\u62C3\u62CB\u62CF\u62D1\u62D5\u62DD\u62DE\u62E0\u62E1\u62E4\u62EA\u62EB\u62F0\u62F2\u62F5\u62F8\u62F9\u62FA\u62FB\u6300\u6303\u6304\u6305\u6306\u630A\u630B\u630C\u630D\u630F\u6310\u6312\u6313\u6314\u6315\u6317\u6318\u6319\u631C\u6326\u6327\u6329\u632C\u632D\u632E\u6330\u6331\u6333", 5, "\u633B\u633C\u633E\u633F\u6340\u6341\u6344\u6347\u6348\u634A\u6351\u6352\u6353\u6354\u6356", 7, "\u6360\u6364\u6365\u6366\u6368\u636A\u636B\u636C\u636F\u6370\u6372\u6373\u6374\u6375\u6378\u6379\u637C\u637D\u637E\u637F\u6381\u6383\u6384\u6385\u6386\u638B\u638D\u6391\u6393\u6394\u6395\u6397\u6399", 6, "\u63A1\u63A4\u63A6\u63AB\u63AF\u63B1\u63B2\u63B5\u63B6\u63B9\u63BB\u63BD\u63BF\u63C0"],
      ["9340", "\u63C1\u63C2\u63C3\u63C5\u63C7\u63C8\u63CA\u63CB\u63CC\u63D1\u63D3\u63D4\u63D5\u63D7", 6, "\u63DF\u63E2\u63E4", 4, "\u63EB\u63EC\u63EE\u63EF\u63F0\u63F1\u63F3\u63F5\u63F7\u63F9\u63FA\u63FB\u63FC\u63FE\u6403\u6404\u6406", 4, "\u640D\u640E\u6411\u6412\u6415", 5, "\u641D\u641F\u6422\u6423\u6424"],
      ["9380", "\u6425\u6427\u6428\u6429\u642B\u642E", 5, "\u6435", 4, "\u643B\u643C\u643E\u6440\u6442\u6443\u6449\u644B", 6, "\u6453\u6455\u6456\u6457\u6459", 4, "\u645F", 7, "\u6468\u646A\u646B\u646C\u646E", 9, "\u647B", 6, "\u6483\u6486\u6488", 8, "\u6493\u6494\u6497\u6498\u649A\u649B\u649C\u649D\u649F", 4, "\u64A5\u64A6\u64A7\u64A8\u64AA\u64AB\u64AF\u64B1\u64B2\u64B3\u64B4\u64B6\u64B9\u64BB\u64BD\u64BE\u64BF\u64C1\u64C3\u64C4\u64C6", 6, "\u64CF\u64D1\u64D3\u64D4\u64D5\u64D6\u64D9\u64DA"],
      ["9440", "\u64DB\u64DC\u64DD\u64DF\u64E0\u64E1\u64E3\u64E5\u64E7", 24, "\u6501", 7, "\u650A", 7, "\u6513", 4, "\u6519", 8],
      ["9480", "\u6522\u6523\u6524\u6526", 4, "\u652C\u652D\u6530\u6531\u6532\u6533\u6537\u653A\u653C\u653D\u6540", 4, "\u6546\u6547\u654A\u654B\u654D\u654E\u6550\u6552\u6553\u6554\u6557\u6558\u655A\u655C\u655F\u6560\u6561\u6564\u6565\u6567\u6568\u6569\u656A\u656D\u656E\u656F\u6571\u6573\u6575\u6576\u6578", 14, "\u6588\u6589\u658A\u658D\u658E\u658F\u6592\u6594\u6595\u6596\u6598\u659A\u659D\u659E\u65A0\u65A2\u65A3\u65A6\u65A8\u65AA\u65AC\u65AE\u65B1", 7, "\u65BA\u65BB\u65BE\u65BF\u65C0\u65C2\u65C7\u65C8\u65C9\u65CA\u65CD\u65D0\u65D1\u65D3\u65D4\u65D5\u65D8", 7, "\u65E1\u65E3\u65E4\u65EA\u65EB"],
      ["9540", "\u65F2\u65F3\u65F4\u65F5\u65F8\u65F9\u65FB", 4, "\u6601\u6604\u6605\u6607\u6608\u6609\u660B\u660D\u6610\u6611\u6612\u6616\u6617\u6618\u661A\u661B\u661C\u661E\u6621\u6622\u6623\u6624\u6626\u6629\u662A\u662B\u662C\u662E\u6630\u6632\u6633\u6637", 4, "\u663D\u663F\u6640\u6642\u6644", 6, "\u664D\u664E\u6650\u6651\u6658"],
      ["9580", "\u6659\u665B\u665C\u665D\u665E\u6660\u6662\u6663\u6665\u6667\u6669", 4, "\u6671\u6672\u6673\u6675\u6678\u6679\u667B\u667C\u667D\u667F\u6680\u6681\u6683\u6685\u6686\u6688\u6689\u668A\u668B\u668D\u668E\u668F\u6690\u6692\u6693\u6694\u6695\u6698", 4, "\u669E", 8, "\u66A9", 4, "\u66AF", 4, "\u66B5\u66B6\u66B7\u66B8\u66BA\u66BB\u66BC\u66BD\u66BF", 25, "\u66DA\u66DE", 7, "\u66E7\u66E8\u66EA", 5, "\u66F1\u66F5\u66F6\u66F8\u66FA\u66FB\u66FD\u6701\u6702\u6703"],
      ["9640", "\u6704\u6705\u6706\u6707\u670C\u670E\u670F\u6711\u6712\u6713\u6716\u6718\u6719\u671A\u671C\u671E\u6720", 5, "\u6727\u6729\u672E\u6730\u6732\u6733\u6736\u6737\u6738\u6739\u673B\u673C\u673E\u673F\u6741\u6744\u6745\u6747\u674A\u674B\u674D\u6752\u6754\u6755\u6757", 4, "\u675D\u6762\u6763\u6764\u6766\u6767\u676B\u676C\u676E\u6771\u6774\u6776"],
      ["9680", "\u6778\u6779\u677A\u677B\u677D\u6780\u6782\u6783\u6785\u6786\u6788\u678A\u678C\u678D\u678E\u678F\u6791\u6792\u6793\u6794\u6796\u6799\u679B\u679F\u67A0\u67A1\u67A4\u67A6\u67A9\u67AC\u67AE\u67B1\u67B2\u67B4\u67B9", 7, "\u67C2\u67C5", 9, "\u67D5\u67D6\u67D7\u67DB\u67DF\u67E1\u67E3\u67E4\u67E6\u67E7\u67E8\u67EA\u67EB\u67ED\u67EE\u67F2\u67F5", 7, "\u67FE\u6801\u6802\u6803\u6804\u6806\u680D\u6810\u6812\u6814\u6815\u6818", 4, "\u681E\u681F\u6820\u6822", 6, "\u682B", 6, "\u6834\u6835\u6836\u683A\u683B\u683F\u6847\u684B\u684D\u684F\u6852\u6856", 5],
      ["9740", "\u685C\u685D\u685E\u685F\u686A\u686C", 7, "\u6875\u6878", 8, "\u6882\u6884\u6887", 7, "\u6890\u6891\u6892\u6894\u6895\u6896\u6898", 9, "\u68A3\u68A4\u68A5\u68A9\u68AA\u68AB\u68AC\u68AE\u68B1\u68B2\u68B4\u68B6\u68B7\u68B8"],
      ["9780", "\u68B9", 6, "\u68C1\u68C3", 5, "\u68CA\u68CC\u68CE\u68CF\u68D0\u68D1\u68D3\u68D4\u68D6\u68D7\u68D9\u68DB", 4, "\u68E1\u68E2\u68E4", 9, "\u68EF\u68F2\u68F3\u68F4\u68F6\u68F7\u68F8\u68FB\u68FD\u68FE\u68FF\u6900\u6902\u6903\u6904\u6906", 4, "\u690C\u690F\u6911\u6913", 11, "\u6921\u6922\u6923\u6925", 7, "\u692E\u692F\u6931\u6932\u6933\u6935\u6936\u6937\u6938\u693A\u693B\u693C\u693E\u6940\u6941\u6943", 16, "\u6955\u6956\u6958\u6959\u695B\u695C\u695F"],
      ["9840", "\u6961\u6962\u6964\u6965\u6967\u6968\u6969\u696A\u696C\u696D\u696F\u6970\u6972", 4, "\u697A\u697B\u697D\u697E\u697F\u6981\u6983\u6985\u698A\u698B\u698C\u698E", 5, "\u6996\u6997\u6999\u699A\u699D", 9, "\u69A9\u69AA\u69AC\u69AE\u69AF\u69B0\u69B2\u69B3\u69B5\u69B6\u69B8\u69B9\u69BA\u69BC\u69BD"],
      ["9880", "\u69BE\u69BF\u69C0\u69C2", 7, "\u69CB\u69CD\u69CF\u69D1\u69D2\u69D3\u69D5", 5, "\u69DC\u69DD\u69DE\u69E1", 11, "\u69EE\u69EF\u69F0\u69F1\u69F3", 9, "\u69FE\u6A00", 9, "\u6A0B", 11, "\u6A19", 5, "\u6A20\u6A22", 5, "\u6A29\u6A2B\u6A2C\u6A2D\u6A2E\u6A30\u6A32\u6A33\u6A34\u6A36", 6, "\u6A3F", 4, "\u6A45\u6A46\u6A48", 7, "\u6A51", 6, "\u6A5A"],
      ["9940", "\u6A5C", 4, "\u6A62\u6A63\u6A64\u6A66", 10, "\u6A72", 6, "\u6A7A\u6A7B\u6A7D\u6A7E\u6A7F\u6A81\u6A82\u6A83\u6A85", 8, "\u6A8F\u6A92", 4, "\u6A98", 7, "\u6AA1", 5],
      ["9980", "\u6AA7\u6AA8\u6AAA\u6AAD", 114, "\u6B25\u6B26\u6B28", 6],
      ["9a40", "\u6B2F\u6B30\u6B31\u6B33\u6B34\u6B35\u6B36\u6B38\u6B3B\u6B3C\u6B3D\u6B3F\u6B40\u6B41\u6B42\u6B44\u6B45\u6B48\u6B4A\u6B4B\u6B4D", 11, "\u6B5A", 7, "\u6B68\u6B69\u6B6B", 13, "\u6B7A\u6B7D\u6B7E\u6B7F\u6B80\u6B85\u6B88"],
      ["9a80", "\u6B8C\u6B8E\u6B8F\u6B90\u6B91\u6B94\u6B95\u6B97\u6B98\u6B99\u6B9C", 4, "\u6BA2", 7, "\u6BAB", 7, "\u6BB6\u6BB8", 6, "\u6BC0\u6BC3\u6BC4\u6BC6", 4, "\u6BCC\u6BCE\u6BD0\u6BD1\u6BD8\u6BDA\u6BDC", 4, "\u6BE2", 7, "\u6BEC\u6BED\u6BEE\u6BF0\u6BF1\u6BF2\u6BF4\u6BF6\u6BF7\u6BF8\u6BFA\u6BFB\u6BFC\u6BFE", 6, "\u6C08", 4, "\u6C0E\u6C12\u6C17\u6C1C\u6C1D\u6C1E\u6C20\u6C23\u6C25\u6C2B\u6C2C\u6C2D\u6C31\u6C33\u6C36\u6C37\u6C39\u6C3A\u6C3B\u6C3C\u6C3E\u6C3F\u6C43\u6C44\u6C45\u6C48\u6C4B", 4, "\u6C51\u6C52\u6C53\u6C56\u6C58"],
      ["9b40", "\u6C59\u6C5A\u6C62\u6C63\u6C65\u6C66\u6C67\u6C6B", 4, "\u6C71\u6C73\u6C75\u6C77\u6C78\u6C7A\u6C7B\u6C7C\u6C7F\u6C80\u6C84\u6C87\u6C8A\u6C8B\u6C8D\u6C8E\u6C91\u6C92\u6C95\u6C96\u6C97\u6C98\u6C9A\u6C9C\u6C9D\u6C9E\u6CA0\u6CA2\u6CA8\u6CAC\u6CAF\u6CB0\u6CB4\u6CB5\u6CB6\u6CB7\u6CBA\u6CC0\u6CC1\u6CC2\u6CC3\u6CC6\u6CC7\u6CC8\u6CCB\u6CCD\u6CCE\u6CCF\u6CD1\u6CD2\u6CD8"],
      ["9b80", "\u6CD9\u6CDA\u6CDC\u6CDD\u6CDF\u6CE4\u6CE6\u6CE7\u6CE9\u6CEC\u6CED\u6CF2\u6CF4\u6CF9\u6CFF\u6D00\u6D02\u6D03\u6D05\u6D06\u6D08\u6D09\u6D0A\u6D0D\u6D0F\u6D10\u6D11\u6D13\u6D14\u6D15\u6D16\u6D18\u6D1C\u6D1D\u6D1F", 5, "\u6D26\u6D28\u6D29\u6D2C\u6D2D\u6D2F\u6D30\u6D34\u6D36\u6D37\u6D38\u6D3A\u6D3F\u6D40\u6D42\u6D44\u6D49\u6D4C\u6D50\u6D55\u6D56\u6D57\u6D58\u6D5B\u6D5D\u6D5F\u6D61\u6D62\u6D64\u6D65\u6D67\u6D68\u6D6B\u6D6C\u6D6D\u6D70\u6D71\u6D72\u6D73\u6D75\u6D76\u6D79\u6D7A\u6D7B\u6D7D", 4, "\u6D83\u6D84\u6D86\u6D87\u6D8A\u6D8B\u6D8D\u6D8F\u6D90\u6D92\u6D96", 4, "\u6D9C\u6DA2\u6DA5\u6DAC\u6DAD\u6DB0\u6DB1\u6DB3\u6DB4\u6DB6\u6DB7\u6DB9", 5, "\u6DC1\u6DC2\u6DC3\u6DC8\u6DC9\u6DCA"],
      ["9c40", "\u6DCD\u6DCE\u6DCF\u6DD0\u6DD2\u6DD3\u6DD4\u6DD5\u6DD7\u6DDA\u6DDB\u6DDC\u6DDF\u6DE2\u6DE3\u6DE5\u6DE7\u6DE8\u6DE9\u6DEA\u6DED\u6DEF\u6DF0\u6DF2\u6DF4\u6DF5\u6DF6\u6DF8\u6DFA\u6DFD", 7, "\u6E06\u6E07\u6E08\u6E09\u6E0B\u6E0F\u6E12\u6E13\u6E15\u6E18\u6E19\u6E1B\u6E1C\u6E1E\u6E1F\u6E22\u6E26\u6E27\u6E28\u6E2A\u6E2C\u6E2E\u6E30\u6E31\u6E33\u6E35"],
      ["9c80", "\u6E36\u6E37\u6E39\u6E3B", 7, "\u6E45", 7, "\u6E4F\u6E50\u6E51\u6E52\u6E55\u6E57\u6E59\u6E5A\u6E5C\u6E5D\u6E5E\u6E60", 10, "\u6E6C\u6E6D\u6E6F", 14, "\u6E80\u6E81\u6E82\u6E84\u6E87\u6E88\u6E8A", 4, "\u6E91", 6, "\u6E99\u6E9A\u6E9B\u6E9D\u6E9E\u6EA0\u6EA1\u6EA3\u6EA4\u6EA6\u6EA8\u6EA9\u6EAB\u6EAC\u6EAD\u6EAE\u6EB0\u6EB3\u6EB5\u6EB8\u6EB9\u6EBC\u6EBE\u6EBF\u6EC0\u6EC3\u6EC4\u6EC5\u6EC6\u6EC8\u6EC9\u6ECA\u6ECC\u6ECD\u6ECE\u6ED0\u6ED2\u6ED6\u6ED8\u6ED9\u6EDB\u6EDC\u6EDD\u6EE3\u6EE7\u6EEA", 5],
      ["9d40", "\u6EF0\u6EF1\u6EF2\u6EF3\u6EF5\u6EF6\u6EF7\u6EF8\u6EFA", 7, "\u6F03\u6F04\u6F05\u6F07\u6F08\u6F0A", 4, "\u6F10\u6F11\u6F12\u6F16", 9, "\u6F21\u6F22\u6F23\u6F25\u6F26\u6F27\u6F28\u6F2C\u6F2E\u6F30\u6F32\u6F34\u6F35\u6F37", 6, "\u6F3F\u6F40\u6F41\u6F42"],
      ["9d80", "\u6F43\u6F44\u6F45\u6F48\u6F49\u6F4A\u6F4C\u6F4E", 9, "\u6F59\u6F5A\u6F5B\u6F5D\u6F5F\u6F60\u6F61\u6F63\u6F64\u6F65\u6F67", 5, "\u6F6F\u6F70\u6F71\u6F73\u6F75\u6F76\u6F77\u6F79\u6F7B\u6F7D", 6, "\u6F85\u6F86\u6F87\u6F8A\u6F8B\u6F8F", 12, "\u6F9D\u6F9E\u6F9F\u6FA0\u6FA2", 4, "\u6FA8", 10, "\u6FB4\u6FB5\u6FB7\u6FB8\u6FBA", 5, "\u6FC1\u6FC3", 5, "\u6FCA", 6, "\u6FD3", 10, "\u6FDF\u6FE2\u6FE3\u6FE4\u6FE5"],
      ["9e40", "\u6FE6", 7, "\u6FF0", 32, "\u7012", 7, "\u701C", 6, "\u7024", 6],
      ["9e80", "\u702B", 9, "\u7036\u7037\u7038\u703A", 17, "\u704D\u704E\u7050", 13, "\u705F", 11, "\u706E\u7071\u7072\u7073\u7074\u7077\u7079\u707A\u707B\u707D\u7081\u7082\u7083\u7084\u7086\u7087\u7088\u708B\u708C\u708D\u708F\u7090\u7091\u7093\u7097\u7098\u709A\u709B\u709E", 12, "\u70B0\u70B2\u70B4\u70B5\u70B6\u70BA\u70BE\u70BF\u70C4\u70C5\u70C6\u70C7\u70C9\u70CB", 12, "\u70DA"],
      ["9f40", "\u70DC\u70DD\u70DE\u70E0\u70E1\u70E2\u70E3\u70E5\u70EA\u70EE\u70F0", 6, "\u70F8\u70FA\u70FB\u70FC\u70FE", 10, "\u710B", 4, "\u7111\u7112\u7114\u7117\u711B", 10, "\u7127", 7, "\u7132\u7133\u7134"],
      ["9f80", "\u7135\u7137", 13, "\u7146\u7147\u7148\u7149\u714B\u714D\u714F", 12, "\u715D\u715F", 4, "\u7165\u7169", 4, "\u716F\u7170\u7171\u7174\u7175\u7176\u7177\u7179\u717B\u717C\u717E", 5, "\u7185", 4, "\u718B\u718C\u718D\u718E\u7190\u7191\u7192\u7193\u7195\u7196\u7197\u719A", 4, "\u71A1", 6, "\u71A9\u71AA\u71AB\u71AD", 5, "\u71B4\u71B6\u71B7\u71B8\u71BA", 8, "\u71C4", 9, "\u71CF", 4],
      ["a040", "\u71D6", 9, "\u71E1\u71E2\u71E3\u71E4\u71E6\u71E8", 5, "\u71EF", 9, "\u71FA", 11, "\u7207", 19],
      ["a080", "\u721B\u721C\u721E", 9, "\u7229\u722B\u722D\u722E\u722F\u7232\u7233\u7234\u723A\u723C\u723E\u7240", 6, "\u7249\u724A\u724B\u724E\u724F\u7250\u7251\u7253\u7254\u7255\u7257\u7258\u725A\u725C\u725E\u7260\u7263\u7264\u7265\u7268\u726A\u726B\u726C\u726D\u7270\u7271\u7273\u7274\u7276\u7277\u7278\u727B\u727C\u727D\u7282\u7283\u7285", 4, "\u728C\u728E\u7290\u7291\u7293", 11, "\u72A0", 11, "\u72AE\u72B1\u72B2\u72B3\u72B5\u72BA", 6, "\u72C5\u72C6\u72C7\u72C9\u72CA\u72CB\u72CC\u72CF\u72D1\u72D3\u72D4\u72D5\u72D6\u72D8\u72DA\u72DB"],
      ["a1a1", "\u3000\u3001\u3002\xB7\u02C9\u02C7\xA8\u3003\u3005\u2014\uFF5E\u2016\u2026\u2018\u2019\u201C\u201D\u3014\u3015\u3008", 7, "\u3016\u3017\u3010\u3011\xB1\xD7\xF7\u2236\u2227\u2228\u2211\u220F\u222A\u2229\u2208\u2237\u221A\u22A5\u2225\u2220\u2312\u2299\u222B\u222E\u2261\u224C\u2248\u223D\u221D\u2260\u226E\u226F\u2264\u2265\u221E\u2235\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFF04\xA4\uFFE0\uFFE1\u2030\xA7\u2116\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u203B\u2192\u2190\u2191\u2193\u3013"],
      ["a2a1", "\u2170", 9],
      ["a2b1", "\u2488", 19, "\u2474", 19, "\u2460", 9],
      ["a2e5", "\u3220", 9],
      ["a2f1", "\u2160", 11],
      ["a3a1", "\uFF01\uFF02\uFF03\uFFE5\uFF05", 88, "\uFFE3"],
      ["a4a1", "\u3041", 82],
      ["a5a1", "\u30A1", 85],
      ["a6a1", "\u0391", 16, "\u03A3", 6],
      ["a6c1", "\u03B1", 16, "\u03C3", 6],
      ["a6e0", "\uFE35\uFE36\uFE39\uFE3A\uFE3F\uFE40\uFE3D\uFE3E\uFE41\uFE42\uFE43\uFE44"],
      ["a6ee", "\uFE3B\uFE3C\uFE37\uFE38\uFE31"],
      ["a6f4", "\uFE33\uFE34"],
      ["a7a1", "\u0410", 5, "\u0401\u0416", 25],
      ["a7d1", "\u0430", 5, "\u0451\u0436", 25],
      ["a840", "\u02CA\u02CB\u02D9\u2013\u2015\u2025\u2035\u2105\u2109\u2196\u2197\u2198\u2199\u2215\u221F\u2223\u2252\u2266\u2267\u22BF\u2550", 35, "\u2581", 6],
      ["a880", "\u2588", 7, "\u2593\u2594\u2595\u25BC\u25BD\u25E2\u25E3\u25E4\u25E5\u2609\u2295\u3012\u301D\u301E"],
      ["a8a1", "\u0101\xE1\u01CE\xE0\u0113\xE9\u011B\xE8\u012B\xED\u01D0\xEC\u014D\xF3\u01D2\xF2\u016B\xFA\u01D4\xF9\u01D6\u01D8\u01DA\u01DC\xFC\xEA\u0251"],
      ["a8bd", "\u0144\u0148"],
      ["a8c0", "\u0261"],
      ["a8c5", "\u3105", 36],
      ["a940", "\u3021", 8, "\u32A3\u338E\u338F\u339C\u339D\u339E\u33A1\u33C4\u33CE\u33D1\u33D2\u33D5\uFE30\uFFE2\uFFE4"],
      ["a959", "\u2121\u3231"],
      ["a95c", "\u2010"],
      ["a960", "\u30FC\u309B\u309C\u30FD\u30FE\u3006\u309D\u309E\uFE49", 9, "\uFE54\uFE55\uFE56\uFE57\uFE59", 8],
      ["a980", "\uFE62", 4, "\uFE68\uFE69\uFE6A\uFE6B"],
      ["a996", "\u3007"],
      ["a9a4", "\u2500", 75],
      ["aa40", "\u72DC\u72DD\u72DF\u72E2", 5, "\u72EA\u72EB\u72F5\u72F6\u72F9\u72FD\u72FE\u72FF\u7300\u7302\u7304", 5, "\u730B\u730C\u730D\u730F\u7310\u7311\u7312\u7314\u7318\u7319\u731A\u731F\u7320\u7323\u7324\u7326\u7327\u7328\u732D\u732F\u7330\u7332\u7333\u7335\u7336\u733A\u733B\u733C\u733D\u7340", 8],
      ["aa80", "\u7349\u734A\u734B\u734C\u734E\u734F\u7351\u7353\u7354\u7355\u7356\u7358", 7, "\u7361", 10, "\u736E\u7370\u7371"],
      ["ab40", "\u7372", 11, "\u737F", 4, "\u7385\u7386\u7388\u738A\u738C\u738D\u738F\u7390\u7392\u7393\u7394\u7395\u7397\u7398\u7399\u739A\u739C\u739D\u739E\u73A0\u73A1\u73A3", 5, "\u73AA\u73AC\u73AD\u73B1\u73B4\u73B5\u73B6\u73B8\u73B9\u73BC\u73BD\u73BE\u73BF\u73C1\u73C3", 4],
      ["ab80", "\u73CB\u73CC\u73CE\u73D2", 6, "\u73DA\u73DB\u73DC\u73DD\u73DF\u73E1\u73E2\u73E3\u73E4\u73E6\u73E8\u73EA\u73EB\u73EC\u73EE\u73EF\u73F0\u73F1\u73F3", 4],
      ["ac40", "\u73F8", 10, "\u7404\u7407\u7408\u740B\u740C\u740D\u740E\u7411", 8, "\u741C", 5, "\u7423\u7424\u7427\u7429\u742B\u742D\u742F\u7431\u7432\u7437", 4, "\u743D\u743E\u743F\u7440\u7442", 11],
      ["ac80", "\u744E", 6, "\u7456\u7458\u745D\u7460", 12, "\u746E\u746F\u7471", 4, "\u7478\u7479\u747A"],
      ["ad40", "\u747B\u747C\u747D\u747F\u7482\u7484\u7485\u7486\u7488\u7489\u748A\u748C\u748D\u748F\u7491", 10, "\u749D\u749F", 7, "\u74AA", 15, "\u74BB", 12],
      ["ad80", "\u74C8", 9, "\u74D3", 8, "\u74DD\u74DF\u74E1\u74E5\u74E7", 6, "\u74F0\u74F1\u74F2"],
      ["ae40", "\u74F3\u74F5\u74F8", 6, "\u7500\u7501\u7502\u7503\u7505", 7, "\u750E\u7510\u7512\u7514\u7515\u7516\u7517\u751B\u751D\u751E\u7520", 4, "\u7526\u7527\u752A\u752E\u7534\u7536\u7539\u753C\u753D\u753F\u7541\u7542\u7543\u7544\u7546\u7547\u7549\u754A\u754D\u7550\u7551\u7552\u7553\u7555\u7556\u7557\u7558"],
      ["ae80", "\u755D", 7, "\u7567\u7568\u7569\u756B", 6, "\u7573\u7575\u7576\u7577\u757A", 4, "\u7580\u7581\u7582\u7584\u7585\u7587"],
      ["af40", "\u7588\u7589\u758A\u758C\u758D\u758E\u7590\u7593\u7595\u7598\u759B\u759C\u759E\u75A2\u75A6", 4, "\u75AD\u75B6\u75B7\u75BA\u75BB\u75BF\u75C0\u75C1\u75C6\u75CB\u75CC\u75CE\u75CF\u75D0\u75D1\u75D3\u75D7\u75D9\u75DA\u75DC\u75DD\u75DF\u75E0\u75E1\u75E5\u75E9\u75EC\u75ED\u75EE\u75EF\u75F2\u75F3\u75F5\u75F6\u75F7\u75F8\u75FA\u75FB\u75FD\u75FE\u7602\u7604\u7606\u7607"],
      ["af80", "\u7608\u7609\u760B\u760D\u760E\u760F\u7611\u7612\u7613\u7614\u7616\u761A\u761C\u761D\u761E\u7621\u7623\u7627\u7628\u762C\u762E\u762F\u7631\u7632\u7636\u7637\u7639\u763A\u763B\u763D\u7641\u7642\u7644"],
      ["b040", "\u7645", 6, "\u764E", 5, "\u7655\u7657", 4, "\u765D\u765F\u7660\u7661\u7662\u7664", 6, "\u766C\u766D\u766E\u7670", 7, "\u7679\u767A\u767C\u767F\u7680\u7681\u7683\u7685\u7689\u768A\u768C\u768D\u768F\u7690\u7692\u7694\u7695\u7697\u7698\u769A\u769B"],
      ["b080", "\u769C", 7, "\u76A5", 8, "\u76AF\u76B0\u76B3\u76B5", 9, "\u76C0\u76C1\u76C3\u554A\u963F\u57C3\u6328\u54CE\u5509\u54C0\u7691\u764C\u853C\u77EE\u827E\u788D\u7231\u9698\u978D\u6C28\u5B89\u4FFA\u6309\u6697\u5CB8\u80FA\u6848\u80AE\u6602\u76CE\u51F9\u6556\u71AC\u7FF1\u8884\u50B2\u5965\u61CA\u6FB3\u82AD\u634C\u6252\u53ED\u5427\u7B06\u516B\u75A4\u5DF4\u62D4\u8DCB\u9776\u628A\u8019\u575D\u9738\u7F62\u7238\u767D\u67CF\u767E\u6446\u4F70\u8D25\u62DC\u7A17\u6591\u73ED\u642C\u6273\u822C\u9881\u677F\u7248\u626E\u62CC\u4F34\u74E3\u534A\u529E\u7ECA\u90A6\u5E2E\u6886\u699C\u8180\u7ED1\u68D2\u78C5\u868C\u9551\u508D\u8C24\u82DE\u80DE\u5305\u8912\u5265"],
      ["b140", "\u76C4\u76C7\u76C9\u76CB\u76CC\u76D3\u76D5\u76D9\u76DA\u76DC\u76DD\u76DE\u76E0", 4, "\u76E6", 7, "\u76F0\u76F3\u76F5\u76F6\u76F7\u76FA\u76FB\u76FD\u76FF\u7700\u7702\u7703\u7705\u7706\u770A\u770C\u770E", 10, "\u771B\u771C\u771D\u771E\u7721\u7723\u7724\u7725\u7727\u772A\u772B"],
      ["b180", "\u772C\u772E\u7730", 4, "\u7739\u773B\u773D\u773E\u773F\u7742\u7744\u7745\u7746\u7748", 7, "\u7752", 7, "\u775C\u8584\u96F9\u4FDD\u5821\u9971\u5B9D\u62B1\u62A5\u66B4\u8C79\u9C8D\u7206\u676F\u7891\u60B2\u5351\u5317\u8F88\u80CC\u8D1D\u94A1\u500D\u72C8\u5907\u60EB\u7119\u88AB\u5954\u82EF\u672C\u7B28\u5D29\u7EF7\u752D\u6CF5\u8E66\u8FF8\u903C\u9F3B\u6BD4\u9119\u7B14\u5F7C\u78A7\u84D6\u853D\u6BD5\u6BD9\u6BD6\u5E01\u5E87\u75F9\u95ED\u655D\u5F0A\u5FC5\u8F9F\u58C1\u81C2\u907F\u965B\u97AD\u8FB9\u7F16\u8D2C\u6241\u4FBF\u53D8\u535E\u8FA8\u8FA9\u8FAB\u904D\u6807\u5F6A\u8198\u8868\u9CD6\u618B\u522B\u762A\u5F6C\u658C\u6FD2\u6EE8\u5BBE\u6448\u5175\u51B0\u67C4\u4E19\u79C9\u997C\u70B3"],
      ["b240", "\u775D\u775E\u775F\u7760\u7764\u7767\u7769\u776A\u776D", 11, "\u777A\u777B\u777C\u7781\u7782\u7783\u7786", 5, "\u778F\u7790\u7793", 11, "\u77A1\u77A3\u77A4\u77A6\u77A8\u77AB\u77AD\u77AE\u77AF\u77B1\u77B2\u77B4\u77B6", 4],
      ["b280", "\u77BC\u77BE\u77C0", 12, "\u77CE", 8, "\u77D8\u77D9\u77DA\u77DD", 4, "\u77E4\u75C5\u5E76\u73BB\u83E0\u64AD\u62E8\u94B5\u6CE2\u535A\u52C3\u640F\u94C2\u7B94\u4F2F\u5E1B\u8236\u8116\u818A\u6E24\u6CCA\u9A73\u6355\u535C\u54FA\u8865\u57E0\u4E0D\u5E03\u6B65\u7C3F\u90E8\u6016\u64E6\u731C\u88C1\u6750\u624D\u8D22\u776C\u8E29\u91C7\u5F69\u83DC\u8521\u9910\u53C2\u8695\u6B8B\u60ED\u60E8\u707F\u82CD\u8231\u4ED3\u6CA7\u85CF\u64CD\u7CD9\u69FD\u66F9\u8349\u5395\u7B56\u4FA7\u518C\u6D4B\u5C42\u8E6D\u63D2\u53C9\u832C\u8336\u67E5\u78B4\u643D\u5BDF\u5C94\u5DEE\u8BE7\u62C6\u67F4\u8C7A\u6400\u63BA\u8749\u998B\u8C17\u7F20\u94F2\u4EA7\u9610\u98A4\u660C\u7316"],
      ["b340", "\u77E6\u77E8\u77EA\u77EF\u77F0\u77F1\u77F2\u77F4\u77F5\u77F7\u77F9\u77FA\u77FB\u77FC\u7803", 5, "\u780A\u780B\u780E\u780F\u7810\u7813\u7815\u7819\u781B\u781E\u7820\u7821\u7822\u7824\u7828\u782A\u782B\u782E\u782F\u7831\u7832\u7833\u7835\u7836\u783D\u783F\u7841\u7842\u7843\u7844\u7846\u7848\u7849\u784A\u784B\u784D\u784F\u7851\u7853\u7854\u7858\u7859\u785A"],
      ["b380", "\u785B\u785C\u785E", 11, "\u786F", 7, "\u7878\u7879\u787A\u787B\u787D", 6, "\u573A\u5C1D\u5E38\u957F\u507F\u80A0\u5382\u655E\u7545\u5531\u5021\u8D85\u6284\u949E\u671D\u5632\u6F6E\u5DE2\u5435\u7092\u8F66\u626F\u64A4\u63A3\u5F7B\u6F88\u90F4\u81E3\u8FB0\u5C18\u6668\u5FF1\u6C89\u9648\u8D81\u886C\u6491\u79F0\u57CE\u6A59\u6210\u5448\u4E58\u7A0B\u60E9\u6F84\u8BDA\u627F\u901E\u9A8B\u79E4\u5403\u75F4\u6301\u5319\u6C60\u8FDF\u5F1B\u9A70\u803B\u9F7F\u4F88\u5C3A\u8D64\u7FC5\u65A5\u70BD\u5145\u51B2\u866B\u5D07\u5BA0\u62BD\u916C\u7574\u8E0C\u7A20\u6101\u7B79\u4EC7\u7EF8\u7785\u4E11\u81ED\u521D\u51FA\u6A71\u53A8\u8E87\u9504\u96CF\u6EC1\u9664\u695A"],
      ["b440", "\u7884\u7885\u7886\u7888\u788A\u788B\u788F\u7890\u7892\u7894\u7895\u7896\u7899\u789D\u789E\u78A0\u78A2\u78A4\u78A6\u78A8", 7, "\u78B5\u78B6\u78B7\u78B8\u78BA\u78BB\u78BC\u78BD\u78BF\u78C0\u78C2\u78C3\u78C4\u78C6\u78C7\u78C8\u78CC\u78CD\u78CE\u78CF\u78D1\u78D2\u78D3\u78D6\u78D7\u78D8\u78DA", 9],
      ["b480", "\u78E4\u78E5\u78E6\u78E7\u78E9\u78EA\u78EB\u78ED", 4, "\u78F3\u78F5\u78F6\u78F8\u78F9\u78FB", 5, "\u7902\u7903\u7904\u7906", 6, "\u7840\u50A8\u77D7\u6410\u89E6\u5904\u63E3\u5DDD\u7A7F\u693D\u4F20\u8239\u5598\u4E32\u75AE\u7A97\u5E62\u5E8A\u95EF\u521B\u5439\u708A\u6376\u9524\u5782\u6625\u693F\u9187\u5507\u6DF3\u7EAF\u8822\u6233\u7EF0\u75B5\u8328\u78C1\u96CC\u8F9E\u6148\u74F7\u8BCD\u6B64\u523A\u8D50\u6B21\u806A\u8471\u56F1\u5306\u4ECE\u4E1B\u51D1\u7C97\u918B\u7C07\u4FC3\u8E7F\u7BE1\u7A9C\u6467\u5D14\u50AC\u8106\u7601\u7CB9\u6DEC\u7FE0\u6751\u5B58\u5BF8\u78CB\u64AE\u6413\u63AA\u632B\u9519\u642D\u8FBE\u7B54\u7629\u6253\u5927\u5446\u6B79\u50A3\u6234\u5E26\u6B86\u4EE3\u8D37\u888B\u5F85\u902E"],
      ["b540", "\u790D", 5, "\u7914", 9, "\u791F", 4, "\u7925", 14, "\u7935", 4, "\u793D\u793F\u7942\u7943\u7944\u7945\u7947\u794A", 8, "\u7954\u7955\u7958\u7959\u7961\u7963"],
      ["b580", "\u7964\u7966\u7969\u796A\u796B\u796C\u796E\u7970", 6, "\u7979\u797B", 4, "\u7982\u7983\u7986\u7987\u7988\u7989\u798B\u798C\u798D\u798E\u7990\u7991\u7992\u6020\u803D\u62C5\u4E39\u5355\u90F8\u63B8\u80C6\u65E6\u6C2E\u4F46\u60EE\u6DE1\u8BDE\u5F39\u86CB\u5F53\u6321\u515A\u8361\u6863\u5200\u6363\u8E48\u5012\u5C9B\u7977\u5BFC\u5230\u7A3B\u60BC\u9053\u76D7\u5FB7\u5F97\u7684\u8E6C\u706F\u767B\u7B49\u77AA\u51F3\u9093\u5824\u4F4E\u6EF4\u8FEA\u654C\u7B1B\u72C4\u6DA4\u7FDF\u5AE1\u62B5\u5E95\u5730\u8482\u7B2C\u5E1D\u5F1F\u9012\u7F14\u98A0\u6382\u6EC7\u7898\u70B9\u5178\u975B\u57AB\u7535\u4F43\u7538\u5E97\u60E6\u5960\u6DC0\u6BBF\u7889\u53FC\u96D5\u51CB\u5201\u6389\u540A\u9493\u8C03\u8DCC\u7239\u789F\u8776\u8FED\u8C0D\u53E0"],
      ["b640", "\u7993", 6, "\u799B", 11, "\u79A8", 10, "\u79B4", 4, "\u79BC\u79BF\u79C2\u79C4\u79C5\u79C7\u79C8\u79CA\u79CC\u79CE\u79CF\u79D0\u79D3\u79D4\u79D6\u79D7\u79D9", 5, "\u79E0\u79E1\u79E2\u79E5\u79E8\u79EA"],
      ["b680", "\u79EC\u79EE\u79F1", 6, "\u79F9\u79FA\u79FC\u79FE\u79FF\u7A01\u7A04\u7A05\u7A07\u7A08\u7A09\u7A0A\u7A0C\u7A0F", 4, "\u7A15\u7A16\u7A18\u7A19\u7A1B\u7A1C\u4E01\u76EF\u53EE\u9489\u9876\u9F0E\u952D\u5B9A\u8BA2\u4E22\u4E1C\u51AC\u8463\u61C2\u52A8\u680B\u4F97\u606B\u51BB\u6D1E\u515C\u6296\u6597\u9661\u8C46\u9017\u75D8\u90FD\u7763\u6BD2\u728A\u72EC\u8BFB\u5835\u7779\u8D4C\u675C\u9540\u809A\u5EA6\u6E21\u5992\u7AEF\u77ED\u953B\u6BB5\u65AD\u7F0E\u5806\u5151\u961F\u5BF9\u58A9\u5428\u8E72\u6566\u987F\u56E4\u949D\u76FE\u9041\u6387\u54C6\u591A\u593A\u579B\u8EB2\u6735\u8DFA\u8235\u5241\u60F0\u5815\u86FE\u5CE8\u9E45\u4FC4\u989D\u8BB9\u5A25\u6076\u5384\u627C\u904F\u9102\u997F\u6069\u800C\u513F\u8033\u5C14\u9975\u6D31\u4E8C"],
      ["b740", "\u7A1D\u7A1F\u7A21\u7A22\u7A24", 14, "\u7A34\u7A35\u7A36\u7A38\u7A3A\u7A3E\u7A40", 5, "\u7A47", 9, "\u7A52", 4, "\u7A58", 16],
      ["b780", "\u7A69", 6, "\u7A71\u7A72\u7A73\u7A75\u7A7B\u7A7C\u7A7D\u7A7E\u7A82\u7A85\u7A87\u7A89\u7A8A\u7A8B\u7A8C\u7A8E\u7A8F\u7A90\u7A93\u7A94\u7A99\u7A9A\u7A9B\u7A9E\u7AA1\u7AA2\u8D30\u53D1\u7F5A\u7B4F\u4F10\u4E4F\u9600\u6CD5\u73D0\u85E9\u5E06\u756A\u7FFB\u6A0A\u77FE\u9492\u7E41\u51E1\u70E6\u53CD\u8FD4\u8303\u8D29\u72AF\u996D\u6CDB\u574A\u82B3\u65B9\u80AA\u623F\u9632\u59A8\u4EFF\u8BBF\u7EBA\u653E\u83F2\u975E\u5561\u98DE\u80A5\u532A\u8BFD\u5420\u80BA\u5E9F\u6CB8\u8D39\u82AC\u915A\u5429\u6C1B\u5206\u7EB7\u575F\u711A\u6C7E\u7C89\u594B\u4EFD\u5FFF\u6124\u7CAA\u4E30\u5C01\u67AB\u8702\u5CF0\u950B\u98CE\u75AF\u70FD\u9022\u51AF\u7F1D\u8BBD\u5949\u51E4\u4F5B\u5426\u592B\u6577\u80A4\u5B75\u6276\u62C2\u8F90\u5E45\u6C1F\u7B26\u4F0F\u4FD8\u670D"],
      ["b840", "\u7AA3\u7AA4\u7AA7\u7AA9\u7AAA\u7AAB\u7AAE", 4, "\u7AB4", 10, "\u7AC0", 10, "\u7ACC", 9, "\u7AD7\u7AD8\u7ADA\u7ADB\u7ADC\u7ADD\u7AE1\u7AE2\u7AE4\u7AE7", 5, "\u7AEE\u7AF0\u7AF1\u7AF2\u7AF3"],
      ["b880", "\u7AF4", 4, "\u7AFB\u7AFC\u7AFE\u7B00\u7B01\u7B02\u7B05\u7B07\u7B09\u7B0C\u7B0D\u7B0E\u7B10\u7B12\u7B13\u7B16\u7B17\u7B18\u7B1A\u7B1C\u7B1D\u7B1F\u7B21\u7B22\u7B23\u7B27\u7B29\u7B2D\u6D6E\u6DAA\u798F\u88B1\u5F17\u752B\u629A\u8F85\u4FEF\u91DC\u65A7\u812F\u8151\u5E9C\u8150\u8D74\u526F\u8986\u8D4B\u590D\u5085\u4ED8\u961C\u7236\u8179\u8D1F\u5BCC\u8BA3\u9644\u5987\u7F1A\u5490\u5676\u560E\u8BE5\u6539\u6982\u9499\u76D6\u6E89\u5E72\u7518\u6746\u67D1\u7AFF\u809D\u8D76\u611F\u79C6\u6562\u8D63\u5188\u521A\u94A2\u7F38\u809B\u7EB2\u5C97\u6E2F\u6760\u7BD9\u768B\u9AD8\u818F\u7F94\u7CD5\u641E\u9550\u7A3F\u544A\u54E5\u6B4C\u6401\u6208\u9E3D\u80F3\u7599\u5272\u9769\u845B\u683C\u86E4\u9601\u9694\u94EC\u4E2A\u5404\u7ED9\u6839\u8DDF\u8015\u66F4\u5E9A\u7FB9"],
      ["b940", "\u7B2F\u7B30\u7B32\u7B34\u7B35\u7B36\u7B37\u7B39\u7B3B\u7B3D\u7B3F", 5, "\u7B46\u7B48\u7B4A\u7B4D\u7B4E\u7B53\u7B55\u7B57\u7B59\u7B5C\u7B5E\u7B5F\u7B61\u7B63", 10, "\u7B6F\u7B70\u7B73\u7B74\u7B76\u7B78\u7B7A\u7B7C\u7B7D\u7B7F\u7B81\u7B82\u7B83\u7B84\u7B86", 6, "\u7B8E\u7B8F"],
      ["b980", "\u7B91\u7B92\u7B93\u7B96\u7B98\u7B99\u7B9A\u7B9B\u7B9E\u7B9F\u7BA0\u7BA3\u7BA4\u7BA5\u7BAE\u7BAF\u7BB0\u7BB2\u7BB3\u7BB5\u7BB6\u7BB7\u7BB9", 7, "\u7BC2\u7BC3\u7BC4\u57C2\u803F\u6897\u5DE5\u653B\u529F\u606D\u9F9A\u4F9B\u8EAC\u516C\u5BAB\u5F13\u5DE9\u6C5E\u62F1\u8D21\u5171\u94A9\u52FE\u6C9F\u82DF\u72D7\u57A2\u6784\u8D2D\u591F\u8F9C\u83C7\u5495\u7B8D\u4F30\u6CBD\u5B64\u59D1\u9F13\u53E4\u86CA\u9AA8\u8C37\u80A1\u6545\u987E\u56FA\u96C7\u522E\u74DC\u5250\u5BE1\u6302\u8902\u4E56\u62D0\u602A\u68FA\u5173\u5B98\u51A0\u89C2\u7BA1\u9986\u7F50\u60EF\u704C\u8D2F\u5149\u5E7F\u901B\u7470\u89C4\u572D\u7845\u5F52\u9F9F\u95FA\u8F68\u9B3C\u8BE1\u7678\u6842\u67DC\u8DEA\u8D35\u523D\u8F8A\u6EDA\u68CD\u9505\u90ED\u56FD\u679C\u88F9\u8FC7\u54C8"],
      ["ba40", "\u7BC5\u7BC8\u7BC9\u7BCA\u7BCB\u7BCD\u7BCE\u7BCF\u7BD0\u7BD2\u7BD4", 4, "\u7BDB\u7BDC\u7BDE\u7BDF\u7BE0\u7BE2\u7BE3\u7BE4\u7BE7\u7BE8\u7BE9\u7BEB\u7BEC\u7BED\u7BEF\u7BF0\u7BF2", 4, "\u7BF8\u7BF9\u7BFA\u7BFB\u7BFD\u7BFF", 7, "\u7C08\u7C09\u7C0A\u7C0D\u7C0E\u7C10", 5, "\u7C17\u7C18\u7C19"],
      ["ba80", "\u7C1A", 4, "\u7C20", 5, "\u7C28\u7C29\u7C2B", 12, "\u7C39", 5, "\u7C42\u9AB8\u5B69\u6D77\u6C26\u4EA5\u5BB3\u9A87\u9163\u61A8\u90AF\u97E9\u542B\u6DB5\u5BD2\u51FD\u558A\u7F55\u7FF0\u64BC\u634D\u65F1\u61BE\u608D\u710A\u6C57\u6C49\u592F\u676D\u822A\u58D5\u568E\u8C6A\u6BEB\u90DD\u597D\u8017\u53F7\u6D69\u5475\u559D\u8377\u83CF\u6838\u79BE\u548C\u4F55\u5408\u76D2\u8C89\u9602\u6CB3\u6DB8\u8D6B\u8910\u9E64\u8D3A\u563F\u9ED1\u75D5\u5F88\u72E0\u6068\u54FC\u4EA8\u6A2A\u8861\u6052\u8F70\u54C4\u70D8\u8679\u9E3F\u6D2A\u5B8F\u5F18\u7EA2\u5589\u4FAF\u7334\u543C\u539A\u5019\u540E\u547C\u4E4E\u5FFD\u745A\u58F6\u846B\u80E1\u8774\u72D0\u7CCA\u6E56"],
      ["bb40", "\u7C43", 9, "\u7C4E", 36, "\u7C75", 5, "\u7C7E", 9],
      ["bb80", "\u7C88\u7C8A", 6, "\u7C93\u7C94\u7C96\u7C99\u7C9A\u7C9B\u7CA0\u7CA1\u7CA3\u7CA6\u7CA7\u7CA8\u7CA9\u7CAB\u7CAC\u7CAD\u7CAF\u7CB0\u7CB4", 4, "\u7CBA\u7CBB\u5F27\u864E\u552C\u62A4\u4E92\u6CAA\u6237\u82B1\u54D7\u534E\u733E\u6ED1\u753B\u5212\u5316\u8BDD\u69D0\u5F8A\u6000\u6DEE\u574F\u6B22\u73AF\u6853\u8FD8\u7F13\u6362\u60A3\u5524\u75EA\u8C62\u7115\u6DA3\u5BA6\u5E7B\u8352\u614C\u9EC4\u78FA\u8757\u7C27\u7687\u51F0\u60F6\u714C\u6643\u5E4C\u604D\u8C0E\u7070\u6325\u8F89\u5FBD\u6062\u86D4\u56DE\u6BC1\u6094\u6167\u5349\u60E0\u6666\u8D3F\u79FD\u4F1A\u70E9\u6C47\u8BB3\u8BF2\u7ED8\u8364\u660F\u5A5A\u9B42\u6D51\u6DF7\u8C41\u6D3B\u4F19\u706B\u83B7\u6216\u60D1\u970D\u8D27\u7978\u51FB\u573E\u57FA\u673A\u7578\u7A3D\u79EF\u7B95"],
      ["bc40", "\u7CBF\u7CC0\u7CC2\u7CC3\u7CC4\u7CC6\u7CC9\u7CCB\u7CCE", 6, "\u7CD8\u7CDA\u7CDB\u7CDD\u7CDE\u7CE1", 6, "\u7CE9", 5, "\u7CF0", 7, "\u7CF9\u7CFA\u7CFC", 13, "\u7D0B", 5],
      ["bc80", "\u7D11", 14, "\u7D21\u7D23\u7D24\u7D25\u7D26\u7D28\u7D29\u7D2A\u7D2C\u7D2D\u7D2E\u7D30", 6, "\u808C\u9965\u8FF9\u6FC0\u8BA5\u9E21\u59EC\u7EE9\u7F09\u5409\u6781\u68D8\u8F91\u7C4D\u96C6\u53CA\u6025\u75BE\u6C72\u5373\u5AC9\u7EA7\u6324\u51E0\u810A\u5DF1\u84DF\u6280\u5180\u5B63\u4F0E\u796D\u5242\u60B8\u6D4E\u5BC4\u5BC2\u8BA1\u8BB0\u65E2\u5FCC\u9645\u5993\u7EE7\u7EAA\u5609\u67B7\u5939\u4F73\u5BB6\u52A0\u835A\u988A\u8D3E\u7532\u94BE\u5047\u7A3C\u4EF7\u67B6\u9A7E\u5AC1\u6B7C\u76D1\u575A\u5C16\u7B3A\u95F4\u714E\u517C\u80A9\u8270\u5978\u7F04\u8327\u68C0\u67EC\u78B1\u7877\u62E3\u6361\u7B80\u4FED\u526A\u51CF\u8350\u69DB\u9274\u8DF5\u8D31\u89C1\u952E\u7BAD\u4EF6"],
      ["bd40", "\u7D37", 54, "\u7D6F", 7],
      ["bd80", "\u7D78", 32, "\u5065\u8230\u5251\u996F\u6E10\u6E85\u6DA7\u5EFA\u50F5\u59DC\u5C06\u6D46\u6C5F\u7586\u848B\u6868\u5956\u8BB2\u5320\u9171\u964D\u8549\u6912\u7901\u7126\u80F6\u4EA4\u90CA\u6D47\u9A84\u5A07\u56BC\u6405\u94F0\u77EB\u4FA5\u811A\u72E1\u89D2\u997A\u7F34\u7EDE\u527F\u6559\u9175\u8F7F\u8F83\u53EB\u7A96\u63ED\u63A5\u7686\u79F8\u8857\u9636\u622A\u52AB\u8282\u6854\u6770\u6377\u776B\u7AED\u6D01\u7ED3\u89E3\u59D0\u6212\u85C9\u82A5\u754C\u501F\u4ECB\u75A5\u8BEB\u5C4A\u5DFE\u7B4B\u65A4\u91D1\u4ECA\u6D25\u895F\u7D27\u9526\u4EC5\u8C28\u8FDB\u9773\u664B\u7981\u8FD1\u70EC\u6D78"],
      ["be40", "\u7D99", 12, "\u7DA7", 6, "\u7DAF", 42],
      ["be80", "\u7DDA", 32, "\u5C3D\u52B2\u8346\u5162\u830E\u775B\u6676\u9CB8\u4EAC\u60CA\u7CBE\u7CB3\u7ECF\u4E95\u8B66\u666F\u9888\u9759\u5883\u656C\u955C\u5F84\u75C9\u9756\u7ADF\u7ADE\u51C0\u70AF\u7A98\u63EA\u7A76\u7EA0\u7396\u97ED\u4E45\u7078\u4E5D\u9152\u53A9\u6551\u65E7\u81FC\u8205\u548E\u5C31\u759A\u97A0\u62D8\u72D9\u75BD\u5C45\u9A79\u83CA\u5C40\u5480\u77E9\u4E3E\u6CAE\u805A\u62D2\u636E\u5DE8\u5177\u8DDD\u8E1E\u952F\u4FF1\u53E5\u60E7\u70AC\u5267\u6350\u9E43\u5A1F\u5026\u7737\u5377\u7EE2\u6485\u652B\u6289\u6398\u5014\u7235\u89C9\u51B3\u8BC0\u7EDD\u5747\u83CC\u94A7\u519B\u541B\u5CFB"],
      ["bf40", "\u7DFB", 62],
      ["bf80", "\u7E3A\u7E3C", 4, "\u7E42", 4, "\u7E48", 21, "\u4FCA\u7AE3\u6D5A\u90E1\u9A8F\u5580\u5496\u5361\u54AF\u5F00\u63E9\u6977\u51EF\u6168\u520A\u582A\u52D8\u574E\u780D\u770B\u5EB7\u6177\u7CE0\u625B\u6297\u4EA2\u7095\u8003\u62F7\u70E4\u9760\u5777\u82DB\u67EF\u68F5\u78D5\u9897\u79D1\u58F3\u54B3\u53EF\u6E34\u514B\u523B\u5BA2\u8BFE\u80AF\u5543\u57A6\u6073\u5751\u542D\u7A7A\u6050\u5B54\u63A7\u62A0\u53E3\u6263\u5BC7\u67AF\u54ED\u7A9F\u82E6\u9177\u5E93\u88E4\u5938\u57AE\u630E\u8DE8\u80EF\u5757\u7B77\u4FA9\u5FEB\u5BBD\u6B3E\u5321\u7B50\u72C2\u6846\u77FF\u7736\u65F7\u51B5\u4E8F\u76D4\u5CBF\u7AA5\u8475\u594E\u9B41\u5080"],
      ["c040", "\u7E5E", 35, "\u7E83", 23, "\u7E9C\u7E9D\u7E9E"],
      ["c080", "\u7EAE\u7EB4\u7EBB\u7EBC\u7ED6\u7EE4\u7EEC\u7EF9\u7F0A\u7F10\u7F1E\u7F37\u7F39\u7F3B", 6, "\u7F43\u7F46", 9, "\u7F52\u7F53\u9988\u6127\u6E83\u5764\u6606\u6346\u56F0\u62EC\u6269\u5ED3\u9614\u5783\u62C9\u5587\u8721\u814A\u8FA3\u5566\u83B1\u6765\u8D56\u84DD\u5A6A\u680F\u62E6\u7BEE\u9611\u5170\u6F9C\u8C30\u63FD\u89C8\u61D2\u7F06\u70C2\u6EE5\u7405\u6994\u72FC\u5ECA\u90CE\u6717\u6D6A\u635E\u52B3\u7262\u8001\u4F6C\u59E5\u916A\u70D9\u6D9D\u52D2\u4E50\u96F7\u956D\u857E\u78CA\u7D2F\u5121\u5792\u64C2\u808B\u7C7B\u6CEA\u68F1\u695E\u51B7\u5398\u68A8\u7281\u9ECE\u7BF1\u72F8\u79BB\u6F13\u7406\u674E\u91CC\u9CA4\u793C\u8389\u8354\u540F\u6817\u4E3D\u5389\u52B1\u783E\u5386\u5229\u5088\u4F8B\u4FD0"],
      ["c140", "\u7F56\u7F59\u7F5B\u7F5C\u7F5D\u7F5E\u7F60\u7F63", 4, "\u7F6B\u7F6C\u7F6D\u7F6F\u7F70\u7F73\u7F75\u7F76\u7F77\u7F78\u7F7A\u7F7B\u7F7C\u7F7D\u7F7F\u7F80\u7F82", 7, "\u7F8B\u7F8D\u7F8F", 4, "\u7F95", 4, "\u7F9B\u7F9C\u7FA0\u7FA2\u7FA3\u7FA5\u7FA6\u7FA8", 6, "\u7FB1"],
      ["c180", "\u7FB3", 4, "\u7FBA\u7FBB\u7FBE\u7FC0\u7FC2\u7FC3\u7FC4\u7FC6\u7FC7\u7FC8\u7FC9\u7FCB\u7FCD\u7FCF", 4, "\u7FD6\u7FD7\u7FD9", 5, "\u7FE2\u7FE3\u75E2\u7ACB\u7C92\u6CA5\u96B6\u529B\u7483\u54E9\u4FE9\u8054\u83B2\u8FDE\u9570\u5EC9\u601C\u6D9F\u5E18\u655B\u8138\u94FE\u604B\u70BC\u7EC3\u7CAE\u51C9\u6881\u7CB1\u826F\u4E24\u8F86\u91CF\u667E\u4EAE\u8C05\u64A9\u804A\u50DA\u7597\u71CE\u5BE5\u8FBD\u6F66\u4E86\u6482\u9563\u5ED6\u6599\u5217\u88C2\u70C8\u52A3\u730E\u7433\u6797\u78F7\u9716\u4E34\u90BB\u9CDE\u6DCB\u51DB\u8D41\u541D\u62CE\u73B2\u83F1\u96F6\u9F84\u94C3\u4F36\u7F9A\u51CC\u7075\u9675\u5CAD\u9886\u53E6\u4EE4\u6E9C\u7409\u69B4\u786B\u998F\u7559\u5218\u7624\u6D41\u67F3\u516D\u9F99\u804B\u5499\u7B3C\u7ABF"],
      ["c240", "\u7FE4\u7FE7\u7FE8\u7FEA\u7FEB\u7FEC\u7FED\u7FEF\u7FF2\u7FF4", 6, "\u7FFD\u7FFE\u7FFF\u8002\u8007\u8008\u8009\u800A\u800E\u800F\u8011\u8013\u801A\u801B\u801D\u801E\u801F\u8021\u8023\u8024\u802B", 5, "\u8032\u8034\u8039\u803A\u803C\u803E\u8040\u8041\u8044\u8045\u8047\u8048\u8049\u804E\u804F\u8050\u8051\u8053\u8055\u8056\u8057"],
      ["c280", "\u8059\u805B", 13, "\u806B", 5, "\u8072", 11, "\u9686\u5784\u62E2\u9647\u697C\u5A04\u6402\u7BD3\u6F0F\u964B\u82A6\u5362\u9885\u5E90\u7089\u63B3\u5364\u864F\u9C81\u9E93\u788C\u9732\u8DEF\u8D42\u9E7F\u6F5E\u7984\u5F55\u9646\u622E\u9A74\u5415\u94DD\u4FA3\u65C5\u5C65\u5C61\u7F15\u8651\u6C2F\u5F8B\u7387\u6EE4\u7EFF\u5CE6\u631B\u5B6A\u6EE6\u5375\u4E71\u63A0\u7565\u62A1\u8F6E\u4F26\u4ED1\u6CA6\u7EB6\u8BBA\u841D\u87BA\u7F57\u903B\u9523\u7BA9\u9AA1\u88F8\u843D\u6D1B\u9A86\u7EDC\u5988\u9EBB\u739B\u7801\u8682\u9A6C\u9A82\u561B\u5417\u57CB\u4E70\u9EA6\u5356\u8FC8\u8109\u7792\u9992\u86EE\u6EE1\u8513\u66FC\u6162\u6F2B"],
      ["c340", "\u807E\u8081\u8082\u8085\u8088\u808A\u808D", 5, "\u8094\u8095\u8097\u8099\u809E\u80A3\u80A6\u80A7\u80A8\u80AC\u80B0\u80B3\u80B5\u80B6\u80B8\u80B9\u80BB\u80C5\u80C7", 4, "\u80CF", 6, "\u80D8\u80DF\u80E0\u80E2\u80E3\u80E6\u80EE\u80F5\u80F7\u80F9\u80FB\u80FE\u80FF\u8100\u8101\u8103\u8104\u8105\u8107\u8108\u810B"],
      ["c380", "\u810C\u8115\u8117\u8119\u811B\u811C\u811D\u811F", 12, "\u812D\u812E\u8130\u8133\u8134\u8135\u8137\u8139", 4, "\u813F\u8C29\u8292\u832B\u76F2\u6C13\u5FD9\u83BD\u732B\u8305\u951A\u6BDB\u77DB\u94C6\u536F\u8302\u5192\u5E3D\u8C8C\u8D38\u4E48\u73AB\u679A\u6885\u9176\u9709\u7164\u6CA1\u7709\u5A92\u9541\u6BCF\u7F8E\u6627\u5BD0\u59B9\u5A9A\u95E8\u95F7\u4EEC\u840C\u8499\u6AAC\u76DF\u9530\u731B\u68A6\u5B5F\u772F\u919A\u9761\u7CDC\u8FF7\u8C1C\u5F25\u7C73\u79D8\u89C5\u6CCC\u871C\u5BC6\u5E42\u68C9\u7720\u7EF5\u5195\u514D\u52C9\u5A29\u7F05\u9762\u82D7\u63CF\u7784\u85D0\u79D2\u6E3A\u5E99\u5999\u8511\u706D\u6C11\u62BF\u76BF\u654F\u60AF\u95FD\u660E\u879F\u9E23\u94ED\u540D\u547D\u8C2C\u6478"],
      ["c440", "\u8140", 5, "\u8147\u8149\u814D\u814E\u814F\u8152\u8156\u8157\u8158\u815B", 4, "\u8161\u8162\u8163\u8164\u8166\u8168\u816A\u816B\u816C\u816F\u8172\u8173\u8175\u8176\u8177\u8178\u8181\u8183", 4, "\u8189\u818B\u818C\u818D\u818E\u8190\u8192", 5, "\u8199\u819A\u819E", 4, "\u81A4\u81A5"],
      ["c480", "\u81A7\u81A9\u81AB", 7, "\u81B4", 5, "\u81BC\u81BD\u81BE\u81BF\u81C4\u81C5\u81C7\u81C8\u81C9\u81CB\u81CD", 6, "\u6479\u8611\u6A21\u819C\u78E8\u6469\u9B54\u62B9\u672B\u83AB\u58A8\u9ED8\u6CAB\u6F20\u5BDE\u964C\u8C0B\u725F\u67D0\u62C7\u7261\u4EA9\u59C6\u6BCD\u5893\u66AE\u5E55\u52DF\u6155\u6728\u76EE\u7766\u7267\u7A46\u62FF\u54EA\u5450\u94A0\u90A3\u5A1C\u7EB3\u6C16\u4E43\u5976\u8010\u5948\u5357\u7537\u96BE\u56CA\u6320\u8111\u607C\u95F9\u6DD6\u5462\u9981\u5185\u5AE9\u80FD\u59AE\u9713\u502A\u6CE5\u5C3C\u62DF\u4F60\u533F\u817B\u9006\u6EBA\u852B\u62C8\u5E74\u78BE\u64B5\u637B\u5FF5\u5A18\u917F\u9E1F\u5C3F\u634F\u8042\u5B7D\u556E\u954A\u954D\u6D85\u60A8\u67E0\u72DE\u51DD\u5B81"],
      ["c540", "\u81D4", 14, "\u81E4\u81E5\u81E6\u81E8\u81E9\u81EB\u81EE", 4, "\u81F5", 5, "\u81FD\u81FF\u8203\u8207", 4, "\u820E\u820F\u8211\u8213\u8215", 5, "\u821D\u8220\u8224\u8225\u8226\u8227\u8229\u822E\u8232\u823A\u823C\u823D\u823F"],
      ["c580", "\u8240\u8241\u8242\u8243\u8245\u8246\u8248\u824A\u824C\u824D\u824E\u8250", 7, "\u8259\u825B\u825C\u825D\u825E\u8260", 7, "\u8269\u62E7\u6CDE\u725B\u626D\u94AE\u7EBD\u8113\u6D53\u519C\u5F04\u5974\u52AA\u6012\u5973\u6696\u8650\u759F\u632A\u61E6\u7CEF\u8BFA\u54E6\u6B27\u9E25\u6BB4\u85D5\u5455\u5076\u6CA4\u556A\u8DB4\u722C\u5E15\u6015\u7436\u62CD\u6392\u724C\u5F98\u6E43\u6D3E\u6500\u6F58\u76D8\u78D0\u76FC\u7554\u5224\u53DB\u4E53\u5E9E\u65C1\u802A\u80D6\u629B\u5486\u5228\u70AE\u888D\u8DD1\u6CE1\u5478\u80DA\u57F9\u88F4\u8D54\u966A\u914D\u4F69\u6C9B\u55B7\u76C6\u7830\u62A8\u70F9\u6F8E\u5F6D\u84EC\u68DA\u787C\u7BF7\u81A8\u670B\u9E4F\u6367\u78B0\u576F\u7812\u9739\u6279\u62AB\u5288\u7435\u6BD7"],
      ["c640", "\u826A\u826B\u826C\u826D\u8271\u8275\u8276\u8277\u8278\u827B\u827C\u8280\u8281\u8283\u8285\u8286\u8287\u8289\u828C\u8290\u8293\u8294\u8295\u8296\u829A\u829B\u829E\u82A0\u82A2\u82A3\u82A7\u82B2\u82B5\u82B6\u82BA\u82BB\u82BC\u82BF\u82C0\u82C2\u82C3\u82C5\u82C6\u82C9\u82D0\u82D6\u82D9\u82DA\u82DD\u82E2\u82E7\u82E8\u82E9\u82EA\u82EC\u82ED\u82EE\u82F0\u82F2\u82F3\u82F5\u82F6\u82F8"],
      ["c680", "\u82FA\u82FC", 4, "\u830A\u830B\u830D\u8310\u8312\u8313\u8316\u8318\u8319\u831D", 9, "\u8329\u832A\u832E\u8330\u8332\u8337\u833B\u833D\u5564\u813E\u75B2\u76AE\u5339\u75DE\u50FB\u5C41\u8B6C\u7BC7\u504F\u7247\u9A97\u98D8\u6F02\u74E2\u7968\u6487\u77A5\u62FC\u9891\u8D2B\u54C1\u8058\u4E52\u576A\u82F9\u840D\u5E73\u51ED\u74F6\u8BC4\u5C4F\u5761\u6CFC\u9887\u5A46\u7834\u9B44\u8FEB\u7C95\u5256\u6251\u94FA\u4EC6\u8386\u8461\u83E9\u84B2\u57D4\u6734\u5703\u666E\u6D66\u8C31\u66DD\u7011\u671F\u6B3A\u6816\u621A\u59BB\u4E03\u51C4\u6F06\u67D2\u6C8F\u5176\u68CB\u5947\u6B67\u7566\u5D0E\u8110\u9F50\u65D7\u7948\u7941\u9A91\u8D77\u5C82\u4E5E\u4F01\u542F\u5951\u780C\u5668\u6C14\u8FC4\u5F03\u6C7D\u6CE3\u8BAB\u6390"],
      ["c740", "\u833E\u833F\u8341\u8342\u8344\u8345\u8348\u834A", 4, "\u8353\u8355", 4, "\u835D\u8362\u8370", 6, "\u8379\u837A\u837E", 6, "\u8387\u8388\u838A\u838B\u838C\u838D\u838F\u8390\u8391\u8394\u8395\u8396\u8397\u8399\u839A\u839D\u839F\u83A1", 6, "\u83AC\u83AD\u83AE"],
      ["c780", "\u83AF\u83B5\u83BB\u83BE\u83BF\u83C2\u83C3\u83C4\u83C6\u83C8\u83C9\u83CB\u83CD\u83CE\u83D0\u83D1\u83D2\u83D3\u83D5\u83D7\u83D9\u83DA\u83DB\u83DE\u83E2\u83E3\u83E4\u83E6\u83E7\u83E8\u83EB\u83EC\u83ED\u6070\u6D3D\u7275\u6266\u948E\u94C5\u5343\u8FC1\u7B7E\u4EDF\u8C26\u4E7E\u9ED4\u94B1\u94B3\u524D\u6F5C\u9063\u6D45\u8C34\u5811\u5D4C\u6B20\u6B49\u67AA\u545B\u8154\u7F8C\u5899\u8537\u5F3A\u62A2\u6A47\u9539\u6572\u6084\u6865\u77A7\u4E54\u4FA8\u5DE7\u9798\u64AC\u7FD8\u5CED\u4FCF\u7A8D\u5207\u8304\u4E14\u602F\u7A83\u94A6\u4FB5\u4EB2\u79E6\u7434\u52E4\u82B9\u64D2\u79BD\u5BDD\u6C81\u9752\u8F7B\u6C22\u503E\u537F\u6E05\u64CE\u6674\u6C30\u60C5\u9877\u8BF7\u5E86\u743C\u7A77\u79CB\u4E18\u90B1\u7403\u6C42\u56DA\u914B\u6CC5\u8D8B\u533A\u86C6\u66F2\u8EAF\u5C48\u9A71\u6E20"],
      ["c840", "\u83EE\u83EF\u83F3", 4, "\u83FA\u83FB\u83FC\u83FE\u83FF\u8400\u8402\u8405\u8407\u8408\u8409\u840A\u8410\u8412", 5, "\u8419\u841A\u841B\u841E", 5, "\u8429", 7, "\u8432", 5, "\u8439\u843A\u843B\u843E", 7, "\u8447\u8448\u8449"],
      ["c880", "\u844A", 6, "\u8452", 4, "\u8458\u845D\u845E\u845F\u8460\u8462\u8464", 4, "\u846A\u846E\u846F\u8470\u8472\u8474\u8477\u8479\u847B\u847C\u53D6\u5A36\u9F8B\u8DA3\u53BB\u5708\u98A7\u6743\u919B\u6CC9\u5168\u75CA\u62F3\u72AC\u5238\u529D\u7F3A\u7094\u7638\u5374\u9E4A\u69B7\u786E\u96C0\u88D9\u7FA4\u7136\u71C3\u5189\u67D3\u74E4\u58E4\u6518\u56B7\u8BA9\u9976\u6270\u7ED5\u60F9\u70ED\u58EC\u4EC1\u4EBA\u5FCD\u97E7\u4EFB\u8BA4\u5203\u598A\u7EAB\u6254\u4ECD\u65E5\u620E\u8338\u84C9\u8363\u878D\u7194\u6EB6\u5BB9\u7ED2\u5197\u63C9\u67D4\u8089\u8339\u8815\u5112\u5B7A\u5982\u8FB1\u4E73\u6C5D\u5165\u8925\u8F6F\u962E\u854A\u745E\u9510\u95F0\u6DA6\u82E5\u5F31\u6492\u6D12\u8428\u816E\u9CC3\u585E\u8D5B\u4E09\u53C1"],
      ["c940", "\u847D", 4, "\u8483\u8484\u8485\u8486\u848A\u848D\u848F", 7, "\u8498\u849A\u849B\u849D\u849E\u849F\u84A0\u84A2", 12, "\u84B0\u84B1\u84B3\u84B5\u84B6\u84B7\u84BB\u84BC\u84BE\u84C0\u84C2\u84C3\u84C5\u84C6\u84C7\u84C8\u84CB\u84CC\u84CE\u84CF\u84D2\u84D4\u84D5\u84D7"],
      ["c980", "\u84D8", 4, "\u84DE\u84E1\u84E2\u84E4\u84E7", 4, "\u84ED\u84EE\u84EF\u84F1", 10, "\u84FD\u84FE\u8500\u8501\u8502\u4F1E\u6563\u6851\u55D3\u4E27\u6414\u9A9A\u626B\u5AC2\u745F\u8272\u6DA9\u68EE\u50E7\u838E\u7802\u6740\u5239\u6C99\u7EB1\u50BB\u5565\u715E\u7B5B\u6652\u73CA\u82EB\u6749\u5C71\u5220\u717D\u886B\u95EA\u9655\u64C5\u8D61\u81B3\u5584\u6C55\u6247\u7F2E\u5892\u4F24\u5546\u8D4F\u664C\u4E0A\u5C1A\u88F3\u68A2\u634E\u7A0D\u70E7\u828D\u52FA\u97F6\u5C11\u54E8\u90B5\u7ECD\u5962\u8D4A\u86C7\u820C\u820D\u8D66\u6444\u5C04\u6151\u6D89\u793E\u8BBE\u7837\u7533\u547B\u4F38\u8EAB\u6DF1\u5A20\u7EC5\u795E\u6C88\u5BA1\u5A76\u751A\u80BE\u614E\u6E17\u58F0\u751F\u7525\u7272\u5347\u7EF3"],
      ["ca40", "\u8503", 8, "\u850D\u850E\u850F\u8510\u8512\u8514\u8515\u8516\u8518\u8519\u851B\u851C\u851D\u851E\u8520\u8522", 8, "\u852D", 9, "\u853E", 4, "\u8544\u8545\u8546\u8547\u854B", 10],
      ["ca80", "\u8557\u8558\u855A\u855B\u855C\u855D\u855F", 4, "\u8565\u8566\u8567\u8569", 8, "\u8573\u8575\u8576\u8577\u8578\u857C\u857D\u857F\u8580\u8581\u7701\u76DB\u5269\u80DC\u5723\u5E08\u5931\u72EE\u65BD\u6E7F\u8BD7\u5C38\u8671\u5341\u77F3\u62FE\u65F6\u4EC0\u98DF\u8680\u5B9E\u8BC6\u53F2\u77E2\u4F7F\u5C4E\u9A76\u59CB\u5F0F\u793A\u58EB\u4E16\u67FF\u4E8B\u62ED\u8A93\u901D\u52BF\u662F\u55DC\u566C\u9002\u4ED5\u4F8D\u91CA\u9970\u6C0F\u5E02\u6043\u5BA4\u89C6\u8BD5\u6536\u624B\u9996\u5B88\u5BFF\u6388\u552E\u53D7\u7626\u517D\u852C\u67A2\u68B3\u6B8A\u6292\u8F93\u53D4\u8212\u6DD1\u758F\u4E66\u8D4E\u5B70\u719F\u85AF\u6691\u66D9\u7F72\u8700\u9ECD\u9F20\u5C5E\u672F\u8FF0\u6811\u675F\u620D\u7AD6\u5885\u5EB6\u6570\u6F31"],
      ["cb40", "\u8582\u8583\u8586\u8588", 6, "\u8590", 10, "\u859D", 6, "\u85A5\u85A6\u85A7\u85A9\u85AB\u85AC\u85AD\u85B1", 5, "\u85B8\u85BA", 6, "\u85C2", 6, "\u85CA", 4, "\u85D1\u85D2"],
      ["cb80", "\u85D4\u85D6", 5, "\u85DD", 6, "\u85E5\u85E6\u85E7\u85E8\u85EA", 14, "\u6055\u5237\u800D\u6454\u8870\u7529\u5E05\u6813\u62F4\u971C\u53CC\u723D\u8C01\u6C34\u7761\u7A0E\u542E\u77AC\u987A\u821C\u8BF4\u7855\u6714\u70C1\u65AF\u6495\u5636\u601D\u79C1\u53F8\u4E1D\u6B7B\u8086\u5BFA\u55E3\u56DB\u4F3A\u4F3C\u9972\u5DF3\u677E\u8038\u6002\u9882\u9001\u5B8B\u8BBC\u8BF5\u641C\u8258\u64DE\u55FD\u82CF\u9165\u4FD7\u7D20\u901F\u7C9F\u50F3\u5851\u6EAF\u5BBF\u8BC9\u8083\u9178\u849C\u7B97\u867D\u968B\u968F\u7EE5\u9AD3\u788E\u5C81\u7A57\u9042\u96A7\u795F\u5B59\u635F\u7B0B\u84D1\u68AD\u5506\u7F29\u7410\u7D22\u9501\u6240\u584C\u4ED6\u5B83\u5979\u5854"],
      ["cc40", "\u85F9\u85FA\u85FC\u85FD\u85FE\u8600", 4, "\u8606", 10, "\u8612\u8613\u8614\u8615\u8617", 15, "\u8628\u862A", 13, "\u8639\u863A\u863B\u863D\u863E\u863F\u8640"],
      ["cc80", "\u8641", 11, "\u8652\u8653\u8655", 4, "\u865B\u865C\u865D\u865F\u8660\u8661\u8663", 7, "\u736D\u631E\u8E4B\u8E0F\u80CE\u82D4\u62AC\u53F0\u6CF0\u915E\u592A\u6001\u6C70\u574D\u644A\u8D2A\u762B\u6EE9\u575B\u6A80\u75F0\u6F6D\u8C2D\u8C08\u5766\u6BEF\u8892\u78B3\u63A2\u53F9\u70AD\u6C64\u5858\u642A\u5802\u68E0\u819B\u5510\u7CD6\u5018\u8EBA\u6DCC\u8D9F\u70EB\u638F\u6D9B\u6ED4\u7EE6\u8404\u6843\u9003\u6DD8\u9676\u8BA8\u5957\u7279\u85E4\u817E\u75BC\u8A8A\u68AF\u5254\u8E22\u9511\u63D0\u9898\u8E44\u557C\u4F53\u66FF\u568F\u60D5\u6D95\u5243\u5C49\u5929\u6DFB\u586B\u7530\u751C\u606C\u8214\u8146\u6311\u6761\u8FE2\u773A\u8DF3\u8D34\u94C1\u5E16\u5385\u542C\u70C3"],
      ["cd40", "\u866D\u866F\u8670\u8672", 6, "\u8683", 6, "\u868E", 4, "\u8694\u8696", 5, "\u869E", 4, "\u86A5\u86A6\u86AB\u86AD\u86AE\u86B2\u86B3\u86B7\u86B8\u86B9\u86BB", 4, "\u86C1\u86C2\u86C3\u86C5\u86C8\u86CC\u86CD\u86D2\u86D3\u86D5\u86D6\u86D7\u86DA\u86DC"],
      ["cd80", "\u86DD\u86E0\u86E1\u86E2\u86E3\u86E5\u86E6\u86E7\u86E8\u86EA\u86EB\u86EC\u86EF\u86F5\u86F6\u86F7\u86FA\u86FB\u86FC\u86FD\u86FF\u8701\u8704\u8705\u8706\u870B\u870C\u870E\u870F\u8710\u8711\u8714\u8716\u6C40\u5EF7\u505C\u4EAD\u5EAD\u633A\u8247\u901A\u6850\u916E\u77B3\u540C\u94DC\u5F64\u7AE5\u6876\u6345\u7B52\u7EDF\u75DB\u5077\u6295\u5934\u900F\u51F8\u79C3\u7A81\u56FE\u5F92\u9014\u6D82\u5C60\u571F\u5410\u5154\u6E4D\u56E2\u63A8\u9893\u817F\u8715\u892A\u9000\u541E\u5C6F\u81C0\u62D6\u6258\u8131\u9E35\u9640\u9A6E\u9A7C\u692D\u59A5\u62D3\u553E\u6316\u54C7\u86D9\u6D3C\u5A03\u74E6\u889C\u6B6A\u5916\u8C4C\u5F2F\u6E7E\u73A9\u987D\u4E38\u70F7\u5B8C\u7897\u633D\u665A\u7696\u60CB\u5B9B\u5A49\u4E07\u8155\u6C6A\u738B\u4EA1\u6789\u7F51\u5F80\u65FA\u671B\u5FD8\u5984\u5A01"],
      ["ce40", "\u8719\u871B\u871D\u871F\u8720\u8724\u8726\u8727\u8728\u872A\u872B\u872C\u872D\u872F\u8730\u8732\u8733\u8735\u8736\u8738\u8739\u873A\u873C\u873D\u8740", 6, "\u874A\u874B\u874D\u874F\u8750\u8751\u8752\u8754\u8755\u8756\u8758\u875A", 5, "\u8761\u8762\u8766", 7, "\u876F\u8771\u8772\u8773\u8775"],
      ["ce80", "\u8777\u8778\u8779\u877A\u877F\u8780\u8781\u8784\u8786\u8787\u8789\u878A\u878C\u878E", 4, "\u8794\u8795\u8796\u8798", 6, "\u87A0", 4, "\u5DCD\u5FAE\u5371\u97E6\u8FDD\u6845\u56F4\u552F\u60DF\u4E3A\u6F4D\u7EF4\u82C7\u840E\u59D4\u4F1F\u4F2A\u5C3E\u7EAC\u672A\u851A\u5473\u754F\u80C3\u5582\u9B4F\u4F4D\u6E2D\u8C13\u5C09\u6170\u536B\u761F\u6E29\u868A\u6587\u95FB\u7EB9\u543B\u7A33\u7D0A\u95EE\u55E1\u7FC1\u74EE\u631D\u8717\u6DA1\u7A9D\u6211\u65A1\u5367\u63E1\u6C83\u5DEB\u545C\u94A8\u4E4C\u6C61\u8BEC\u5C4B\u65E0\u829C\u68A7\u543E\u5434\u6BCB\u6B66\u4E94\u6342\u5348\u821E\u4F0D\u4FAE\u575E\u620A\u96FE\u6664\u7269\u52FF\u52A1\u609F\u8BEF\u6614\u7199\u6790\u897F\u7852\u77FD\u6670\u563B\u5438\u9521\u727A"],
      ["cf40", "\u87A5\u87A6\u87A7\u87A9\u87AA\u87AE\u87B0\u87B1\u87B2\u87B4\u87B6\u87B7\u87B8\u87B9\u87BB\u87BC\u87BE\u87BF\u87C1", 4, "\u87C7\u87C8\u87C9\u87CC", 4, "\u87D4", 6, "\u87DC\u87DD\u87DE\u87DF\u87E1\u87E2\u87E3\u87E4\u87E6\u87E7\u87E8\u87E9\u87EB\u87EC\u87ED\u87EF", 9],
      ["cf80", "\u87FA\u87FB\u87FC\u87FD\u87FF\u8800\u8801\u8802\u8804", 5, "\u880B", 7, "\u8814\u8817\u8818\u8819\u881A\u881C", 4, "\u8823\u7A00\u606F\u5E0C\u6089\u819D\u5915\u60DC\u7184\u70EF\u6EAA\u6C50\u7280\u6A84\u88AD\u5E2D\u4E60\u5AB3\u559C\u94E3\u6D17\u7CFB\u9699\u620F\u7EC6\u778E\u867E\u5323\u971E\u8F96\u6687\u5CE1\u4FA0\u72ED\u4E0B\u53A6\u590F\u5413\u6380\u9528\u5148\u4ED9\u9C9C\u7EA4\u54B8\u8D24\u8854\u8237\u95F2\u6D8E\u5F26\u5ACC\u663E\u9669\u73B0\u732E\u53BF\u817A\u9985\u7FA1\u5BAA\u9677\u9650\u7EBF\u76F8\u53A2\u9576\u9999\u7BB1\u8944\u6E58\u4E61\u7FD4\u7965\u8BE6\u60F3\u54CD\u4EAB\u9879\u5DF7\u6A61\u50CF\u5411\u8C61\u8427\u785D\u9704\u524A\u54EE\u56A3\u9500\u6D88\u5BB5\u6DC6\u6653"],
      ["d040", "\u8824", 13, "\u8833", 5, "\u883A\u883B\u883D\u883E\u883F\u8841\u8842\u8843\u8846", 5, "\u884E", 5, "\u8855\u8856\u8858\u885A", 6, "\u8866\u8867\u886A\u886D\u886F\u8871\u8873\u8874\u8875\u8876\u8878\u8879\u887A"],
      ["d080", "\u887B\u887C\u8880\u8883\u8886\u8887\u8889\u888A\u888C\u888E\u888F\u8890\u8891\u8893\u8894\u8895\u8897", 4, "\u889D", 4, "\u88A3\u88A5", 5, "\u5C0F\u5B5D\u6821\u8096\u5578\u7B11\u6548\u6954\u4E9B\u6B47\u874E\u978B\u534F\u631F\u643A\u90AA\u659C\u80C1\u8C10\u5199\u68B0\u5378\u87F9\u61C8\u6CC4\u6CFB\u8C22\u5C51\u85AA\u82AF\u950C\u6B23\u8F9B\u65B0\u5FFB\u5FC3\u4FE1\u8845\u661F\u8165\u7329\u60FA\u5174\u5211\u578B\u5F62\u90A2\u884C\u9192\u5E78\u674F\u6027\u59D3\u5144\u51F6\u80F8\u5308\u6C79\u96C4\u718A\u4F11\u4FEE\u7F9E\u673D\u55C5\u9508\u79C0\u8896\u7EE3\u589F\u620C\u9700\u865A\u5618\u987B\u5F90\u8BB8\u84C4\u9157\u53D9\u65ED\u5E8F\u755C\u6064\u7D6E\u5A7F\u7EEA\u7EED\u8F69\u55A7\u5BA3\u60AC\u65CB\u7384"],
      ["d140", "\u88AC\u88AE\u88AF\u88B0\u88B2", 4, "\u88B8\u88B9\u88BA\u88BB\u88BD\u88BE\u88BF\u88C0\u88C3\u88C4\u88C7\u88C8\u88CA\u88CB\u88CC\u88CD\u88CF\u88D0\u88D1\u88D3\u88D6\u88D7\u88DA", 4, "\u88E0\u88E1\u88E6\u88E7\u88E9", 6, "\u88F2\u88F5\u88F6\u88F7\u88FA\u88FB\u88FD\u88FF\u8900\u8901\u8903", 5],
      ["d180", "\u8909\u890B", 4, "\u8911\u8914", 4, "\u891C", 4, "\u8922\u8923\u8924\u8926\u8927\u8928\u8929\u892C\u892D\u892E\u892F\u8931\u8932\u8933\u8935\u8937\u9009\u7663\u7729\u7EDA\u9774\u859B\u5B66\u7A74\u96EA\u8840\u52CB\u718F\u5FAA\u65EC\u8BE2\u5BFB\u9A6F\u5DE1\u6B89\u6C5B\u8BAD\u8BAF\u900A\u8FC5\u538B\u62BC\u9E26\u9E2D\u5440\u4E2B\u82BD\u7259\u869C\u5D16\u8859\u6DAF\u96C5\u54D1\u4E9A\u8BB6\u7109\u54BD\u9609\u70DF\u6DF9\u76D0\u4E25\u7814\u8712\u5CA9\u5EF6\u8A00\u989C\u960E\u708E\u6CBF\u5944\u63A9\u773C\u884D\u6F14\u8273\u5830\u71D5\u538C\u781A\u96C1\u5501\u5F66\u7130\u5BB4\u8C1A\u9A8C\u6B83\u592E\u9E2F\u79E7\u6768\u626C\u4F6F\u75A1\u7F8A\u6D0B\u9633\u6C27\u4EF0\u75D2\u517B\u6837\u6F3E\u9080\u8170\u5996\u7476"],
      ["d240", "\u8938", 8, "\u8942\u8943\u8945", 24, "\u8960", 5, "\u8967", 19, "\u897C"],
      ["d280", "\u897D\u897E\u8980\u8982\u8984\u8985\u8987", 26, "\u6447\u5C27\u9065\u7A91\u8C23\u59DA\u54AC\u8200\u836F\u8981\u8000\u6930\u564E\u8036\u7237\u91CE\u51B6\u4E5F\u9875\u6396\u4E1A\u53F6\u66F3\u814B\u591C\u6DB2\u4E00\u58F9\u533B\u63D6\u94F1\u4F9D\u4F0A\u8863\u9890\u5937\u9057\u79FB\u4EEA\u80F0\u7591\u6C82\u5B9C\u59E8\u5F5D\u6905\u8681\u501A\u5DF2\u4E59\u77E3\u4EE5\u827A\u6291\u6613\u9091\u5C79\u4EBF\u5F79\u81C6\u9038\u8084\u75AB\u4EA6\u88D4\u610F\u6BC5\u5FC6\u4E49\u76CA\u6EA2\u8BE3\u8BAE\u8C0A\u8BD1\u5F02\u7FFC\u7FCC\u7ECE\u8335\u836B\u56E0\u6BB7\u97F3\u9634\u59FB\u541F\u94F6\u6DEB\u5BC5\u996E\u5C39\u5F15\u9690"],
      ["d340", "\u89A2", 30, "\u89C3\u89CD\u89D3\u89D4\u89D5\u89D7\u89D8\u89D9\u89DB\u89DD\u89DF\u89E0\u89E1\u89E2\u89E4\u89E7\u89E8\u89E9\u89EA\u89EC\u89ED\u89EE\u89F0\u89F1\u89F2\u89F4", 6],
      ["d380", "\u89FB", 4, "\u8A01", 5, "\u8A08", 21, "\u5370\u82F1\u6A31\u5A74\u9E70\u5E94\u7F28\u83B9\u8424\u8425\u8367\u8747\u8FCE\u8D62\u76C8\u5F71\u9896\u786C\u6620\u54DF\u62E5\u4F63\u81C3\u75C8\u5EB8\u96CD\u8E0A\u86F9\u548F\u6CF3\u6D8C\u6C38\u607F\u52C7\u7528\u5E7D\u4F18\u60A0\u5FE7\u5C24\u7531\u90AE\u94C0\u72B9\u6CB9\u6E38\u9149\u6709\u53CB\u53F3\u4F51\u91C9\u8BF1\u53C8\u5E7C\u8FC2\u6DE4\u4E8E\u76C2\u6986\u865E\u611A\u8206\u4F59\u4FDE\u903E\u9C7C\u6109\u6E1D\u6E14\u9685\u4E88\u5A31\u96E8\u4E0E\u5C7F\u79B9\u5B87\u8BED\u7FBD\u7389\u57DF\u828B\u90C1\u5401\u9047\u55BB\u5CEA\u5FA1\u6108\u6B32\u72F1\u80B2\u8A89"],
      ["d440", "\u8A1E", 31, "\u8A3F", 8, "\u8A49", 21],
      ["d480", "\u8A5F", 25, "\u8A7A", 6, "\u6D74\u5BD3\u88D5\u9884\u8C6B\u9A6D\u9E33\u6E0A\u51A4\u5143\u57A3\u8881\u539F\u63F4\u8F95\u56ED\u5458\u5706\u733F\u6E90\u7F18\u8FDC\u82D1\u613F\u6028\u9662\u66F0\u7EA6\u8D8A\u8DC3\u94A5\u5CB3\u7CA4\u6708\u60A6\u9605\u8018\u4E91\u90E7\u5300\u9668\u5141\u8FD0\u8574\u915D\u6655\u97F5\u5B55\u531D\u7838\u6742\u683D\u54C9\u707E\u5BB0\u8F7D\u518D\u5728\u54B1\u6512\u6682\u8D5E\u8D43\u810F\u846C\u906D\u7CDF\u51FF\u85FB\u67A3\u65E9\u6FA1\u86A4\u8E81\u566A\u9020\u7682\u7076\u71E5\u8D23\u62E9\u5219\u6CFD\u8D3C\u600E\u589E\u618E\u66FE\u8D60\u624E\u55B3\u6E23\u672D\u8F67"],
      ["d540", "\u8A81", 7, "\u8A8B", 7, "\u8A94", 46],
      ["d580", "\u8AC3", 32, "\u94E1\u95F8\u7728\u6805\u69A8\u548B\u4E4D\u70B8\u8BC8\u6458\u658B\u5B85\u7A84\u503A\u5BE8\u77BB\u6BE1\u8A79\u7C98\u6CBE\u76CF\u65A9\u8F97\u5D2D\u5C55\u8638\u6808\u5360\u6218\u7AD9\u6E5B\u7EFD\u6A1F\u7AE0\u5F70\u6F33\u5F20\u638C\u6DA8\u6756\u4E08\u5E10\u8D26\u4ED7\u80C0\u7634\u969C\u62DB\u662D\u627E\u6CBC\u8D75\u7167\u7F69\u5146\u8087\u53EC\u906E\u6298\u54F2\u86F0\u8F99\u8005\u9517\u8517\u8FD9\u6D59\u73CD\u659F\u771F\u7504\u7827\u81FB\u8D1E\u9488\u4FA6\u6795\u75B9\u8BCA\u9707\u632F\u9547\u9635\u84B8\u6323\u7741\u5F81\u72F0\u4E89\u6014\u6574\u62EF\u6B63\u653F"],
      ["d640", "\u8AE4", 34, "\u8B08", 27],
      ["d680", "\u8B24\u8B25\u8B27", 30, "\u5E27\u75C7\u90D1\u8BC1\u829D\u679D\u652F\u5431\u8718\u77E5\u80A2\u8102\u6C41\u4E4B\u7EC7\u804C\u76F4\u690D\u6B96\u6267\u503C\u4F84\u5740\u6307\u6B62\u8DBE\u53EA\u65E8\u7EB8\u5FD7\u631A\u63B7\u81F3\u81F4\u7F6E\u5E1C\u5CD9\u5236\u667A\u79E9\u7A1A\u8D28\u7099\u75D4\u6EDE\u6CBB\u7A92\u4E2D\u76C5\u5FE0\u949F\u8877\u7EC8\u79CD\u80BF\u91CD\u4EF2\u4F17\u821F\u5468\u5DDE\u6D32\u8BCC\u7CA5\u8F74\u8098\u5E1A\u5492\u76B1\u5B99\u663C\u9AA4\u73E0\u682A\u86DB\u6731\u732A\u8BF8\u8BDB\u9010\u7AF9\u70DB\u716E\u62C4\u77A9\u5631\u4E3B\u8457\u67F1\u52A9\u86C0\u8D2E\u94F8\u7B51"],
      ["d740", "\u8B46", 31, "\u8B67", 4, "\u8B6D", 25],
      ["d780", "\u8B87", 24, "\u8BAC\u8BB1\u8BBB\u8BC7\u8BD0\u8BEA\u8C09\u8C1E\u4F4F\u6CE8\u795D\u9A7B\u6293\u722A\u62FD\u4E13\u7816\u8F6C\u64B0\u8D5A\u7BC6\u6869\u5E84\u88C5\u5986\u649E\u58EE\u72B6\u690E\u9525\u8FFD\u8D58\u5760\u7F00\u8C06\u51C6\u6349\u62D9\u5353\u684C\u7422\u8301\u914C\u5544\u7740\u707C\u6D4A\u5179\u54A8\u8D44\u59FF\u6ECB\u6DC4\u5B5C\u7D2B\u4ED4\u7C7D\u6ED3\u5B50\u81EA\u6E0D\u5B57\u9B03\u68D5\u8E2A\u5B97\u7EFC\u603B\u7EB5\u90B9\u8D70\u594F\u63CD\u79DF\u8DB3\u5352\u65CF\u7956\u8BC5\u963B\u7EC4\u94BB\u7E82\u5634\u9189\u6700\u7F6A\u5C0A\u9075\u6628\u5DE6\u4F50\u67DE\u505A\u4F5C\u5750\u5EA7"],
      ["d840", "\u8C38", 8, "\u8C42\u8C43\u8C44\u8C45\u8C48\u8C4A\u8C4B\u8C4D", 7, "\u8C56\u8C57\u8C58\u8C59\u8C5B", 5, "\u8C63", 6, "\u8C6C", 6, "\u8C74\u8C75\u8C76\u8C77\u8C7B", 6, "\u8C83\u8C84\u8C86\u8C87"],
      ["d880", "\u8C88\u8C8B\u8C8D", 6, "\u8C95\u8C96\u8C97\u8C99", 20, "\u4E8D\u4E0C\u5140\u4E10\u5EFF\u5345\u4E15\u4E98\u4E1E\u9B32\u5B6C\u5669\u4E28\u79BA\u4E3F\u5315\u4E47\u592D\u723B\u536E\u6C10\u56DF\u80E4\u9997\u6BD3\u777E\u9F17\u4E36\u4E9F\u9F10\u4E5C\u4E69\u4E93\u8288\u5B5B\u556C\u560F\u4EC4\u538D\u539D\u53A3\u53A5\u53AE\u9765\u8D5D\u531A\u53F5\u5326\u532E\u533E\u8D5C\u5366\u5363\u5202\u5208\u520E\u522D\u5233\u523F\u5240\u524C\u525E\u5261\u525C\u84AF\u527D\u5282\u5281\u5290\u5293\u5182\u7F54\u4EBB\u4EC3\u4EC9\u4EC2\u4EE8\u4EE1\u4EEB\u4EDE\u4F1B\u4EF3\u4F22\u4F64\u4EF5\u4F25\u4F27\u4F09\u4F2B\u4F5E\u4F67\u6538\u4F5A\u4F5D"],
      ["d940", "\u8CAE", 62],
      ["d980", "\u8CED", 32, "\u4F5F\u4F57\u4F32\u4F3D\u4F76\u4F74\u4F91\u4F89\u4F83\u4F8F\u4F7E\u4F7B\u4FAA\u4F7C\u4FAC\u4F94\u4FE6\u4FE8\u4FEA\u4FC5\u4FDA\u4FE3\u4FDC\u4FD1\u4FDF\u4FF8\u5029\u504C\u4FF3\u502C\u500F\u502E\u502D\u4FFE\u501C\u500C\u5025\u5028\u507E\u5043\u5055\u5048\u504E\u506C\u507B\u50A5\u50A7\u50A9\u50BA\u50D6\u5106\u50ED\u50EC\u50E6\u50EE\u5107\u510B\u4EDD\u6C3D\u4F58\u4F65\u4FCE\u9FA0\u6C46\u7C74\u516E\u5DFD\u9EC9\u9998\u5181\u5914\u52F9\u530D\u8A07\u5310\u51EB\u5919\u5155\u4EA0\u5156\u4EB3\u886E\u88A4\u4EB5\u8114\u88D2\u7980\u5B34\u8803\u7FB8\u51AB\u51B1\u51BD\u51BC"],
      ["da40", "\u8D0E", 14, "\u8D20\u8D51\u8D52\u8D57\u8D5F\u8D65\u8D68\u8D69\u8D6A\u8D6C\u8D6E\u8D6F\u8D71\u8D72\u8D78", 8, "\u8D82\u8D83\u8D86\u8D87\u8D88\u8D89\u8D8C", 4, "\u8D92\u8D93\u8D95", 9, "\u8DA0\u8DA1"],
      ["da80", "\u8DA2\u8DA4", 12, "\u8DB2\u8DB6\u8DB7\u8DB9\u8DBB\u8DBD\u8DC0\u8DC1\u8DC2\u8DC5\u8DC7\u8DC8\u8DC9\u8DCA\u8DCD\u8DD0\u8DD2\u8DD3\u8DD4\u51C7\u5196\u51A2\u51A5\u8BA0\u8BA6\u8BA7\u8BAA\u8BB4\u8BB5\u8BB7\u8BC2\u8BC3\u8BCB\u8BCF\u8BCE\u8BD2\u8BD3\u8BD4\u8BD6\u8BD8\u8BD9\u8BDC\u8BDF\u8BE0\u8BE4\u8BE8\u8BE9\u8BEE\u8BF0\u8BF3\u8BF6\u8BF9\u8BFC\u8BFF\u8C00\u8C02\u8C04\u8C07\u8C0C\u8C0F\u8C11\u8C12\u8C14\u8C15\u8C16\u8C19\u8C1B\u8C18\u8C1D\u8C1F\u8C20\u8C21\u8C25\u8C27\u8C2A\u8C2B\u8C2E\u8C2F\u8C32\u8C33\u8C35\u8C36\u5369\u537A\u961D\u9622\u9621\u9631\u962A\u963D\u963C\u9642\u9649\u9654\u965F\u9667\u966C\u9672\u9674\u9688\u968D\u9697\u96B0\u9097\u909B\u909D\u9099\u90AC\u90A1\u90B4\u90B3\u90B6\u90BA"],
      ["db40", "\u8DD5\u8DD8\u8DD9\u8DDC\u8DE0\u8DE1\u8DE2\u8DE5\u8DE6\u8DE7\u8DE9\u8DED\u8DEE\u8DF0\u8DF1\u8DF2\u8DF4\u8DF6\u8DFC\u8DFE", 6, "\u8E06\u8E07\u8E08\u8E0B\u8E0D\u8E0E\u8E10\u8E11\u8E12\u8E13\u8E15", 7, "\u8E20\u8E21\u8E24", 4, "\u8E2B\u8E2D\u8E30\u8E32\u8E33\u8E34\u8E36\u8E37\u8E38\u8E3B\u8E3C\u8E3E"],
      ["db80", "\u8E3F\u8E43\u8E45\u8E46\u8E4C", 4, "\u8E53", 5, "\u8E5A", 11, "\u8E67\u8E68\u8E6A\u8E6B\u8E6E\u8E71\u90B8\u90B0\u90CF\u90C5\u90BE\u90D0\u90C4\u90C7\u90D3\u90E6\u90E2\u90DC\u90D7\u90DB\u90EB\u90EF\u90FE\u9104\u9122\u911E\u9123\u9131\u912F\u9139\u9143\u9146\u520D\u5942\u52A2\u52AC\u52AD\u52BE\u54FF\u52D0\u52D6\u52F0\u53DF\u71EE\u77CD\u5EF4\u51F5\u51FC\u9B2F\u53B6\u5F01\u755A\u5DEF\u574C\u57A9\u57A1\u587E\u58BC\u58C5\u58D1\u5729\u572C\u572A\u5733\u5739\u572E\u572F\u575C\u573B\u5742\u5769\u5785\u576B\u5786\u577C\u577B\u5768\u576D\u5776\u5773\u57AD\u57A4\u578C\u57B2\u57CF\u57A7\u57B4\u5793\u57A0\u57D5\u57D8\u57DA\u57D9\u57D2\u57B8\u57F4\u57EF\u57F8\u57E4\u57DD"],
      ["dc40", "\u8E73\u8E75\u8E77", 4, "\u8E7D\u8E7E\u8E80\u8E82\u8E83\u8E84\u8E86\u8E88", 6, "\u8E91\u8E92\u8E93\u8E95", 6, "\u8E9D\u8E9F", 11, "\u8EAD\u8EAE\u8EB0\u8EB1\u8EB3", 6, "\u8EBB", 7],
      ["dc80", "\u8EC3", 10, "\u8ECF", 21, "\u580B\u580D\u57FD\u57ED\u5800\u581E\u5819\u5844\u5820\u5865\u586C\u5881\u5889\u589A\u5880\u99A8\u9F19\u61FF\u8279\u827D\u827F\u828F\u828A\u82A8\u8284\u828E\u8291\u8297\u8299\u82AB\u82B8\u82BE\u82B0\u82C8\u82CA\u82E3\u8298\u82B7\u82AE\u82CB\u82CC\u82C1\u82A9\u82B4\u82A1\u82AA\u829F\u82C4\u82CE\u82A4\u82E1\u8309\u82F7\u82E4\u830F\u8307\u82DC\u82F4\u82D2\u82D8\u830C\u82FB\u82D3\u8311\u831A\u8306\u8314\u8315\u82E0\u82D5\u831C\u8351\u835B\u835C\u8308\u8392\u833C\u8334\u8331\u839B\u835E\u832F\u834F\u8347\u8343\u835F\u8340\u8317\u8360\u832D\u833A\u8333\u8366\u8365"],
      ["dd40", "\u8EE5", 62],
      ["dd80", "\u8F24", 32, "\u8368\u831B\u8369\u836C\u836A\u836D\u836E\u83B0\u8378\u83B3\u83B4\u83A0\u83AA\u8393\u839C\u8385\u837C\u83B6\u83A9\u837D\u83B8\u837B\u8398\u839E\u83A8\u83BA\u83BC\u83C1\u8401\u83E5\u83D8\u5807\u8418\u840B\u83DD\u83FD\u83D6\u841C\u8438\u8411\u8406\u83D4\u83DF\u840F\u8403\u83F8\u83F9\u83EA\u83C5\u83C0\u8426\u83F0\u83E1\u845C\u8451\u845A\u8459\u8473\u8487\u8488\u847A\u8489\u8478\u843C\u8446\u8469\u8476\u848C\u848E\u8431\u846D\u84C1\u84CD\u84D0\u84E6\u84BD\u84D3\u84CA\u84BF\u84BA\u84E0\u84A1\u84B9\u84B4\u8497\u84E5\u84E3\u850C\u750D\u8538\u84F0\u8539\u851F\u853A"],
      ["de40", "\u8F45", 32, "\u8F6A\u8F80\u8F8C\u8F92\u8F9D\u8FA0\u8FA1\u8FA2\u8FA4\u8FA5\u8FA6\u8FA7\u8FAA\u8FAC\u8FAD\u8FAE\u8FAF\u8FB2\u8FB3\u8FB4\u8FB5\u8FB7\u8FB8\u8FBA\u8FBB\u8FBC\u8FBF\u8FC0\u8FC3\u8FC6"],
      ["de80", "\u8FC9", 4, "\u8FCF\u8FD2\u8FD6\u8FD7\u8FDA\u8FE0\u8FE1\u8FE3\u8FE7\u8FEC\u8FEF\u8FF1\u8FF2\u8FF4\u8FF5\u8FF6\u8FFA\u8FFB\u8FFC\u8FFE\u8FFF\u9007\u9008\u900C\u900E\u9013\u9015\u9018\u8556\u853B\u84FF\u84FC\u8559\u8548\u8568\u8564\u855E\u857A\u77A2\u8543\u8572\u857B\u85A4\u85A8\u8587\u858F\u8579\u85AE\u859C\u8585\u85B9\u85B7\u85B0\u85D3\u85C1\u85DC\u85FF\u8627\u8605\u8629\u8616\u863C\u5EFE\u5F08\u593C\u5941\u8037\u5955\u595A\u5958\u530F\u5C22\u5C25\u5C2C\u5C34\u624C\u626A\u629F\u62BB\u62CA\u62DA\u62D7\u62EE\u6322\u62F6\u6339\u634B\u6343\u63AD\u63F6\u6371\u637A\u638E\u63B4\u636D\u63AC\u638A\u6369\u63AE\u63BC\u63F2\u63F8\u63E0\u63FF\u63C4\u63DE\u63CE\u6452\u63C6\u63BE\u6445\u6441\u640B\u641B\u6420\u640C\u6426\u6421\u645E\u6484\u646D\u6496"],
      ["df40", "\u9019\u901C\u9023\u9024\u9025\u9027", 5, "\u9030", 4, "\u9037\u9039\u903A\u903D\u903F\u9040\u9043\u9045\u9046\u9048", 4, "\u904E\u9054\u9055\u9056\u9059\u905A\u905C", 5, "\u9064\u9066\u9067\u9069\u906A\u906B\u906C\u906F", 4, "\u9076", 6, "\u907E\u9081"],
      ["df80", "\u9084\u9085\u9086\u9087\u9089\u908A\u908C", 4, "\u9092\u9094\u9096\u9098\u909A\u909C\u909E\u909F\u90A0\u90A4\u90A5\u90A7\u90A8\u90A9\u90AB\u90AD\u90B2\u90B7\u90BC\u90BD\u90BF\u90C0\u647A\u64B7\u64B8\u6499\u64BA\u64C0\u64D0\u64D7\u64E4\u64E2\u6509\u6525\u652E\u5F0B\u5FD2\u7519\u5F11\u535F\u53F1\u53FD\u53E9\u53E8\u53FB\u5412\u5416\u5406\u544B\u5452\u5453\u5454\u5456\u5443\u5421\u5457\u5459\u5423\u5432\u5482\u5494\u5477\u5471\u5464\u549A\u549B\u5484\u5476\u5466\u549D\u54D0\u54AD\u54C2\u54B4\u54D2\u54A7\u54A6\u54D3\u54D4\u5472\u54A3\u54D5\u54BB\u54BF\u54CC\u54D9\u54DA\u54DC\u54A9\u54AA\u54A4\u54DD\u54CF\u54DE\u551B\u54E7\u5520\u54FD\u5514\u54F3\u5522\u5523\u550F\u5511\u5527\u552A\u5567\u558F\u55B5\u5549\u556D\u5541\u5555\u553F\u5550\u553C"],
      ["e040", "\u90C2\u90C3\u90C6\u90C8\u90C9\u90CB\u90CC\u90CD\u90D2\u90D4\u90D5\u90D6\u90D8\u90D9\u90DA\u90DE\u90DF\u90E0\u90E3\u90E4\u90E5\u90E9\u90EA\u90EC\u90EE\u90F0\u90F1\u90F2\u90F3\u90F5\u90F6\u90F7\u90F9\u90FA\u90FB\u90FC\u90FF\u9100\u9101\u9103\u9105", 19, "\u911A\u911B\u911C"],
      ["e080", "\u911D\u911F\u9120\u9121\u9124", 10, "\u9130\u9132", 6, "\u913A", 8, "\u9144\u5537\u5556\u5575\u5576\u5577\u5533\u5530\u555C\u558B\u55D2\u5583\u55B1\u55B9\u5588\u5581\u559F\u557E\u55D6\u5591\u557B\u55DF\u55BD\u55BE\u5594\u5599\u55EA\u55F7\u55C9\u561F\u55D1\u55EB\u55EC\u55D4\u55E6\u55DD\u55C4\u55EF\u55E5\u55F2\u55F3\u55CC\u55CD\u55E8\u55F5\u55E4\u8F94\u561E\u5608\u560C\u5601\u5624\u5623\u55FE\u5600\u5627\u562D\u5658\u5639\u5657\u562C\u564D\u5662\u5659\u565C\u564C\u5654\u5686\u5664\u5671\u566B\u567B\u567C\u5685\u5693\u56AF\u56D4\u56D7\u56DD\u56E1\u56F5\u56EB\u56F9\u56FF\u5704\u570A\u5709\u571C\u5E0F\u5E19\u5E14\u5E11\u5E31\u5E3B\u5E3C"],
      ["e140", "\u9145\u9147\u9148\u9151\u9153\u9154\u9155\u9156\u9158\u9159\u915B\u915C\u915F\u9160\u9166\u9167\u9168\u916B\u916D\u9173\u917A\u917B\u917C\u9180", 4, "\u9186\u9188\u918A\u918E\u918F\u9193", 6, "\u919C", 5, "\u91A4", 5, "\u91AB\u91AC\u91B0\u91B1\u91B2\u91B3\u91B6\u91B7\u91B8\u91B9\u91BB"],
      ["e180", "\u91BC", 10, "\u91C8\u91CB\u91D0\u91D2", 9, "\u91DD", 8, "\u5E37\u5E44\u5E54\u5E5B\u5E5E\u5E61\u5C8C\u5C7A\u5C8D\u5C90\u5C96\u5C88\u5C98\u5C99\u5C91\u5C9A\u5C9C\u5CB5\u5CA2\u5CBD\u5CAC\u5CAB\u5CB1\u5CA3\u5CC1\u5CB7\u5CC4\u5CD2\u5CE4\u5CCB\u5CE5\u5D02\u5D03\u5D27\u5D26\u5D2E\u5D24\u5D1E\u5D06\u5D1B\u5D58\u5D3E\u5D34\u5D3D\u5D6C\u5D5B\u5D6F\u5D5D\u5D6B\u5D4B\u5D4A\u5D69\u5D74\u5D82\u5D99\u5D9D\u8C73\u5DB7\u5DC5\u5F73\u5F77\u5F82\u5F87\u5F89\u5F8C\u5F95\u5F99\u5F9C\u5FA8\u5FAD\u5FB5\u5FBC\u8862\u5F61\u72AD\u72B0\u72B4\u72B7\u72B8\u72C3\u72C1\u72CE\u72CD\u72D2\u72E8\u72EF\u72E9\u72F2\u72F4\u72F7\u7301\u72F3\u7303\u72FA"],
      ["e240", "\u91E6", 62],
      ["e280", "\u9225", 32, "\u72FB\u7317\u7313\u7321\u730A\u731E\u731D\u7315\u7322\u7339\u7325\u732C\u7338\u7331\u7350\u734D\u7357\u7360\u736C\u736F\u737E\u821B\u5925\u98E7\u5924\u5902\u9963\u9967", 5, "\u9974\u9977\u997D\u9980\u9984\u9987\u998A\u998D\u9990\u9991\u9993\u9994\u9995\u5E80\u5E91\u5E8B\u5E96\u5EA5\u5EA0\u5EB9\u5EB5\u5EBE\u5EB3\u8D53\u5ED2\u5ED1\u5EDB\u5EE8\u5EEA\u81BA\u5FC4\u5FC9\u5FD6\u5FCF\u6003\u5FEE\u6004\u5FE1\u5FE4\u5FFE\u6005\u6006\u5FEA\u5FED\u5FF8\u6019\u6035\u6026\u601B\u600F\u600D\u6029\u602B\u600A\u603F\u6021\u6078\u6079\u607B\u607A\u6042"],
      ["e340", "\u9246", 45, "\u9275", 16],
      ["e380", "\u9286", 7, "\u928F", 24, "\u606A\u607D\u6096\u609A\u60AD\u609D\u6083\u6092\u608C\u609B\u60EC\u60BB\u60B1\u60DD\u60D8\u60C6\u60DA\u60B4\u6120\u6126\u6115\u6123\u60F4\u6100\u610E\u612B\u614A\u6175\u61AC\u6194\u61A7\u61B7\u61D4\u61F5\u5FDD\u96B3\u95E9\u95EB\u95F1\u95F3\u95F5\u95F6\u95FC\u95FE\u9603\u9604\u9606\u9608\u960A\u960B\u960C\u960D\u960F\u9612\u9615\u9616\u9617\u9619\u961A\u4E2C\u723F\u6215\u6C35\u6C54\u6C5C\u6C4A\u6CA3\u6C85\u6C90\u6C94\u6C8C\u6C68\u6C69\u6C74\u6C76\u6C86\u6CA9\u6CD0\u6CD4\u6CAD\u6CF7\u6CF8\u6CF1\u6CD7\u6CB2\u6CE0\u6CD6\u6CFA\u6CEB\u6CEE\u6CB1\u6CD3\u6CEF\u6CFE"],
      ["e440", "\u92A8", 5, "\u92AF", 24, "\u92C9", 31],
      ["e480", "\u92E9", 32, "\u6D39\u6D27\u6D0C\u6D43\u6D48\u6D07\u6D04\u6D19\u6D0E\u6D2B\u6D4D\u6D2E\u6D35\u6D1A\u6D4F\u6D52\u6D54\u6D33\u6D91\u6D6F\u6D9E\u6DA0\u6D5E\u6D93\u6D94\u6D5C\u6D60\u6D7C\u6D63\u6E1A\u6DC7\u6DC5\u6DDE\u6E0E\u6DBF\u6DE0\u6E11\u6DE6\u6DDD\u6DD9\u6E16\u6DAB\u6E0C\u6DAE\u6E2B\u6E6E\u6E4E\u6E6B\u6EB2\u6E5F\u6E86\u6E53\u6E54\u6E32\u6E25\u6E44\u6EDF\u6EB1\u6E98\u6EE0\u6F2D\u6EE2\u6EA5\u6EA7\u6EBD\u6EBB\u6EB7\u6ED7\u6EB4\u6ECF\u6E8F\u6EC2\u6E9F\u6F62\u6F46\u6F47\u6F24\u6F15\u6EF9\u6F2F\u6F36\u6F4B\u6F74\u6F2A\u6F09\u6F29\u6F89\u6F8D\u6F8C\u6F78\u6F72\u6F7C\u6F7A\u6FD1"],
      ["e540", "\u930A", 51, "\u933F", 10],
      ["e580", "\u934A", 31, "\u936B\u6FC9\u6FA7\u6FB9\u6FB6\u6FC2\u6FE1\u6FEE\u6FDE\u6FE0\u6FEF\u701A\u7023\u701B\u7039\u7035\u704F\u705E\u5B80\u5B84\u5B95\u5B93\u5BA5\u5BB8\u752F\u9A9E\u6434\u5BE4\u5BEE\u8930\u5BF0\u8E47\u8B07\u8FB6\u8FD3\u8FD5\u8FE5\u8FEE\u8FE4\u8FE9\u8FE6\u8FF3\u8FE8\u9005\u9004\u900B\u9026\u9011\u900D\u9016\u9021\u9035\u9036\u902D\u902F\u9044\u9051\u9052\u9050\u9068\u9058\u9062\u905B\u66B9\u9074\u907D\u9082\u9088\u9083\u908B\u5F50\u5F57\u5F56\u5F58\u5C3B\u54AB\u5C50\u5C59\u5B71\u5C63\u5C66\u7FBC\u5F2A\u5F29\u5F2D\u8274\u5F3C\u9B3B\u5C6E\u5981\u5983\u598D\u59A9\u59AA\u59A3"],
      ["e640", "\u936C", 34, "\u9390", 27],
      ["e680", "\u93AC", 29, "\u93CB\u93CC\u93CD\u5997\u59CA\u59AB\u599E\u59A4\u59D2\u59B2\u59AF\u59D7\u59BE\u5A05\u5A06\u59DD\u5A08\u59E3\u59D8\u59F9\u5A0C\u5A09\u5A32\u5A34\u5A11\u5A23\u5A13\u5A40\u5A67\u5A4A\u5A55\u5A3C\u5A62\u5A75\u80EC\u5AAA\u5A9B\u5A77\u5A7A\u5ABE\u5AEB\u5AB2\u5AD2\u5AD4\u5AB8\u5AE0\u5AE3\u5AF1\u5AD6\u5AE6\u5AD8\u5ADC\u5B09\u5B17\u5B16\u5B32\u5B37\u5B40\u5C15\u5C1C\u5B5A\u5B65\u5B73\u5B51\u5B53\u5B62\u9A75\u9A77\u9A78\u9A7A\u9A7F\u9A7D\u9A80\u9A81\u9A85\u9A88\u9A8A\u9A90\u9A92\u9A93\u9A96\u9A98\u9A9B\u9A9C\u9A9D\u9A9F\u9AA0\u9AA2\u9AA3\u9AA5\u9AA7\u7E9F\u7EA1\u7EA3\u7EA5\u7EA8\u7EA9"],
      ["e740", "\u93CE", 7, "\u93D7", 54],
      ["e780", "\u940E", 32, "\u7EAD\u7EB0\u7EBE\u7EC0\u7EC1\u7EC2\u7EC9\u7ECB\u7ECC\u7ED0\u7ED4\u7ED7\u7EDB\u7EE0\u7EE1\u7EE8\u7EEB\u7EEE\u7EEF\u7EF1\u7EF2\u7F0D\u7EF6\u7EFA\u7EFB\u7EFE\u7F01\u7F02\u7F03\u7F07\u7F08\u7F0B\u7F0C\u7F0F\u7F11\u7F12\u7F17\u7F19\u7F1C\u7F1B\u7F1F\u7F21", 6, "\u7F2A\u7F2B\u7F2C\u7F2D\u7F2F", 4, "\u7F35\u5E7A\u757F\u5DDB\u753E\u9095\u738E\u7391\u73AE\u73A2\u739F\u73CF\u73C2\u73D1\u73B7\u73B3\u73C0\u73C9\u73C8\u73E5\u73D9\u987C\u740A\u73E9\u73E7\u73DE\u73BA\u73F2\u740F\u742A\u745B\u7426\u7425\u7428\u7430\u742E\u742C"],
      ["e840", "\u942F", 14, "\u943F", 43, "\u946C\u946D\u946E\u946F"],
      ["e880", "\u9470", 20, "\u9491\u9496\u9498\u94C7\u94CF\u94D3\u94D4\u94DA\u94E6\u94FB\u951C\u9520\u741B\u741A\u7441\u745C\u7457\u7455\u7459\u7477\u746D\u747E\u749C\u748E\u7480\u7481\u7487\u748B\u749E\u74A8\u74A9\u7490\u74A7\u74D2\u74BA\u97EA\u97EB\u97EC\u674C\u6753\u675E\u6748\u6769\u67A5\u6787\u676A\u6773\u6798\u67A7\u6775\u67A8\u679E\u67AD\u678B\u6777\u677C\u67F0\u6809\u67D8\u680A\u67E9\u67B0\u680C\u67D9\u67B5\u67DA\u67B3\u67DD\u6800\u67C3\u67B8\u67E2\u680E\u67C1\u67FD\u6832\u6833\u6860\u6861\u684E\u6862\u6844\u6864\u6883\u681D\u6855\u6866\u6841\u6867\u6840\u683E\u684A\u6849\u6829\u68B5\u688F\u6874\u6877\u6893\u686B\u68C2\u696E\u68FC\u691F\u6920\u68F9"],
      ["e940", "\u9527\u9533\u953D\u9543\u9548\u954B\u9555\u955A\u9560\u956E\u9574\u9575\u9577", 7, "\u9580", 42],
      ["e980", "\u95AB", 32, "\u6924\u68F0\u690B\u6901\u6957\u68E3\u6910\u6971\u6939\u6960\u6942\u695D\u6984\u696B\u6980\u6998\u6978\u6934\u69CC\u6987\u6988\u69CE\u6989\u6966\u6963\u6979\u699B\u69A7\u69BB\u69AB\u69AD\u69D4\u69B1\u69C1\u69CA\u69DF\u6995\u69E0\u698D\u69FF\u6A2F\u69ED\u6A17\u6A18\u6A65\u69F2\u6A44\u6A3E\u6AA0\u6A50\u6A5B\u6A35\u6A8E\u6A79\u6A3D\u6A28\u6A58\u6A7C\u6A91\u6A90\u6AA9\u6A97\u6AAB\u7337\u7352\u6B81\u6B82\u6B87\u6B84\u6B92\u6B93\u6B8D\u6B9A\u6B9B\u6BA1\u6BAA\u8F6B\u8F6D\u8F71\u8F72\u8F73\u8F75\u8F76\u8F78\u8F77\u8F79\u8F7A\u8F7C\u8F7E\u8F81\u8F82\u8F84\u8F87\u8F8B"],
      ["ea40", "\u95CC", 27, "\u95EC\u95FF\u9607\u9613\u9618\u961B\u961E\u9620\u9623", 6, "\u962B\u962C\u962D\u962F\u9630\u9637\u9638\u9639\u963A\u963E\u9641\u9643\u964A\u964E\u964F\u9651\u9652\u9653\u9656\u9657"],
      ["ea80", "\u9658\u9659\u965A\u965C\u965D\u965E\u9660\u9663\u9665\u9666\u966B\u966D", 4, "\u9673\u9678", 12, "\u9687\u9689\u968A\u8F8D\u8F8E\u8F8F\u8F98\u8F9A\u8ECE\u620B\u6217\u621B\u621F\u6222\u6221\u6225\u6224\u622C\u81E7\u74EF\u74F4\u74FF\u750F\u7511\u7513\u6534\u65EE\u65EF\u65F0\u660A\u6619\u6772\u6603\u6615\u6600\u7085\u66F7\u661D\u6634\u6631\u6636\u6635\u8006\u665F\u6654\u6641\u664F\u6656\u6661\u6657\u6677\u6684\u668C\u66A7\u669D\u66BE\u66DB\u66DC\u66E6\u66E9\u8D32\u8D33\u8D36\u8D3B\u8D3D\u8D40\u8D45\u8D46\u8D48\u8D49\u8D47\u8D4D\u8D55\u8D59\u89C7\u89CA\u89CB\u89CC\u89CE\u89CF\u89D0\u89D1\u726E\u729F\u725D\u7266\u726F\u727E\u727F\u7284\u728B\u728D\u728F\u7292\u6308\u6332\u63B0"],
      ["eb40", "\u968C\u968E\u9691\u9692\u9693\u9695\u9696\u969A\u969B\u969D", 9, "\u96A8", 7, "\u96B1\u96B2\u96B4\u96B5\u96B7\u96B8\u96BA\u96BB\u96BF\u96C2\u96C3\u96C8\u96CA\u96CB\u96D0\u96D1\u96D3\u96D4\u96D6", 9, "\u96E1", 6, "\u96EB"],
      ["eb80", "\u96EC\u96ED\u96EE\u96F0\u96F1\u96F2\u96F4\u96F5\u96F8\u96FA\u96FB\u96FC\u96FD\u96FF\u9702\u9703\u9705\u970A\u970B\u970C\u9710\u9711\u9712\u9714\u9715\u9717", 4, "\u971D\u971F\u9720\u643F\u64D8\u8004\u6BEA\u6BF3\u6BFD\u6BF5\u6BF9\u6C05\u6C07\u6C06\u6C0D\u6C15\u6C18\u6C19\u6C1A\u6C21\u6C29\u6C24\u6C2A\u6C32\u6535\u6555\u656B\u724D\u7252\u7256\u7230\u8662\u5216\u809F\u809C\u8093\u80BC\u670A\u80BD\u80B1\u80AB\u80AD\u80B4\u80B7\u80E7\u80E8\u80E9\u80EA\u80DB\u80C2\u80C4\u80D9\u80CD\u80D7\u6710\u80DD\u80EB\u80F1\u80F4\u80ED\u810D\u810E\u80F2\u80FC\u6715\u8112\u8C5A\u8136\u811E\u812C\u8118\u8132\u8148\u814C\u8153\u8174\u8159\u815A\u8171\u8160\u8169\u817C\u817D\u816D\u8167\u584D\u5AB5\u8188\u8182\u8191\u6ED5\u81A3\u81AA\u81CC\u6726\u81CA\u81BB"],
      ["ec40", "\u9721", 8, "\u972B\u972C\u972E\u972F\u9731\u9733", 4, "\u973A\u973B\u973C\u973D\u973F", 18, "\u9754\u9755\u9757\u9758\u975A\u975C\u975D\u975F\u9763\u9764\u9766\u9767\u9768\u976A", 7],
      ["ec80", "\u9772\u9775\u9777", 4, "\u977D", 7, "\u9786", 4, "\u978C\u978E\u978F\u9790\u9793\u9795\u9796\u9797\u9799", 4, "\u81C1\u81A6\u6B24\u6B37\u6B39\u6B43\u6B46\u6B59\u98D1\u98D2\u98D3\u98D5\u98D9\u98DA\u6BB3\u5F40\u6BC2\u89F3\u6590\u9F51\u6593\u65BC\u65C6\u65C4\u65C3\u65CC\u65CE\u65D2\u65D6\u7080\u709C\u7096\u709D\u70BB\u70C0\u70B7\u70AB\u70B1\u70E8\u70CA\u7110\u7113\u7116\u712F\u7131\u7173\u715C\u7168\u7145\u7172\u714A\u7178\u717A\u7198\u71B3\u71B5\u71A8\u71A0\u71E0\u71D4\u71E7\u71F9\u721D\u7228\u706C\u7118\u7166\u71B9\u623E\u623D\u6243\u6248\u6249\u793B\u7940\u7946\u7949\u795B\u795C\u7953\u795A\u7962\u7957\u7960\u796F\u7967\u797A\u7985\u798A\u799A\u79A7\u79B3\u5FD1\u5FD0"],
      ["ed40", "\u979E\u979F\u97A1\u97A2\u97A4", 6, "\u97AC\u97AE\u97B0\u97B1\u97B3\u97B5", 46],
      ["ed80", "\u97E4\u97E5\u97E8\u97EE", 4, "\u97F4\u97F7", 23, "\u603C\u605D\u605A\u6067\u6041\u6059\u6063\u60AB\u6106\u610D\u615D\u61A9\u619D\u61CB\u61D1\u6206\u8080\u807F\u6C93\u6CF6\u6DFC\u77F6\u77F8\u7800\u7809\u7817\u7818\u7811\u65AB\u782D\u781C\u781D\u7839\u783A\u783B\u781F\u783C\u7825\u782C\u7823\u7829\u784E\u786D\u7856\u7857\u7826\u7850\u7847\u784C\u786A\u789B\u7893\u789A\u7887\u789C\u78A1\u78A3\u78B2\u78B9\u78A5\u78D4\u78D9\u78C9\u78EC\u78F2\u7905\u78F4\u7913\u7924\u791E\u7934\u9F9B\u9EF9\u9EFB\u9EFC\u76F1\u7704\u770D\u76F9\u7707\u7708\u771A\u7722\u7719\u772D\u7726\u7735\u7738\u7750\u7751\u7747\u7743\u775A\u7768"],
      ["ee40", "\u980F", 62],
      ["ee80", "\u984E", 32, "\u7762\u7765\u777F\u778D\u777D\u7780\u778C\u7791\u779F\u77A0\u77B0\u77B5\u77BD\u753A\u7540\u754E\u754B\u7548\u755B\u7572\u7579\u7583\u7F58\u7F61\u7F5F\u8A48\u7F68\u7F74\u7F71\u7F79\u7F81\u7F7E\u76CD\u76E5\u8832\u9485\u9486\u9487\u948B\u948A\u948C\u948D\u948F\u9490\u9494\u9497\u9495\u949A\u949B\u949C\u94A3\u94A4\u94AB\u94AA\u94AD\u94AC\u94AF\u94B0\u94B2\u94B4\u94B6", 4, "\u94BC\u94BD\u94BF\u94C4\u94C8", 6, "\u94D0\u94D1\u94D2\u94D5\u94D6\u94D7\u94D9\u94D8\u94DB\u94DE\u94DF\u94E0\u94E2\u94E4\u94E5\u94E7\u94E8\u94EA"],
      ["ef40", "\u986F", 5, "\u988B\u988E\u9892\u9895\u9899\u98A3\u98A8", 37, "\u98CF\u98D0\u98D4\u98D6\u98D7\u98DB\u98DC\u98DD\u98E0", 4],
      ["ef80", "\u98E5\u98E6\u98E9", 30, "\u94E9\u94EB\u94EE\u94EF\u94F3\u94F4\u94F5\u94F7\u94F9\u94FC\u94FD\u94FF\u9503\u9502\u9506\u9507\u9509\u950A\u950D\u950E\u950F\u9512", 4, "\u9518\u951B\u951D\u951E\u951F\u9522\u952A\u952B\u9529\u952C\u9531\u9532\u9534\u9536\u9537\u9538\u953C\u953E\u953F\u9542\u9535\u9544\u9545\u9546\u9549\u954C\u954E\u954F\u9552\u9553\u9554\u9556\u9557\u9558\u9559\u955B\u955E\u955F\u955D\u9561\u9562\u9564", 8, "\u956F\u9571\u9572\u9573\u953A\u77E7\u77EC\u96C9\u79D5\u79ED\u79E3\u79EB\u7A06\u5D47\u7A03\u7A02\u7A1E\u7A14"],
      ["f040", "\u9908", 4, "\u990E\u990F\u9911", 28, "\u992F", 26],
      ["f080", "\u994A", 9, "\u9956", 12, "\u9964\u9966\u9973\u9978\u9979\u997B\u997E\u9982\u9983\u9989\u7A39\u7A37\u7A51\u9ECF\u99A5\u7A70\u7688\u768E\u7693\u7699\u76A4\u74DE\u74E0\u752C\u9E20\u9E22\u9E28", 4, "\u9E32\u9E31\u9E36\u9E38\u9E37\u9E39\u9E3A\u9E3E\u9E41\u9E42\u9E44\u9E46\u9E47\u9E48\u9E49\u9E4B\u9E4C\u9E4E\u9E51\u9E55\u9E57\u9E5A\u9E5B\u9E5C\u9E5E\u9E63\u9E66", 6, "\u9E71\u9E6D\u9E73\u7592\u7594\u7596\u75A0\u759D\u75AC\u75A3\u75B3\u75B4\u75B8\u75C4\u75B1\u75B0\u75C3\u75C2\u75D6\u75CD\u75E3\u75E8\u75E6\u75E4\u75EB\u75E7\u7603\u75F1\u75FC\u75FF\u7610\u7600\u7605\u760C\u7617\u760A\u7625\u7618\u7615\u7619"],
      ["f140", "\u998C\u998E\u999A", 10, "\u99A6\u99A7\u99A9", 47],
      ["f180", "\u99D9", 32, "\u761B\u763C\u7622\u7620\u7640\u762D\u7630\u763F\u7635\u7643\u763E\u7633\u764D\u765E\u7654\u765C\u7656\u766B\u766F\u7FCA\u7AE6\u7A78\u7A79\u7A80\u7A86\u7A88\u7A95\u7AA6\u7AA0\u7AAC\u7AA8\u7AAD\u7AB3\u8864\u8869\u8872\u887D\u887F\u8882\u88A2\u88C6\u88B7\u88BC\u88C9\u88E2\u88CE\u88E3\u88E5\u88F1\u891A\u88FC\u88E8\u88FE\u88F0\u8921\u8919\u8913\u891B\u890A\u8934\u892B\u8936\u8941\u8966\u897B\u758B\u80E5\u76B2\u76B4\u77DC\u8012\u8014\u8016\u801C\u8020\u8022\u8025\u8026\u8027\u8029\u8028\u8031\u800B\u8035\u8043\u8046\u804D\u8052\u8069\u8071\u8983\u9878\u9880\u9883"],
      ["f240", "\u99FA", 62],
      ["f280", "\u9A39", 32, "\u9889\u988C\u988D\u988F\u9894\u989A\u989B\u989E\u989F\u98A1\u98A2\u98A5\u98A6\u864D\u8654\u866C\u866E\u867F\u867A\u867C\u867B\u86A8\u868D\u868B\u86AC\u869D\u86A7\u86A3\u86AA\u8693\u86A9\u86B6\u86C4\u86B5\u86CE\u86B0\u86BA\u86B1\u86AF\u86C9\u86CF\u86B4\u86E9\u86F1\u86F2\u86ED\u86F3\u86D0\u8713\u86DE\u86F4\u86DF\u86D8\u86D1\u8703\u8707\u86F8\u8708\u870A\u870D\u8709\u8723\u873B\u871E\u8725\u872E\u871A\u873E\u8748\u8734\u8731\u8729\u8737\u873F\u8782\u8722\u877D\u877E\u877B\u8760\u8770\u874C\u876E\u878B\u8753\u8763\u877C\u8764\u8759\u8765\u8793\u87AF\u87A8\u87D2"],
      ["f340", "\u9A5A", 17, "\u9A72\u9A83\u9A89\u9A8D\u9A8E\u9A94\u9A95\u9A99\u9AA6\u9AA9", 6, "\u9AB2\u9AB3\u9AB4\u9AB5\u9AB9\u9ABB\u9ABD\u9ABE\u9ABF\u9AC3\u9AC4\u9AC6", 4, "\u9ACD\u9ACE\u9ACF\u9AD0\u9AD2\u9AD4\u9AD5\u9AD6\u9AD7\u9AD9\u9ADA\u9ADB\u9ADC"],
      ["f380", "\u9ADD\u9ADE\u9AE0\u9AE2\u9AE3\u9AE4\u9AE5\u9AE7\u9AE8\u9AE9\u9AEA\u9AEC\u9AEE\u9AF0", 8, "\u9AFA\u9AFC", 6, "\u9B04\u9B05\u9B06\u87C6\u8788\u8785\u87AD\u8797\u8783\u87AB\u87E5\u87AC\u87B5\u87B3\u87CB\u87D3\u87BD\u87D1\u87C0\u87CA\u87DB\u87EA\u87E0\u87EE\u8816\u8813\u87FE\u880A\u881B\u8821\u8839\u883C\u7F36\u7F42\u7F44\u7F45\u8210\u7AFA\u7AFD\u7B08\u7B03\u7B04\u7B15\u7B0A\u7B2B\u7B0F\u7B47\u7B38\u7B2A\u7B19\u7B2E\u7B31\u7B20\u7B25\u7B24\u7B33\u7B3E\u7B1E\u7B58\u7B5A\u7B45\u7B75\u7B4C\u7B5D\u7B60\u7B6E\u7B7B\u7B62\u7B72\u7B71\u7B90\u7BA6\u7BA7\u7BB8\u7BAC\u7B9D\u7BA8\u7B85\u7BAA\u7B9C\u7BA2\u7BAB\u7BB4\u7BD1\u7BC1\u7BCC\u7BDD\u7BDA\u7BE5\u7BE6\u7BEA\u7C0C\u7BFE\u7BFC\u7C0F\u7C16\u7C0B"],
      ["f440", "\u9B07\u9B09", 5, "\u9B10\u9B11\u9B12\u9B14", 10, "\u9B20\u9B21\u9B22\u9B24", 10, "\u9B30\u9B31\u9B33", 7, "\u9B3D\u9B3E\u9B3F\u9B40\u9B46\u9B4A\u9B4B\u9B4C\u9B4E\u9B50\u9B52\u9B53\u9B55", 5],
      ["f480", "\u9B5B", 32, "\u7C1F\u7C2A\u7C26\u7C38\u7C41\u7C40\u81FE\u8201\u8202\u8204\u81EC\u8844\u8221\u8222\u8223\u822D\u822F\u8228\u822B\u8238\u823B\u8233\u8234\u823E\u8244\u8249\u824B\u824F\u825A\u825F\u8268\u887E\u8885\u8888\u88D8\u88DF\u895E\u7F9D\u7F9F\u7FA7\u7FAF\u7FB0\u7FB2\u7C7C\u6549\u7C91\u7C9D\u7C9C\u7C9E\u7CA2\u7CB2\u7CBC\u7CBD\u7CC1\u7CC7\u7CCC\u7CCD\u7CC8\u7CC5\u7CD7\u7CE8\u826E\u66A8\u7FBF\u7FCE\u7FD5\u7FE5\u7FE1\u7FE6\u7FE9\u7FEE\u7FF3\u7CF8\u7D77\u7DA6\u7DAE\u7E47\u7E9B\u9EB8\u9EB4\u8D73\u8D84\u8D94\u8D91\u8DB1\u8D67\u8D6D\u8C47\u8C49\u914A\u9150\u914E\u914F\u9164"],
      ["f540", "\u9B7C", 62],
      ["f580", "\u9BBB", 32, "\u9162\u9161\u9170\u9169\u916F\u917D\u917E\u9172\u9174\u9179\u918C\u9185\u9190\u918D\u9191\u91A2\u91A3\u91AA\u91AD\u91AE\u91AF\u91B5\u91B4\u91BA\u8C55\u9E7E\u8DB8\u8DEB\u8E05\u8E59\u8E69\u8DB5\u8DBF\u8DBC\u8DBA\u8DC4\u8DD6\u8DD7\u8DDA\u8DDE\u8DCE\u8DCF\u8DDB\u8DC6\u8DEC\u8DF7\u8DF8\u8DE3\u8DF9\u8DFB\u8DE4\u8E09\u8DFD\u8E14\u8E1D\u8E1F\u8E2C\u8E2E\u8E23\u8E2F\u8E3A\u8E40\u8E39\u8E35\u8E3D\u8E31\u8E49\u8E41\u8E42\u8E51\u8E52\u8E4A\u8E70\u8E76\u8E7C\u8E6F\u8E74\u8E85\u8E8F\u8E94\u8E90\u8E9C\u8E9E\u8C78\u8C82\u8C8A\u8C85\u8C98\u8C94\u659B\u89D6\u89DE\u89DA\u89DC"],
      ["f640", "\u9BDC", 62],
      ["f680", "\u9C1B", 32, "\u89E5\u89EB\u89EF\u8A3E\u8B26\u9753\u96E9\u96F3\u96EF\u9706\u9701\u9708\u970F\u970E\u972A\u972D\u9730\u973E\u9F80\u9F83\u9F85", 5, "\u9F8C\u9EFE\u9F0B\u9F0D\u96B9\u96BC\u96BD\u96CE\u96D2\u77BF\u96E0\u928E\u92AE\u92C8\u933E\u936A\u93CA\u938F\u943E\u946B\u9C7F\u9C82\u9C85\u9C86\u9C87\u9C88\u7A23\u9C8B\u9C8E\u9C90\u9C91\u9C92\u9C94\u9C95\u9C9A\u9C9B\u9C9E", 5, "\u9CA5", 4, "\u9CAB\u9CAD\u9CAE\u9CB0", 7, "\u9CBA\u9CBB\u9CBC\u9CBD\u9CC4\u9CC5\u9CC6\u9CC7\u9CCA\u9CCB"],
      ["f740", "\u9C3C", 62],
      ["f780", "\u9C7B\u9C7D\u9C7E\u9C80\u9C83\u9C84\u9C89\u9C8A\u9C8C\u9C8F\u9C93\u9C96\u9C97\u9C98\u9C99\u9C9D\u9CAA\u9CAC\u9CAF\u9CB9\u9CBE", 4, "\u9CC8\u9CC9\u9CD1\u9CD2\u9CDA\u9CDB\u9CE0\u9CE1\u9CCC", 4, "\u9CD3\u9CD4\u9CD5\u9CD7\u9CD8\u9CD9\u9CDC\u9CDD\u9CDF\u9CE2\u977C\u9785\u9791\u9792\u9794\u97AF\u97AB\u97A3\u97B2\u97B4\u9AB1\u9AB0\u9AB7\u9E58\u9AB6\u9ABA\u9ABC\u9AC1\u9AC0\u9AC5\u9AC2\u9ACB\u9ACC\u9AD1\u9B45\u9B43\u9B47\u9B49\u9B48\u9B4D\u9B51\u98E8\u990D\u992E\u9955\u9954\u9ADF\u9AE1\u9AE6\u9AEF\u9AEB\u9AFB\u9AED\u9AF9\u9B08\u9B0F\u9B13\u9B1F\u9B23\u9EBD\u9EBE\u7E3B\u9E82\u9E87\u9E88\u9E8B\u9E92\u93D6\u9E9D\u9E9F\u9EDB\u9EDC\u9EDD\u9EE0\u9EDF\u9EE2\u9EE9\u9EE7\u9EE5\u9EEA\u9EEF\u9F22\u9F2C\u9F2F\u9F39\u9F37\u9F3D\u9F3E\u9F44"],
      ["f840", "\u9CE3", 62],
      ["f880", "\u9D22", 32],
      ["f940", "\u9D43", 62],
      ["f980", "\u9D82", 32],
      ["fa40", "\u9DA3", 62],
      ["fa80", "\u9DE2", 32],
      ["fb40", "\u9E03", 27, "\u9E24\u9E27\u9E2E\u9E30\u9E34\u9E3B\u9E3C\u9E40\u9E4D\u9E50\u9E52\u9E53\u9E54\u9E56\u9E59\u9E5D\u9E5F\u9E60\u9E61\u9E62\u9E65\u9E6E\u9E6F\u9E72\u9E74", 9, "\u9E80"],
      ["fb80", "\u9E81\u9E83\u9E84\u9E85\u9E86\u9E89\u9E8A\u9E8C", 5, "\u9E94", 8, "\u9E9E\u9EA0", 5, "\u9EA7\u9EA8\u9EA9\u9EAA"],
      ["fc40", "\u9EAB", 8, "\u9EB5\u9EB6\u9EB7\u9EB9\u9EBA\u9EBC\u9EBF", 4, "\u9EC5\u9EC6\u9EC7\u9EC8\u9ECA\u9ECB\u9ECC\u9ED0\u9ED2\u9ED3\u9ED5\u9ED6\u9ED7\u9ED9\u9EDA\u9EDE\u9EE1\u9EE3\u9EE4\u9EE6\u9EE8\u9EEB\u9EEC\u9EED\u9EEE\u9EF0", 8, "\u9EFA\u9EFD\u9EFF", 6],
      ["fc80", "\u9F06", 4, "\u9F0C\u9F0F\u9F11\u9F12\u9F14\u9F15\u9F16\u9F18\u9F1A", 5, "\u9F21\u9F23", 8, "\u9F2D\u9F2E\u9F30\u9F31"],
      ["fd40", "\u9F32", 4, "\u9F38\u9F3A\u9F3C\u9F3F", 4, "\u9F45", 10, "\u9F52", 38],
      ["fd80", "\u9F79", 5, "\u9F81\u9F82\u9F8D", 11, "\u9F9C\u9F9D\u9F9E\u9FA1", 4, "\uF92C\uF979\uF995\uF9E7\uF9F1"],
      ["fe40", "\uFA0C\uFA0D\uFA0E\uFA0F\uFA11\uFA13\uFA14\uFA18\uFA1F\uFA20\uFA21\uFA23\uFA24\uFA27\uFA28\uFA29"]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/gbk-added.json
var require_gbk_added = __commonJS({
  "node_modules/iconv-lite/encodings/tables/gbk-added.json"(exports, module2) {
    module2.exports = [
      ["a140", "\uE4C6", 62],
      ["a180", "\uE505", 32],
      ["a240", "\uE526", 62],
      ["a280", "\uE565", 32],
      ["a2ab", "\uE766", 5],
      ["a2e3", "\u20AC\uE76D"],
      ["a2ef", "\uE76E\uE76F"],
      ["a2fd", "\uE770\uE771"],
      ["a340", "\uE586", 62],
      ["a380", "\uE5C5", 31, "\u3000"],
      ["a440", "\uE5E6", 62],
      ["a480", "\uE625", 32],
      ["a4f4", "\uE772", 10],
      ["a540", "\uE646", 62],
      ["a580", "\uE685", 32],
      ["a5f7", "\uE77D", 7],
      ["a640", "\uE6A6", 62],
      ["a680", "\uE6E5", 32],
      ["a6b9", "\uE785", 7],
      ["a6d9", "\uE78D", 6],
      ["a6ec", "\uE794\uE795"],
      ["a6f3", "\uE796"],
      ["a6f6", "\uE797", 8],
      ["a740", "\uE706", 62],
      ["a780", "\uE745", 32],
      ["a7c2", "\uE7A0", 14],
      ["a7f2", "\uE7AF", 12],
      ["a896", "\uE7BC", 10],
      ["a8bc", "\uE7C7"],
      ["a8bf", "\u01F9"],
      ["a8c1", "\uE7C9\uE7CA\uE7CB\uE7CC"],
      ["a8ea", "\uE7CD", 20],
      ["a958", "\uE7E2"],
      ["a95b", "\uE7E3"],
      ["a95d", "\uE7E4\uE7E5\uE7E6"],
      ["a989", "\u303E\u2FF0", 11],
      ["a997", "\uE7F4", 12],
      ["a9f0", "\uE801", 14],
      ["aaa1", "\uE000", 93],
      ["aba1", "\uE05E", 93],
      ["aca1", "\uE0BC", 93],
      ["ada1", "\uE11A", 93],
      ["aea1", "\uE178", 93],
      ["afa1", "\uE1D6", 93],
      ["d7fa", "\uE810", 4],
      ["f8a1", "\uE234", 93],
      ["f9a1", "\uE292", 93],
      ["faa1", "\uE2F0", 93],
      ["fba1", "\uE34E", 93],
      ["fca1", "\uE3AC", 93],
      ["fda1", "\uE40A", 93],
      ["fe50", "\u2E81\uE816\uE817\uE818\u2E84\u3473\u3447\u2E88\u2E8B\uE81E\u359E\u361A\u360E\u2E8C\u2E97\u396E\u3918\uE826\u39CF\u39DF\u3A73\u39D0\uE82B\uE82C\u3B4E\u3C6E\u3CE0\u2EA7\uE831\uE832\u2EAA\u4056\u415F\u2EAE\u4337\u2EB3\u2EB6\u2EB7\uE83B\u43B1\u43AC\u2EBB\u43DD\u44D6\u4661\u464C\uE843"],
      ["fe80", "\u4723\u4729\u477C\u478D\u2ECA\u4947\u497A\u497D\u4982\u4983\u4985\u4986\u499F\u499B\u49B7\u49B6\uE854\uE855\u4CA3\u4C9F\u4CA0\u4CA1\u4C77\u4CA2\u4D13", 6, "\u4DAE\uE864\uE468", 93]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/gb18030-ranges.json
var require_gb18030_ranges = __commonJS({
  "node_modules/iconv-lite/encodings/tables/gb18030-ranges.json"(exports, module2) {
    module2.exports = { uChars: [128, 165, 169, 178, 184, 216, 226, 235, 238, 244, 248, 251, 253, 258, 276, 284, 300, 325, 329, 334, 364, 463, 465, 467, 469, 471, 473, 475, 477, 506, 594, 610, 712, 716, 730, 930, 938, 962, 970, 1026, 1104, 1106, 8209, 8215, 8218, 8222, 8231, 8241, 8244, 8246, 8252, 8365, 8452, 8454, 8458, 8471, 8482, 8556, 8570, 8596, 8602, 8713, 8720, 8722, 8726, 8731, 8737, 8740, 8742, 8748, 8751, 8760, 8766, 8777, 8781, 8787, 8802, 8808, 8816, 8854, 8858, 8870, 8896, 8979, 9322, 9372, 9548, 9588, 9616, 9622, 9634, 9652, 9662, 9672, 9676, 9680, 9702, 9735, 9738, 9793, 9795, 11906, 11909, 11913, 11917, 11928, 11944, 11947, 11951, 11956, 11960, 11964, 11979, 12284, 12292, 12312, 12319, 12330, 12351, 12436, 12447, 12535, 12543, 12586, 12842, 12850, 12964, 13200, 13215, 13218, 13253, 13263, 13267, 13270, 13384, 13428, 13727, 13839, 13851, 14617, 14703, 14801, 14816, 14964, 15183, 15471, 15585, 16471, 16736, 17208, 17325, 17330, 17374, 17623, 17997, 18018, 18212, 18218, 18301, 18318, 18760, 18811, 18814, 18820, 18823, 18844, 18848, 18872, 19576, 19620, 19738, 19887, 40870, 59244, 59336, 59367, 59413, 59417, 59423, 59431, 59437, 59443, 59452, 59460, 59478, 59493, 63789, 63866, 63894, 63976, 63986, 64016, 64018, 64021, 64025, 64034, 64037, 64042, 65074, 65093, 65107, 65112, 65127, 65132, 65375, 65510, 65536], gbChars: [0, 36, 38, 45, 50, 81, 89, 95, 96, 100, 103, 104, 105, 109, 126, 133, 148, 172, 175, 179, 208, 306, 307, 308, 309, 310, 311, 312, 313, 341, 428, 443, 544, 545, 558, 741, 742, 749, 750, 805, 819, 820, 7922, 7924, 7925, 7927, 7934, 7943, 7944, 7945, 7950, 8062, 8148, 8149, 8152, 8164, 8174, 8236, 8240, 8262, 8264, 8374, 8380, 8381, 8384, 8388, 8390, 8392, 8393, 8394, 8396, 8401, 8406, 8416, 8419, 8424, 8437, 8439, 8445, 8482, 8485, 8496, 8521, 8603, 8936, 8946, 9046, 9050, 9063, 9066, 9076, 9092, 9100, 9108, 9111, 9113, 9131, 9162, 9164, 9218, 9219, 11329, 11331, 11334, 11336, 11346, 11361, 11363, 11366, 11370, 11372, 11375, 11389, 11682, 11686, 11687, 11692, 11694, 11714, 11716, 11723, 11725, 11730, 11736, 11982, 11989, 12102, 12336, 12348, 12350, 12384, 12393, 12395, 12397, 12510, 12553, 12851, 12962, 12973, 13738, 13823, 13919, 13933, 14080, 14298, 14585, 14698, 15583, 15847, 16318, 16434, 16438, 16481, 16729, 17102, 17122, 17315, 17320, 17402, 17418, 17859, 17909, 17911, 17915, 17916, 17936, 17939, 17961, 18664, 18703, 18814, 18962, 19043, 33469, 33470, 33471, 33484, 33485, 33490, 33497, 33501, 33505, 33513, 33520, 33536, 33550, 37845, 37921, 37948, 38029, 38038, 38064, 38065, 38066, 38069, 38075, 38076, 38078, 39108, 39109, 39113, 39114, 39115, 39116, 39265, 39394, 189e3] };
  }
});

// node_modules/iconv-lite/encodings/tables/cp949.json
var require_cp949 = __commonJS({
  "node_modules/iconv-lite/encodings/tables/cp949.json"(exports, module2) {
    module2.exports = [
      ["0", "\0", 127],
      ["8141", "\uAC02\uAC03\uAC05\uAC06\uAC0B", 4, "\uAC18\uAC1E\uAC1F\uAC21\uAC22\uAC23\uAC25", 6, "\uAC2E\uAC32\uAC33\uAC34"],
      ["8161", "\uAC35\uAC36\uAC37\uAC3A\uAC3B\uAC3D\uAC3E\uAC3F\uAC41", 9, "\uAC4C\uAC4E", 5, "\uAC55"],
      ["8181", "\uAC56\uAC57\uAC59\uAC5A\uAC5B\uAC5D", 18, "\uAC72\uAC73\uAC75\uAC76\uAC79\uAC7B", 4, "\uAC82\uAC87\uAC88\uAC8D\uAC8E\uAC8F\uAC91\uAC92\uAC93\uAC95", 6, "\uAC9E\uACA2", 5, "\uACAB\uACAD\uACAE\uACB1", 6, "\uACBA\uACBE\uACBF\uACC0\uACC2\uACC3\uACC5\uACC6\uACC7\uACC9\uACCA\uACCB\uACCD", 7, "\uACD6\uACD8", 7, "\uACE2\uACE3\uACE5\uACE6\uACE9\uACEB\uACED\uACEE\uACF2\uACF4\uACF7", 4, "\uACFE\uACFF\uAD01\uAD02\uAD03\uAD05\uAD07", 4, "\uAD0E\uAD10\uAD12\uAD13"],
      ["8241", "\uAD14\uAD15\uAD16\uAD17\uAD19\uAD1A\uAD1B\uAD1D\uAD1E\uAD1F\uAD21", 7, "\uAD2A\uAD2B\uAD2E", 5],
      ["8261", "\uAD36\uAD37\uAD39\uAD3A\uAD3B\uAD3D", 6, "\uAD46\uAD48\uAD4A", 5, "\uAD51\uAD52\uAD53\uAD55\uAD56\uAD57"],
      ["8281", "\uAD59", 7, "\uAD62\uAD64", 7, "\uAD6E\uAD6F\uAD71\uAD72\uAD77\uAD78\uAD79\uAD7A\uAD7E\uAD80\uAD83", 4, "\uAD8A\uAD8B\uAD8D\uAD8E\uAD8F\uAD91", 10, "\uAD9E", 5, "\uADA5", 17, "\uADB8", 7, "\uADC2\uADC3\uADC5\uADC6\uADC7\uADC9", 6, "\uADD2\uADD4", 7, "\uADDD\uADDE\uADDF\uADE1\uADE2\uADE3\uADE5", 18],
      ["8341", "\uADFA\uADFB\uADFD\uADFE\uAE02", 5, "\uAE0A\uAE0C\uAE0E", 5, "\uAE15", 7],
      ["8361", "\uAE1D", 18, "\uAE32\uAE33\uAE35\uAE36\uAE39\uAE3B\uAE3C"],
      ["8381", "\uAE3D\uAE3E\uAE3F\uAE42\uAE44\uAE47\uAE48\uAE49\uAE4B\uAE4F\uAE51\uAE52\uAE53\uAE55\uAE57", 4, "\uAE5E\uAE62\uAE63\uAE64\uAE66\uAE67\uAE6A\uAE6B\uAE6D\uAE6E\uAE6F\uAE71", 6, "\uAE7A\uAE7E", 5, "\uAE86", 5, "\uAE8D", 46, "\uAEBF\uAEC1\uAEC2\uAEC3\uAEC5", 6, "\uAECE\uAED2", 5, "\uAEDA\uAEDB\uAEDD", 8],
      ["8441", "\uAEE6\uAEE7\uAEE9\uAEEA\uAEEC\uAEEE", 5, "\uAEF5\uAEF6\uAEF7\uAEF9\uAEFA\uAEFB\uAEFD", 8],
      ["8461", "\uAF06\uAF09\uAF0A\uAF0B\uAF0C\uAF0E\uAF0F\uAF11", 18],
      ["8481", "\uAF24", 7, "\uAF2E\uAF2F\uAF31\uAF33\uAF35", 6, "\uAF3E\uAF40\uAF44\uAF45\uAF46\uAF47\uAF4A", 5, "\uAF51", 10, "\uAF5E", 5, "\uAF66", 18, "\uAF7A", 5, "\uAF81\uAF82\uAF83\uAF85\uAF86\uAF87\uAF89", 6, "\uAF92\uAF93\uAF94\uAF96", 5, "\uAF9D", 26, "\uAFBA\uAFBB\uAFBD\uAFBE"],
      ["8541", "\uAFBF\uAFC1", 5, "\uAFCA\uAFCC\uAFCF", 4, "\uAFD5", 6, "\uAFDD", 4],
      ["8561", "\uAFE2", 5, "\uAFEA", 5, "\uAFF2\uAFF3\uAFF5\uAFF6\uAFF7\uAFF9", 6, "\uB002\uB003"],
      ["8581", "\uB005", 6, "\uB00D\uB00E\uB00F\uB011\uB012\uB013\uB015", 6, "\uB01E", 9, "\uB029", 26, "\uB046\uB047\uB049\uB04B\uB04D\uB04F\uB050\uB051\uB052\uB056\uB058\uB05A\uB05B\uB05C\uB05E", 29, "\uB07E\uB07F\uB081\uB082\uB083\uB085", 6, "\uB08E\uB090\uB092", 5, "\uB09B\uB09D\uB09E\uB0A3\uB0A4"],
      ["8641", "\uB0A5\uB0A6\uB0A7\uB0AA\uB0B0\uB0B2\uB0B6\uB0B7\uB0B9\uB0BA\uB0BB\uB0BD", 6, "\uB0C6\uB0CA", 5, "\uB0D2"],
      ["8661", "\uB0D3\uB0D5\uB0D6\uB0D7\uB0D9", 6, "\uB0E1\uB0E2\uB0E3\uB0E4\uB0E6", 10],
      ["8681", "\uB0F1", 22, "\uB10A\uB10D\uB10E\uB10F\uB111\uB114\uB115\uB116\uB117\uB11A\uB11E", 4, "\uB126\uB127\uB129\uB12A\uB12B\uB12D", 6, "\uB136\uB13A", 5, "\uB142\uB143\uB145\uB146\uB147\uB149", 6, "\uB152\uB153\uB156\uB157\uB159\uB15A\uB15B\uB15D\uB15E\uB15F\uB161", 22, "\uB17A\uB17B\uB17D\uB17E\uB17F\uB181\uB183", 4, "\uB18A\uB18C\uB18E\uB18F\uB190\uB191\uB195\uB196\uB197\uB199\uB19A\uB19B\uB19D"],
      ["8741", "\uB19E", 9, "\uB1A9", 15],
      ["8761", "\uB1B9", 18, "\uB1CD\uB1CE\uB1CF\uB1D1\uB1D2\uB1D3\uB1D5"],
      ["8781", "\uB1D6", 5, "\uB1DE\uB1E0", 7, "\uB1EA\uB1EB\uB1ED\uB1EE\uB1EF\uB1F1", 7, "\uB1FA\uB1FC\uB1FE", 5, "\uB206\uB207\uB209\uB20A\uB20D", 6, "\uB216\uB218\uB21A", 5, "\uB221", 18, "\uB235", 6, "\uB23D", 26, "\uB259\uB25A\uB25B\uB25D\uB25E\uB25F\uB261", 6, "\uB26A", 4],
      ["8841", "\uB26F", 4, "\uB276", 5, "\uB27D", 6, "\uB286\uB287\uB288\uB28A", 4],
      ["8861", "\uB28F\uB292\uB293\uB295\uB296\uB297\uB29B", 4, "\uB2A2\uB2A4\uB2A7\uB2A8\uB2A9\uB2AB\uB2AD\uB2AE\uB2AF\uB2B1\uB2B2\uB2B3\uB2B5\uB2B6\uB2B7"],
      ["8881", "\uB2B8", 15, "\uB2CA\uB2CB\uB2CD\uB2CE\uB2CF\uB2D1\uB2D3", 4, "\uB2DA\uB2DC\uB2DE\uB2DF\uB2E0\uB2E1\uB2E3\uB2E7\uB2E9\uB2EA\uB2F0\uB2F1\uB2F2\uB2F6\uB2FC\uB2FD\uB2FE\uB302\uB303\uB305\uB306\uB307\uB309", 6, "\uB312\uB316", 5, "\uB31D", 54, "\uB357\uB359\uB35A\uB35D\uB360\uB361\uB362\uB363"],
      ["8941", "\uB366\uB368\uB36A\uB36C\uB36D\uB36F\uB372\uB373\uB375\uB376\uB377\uB379", 6, "\uB382\uB386", 5, "\uB38D"],
      ["8961", "\uB38E\uB38F\uB391\uB392\uB393\uB395", 10, "\uB3A2", 5, "\uB3A9\uB3AA\uB3AB\uB3AD"],
      ["8981", "\uB3AE", 21, "\uB3C6\uB3C7\uB3C9\uB3CA\uB3CD\uB3CF\uB3D1\uB3D2\uB3D3\uB3D6\uB3D8\uB3DA\uB3DC\uB3DE\uB3DF\uB3E1\uB3E2\uB3E3\uB3E5\uB3E6\uB3E7\uB3E9", 18, "\uB3FD", 18, "\uB411", 6, "\uB419\uB41A\uB41B\uB41D\uB41E\uB41F\uB421", 6, "\uB42A\uB42C", 7, "\uB435", 15],
      ["8a41", "\uB445", 10, "\uB452\uB453\uB455\uB456\uB457\uB459", 6, "\uB462\uB464\uB466"],
      ["8a61", "\uB467", 4, "\uB46D", 18, "\uB481\uB482"],
      ["8a81", "\uB483", 4, "\uB489", 19, "\uB49E", 5, "\uB4A5\uB4A6\uB4A7\uB4A9\uB4AA\uB4AB\uB4AD", 7, "\uB4B6\uB4B8\uB4BA", 5, "\uB4C1\uB4C2\uB4C3\uB4C5\uB4C6\uB4C7\uB4C9", 6, "\uB4D1\uB4D2\uB4D3\uB4D4\uB4D6", 5, "\uB4DE\uB4DF\uB4E1\uB4E2\uB4E5\uB4E7", 4, "\uB4EE\uB4F0\uB4F2", 5, "\uB4F9", 26, "\uB516\uB517\uB519\uB51A\uB51D"],
      ["8b41", "\uB51E", 5, "\uB526\uB52B", 4, "\uB532\uB533\uB535\uB536\uB537\uB539", 6, "\uB542\uB546"],
      ["8b61", "\uB547\uB548\uB549\uB54A\uB54E\uB54F\uB551\uB552\uB553\uB555", 6, "\uB55E\uB562", 8],
      ["8b81", "\uB56B", 52, "\uB5A2\uB5A3\uB5A5\uB5A6\uB5A7\uB5A9\uB5AC\uB5AD\uB5AE\uB5AF\uB5B2\uB5B6", 4, "\uB5BE\uB5BF\uB5C1\uB5C2\uB5C3\uB5C5", 6, "\uB5CE\uB5D2", 5, "\uB5D9", 18, "\uB5ED", 18],
      ["8c41", "\uB600", 15, "\uB612\uB613\uB615\uB616\uB617\uB619", 4],
      ["8c61", "\uB61E", 6, "\uB626", 5, "\uB62D", 6, "\uB635", 5],
      ["8c81", "\uB63B", 12, "\uB649", 26, "\uB665\uB666\uB667\uB669", 50, "\uB69E\uB69F\uB6A1\uB6A2\uB6A3\uB6A5", 5, "\uB6AD\uB6AE\uB6AF\uB6B0\uB6B2", 16],
      ["8d41", "\uB6C3", 16, "\uB6D5", 8],
      ["8d61", "\uB6DE", 17, "\uB6F1\uB6F2\uB6F3\uB6F5\uB6F6\uB6F7\uB6F9\uB6FA"],
      ["8d81", "\uB6FB", 4, "\uB702\uB703\uB704\uB706", 33, "\uB72A\uB72B\uB72D\uB72E\uB731", 6, "\uB73A\uB73C", 7, "\uB745\uB746\uB747\uB749\uB74A\uB74B\uB74D", 6, "\uB756", 9, "\uB761\uB762\uB763\uB765\uB766\uB767\uB769", 6, "\uB772\uB774\uB776", 5, "\uB77E\uB77F\uB781\uB782\uB783\uB785", 6, "\uB78E\uB793\uB794\uB795\uB79A\uB79B\uB79D\uB79E"],
      ["8e41", "\uB79F\uB7A1", 6, "\uB7AA\uB7AE", 5, "\uB7B6\uB7B7\uB7B9", 8],
      ["8e61", "\uB7C2", 4, "\uB7C8\uB7CA", 19],
      ["8e81", "\uB7DE", 13, "\uB7EE\uB7EF\uB7F1\uB7F2\uB7F3\uB7F5", 6, "\uB7FE\uB802", 4, "\uB80A\uB80B\uB80D\uB80E\uB80F\uB811", 6, "\uB81A\uB81C\uB81E", 5, "\uB826\uB827\uB829\uB82A\uB82B\uB82D", 6, "\uB836\uB83A", 5, "\uB841\uB842\uB843\uB845", 11, "\uB852\uB854", 7, "\uB85E\uB85F\uB861\uB862\uB863\uB865", 6, "\uB86E\uB870\uB872", 5, "\uB879\uB87A\uB87B\uB87D", 7],
      ["8f41", "\uB885", 7, "\uB88E", 17],
      ["8f61", "\uB8A0", 7, "\uB8A9", 6, "\uB8B1\uB8B2\uB8B3\uB8B5\uB8B6\uB8B7\uB8B9", 4],
      ["8f81", "\uB8BE\uB8BF\uB8C2\uB8C4\uB8C6", 5, "\uB8CD\uB8CE\uB8CF\uB8D1\uB8D2\uB8D3\uB8D5", 7, "\uB8DE\uB8E0\uB8E2", 5, "\uB8EA\uB8EB\uB8ED\uB8EE\uB8EF\uB8F1", 6, "\uB8FA\uB8FC\uB8FE", 5, "\uB905", 18, "\uB919", 6, "\uB921", 26, "\uB93E\uB93F\uB941\uB942\uB943\uB945", 6, "\uB94D\uB94E\uB950\uB952", 5],
      ["9041", "\uB95A\uB95B\uB95D\uB95E\uB95F\uB961", 6, "\uB96A\uB96C\uB96E", 5, "\uB976\uB977\uB979\uB97A\uB97B\uB97D"],
      ["9061", "\uB97E", 5, "\uB986\uB988\uB98B\uB98C\uB98F", 15],
      ["9081", "\uB99F", 12, "\uB9AE\uB9AF\uB9B1\uB9B2\uB9B3\uB9B5", 6, "\uB9BE\uB9C0\uB9C2", 5, "\uB9CA\uB9CB\uB9CD\uB9D3", 4, "\uB9DA\uB9DC\uB9DF\uB9E0\uB9E2\uB9E6\uB9E7\uB9E9\uB9EA\uB9EB\uB9ED", 6, "\uB9F6\uB9FB", 4, "\uBA02", 5, "\uBA09", 11, "\uBA16", 33, "\uBA3A\uBA3B\uBA3D\uBA3E\uBA3F\uBA41\uBA43\uBA44\uBA45\uBA46"],
      ["9141", "\uBA47\uBA4A\uBA4C\uBA4F\uBA50\uBA51\uBA52\uBA56\uBA57\uBA59\uBA5A\uBA5B\uBA5D", 6, "\uBA66\uBA6A", 5],
      ["9161", "\uBA72\uBA73\uBA75\uBA76\uBA77\uBA79", 9, "\uBA86\uBA88\uBA89\uBA8A\uBA8B\uBA8D", 5],
      ["9181", "\uBA93", 20, "\uBAAA\uBAAD\uBAAE\uBAAF\uBAB1\uBAB3", 4, "\uBABA\uBABC\uBABE", 5, "\uBAC5\uBAC6\uBAC7\uBAC9", 14, "\uBADA", 33, "\uBAFD\uBAFE\uBAFF\uBB01\uBB02\uBB03\uBB05", 7, "\uBB0E\uBB10\uBB12", 5, "\uBB19\uBB1A\uBB1B\uBB1D\uBB1E\uBB1F\uBB21", 6],
      ["9241", "\uBB28\uBB2A\uBB2C", 7, "\uBB37\uBB39\uBB3A\uBB3F", 4, "\uBB46\uBB48\uBB4A\uBB4B\uBB4C\uBB4E\uBB51\uBB52"],
      ["9261", "\uBB53\uBB55\uBB56\uBB57\uBB59", 7, "\uBB62\uBB64", 7, "\uBB6D", 4],
      ["9281", "\uBB72", 21, "\uBB89\uBB8A\uBB8B\uBB8D\uBB8E\uBB8F\uBB91", 18, "\uBBA5\uBBA6\uBBA7\uBBA9\uBBAA\uBBAB\uBBAD", 6, "\uBBB5\uBBB6\uBBB8", 7, "\uBBC1\uBBC2\uBBC3\uBBC5\uBBC6\uBBC7\uBBC9", 6, "\uBBD1\uBBD2\uBBD4", 35, "\uBBFA\uBBFB\uBBFD\uBBFE\uBC01"],
      ["9341", "\uBC03", 4, "\uBC0A\uBC0E\uBC10\uBC12\uBC13\uBC19\uBC1A\uBC20\uBC21\uBC22\uBC23\uBC26\uBC28\uBC2A\uBC2B\uBC2C\uBC2E\uBC2F\uBC32\uBC33\uBC35"],
      ["9361", "\uBC36\uBC37\uBC39", 6, "\uBC42\uBC46\uBC47\uBC48\uBC4A\uBC4B\uBC4E\uBC4F\uBC51", 8],
      ["9381", "\uBC5A\uBC5B\uBC5C\uBC5E", 37, "\uBC86\uBC87\uBC89\uBC8A\uBC8D\uBC8F", 4, "\uBC96\uBC98\uBC9B", 4, "\uBCA2\uBCA3\uBCA5\uBCA6\uBCA9", 6, "\uBCB2\uBCB6", 5, "\uBCBE\uBCBF\uBCC1\uBCC2\uBCC3\uBCC5", 7, "\uBCCE\uBCD2\uBCD3\uBCD4\uBCD6\uBCD7\uBCD9\uBCDA\uBCDB\uBCDD", 22, "\uBCF7\uBCF9\uBCFA\uBCFB\uBCFD"],
      ["9441", "\uBCFE", 5, "\uBD06\uBD08\uBD0A", 5, "\uBD11\uBD12\uBD13\uBD15", 8],
      ["9461", "\uBD1E", 5, "\uBD25", 6, "\uBD2D", 12],
      ["9481", "\uBD3A", 5, "\uBD41", 6, "\uBD4A\uBD4B\uBD4D\uBD4E\uBD4F\uBD51", 6, "\uBD5A", 9, "\uBD65\uBD66\uBD67\uBD69", 22, "\uBD82\uBD83\uBD85\uBD86\uBD8B", 4, "\uBD92\uBD94\uBD96\uBD97\uBD98\uBD9B\uBD9D", 6, "\uBDA5", 10, "\uBDB1", 6, "\uBDB9", 24],
      ["9541", "\uBDD2\uBDD3\uBDD6\uBDD7\uBDD9\uBDDA\uBDDB\uBDDD", 11, "\uBDEA", 5, "\uBDF1"],
      ["9561", "\uBDF2\uBDF3\uBDF5\uBDF6\uBDF7\uBDF9", 6, "\uBE01\uBE02\uBE04\uBE06", 5, "\uBE0E\uBE0F\uBE11\uBE12\uBE13"],
      ["9581", "\uBE15", 6, "\uBE1E\uBE20", 35, "\uBE46\uBE47\uBE49\uBE4A\uBE4B\uBE4D\uBE4F", 4, "\uBE56\uBE58\uBE5C\uBE5D\uBE5E\uBE5F\uBE62\uBE63\uBE65\uBE66\uBE67\uBE69\uBE6B", 4, "\uBE72\uBE76", 4, "\uBE7E\uBE7F\uBE81\uBE82\uBE83\uBE85", 6, "\uBE8E\uBE92", 5, "\uBE9A", 13, "\uBEA9", 14],
      ["9641", "\uBEB8", 23, "\uBED2\uBED3"],
      ["9661", "\uBED5\uBED6\uBED9", 6, "\uBEE1\uBEE2\uBEE6", 5, "\uBEED", 8],
      ["9681", "\uBEF6", 10, "\uBF02", 5, "\uBF0A", 13, "\uBF1A\uBF1E", 33, "\uBF42\uBF43\uBF45\uBF46\uBF47\uBF49", 6, "\uBF52\uBF53\uBF54\uBF56", 44],
      ["9741", "\uBF83", 16, "\uBF95", 8],
      ["9761", "\uBF9E", 17, "\uBFB1", 7],
      ["9781", "\uBFB9", 11, "\uBFC6", 5, "\uBFCE\uBFCF\uBFD1\uBFD2\uBFD3\uBFD5", 6, "\uBFDD\uBFDE\uBFE0\uBFE2", 89, "\uC03D\uC03E\uC03F"],
      ["9841", "\uC040", 16, "\uC052", 5, "\uC059\uC05A\uC05B"],
      ["9861", "\uC05D\uC05E\uC05F\uC061", 6, "\uC06A", 15],
      ["9881", "\uC07A", 21, "\uC092\uC093\uC095\uC096\uC097\uC099", 6, "\uC0A2\uC0A4\uC0A6", 5, "\uC0AE\uC0B1\uC0B2\uC0B7", 4, "\uC0BE\uC0C2\uC0C3\uC0C4\uC0C6\uC0C7\uC0CA\uC0CB\uC0CD\uC0CE\uC0CF\uC0D1", 6, "\uC0DA\uC0DE", 5, "\uC0E6\uC0E7\uC0E9\uC0EA\uC0EB\uC0ED", 6, "\uC0F6\uC0F8\uC0FA", 5, "\uC101\uC102\uC103\uC105\uC106\uC107\uC109", 6, "\uC111\uC112\uC113\uC114\uC116", 5, "\uC121\uC122\uC125\uC128\uC129\uC12A\uC12B\uC12E"],
      ["9941", "\uC132\uC133\uC134\uC135\uC137\uC13A\uC13B\uC13D\uC13E\uC13F\uC141", 6, "\uC14A\uC14E", 5, "\uC156\uC157"],
      ["9961", "\uC159\uC15A\uC15B\uC15D", 6, "\uC166\uC16A", 5, "\uC171\uC172\uC173\uC175\uC176\uC177\uC179\uC17A\uC17B"],
      ["9981", "\uC17C", 8, "\uC186", 5, "\uC18F\uC191\uC192\uC193\uC195\uC197", 4, "\uC19E\uC1A0\uC1A2\uC1A3\uC1A4\uC1A6\uC1A7\uC1AA\uC1AB\uC1AD\uC1AE\uC1AF\uC1B1", 11, "\uC1BE", 5, "\uC1C5\uC1C6\uC1C7\uC1C9\uC1CA\uC1CB\uC1CD", 6, "\uC1D5\uC1D6\uC1D9", 6, "\uC1E1\uC1E2\uC1E3\uC1E5\uC1E6\uC1E7\uC1E9", 6, "\uC1F2\uC1F4", 7, "\uC1FE\uC1FF\uC201\uC202\uC203\uC205", 6, "\uC20E\uC210\uC212", 5, "\uC21A\uC21B\uC21D\uC21E\uC221\uC222\uC223"],
      ["9a41", "\uC224\uC225\uC226\uC227\uC22A\uC22C\uC22E\uC230\uC233\uC235", 16],
      ["9a61", "\uC246\uC247\uC249", 6, "\uC252\uC253\uC255\uC256\uC257\uC259", 6, "\uC261\uC262\uC263\uC264\uC266"],
      ["9a81", "\uC267", 4, "\uC26E\uC26F\uC271\uC272\uC273\uC275", 6, "\uC27E\uC280\uC282", 5, "\uC28A", 5, "\uC291", 6, "\uC299\uC29A\uC29C\uC29E", 5, "\uC2A6\uC2A7\uC2A9\uC2AA\uC2AB\uC2AE", 5, "\uC2B6\uC2B8\uC2BA", 33, "\uC2DE\uC2DF\uC2E1\uC2E2\uC2E5", 5, "\uC2EE\uC2F0\uC2F2\uC2F3\uC2F4\uC2F5\uC2F7\uC2FA\uC2FD\uC2FE\uC2FF\uC301", 6, "\uC30A\uC30B\uC30E\uC30F"],
      ["9b41", "\uC310\uC311\uC312\uC316\uC317\uC319\uC31A\uC31B\uC31D", 6, "\uC326\uC327\uC32A", 8],
      ["9b61", "\uC333", 17, "\uC346", 7],
      ["9b81", "\uC34E", 25, "\uC36A\uC36B\uC36D\uC36E\uC36F\uC371\uC373", 4, "\uC37A\uC37B\uC37E", 5, "\uC385\uC386\uC387\uC389\uC38A\uC38B\uC38D", 50, "\uC3C1", 22, "\uC3DA"],
      ["9c41", "\uC3DB\uC3DD\uC3DE\uC3E1\uC3E3", 4, "\uC3EA\uC3EB\uC3EC\uC3EE", 5, "\uC3F6\uC3F7\uC3F9", 5],
      ["9c61", "\uC3FF", 8, "\uC409", 6, "\uC411", 9],
      ["9c81", "\uC41B", 8, "\uC425", 6, "\uC42D\uC42E\uC42F\uC431\uC432\uC433\uC435", 6, "\uC43E", 9, "\uC449", 26, "\uC466\uC467\uC469\uC46A\uC46B\uC46D", 6, "\uC476\uC477\uC478\uC47A", 5, "\uC481", 18, "\uC495", 6, "\uC49D", 12],
      ["9d41", "\uC4AA", 13, "\uC4B9\uC4BA\uC4BB\uC4BD", 8],
      ["9d61", "\uC4C6", 25],
      ["9d81", "\uC4E0", 8, "\uC4EA", 5, "\uC4F2\uC4F3\uC4F5\uC4F6\uC4F7\uC4F9\uC4FB\uC4FC\uC4FD\uC4FE\uC502", 9, "\uC50D\uC50E\uC50F\uC511\uC512\uC513\uC515", 6, "\uC51D", 10, "\uC52A\uC52B\uC52D\uC52E\uC52F\uC531", 6, "\uC53A\uC53C\uC53E", 5, "\uC546\uC547\uC54B\uC54F\uC550\uC551\uC552\uC556\uC55A\uC55B\uC55C\uC55F\uC562\uC563\uC565\uC566\uC567\uC569", 6, "\uC572\uC576", 5, "\uC57E\uC57F\uC581\uC582\uC583\uC585\uC586\uC588\uC589\uC58A\uC58B\uC58E\uC590\uC592\uC593\uC594"],
      ["9e41", "\uC596\uC599\uC59A\uC59B\uC59D\uC59E\uC59F\uC5A1", 7, "\uC5AA", 9, "\uC5B6"],
      ["9e61", "\uC5B7\uC5BA\uC5BF", 4, "\uC5CB\uC5CD\uC5CF\uC5D2\uC5D3\uC5D5\uC5D6\uC5D7\uC5D9", 6, "\uC5E2\uC5E4\uC5E6\uC5E7"],
      ["9e81", "\uC5E8\uC5E9\uC5EA\uC5EB\uC5EF\uC5F1\uC5F2\uC5F3\uC5F5\uC5F8\uC5F9\uC5FA\uC5FB\uC602\uC603\uC604\uC609\uC60A\uC60B\uC60D\uC60E\uC60F\uC611", 6, "\uC61A\uC61D", 6, "\uC626\uC627\uC629\uC62A\uC62B\uC62F\uC631\uC632\uC636\uC638\uC63A\uC63C\uC63D\uC63E\uC63F\uC642\uC643\uC645\uC646\uC647\uC649", 6, "\uC652\uC656", 5, "\uC65E\uC65F\uC661", 10, "\uC66D\uC66E\uC670\uC672", 5, "\uC67A\uC67B\uC67D\uC67E\uC67F\uC681", 6, "\uC68A\uC68C\uC68E", 5, "\uC696\uC697\uC699\uC69A\uC69B\uC69D", 6, "\uC6A6"],
      ["9f41", "\uC6A8\uC6AA", 5, "\uC6B2\uC6B3\uC6B5\uC6B6\uC6B7\uC6BB", 4, "\uC6C2\uC6C4\uC6C6", 5, "\uC6CE"],
      ["9f61", "\uC6CF\uC6D1\uC6D2\uC6D3\uC6D5", 6, "\uC6DE\uC6DF\uC6E2", 5, "\uC6EA\uC6EB\uC6ED\uC6EE\uC6EF\uC6F1\uC6F2"],
      ["9f81", "\uC6F3", 4, "\uC6FA\uC6FB\uC6FC\uC6FE", 5, "\uC706\uC707\uC709\uC70A\uC70B\uC70D", 6, "\uC716\uC718\uC71A", 5, "\uC722\uC723\uC725\uC726\uC727\uC729", 6, "\uC732\uC734\uC736\uC738\uC739\uC73A\uC73B\uC73E\uC73F\uC741\uC742\uC743\uC745", 4, "\uC74B\uC74E\uC750\uC759\uC75A\uC75B\uC75D\uC75E\uC75F\uC761", 6, "\uC769\uC76A\uC76C", 7, "\uC776\uC777\uC779\uC77A\uC77B\uC77F\uC780\uC781\uC782\uC786\uC78B\uC78C\uC78D\uC78F\uC792\uC793\uC795\uC799\uC79B", 4, "\uC7A2\uC7A7", 4, "\uC7AE\uC7AF\uC7B1\uC7B2\uC7B3\uC7B5\uC7B6\uC7B7"],
      ["a041", "\uC7B8\uC7B9\uC7BA\uC7BB\uC7BE\uC7C2", 5, "\uC7CA\uC7CB\uC7CD\uC7CF\uC7D1", 6, "\uC7D9\uC7DA\uC7DB\uC7DC"],
      ["a061", "\uC7DE", 5, "\uC7E5\uC7E6\uC7E7\uC7E9\uC7EA\uC7EB\uC7ED", 13],
      ["a081", "\uC7FB", 4, "\uC802\uC803\uC805\uC806\uC807\uC809\uC80B", 4, "\uC812\uC814\uC817", 4, "\uC81E\uC81F\uC821\uC822\uC823\uC825", 6, "\uC82E\uC830\uC832", 5, "\uC839\uC83A\uC83B\uC83D\uC83E\uC83F\uC841", 6, "\uC84A\uC84B\uC84E", 5, "\uC855", 26, "\uC872\uC873\uC875\uC876\uC877\uC879\uC87B", 4, "\uC882\uC884\uC888\uC889\uC88A\uC88E", 5, "\uC895", 7, "\uC89E\uC8A0\uC8A2\uC8A3\uC8A4"],
      ["a141", "\uC8A5\uC8A6\uC8A7\uC8A9", 18, "\uC8BE\uC8BF\uC8C0\uC8C1"],
      ["a161", "\uC8C2\uC8C3\uC8C5\uC8C6\uC8C7\uC8C9\uC8CA\uC8CB\uC8CD", 6, "\uC8D6\uC8D8\uC8DA", 5, "\uC8E2\uC8E3\uC8E5"],
      ["a181", "\uC8E6", 14, "\uC8F6", 5, "\uC8FE\uC8FF\uC901\uC902\uC903\uC907", 4, "\uC90E\u3000\u3001\u3002\xB7\u2025\u2026\xA8\u3003\xAD\u2015\u2225\uFF3C\u223C\u2018\u2019\u201C\u201D\u3014\u3015\u3008", 9, "\xB1\xD7\xF7\u2260\u2264\u2265\u221E\u2234\xB0\u2032\u2033\u2103\u212B\uFFE0\uFFE1\uFFE5\u2642\u2640\u2220\u22A5\u2312\u2202\u2207\u2261\u2252\xA7\u203B\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u25BD\u25BC\u2192\u2190\u2191\u2193\u2194\u3013\u226A\u226B\u221A\u223D\u221D\u2235\u222B\u222C\u2208\u220B\u2286\u2287\u2282\u2283\u222A\u2229\u2227\u2228\uFFE2"],
      ["a241", "\uC910\uC912", 5, "\uC919", 18],
      ["a261", "\uC92D", 6, "\uC935", 18],
      ["a281", "\uC948", 7, "\uC952\uC953\uC955\uC956\uC957\uC959", 6, "\uC962\uC964", 7, "\uC96D\uC96E\uC96F\u21D2\u21D4\u2200\u2203\xB4\uFF5E\u02C7\u02D8\u02DD\u02DA\u02D9\xB8\u02DB\xA1\xBF\u02D0\u222E\u2211\u220F\xA4\u2109\u2030\u25C1\u25C0\u25B7\u25B6\u2664\u2660\u2661\u2665\u2667\u2663\u2299\u25C8\u25A3\u25D0\u25D1\u2592\u25A4\u25A5\u25A8\u25A7\u25A6\u25A9\u2668\u260F\u260E\u261C\u261E\xB6\u2020\u2021\u2195\u2197\u2199\u2196\u2198\u266D\u2669\u266A\u266C\u327F\u321C\u2116\u33C7\u2122\u33C2\u33D8\u2121\u20AC\xAE"],
      ["a341", "\uC971\uC972\uC973\uC975", 6, "\uC97D", 10, "\uC98A\uC98B\uC98D\uC98E\uC98F"],
      ["a361", "\uC991", 6, "\uC99A\uC99C\uC99E", 16],
      ["a381", "\uC9AF", 16, "\uC9C2\uC9C3\uC9C5\uC9C6\uC9C9\uC9CB", 4, "\uC9D2\uC9D4\uC9D7\uC9D8\uC9DB\uFF01", 58, "\uFFE6\uFF3D", 32, "\uFFE3"],
      ["a441", "\uC9DE\uC9DF\uC9E1\uC9E3\uC9E5\uC9E6\uC9E8\uC9E9\uC9EA\uC9EB\uC9EE\uC9F2", 5, "\uC9FA\uC9FB\uC9FD\uC9FE\uC9FF\uCA01\uCA02\uCA03\uCA04"],
      ["a461", "\uCA05\uCA06\uCA07\uCA0A\uCA0E", 5, "\uCA15\uCA16\uCA17\uCA19", 12],
      ["a481", "\uCA26\uCA27\uCA28\uCA2A", 28, "\u3131", 93],
      ["a541", "\uCA47", 4, "\uCA4E\uCA4F\uCA51\uCA52\uCA53\uCA55", 6, "\uCA5E\uCA62", 5, "\uCA69\uCA6A"],
      ["a561", "\uCA6B", 17, "\uCA7E", 5, "\uCA85\uCA86"],
      ["a581", "\uCA87", 16, "\uCA99", 14, "\u2170", 9],
      ["a5b0", "\u2160", 9],
      ["a5c1", "\u0391", 16, "\u03A3", 6],
      ["a5e1", "\u03B1", 16, "\u03C3", 6],
      ["a641", "\uCAA8", 19, "\uCABE\uCABF\uCAC1\uCAC2\uCAC3\uCAC5"],
      ["a661", "\uCAC6", 5, "\uCACE\uCAD0\uCAD2\uCAD4\uCAD5\uCAD6\uCAD7\uCADA", 5, "\uCAE1", 6],
      ["a681", "\uCAE8\uCAE9\uCAEA\uCAEB\uCAED", 6, "\uCAF5", 18, "\uCB09\uCB0A\u2500\u2502\u250C\u2510\u2518\u2514\u251C\u252C\u2524\u2534\u253C\u2501\u2503\u250F\u2513\u251B\u2517\u2523\u2533\u252B\u253B\u254B\u2520\u252F\u2528\u2537\u253F\u251D\u2530\u2525\u2538\u2542\u2512\u2511\u251A\u2519\u2516\u2515\u250E\u250D\u251E\u251F\u2521\u2522\u2526\u2527\u2529\u252A\u252D\u252E\u2531\u2532\u2535\u2536\u2539\u253A\u253D\u253E\u2540\u2541\u2543", 7],
      ["a741", "\uCB0B", 4, "\uCB11\uCB12\uCB13\uCB15\uCB16\uCB17\uCB19", 6, "\uCB22", 7],
      ["a761", "\uCB2A", 22, "\uCB42\uCB43\uCB44"],
      ["a781", "\uCB45\uCB46\uCB47\uCB4A\uCB4B\uCB4D\uCB4E\uCB4F\uCB51", 6, "\uCB5A\uCB5B\uCB5C\uCB5E", 5, "\uCB65", 7, "\u3395\u3396\u3397\u2113\u3398\u33C4\u33A3\u33A4\u33A5\u33A6\u3399", 9, "\u33CA\u338D\u338E\u338F\u33CF\u3388\u3389\u33C8\u33A7\u33A8\u33B0", 9, "\u3380", 4, "\u33BA", 5, "\u3390", 4, "\u2126\u33C0\u33C1\u338A\u338B\u338C\u33D6\u33C5\u33AD\u33AE\u33AF\u33DB\u33A9\u33AA\u33AB\u33AC\u33DD\u33D0\u33D3\u33C3\u33C9\u33DC\u33C6"],
      ["a841", "\uCB6D", 10, "\uCB7A", 14],
      ["a861", "\uCB89", 18, "\uCB9D", 6],
      ["a881", "\uCBA4", 19, "\uCBB9", 11, "\xC6\xD0\xAA\u0126"],
      ["a8a6", "\u0132"],
      ["a8a8", "\u013F\u0141\xD8\u0152\xBA\xDE\u0166\u014A"],
      ["a8b1", "\u3260", 27, "\u24D0", 25, "\u2460", 14, "\xBD\u2153\u2154\xBC\xBE\u215B\u215C\u215D\u215E"],
      ["a941", "\uCBC5", 14, "\uCBD5", 10],
      ["a961", "\uCBE0\uCBE1\uCBE2\uCBE3\uCBE5\uCBE6\uCBE8\uCBEA", 18],
      ["a981", "\uCBFD", 14, "\uCC0E\uCC0F\uCC11\uCC12\uCC13\uCC15", 6, "\uCC1E\uCC1F\uCC20\uCC23\uCC24\xE6\u0111\xF0\u0127\u0131\u0133\u0138\u0140\u0142\xF8\u0153\xDF\xFE\u0167\u014B\u0149\u3200", 27, "\u249C", 25, "\u2474", 14, "\xB9\xB2\xB3\u2074\u207F\u2081\u2082\u2083\u2084"],
      ["aa41", "\uCC25\uCC26\uCC2A\uCC2B\uCC2D\uCC2F\uCC31", 6, "\uCC3A\uCC3F", 4, "\uCC46\uCC47\uCC49\uCC4A\uCC4B\uCC4D\uCC4E"],
      ["aa61", "\uCC4F", 4, "\uCC56\uCC5A", 5, "\uCC61\uCC62\uCC63\uCC65\uCC67\uCC69", 6, "\uCC71\uCC72"],
      ["aa81", "\uCC73\uCC74\uCC76", 29, "\u3041", 82],
      ["ab41", "\uCC94\uCC95\uCC96\uCC97\uCC9A\uCC9B\uCC9D\uCC9E\uCC9F\uCCA1", 6, "\uCCAA\uCCAE", 5, "\uCCB6\uCCB7\uCCB9"],
      ["ab61", "\uCCBA\uCCBB\uCCBD", 6, "\uCCC6\uCCC8\uCCCA", 5, "\uCCD1\uCCD2\uCCD3\uCCD5", 5],
      ["ab81", "\uCCDB", 8, "\uCCE5", 6, "\uCCED\uCCEE\uCCEF\uCCF1", 12, "\u30A1", 85],
      ["ac41", "\uCCFE\uCCFF\uCD00\uCD02", 5, "\uCD0A\uCD0B\uCD0D\uCD0E\uCD0F\uCD11", 6, "\uCD1A\uCD1C\uCD1E\uCD1F\uCD20"],
      ["ac61", "\uCD21\uCD22\uCD23\uCD25\uCD26\uCD27\uCD29\uCD2A\uCD2B\uCD2D", 11, "\uCD3A", 4],
      ["ac81", "\uCD3F", 28, "\uCD5D\uCD5E\uCD5F\u0410", 5, "\u0401\u0416", 25],
      ["acd1", "\u0430", 5, "\u0451\u0436", 25],
      ["ad41", "\uCD61\uCD62\uCD63\uCD65", 6, "\uCD6E\uCD70\uCD72", 5, "\uCD79", 7],
      ["ad61", "\uCD81", 6, "\uCD89", 10, "\uCD96\uCD97\uCD99\uCD9A\uCD9B\uCD9D\uCD9E\uCD9F"],
      ["ad81", "\uCDA0\uCDA1\uCDA2\uCDA3\uCDA6\uCDA8\uCDAA", 5, "\uCDB1", 18, "\uCDC5"],
      ["ae41", "\uCDC6", 5, "\uCDCD\uCDCE\uCDCF\uCDD1", 16],
      ["ae61", "\uCDE2", 5, "\uCDE9\uCDEA\uCDEB\uCDED\uCDEE\uCDEF\uCDF1", 6, "\uCDFA\uCDFC\uCDFE", 4],
      ["ae81", "\uCE03\uCE05\uCE06\uCE07\uCE09\uCE0A\uCE0B\uCE0D", 6, "\uCE15\uCE16\uCE17\uCE18\uCE1A", 5, "\uCE22\uCE23\uCE25\uCE26\uCE27\uCE29\uCE2A\uCE2B"],
      ["af41", "\uCE2C\uCE2D\uCE2E\uCE2F\uCE32\uCE34\uCE36", 19],
      ["af61", "\uCE4A", 13, "\uCE5A\uCE5B\uCE5D\uCE5E\uCE62", 5, "\uCE6A\uCE6C"],
      ["af81", "\uCE6E", 5, "\uCE76\uCE77\uCE79\uCE7A\uCE7B\uCE7D", 6, "\uCE86\uCE88\uCE8A", 5, "\uCE92\uCE93\uCE95\uCE96\uCE97\uCE99"],
      ["b041", "\uCE9A", 5, "\uCEA2\uCEA6", 5, "\uCEAE", 12],
      ["b061", "\uCEBB", 5, "\uCEC2", 19],
      ["b081", "\uCED6", 13, "\uCEE6\uCEE7\uCEE9\uCEEA\uCEED", 6, "\uCEF6\uCEFA", 5, "\uAC00\uAC01\uAC04\uAC07\uAC08\uAC09\uAC0A\uAC10", 7, "\uAC19", 4, "\uAC20\uAC24\uAC2C\uAC2D\uAC2F\uAC30\uAC31\uAC38\uAC39\uAC3C\uAC40\uAC4B\uAC4D\uAC54\uAC58\uAC5C\uAC70\uAC71\uAC74\uAC77\uAC78\uAC7A\uAC80\uAC81\uAC83\uAC84\uAC85\uAC86\uAC89\uAC8A\uAC8B\uAC8C\uAC90\uAC94\uAC9C\uAC9D\uAC9F\uACA0\uACA1\uACA8\uACA9\uACAA\uACAC\uACAF\uACB0\uACB8\uACB9\uACBB\uACBC\uACBD\uACC1\uACC4\uACC8\uACCC\uACD5\uACD7\uACE0\uACE1\uACE4\uACE7\uACE8\uACEA\uACEC\uACEF\uACF0\uACF1\uACF3\uACF5\uACF6\uACFC\uACFD\uAD00\uAD04\uAD06"],
      ["b141", "\uCF02\uCF03\uCF05\uCF06\uCF07\uCF09", 6, "\uCF12\uCF14\uCF16", 5, "\uCF1D\uCF1E\uCF1F\uCF21\uCF22\uCF23"],
      ["b161", "\uCF25", 6, "\uCF2E\uCF32", 5, "\uCF39", 11],
      ["b181", "\uCF45", 14, "\uCF56\uCF57\uCF59\uCF5A\uCF5B\uCF5D", 6, "\uCF66\uCF68\uCF6A\uCF6B\uCF6C\uAD0C\uAD0D\uAD0F\uAD11\uAD18\uAD1C\uAD20\uAD29\uAD2C\uAD2D\uAD34\uAD35\uAD38\uAD3C\uAD44\uAD45\uAD47\uAD49\uAD50\uAD54\uAD58\uAD61\uAD63\uAD6C\uAD6D\uAD70\uAD73\uAD74\uAD75\uAD76\uAD7B\uAD7C\uAD7D\uAD7F\uAD81\uAD82\uAD88\uAD89\uAD8C\uAD90\uAD9C\uAD9D\uADA4\uADB7\uADC0\uADC1\uADC4\uADC8\uADD0\uADD1\uADD3\uADDC\uADE0\uADE4\uADF8\uADF9\uADFC\uADFF\uAE00\uAE01\uAE08\uAE09\uAE0B\uAE0D\uAE14\uAE30\uAE31\uAE34\uAE37\uAE38\uAE3A\uAE40\uAE41\uAE43\uAE45\uAE46\uAE4A\uAE4C\uAE4D\uAE4E\uAE50\uAE54\uAE56\uAE5C\uAE5D\uAE5F\uAE60\uAE61\uAE65\uAE68\uAE69\uAE6C\uAE70\uAE78"],
      ["b241", "\uCF6D\uCF6E\uCF6F\uCF72\uCF73\uCF75\uCF76\uCF77\uCF79", 6, "\uCF81\uCF82\uCF83\uCF84\uCF86", 5, "\uCF8D"],
      ["b261", "\uCF8E", 18, "\uCFA2", 5, "\uCFA9"],
      ["b281", "\uCFAA", 5, "\uCFB1", 18, "\uCFC5", 6, "\uAE79\uAE7B\uAE7C\uAE7D\uAE84\uAE85\uAE8C\uAEBC\uAEBD\uAEBE\uAEC0\uAEC4\uAECC\uAECD\uAECF\uAED0\uAED1\uAED8\uAED9\uAEDC\uAEE8\uAEEB\uAEED\uAEF4\uAEF8\uAEFC\uAF07\uAF08\uAF0D\uAF10\uAF2C\uAF2D\uAF30\uAF32\uAF34\uAF3C\uAF3D\uAF3F\uAF41\uAF42\uAF43\uAF48\uAF49\uAF50\uAF5C\uAF5D\uAF64\uAF65\uAF79\uAF80\uAF84\uAF88\uAF90\uAF91\uAF95\uAF9C\uAFB8\uAFB9\uAFBC\uAFC0\uAFC7\uAFC8\uAFC9\uAFCB\uAFCD\uAFCE\uAFD4\uAFDC\uAFE8\uAFE9\uAFF0\uAFF1\uAFF4\uAFF8\uB000\uB001\uB004\uB00C\uB010\uB014\uB01C\uB01D\uB028\uB044\uB045\uB048\uB04A\uB04C\uB04E\uB053\uB054\uB055\uB057\uB059"],
      ["b341", "\uCFCC", 19, "\uCFE2\uCFE3\uCFE5\uCFE6\uCFE7\uCFE9"],
      ["b361", "\uCFEA", 5, "\uCFF2\uCFF4\uCFF6", 5, "\uCFFD\uCFFE\uCFFF\uD001\uD002\uD003\uD005", 5],
      ["b381", "\uD00B", 5, "\uD012", 5, "\uD019", 19, "\uB05D\uB07C\uB07D\uB080\uB084\uB08C\uB08D\uB08F\uB091\uB098\uB099\uB09A\uB09C\uB09F\uB0A0\uB0A1\uB0A2\uB0A8\uB0A9\uB0AB", 4, "\uB0B1\uB0B3\uB0B4\uB0B5\uB0B8\uB0BC\uB0C4\uB0C5\uB0C7\uB0C8\uB0C9\uB0D0\uB0D1\uB0D4\uB0D8\uB0E0\uB0E5\uB108\uB109\uB10B\uB10C\uB110\uB112\uB113\uB118\uB119\uB11B\uB11C\uB11D\uB123\uB124\uB125\uB128\uB12C\uB134\uB135\uB137\uB138\uB139\uB140\uB141\uB144\uB148\uB150\uB151\uB154\uB155\uB158\uB15C\uB160\uB178\uB179\uB17C\uB180\uB182\uB188\uB189\uB18B\uB18D\uB192\uB193\uB194\uB198\uB19C\uB1A8\uB1CC\uB1D0\uB1D4\uB1DC\uB1DD"],
      ["b441", "\uD02E", 5, "\uD036\uD037\uD039\uD03A\uD03B\uD03D", 6, "\uD046\uD048\uD04A", 5],
      ["b461", "\uD051\uD052\uD053\uD055\uD056\uD057\uD059", 6, "\uD061", 10, "\uD06E\uD06F"],
      ["b481", "\uD071\uD072\uD073\uD075", 6, "\uD07E\uD07F\uD080\uD082", 18, "\uB1DF\uB1E8\uB1E9\uB1EC\uB1F0\uB1F9\uB1FB\uB1FD\uB204\uB205\uB208\uB20B\uB20C\uB214\uB215\uB217\uB219\uB220\uB234\uB23C\uB258\uB25C\uB260\uB268\uB269\uB274\uB275\uB27C\uB284\uB285\uB289\uB290\uB291\uB294\uB298\uB299\uB29A\uB2A0\uB2A1\uB2A3\uB2A5\uB2A6\uB2AA\uB2AC\uB2B0\uB2B4\uB2C8\uB2C9\uB2CC\uB2D0\uB2D2\uB2D8\uB2D9\uB2DB\uB2DD\uB2E2\uB2E4\uB2E5\uB2E6\uB2E8\uB2EB", 4, "\uB2F3\uB2F4\uB2F5\uB2F7", 4, "\uB2FF\uB300\uB301\uB304\uB308\uB310\uB311\uB313\uB314\uB315\uB31C\uB354\uB355\uB356\uB358\uB35B\uB35C\uB35E\uB35F\uB364\uB365"],
      ["b541", "\uD095", 14, "\uD0A6\uD0A7\uD0A9\uD0AA\uD0AB\uD0AD", 5],
      ["b561", "\uD0B3\uD0B6\uD0B8\uD0BA", 5, "\uD0C2\uD0C3\uD0C5\uD0C6\uD0C7\uD0CA", 5, "\uD0D2\uD0D6", 4],
      ["b581", "\uD0DB\uD0DE\uD0DF\uD0E1\uD0E2\uD0E3\uD0E5", 6, "\uD0EE\uD0F2", 5, "\uD0F9", 11, "\uB367\uB369\uB36B\uB36E\uB370\uB371\uB374\uB378\uB380\uB381\uB383\uB384\uB385\uB38C\uB390\uB394\uB3A0\uB3A1\uB3A8\uB3AC\uB3C4\uB3C5\uB3C8\uB3CB\uB3CC\uB3CE\uB3D0\uB3D4\uB3D5\uB3D7\uB3D9\uB3DB\uB3DD\uB3E0\uB3E4\uB3E8\uB3FC\uB410\uB418\uB41C\uB420\uB428\uB429\uB42B\uB434\uB450\uB451\uB454\uB458\uB460\uB461\uB463\uB465\uB46C\uB480\uB488\uB49D\uB4A4\uB4A8\uB4AC\uB4B5\uB4B7\uB4B9\uB4C0\uB4C4\uB4C8\uB4D0\uB4D5\uB4DC\uB4DD\uB4E0\uB4E3\uB4E4\uB4E6\uB4EC\uB4ED\uB4EF\uB4F1\uB4F8\uB514\uB515\uB518\uB51B\uB51C\uB524\uB525\uB527\uB528\uB529\uB52A\uB530\uB531\uB534\uB538"],
      ["b641", "\uD105", 7, "\uD10E", 17],
      ["b661", "\uD120", 15, "\uD132\uD133\uD135\uD136\uD137\uD139\uD13B\uD13C\uD13D\uD13E"],
      ["b681", "\uD13F\uD142\uD146", 5, "\uD14E\uD14F\uD151\uD152\uD153\uD155", 6, "\uD15E\uD160\uD162", 5, "\uD169\uD16A\uD16B\uD16D\uB540\uB541\uB543\uB544\uB545\uB54B\uB54C\uB54D\uB550\uB554\uB55C\uB55D\uB55F\uB560\uB561\uB5A0\uB5A1\uB5A4\uB5A8\uB5AA\uB5AB\uB5B0\uB5B1\uB5B3\uB5B4\uB5B5\uB5BB\uB5BC\uB5BD\uB5C0\uB5C4\uB5CC\uB5CD\uB5CF\uB5D0\uB5D1\uB5D8\uB5EC\uB610\uB611\uB614\uB618\uB625\uB62C\uB634\uB648\uB664\uB668\uB69C\uB69D\uB6A0\uB6A4\uB6AB\uB6AC\uB6B1\uB6D4\uB6F0\uB6F4\uB6F8\uB700\uB701\uB705\uB728\uB729\uB72C\uB72F\uB730\uB738\uB739\uB73B\uB744\uB748\uB74C\uB754\uB755\uB760\uB764\uB768\uB770\uB771\uB773\uB775\uB77C\uB77D\uB780\uB784\uB78C\uB78D\uB78F\uB790\uB791\uB792\uB796\uB797"],
      ["b741", "\uD16E", 13, "\uD17D", 6, "\uD185\uD186\uD187\uD189\uD18A"],
      ["b761", "\uD18B", 20, "\uD1A2\uD1A3\uD1A5\uD1A6\uD1A7"],
      ["b781", "\uD1A9", 6, "\uD1B2\uD1B4\uD1B6\uD1B7\uD1B8\uD1B9\uD1BB\uD1BD\uD1BE\uD1BF\uD1C1", 14, "\uB798\uB799\uB79C\uB7A0\uB7A8\uB7A9\uB7AB\uB7AC\uB7AD\uB7B4\uB7B5\uB7B8\uB7C7\uB7C9\uB7EC\uB7ED\uB7F0\uB7F4\uB7FC\uB7FD\uB7FF\uB800\uB801\uB807\uB808\uB809\uB80C\uB810\uB818\uB819\uB81B\uB81D\uB824\uB825\uB828\uB82C\uB834\uB835\uB837\uB838\uB839\uB840\uB844\uB851\uB853\uB85C\uB85D\uB860\uB864\uB86C\uB86D\uB86F\uB871\uB878\uB87C\uB88D\uB8A8\uB8B0\uB8B4\uB8B8\uB8C0\uB8C1\uB8C3\uB8C5\uB8CC\uB8D0\uB8D4\uB8DD\uB8DF\uB8E1\uB8E8\uB8E9\uB8EC\uB8F0\uB8F8\uB8F9\uB8FB\uB8FD\uB904\uB918\uB920\uB93C\uB93D\uB940\uB944\uB94C\uB94F\uB951\uB958\uB959\uB95C\uB960\uB968\uB969"],
      ["b841", "\uD1D0", 7, "\uD1D9", 17],
      ["b861", "\uD1EB", 8, "\uD1F5\uD1F6\uD1F7\uD1F9", 13],
      ["b881", "\uD208\uD20A", 5, "\uD211", 24, "\uB96B\uB96D\uB974\uB975\uB978\uB97C\uB984\uB985\uB987\uB989\uB98A\uB98D\uB98E\uB9AC\uB9AD\uB9B0\uB9B4\uB9BC\uB9BD\uB9BF\uB9C1\uB9C8\uB9C9\uB9CC\uB9CE", 4, "\uB9D8\uB9D9\uB9DB\uB9DD\uB9DE\uB9E1\uB9E3\uB9E4\uB9E5\uB9E8\uB9EC\uB9F4\uB9F5\uB9F7\uB9F8\uB9F9\uB9FA\uBA00\uBA01\uBA08\uBA15\uBA38\uBA39\uBA3C\uBA40\uBA42\uBA48\uBA49\uBA4B\uBA4D\uBA4E\uBA53\uBA54\uBA55\uBA58\uBA5C\uBA64\uBA65\uBA67\uBA68\uBA69\uBA70\uBA71\uBA74\uBA78\uBA83\uBA84\uBA85\uBA87\uBA8C\uBAA8\uBAA9\uBAAB\uBAAC\uBAB0\uBAB2\uBAB8\uBAB9\uBABB\uBABD\uBAC4\uBAC8\uBAD8\uBAD9\uBAFC"],
      ["b941", "\uD22A\uD22B\uD22E\uD22F\uD231\uD232\uD233\uD235", 6, "\uD23E\uD240\uD242", 5, "\uD249\uD24A\uD24B\uD24C"],
      ["b961", "\uD24D", 14, "\uD25D", 6, "\uD265\uD266\uD267\uD268"],
      ["b981", "\uD269", 22, "\uD282\uD283\uD285\uD286\uD287\uD289\uD28A\uD28B\uD28C\uBB00\uBB04\uBB0D\uBB0F\uBB11\uBB18\uBB1C\uBB20\uBB29\uBB2B\uBB34\uBB35\uBB36\uBB38\uBB3B\uBB3C\uBB3D\uBB3E\uBB44\uBB45\uBB47\uBB49\uBB4D\uBB4F\uBB50\uBB54\uBB58\uBB61\uBB63\uBB6C\uBB88\uBB8C\uBB90\uBBA4\uBBA8\uBBAC\uBBB4\uBBB7\uBBC0\uBBC4\uBBC8\uBBD0\uBBD3\uBBF8\uBBF9\uBBFC\uBBFF\uBC00\uBC02\uBC08\uBC09\uBC0B\uBC0C\uBC0D\uBC0F\uBC11\uBC14", 4, "\uBC1B", 4, "\uBC24\uBC25\uBC27\uBC29\uBC2D\uBC30\uBC31\uBC34\uBC38\uBC40\uBC41\uBC43\uBC44\uBC45\uBC49\uBC4C\uBC4D\uBC50\uBC5D\uBC84\uBC85\uBC88\uBC8B\uBC8C\uBC8E\uBC94\uBC95\uBC97"],
      ["ba41", "\uD28D\uD28E\uD28F\uD292\uD293\uD294\uD296", 5, "\uD29D\uD29E\uD29F\uD2A1\uD2A2\uD2A3\uD2A5", 6, "\uD2AD"],
      ["ba61", "\uD2AE\uD2AF\uD2B0\uD2B2", 5, "\uD2BA\uD2BB\uD2BD\uD2BE\uD2C1\uD2C3", 4, "\uD2CA\uD2CC", 5],
      ["ba81", "\uD2D2\uD2D3\uD2D5\uD2D6\uD2D7\uD2D9\uD2DA\uD2DB\uD2DD", 6, "\uD2E6", 9, "\uD2F2\uD2F3\uD2F5\uD2F6\uD2F7\uD2F9\uD2FA\uBC99\uBC9A\uBCA0\uBCA1\uBCA4\uBCA7\uBCA8\uBCB0\uBCB1\uBCB3\uBCB4\uBCB5\uBCBC\uBCBD\uBCC0\uBCC4\uBCCD\uBCCF\uBCD0\uBCD1\uBCD5\uBCD8\uBCDC\uBCF4\uBCF5\uBCF6\uBCF8\uBCFC\uBD04\uBD05\uBD07\uBD09\uBD10\uBD14\uBD24\uBD2C\uBD40\uBD48\uBD49\uBD4C\uBD50\uBD58\uBD59\uBD64\uBD68\uBD80\uBD81\uBD84\uBD87\uBD88\uBD89\uBD8A\uBD90\uBD91\uBD93\uBD95\uBD99\uBD9A\uBD9C\uBDA4\uBDB0\uBDB8\uBDD4\uBDD5\uBDD8\uBDDC\uBDE9\uBDF0\uBDF4\uBDF8\uBE00\uBE03\uBE05\uBE0C\uBE0D\uBE10\uBE14\uBE1C\uBE1D\uBE1F\uBE44\uBE45\uBE48\uBE4C\uBE4E\uBE54\uBE55\uBE57\uBE59\uBE5A\uBE5B\uBE60\uBE61\uBE64"],
      ["bb41", "\uD2FB", 4, "\uD302\uD304\uD306", 5, "\uD30F\uD311\uD312\uD313\uD315\uD317", 4, "\uD31E\uD322\uD323"],
      ["bb61", "\uD324\uD326\uD327\uD32A\uD32B\uD32D\uD32E\uD32F\uD331", 6, "\uD33A\uD33E", 5, "\uD346\uD347\uD348\uD349"],
      ["bb81", "\uD34A", 31, "\uBE68\uBE6A\uBE70\uBE71\uBE73\uBE74\uBE75\uBE7B\uBE7C\uBE7D\uBE80\uBE84\uBE8C\uBE8D\uBE8F\uBE90\uBE91\uBE98\uBE99\uBEA8\uBED0\uBED1\uBED4\uBED7\uBED8\uBEE0\uBEE3\uBEE4\uBEE5\uBEEC\uBF01\uBF08\uBF09\uBF18\uBF19\uBF1B\uBF1C\uBF1D\uBF40\uBF41\uBF44\uBF48\uBF50\uBF51\uBF55\uBF94\uBFB0\uBFC5\uBFCC\uBFCD\uBFD0\uBFD4\uBFDC\uBFDF\uBFE1\uC03C\uC051\uC058\uC05C\uC060\uC068\uC069\uC090\uC091\uC094\uC098\uC0A0\uC0A1\uC0A3\uC0A5\uC0AC\uC0AD\uC0AF\uC0B0\uC0B3\uC0B4\uC0B5\uC0B6\uC0BC\uC0BD\uC0BF\uC0C0\uC0C1\uC0C5\uC0C8\uC0C9\uC0CC\uC0D0\uC0D8\uC0D9\uC0DB\uC0DC\uC0DD\uC0E4"],
      ["bc41", "\uD36A", 17, "\uD37E\uD37F\uD381\uD382\uD383\uD385\uD386\uD387"],
      ["bc61", "\uD388\uD389\uD38A\uD38B\uD38E\uD392", 5, "\uD39A\uD39B\uD39D\uD39E\uD39F\uD3A1", 6, "\uD3AA\uD3AC\uD3AE"],
      ["bc81", "\uD3AF", 4, "\uD3B5\uD3B6\uD3B7\uD3B9\uD3BA\uD3BB\uD3BD", 6, "\uD3C6\uD3C7\uD3CA", 5, "\uD3D1", 5, "\uC0E5\uC0E8\uC0EC\uC0F4\uC0F5\uC0F7\uC0F9\uC100\uC104\uC108\uC110\uC115\uC11C", 4, "\uC123\uC124\uC126\uC127\uC12C\uC12D\uC12F\uC130\uC131\uC136\uC138\uC139\uC13C\uC140\uC148\uC149\uC14B\uC14C\uC14D\uC154\uC155\uC158\uC15C\uC164\uC165\uC167\uC168\uC169\uC170\uC174\uC178\uC185\uC18C\uC18D\uC18E\uC190\uC194\uC196\uC19C\uC19D\uC19F\uC1A1\uC1A5\uC1A8\uC1A9\uC1AC\uC1B0\uC1BD\uC1C4\uC1C8\uC1CC\uC1D4\uC1D7\uC1D8\uC1E0\uC1E4\uC1E8\uC1F0\uC1F1\uC1F3\uC1FC\uC1FD\uC200\uC204\uC20C\uC20D\uC20F\uC211\uC218\uC219\uC21C\uC21F\uC220\uC228\uC229\uC22B\uC22D"],
      ["bd41", "\uD3D7\uD3D9", 7, "\uD3E2\uD3E4", 7, "\uD3EE\uD3EF\uD3F1\uD3F2\uD3F3\uD3F5\uD3F6\uD3F7"],
      ["bd61", "\uD3F8\uD3F9\uD3FA\uD3FB\uD3FE\uD400\uD402", 5, "\uD409", 13],
      ["bd81", "\uD417", 5, "\uD41E", 25, "\uC22F\uC231\uC232\uC234\uC248\uC250\uC251\uC254\uC258\uC260\uC265\uC26C\uC26D\uC270\uC274\uC27C\uC27D\uC27F\uC281\uC288\uC289\uC290\uC298\uC29B\uC29D\uC2A4\uC2A5\uC2A8\uC2AC\uC2AD\uC2B4\uC2B5\uC2B7\uC2B9\uC2DC\uC2DD\uC2E0\uC2E3\uC2E4\uC2EB\uC2EC\uC2ED\uC2EF\uC2F1\uC2F6\uC2F8\uC2F9\uC2FB\uC2FC\uC300\uC308\uC309\uC30C\uC30D\uC313\uC314\uC315\uC318\uC31C\uC324\uC325\uC328\uC329\uC345\uC368\uC369\uC36C\uC370\uC372\uC378\uC379\uC37C\uC37D\uC384\uC388\uC38C\uC3C0\uC3D8\uC3D9\uC3DC\uC3DF\uC3E0\uC3E2\uC3E8\uC3E9\uC3ED\uC3F4\uC3F5\uC3F8\uC408\uC410\uC424\uC42C\uC430"],
      ["be41", "\uD438", 7, "\uD441\uD442\uD443\uD445", 14],
      ["be61", "\uD454", 7, "\uD45D\uD45E\uD45F\uD461\uD462\uD463\uD465", 7, "\uD46E\uD470\uD471\uD472"],
      ["be81", "\uD473", 4, "\uD47A\uD47B\uD47D\uD47E\uD481\uD483", 4, "\uD48A\uD48C\uD48E", 5, "\uD495", 8, "\uC434\uC43C\uC43D\uC448\uC464\uC465\uC468\uC46C\uC474\uC475\uC479\uC480\uC494\uC49C\uC4B8\uC4BC\uC4E9\uC4F0\uC4F1\uC4F4\uC4F8\uC4FA\uC4FF\uC500\uC501\uC50C\uC510\uC514\uC51C\uC528\uC529\uC52C\uC530\uC538\uC539\uC53B\uC53D\uC544\uC545\uC548\uC549\uC54A\uC54C\uC54D\uC54E\uC553\uC554\uC555\uC557\uC558\uC559\uC55D\uC55E\uC560\uC561\uC564\uC568\uC570\uC571\uC573\uC574\uC575\uC57C\uC57D\uC580\uC584\uC587\uC58C\uC58D\uC58F\uC591\uC595\uC597\uC598\uC59C\uC5A0\uC5A9\uC5B4\uC5B5\uC5B8\uC5B9\uC5BB\uC5BC\uC5BD\uC5BE\uC5C4", 6, "\uC5CC\uC5CE"],
      ["bf41", "\uD49E", 10, "\uD4AA", 14],
      ["bf61", "\uD4B9", 18, "\uD4CD\uD4CE\uD4CF\uD4D1\uD4D2\uD4D3\uD4D5"],
      ["bf81", "\uD4D6", 5, "\uD4DD\uD4DE\uD4E0", 7, "\uD4E9\uD4EA\uD4EB\uD4ED\uD4EE\uD4EF\uD4F1", 6, "\uD4F9\uD4FA\uD4FC\uC5D0\uC5D1\uC5D4\uC5D8\uC5E0\uC5E1\uC5E3\uC5E5\uC5EC\uC5ED\uC5EE\uC5F0\uC5F4\uC5F6\uC5F7\uC5FC", 5, "\uC605\uC606\uC607\uC608\uC60C\uC610\uC618\uC619\uC61B\uC61C\uC624\uC625\uC628\uC62C\uC62D\uC62E\uC630\uC633\uC634\uC635\uC637\uC639\uC63B\uC640\uC641\uC644\uC648\uC650\uC651\uC653\uC654\uC655\uC65C\uC65D\uC660\uC66C\uC66F\uC671\uC678\uC679\uC67C\uC680\uC688\uC689\uC68B\uC68D\uC694\uC695\uC698\uC69C\uC6A4\uC6A5\uC6A7\uC6A9\uC6B0\uC6B1\uC6B4\uC6B8\uC6B9\uC6BA\uC6C0\uC6C1\uC6C3\uC6C5\uC6CC\uC6CD\uC6D0\uC6D4\uC6DC\uC6DD\uC6E0\uC6E1\uC6E8"],
      ["c041", "\uD4FE", 5, "\uD505\uD506\uD507\uD509\uD50A\uD50B\uD50D", 6, "\uD516\uD518", 5],
      ["c061", "\uD51E", 25],
      ["c081", "\uD538\uD539\uD53A\uD53B\uD53E\uD53F\uD541\uD542\uD543\uD545", 6, "\uD54E\uD550\uD552", 5, "\uD55A\uD55B\uD55D\uD55E\uD55F\uD561\uD562\uD563\uC6E9\uC6EC\uC6F0\uC6F8\uC6F9\uC6FD\uC704\uC705\uC708\uC70C\uC714\uC715\uC717\uC719\uC720\uC721\uC724\uC728\uC730\uC731\uC733\uC735\uC737\uC73C\uC73D\uC740\uC744\uC74A\uC74C\uC74D\uC74F\uC751", 7, "\uC75C\uC760\uC768\uC76B\uC774\uC775\uC778\uC77C\uC77D\uC77E\uC783\uC784\uC785\uC787\uC788\uC789\uC78A\uC78E\uC790\uC791\uC794\uC796\uC797\uC798\uC79A\uC7A0\uC7A1\uC7A3\uC7A4\uC7A5\uC7A6\uC7AC\uC7AD\uC7B0\uC7B4\uC7BC\uC7BD\uC7BF\uC7C0\uC7C1\uC7C8\uC7C9\uC7CC\uC7CE\uC7D0\uC7D8\uC7DD\uC7E4\uC7E8\uC7EC\uC800\uC801\uC804\uC808\uC80A"],
      ["c141", "\uD564\uD566\uD567\uD56A\uD56C\uD56E", 5, "\uD576\uD577\uD579\uD57A\uD57B\uD57D", 6, "\uD586\uD58A\uD58B"],
      ["c161", "\uD58C\uD58D\uD58E\uD58F\uD591", 19, "\uD5A6\uD5A7"],
      ["c181", "\uD5A8", 31, "\uC810\uC811\uC813\uC815\uC816\uC81C\uC81D\uC820\uC824\uC82C\uC82D\uC82F\uC831\uC838\uC83C\uC840\uC848\uC849\uC84C\uC84D\uC854\uC870\uC871\uC874\uC878\uC87A\uC880\uC881\uC883\uC885\uC886\uC887\uC88B\uC88C\uC88D\uC894\uC89D\uC89F\uC8A1\uC8A8\uC8BC\uC8BD\uC8C4\uC8C8\uC8CC\uC8D4\uC8D5\uC8D7\uC8D9\uC8E0\uC8E1\uC8E4\uC8F5\uC8FC\uC8FD\uC900\uC904\uC905\uC906\uC90C\uC90D\uC90F\uC911\uC918\uC92C\uC934\uC950\uC951\uC954\uC958\uC960\uC961\uC963\uC96C\uC970\uC974\uC97C\uC988\uC989\uC98C\uC990\uC998\uC999\uC99B\uC99D\uC9C0\uC9C1\uC9C4\uC9C7\uC9C8\uC9CA\uC9D0\uC9D1\uC9D3"],
      ["c241", "\uD5CA\uD5CB\uD5CD\uD5CE\uD5CF\uD5D1\uD5D3", 4, "\uD5DA\uD5DC\uD5DE", 5, "\uD5E6\uD5E7\uD5E9\uD5EA\uD5EB\uD5ED\uD5EE"],
      ["c261", "\uD5EF", 4, "\uD5F6\uD5F8\uD5FA", 5, "\uD602\uD603\uD605\uD606\uD607\uD609", 6, "\uD612"],
      ["c281", "\uD616", 5, "\uD61D\uD61E\uD61F\uD621\uD622\uD623\uD625", 7, "\uD62E", 9, "\uD63A\uD63B\uC9D5\uC9D6\uC9D9\uC9DA\uC9DC\uC9DD\uC9E0\uC9E2\uC9E4\uC9E7\uC9EC\uC9ED\uC9EF\uC9F0\uC9F1\uC9F8\uC9F9\uC9FC\uCA00\uCA08\uCA09\uCA0B\uCA0C\uCA0D\uCA14\uCA18\uCA29\uCA4C\uCA4D\uCA50\uCA54\uCA5C\uCA5D\uCA5F\uCA60\uCA61\uCA68\uCA7D\uCA84\uCA98\uCABC\uCABD\uCAC0\uCAC4\uCACC\uCACD\uCACF\uCAD1\uCAD3\uCAD8\uCAD9\uCAE0\uCAEC\uCAF4\uCB08\uCB10\uCB14\uCB18\uCB20\uCB21\uCB41\uCB48\uCB49\uCB4C\uCB50\uCB58\uCB59\uCB5D\uCB64\uCB78\uCB79\uCB9C\uCBB8\uCBD4\uCBE4\uCBE7\uCBE9\uCC0C\uCC0D\uCC10\uCC14\uCC1C\uCC1D\uCC21\uCC22\uCC27\uCC28\uCC29\uCC2C\uCC2E\uCC30\uCC38\uCC39\uCC3B"],
      ["c341", "\uD63D\uD63E\uD63F\uD641\uD642\uD643\uD644\uD646\uD647\uD64A\uD64C\uD64E\uD64F\uD650\uD652\uD653\uD656\uD657\uD659\uD65A\uD65B\uD65D", 4],
      ["c361", "\uD662", 4, "\uD668\uD66A", 5, "\uD672\uD673\uD675", 11],
      ["c381", "\uD681\uD682\uD684\uD686", 5, "\uD68E\uD68F\uD691\uD692\uD693\uD695", 7, "\uD69E\uD6A0\uD6A2", 5, "\uD6A9\uD6AA\uCC3C\uCC3D\uCC3E\uCC44\uCC45\uCC48\uCC4C\uCC54\uCC55\uCC57\uCC58\uCC59\uCC60\uCC64\uCC66\uCC68\uCC70\uCC75\uCC98\uCC99\uCC9C\uCCA0\uCCA8\uCCA9\uCCAB\uCCAC\uCCAD\uCCB4\uCCB5\uCCB8\uCCBC\uCCC4\uCCC5\uCCC7\uCCC9\uCCD0\uCCD4\uCCE4\uCCEC\uCCF0\uCD01\uCD08\uCD09\uCD0C\uCD10\uCD18\uCD19\uCD1B\uCD1D\uCD24\uCD28\uCD2C\uCD39\uCD5C\uCD60\uCD64\uCD6C\uCD6D\uCD6F\uCD71\uCD78\uCD88\uCD94\uCD95\uCD98\uCD9C\uCDA4\uCDA5\uCDA7\uCDA9\uCDB0\uCDC4\uCDCC\uCDD0\uCDE8\uCDEC\uCDF0\uCDF8\uCDF9\uCDFB\uCDFD\uCE04\uCE08\uCE0C\uCE14\uCE19\uCE20\uCE21\uCE24\uCE28\uCE30\uCE31\uCE33\uCE35"],
      ["c441", "\uD6AB\uD6AD\uD6AE\uD6AF\uD6B1", 7, "\uD6BA\uD6BC", 7, "\uD6C6\uD6C7\uD6C9\uD6CA\uD6CB"],
      ["c461", "\uD6CD\uD6CE\uD6CF\uD6D0\uD6D2\uD6D3\uD6D5\uD6D6\uD6D8\uD6DA", 5, "\uD6E1\uD6E2\uD6E3\uD6E5\uD6E6\uD6E7\uD6E9", 4],
      ["c481", "\uD6EE\uD6EF\uD6F1\uD6F2\uD6F3\uD6F4\uD6F6", 5, "\uD6FE\uD6FF\uD701\uD702\uD703\uD705", 11, "\uD712\uD713\uD714\uCE58\uCE59\uCE5C\uCE5F\uCE60\uCE61\uCE68\uCE69\uCE6B\uCE6D\uCE74\uCE75\uCE78\uCE7C\uCE84\uCE85\uCE87\uCE89\uCE90\uCE91\uCE94\uCE98\uCEA0\uCEA1\uCEA3\uCEA4\uCEA5\uCEAC\uCEAD\uCEC1\uCEE4\uCEE5\uCEE8\uCEEB\uCEEC\uCEF4\uCEF5\uCEF7\uCEF8\uCEF9\uCF00\uCF01\uCF04\uCF08\uCF10\uCF11\uCF13\uCF15\uCF1C\uCF20\uCF24\uCF2C\uCF2D\uCF2F\uCF30\uCF31\uCF38\uCF54\uCF55\uCF58\uCF5C\uCF64\uCF65\uCF67\uCF69\uCF70\uCF71\uCF74\uCF78\uCF80\uCF85\uCF8C\uCFA1\uCFA8\uCFB0\uCFC4\uCFE0\uCFE1\uCFE4\uCFE8\uCFF0\uCFF1\uCFF3\uCFF5\uCFFC\uD000\uD004\uD011\uD018\uD02D\uD034\uD035\uD038\uD03C"],
      ["c541", "\uD715\uD716\uD717\uD71A\uD71B\uD71D\uD71E\uD71F\uD721", 6, "\uD72A\uD72C\uD72E", 5, "\uD736\uD737\uD739"],
      ["c561", "\uD73A\uD73B\uD73D", 6, "\uD745\uD746\uD748\uD74A", 5, "\uD752\uD753\uD755\uD75A", 4],
      ["c581", "\uD75F\uD762\uD764\uD766\uD767\uD768\uD76A\uD76B\uD76D\uD76E\uD76F\uD771\uD772\uD773\uD775", 6, "\uD77E\uD77F\uD780\uD782", 5, "\uD78A\uD78B\uD044\uD045\uD047\uD049\uD050\uD054\uD058\uD060\uD06C\uD06D\uD070\uD074\uD07C\uD07D\uD081\uD0A4\uD0A5\uD0A8\uD0AC\uD0B4\uD0B5\uD0B7\uD0B9\uD0C0\uD0C1\uD0C4\uD0C8\uD0C9\uD0D0\uD0D1\uD0D3\uD0D4\uD0D5\uD0DC\uD0DD\uD0E0\uD0E4\uD0EC\uD0ED\uD0EF\uD0F0\uD0F1\uD0F8\uD10D\uD130\uD131\uD134\uD138\uD13A\uD140\uD141\uD143\uD144\uD145\uD14C\uD14D\uD150\uD154\uD15C\uD15D\uD15F\uD161\uD168\uD16C\uD17C\uD184\uD188\uD1A0\uD1A1\uD1A4\uD1A8\uD1B0\uD1B1\uD1B3\uD1B5\uD1BA\uD1BC\uD1C0\uD1D8\uD1F4\uD1F8\uD207\uD209\uD210\uD22C\uD22D\uD230\uD234\uD23C\uD23D\uD23F\uD241\uD248\uD25C"],
      ["c641", "\uD78D\uD78E\uD78F\uD791", 6, "\uD79A\uD79C\uD79E", 5],
      ["c6a1", "\uD264\uD280\uD281\uD284\uD288\uD290\uD291\uD295\uD29C\uD2A0\uD2A4\uD2AC\uD2B1\uD2B8\uD2B9\uD2BC\uD2BF\uD2C0\uD2C2\uD2C8\uD2C9\uD2CB\uD2D4\uD2D8\uD2DC\uD2E4\uD2E5\uD2F0\uD2F1\uD2F4\uD2F8\uD300\uD301\uD303\uD305\uD30C\uD30D\uD30E\uD310\uD314\uD316\uD31C\uD31D\uD31F\uD320\uD321\uD325\uD328\uD329\uD32C\uD330\uD338\uD339\uD33B\uD33C\uD33D\uD344\uD345\uD37C\uD37D\uD380\uD384\uD38C\uD38D\uD38F\uD390\uD391\uD398\uD399\uD39C\uD3A0\uD3A8\uD3A9\uD3AB\uD3AD\uD3B4\uD3B8\uD3BC\uD3C4\uD3C5\uD3C8\uD3C9\uD3D0\uD3D8\uD3E1\uD3E3\uD3EC\uD3ED\uD3F0\uD3F4\uD3FC\uD3FD\uD3FF\uD401"],
      ["c7a1", "\uD408\uD41D\uD440\uD444\uD45C\uD460\uD464\uD46D\uD46F\uD478\uD479\uD47C\uD47F\uD480\uD482\uD488\uD489\uD48B\uD48D\uD494\uD4A9\uD4CC\uD4D0\uD4D4\uD4DC\uD4DF\uD4E8\uD4EC\uD4F0\uD4F8\uD4FB\uD4FD\uD504\uD508\uD50C\uD514\uD515\uD517\uD53C\uD53D\uD540\uD544\uD54C\uD54D\uD54F\uD551\uD558\uD559\uD55C\uD560\uD565\uD568\uD569\uD56B\uD56D\uD574\uD575\uD578\uD57C\uD584\uD585\uD587\uD588\uD589\uD590\uD5A5\uD5C8\uD5C9\uD5CC\uD5D0\uD5D2\uD5D8\uD5D9\uD5DB\uD5DD\uD5E4\uD5E5\uD5E8\uD5EC\uD5F4\uD5F5\uD5F7\uD5F9\uD600\uD601\uD604\uD608\uD610\uD611\uD613\uD614\uD615\uD61C\uD620"],
      ["c8a1", "\uD624\uD62D\uD638\uD639\uD63C\uD640\uD645\uD648\uD649\uD64B\uD64D\uD651\uD654\uD655\uD658\uD65C\uD667\uD669\uD670\uD671\uD674\uD683\uD685\uD68C\uD68D\uD690\uD694\uD69D\uD69F\uD6A1\uD6A8\uD6AC\uD6B0\uD6B9\uD6BB\uD6C4\uD6C5\uD6C8\uD6CC\uD6D1\uD6D4\uD6D7\uD6D9\uD6E0\uD6E4\uD6E8\uD6F0\uD6F5\uD6FC\uD6FD\uD700\uD704\uD711\uD718\uD719\uD71C\uD720\uD728\uD729\uD72B\uD72D\uD734\uD735\uD738\uD73C\uD744\uD747\uD749\uD750\uD751\uD754\uD756\uD757\uD758\uD759\uD760\uD761\uD763\uD765\uD769\uD76C\uD770\uD774\uD77C\uD77D\uD781\uD788\uD789\uD78C\uD790\uD798\uD799\uD79B\uD79D"],
      ["caa1", "\u4F3D\u4F73\u5047\u50F9\u52A0\u53EF\u5475\u54E5\u5609\u5AC1\u5BB6\u6687\u67B6\u67B7\u67EF\u6B4C\u73C2\u75C2\u7A3C\u82DB\u8304\u8857\u8888\u8A36\u8CC8\u8DCF\u8EFB\u8FE6\u99D5\u523B\u5374\u5404\u606A\u6164\u6BBC\u73CF\u811A\u89BA\u89D2\u95A3\u4F83\u520A\u58BE\u5978\u59E6\u5E72\u5E79\u61C7\u63C0\u6746\u67EC\u687F\u6F97\u764E\u770B\u78F5\u7A08\u7AFF\u7C21\u809D\u826E\u8271\u8AEB\u9593\u4E6B\u559D\u66F7\u6E34\u78A3\u7AED\u845B\u8910\u874E\u97A8\u52D8\u574E\u582A\u5D4C\u611F\u61BE\u6221\u6562\u67D1\u6A44\u6E1B\u7518\u75B3\u76E3\u77B0\u7D3A\u90AF\u9451\u9452\u9F95"],
      ["cba1", "\u5323\u5CAC\u7532\u80DB\u9240\u9598\u525B\u5808\u59DC\u5CA1\u5D17\u5EB7\u5F3A\u5F4A\u6177\u6C5F\u757A\u7586\u7CE0\u7D73\u7DB1\u7F8C\u8154\u8221\u8591\u8941\u8B1B\u92FC\u964D\u9C47\u4ECB\u4EF7\u500B\u51F1\u584F\u6137\u613E\u6168\u6539\u69EA\u6F11\u75A5\u7686\u76D6\u7B87\u82A5\u84CB\uF900\u93A7\u958B\u5580\u5BA2\u5751\uF901\u7CB3\u7FB9\u91B5\u5028\u53BB\u5C45\u5DE8\u62D2\u636E\u64DA\u64E7\u6E20\u70AC\u795B\u8DDD\u8E1E\uF902\u907D\u9245\u92F8\u4E7E\u4EF6\u5065\u5DFE\u5EFA\u6106\u6957\u8171\u8654\u8E47\u9375\u9A2B\u4E5E\u5091\u6770\u6840\u5109\u528D\u5292\u6AA2"],
      ["cca1", "\u77BC\u9210\u9ED4\u52AB\u602F\u8FF2\u5048\u61A9\u63ED\u64CA\u683C\u6A84\u6FC0\u8188\u89A1\u9694\u5805\u727D\u72AC\u7504\u7D79\u7E6D\u80A9\u898B\u8B74\u9063\u9D51\u6289\u6C7A\u6F54\u7D50\u7F3A\u8A23\u517C\u614A\u7B9D\u8B19\u9257\u938C\u4EAC\u4FD3\u501E\u50BE\u5106\u52C1\u52CD\u537F\u5770\u5883\u5E9A\u5F91\u6176\u61AC\u64CE\u656C\u666F\u66BB\u66F4\u6897\u6D87\u7085\u70F1\u749F\u74A5\u74CA\u75D9\u786C\u78EC\u7ADF\u7AF6\u7D45\u7D93\u8015\u803F\u811B\u8396\u8B66\u8F15\u9015\u93E1\u9803\u9838\u9A5A\u9BE8\u4FC2\u5553\u583A\u5951\u5B63\u5C46\u60B8\u6212\u6842\u68B0"],
      ["cda1", "\u68E8\u6EAA\u754C\u7678\u78CE\u7A3D\u7CFB\u7E6B\u7E7C\u8A08\u8AA1\u8C3F\u968E\u9DC4\u53E4\u53E9\u544A\u5471\u56FA\u59D1\u5B64\u5C3B\u5EAB\u62F7\u6537\u6545\u6572\u66A0\u67AF\u69C1\u6CBD\u75FC\u7690\u777E\u7A3F\u7F94\u8003\u80A1\u818F\u82E6\u82FD\u83F0\u85C1\u8831\u88B4\u8AA5\uF903\u8F9C\u932E\u96C7\u9867\u9AD8\u9F13\u54ED\u659B\u66F2\u688F\u7A40\u8C37\u9D60\u56F0\u5764\u5D11\u6606\u68B1\u68CD\u6EFE\u7428\u889E\u9BE4\u6C68\uF904\u9AA8\u4F9B\u516C\u5171\u529F\u5B54\u5DE5\u6050\u606D\u62F1\u63A7\u653B\u73D9\u7A7A\u86A3\u8CA2\u978F\u4E32\u5BE1\u6208\u679C\u74DC"],
      ["cea1", "\u79D1\u83D3\u8A87\u8AB2\u8DE8\u904E\u934B\u9846\u5ED3\u69E8\u85FF\u90ED\uF905\u51A0\u5B98\u5BEC\u6163\u68FA\u6B3E\u704C\u742F\u74D8\u7BA1\u7F50\u83C5\u89C0\u8CAB\u95DC\u9928\u522E\u605D\u62EC\u9002\u4F8A\u5149\u5321\u58D9\u5EE3\u66E0\u6D38\u709A\u72C2\u73D6\u7B50\u80F1\u945B\u5366\u639B\u7F6B\u4E56\u5080\u584A\u58DE\u602A\u6127\u62D0\u69D0\u9B41\u5B8F\u7D18\u80B1\u8F5F\u4EA4\u50D1\u54AC\u55AC\u5B0C\u5DA0\u5DE7\u652A\u654E\u6821\u6A4B\u72E1\u768E\u77EF\u7D5E\u7FF9\u81A0\u854E\u86DF\u8F03\u8F4E\u90CA\u9903\u9A55\u9BAB\u4E18\u4E45\u4E5D\u4EC7\u4FF1\u5177\u52FE"],
      ["cfa1", "\u5340\u53E3\u53E5\u548E\u5614\u5775\u57A2\u5BC7\u5D87\u5ED0\u61FC\u62D8\u6551\u67B8\u67E9\u69CB\u6B50\u6BC6\u6BEC\u6C42\u6E9D\u7078\u72D7\u7396\u7403\u77BF\u77E9\u7A76\u7D7F\u8009\u81FC\u8205\u820A\u82DF\u8862\u8B33\u8CFC\u8EC0\u9011\u90B1\u9264\u92B6\u99D2\u9A45\u9CE9\u9DD7\u9F9C\u570B\u5C40\u83CA\u97A0\u97AB\u9EB4\u541B\u7A98\u7FA4\u88D9\u8ECD\u90E1\u5800\u5C48\u6398\u7A9F\u5BAE\u5F13\u7A79\u7AAE\u828E\u8EAC\u5026\u5238\u52F8\u5377\u5708\u62F3\u6372\u6B0A\u6DC3\u7737\u53A5\u7357\u8568\u8E76\u95D5\u673A\u6AC3\u6F70\u8A6D\u8ECC\u994B\uF906\u6677\u6B78\u8CB4"],
      ["d0a1", "\u9B3C\uF907\u53EB\u572D\u594E\u63C6\u69FB\u73EA\u7845\u7ABA\u7AC5\u7CFE\u8475\u898F\u8D73\u9035\u95A8\u52FB\u5747\u7547\u7B60\u83CC\u921E\uF908\u6A58\u514B\u524B\u5287\u621F\u68D8\u6975\u9699\u50C5\u52A4\u52E4\u61C3\u65A4\u6839\u69FF\u747E\u7B4B\u82B9\u83EB\u89B2\u8B39\u8FD1\u9949\uF909\u4ECA\u5997\u64D2\u6611\u6A8E\u7434\u7981\u79BD\u82A9\u887E\u887F\u895F\uF90A\u9326\u4F0B\u53CA\u6025\u6271\u6C72\u7D1A\u7D66\u4E98\u5162\u77DC\u80AF\u4F01\u4F0E\u5176\u5180\u55DC\u5668\u573B\u57FA\u57FC\u5914\u5947\u5993\u5BC4\u5C90\u5D0E\u5DF1\u5E7E\u5FCC\u6280\u65D7\u65E3"],
      ["d1a1", "\u671E\u671F\u675E\u68CB\u68C4\u6A5F\u6B3A\u6C23\u6C7D\u6C82\u6DC7\u7398\u7426\u742A\u7482\u74A3\u7578\u757F\u7881\u78EF\u7941\u7947\u7948\u797A\u7B95\u7D00\u7DBA\u7F88\u8006\u802D\u808C\u8A18\u8B4F\u8C48\u8D77\u9321\u9324\u98E2\u9951\u9A0E\u9A0F\u9A65\u9E92\u7DCA\u4F76\u5409\u62EE\u6854\u91D1\u55AB\u513A\uF90B\uF90C\u5A1C\u61E6\uF90D\u62CF\u62FF\uF90E", 5, "\u90A3\uF914", 4, "\u8AFE\uF919\uF91A\uF91B\uF91C\u6696\uF91D\u7156\uF91E\uF91F\u96E3\uF920\u634F\u637A\u5357\uF921\u678F\u6960\u6E73\uF922\u7537\uF923\uF924\uF925"],
      ["d2a1", "\u7D0D\uF926\uF927\u8872\u56CA\u5A18\uF928", 4, "\u4E43\uF92D\u5167\u5948\u67F0\u8010\uF92E\u5973\u5E74\u649A\u79CA\u5FF5\u606C\u62C8\u637B\u5BE7\u5BD7\u52AA\uF92F\u5974\u5F29\u6012\uF930\uF931\uF932\u7459\uF933", 5, "\u99D1\uF939", 10, "\u6FC3\uF944\uF945\u81BF\u8FB2\u60F1\uF946\uF947\u8166\uF948\uF949\u5C3F\uF94A", 7, "\u5AE9\u8A25\u677B\u7D10\uF952", 5, "\u80FD\uF958\uF959\u5C3C\u6CE5\u533F\u6EBA\u591A\u8336"],
      ["d3a1", "\u4E39\u4EB6\u4F46\u55AE\u5718\u58C7\u5F56\u65B7\u65E6\u6A80\u6BB5\u6E4D\u77ED\u7AEF\u7C1E\u7DDE\u86CB\u8892\u9132\u935B\u64BB\u6FBE\u737A\u75B8\u9054\u5556\u574D\u61BA\u64D4\u66C7\u6DE1\u6E5B\u6F6D\u6FB9\u75F0\u8043\u81BD\u8541\u8983\u8AC7\u8B5A\u931F\u6C93\u7553\u7B54\u8E0F\u905D\u5510\u5802\u5858\u5E62\u6207\u649E\u68E0\u7576\u7CD6\u87B3\u9EE8\u4EE3\u5788\u576E\u5927\u5C0D\u5CB1\u5E36\u5F85\u6234\u64E1\u73B3\u81FA\u888B\u8CB8\u968A\u9EDB\u5B85\u5FB7\u60B3\u5012\u5200\u5230\u5716\u5835\u5857\u5C0E\u5C60\u5CF6\u5D8B\u5EA6\u5F92\u60BC\u6311\u6389\u6417\u6843"],
      ["d4a1", "\u68F9\u6AC2\u6DD8\u6E21\u6ED4\u6FE4\u71FE\u76DC\u7779\u79B1\u7A3B\u8404\u89A9\u8CED\u8DF3\u8E48\u9003\u9014\u9053\u90FD\u934D\u9676\u97DC\u6BD2\u7006\u7258\u72A2\u7368\u7763\u79BF\u7BE4\u7E9B\u8B80\u58A9\u60C7\u6566\u65FD\u66BE\u6C8C\u711E\u71C9\u8C5A\u9813\u4E6D\u7A81\u4EDD\u51AC\u51CD\u52D5\u540C\u61A7\u6771\u6850\u68DF\u6D1E\u6F7C\u75BC\u77B3\u7AE5\u80F4\u8463\u9285\u515C\u6597\u675C\u6793\u75D8\u7AC7\u8373\uF95A\u8C46\u9017\u982D\u5C6F\u81C0\u829A\u9041\u906F\u920D\u5F97\u5D9D\u6A59\u71C8\u767B\u7B49\u85E4\u8B04\u9127\u9A30\u5587\u61F6\uF95B\u7669\u7F85"],
      ["d5a1", "\u863F\u87BA\u88F8\u908F\uF95C\u6D1B\u70D9\u73DE\u7D61\u843D\uF95D\u916A\u99F1\uF95E\u4E82\u5375\u6B04\u6B12\u703E\u721B\u862D\u9E1E\u524C\u8FA3\u5D50\u64E5\u652C\u6B16\u6FEB\u7C43\u7E9C\u85CD\u8964\u89BD\u62C9\u81D8\u881F\u5ECA\u6717\u6D6A\u72FC\u7405\u746F\u8782\u90DE\u4F86\u5D0D\u5FA0\u840A\u51B7\u63A0\u7565\u4EAE\u5006\u5169\u51C9\u6881\u6A11\u7CAE\u7CB1\u7CE7\u826F\u8AD2\u8F1B\u91CF\u4FB6\u5137\u52F5\u5442\u5EEC\u616E\u623E\u65C5\u6ADA\u6FFE\u792A\u85DC\u8823\u95AD\u9A62\u9A6A\u9E97\u9ECE\u529B\u66C6\u6B77\u701D\u792B\u8F62\u9742\u6190\u6200\u6523\u6F23"],
      ["d6a1", "\u7149\u7489\u7DF4\u806F\u84EE\u8F26\u9023\u934A\u51BD\u5217\u52A3\u6D0C\u70C8\u88C2\u5EC9\u6582\u6BAE\u6FC2\u7C3E\u7375\u4EE4\u4F36\u56F9\uF95F\u5CBA\u5DBA\u601C\u73B2\u7B2D\u7F9A\u7FCE\u8046\u901E\u9234\u96F6\u9748\u9818\u9F61\u4F8B\u6FA7\u79AE\u91B4\u96B7\u52DE\uF960\u6488\u64C4\u6AD3\u6F5E\u7018\u7210\u76E7\u8001\u8606\u865C\u8DEF\u8F05\u9732\u9B6F\u9DFA\u9E75\u788C\u797F\u7DA0\u83C9\u9304\u9E7F\u9E93\u8AD6\u58DF\u5F04\u6727\u7027\u74CF\u7C60\u807E\u5121\u7028\u7262\u78CA\u8CC2\u8CDA\u8CF4\u96F7\u4E86\u50DA\u5BEE\u5ED6\u6599\u71CE\u7642\u77AD\u804A\u84FC"],
      ["d7a1", "\u907C\u9B27\u9F8D\u58D8\u5A41\u5C62\u6A13\u6DDA\u6F0F\u763B\u7D2F\u7E37\u851E\u8938\u93E4\u964B\u5289\u65D2\u67F3\u69B4\u6D41\u6E9C\u700F\u7409\u7460\u7559\u7624\u786B\u8B2C\u985E\u516D\u622E\u9678\u4F96\u502B\u5D19\u6DEA\u7DB8\u8F2A\u5F8B\u6144\u6817\uF961\u9686\u52D2\u808B\u51DC\u51CC\u695E\u7A1C\u7DBE\u83F1\u9675\u4FDA\u5229\u5398\u540F\u550E\u5C65\u60A7\u674E\u68A8\u6D6C\u7281\u72F8\u7406\u7483\uF962\u75E2\u7C6C\u7F79\u7FB8\u8389\u88CF\u88E1\u91CC\u91D0\u96E2\u9BC9\u541D\u6F7E\u71D0\u7498\u85FA\u8EAA\u96A3\u9C57\u9E9F\u6797\u6DCB\u7433\u81E8\u9716\u782C"],
      ["d8a1", "\u7ACB\u7B20\u7C92\u6469\u746A\u75F2\u78BC\u78E8\u99AC\u9B54\u9EBB\u5BDE\u5E55\u6F20\u819C\u83AB\u9088\u4E07\u534D\u5A29\u5DD2\u5F4E\u6162\u633D\u6669\u66FC\u6EFF\u6F2B\u7063\u779E\u842C\u8513\u883B\u8F13\u9945\u9C3B\u551C\u62B9\u672B\u6CAB\u8309\u896A\u977A\u4EA1\u5984\u5FD8\u5FD9\u671B\u7DB2\u7F54\u8292\u832B\u83BD\u8F1E\u9099\u57CB\u59B9\u5A92\u5BD0\u6627\u679A\u6885\u6BCF\u7164\u7F75\u8CB7\u8CE3\u9081\u9B45\u8108\u8C8A\u964C\u9A40\u9EA5\u5B5F\u6C13\u731B\u76F2\u76DF\u840C\u51AA\u8993\u514D\u5195\u52C9\u68C9\u6C94\u7704\u7720\u7DBF\u7DEC\u9762\u9EB5\u6EC5"],
      ["d9a1", "\u8511\u51A5\u540D\u547D\u660E\u669D\u6927\u6E9F\u76BF\u7791\u8317\u84C2\u879F\u9169\u9298\u9CF4\u8882\u4FAE\u5192\u52DF\u59C6\u5E3D\u6155\u6478\u6479\u66AE\u67D0\u6A21\u6BCD\u6BDB\u725F\u7261\u7441\u7738\u77DB\u8017\u82BC\u8305\u8B00\u8B28\u8C8C\u6728\u6C90\u7267\u76EE\u7766\u7A46\u9DA9\u6B7F\u6C92\u5922\u6726\u8499\u536F\u5893\u5999\u5EDF\u63CF\u6634\u6773\u6E3A\u732B\u7AD7\u82D7\u9328\u52D9\u5DEB\u61AE\u61CB\u620A\u62C7\u64AB\u65E0\u6959\u6B66\u6BCB\u7121\u73F7\u755D\u7E46\u821E\u8302\u856A\u8AA3\u8CBF\u9727\u9D61\u58A8\u9ED8\u5011\u520E\u543B\u554F\u6587"],
      ["daa1", "\u6C76\u7D0A\u7D0B\u805E\u868A\u9580\u96EF\u52FF\u6C95\u7269\u5473\u5A9A\u5C3E\u5D4B\u5F4C\u5FAE\u672A\u68B6\u6963\u6E3C\u6E44\u7709\u7C73\u7F8E\u8587\u8B0E\u8FF7\u9761\u9EF4\u5CB7\u60B6\u610D\u61AB\u654F\u65FB\u65FC\u6C11\u6CEF\u739F\u73C9\u7DE1\u9594\u5BC6\u871C\u8B10\u525D\u535A\u62CD\u640F\u64B2\u6734\u6A38\u6CCA\u73C0\u749E\u7B94\u7C95\u7E1B\u818A\u8236\u8584\u8FEB\u96F9\u99C1\u4F34\u534A\u53CD\u53DB\u62CC\u642C\u6500\u6591\u69C3\u6CEE\u6F58\u73ED\u7554\u7622\u76E4\u76FC\u78D0\u78FB\u792C\u7D46\u822C\u87E0\u8FD4\u9812\u98EF\u52C3\u62D4\u64A5\u6E24\u6F51"],
      ["dba1", "\u767C\u8DCB\u91B1\u9262\u9AEE\u9B43\u5023\u508D\u574A\u59A8\u5C28\u5E47\u5F77\u623F\u653E\u65B9\u65C1\u6609\u678B\u699C\u6EC2\u78C5\u7D21\u80AA\u8180\u822B\u82B3\u84A1\u868C\u8A2A\u8B17\u90A6\u9632\u9F90\u500D\u4FF3\uF963\u57F9\u5F98\u62DC\u6392\u676F\u6E43\u7119\u76C3\u80CC\u80DA\u88F4\u88F5\u8919\u8CE0\u8F29\u914D\u966A\u4F2F\u4F70\u5E1B\u67CF\u6822\u767D\u767E\u9B44\u5E61\u6A0A\u7169\u71D4\u756A\uF964\u7E41\u8543\u85E9\u98DC\u4F10\u7B4F\u7F70\u95A5\u51E1\u5E06\u68B5\u6C3E\u6C4E\u6CDB\u72AF\u7BC4\u8303\u6CD5\u743A\u50FB\u5288\u58C1\u64D8\u6A97\u74A7\u7656"],
      ["dca1", "\u78A7\u8617\u95E2\u9739\uF965\u535E\u5F01\u8B8A\u8FA8\u8FAF\u908A\u5225\u77A5\u9C49\u9F08\u4E19\u5002\u5175\u5C5B\u5E77\u661E\u663A\u67C4\u68C5\u70B3\u7501\u75C5\u79C9\u7ADD\u8F27\u9920\u9A08\u4FDD\u5821\u5831\u5BF6\u666E\u6B65\u6D11\u6E7A\u6F7D\u73E4\u752B\u83E9\u88DC\u8913\u8B5C\u8F14\u4F0F\u50D5\u5310\u535C\u5B93\u5FA9\u670D\u798F\u8179\u832F\u8514\u8907\u8986\u8F39\u8F3B\u99A5\u9C12\u672C\u4E76\u4FF8\u5949\u5C01\u5CEF\u5CF0\u6367\u68D2\u70FD\u71A2\u742B\u7E2B\u84EC\u8702\u9022\u92D2\u9CF3\u4E0D\u4ED8\u4FEF\u5085\u5256\u526F\u5426\u5490\u57E0\u592B\u5A66"],
      ["dda1", "\u5B5A\u5B75\u5BCC\u5E9C\uF966\u6276\u6577\u65A7\u6D6E\u6EA5\u7236\u7B26\u7C3F\u7F36\u8150\u8151\u819A\u8240\u8299\u83A9\u8A03\u8CA0\u8CE6\u8CFB\u8D74\u8DBA\u90E8\u91DC\u961C\u9644\u99D9\u9CE7\u5317\u5206\u5429\u5674\u58B3\u5954\u596E\u5FFF\u61A4\u626E\u6610\u6C7E\u711A\u76C6\u7C89\u7CDE\u7D1B\u82AC\u8CC1\u96F0\uF967\u4F5B\u5F17\u5F7F\u62C2\u5D29\u670B\u68DA\u787C\u7E43\u9D6C\u4E15\u5099\u5315\u532A\u5351\u5983\u5A62\u5E87\u60B2\u618A\u6249\u6279\u6590\u6787\u69A7\u6BD4\u6BD6\u6BD7\u6BD8\u6CB8\uF968\u7435\u75FA\u7812\u7891\u79D5\u79D8\u7C83\u7DCB\u7FE1\u80A5"],
      ["dea1", "\u813E\u81C2\u83F2\u871A\u88E8\u8AB9\u8B6C\u8CBB\u9119\u975E\u98DB\u9F3B\u56AC\u5B2A\u5F6C\u658C\u6AB3\u6BAF\u6D5C\u6FF1\u7015\u725D\u73AD\u8CA7\u8CD3\u983B\u6191\u6C37\u8058\u9A01\u4E4D\u4E8B\u4E9B\u4ED5\u4F3A\u4F3C\u4F7F\u4FDF\u50FF\u53F2\u53F8\u5506\u55E3\u56DB\u58EB\u5962\u5A11\u5BEB\u5BFA\u5C04\u5DF3\u5E2B\u5F99\u601D\u6368\u659C\u65AF\u67F6\u67FB\u68AD\u6B7B\u6C99\u6CD7\u6E23\u7009\u7345\u7802\u793E\u7940\u7960\u79C1\u7BE9\u7D17\u7D72\u8086\u820D\u838E\u84D1\u86C7\u88DF\u8A50\u8A5E\u8B1D\u8CDC\u8D66\u8FAD\u90AA\u98FC\u99DF\u9E9D\u524A\uF969\u6714\uF96A"],
      ["dfa1", "\u5098\u522A\u5C71\u6563\u6C55\u73CA\u7523\u759D\u7B97\u849C\u9178\u9730\u4E77\u6492\u6BBA\u715E\u85A9\u4E09\uF96B\u6749\u68EE\u6E17\u829F\u8518\u886B\u63F7\u6F81\u9212\u98AF\u4E0A\u50B7\u50CF\u511F\u5546\u55AA\u5617\u5B40\u5C19\u5CE0\u5E38\u5E8A\u5EA0\u5EC2\u60F3\u6851\u6A61\u6E58\u723D\u7240\u72C0\u76F8\u7965\u7BB1\u7FD4\u88F3\u89F4\u8A73\u8C61\u8CDE\u971C\u585E\u74BD\u8CFD\u55C7\uF96C\u7A61\u7D22\u8272\u7272\u751F\u7525\uF96D\u7B19\u5885\u58FB\u5DBC\u5E8F\u5EB6\u5F90\u6055\u6292\u637F\u654D\u6691\u66D9\u66F8\u6816\u68F2\u7280\u745E\u7B6E\u7D6E\u7DD6\u7F72"],
      ["e0a1", "\u80E5\u8212\u85AF\u897F\u8A93\u901D\u92E4\u9ECD\u9F20\u5915\u596D\u5E2D\u60DC\u6614\u6673\u6790\u6C50\u6DC5\u6F5F\u77F3\u78A9\u84C6\u91CB\u932B\u4ED9\u50CA\u5148\u5584\u5B0B\u5BA3\u6247\u657E\u65CB\u6E32\u717D\u7401\u7444\u7487\u74BF\u766C\u79AA\u7DDA\u7E55\u7FA8\u817A\u81B3\u8239\u861A\u87EC\u8A75\u8DE3\u9078\u9291\u9425\u994D\u9BAE\u5368\u5C51\u6954\u6CC4\u6D29\u6E2B\u820C\u859B\u893B\u8A2D\u8AAA\u96EA\u9F67\u5261\u66B9\u6BB2\u7E96\u87FE\u8D0D\u9583\u965D\u651D\u6D89\u71EE\uF96E\u57CE\u59D3\u5BAC\u6027\u60FA\u6210\u661F\u665F\u7329\u73F9\u76DB\u7701\u7B6C"],
      ["e1a1", "\u8056\u8072\u8165\u8AA0\u9192\u4E16\u52E2\u6B72\u6D17\u7A05\u7B39\u7D30\uF96F\u8CB0\u53EC\u562F\u5851\u5BB5\u5C0F\u5C11\u5DE2\u6240\u6383\u6414\u662D\u68B3\u6CBC\u6D88\u6EAF\u701F\u70A4\u71D2\u7526\u758F\u758E\u7619\u7B11\u7BE0\u7C2B\u7D20\u7D39\u852C\u856D\u8607\u8A34\u900D\u9061\u90B5\u92B7\u97F6\u9A37\u4FD7\u5C6C\u675F\u6D91\u7C9F\u7E8C\u8B16\u8D16\u901F\u5B6B\u5DFD\u640D\u84C0\u905C\u98E1\u7387\u5B8B\u609A\u677E\u6DDE\u8A1F\u8AA6\u9001\u980C\u5237\uF970\u7051\u788E\u9396\u8870\u91D7\u4FEE\u53D7\u55FD\u56DA\u5782\u58FD\u5AC2\u5B88\u5CAB\u5CC0\u5E25\u6101"],
      ["e2a1", "\u620D\u624B\u6388\u641C\u6536\u6578\u6A39\u6B8A\u6C34\u6D19\u6F31\u71E7\u72E9\u7378\u7407\u74B2\u7626\u7761\u79C0\u7A57\u7AEA\u7CB9\u7D8F\u7DAC\u7E61\u7F9E\u8129\u8331\u8490\u84DA\u85EA\u8896\u8AB0\u8B90\u8F38\u9042\u9083\u916C\u9296\u92B9\u968B\u96A7\u96A8\u96D6\u9700\u9808\u9996\u9AD3\u9B1A\u53D4\u587E\u5919\u5B70\u5BBF\u6DD1\u6F5A\u719F\u7421\u74B9\u8085\u83FD\u5DE1\u5F87\u5FAA\u6042\u65EC\u6812\u696F\u6A53\u6B89\u6D35\u6DF3\u73E3\u76FE\u77AC\u7B4D\u7D14\u8123\u821C\u8340\u84F4\u8563\u8A62\u8AC4\u9187\u931E\u9806\u99B4\u620C\u8853\u8FF0\u9265\u5D07\u5D27"],
      ["e3a1", "\u5D69\u745F\u819D\u8768\u6FD5\u62FE\u7FD2\u8936\u8972\u4E1E\u4E58\u50E7\u52DD\u5347\u627F\u6607\u7E69\u8805\u965E\u4F8D\u5319\u5636\u59CB\u5AA4\u5C38\u5C4E\u5C4D\u5E02\u5F11\u6043\u65BD\u662F\u6642\u67BE\u67F4\u731C\u77E2\u793A\u7FC5\u8494\u84CD\u8996\u8A66\u8A69\u8AE1\u8C55\u8C7A\u57F4\u5BD4\u5F0F\u606F\u62ED\u690D\u6B96\u6E5C\u7184\u7BD2\u8755\u8B58\u8EFE\u98DF\u98FE\u4F38\u4F81\u4FE1\u547B\u5A20\u5BB8\u613C\u65B0\u6668\u71FC\u7533\u795E\u7D33\u814E\u81E3\u8398\u85AA\u85CE\u8703\u8A0A\u8EAB\u8F9B\uF971\u8FC5\u5931\u5BA4\u5BE6\u6089\u5BE9\u5C0B\u5FC3\u6C81"],
      ["e4a1", "\uF972\u6DF1\u700B\u751A\u82AF\u8AF6\u4EC0\u5341\uF973\u96D9\u6C0F\u4E9E\u4FC4\u5152\u555E\u5A25\u5CE8\u6211\u7259\u82BD\u83AA\u86FE\u8859\u8A1D\u963F\u96C5\u9913\u9D09\u9D5D\u580A\u5CB3\u5DBD\u5E44\u60E1\u6115\u63E1\u6A02\u6E25\u9102\u9354\u984E\u9C10\u9F77\u5B89\u5CB8\u6309\u664F\u6848\u773C\u96C1\u978D\u9854\u9B9F\u65A1\u8B01\u8ECB\u95BC\u5535\u5CA9\u5DD6\u5EB5\u6697\u764C\u83F4\u95C7\u58D3\u62BC\u72CE\u9D28\u4EF0\u592E\u600F\u663B\u6B83\u79E7\u9D26\u5393\u54C0\u57C3\u5D16\u611B\u66D6\u6DAF\u788D\u827E\u9698\u9744\u5384\u627C\u6396\u6DB2\u7E0A\u814B\u984D"],
      ["e5a1", "\u6AFB\u7F4C\u9DAF\u9E1A\u4E5F\u503B\u51B6\u591C\u60F9\u63F6\u6930\u723A\u8036\uF974\u91CE\u5F31\uF975\uF976\u7D04\u82E5\u846F\u84BB\u85E5\u8E8D\uF977\u4F6F\uF978\uF979\u58E4\u5B43\u6059\u63DA\u6518\u656D\u6698\uF97A\u694A\u6A23\u6D0B\u7001\u716C\u75D2\u760D\u79B3\u7A70\uF97B\u7F8A\uF97C\u8944\uF97D\u8B93\u91C0\u967D\uF97E\u990A\u5704\u5FA1\u65BC\u6F01\u7600\u79A6\u8A9E\u99AD\u9B5A\u9F6C\u5104\u61B6\u6291\u6A8D\u81C6\u5043\u5830\u5F66\u7109\u8A00\u8AFA\u5B7C\u8616\u4FFA\u513C\u56B4\u5944\u63A9\u6DF9\u5DAA\u696D\u5186\u4E88\u4F59\uF97F\uF980\uF981\u5982\uF982"],
      ["e6a1", "\uF983\u6B5F\u6C5D\uF984\u74B5\u7916\uF985\u8207\u8245\u8339\u8F3F\u8F5D\uF986\u9918\uF987\uF988\uF989\u4EA6\uF98A\u57DF\u5F79\u6613\uF98B\uF98C\u75AB\u7E79\u8B6F\uF98D\u9006\u9A5B\u56A5\u5827\u59F8\u5A1F\u5BB4\uF98E\u5EF6\uF98F\uF990\u6350\u633B\uF991\u693D\u6C87\u6CBF\u6D8E\u6D93\u6DF5\u6F14\uF992\u70DF\u7136\u7159\uF993\u71C3\u71D5\uF994\u784F\u786F\uF995\u7B75\u7DE3\uF996\u7E2F\uF997\u884D\u8EDF\uF998\uF999\uF99A\u925B\uF99B\u9CF6\uF99C\uF99D\uF99E\u6085\u6D85\uF99F\u71B1\uF9A0\uF9A1\u95B1\u53AD\uF9A2\uF9A3\uF9A4\u67D3\uF9A5\u708E\u7130\u7430\u8276\u82D2"],
      ["e7a1", "\uF9A6\u95BB\u9AE5\u9E7D\u66C4\uF9A7\u71C1\u8449\uF9A8\uF9A9\u584B\uF9AA\uF9AB\u5DB8\u5F71\uF9AC\u6620\u668E\u6979\u69AE\u6C38\u6CF3\u6E36\u6F41\u6FDA\u701B\u702F\u7150\u71DF\u7370\uF9AD\u745B\uF9AE\u74D4\u76C8\u7A4E\u7E93\uF9AF\uF9B0\u82F1\u8A60\u8FCE\uF9B1\u9348\uF9B2\u9719\uF9B3\uF9B4\u4E42\u502A\uF9B5\u5208\u53E1\u66F3\u6C6D\u6FCA\u730A\u777F\u7A62\u82AE\u85DD\u8602\uF9B6\u88D4\u8A63\u8B7D\u8C6B\uF9B7\u92B3\uF9B8\u9713\u9810\u4E94\u4F0D\u4FC9\u50B2\u5348\u543E\u5433\u55DA\u5862\u58BA\u5967\u5A1B\u5BE4\u609F\uF9B9\u61CA\u6556\u65FF\u6664\u68A7\u6C5A\u6FB3"],
      ["e8a1", "\u70CF\u71AC\u7352\u7B7D\u8708\u8AA4\u9C32\u9F07\u5C4B\u6C83\u7344\u7389\u923A\u6EAB\u7465\u761F\u7A69\u7E15\u860A\u5140\u58C5\u64C1\u74EE\u7515\u7670\u7FC1\u9095\u96CD\u9954\u6E26\u74E6\u7AA9\u7AAA\u81E5\u86D9\u8778\u8A1B\u5A49\u5B8C\u5B9B\u68A1\u6900\u6D63\u73A9\u7413\u742C\u7897\u7DE9\u7FEB\u8118\u8155\u839E\u8C4C\u962E\u9811\u66F0\u5F80\u65FA\u6789\u6C6A\u738B\u502D\u5A03\u6B6A\u77EE\u5916\u5D6C\u5DCD\u7325\u754F\uF9BA\uF9BB\u50E5\u51F9\u582F\u592D\u5996\u59DA\u5BE5\uF9BC\uF9BD\u5DA2\u62D7\u6416\u6493\u64FE\uF9BE\u66DC\uF9BF\u6A48\uF9C0\u71FF\u7464\uF9C1"],
      ["e9a1", "\u7A88\u7AAF\u7E47\u7E5E\u8000\u8170\uF9C2\u87EF\u8981\u8B20\u9059\uF9C3\u9080\u9952\u617E\u6B32\u6D74\u7E1F\u8925\u8FB1\u4FD1\u50AD\u5197\u52C7\u57C7\u5889\u5BB9\u5EB8\u6142\u6995\u6D8C\u6E67\u6EB6\u7194\u7462\u7528\u752C\u8073\u8338\u84C9\u8E0A\u9394\u93DE\uF9C4\u4E8E\u4F51\u5076\u512A\u53C8\u53CB\u53F3\u5B87\u5BD3\u5C24\u611A\u6182\u65F4\u725B\u7397\u7440\u76C2\u7950\u7991\u79B9\u7D06\u7FBD\u828B\u85D5\u865E\u8FC2\u9047\u90F5\u91EA\u9685\u96E8\u96E9\u52D6\u5F67\u65ED\u6631\u682F\u715C\u7A36\u90C1\u980A\u4E91\uF9C5\u6A52\u6B9E\u6F90\u7189\u8018\u82B8\u8553"],
      ["eaa1", "\u904B\u9695\u96F2\u97FB\u851A\u9B31\u4E90\u718A\u96C4\u5143\u539F\u54E1\u5713\u5712\u57A3\u5A9B\u5AC4\u5BC3\u6028\u613F\u63F4\u6C85\u6D39\u6E72\u6E90\u7230\u733F\u7457\u82D1\u8881\u8F45\u9060\uF9C6\u9662\u9858\u9D1B\u6708\u8D8A\u925E\u4F4D\u5049\u50DE\u5371\u570D\u59D4\u5A01\u5C09\u6170\u6690\u6E2D\u7232\u744B\u7DEF\u80C3\u840E\u8466\u853F\u875F\u885B\u8918\u8B02\u9055\u97CB\u9B4F\u4E73\u4F91\u5112\u516A\uF9C7\u552F\u55A9\u5B7A\u5BA5\u5E7C\u5E7D\u5EBE\u60A0\u60DF\u6108\u6109\u63C4\u6538\u6709\uF9C8\u67D4\u67DA\uF9C9\u6961\u6962\u6CB9\u6D27\uF9CA\u6E38\uF9CB"],
      ["eba1", "\u6FE1\u7336\u7337\uF9CC\u745C\u7531\uF9CD\u7652\uF9CE\uF9CF\u7DAD\u81FE\u8438\u88D5\u8A98\u8ADB\u8AED\u8E30\u8E42\u904A\u903E\u907A\u9149\u91C9\u936E\uF9D0\uF9D1\u5809\uF9D2\u6BD3\u8089\u80B2\uF9D3\uF9D4\u5141\u596B\u5C39\uF9D5\uF9D6\u6F64\u73A7\u80E4\u8D07\uF9D7\u9217\u958F\uF9D8\uF9D9\uF9DA\uF9DB\u807F\u620E\u701C\u7D68\u878D\uF9DC\u57A0\u6069\u6147\u6BB7\u8ABE\u9280\u96B1\u4E59\u541F\u6DEB\u852D\u9670\u97F3\u98EE\u63D6\u6CE3\u9091\u51DD\u61C9\u81BA\u9DF9\u4F9D\u501A\u5100\u5B9C\u610F\u61FF\u64EC\u6905\u6BC5\u7591\u77E3\u7FA9\u8264\u858F\u87FB\u8863\u8ABC"],
      ["eca1", "\u8B70\u91AB\u4E8C\u4EE5\u4F0A\uF9DD\uF9DE\u5937\u59E8\uF9DF\u5DF2\u5F1B\u5F5B\u6021\uF9E0\uF9E1\uF9E2\uF9E3\u723E\u73E5\uF9E4\u7570\u75CD\uF9E5\u79FB\uF9E6\u800C\u8033\u8084\u82E1\u8351\uF9E7\uF9E8\u8CBD\u8CB3\u9087\uF9E9\uF9EA\u98F4\u990C\uF9EB\uF9EC\u7037\u76CA\u7FCA\u7FCC\u7FFC\u8B1A\u4EBA\u4EC1\u5203\u5370\uF9ED\u54BD\u56E0\u59FB\u5BC5\u5F15\u5FCD\u6E6E\uF9EE\uF9EF\u7D6A\u8335\uF9F0\u8693\u8A8D\uF9F1\u976D\u9777\uF9F2\uF9F3\u4E00\u4F5A\u4F7E\u58F9\u65E5\u6EA2\u9038\u93B0\u99B9\u4EFB\u58EC\u598A\u59D9\u6041\uF9F4\uF9F5\u7A14\uF9F6\u834F\u8CC3\u5165\u5344"],
      ["eda1", "\uF9F7\uF9F8\uF9F9\u4ECD\u5269\u5B55\u82BF\u4ED4\u523A\u54A8\u59C9\u59FF\u5B50\u5B57\u5B5C\u6063\u6148\u6ECB\u7099\u716E\u7386\u74F7\u75B5\u78C1\u7D2B\u8005\u81EA\u8328\u8517\u85C9\u8AEE\u8CC7\u96CC\u4F5C\u52FA\u56BC\u65AB\u6628\u707C\u70B8\u7235\u7DBD\u828D\u914C\u96C0\u9D72\u5B71\u68E7\u6B98\u6F7A\u76DE\u5C91\u66AB\u6F5B\u7BB4\u7C2A\u8836\u96DC\u4E08\u4ED7\u5320\u5834\u58BB\u58EF\u596C\u5C07\u5E33\u5E84\u5F35\u638C\u66B2\u6756\u6A1F\u6AA3\u6B0C\u6F3F\u7246\uF9FA\u7350\u748B\u7AE0\u7CA7\u8178\u81DF\u81E7\u838A\u846C\u8523\u8594\u85CF\u88DD\u8D13\u91AC\u9577"],
      ["eea1", "\u969C\u518D\u54C9\u5728\u5BB0\u624D\u6750\u683D\u6893\u6E3D\u6ED3\u707D\u7E21\u88C1\u8CA1\u8F09\u9F4B\u9F4E\u722D\u7B8F\u8ACD\u931A\u4F47\u4F4E\u5132\u5480\u59D0\u5E95\u62B5\u6775\u696E\u6A17\u6CAE\u6E1A\u72D9\u732A\u75BD\u7BB8\u7D35\u82E7\u83F9\u8457\u85F7\u8A5B\u8CAF\u8E87\u9019\u90B8\u96CE\u9F5F\u52E3\u540A\u5AE1\u5BC2\u6458\u6575\u6EF4\u72C4\uF9FB\u7684\u7A4D\u7B1B\u7C4D\u7E3E\u7FDF\u837B\u8B2B\u8CCA\u8D64\u8DE1\u8E5F\u8FEA\u8FF9\u9069\u93D1\u4F43\u4F7A\u50B3\u5168\u5178\u524D\u526A\u5861\u587C\u5960\u5C08\u5C55\u5EDB\u609B\u6230\u6813\u6BBF\u6C08\u6FB1"],
      ["efa1", "\u714E\u7420\u7530\u7538\u7551\u7672\u7B4C\u7B8B\u7BAD\u7BC6\u7E8F\u8A6E\u8F3E\u8F49\u923F\u9293\u9322\u942B\u96FB\u985A\u986B\u991E\u5207\u622A\u6298\u6D59\u7664\u7ACA\u7BC0\u7D76\u5360\u5CBE\u5E97\u6F38\u70B9\u7C98\u9711\u9B8E\u9EDE\u63A5\u647A\u8776\u4E01\u4E95\u4EAD\u505C\u5075\u5448\u59C3\u5B9A\u5E40\u5EAD\u5EF7\u5F81\u60C5\u633A\u653F\u6574\u65CC\u6676\u6678\u67FE\u6968\u6A89\u6B63\u6C40\u6DC0\u6DE8\u6E1F\u6E5E\u701E\u70A1\u738E\u73FD\u753A\u775B\u7887\u798E\u7A0B\u7A7D\u7CBE\u7D8E\u8247\u8A02\u8AEA\u8C9E\u912D\u914A\u91D8\u9266\u92CC\u9320\u9706\u9756"],
      ["f0a1", "\u975C\u9802\u9F0E\u5236\u5291\u557C\u5824\u5E1D\u5F1F\u608C\u63D0\u68AF\u6FDF\u796D\u7B2C\u81CD\u85BA\u88FD\u8AF8\u8E44\u918D\u9664\u969B\u973D\u984C\u9F4A\u4FCE\u5146\u51CB\u52A9\u5632\u5F14\u5F6B\u63AA\u64CD\u65E9\u6641\u66FA\u66F9\u671D\u689D\u68D7\u69FD\u6F15\u6F6E\u7167\u71E5\u722A\u74AA\u773A\u7956\u795A\u79DF\u7A20\u7A95\u7C97\u7CDF\u7D44\u7E70\u8087\u85FB\u86A4\u8A54\u8ABF\u8D99\u8E81\u9020\u906D\u91E3\u963B\u96D5\u9CE5\u65CF\u7C07\u8DB3\u93C3\u5B58\u5C0A\u5352\u62D9\u731D\u5027\u5B97\u5F9E\u60B0\u616B\u68D5\u6DD9\u742E\u7A2E\u7D42\u7D9C\u7E31\u816B"],
      ["f1a1", "\u8E2A\u8E35\u937E\u9418\u4F50\u5750\u5DE6\u5EA7\u632B\u7F6A\u4E3B\u4F4F\u4F8F\u505A\u59DD\u80C4\u546A\u5468\u55FE\u594F\u5B99\u5DDE\u5EDA\u665D\u6731\u67F1\u682A\u6CE8\u6D32\u6E4A\u6F8D\u70B7\u73E0\u7587\u7C4C\u7D02\u7D2C\u7DA2\u821F\u86DB\u8A3B\u8A85\u8D70\u8E8A\u8F33\u9031\u914E\u9152\u9444\u99D0\u7AF9\u7CA5\u4FCA\u5101\u51C6\u57C8\u5BEF\u5CFB\u6659\u6A3D\u6D5A\u6E96\u6FEC\u710C\u756F\u7AE3\u8822\u9021\u9075\u96CB\u99FF\u8301\u4E2D\u4EF2\u8846\u91CD\u537D\u6ADB\u696B\u6C41\u847A\u589E\u618E\u66FE\u62EF\u70DD\u7511\u75C7\u7E52\u84B8\u8B49\u8D08\u4E4B\u53EA"],
      ["f2a1", "\u54AB\u5730\u5740\u5FD7\u6301\u6307\u646F\u652F\u65E8\u667A\u679D\u67B3\u6B62\u6C60\u6C9A\u6F2C\u77E5\u7825\u7949\u7957\u7D19\u80A2\u8102\u81F3\u829D\u82B7\u8718\u8A8C\uF9FC\u8D04\u8DBE\u9072\u76F4\u7A19\u7A37\u7E54\u8077\u5507\u55D4\u5875\u632F\u6422\u6649\u664B\u686D\u699B\u6B84\u6D25\u6EB1\u73CD\u7468\u74A1\u755B\u75B9\u76E1\u771E\u778B\u79E6\u7E09\u7E1D\u81FB\u852F\u8897\u8A3A\u8CD1\u8EEB\u8FB0\u9032\u93AD\u9663\u9673\u9707\u4F84\u53F1\u59EA\u5AC9\u5E19\u684E\u74C6\u75BE\u79E9\u7A92\u81A3\u86ED\u8CEA\u8DCC\u8FED\u659F\u6715\uF9FD\u57F7\u6F57\u7DDD\u8F2F"],
      ["f3a1", "\u93F6\u96C6\u5FB5\u61F2\u6F84\u4E14\u4F98\u501F\u53C9\u55DF\u5D6F\u5DEE\u6B21\u6B64\u78CB\u7B9A\uF9FE\u8E49\u8ECA\u906E\u6349\u643E\u7740\u7A84\u932F\u947F\u9F6A\u64B0\u6FAF\u71E6\u74A8\u74DA\u7AC4\u7C12\u7E82\u7CB2\u7E98\u8B9A\u8D0A\u947D\u9910\u994C\u5239\u5BDF\u64E6\u672D\u7D2E\u50ED\u53C3\u5879\u6158\u6159\u61FA\u65AC\u7AD9\u8B92\u8B96\u5009\u5021\u5275\u5531\u5A3C\u5EE0\u5F70\u6134\u655E\u660C\u6636\u66A2\u69CD\u6EC4\u6F32\u7316\u7621\u7A93\u8139\u8259\u83D6\u84BC\u50B5\u57F0\u5BC0\u5BE8\u5F69\u63A1\u7826\u7DB5\u83DC\u8521\u91C7\u91F5\u518A\u67F5\u7B56"],
      ["f4a1", "\u8CAC\u51C4\u59BB\u60BD\u8655\u501C\uF9FF\u5254\u5C3A\u617D\u621A\u62D3\u64F2\u65A5\u6ECC\u7620\u810A\u8E60\u965F\u96BB\u4EDF\u5343\u5598\u5929\u5DDD\u64C5\u6CC9\u6DFA\u7394\u7A7F\u821B\u85A6\u8CE4\u8E10\u9077\u91E7\u95E1\u9621\u97C6\u51F8\u54F2\u5586\u5FB9\u64A4\u6F88\u7DB4\u8F1F\u8F4D\u9435\u50C9\u5C16\u6CBE\u6DFB\u751B\u77BB\u7C3D\u7C64\u8A79\u8AC2\u581E\u59BE\u5E16\u6377\u7252\u758A\u776B\u8ADC\u8CBC\u8F12\u5EF3\u6674\u6DF8\u807D\u83C1\u8ACB\u9751\u9BD6\uFA00\u5243\u66FF\u6D95\u6EEF\u7DE0\u8AE6\u902E\u905E\u9AD4\u521D\u527F\u54E8\u6194\u6284\u62DB\u68A2"],
      ["f5a1", "\u6912\u695A\u6A35\u7092\u7126\u785D\u7901\u790E\u79D2\u7A0D\u8096\u8278\u82D5\u8349\u8549\u8C82\u8D85\u9162\u918B\u91AE\u4FC3\u56D1\u71ED\u77D7\u8700\u89F8\u5BF8\u5FD6\u6751\u90A8\u53E2\u585A\u5BF5\u60A4\u6181\u6460\u7E3D\u8070\u8525\u9283\u64AE\u50AC\u5D14\u6700\u589C\u62BD\u63A8\u690E\u6978\u6A1E\u6E6B\u76BA\u79CB\u82BB\u8429\u8ACF\u8DA8\u8FFD\u9112\u914B\u919C\u9310\u9318\u939A\u96DB\u9A36\u9C0D\u4E11\u755C\u795D\u7AFA\u7B51\u7BC9\u7E2E\u84C4\u8E59\u8E74\u8EF8\u9010\u6625\u693F\u7443\u51FA\u672E\u9EDC\u5145\u5FE0\u6C96\u87F2\u885D\u8877\u60B4\u81B5\u8403"],
      ["f6a1", "\u8D05\u53D6\u5439\u5634\u5A36\u5C31\u708A\u7FE0\u805A\u8106\u81ED\u8DA3\u9189\u9A5F\u9DF2\u5074\u4EC4\u53A0\u60FB\u6E2C\u5C64\u4F88\u5024\u55E4\u5CD9\u5E5F\u6065\u6894\u6CBB\u6DC4\u71BE\u75D4\u75F4\u7661\u7A1A\u7A49\u7DC7\u7DFB\u7F6E\u81F4\u86A9\u8F1C\u96C9\u99B3\u9F52\u5247\u52C5\u98ED\u89AA\u4E03\u67D2\u6F06\u4FB5\u5BE2\u6795\u6C88\u6D78\u741B\u7827\u91DD\u937C\u87C4\u79E4\u7A31\u5FEB\u4ED6\u54A4\u553E\u58AE\u59A5\u60F0\u6253\u62D6\u6736\u6955\u8235\u9640\u99B1\u99DD\u502C\u5353\u5544\u577C\uFA01\u6258\uFA02\u64E2\u666B\u67DD\u6FC1\u6FEF\u7422\u7438\u8A17"],
      ["f7a1", "\u9438\u5451\u5606\u5766\u5F48\u619A\u6B4E\u7058\u70AD\u7DBB\u8A95\u596A\u812B\u63A2\u7708\u803D\u8CAA\u5854\u642D\u69BB\u5B95\u5E11\u6E6F\uFA03\u8569\u514C\u53F0\u592A\u6020\u614B\u6B86\u6C70\u6CF0\u7B1E\u80CE\u82D4\u8DC6\u90B0\u98B1\uFA04\u64C7\u6FA4\u6491\u6504\u514E\u5410\u571F\u8A0E\u615F\u6876\uFA05\u75DB\u7B52\u7D71\u901A\u5806\u69CC\u817F\u892A\u9000\u9839\u5078\u5957\u59AC\u6295\u900F\u9B2A\u615D\u7279\u95D6\u5761\u5A46\u5DF4\u628A\u64AD\u64FA\u6777\u6CE2\u6D3E\u722C\u7436\u7834\u7F77\u82AD\u8DDB\u9817\u5224\u5742\u677F\u7248\u74E3\u8CA9\u8FA6\u9211"],
      ["f8a1", "\u962A\u516B\u53ED\u634C\u4F69\u5504\u6096\u6557\u6C9B\u6D7F\u724C\u72FD\u7A17\u8987\u8C9D\u5F6D\u6F8E\u70F9\u81A8\u610E\u4FBF\u504F\u6241\u7247\u7BC7\u7DE8\u7FE9\u904D\u97AD\u9A19\u8CB6\u576A\u5E73\u67B0\u840D\u8A55\u5420\u5B16\u5E63\u5EE2\u5F0A\u6583\u80BA\u853D\u9589\u965B\u4F48\u5305\u530D\u530F\u5486\u54FA\u5703\u5E03\u6016\u629B\u62B1\u6355\uFA06\u6CE1\u6D66\u75B1\u7832\u80DE\u812F\u82DE\u8461\u84B2\u888D\u8912\u900B\u92EA\u98FD\u9B91\u5E45\u66B4\u66DD\u7011\u7206\uFA07\u4FF5\u527D\u5F6A\u6153\u6753\u6A19\u6F02\u74E2\u7968\u8868\u8C79\u98C7\u98C4\u9A43"],
      ["f9a1", "\u54C1\u7A1F\u6953\u8AF7\u8C4A\u98A8\u99AE\u5F7C\u62AB\u75B2\u76AE\u88AB\u907F\u9642\u5339\u5F3C\u5FC5\u6CCC\u73CC\u7562\u758B\u7B46\u82FE\u999D\u4E4F\u903C\u4E0B\u4F55\u53A6\u590F\u5EC8\u6630\u6CB3\u7455\u8377\u8766\u8CC0\u9050\u971E\u9C15\u58D1\u5B78\u8650\u8B14\u9DB4\u5BD2\u6068\u608D\u65F1\u6C57\u6F22\u6FA3\u701A\u7F55\u7FF0\u9591\u9592\u9650\u97D3\u5272\u8F44\u51FD\u542B\u54B8\u5563\u558A\u6ABB\u6DB5\u7DD8\u8266\u929C\u9677\u9E79\u5408\u54C8\u76D2\u86E4\u95A4\u95D4\u965C\u4EA2\u4F09\u59EE\u5AE6\u5DF7\u6052\u6297\u676D\u6841\u6C86\u6E2F\u7F38\u809B\u822A"],
      ["faa1", "\uFA08\uFA09\u9805\u4EA5\u5055\u54B3\u5793\u595A\u5B69\u5BB3\u61C8\u6977\u6D77\u7023\u87F9\u89E3\u8A72\u8AE7\u9082\u99ED\u9AB8\u52BE\u6838\u5016\u5E78\u674F\u8347\u884C\u4EAB\u5411\u56AE\u73E6\u9115\u97FF\u9909\u9957\u9999\u5653\u589F\u865B\u8A31\u61B2\u6AF6\u737B\u8ED2\u6B47\u96AA\u9A57\u5955\u7200\u8D6B\u9769\u4FD4\u5CF4\u5F26\u61F8\u665B\u6CEB\u70AB\u7384\u73B9\u73FE\u7729\u774D\u7D43\u7D62\u7E23\u8237\u8852\uFA0A\u8CE2\u9249\u986F\u5B51\u7A74\u8840\u9801\u5ACC\u4FE0\u5354\u593E\u5CFD\u633E\u6D79\u72F9\u8105\u8107\u83A2\u92CF\u9830\u4EA8\u5144\u5211\u578B"],
      ["fba1", "\u5F62\u6CC2\u6ECE\u7005\u7050\u70AF\u7192\u73E9\u7469\u834A\u87A2\u8861\u9008\u90A2\u93A3\u99A8\u516E\u5F57\u60E0\u6167\u66B3\u8559\u8E4A\u91AF\u978B\u4E4E\u4E92\u547C\u58D5\u58FA\u597D\u5CB5\u5F27\u6236\u6248\u660A\u6667\u6BEB\u6D69\u6DCF\u6E56\u6EF8\u6F94\u6FE0\u6FE9\u705D\u72D0\u7425\u745A\u74E0\u7693\u795C\u7CCA\u7E1E\u80E1\u82A6\u846B\u84BF\u864E\u865F\u8774\u8B77\u8C6A\u93AC\u9800\u9865\u60D1\u6216\u9177\u5A5A\u660F\u6DF7\u6E3E\u743F\u9B42\u5FFD\u60DA\u7B0F\u54C4\u5F18\u6C5E\u6CD3\u6D2A\u70D8\u7D05\u8679\u8A0C\u9D3B\u5316\u548C\u5B05\u6A3A\u706B\u7575"],
      ["fca1", "\u798D\u79BE\u82B1\u83EF\u8A71\u8B41\u8CA8\u9774\uFA0B\u64F4\u652B\u78BA\u78BB\u7A6B\u4E38\u559A\u5950\u5BA6\u5E7B\u60A3\u63DB\u6B61\u6665\u6853\u6E19\u7165\u74B0\u7D08\u9084\u9A69\u9C25\u6D3B\u6ED1\u733E\u8C41\u95CA\u51F0\u5E4C\u5FA8\u604D\u60F6\u6130\u614C\u6643\u6644\u69A5\u6CC1\u6E5F\u6EC9\u6F62\u714C\u749C\u7687\u7BC1\u7C27\u8352\u8757\u9051\u968D\u9EC3\u532F\u56DE\u5EFB\u5F8A\u6062\u6094\u61F7\u6666\u6703\u6A9C\u6DEE\u6FAE\u7070\u736A\u7E6A\u81BE\u8334\u86D4\u8AA8\u8CC4\u5283\u7372\u5B96\u6A6B\u9404\u54EE\u5686\u5B5D\u6548\u6585\u66C9\u689F\u6D8D\u6DC6"],
      ["fda1", "\u723B\u80B4\u9175\u9A4D\u4FAF\u5019\u539A\u540E\u543C\u5589\u55C5\u5E3F\u5F8C\u673D\u7166\u73DD\u9005\u52DB\u52F3\u5864\u58CE\u7104\u718F\u71FB\u85B0\u8A13\u6688\u85A8\u55A7\u6684\u714A\u8431\u5349\u5599\u6BC1\u5F59\u5FBD\u63EE\u6689\u7147\u8AF1\u8F1D\u9EBE\u4F11\u643A\u70CB\u7566\u8667\u6064\u8B4E\u9DF8\u5147\u51F6\u5308\u6D36\u80F8\u9ED1\u6615\u6B23\u7098\u75D5\u5403\u5C79\u7D07\u8A16\u6B20\u6B3D\u6B46\u5438\u6070\u6D3D\u7FD5\u8208\u50D6\u51DE\u559C\u566B\u56CD\u59EC\u5B09\u5E0C\u6199\u6198\u6231\u665E\u66E6\u7199\u71B9\u71BA\u72A7\u79A7\u7A00\u7FB2\u8A70"]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/cp950.json
var require_cp950 = __commonJS({
  "node_modules/iconv-lite/encodings/tables/cp950.json"(exports, module2) {
    module2.exports = [
      ["0", "\0", 127],
      ["a140", "\u3000\uFF0C\u3001\u3002\uFF0E\u2027\uFF1B\uFF1A\uFF1F\uFF01\uFE30\u2026\u2025\uFE50\uFE51\uFE52\xB7\uFE54\uFE55\uFE56\uFE57\uFF5C\u2013\uFE31\u2014\uFE33\u2574\uFE34\uFE4F\uFF08\uFF09\uFE35\uFE36\uFF5B\uFF5D\uFE37\uFE38\u3014\u3015\uFE39\uFE3A\u3010\u3011\uFE3B\uFE3C\u300A\u300B\uFE3D\uFE3E\u3008\u3009\uFE3F\uFE40\u300C\u300D\uFE41\uFE42\u300E\u300F\uFE43\uFE44\uFE59\uFE5A"],
      ["a1a1", "\uFE5B\uFE5C\uFE5D\uFE5E\u2018\u2019\u201C\u201D\u301D\u301E\u2035\u2032\uFF03\uFF06\uFF0A\u203B\xA7\u3003\u25CB\u25CF\u25B3\u25B2\u25CE\u2606\u2605\u25C7\u25C6\u25A1\u25A0\u25BD\u25BC\u32A3\u2105\xAF\uFFE3\uFF3F\u02CD\uFE49\uFE4A\uFE4D\uFE4E\uFE4B\uFE4C\uFE5F\uFE60\uFE61\uFF0B\uFF0D\xD7\xF7\xB1\u221A\uFF1C\uFF1E\uFF1D\u2266\u2267\u2260\u221E\u2252\u2261\uFE62", 4, "\uFF5E\u2229\u222A\u22A5\u2220\u221F\u22BF\u33D2\u33D1\u222B\u222E\u2235\u2234\u2640\u2642\u2295\u2299\u2191\u2193\u2190\u2192\u2196\u2197\u2199\u2198\u2225\u2223\uFF0F"],
      ["a240", "\uFF3C\u2215\uFE68\uFF04\uFFE5\u3012\uFFE0\uFFE1\uFF05\uFF20\u2103\u2109\uFE69\uFE6A\uFE6B\u33D5\u339C\u339D\u339E\u33CE\u33A1\u338E\u338F\u33C4\xB0\u5159\u515B\u515E\u515D\u5161\u5163\u55E7\u74E9\u7CCE\u2581", 7, "\u258F\u258E\u258D\u258C\u258B\u258A\u2589\u253C\u2534\u252C\u2524\u251C\u2594\u2500\u2502\u2595\u250C\u2510\u2514\u2518\u256D"],
      ["a2a1", "\u256E\u2570\u256F\u2550\u255E\u256A\u2561\u25E2\u25E3\u25E5\u25E4\u2571\u2572\u2573\uFF10", 9, "\u2160", 9, "\u3021", 8, "\u5341\u5344\u5345\uFF21", 25, "\uFF41", 21],
      ["a340", "\uFF57\uFF58\uFF59\uFF5A\u0391", 16, "\u03A3", 6, "\u03B1", 16, "\u03C3", 6, "\u3105", 10],
      ["a3a1", "\u3110", 25, "\u02D9\u02C9\u02CA\u02C7\u02CB"],
      ["a3e1", "\u20AC"],
      ["a440", "\u4E00\u4E59\u4E01\u4E03\u4E43\u4E5D\u4E86\u4E8C\u4EBA\u513F\u5165\u516B\u51E0\u5200\u5201\u529B\u5315\u5341\u535C\u53C8\u4E09\u4E0B\u4E08\u4E0A\u4E2B\u4E38\u51E1\u4E45\u4E48\u4E5F\u4E5E\u4E8E\u4EA1\u5140\u5203\u52FA\u5343\u53C9\u53E3\u571F\u58EB\u5915\u5927\u5973\u5B50\u5B51\u5B53\u5BF8\u5C0F\u5C22\u5C38\u5C71\u5DDD\u5DE5\u5DF1\u5DF2\u5DF3\u5DFE\u5E72\u5EFE\u5F0B\u5F13\u624D"],
      ["a4a1", "\u4E11\u4E10\u4E0D\u4E2D\u4E30\u4E39\u4E4B\u5C39\u4E88\u4E91\u4E95\u4E92\u4E94\u4EA2\u4EC1\u4EC0\u4EC3\u4EC6\u4EC7\u4ECD\u4ECA\u4ECB\u4EC4\u5143\u5141\u5167\u516D\u516E\u516C\u5197\u51F6\u5206\u5207\u5208\u52FB\u52FE\u52FF\u5316\u5339\u5348\u5347\u5345\u535E\u5384\u53CB\u53CA\u53CD\u58EC\u5929\u592B\u592A\u592D\u5B54\u5C11\u5C24\u5C3A\u5C6F\u5DF4\u5E7B\u5EFF\u5F14\u5F15\u5FC3\u6208\u6236\u624B\u624E\u652F\u6587\u6597\u65A4\u65B9\u65E5\u66F0\u6708\u6728\u6B20\u6B62\u6B79\u6BCB\u6BD4\u6BDB\u6C0F\u6C34\u706B\u722A\u7236\u723B\u7247\u7259\u725B\u72AC\u738B\u4E19"],
      ["a540", "\u4E16\u4E15\u4E14\u4E18\u4E3B\u4E4D\u4E4F\u4E4E\u4EE5\u4ED8\u4ED4\u4ED5\u4ED6\u4ED7\u4EE3\u4EE4\u4ED9\u4EDE\u5145\u5144\u5189\u518A\u51AC\u51F9\u51FA\u51F8\u520A\u52A0\u529F\u5305\u5306\u5317\u531D\u4EDF\u534A\u5349\u5361\u5360\u536F\u536E\u53BB\u53EF\u53E4\u53F3\u53EC\u53EE\u53E9\u53E8\u53FC\u53F8\u53F5\u53EB\u53E6\u53EA\u53F2\u53F1\u53F0\u53E5\u53ED\u53FB\u56DB\u56DA\u5916"],
      ["a5a1", "\u592E\u5931\u5974\u5976\u5B55\u5B83\u5C3C\u5DE8\u5DE7\u5DE6\u5E02\u5E03\u5E73\u5E7C\u5F01\u5F18\u5F17\u5FC5\u620A\u6253\u6254\u6252\u6251\u65A5\u65E6\u672E\u672C\u672A\u672B\u672D\u6B63\u6BCD\u6C11\u6C10\u6C38\u6C41\u6C40\u6C3E\u72AF\u7384\u7389\u74DC\u74E6\u7518\u751F\u7528\u7529\u7530\u7531\u7532\u7533\u758B\u767D\u76AE\u76BF\u76EE\u77DB\u77E2\u77F3\u793A\u79BE\u7A74\u7ACB\u4E1E\u4E1F\u4E52\u4E53\u4E69\u4E99\u4EA4\u4EA6\u4EA5\u4EFF\u4F09\u4F19\u4F0A\u4F15\u4F0D\u4F10\u4F11\u4F0F\u4EF2\u4EF6\u4EFB\u4EF0\u4EF3\u4EFD\u4F01\u4F0B\u5149\u5147\u5146\u5148\u5168"],
      ["a640", "\u5171\u518D\u51B0\u5217\u5211\u5212\u520E\u5216\u52A3\u5308\u5321\u5320\u5370\u5371\u5409\u540F\u540C\u540A\u5410\u5401\u540B\u5404\u5411\u540D\u5408\u5403\u540E\u5406\u5412\u56E0\u56DE\u56DD\u5733\u5730\u5728\u572D\u572C\u572F\u5729\u5919\u591A\u5937\u5938\u5984\u5978\u5983\u597D\u5979\u5982\u5981\u5B57\u5B58\u5B87\u5B88\u5B85\u5B89\u5BFA\u5C16\u5C79\u5DDE\u5E06\u5E76\u5E74"],
      ["a6a1", "\u5F0F\u5F1B\u5FD9\u5FD6\u620E\u620C\u620D\u6210\u6263\u625B\u6258\u6536\u65E9\u65E8\u65EC\u65ED\u66F2\u66F3\u6709\u673D\u6734\u6731\u6735\u6B21\u6B64\u6B7B\u6C16\u6C5D\u6C57\u6C59\u6C5F\u6C60\u6C50\u6C55\u6C61\u6C5B\u6C4D\u6C4E\u7070\u725F\u725D\u767E\u7AF9\u7C73\u7CF8\u7F36\u7F8A\u7FBD\u8001\u8003\u800C\u8012\u8033\u807F\u8089\u808B\u808C\u81E3\u81EA\u81F3\u81FC\u820C\u821B\u821F\u826E\u8272\u827E\u866B\u8840\u884C\u8863\u897F\u9621\u4E32\u4EA8\u4F4D\u4F4F\u4F47\u4F57\u4F5E\u4F34\u4F5B\u4F55\u4F30\u4F50\u4F51\u4F3D\u4F3A\u4F38\u4F43\u4F54\u4F3C\u4F46\u4F63"],
      ["a740", "\u4F5C\u4F60\u4F2F\u4F4E\u4F36\u4F59\u4F5D\u4F48\u4F5A\u514C\u514B\u514D\u5175\u51B6\u51B7\u5225\u5224\u5229\u522A\u5228\u52AB\u52A9\u52AA\u52AC\u5323\u5373\u5375\u541D\u542D\u541E\u543E\u5426\u544E\u5427\u5446\u5443\u5433\u5448\u5442\u541B\u5429\u544A\u5439\u543B\u5438\u542E\u5435\u5436\u5420\u543C\u5440\u5431\u542B\u541F\u542C\u56EA\u56F0\u56E4\u56EB\u574A\u5751\u5740\u574D"],
      ["a7a1", "\u5747\u574E\u573E\u5750\u574F\u573B\u58EF\u593E\u599D\u5992\u59A8\u599E\u59A3\u5999\u5996\u598D\u59A4\u5993\u598A\u59A5\u5B5D\u5B5C\u5B5A\u5B5B\u5B8C\u5B8B\u5B8F\u5C2C\u5C40\u5C41\u5C3F\u5C3E\u5C90\u5C91\u5C94\u5C8C\u5DEB\u5E0C\u5E8F\u5E87\u5E8A\u5EF7\u5F04\u5F1F\u5F64\u5F62\u5F77\u5F79\u5FD8\u5FCC\u5FD7\u5FCD\u5FF1\u5FEB\u5FF8\u5FEA\u6212\u6211\u6284\u6297\u6296\u6280\u6276\u6289\u626D\u628A\u627C\u627E\u6279\u6273\u6292\u626F\u6298\u626E\u6295\u6293\u6291\u6286\u6539\u653B\u6538\u65F1\u66F4\u675F\u674E\u674F\u6750\u6751\u675C\u6756\u675E\u6749\u6746\u6760"],
      ["a840", "\u6753\u6757\u6B65\u6BCF\u6C42\u6C5E\u6C99\u6C81\u6C88\u6C89\u6C85\u6C9B\u6C6A\u6C7A\u6C90\u6C70\u6C8C\u6C68\u6C96\u6C92\u6C7D\u6C83\u6C72\u6C7E\u6C74\u6C86\u6C76\u6C8D\u6C94\u6C98\u6C82\u7076\u707C\u707D\u7078\u7262\u7261\u7260\u72C4\u72C2\u7396\u752C\u752B\u7537\u7538\u7682\u76EF\u77E3\u79C1\u79C0\u79BF\u7A76\u7CFB\u7F55\u8096\u8093\u809D\u8098\u809B\u809A\u80B2\u826F\u8292"],
      ["a8a1", "\u828B\u828D\u898B\u89D2\u8A00\u8C37\u8C46\u8C55\u8C9D\u8D64\u8D70\u8DB3\u8EAB\u8ECA\u8F9B\u8FB0\u8FC2\u8FC6\u8FC5\u8FC4\u5DE1\u9091\u90A2\u90AA\u90A6\u90A3\u9149\u91C6\u91CC\u9632\u962E\u9631\u962A\u962C\u4E26\u4E56\u4E73\u4E8B\u4E9B\u4E9E\u4EAB\u4EAC\u4F6F\u4F9D\u4F8D\u4F73\u4F7F\u4F6C\u4F9B\u4F8B\u4F86\u4F83\u4F70\u4F75\u4F88\u4F69\u4F7B\u4F96\u4F7E\u4F8F\u4F91\u4F7A\u5154\u5152\u5155\u5169\u5177\u5176\u5178\u51BD\u51FD\u523B\u5238\u5237\u523A\u5230\u522E\u5236\u5241\u52BE\u52BB\u5352\u5354\u5353\u5351\u5366\u5377\u5378\u5379\u53D6\u53D4\u53D7\u5473\u5475"],
      ["a940", "\u5496\u5478\u5495\u5480\u547B\u5477\u5484\u5492\u5486\u547C\u5490\u5471\u5476\u548C\u549A\u5462\u5468\u548B\u547D\u548E\u56FA\u5783\u5777\u576A\u5769\u5761\u5766\u5764\u577C\u591C\u5949\u5947\u5948\u5944\u5954\u59BE\u59BB\u59D4\u59B9\u59AE\u59D1\u59C6\u59D0\u59CD\u59CB\u59D3\u59CA\u59AF\u59B3\u59D2\u59C5\u5B5F\u5B64\u5B63\u5B97\u5B9A\u5B98\u5B9C\u5B99\u5B9B\u5C1A\u5C48\u5C45"],
      ["a9a1", "\u5C46\u5CB7\u5CA1\u5CB8\u5CA9\u5CAB\u5CB1\u5CB3\u5E18\u5E1A\u5E16\u5E15\u5E1B\u5E11\u5E78\u5E9A\u5E97\u5E9C\u5E95\u5E96\u5EF6\u5F26\u5F27\u5F29\u5F80\u5F81\u5F7F\u5F7C\u5FDD\u5FE0\u5FFD\u5FF5\u5FFF\u600F\u6014\u602F\u6035\u6016\u602A\u6015\u6021\u6027\u6029\u602B\u601B\u6216\u6215\u623F\u623E\u6240\u627F\u62C9\u62CC\u62C4\u62BF\u62C2\u62B9\u62D2\u62DB\u62AB\u62D3\u62D4\u62CB\u62C8\u62A8\u62BD\u62BC\u62D0\u62D9\u62C7\u62CD\u62B5\u62DA\u62B1\u62D8\u62D6\u62D7\u62C6\u62AC\u62CE\u653E\u65A7\u65BC\u65FA\u6614\u6613\u660C\u6606\u6602\u660E\u6600\u660F\u6615\u660A"],
      ["aa40", "\u6607\u670D\u670B\u676D\u678B\u6795\u6771\u679C\u6773\u6777\u6787\u679D\u6797\u676F\u6770\u677F\u6789\u677E\u6790\u6775\u679A\u6793\u677C\u676A\u6772\u6B23\u6B66\u6B67\u6B7F\u6C13\u6C1B\u6CE3\u6CE8\u6CF3\u6CB1\u6CCC\u6CE5\u6CB3\u6CBD\u6CBE\u6CBC\u6CE2\u6CAB\u6CD5\u6CD3\u6CB8\u6CC4\u6CB9\u6CC1\u6CAE\u6CD7\u6CC5\u6CF1\u6CBF\u6CBB\u6CE1\u6CDB\u6CCA\u6CAC\u6CEF\u6CDC\u6CD6\u6CE0"],
      ["aaa1", "\u7095\u708E\u7092\u708A\u7099\u722C\u722D\u7238\u7248\u7267\u7269\u72C0\u72CE\u72D9\u72D7\u72D0\u73A9\u73A8\u739F\u73AB\u73A5\u753D\u759D\u7599\u759A\u7684\u76C2\u76F2\u76F4\u77E5\u77FD\u793E\u7940\u7941\u79C9\u79C8\u7A7A\u7A79\u7AFA\u7CFE\u7F54\u7F8C\u7F8B\u8005\u80BA\u80A5\u80A2\u80B1\u80A1\u80AB\u80A9\u80B4\u80AA\u80AF\u81E5\u81FE\u820D\u82B3\u829D\u8299\u82AD\u82BD\u829F\u82B9\u82B1\u82AC\u82A5\u82AF\u82B8\u82A3\u82B0\u82BE\u82B7\u864E\u8671\u521D\u8868\u8ECB\u8FCE\u8FD4\u8FD1\u90B5\u90B8\u90B1\u90B6\u91C7\u91D1\u9577\u9580\u961C\u9640\u963F\u963B\u9644"],
      ["ab40", "\u9642\u96B9\u96E8\u9752\u975E\u4E9F\u4EAD\u4EAE\u4FE1\u4FB5\u4FAF\u4FBF\u4FE0\u4FD1\u4FCF\u4FDD\u4FC3\u4FB6\u4FD8\u4FDF\u4FCA\u4FD7\u4FAE\u4FD0\u4FC4\u4FC2\u4FDA\u4FCE\u4FDE\u4FB7\u5157\u5192\u5191\u51A0\u524E\u5243\u524A\u524D\u524C\u524B\u5247\u52C7\u52C9\u52C3\u52C1\u530D\u5357\u537B\u539A\u53DB\u54AC\u54C0\u54A8\u54CE\u54C9\u54B8\u54A6\u54B3\u54C7\u54C2\u54BD\u54AA\u54C1"],
      ["aba1", "\u54C4\u54C8\u54AF\u54AB\u54B1\u54BB\u54A9\u54A7\u54BF\u56FF\u5782\u578B\u57A0\u57A3\u57A2\u57CE\u57AE\u5793\u5955\u5951\u594F\u594E\u5950\u59DC\u59D8\u59FF\u59E3\u59E8\u5A03\u59E5\u59EA\u59DA\u59E6\u5A01\u59FB\u5B69\u5BA3\u5BA6\u5BA4\u5BA2\u5BA5\u5C01\u5C4E\u5C4F\u5C4D\u5C4B\u5CD9\u5CD2\u5DF7\u5E1D\u5E25\u5E1F\u5E7D\u5EA0\u5EA6\u5EFA\u5F08\u5F2D\u5F65\u5F88\u5F85\u5F8A\u5F8B\u5F87\u5F8C\u5F89\u6012\u601D\u6020\u6025\u600E\u6028\u604D\u6070\u6068\u6062\u6046\u6043\u606C\u606B\u606A\u6064\u6241\u62DC\u6316\u6309\u62FC\u62ED\u6301\u62EE\u62FD\u6307\u62F1\u62F7"],
      ["ac40", "\u62EF\u62EC\u62FE\u62F4\u6311\u6302\u653F\u6545\u65AB\u65BD\u65E2\u6625\u662D\u6620\u6627\u662F\u661F\u6628\u6631\u6624\u66F7\u67FF\u67D3\u67F1\u67D4\u67D0\u67EC\u67B6\u67AF\u67F5\u67E9\u67EF\u67C4\u67D1\u67B4\u67DA\u67E5\u67B8\u67CF\u67DE\u67F3\u67B0\u67D9\u67E2\u67DD\u67D2\u6B6A\u6B83\u6B86\u6BB5\u6BD2\u6BD7\u6C1F\u6CC9\u6D0B\u6D32\u6D2A\u6D41\u6D25\u6D0C\u6D31\u6D1E\u6D17"],
      ["aca1", "\u6D3B\u6D3D\u6D3E\u6D36\u6D1B\u6CF5\u6D39\u6D27\u6D38\u6D29\u6D2E\u6D35\u6D0E\u6D2B\u70AB\u70BA\u70B3\u70AC\u70AF\u70AD\u70B8\u70AE\u70A4\u7230\u7272\u726F\u7274\u72E9\u72E0\u72E1\u73B7\u73CA\u73BB\u73B2\u73CD\u73C0\u73B3\u751A\u752D\u754F\u754C\u754E\u754B\u75AB\u75A4\u75A5\u75A2\u75A3\u7678\u7686\u7687\u7688\u76C8\u76C6\u76C3\u76C5\u7701\u76F9\u76F8\u7709\u770B\u76FE\u76FC\u7707\u77DC\u7802\u7814\u780C\u780D\u7946\u7949\u7948\u7947\u79B9\u79BA\u79D1\u79D2\u79CB\u7A7F\u7A81\u7AFF\u7AFD\u7C7D\u7D02\u7D05\u7D00\u7D09\u7D07\u7D04\u7D06\u7F38\u7F8E\u7FBF\u8004"],
      ["ad40", "\u8010\u800D\u8011\u8036\u80D6\u80E5\u80DA\u80C3\u80C4\u80CC\u80E1\u80DB\u80CE\u80DE\u80E4\u80DD\u81F4\u8222\u82E7\u8303\u8305\u82E3\u82DB\u82E6\u8304\u82E5\u8302\u8309\u82D2\u82D7\u82F1\u8301\u82DC\u82D4\u82D1\u82DE\u82D3\u82DF\u82EF\u8306\u8650\u8679\u867B\u867A\u884D\u886B\u8981\u89D4\u8A08\u8A02\u8A03\u8C9E\u8CA0\u8D74\u8D73\u8DB4\u8ECD\u8ECC\u8FF0\u8FE6\u8FE2\u8FEA\u8FE5"],
      ["ada1", "\u8FED\u8FEB\u8FE4\u8FE8\u90CA\u90CE\u90C1\u90C3\u914B\u914A\u91CD\u9582\u9650\u964B\u964C\u964D\u9762\u9769\u97CB\u97ED\u97F3\u9801\u98A8\u98DB\u98DF\u9996\u9999\u4E58\u4EB3\u500C\u500D\u5023\u4FEF\u5026\u5025\u4FF8\u5029\u5016\u5006\u503C\u501F\u501A\u5012\u5011\u4FFA\u5000\u5014\u5028\u4FF1\u5021\u500B\u5019\u5018\u4FF3\u4FEE\u502D\u502A\u4FFE\u502B\u5009\u517C\u51A4\u51A5\u51A2\u51CD\u51CC\u51C6\u51CB\u5256\u525C\u5254\u525B\u525D\u532A\u537F\u539F\u539D\u53DF\u54E8\u5510\u5501\u5537\u54FC\u54E5\u54F2\u5506\u54FA\u5514\u54E9\u54ED\u54E1\u5509\u54EE\u54EA"],
      ["ae40", "\u54E6\u5527\u5507\u54FD\u550F\u5703\u5704\u57C2\u57D4\u57CB\u57C3\u5809\u590F\u5957\u5958\u595A\u5A11\u5A18\u5A1C\u5A1F\u5A1B\u5A13\u59EC\u5A20\u5A23\u5A29\u5A25\u5A0C\u5A09\u5B6B\u5C58\u5BB0\u5BB3\u5BB6\u5BB4\u5BAE\u5BB5\u5BB9\u5BB8\u5C04\u5C51\u5C55\u5C50\u5CED\u5CFD\u5CFB\u5CEA\u5CE8\u5CF0\u5CF6\u5D01\u5CF4\u5DEE\u5E2D\u5E2B\u5EAB\u5EAD\u5EA7\u5F31\u5F92\u5F91\u5F90\u6059"],
      ["aea1", "\u6063\u6065\u6050\u6055\u606D\u6069\u606F\u6084\u609F\u609A\u608D\u6094\u608C\u6085\u6096\u6247\u62F3\u6308\u62FF\u634E\u633E\u632F\u6355\u6342\u6346\u634F\u6349\u633A\u6350\u633D\u632A\u632B\u6328\u634D\u634C\u6548\u6549\u6599\u65C1\u65C5\u6642\u6649\u664F\u6643\u6652\u664C\u6645\u6641\u66F8\u6714\u6715\u6717\u6821\u6838\u6848\u6846\u6853\u6839\u6842\u6854\u6829\u68B3\u6817\u684C\u6851\u683D\u67F4\u6850\u6840\u683C\u6843\u682A\u6845\u6813\u6818\u6841\u6B8A\u6B89\u6BB7\u6C23\u6C27\u6C28\u6C26\u6C24\u6CF0\u6D6A\u6D95\u6D88\u6D87\u6D66\u6D78\u6D77\u6D59\u6D93"],
      ["af40", "\u6D6C\u6D89\u6D6E\u6D5A\u6D74\u6D69\u6D8C\u6D8A\u6D79\u6D85\u6D65\u6D94\u70CA\u70D8\u70E4\u70D9\u70C8\u70CF\u7239\u7279\u72FC\u72F9\u72FD\u72F8\u72F7\u7386\u73ED\u7409\u73EE\u73E0\u73EA\u73DE\u7554\u755D\u755C\u755A\u7559\u75BE\u75C5\u75C7\u75B2\u75B3\u75BD\u75BC\u75B9\u75C2\u75B8\u768B\u76B0\u76CA\u76CD\u76CE\u7729\u771F\u7720\u7728\u77E9\u7830\u7827\u7838\u781D\u7834\u7837"],
      ["afa1", "\u7825\u782D\u7820\u781F\u7832\u7955\u7950\u7960\u795F\u7956\u795E\u795D\u7957\u795A\u79E4\u79E3\u79E7\u79DF\u79E6\u79E9\u79D8\u7A84\u7A88\u7AD9\u7B06\u7B11\u7C89\u7D21\u7D17\u7D0B\u7D0A\u7D20\u7D22\u7D14\u7D10\u7D15\u7D1A\u7D1C\u7D0D\u7D19\u7D1B\u7F3A\u7F5F\u7F94\u7FC5\u7FC1\u8006\u8018\u8015\u8019\u8017\u803D\u803F\u80F1\u8102\u80F0\u8105\u80ED\u80F4\u8106\u80F8\u80F3\u8108\u80FD\u810A\u80FC\u80EF\u81ED\u81EC\u8200\u8210\u822A\u822B\u8228\u822C\u82BB\u832B\u8352\u8354\u834A\u8338\u8350\u8349\u8335\u8334\u834F\u8332\u8339\u8336\u8317\u8340\u8331\u8328\u8343"],
      ["b040", "\u8654\u868A\u86AA\u8693\u86A4\u86A9\u868C\u86A3\u869C\u8870\u8877\u8881\u8882\u887D\u8879\u8A18\u8A10\u8A0E\u8A0C\u8A15\u8A0A\u8A17\u8A13\u8A16\u8A0F\u8A11\u8C48\u8C7A\u8C79\u8CA1\u8CA2\u8D77\u8EAC\u8ED2\u8ED4\u8ECF\u8FB1\u9001\u9006\u8FF7\u9000\u8FFA\u8FF4\u9003\u8FFD\u9005\u8FF8\u9095\u90E1\u90DD\u90E2\u9152\u914D\u914C\u91D8\u91DD\u91D7\u91DC\u91D9\u9583\u9662\u9663\u9661"],
      ["b0a1", "\u965B\u965D\u9664\u9658\u965E\u96BB\u98E2\u99AC\u9AA8\u9AD8\u9B25\u9B32\u9B3C\u4E7E\u507A\u507D\u505C\u5047\u5043\u504C\u505A\u5049\u5065\u5076\u504E\u5055\u5075\u5074\u5077\u504F\u500F\u506F\u506D\u515C\u5195\u51F0\u526A\u526F\u52D2\u52D9\u52D8\u52D5\u5310\u530F\u5319\u533F\u5340\u533E\u53C3\u66FC\u5546\u556A\u5566\u5544\u555E\u5561\u5543\u554A\u5531\u5556\u554F\u5555\u552F\u5564\u5538\u552E\u555C\u552C\u5563\u5533\u5541\u5557\u5708\u570B\u5709\u57DF\u5805\u580A\u5806\u57E0\u57E4\u57FA\u5802\u5835\u57F7\u57F9\u5920\u5962\u5A36\u5A41\u5A49\u5A66\u5A6A\u5A40"],
      ["b140", "\u5A3C\u5A62\u5A5A\u5A46\u5A4A\u5B70\u5BC7\u5BC5\u5BC4\u5BC2\u5BBF\u5BC6\u5C09\u5C08\u5C07\u5C60\u5C5C\u5C5D\u5D07\u5D06\u5D0E\u5D1B\u5D16\u5D22\u5D11\u5D29\u5D14\u5D19\u5D24\u5D27\u5D17\u5DE2\u5E38\u5E36\u5E33\u5E37\u5EB7\u5EB8\u5EB6\u5EB5\u5EBE\u5F35\u5F37\u5F57\u5F6C\u5F69\u5F6B\u5F97\u5F99\u5F9E\u5F98\u5FA1\u5FA0\u5F9C\u607F\u60A3\u6089\u60A0\u60A8\u60CB\u60B4\u60E6\u60BD"],
      ["b1a1", "\u60C5\u60BB\u60B5\u60DC\u60BC\u60D8\u60D5\u60C6\u60DF\u60B8\u60DA\u60C7\u621A\u621B\u6248\u63A0\u63A7\u6372\u6396\u63A2\u63A5\u6377\u6367\u6398\u63AA\u6371\u63A9\u6389\u6383\u639B\u636B\u63A8\u6384\u6388\u6399\u63A1\u63AC\u6392\u638F\u6380\u637B\u6369\u6368\u637A\u655D\u6556\u6551\u6559\u6557\u555F\u654F\u6558\u6555\u6554\u659C\u659B\u65AC\u65CF\u65CB\u65CC\u65CE\u665D\u665A\u6664\u6668\u6666\u665E\u66F9\u52D7\u671B\u6881\u68AF\u68A2\u6893\u68B5\u687F\u6876\u68B1\u68A7\u6897\u68B0\u6883\u68C4\u68AD\u6886\u6885\u6894\u689D\u68A8\u689F\u68A1\u6882\u6B32\u6BBA"],
      ["b240", "\u6BEB\u6BEC\u6C2B\u6D8E\u6DBC\u6DF3\u6DD9\u6DB2\u6DE1\u6DCC\u6DE4\u6DFB\u6DFA\u6E05\u6DC7\u6DCB\u6DAF\u6DD1\u6DAE\u6DDE\u6DF9\u6DB8\u6DF7\u6DF5\u6DC5\u6DD2\u6E1A\u6DB5\u6DDA\u6DEB\u6DD8\u6DEA\u6DF1\u6DEE\u6DE8\u6DC6\u6DC4\u6DAA\u6DEC\u6DBF\u6DE6\u70F9\u7109\u710A\u70FD\u70EF\u723D\u727D\u7281\u731C\u731B\u7316\u7313\u7319\u7387\u7405\u740A\u7403\u7406\u73FE\u740D\u74E0\u74F6"],
      ["b2a1", "\u74F7\u751C\u7522\u7565\u7566\u7562\u7570\u758F\u75D4\u75D5\u75B5\u75CA\u75CD\u768E\u76D4\u76D2\u76DB\u7737\u773E\u773C\u7736\u7738\u773A\u786B\u7843\u784E\u7965\u7968\u796D\u79FB\u7A92\u7A95\u7B20\u7B28\u7B1B\u7B2C\u7B26\u7B19\u7B1E\u7B2E\u7C92\u7C97\u7C95\u7D46\u7D43\u7D71\u7D2E\u7D39\u7D3C\u7D40\u7D30\u7D33\u7D44\u7D2F\u7D42\u7D32\u7D31\u7F3D\u7F9E\u7F9A\u7FCC\u7FCE\u7FD2\u801C\u804A\u8046\u812F\u8116\u8123\u812B\u8129\u8130\u8124\u8202\u8235\u8237\u8236\u8239\u838E\u839E\u8398\u8378\u83A2\u8396\u83BD\u83AB\u8392\u838A\u8393\u8389\u83A0\u8377\u837B\u837C"],
      ["b340", "\u8386\u83A7\u8655\u5F6A\u86C7\u86C0\u86B6\u86C4\u86B5\u86C6\u86CB\u86B1\u86AF\u86C9\u8853\u889E\u8888\u88AB\u8892\u8896\u888D\u888B\u8993\u898F\u8A2A\u8A1D\u8A23\u8A25\u8A31\u8A2D\u8A1F\u8A1B\u8A22\u8C49\u8C5A\u8CA9\u8CAC\u8CAB\u8CA8\u8CAA\u8CA7\u8D67\u8D66\u8DBE\u8DBA\u8EDB\u8EDF\u9019\u900D\u901A\u9017\u9023\u901F\u901D\u9010\u9015\u901E\u9020\u900F\u9022\u9016\u901B\u9014"],
      ["b3a1", "\u90E8\u90ED\u90FD\u9157\u91CE\u91F5\u91E6\u91E3\u91E7\u91ED\u91E9\u9589\u966A\u9675\u9673\u9678\u9670\u9674\u9676\u9677\u966C\u96C0\u96EA\u96E9\u7AE0\u7ADF\u9802\u9803\u9B5A\u9CE5\u9E75\u9E7F\u9EA5\u9EBB\u50A2\u508D\u5085\u5099\u5091\u5080\u5096\u5098\u509A\u6700\u51F1\u5272\u5274\u5275\u5269\u52DE\u52DD\u52DB\u535A\u53A5\u557B\u5580\u55A7\u557C\u558A\u559D\u5598\u5582\u559C\u55AA\u5594\u5587\u558B\u5583\u55B3\u55AE\u559F\u553E\u55B2\u559A\u55BB\u55AC\u55B1\u557E\u5589\u55AB\u5599\u570D\u582F\u582A\u5834\u5824\u5830\u5831\u5821\u581D\u5820\u58F9\u58FA\u5960"],
      ["b440", "\u5A77\u5A9A\u5A7F\u5A92\u5A9B\u5AA7\u5B73\u5B71\u5BD2\u5BCC\u5BD3\u5BD0\u5C0A\u5C0B\u5C31\u5D4C\u5D50\u5D34\u5D47\u5DFD\u5E45\u5E3D\u5E40\u5E43\u5E7E\u5ECA\u5EC1\u5EC2\u5EC4\u5F3C\u5F6D\u5FA9\u5FAA\u5FA8\u60D1\u60E1\u60B2\u60B6\u60E0\u611C\u6123\u60FA\u6115\u60F0\u60FB\u60F4\u6168\u60F1\u610E\u60F6\u6109\u6100\u6112\u621F\u6249\u63A3\u638C\u63CF\u63C0\u63E9\u63C9\u63C6\u63CD"],
      ["b4a1", "\u63D2\u63E3\u63D0\u63E1\u63D6\u63ED\u63EE\u6376\u63F4\u63EA\u63DB\u6452\u63DA\u63F9\u655E\u6566\u6562\u6563\u6591\u6590\u65AF\u666E\u6670\u6674\u6676\u666F\u6691\u667A\u667E\u6677\u66FE\u66FF\u671F\u671D\u68FA\u68D5\u68E0\u68D8\u68D7\u6905\u68DF\u68F5\u68EE\u68E7\u68F9\u68D2\u68F2\u68E3\u68CB\u68CD\u690D\u6912\u690E\u68C9\u68DA\u696E\u68FB\u6B3E\u6B3A\u6B3D\u6B98\u6B96\u6BBC\u6BEF\u6C2E\u6C2F\u6C2C\u6E2F\u6E38\u6E54\u6E21\u6E32\u6E67\u6E4A\u6E20\u6E25\u6E23\u6E1B\u6E5B\u6E58\u6E24\u6E56\u6E6E\u6E2D\u6E26\u6E6F\u6E34\u6E4D\u6E3A\u6E2C\u6E43\u6E1D\u6E3E\u6ECB"],
      ["b540", "\u6E89\u6E19\u6E4E\u6E63\u6E44\u6E72\u6E69\u6E5F\u7119\u711A\u7126\u7130\u7121\u7136\u716E\u711C\u724C\u7284\u7280\u7336\u7325\u7334\u7329\u743A\u742A\u7433\u7422\u7425\u7435\u7436\u7434\u742F\u741B\u7426\u7428\u7525\u7526\u756B\u756A\u75E2\u75DB\u75E3\u75D9\u75D8\u75DE\u75E0\u767B\u767C\u7696\u7693\u76B4\u76DC\u774F\u77ED\u785D\u786C\u786F\u7A0D\u7A08\u7A0B\u7A05\u7A00\u7A98"],
      ["b5a1", "\u7A97\u7A96\u7AE5\u7AE3\u7B49\u7B56\u7B46\u7B50\u7B52\u7B54\u7B4D\u7B4B\u7B4F\u7B51\u7C9F\u7CA5\u7D5E\u7D50\u7D68\u7D55\u7D2B\u7D6E\u7D72\u7D61\u7D66\u7D62\u7D70\u7D73\u5584\u7FD4\u7FD5\u800B\u8052\u8085\u8155\u8154\u814B\u8151\u814E\u8139\u8146\u813E\u814C\u8153\u8174\u8212\u821C\u83E9\u8403\u83F8\u840D\u83E0\u83C5\u840B\u83C1\u83EF\u83F1\u83F4\u8457\u840A\u83F0\u840C\u83CC\u83FD\u83F2\u83CA\u8438\u840E\u8404\u83DC\u8407\u83D4\u83DF\u865B\u86DF\u86D9\u86ED\u86D4\u86DB\u86E4\u86D0\u86DE\u8857\u88C1\u88C2\u88B1\u8983\u8996\u8A3B\u8A60\u8A55\u8A5E\u8A3C\u8A41"],
      ["b640", "\u8A54\u8A5B\u8A50\u8A46\u8A34\u8A3A\u8A36\u8A56\u8C61\u8C82\u8CAF\u8CBC\u8CB3\u8CBD\u8CC1\u8CBB\u8CC0\u8CB4\u8CB7\u8CB6\u8CBF\u8CB8\u8D8A\u8D85\u8D81\u8DCE\u8DDD\u8DCB\u8DDA\u8DD1\u8DCC\u8DDB\u8DC6\u8EFB\u8EF8\u8EFC\u8F9C\u902E\u9035\u9031\u9038\u9032\u9036\u9102\u90F5\u9109\u90FE\u9163\u9165\u91CF\u9214\u9215\u9223\u9209\u921E\u920D\u9210\u9207\u9211\u9594\u958F\u958B\u9591"],
      ["b6a1", "\u9593\u9592\u958E\u968A\u968E\u968B\u967D\u9685\u9686\u968D\u9672\u9684\u96C1\u96C5\u96C4\u96C6\u96C7\u96EF\u96F2\u97CC\u9805\u9806\u9808\u98E7\u98EA\u98EF\u98E9\u98F2\u98ED\u99AE\u99AD\u9EC3\u9ECD\u9ED1\u4E82\u50AD\u50B5\u50B2\u50B3\u50C5\u50BE\u50AC\u50B7\u50BB\u50AF\u50C7\u527F\u5277\u527D\u52DF\u52E6\u52E4\u52E2\u52E3\u532F\u55DF\u55E8\u55D3\u55E6\u55CE\u55DC\u55C7\u55D1\u55E3\u55E4\u55EF\u55DA\u55E1\u55C5\u55C6\u55E5\u55C9\u5712\u5713\u585E\u5851\u5858\u5857\u585A\u5854\u586B\u584C\u586D\u584A\u5862\u5852\u584B\u5967\u5AC1\u5AC9\u5ACC\u5ABE\u5ABD\u5ABC"],
      ["b740", "\u5AB3\u5AC2\u5AB2\u5D69\u5D6F\u5E4C\u5E79\u5EC9\u5EC8\u5F12\u5F59\u5FAC\u5FAE\u611A\u610F\u6148\u611F\u60F3\u611B\u60F9\u6101\u6108\u614E\u614C\u6144\u614D\u613E\u6134\u6127\u610D\u6106\u6137\u6221\u6222\u6413\u643E\u641E\u642A\u642D\u643D\u642C\u640F\u641C\u6414\u640D\u6436\u6416\u6417\u6406\u656C\u659F\u65B0\u6697\u6689\u6687\u6688\u6696\u6684\u6698\u668D\u6703\u6994\u696D"],
      ["b7a1", "\u695A\u6977\u6960\u6954\u6975\u6930\u6982\u694A\u6968\u696B\u695E\u6953\u6979\u6986\u695D\u6963\u695B\u6B47\u6B72\u6BC0\u6BBF\u6BD3\u6BFD\u6EA2\u6EAF\u6ED3\u6EB6\u6EC2\u6E90\u6E9D\u6EC7\u6EC5\u6EA5\u6E98\u6EBC\u6EBA\u6EAB\u6ED1\u6E96\u6E9C\u6EC4\u6ED4\u6EAA\u6EA7\u6EB4\u714E\u7159\u7169\u7164\u7149\u7167\u715C\u716C\u7166\u714C\u7165\u715E\u7146\u7168\u7156\u723A\u7252\u7337\u7345\u733F\u733E\u746F\u745A\u7455\u745F\u745E\u7441\u743F\u7459\u745B\u745C\u7576\u7578\u7600\u75F0\u7601\u75F2\u75F1\u75FA\u75FF\u75F4\u75F3\u76DE\u76DF\u775B\u776B\u7766\u775E\u7763"],
      ["b840", "\u7779\u776A\u776C\u775C\u7765\u7768\u7762\u77EE\u788E\u78B0\u7897\u7898\u788C\u7889\u787C\u7891\u7893\u787F\u797A\u797F\u7981\u842C\u79BD\u7A1C\u7A1A\u7A20\u7A14\u7A1F\u7A1E\u7A9F\u7AA0\u7B77\u7BC0\u7B60\u7B6E\u7B67\u7CB1\u7CB3\u7CB5\u7D93\u7D79\u7D91\u7D81\u7D8F\u7D5B\u7F6E\u7F69\u7F6A\u7F72\u7FA9\u7FA8\u7FA4\u8056\u8058\u8086\u8084\u8171\u8170\u8178\u8165\u816E\u8173\u816B"],
      ["b8a1", "\u8179\u817A\u8166\u8205\u8247\u8482\u8477\u843D\u8431\u8475\u8466\u846B\u8449\u846C\u845B\u843C\u8435\u8461\u8463\u8469\u846D\u8446\u865E\u865C\u865F\u86F9\u8713\u8708\u8707\u8700\u86FE\u86FB\u8702\u8703\u8706\u870A\u8859\u88DF\u88D4\u88D9\u88DC\u88D8\u88DD\u88E1\u88CA\u88D5\u88D2\u899C\u89E3\u8A6B\u8A72\u8A73\u8A66\u8A69\u8A70\u8A87\u8A7C\u8A63\u8AA0\u8A71\u8A85\u8A6D\u8A62\u8A6E\u8A6C\u8A79\u8A7B\u8A3E\u8A68\u8C62\u8C8A\u8C89\u8CCA\u8CC7\u8CC8\u8CC4\u8CB2\u8CC3\u8CC2\u8CC5\u8DE1\u8DDF\u8DE8\u8DEF\u8DF3\u8DFA\u8DEA\u8DE4\u8DE6\u8EB2\u8F03\u8F09\u8EFE\u8F0A"],
      ["b940", "\u8F9F\u8FB2\u904B\u904A\u9053\u9042\u9054\u903C\u9055\u9050\u9047\u904F\u904E\u904D\u9051\u903E\u9041\u9112\u9117\u916C\u916A\u9169\u91C9\u9237\u9257\u9238\u923D\u9240\u923E\u925B\u924B\u9264\u9251\u9234\u9249\u924D\u9245\u9239\u923F\u925A\u9598\u9698\u9694\u9695\u96CD\u96CB\u96C9\u96CA\u96F7\u96FB\u96F9\u96F6\u9756\u9774\u9776\u9810\u9811\u9813\u980A\u9812\u980C\u98FC\u98F4"],
      ["b9a1", "\u98FD\u98FE\u99B3\u99B1\u99B4\u9AE1\u9CE9\u9E82\u9F0E\u9F13\u9F20\u50E7\u50EE\u50E5\u50D6\u50ED\u50DA\u50D5\u50CF\u50D1\u50F1\u50CE\u50E9\u5162\u51F3\u5283\u5282\u5331\u53AD\u55FE\u5600\u561B\u5617\u55FD\u5614\u5606\u5609\u560D\u560E\u55F7\u5616\u561F\u5608\u5610\u55F6\u5718\u5716\u5875\u587E\u5883\u5893\u588A\u5879\u5885\u587D\u58FD\u5925\u5922\u5924\u596A\u5969\u5AE1\u5AE6\u5AE9\u5AD7\u5AD6\u5AD8\u5AE3\u5B75\u5BDE\u5BE7\u5BE1\u5BE5\u5BE6\u5BE8\u5BE2\u5BE4\u5BDF\u5C0D\u5C62\u5D84\u5D87\u5E5B\u5E63\u5E55\u5E57\u5E54\u5ED3\u5ED6\u5F0A\u5F46\u5F70\u5FB9\u6147"],
      ["ba40", "\u613F\u614B\u6177\u6162\u6163\u615F\u615A\u6158\u6175\u622A\u6487\u6458\u6454\u64A4\u6478\u645F\u647A\u6451\u6467\u6434\u646D\u647B\u6572\u65A1\u65D7\u65D6\u66A2\u66A8\u669D\u699C\u69A8\u6995\u69C1\u69AE\u69D3\u69CB\u699B\u69B7\u69BB\u69AB\u69B4\u69D0\u69CD\u69AD\u69CC\u69A6\u69C3\u69A3\u6B49\u6B4C\u6C33\u6F33\u6F14\u6EFE\u6F13\u6EF4\u6F29\u6F3E\u6F20\u6F2C\u6F0F\u6F02\u6F22"],
      ["baa1", "\u6EFF\u6EEF\u6F06\u6F31\u6F38\u6F32\u6F23\u6F15\u6F2B\u6F2F\u6F88\u6F2A\u6EEC\u6F01\u6EF2\u6ECC\u6EF7\u7194\u7199\u717D\u718A\u7184\u7192\u723E\u7292\u7296\u7344\u7350\u7464\u7463\u746A\u7470\u746D\u7504\u7591\u7627\u760D\u760B\u7609\u7613\u76E1\u76E3\u7784\u777D\u777F\u7761\u78C1\u789F\u78A7\u78B3\u78A9\u78A3\u798E\u798F\u798D\u7A2E\u7A31\u7AAA\u7AA9\u7AED\u7AEF\u7BA1\u7B95\u7B8B\u7B75\u7B97\u7B9D\u7B94\u7B8F\u7BB8\u7B87\u7B84\u7CB9\u7CBD\u7CBE\u7DBB\u7DB0\u7D9C\u7DBD\u7DBE\u7DA0\u7DCA\u7DB4\u7DB2\u7DB1\u7DBA\u7DA2\u7DBF\u7DB5\u7DB8\u7DAD\u7DD2\u7DC7\u7DAC"],
      ["bb40", "\u7F70\u7FE0\u7FE1\u7FDF\u805E\u805A\u8087\u8150\u8180\u818F\u8188\u818A\u817F\u8182\u81E7\u81FA\u8207\u8214\u821E\u824B\u84C9\u84BF\u84C6\u84C4\u8499\u849E\u84B2\u849C\u84CB\u84B8\u84C0\u84D3\u8490\u84BC\u84D1\u84CA\u873F\u871C\u873B\u8722\u8725\u8734\u8718\u8755\u8737\u8729\u88F3\u8902\u88F4\u88F9\u88F8\u88FD\u88E8\u891A\u88EF\u8AA6\u8A8C\u8A9E\u8AA3\u8A8D\u8AA1\u8A93\u8AA4"],
      ["bba1", "\u8AAA\u8AA5\u8AA8\u8A98\u8A91\u8A9A\u8AA7\u8C6A\u8C8D\u8C8C\u8CD3\u8CD1\u8CD2\u8D6B\u8D99\u8D95\u8DFC\u8F14\u8F12\u8F15\u8F13\u8FA3\u9060\u9058\u905C\u9063\u9059\u905E\u9062\u905D\u905B\u9119\u9118\u911E\u9175\u9178\u9177\u9174\u9278\u9280\u9285\u9298\u9296\u927B\u9293\u929C\u92A8\u927C\u9291\u95A1\u95A8\u95A9\u95A3\u95A5\u95A4\u9699\u969C\u969B\u96CC\u96D2\u9700\u977C\u9785\u97F6\u9817\u9818\u98AF\u98B1\u9903\u9905\u990C\u9909\u99C1\u9AAF\u9AB0\u9AE6\u9B41\u9B42\u9CF4\u9CF6\u9CF3\u9EBC\u9F3B\u9F4A\u5104\u5100\u50FB\u50F5\u50F9\u5102\u5108\u5109\u5105\u51DC"],
      ["bc40", "\u5287\u5288\u5289\u528D\u528A\u52F0\u53B2\u562E\u563B\u5639\u5632\u563F\u5634\u5629\u5653\u564E\u5657\u5674\u5636\u562F\u5630\u5880\u589F\u589E\u58B3\u589C\u58AE\u58A9\u58A6\u596D\u5B09\u5AFB\u5B0B\u5AF5\u5B0C\u5B08\u5BEE\u5BEC\u5BE9\u5BEB\u5C64\u5C65\u5D9D\u5D94\u5E62\u5E5F\u5E61\u5EE2\u5EDA\u5EDF\u5EDD\u5EE3\u5EE0\u5F48\u5F71\u5FB7\u5FB5\u6176\u6167\u616E\u615D\u6155\u6182"],
      ["bca1", "\u617C\u6170\u616B\u617E\u61A7\u6190\u61AB\u618E\u61AC\u619A\u61A4\u6194\u61AE\u622E\u6469\u646F\u6479\u649E\u64B2\u6488\u6490\u64B0\u64A5\u6493\u6495\u64A9\u6492\u64AE\u64AD\u64AB\u649A\u64AC\u6499\u64A2\u64B3\u6575\u6577\u6578\u66AE\u66AB\u66B4\u66B1\u6A23\u6A1F\u69E8\u6A01\u6A1E\u6A19\u69FD\u6A21\u6A13\u6A0A\u69F3\u6A02\u6A05\u69ED\u6A11\u6B50\u6B4E\u6BA4\u6BC5\u6BC6\u6F3F\u6F7C\u6F84\u6F51\u6F66\u6F54\u6F86\u6F6D\u6F5B\u6F78\u6F6E\u6F8E\u6F7A\u6F70\u6F64\u6F97\u6F58\u6ED5\u6F6F\u6F60\u6F5F\u719F\u71AC\u71B1\u71A8\u7256\u729B\u734E\u7357\u7469\u748B\u7483"],
      ["bd40", "\u747E\u7480\u757F\u7620\u7629\u761F\u7624\u7626\u7621\u7622\u769A\u76BA\u76E4\u778E\u7787\u778C\u7791\u778B\u78CB\u78C5\u78BA\u78CA\u78BE\u78D5\u78BC\u78D0\u7A3F\u7A3C\u7A40\u7A3D\u7A37\u7A3B\u7AAF\u7AAE\u7BAD\u7BB1\u7BC4\u7BB4\u7BC6\u7BC7\u7BC1\u7BA0\u7BCC\u7CCA\u7DE0\u7DF4\u7DEF\u7DFB\u7DD8\u7DEC\u7DDD\u7DE8\u7DE3\u7DDA\u7DDE\u7DE9\u7D9E\u7DD9\u7DF2\u7DF9\u7F75\u7F77\u7FAF"],
      ["bda1", "\u7FE9\u8026\u819B\u819C\u819D\u81A0\u819A\u8198\u8517\u853D\u851A\u84EE\u852C\u852D\u8513\u8511\u8523\u8521\u8514\u84EC\u8525\u84FF\u8506\u8782\u8774\u8776\u8760\u8766\u8778\u8768\u8759\u8757\u874C\u8753\u885B\u885D\u8910\u8907\u8912\u8913\u8915\u890A\u8ABC\u8AD2\u8AC7\u8AC4\u8A95\u8ACB\u8AF8\u8AB2\u8AC9\u8AC2\u8ABF\u8AB0\u8AD6\u8ACD\u8AB6\u8AB9\u8ADB\u8C4C\u8C4E\u8C6C\u8CE0\u8CDE\u8CE6\u8CE4\u8CEC\u8CED\u8CE2\u8CE3\u8CDC\u8CEA\u8CE1\u8D6D\u8D9F\u8DA3\u8E2B\u8E10\u8E1D\u8E22\u8E0F\u8E29\u8E1F\u8E21\u8E1E\u8EBA\u8F1D\u8F1B\u8F1F\u8F29\u8F26\u8F2A\u8F1C\u8F1E"],
      ["be40", "\u8F25\u9069\u906E\u9068\u906D\u9077\u9130\u912D\u9127\u9131\u9187\u9189\u918B\u9183\u92C5\u92BB\u92B7\u92EA\u92AC\u92E4\u92C1\u92B3\u92BC\u92D2\u92C7\u92F0\u92B2\u95AD\u95B1\u9704\u9706\u9707\u9709\u9760\u978D\u978B\u978F\u9821\u982B\u981C\u98B3\u990A\u9913\u9912\u9918\u99DD\u99D0\u99DF\u99DB\u99D1\u99D5\u99D2\u99D9\u9AB7\u9AEE\u9AEF\u9B27\u9B45\u9B44\u9B77\u9B6F\u9D06\u9D09"],
      ["bea1", "\u9D03\u9EA9\u9EBE\u9ECE\u58A8\u9F52\u5112\u5118\u5114\u5110\u5115\u5180\u51AA\u51DD\u5291\u5293\u52F3\u5659\u566B\u5679\u5669\u5664\u5678\u566A\u5668\u5665\u5671\u566F\u566C\u5662\u5676\u58C1\u58BE\u58C7\u58C5\u596E\u5B1D\u5B34\u5B78\u5BF0\u5C0E\u5F4A\u61B2\u6191\u61A9\u618A\u61CD\u61B6\u61BE\u61CA\u61C8\u6230\u64C5\u64C1\u64CB\u64BB\u64BC\u64DA\u64C4\u64C7\u64C2\u64CD\u64BF\u64D2\u64D4\u64BE\u6574\u66C6\u66C9\u66B9\u66C4\u66C7\u66B8\u6A3D\u6A38\u6A3A\u6A59\u6A6B\u6A58\u6A39\u6A44\u6A62\u6A61\u6A4B\u6A47\u6A35\u6A5F\u6A48\u6B59\u6B77\u6C05\u6FC2\u6FB1\u6FA1"],
      ["bf40", "\u6FC3\u6FA4\u6FC1\u6FA7\u6FB3\u6FC0\u6FB9\u6FB6\u6FA6\u6FA0\u6FB4\u71BE\u71C9\u71D0\u71D2\u71C8\u71D5\u71B9\u71CE\u71D9\u71DC\u71C3\u71C4\u7368\u749C\u74A3\u7498\u749F\u749E\u74E2\u750C\u750D\u7634\u7638\u763A\u76E7\u76E5\u77A0\u779E\u779F\u77A5\u78E8\u78DA\u78EC\u78E7\u79A6\u7A4D\u7A4E\u7A46\u7A4C\u7A4B\u7ABA\u7BD9\u7C11\u7BC9\u7BE4\u7BDB\u7BE1\u7BE9\u7BE6\u7CD5\u7CD6\u7E0A"],
      ["bfa1", "\u7E11\u7E08\u7E1B\u7E23\u7E1E\u7E1D\u7E09\u7E10\u7F79\u7FB2\u7FF0\u7FF1\u7FEE\u8028\u81B3\u81A9\u81A8\u81FB\u8208\u8258\u8259\u854A\u8559\u8548\u8568\u8569\u8543\u8549\u856D\u856A\u855E\u8783\u879F\u879E\u87A2\u878D\u8861\u892A\u8932\u8925\u892B\u8921\u89AA\u89A6\u8AE6\u8AFA\u8AEB\u8AF1\u8B00\u8ADC\u8AE7\u8AEE\u8AFE\u8B01\u8B02\u8AF7\u8AED\u8AF3\u8AF6\u8AFC\u8C6B\u8C6D\u8C93\u8CF4\u8E44\u8E31\u8E34\u8E42\u8E39\u8E35\u8F3B\u8F2F\u8F38\u8F33\u8FA8\u8FA6\u9075\u9074\u9078\u9072\u907C\u907A\u9134\u9192\u9320\u9336\u92F8\u9333\u932F\u9322\u92FC\u932B\u9304\u931A"],
      ["c040", "\u9310\u9326\u9321\u9315\u932E\u9319\u95BB\u96A7\u96A8\u96AA\u96D5\u970E\u9711\u9716\u970D\u9713\u970F\u975B\u975C\u9766\u9798\u9830\u9838\u983B\u9837\u982D\u9839\u9824\u9910\u9928\u991E\u991B\u9921\u991A\u99ED\u99E2\u99F1\u9AB8\u9ABC\u9AFB\u9AED\u9B28\u9B91\u9D15\u9D23\u9D26\u9D28\u9D12\u9D1B\u9ED8\u9ED4\u9F8D\u9F9C\u512A\u511F\u5121\u5132\u52F5\u568E\u5680\u5690\u5685\u5687"],
      ["c0a1", "\u568F\u58D5\u58D3\u58D1\u58CE\u5B30\u5B2A\u5B24\u5B7A\u5C37\u5C68\u5DBC\u5DBA\u5DBD\u5DB8\u5E6B\u5F4C\u5FBD\u61C9\u61C2\u61C7\u61E6\u61CB\u6232\u6234\u64CE\u64CA\u64D8\u64E0\u64F0\u64E6\u64EC\u64F1\u64E2\u64ED\u6582\u6583\u66D9\u66D6\u6A80\u6A94\u6A84\u6AA2\u6A9C\u6ADB\u6AA3\u6A7E\u6A97\u6A90\u6AA0\u6B5C\u6BAE\u6BDA\u6C08\u6FD8\u6FF1\u6FDF\u6FE0\u6FDB\u6FE4\u6FEB\u6FEF\u6F80\u6FEC\u6FE1\u6FE9\u6FD5\u6FEE\u6FF0\u71E7\u71DF\u71EE\u71E6\u71E5\u71ED\u71EC\u71F4\u71E0\u7235\u7246\u7370\u7372\u74A9\u74B0\u74A6\u74A8\u7646\u7642\u764C\u76EA\u77B3\u77AA\u77B0\u77AC"],
      ["c140", "\u77A7\u77AD\u77EF\u78F7\u78FA\u78F4\u78EF\u7901\u79A7\u79AA\u7A57\u7ABF\u7C07\u7C0D\u7BFE\u7BF7\u7C0C\u7BE0\u7CE0\u7CDC\u7CDE\u7CE2\u7CDF\u7CD9\u7CDD\u7E2E\u7E3E\u7E46\u7E37\u7E32\u7E43\u7E2B\u7E3D\u7E31\u7E45\u7E41\u7E34\u7E39\u7E48\u7E35\u7E3F\u7E2F\u7F44\u7FF3\u7FFC\u8071\u8072\u8070\u806F\u8073\u81C6\u81C3\u81BA\u81C2\u81C0\u81BF\u81BD\u81C9\u81BE\u81E8\u8209\u8271\u85AA"],
      ["c1a1", "\u8584\u857E\u859C\u8591\u8594\u85AF\u859B\u8587\u85A8\u858A\u8667\u87C0\u87D1\u87B3\u87D2\u87C6\u87AB\u87BB\u87BA\u87C8\u87CB\u893B\u8936\u8944\u8938\u893D\u89AC\u8B0E\u8B17\u8B19\u8B1B\u8B0A\u8B20\u8B1D\u8B04\u8B10\u8C41\u8C3F\u8C73\u8CFA\u8CFD\u8CFC\u8CF8\u8CFB\u8DA8\u8E49\u8E4B\u8E48\u8E4A\u8F44\u8F3E\u8F42\u8F45\u8F3F\u907F\u907D\u9084\u9081\u9082\u9080\u9139\u91A3\u919E\u919C\u934D\u9382\u9328\u9375\u934A\u9365\u934B\u9318\u937E\u936C\u935B\u9370\u935A\u9354\u95CA\u95CB\u95CC\u95C8\u95C6\u96B1\u96B8\u96D6\u971C\u971E\u97A0\u97D3\u9846\u98B6\u9935\u9A01"],
      ["c240", "\u99FF\u9BAE\u9BAB\u9BAA\u9BAD\u9D3B\u9D3F\u9E8B\u9ECF\u9EDE\u9EDC\u9EDD\u9EDB\u9F3E\u9F4B\u53E2\u5695\u56AE\u58D9\u58D8\u5B38\u5F5D\u61E3\u6233\u64F4\u64F2\u64FE\u6506\u64FA\u64FB\u64F7\u65B7\u66DC\u6726\u6AB3\u6AAC\u6AC3\u6ABB\u6AB8\u6AC2\u6AAE\u6AAF\u6B5F\u6B78\u6BAF\u7009\u700B\u6FFE\u7006\u6FFA\u7011\u700F\u71FB\u71FC\u71FE\u71F8\u7377\u7375\u74A7\u74BF\u7515\u7656\u7658"],
      ["c2a1", "\u7652\u77BD\u77BF\u77BB\u77BC\u790E\u79AE\u7A61\u7A62\u7A60\u7AC4\u7AC5\u7C2B\u7C27\u7C2A\u7C1E\u7C23\u7C21\u7CE7\u7E54\u7E55\u7E5E\u7E5A\u7E61\u7E52\u7E59\u7F48\u7FF9\u7FFB\u8077\u8076\u81CD\u81CF\u820A\u85CF\u85A9\u85CD\u85D0\u85C9\u85B0\u85BA\u85B9\u85A6\u87EF\u87EC\u87F2\u87E0\u8986\u89B2\u89F4\u8B28\u8B39\u8B2C\u8B2B\u8C50\u8D05\u8E59\u8E63\u8E66\u8E64\u8E5F\u8E55\u8EC0\u8F49\u8F4D\u9087\u9083\u9088\u91AB\u91AC\u91D0\u9394\u938A\u9396\u93A2\u93B3\u93AE\u93AC\u93B0\u9398\u939A\u9397\u95D4\u95D6\u95D0\u95D5\u96E2\u96DC\u96D9\u96DB\u96DE\u9724\u97A3\u97A6"],
      ["c340", "\u97AD\u97F9\u984D\u984F\u984C\u984E\u9853\u98BA\u993E\u993F\u993D\u992E\u99A5\u9A0E\u9AC1\u9B03\u9B06\u9B4F\u9B4E\u9B4D\u9BCA\u9BC9\u9BFD\u9BC8\u9BC0\u9D51\u9D5D\u9D60\u9EE0\u9F15\u9F2C\u5133\u56A5\u58DE\u58DF\u58E2\u5BF5\u9F90\u5EEC\u61F2\u61F7\u61F6\u61F5\u6500\u650F\u66E0\u66DD\u6AE5\u6ADD\u6ADA\u6AD3\u701B\u701F\u7028\u701A\u701D\u7015\u7018\u7206\u720D\u7258\u72A2\u7378"],
      ["c3a1", "\u737A\u74BD\u74CA\u74E3\u7587\u7586\u765F\u7661\u77C7\u7919\u79B1\u7A6B\u7A69\u7C3E\u7C3F\u7C38\u7C3D\u7C37\u7C40\u7E6B\u7E6D\u7E79\u7E69\u7E6A\u7F85\u7E73\u7FB6\u7FB9\u7FB8\u81D8\u85E9\u85DD\u85EA\u85D5\u85E4\u85E5\u85F7\u87FB\u8805\u880D\u87F9\u87FE\u8960\u895F\u8956\u895E\u8B41\u8B5C\u8B58\u8B49\u8B5A\u8B4E\u8B4F\u8B46\u8B59\u8D08\u8D0A\u8E7C\u8E72\u8E87\u8E76\u8E6C\u8E7A\u8E74\u8F54\u8F4E\u8FAD\u908A\u908B\u91B1\u91AE\u93E1\u93D1\u93DF\u93C3\u93C8\u93DC\u93DD\u93D6\u93E2\u93CD\u93D8\u93E4\u93D7\u93E8\u95DC\u96B4\u96E3\u972A\u9727\u9761\u97DC\u97FB\u985E"],
      ["c440", "\u9858\u985B\u98BC\u9945\u9949\u9A16\u9A19\u9B0D\u9BE8\u9BE7\u9BD6\u9BDB\u9D89\u9D61\u9D72\u9D6A\u9D6C\u9E92\u9E97\u9E93\u9EB4\u52F8\u56A8\u56B7\u56B6\u56B4\u56BC\u58E4\u5B40\u5B43\u5B7D\u5BF6\u5DC9\u61F8\u61FA\u6518\u6514\u6519\u66E6\u6727\u6AEC\u703E\u7030\u7032\u7210\u737B\u74CF\u7662\u7665\u7926\u792A\u792C\u792B\u7AC7\u7AF6\u7C4C\u7C43\u7C4D\u7CEF\u7CF0\u8FAE\u7E7D\u7E7C"],
      ["c4a1", "\u7E82\u7F4C\u8000\u81DA\u8266\u85FB\u85F9\u8611\u85FA\u8606\u860B\u8607\u860A\u8814\u8815\u8964\u89BA\u89F8\u8B70\u8B6C\u8B66\u8B6F\u8B5F\u8B6B\u8D0F\u8D0D\u8E89\u8E81\u8E85\u8E82\u91B4\u91CB\u9418\u9403\u93FD\u95E1\u9730\u98C4\u9952\u9951\u99A8\u9A2B\u9A30\u9A37\u9A35\u9C13\u9C0D\u9E79\u9EB5\u9EE8\u9F2F\u9F5F\u9F63\u9F61\u5137\u5138\u56C1\u56C0\u56C2\u5914\u5C6C\u5DCD\u61FC\u61FE\u651D\u651C\u6595\u66E9\u6AFB\u6B04\u6AFA\u6BB2\u704C\u721B\u72A7\u74D6\u74D4\u7669\u77D3\u7C50\u7E8F\u7E8C\u7FBC\u8617\u862D\u861A\u8823\u8822\u8821\u881F\u896A\u896C\u89BD\u8B74"],
      ["c540", "\u8B77\u8B7D\u8D13\u8E8A\u8E8D\u8E8B\u8F5F\u8FAF\u91BA\u942E\u9433\u9435\u943A\u9438\u9432\u942B\u95E2\u9738\u9739\u9732\u97FF\u9867\u9865\u9957\u9A45\u9A43\u9A40\u9A3E\u9ACF\u9B54\u9B51\u9C2D\u9C25\u9DAF\u9DB4\u9DC2\u9DB8\u9E9D\u9EEF\u9F19\u9F5C\u9F66\u9F67\u513C\u513B\u56C8\u56CA\u56C9\u5B7F\u5DD4\u5DD2\u5F4E\u61FF\u6524\u6B0A\u6B61\u7051\u7058\u7380\u74E4\u758A\u766E\u766C"],
      ["c5a1", "\u79B3\u7C60\u7C5F\u807E\u807D\u81DF\u8972\u896F\u89FC\u8B80\u8D16\u8D17\u8E91\u8E93\u8F61\u9148\u9444\u9451\u9452\u973D\u973E\u97C3\u97C1\u986B\u9955\u9A55\u9A4D\u9AD2\u9B1A\u9C49\u9C31\u9C3E\u9C3B\u9DD3\u9DD7\u9F34\u9F6C\u9F6A\u9F94\u56CC\u5DD6\u6200\u6523\u652B\u652A\u66EC\u6B10\u74DA\u7ACA\u7C64\u7C63\u7C65\u7E93\u7E96\u7E94\u81E2\u8638\u863F\u8831\u8B8A\u9090\u908F\u9463\u9460\u9464\u9768\u986F\u995C\u9A5A\u9A5B\u9A57\u9AD3\u9AD4\u9AD1\u9C54\u9C57\u9C56\u9DE5\u9E9F\u9EF4\u56D1\u58E9\u652C\u705E\u7671\u7672\u77D7\u7F50\u7F88\u8836\u8839\u8862\u8B93\u8B92"],
      ["c640", "\u8B96\u8277\u8D1B\u91C0\u946A\u9742\u9748\u9744\u97C6\u9870\u9A5F\u9B22\u9B58\u9C5F\u9DF9\u9DFA\u9E7C\u9E7D\u9F07\u9F77\u9F72\u5EF3\u6B16\u7063\u7C6C\u7C6E\u883B\u89C0\u8EA1\u91C1\u9472\u9470\u9871\u995E\u9AD6\u9B23\u9ECC\u7064\u77DA\u8B9A\u9477\u97C9\u9A62\u9A65\u7E9C\u8B9C\u8EAA\u91C5\u947D\u947E\u947C\u9C77\u9C78\u9EF7\u8C54\u947F\u9E1A\u7228\u9A6A\u9B31\u9E1B\u9E1E\u7C72"],
      ["c940", "\u4E42\u4E5C\u51F5\u531A\u5382\u4E07\u4E0C\u4E47\u4E8D\u56D7\uFA0C\u5C6E\u5F73\u4E0F\u5187\u4E0E\u4E2E\u4E93\u4EC2\u4EC9\u4EC8\u5198\u52FC\u536C\u53B9\u5720\u5903\u592C\u5C10\u5DFF\u65E1\u6BB3\u6BCC\u6C14\u723F\u4E31\u4E3C\u4EE8\u4EDC\u4EE9\u4EE1\u4EDD\u4EDA\u520C\u531C\u534C\u5722\u5723\u5917\u592F\u5B81\u5B84\u5C12\u5C3B\u5C74\u5C73\u5E04\u5E80\u5E82\u5FC9\u6209\u6250\u6C15"],
      ["c9a1", "\u6C36\u6C43\u6C3F\u6C3B\u72AE\u72B0\u738A\u79B8\u808A\u961E\u4F0E\u4F18\u4F2C\u4EF5\u4F14\u4EF1\u4F00\u4EF7\u4F08\u4F1D\u4F02\u4F05\u4F22\u4F13\u4F04\u4EF4\u4F12\u51B1\u5213\u5209\u5210\u52A6\u5322\u531F\u534D\u538A\u5407\u56E1\u56DF\u572E\u572A\u5734\u593C\u5980\u597C\u5985\u597B\u597E\u5977\u597F\u5B56\u5C15\u5C25\u5C7C\u5C7A\u5C7B\u5C7E\u5DDF\u5E75\u5E84\u5F02\u5F1A\u5F74\u5FD5\u5FD4\u5FCF\u625C\u625E\u6264\u6261\u6266\u6262\u6259\u6260\u625A\u6265\u65EF\u65EE\u673E\u6739\u6738\u673B\u673A\u673F\u673C\u6733\u6C18\u6C46\u6C52\u6C5C\u6C4F\u6C4A\u6C54\u6C4B"],
      ["ca40", "\u6C4C\u7071\u725E\u72B4\u72B5\u738E\u752A\u767F\u7A75\u7F51\u8278\u827C\u8280\u827D\u827F\u864D\u897E\u9099\u9097\u9098\u909B\u9094\u9622\u9624\u9620\u9623\u4F56\u4F3B\u4F62\u4F49\u4F53\u4F64\u4F3E\u4F67\u4F52\u4F5F\u4F41\u4F58\u4F2D\u4F33\u4F3F\u4F61\u518F\u51B9\u521C\u521E\u5221\u52AD\u52AE\u5309\u5363\u5372\u538E\u538F\u5430\u5437\u542A\u5454\u5445\u5419\u541C\u5425\u5418"],
      ["caa1", "\u543D\u544F\u5441\u5428\u5424\u5447\u56EE\u56E7\u56E5\u5741\u5745\u574C\u5749\u574B\u5752\u5906\u5940\u59A6\u5998\u59A0\u5997\u598E\u59A2\u5990\u598F\u59A7\u59A1\u5B8E\u5B92\u5C28\u5C2A\u5C8D\u5C8F\u5C88\u5C8B\u5C89\u5C92\u5C8A\u5C86\u5C93\u5C95\u5DE0\u5E0A\u5E0E\u5E8B\u5E89\u5E8C\u5E88\u5E8D\u5F05\u5F1D\u5F78\u5F76\u5FD2\u5FD1\u5FD0\u5FED\u5FE8\u5FEE\u5FF3\u5FE1\u5FE4\u5FE3\u5FFA\u5FEF\u5FF7\u5FFB\u6000\u5FF4\u623A\u6283\u628C\u628E\u628F\u6294\u6287\u6271\u627B\u627A\u6270\u6281\u6288\u6277\u627D\u6272\u6274\u6537\u65F0\u65F4\u65F3\u65F2\u65F5\u6745\u6747"],
      ["cb40", "\u6759\u6755\u674C\u6748\u675D\u674D\u675A\u674B\u6BD0\u6C19\u6C1A\u6C78\u6C67\u6C6B\u6C84\u6C8B\u6C8F\u6C71\u6C6F\u6C69\u6C9A\u6C6D\u6C87\u6C95\u6C9C\u6C66\u6C73\u6C65\u6C7B\u6C8E\u7074\u707A\u7263\u72BF\u72BD\u72C3\u72C6\u72C1\u72BA\u72C5\u7395\u7397\u7393\u7394\u7392\u753A\u7539\u7594\u7595\u7681\u793D\u8034\u8095\u8099\u8090\u8092\u809C\u8290\u828F\u8285\u828E\u8291\u8293"],
      ["cba1", "\u828A\u8283\u8284\u8C78\u8FC9\u8FBF\u909F\u90A1\u90A5\u909E\u90A7\u90A0\u9630\u9628\u962F\u962D\u4E33\u4F98\u4F7C\u4F85\u4F7D\u4F80\u4F87\u4F76\u4F74\u4F89\u4F84\u4F77\u4F4C\u4F97\u4F6A\u4F9A\u4F79\u4F81\u4F78\u4F90\u4F9C\u4F94\u4F9E\u4F92\u4F82\u4F95\u4F6B\u4F6E\u519E\u51BC\u51BE\u5235\u5232\u5233\u5246\u5231\u52BC\u530A\u530B\u533C\u5392\u5394\u5487\u547F\u5481\u5491\u5482\u5488\u546B\u547A\u547E\u5465\u546C\u5474\u5466\u548D\u546F\u5461\u5460\u5498\u5463\u5467\u5464\u56F7\u56F9\u576F\u5772\u576D\u576B\u5771\u5770\u5776\u5780\u5775\u577B\u5773\u5774\u5762"],
      ["cc40", "\u5768\u577D\u590C\u5945\u59B5\u59BA\u59CF\u59CE\u59B2\u59CC\u59C1\u59B6\u59BC\u59C3\u59D6\u59B1\u59BD\u59C0\u59C8\u59B4\u59C7\u5B62\u5B65\u5B93\u5B95\u5C44\u5C47\u5CAE\u5CA4\u5CA0\u5CB5\u5CAF\u5CA8\u5CAC\u5C9F\u5CA3\u5CAD\u5CA2\u5CAA\u5CA7\u5C9D\u5CA5\u5CB6\u5CB0\u5CA6\u5E17\u5E14\u5E19\u5F28\u5F22\u5F23\u5F24\u5F54\u5F82\u5F7E\u5F7D\u5FDE\u5FE5\u602D\u6026\u6019\u6032\u600B"],
      ["cca1", "\u6034\u600A\u6017\u6033\u601A\u601E\u602C\u6022\u600D\u6010\u602E\u6013\u6011\u600C\u6009\u601C\u6214\u623D\u62AD\u62B4\u62D1\u62BE\u62AA\u62B6\u62CA\u62AE\u62B3\u62AF\u62BB\u62A9\u62B0\u62B8\u653D\u65A8\u65BB\u6609\u65FC\u6604\u6612\u6608\u65FB\u6603\u660B\u660D\u6605\u65FD\u6611\u6610\u66F6\u670A\u6785\u676C\u678E\u6792\u6776\u677B\u6798\u6786\u6784\u6774\u678D\u678C\u677A\u679F\u6791\u6799\u6783\u677D\u6781\u6778\u6779\u6794\u6B25\u6B80\u6B7E\u6BDE\u6C1D\u6C93\u6CEC\u6CEB\u6CEE\u6CD9\u6CB6\u6CD4\u6CAD\u6CE7\u6CB7\u6CD0\u6CC2\u6CBA\u6CC3\u6CC6\u6CED\u6CF2"],
      ["cd40", "\u6CD2\u6CDD\u6CB4\u6C8A\u6C9D\u6C80\u6CDE\u6CC0\u6D30\u6CCD\u6CC7\u6CB0\u6CF9\u6CCF\u6CE9\u6CD1\u7094\u7098\u7085\u7093\u7086\u7084\u7091\u7096\u7082\u709A\u7083\u726A\u72D6\u72CB\u72D8\u72C9\u72DC\u72D2\u72D4\u72DA\u72CC\u72D1\u73A4\u73A1\u73AD\u73A6\u73A2\u73A0\u73AC\u739D\u74DD\u74E8\u753F\u7540\u753E\u758C\u7598\u76AF\u76F3\u76F1\u76F0\u76F5\u77F8\u77FC\u77F9\u77FB\u77FA"],
      ["cda1", "\u77F7\u7942\u793F\u79C5\u7A78\u7A7B\u7AFB\u7C75\u7CFD\u8035\u808F\u80AE\u80A3\u80B8\u80B5\u80AD\u8220\u82A0\u82C0\u82AB\u829A\u8298\u829B\u82B5\u82A7\u82AE\u82BC\u829E\u82BA\u82B4\u82A8\u82A1\u82A9\u82C2\u82A4\u82C3\u82B6\u82A2\u8670\u866F\u866D\u866E\u8C56\u8FD2\u8FCB\u8FD3\u8FCD\u8FD6\u8FD5\u8FD7\u90B2\u90B4\u90AF\u90B3\u90B0\u9639\u963D\u963C\u963A\u9643\u4FCD\u4FC5\u4FD3\u4FB2\u4FC9\u4FCB\u4FC1\u4FD4\u4FDC\u4FD9\u4FBB\u4FB3\u4FDB\u4FC7\u4FD6\u4FBA\u4FC0\u4FB9\u4FEC\u5244\u5249\u52C0\u52C2\u533D\u537C\u5397\u5396\u5399\u5398\u54BA\u54A1\u54AD\u54A5\u54CF"],
      ["ce40", "\u54C3\u830D\u54B7\u54AE\u54D6\u54B6\u54C5\u54C6\u54A0\u5470\u54BC\u54A2\u54BE\u5472\u54DE\u54B0\u57B5\u579E\u579F\u57A4\u578C\u5797\u579D\u579B\u5794\u5798\u578F\u5799\u57A5\u579A\u5795\u58F4\u590D\u5953\u59E1\u59DE\u59EE\u5A00\u59F1\u59DD\u59FA\u59FD\u59FC\u59F6\u59E4\u59F2\u59F7\u59DB\u59E9\u59F3\u59F5\u59E0\u59FE\u59F4\u59ED\u5BA8\u5C4C\u5CD0\u5CD8\u5CCC\u5CD7\u5CCB\u5CDB"],
      ["cea1", "\u5CDE\u5CDA\u5CC9\u5CC7\u5CCA\u5CD6\u5CD3\u5CD4\u5CCF\u5CC8\u5CC6\u5CCE\u5CDF\u5CF8\u5DF9\u5E21\u5E22\u5E23\u5E20\u5E24\u5EB0\u5EA4\u5EA2\u5E9B\u5EA3\u5EA5\u5F07\u5F2E\u5F56\u5F86\u6037\u6039\u6054\u6072\u605E\u6045\u6053\u6047\u6049\u605B\u604C\u6040\u6042\u605F\u6024\u6044\u6058\u6066\u606E\u6242\u6243\u62CF\u630D\u630B\u62F5\u630E\u6303\u62EB\u62F9\u630F\u630C\u62F8\u62F6\u6300\u6313\u6314\u62FA\u6315\u62FB\u62F0\u6541\u6543\u65AA\u65BF\u6636\u6621\u6632\u6635\u661C\u6626\u6622\u6633\u662B\u663A\u661D\u6634\u6639\u662E\u670F\u6710\u67C1\u67F2\u67C8\u67BA"],
      ["cf40", "\u67DC\u67BB\u67F8\u67D8\u67C0\u67B7\u67C5\u67EB\u67E4\u67DF\u67B5\u67CD\u67B3\u67F7\u67F6\u67EE\u67E3\u67C2\u67B9\u67CE\u67E7\u67F0\u67B2\u67FC\u67C6\u67ED\u67CC\u67AE\u67E6\u67DB\u67FA\u67C9\u67CA\u67C3\u67EA\u67CB\u6B28\u6B82\u6B84\u6BB6\u6BD6\u6BD8\u6BE0\u6C20\u6C21\u6D28\u6D34\u6D2D\u6D1F\u6D3C\u6D3F\u6D12\u6D0A\u6CDA\u6D33\u6D04\u6D19\u6D3A\u6D1A\u6D11\u6D00\u6D1D\u6D42"],
      ["cfa1", "\u6D01\u6D18\u6D37\u6D03\u6D0F\u6D40\u6D07\u6D20\u6D2C\u6D08\u6D22\u6D09\u6D10\u70B7\u709F\u70BE\u70B1\u70B0\u70A1\u70B4\u70B5\u70A9\u7241\u7249\u724A\u726C\u7270\u7273\u726E\u72CA\u72E4\u72E8\u72EB\u72DF\u72EA\u72E6\u72E3\u7385\u73CC\u73C2\u73C8\u73C5\u73B9\u73B6\u73B5\u73B4\u73EB\u73BF\u73C7\u73BE\u73C3\u73C6\u73B8\u73CB\u74EC\u74EE\u752E\u7547\u7548\u75A7\u75AA\u7679\u76C4\u7708\u7703\u7704\u7705\u770A\u76F7\u76FB\u76FA\u77E7\u77E8\u7806\u7811\u7812\u7805\u7810\u780F\u780E\u7809\u7803\u7813\u794A\u794C\u794B\u7945\u7944\u79D5\u79CD\u79CF\u79D6\u79CE\u7A80"],
      ["d040", "\u7A7E\u7AD1\u7B00\u7B01\u7C7A\u7C78\u7C79\u7C7F\u7C80\u7C81\u7D03\u7D08\u7D01\u7F58\u7F91\u7F8D\u7FBE\u8007\u800E\u800F\u8014\u8037\u80D8\u80C7\u80E0\u80D1\u80C8\u80C2\u80D0\u80C5\u80E3\u80D9\u80DC\u80CA\u80D5\u80C9\u80CF\u80D7\u80E6\u80CD\u81FF\u8221\u8294\u82D9\u82FE\u82F9\u8307\u82E8\u8300\u82D5\u833A\u82EB\u82D6\u82F4\u82EC\u82E1\u82F2\u82F5\u830C\u82FB\u82F6\u82F0\u82EA"],
      ["d0a1", "\u82E4\u82E0\u82FA\u82F3\u82ED\u8677\u8674\u867C\u8673\u8841\u884E\u8867\u886A\u8869\u89D3\u8A04\u8A07\u8D72\u8FE3\u8FE1\u8FEE\u8FE0\u90F1\u90BD\u90BF\u90D5\u90C5\u90BE\u90C7\u90CB\u90C8\u91D4\u91D3\u9654\u964F\u9651\u9653\u964A\u964E\u501E\u5005\u5007\u5013\u5022\u5030\u501B\u4FF5\u4FF4\u5033\u5037\u502C\u4FF6\u4FF7\u5017\u501C\u5020\u5027\u5035\u502F\u5031\u500E\u515A\u5194\u5193\u51CA\u51C4\u51C5\u51C8\u51CE\u5261\u525A\u5252\u525E\u525F\u5255\u5262\u52CD\u530E\u539E\u5526\u54E2\u5517\u5512\u54E7\u54F3\u54E4\u551A\u54FF\u5504\u5508\u54EB\u5511\u5505\u54F1"],
      ["d140", "\u550A\u54FB\u54F7\u54F8\u54E0\u550E\u5503\u550B\u5701\u5702\u57CC\u5832\u57D5\u57D2\u57BA\u57C6\u57BD\u57BC\u57B8\u57B6\u57BF\u57C7\u57D0\u57B9\u57C1\u590E\u594A\u5A19\u5A16\u5A2D\u5A2E\u5A15\u5A0F\u5A17\u5A0A\u5A1E\u5A33\u5B6C\u5BA7\u5BAD\u5BAC\u5C03\u5C56\u5C54\u5CEC\u5CFF\u5CEE\u5CF1\u5CF7\u5D00\u5CF9\u5E29\u5E28\u5EA8\u5EAE\u5EAA\u5EAC\u5F33\u5F30\u5F67\u605D\u605A\u6067"],
      ["d1a1", "\u6041\u60A2\u6088\u6080\u6092\u6081\u609D\u6083\u6095\u609B\u6097\u6087\u609C\u608E\u6219\u6246\u62F2\u6310\u6356\u632C\u6344\u6345\u6336\u6343\u63E4\u6339\u634B\u634A\u633C\u6329\u6341\u6334\u6358\u6354\u6359\u632D\u6347\u6333\u635A\u6351\u6338\u6357\u6340\u6348\u654A\u6546\u65C6\u65C3\u65C4\u65C2\u664A\u665F\u6647\u6651\u6712\u6713\u681F\u681A\u6849\u6832\u6833\u683B\u684B\u684F\u6816\u6831\u681C\u6835\u682B\u682D\u682F\u684E\u6844\u6834\u681D\u6812\u6814\u6826\u6828\u682E\u684D\u683A\u6825\u6820\u6B2C\u6B2F\u6B2D\u6B31\u6B34\u6B6D\u8082\u6B88\u6BE6\u6BE4"],
      ["d240", "\u6BE8\u6BE3\u6BE2\u6BE7\u6C25\u6D7A\u6D63\u6D64\u6D76\u6D0D\u6D61\u6D92\u6D58\u6D62\u6D6D\u6D6F\u6D91\u6D8D\u6DEF\u6D7F\u6D86\u6D5E\u6D67\u6D60\u6D97\u6D70\u6D7C\u6D5F\u6D82\u6D98\u6D2F\u6D68\u6D8B\u6D7E\u6D80\u6D84\u6D16\u6D83\u6D7B\u6D7D\u6D75\u6D90\u70DC\u70D3\u70D1\u70DD\u70CB\u7F39\u70E2\u70D7\u70D2\u70DE\u70E0\u70D4\u70CD\u70C5\u70C6\u70C7\u70DA\u70CE\u70E1\u7242\u7278"],
      ["d2a1", "\u7277\u7276\u7300\u72FA\u72F4\u72FE\u72F6\u72F3\u72FB\u7301\u73D3\u73D9\u73E5\u73D6\u73BC\u73E7\u73E3\u73E9\u73DC\u73D2\u73DB\u73D4\u73DD\u73DA\u73D7\u73D8\u73E8\u74DE\u74DF\u74F4\u74F5\u7521\u755B\u755F\u75B0\u75C1\u75BB\u75C4\u75C0\u75BF\u75B6\u75BA\u768A\u76C9\u771D\u771B\u7710\u7713\u7712\u7723\u7711\u7715\u7719\u771A\u7722\u7727\u7823\u782C\u7822\u7835\u782F\u7828\u782E\u782B\u7821\u7829\u7833\u782A\u7831\u7954\u795B\u794F\u795C\u7953\u7952\u7951\u79EB\u79EC\u79E0\u79EE\u79ED\u79EA\u79DC\u79DE\u79DD\u7A86\u7A89\u7A85\u7A8B\u7A8C\u7A8A\u7A87\u7AD8\u7B10"],
      ["d340", "\u7B04\u7B13\u7B05\u7B0F\u7B08\u7B0A\u7B0E\u7B09\u7B12\u7C84\u7C91\u7C8A\u7C8C\u7C88\u7C8D\u7C85\u7D1E\u7D1D\u7D11\u7D0E\u7D18\u7D16\u7D13\u7D1F\u7D12\u7D0F\u7D0C\u7F5C\u7F61\u7F5E\u7F60\u7F5D\u7F5B\u7F96\u7F92\u7FC3\u7FC2\u7FC0\u8016\u803E\u8039\u80FA\u80F2\u80F9\u80F5\u8101\u80FB\u8100\u8201\u822F\u8225\u8333\u832D\u8344\u8319\u8351\u8325\u8356\u833F\u8341\u8326\u831C\u8322"],
      ["d3a1", "\u8342\u834E\u831B\u832A\u8308\u833C\u834D\u8316\u8324\u8320\u8337\u832F\u8329\u8347\u8345\u834C\u8353\u831E\u832C\u834B\u8327\u8348\u8653\u8652\u86A2\u86A8\u8696\u868D\u8691\u869E\u8687\u8697\u8686\u868B\u869A\u8685\u86A5\u8699\u86A1\u86A7\u8695\u8698\u868E\u869D\u8690\u8694\u8843\u8844\u886D\u8875\u8876\u8872\u8880\u8871\u887F\u886F\u8883\u887E\u8874\u887C\u8A12\u8C47\u8C57\u8C7B\u8CA4\u8CA3\u8D76\u8D78\u8DB5\u8DB7\u8DB6\u8ED1\u8ED3\u8FFE\u8FF5\u9002\u8FFF\u8FFB\u9004\u8FFC\u8FF6\u90D6\u90E0\u90D9\u90DA\u90E3\u90DF\u90E5\u90D8\u90DB\u90D7\u90DC\u90E4\u9150"],
      ["d440", "\u914E\u914F\u91D5\u91E2\u91DA\u965C\u965F\u96BC\u98E3\u9ADF\u9B2F\u4E7F\u5070\u506A\u5061\u505E\u5060\u5053\u504B\u505D\u5072\u5048\u504D\u5041\u505B\u504A\u5062\u5015\u5045\u505F\u5069\u506B\u5063\u5064\u5046\u5040\u506E\u5073\u5057\u5051\u51D0\u526B\u526D\u526C\u526E\u52D6\u52D3\u532D\u539C\u5575\u5576\u553C\u554D\u5550\u5534\u552A\u5551\u5562\u5536\u5535\u5530\u5552\u5545"],
      ["d4a1", "\u550C\u5532\u5565\u554E\u5539\u5548\u552D\u553B\u5540\u554B\u570A\u5707\u57FB\u5814\u57E2\u57F6\u57DC\u57F4\u5800\u57ED\u57FD\u5808\u57F8\u580B\u57F3\u57CF\u5807\u57EE\u57E3\u57F2\u57E5\u57EC\u57E1\u580E\u57FC\u5810\u57E7\u5801\u580C\u57F1\u57E9\u57F0\u580D\u5804\u595C\u5A60\u5A58\u5A55\u5A67\u5A5E\u5A38\u5A35\u5A6D\u5A50\u5A5F\u5A65\u5A6C\u5A53\u5A64\u5A57\u5A43\u5A5D\u5A52\u5A44\u5A5B\u5A48\u5A8E\u5A3E\u5A4D\u5A39\u5A4C\u5A70\u5A69\u5A47\u5A51\u5A56\u5A42\u5A5C\u5B72\u5B6E\u5BC1\u5BC0\u5C59\u5D1E\u5D0B\u5D1D\u5D1A\u5D20\u5D0C\u5D28\u5D0D\u5D26\u5D25\u5D0F"],
      ["d540", "\u5D30\u5D12\u5D23\u5D1F\u5D2E\u5E3E\u5E34\u5EB1\u5EB4\u5EB9\u5EB2\u5EB3\u5F36\u5F38\u5F9B\u5F96\u5F9F\u608A\u6090\u6086\u60BE\u60B0\u60BA\u60D3\u60D4\u60CF\u60E4\u60D9\u60DD\u60C8\u60B1\u60DB\u60B7\u60CA\u60BF\u60C3\u60CD\u60C0\u6332\u6365\u638A\u6382\u637D\u63BD\u639E\u63AD\u639D\u6397\u63AB\u638E\u636F\u6387\u6390\u636E\u63AF\u6375\u639C\u636D\u63AE\u637C\u63A4\u633B\u639F"],
      ["d5a1", "\u6378\u6385\u6381\u6391\u638D\u6370\u6553\u65CD\u6665\u6661\u665B\u6659\u665C\u6662\u6718\u6879\u6887\u6890\u689C\u686D\u686E\u68AE\u68AB\u6956\u686F\u68A3\u68AC\u68A9\u6875\u6874\u68B2\u688F\u6877\u6892\u687C\u686B\u6872\u68AA\u6880\u6871\u687E\u689B\u6896\u688B\u68A0\u6889\u68A4\u6878\u687B\u6891\u688C\u688A\u687D\u6B36\u6B33\u6B37\u6B38\u6B91\u6B8F\u6B8D\u6B8E\u6B8C\u6C2A\u6DC0\u6DAB\u6DB4\u6DB3\u6E74\u6DAC\u6DE9\u6DE2\u6DB7\u6DF6\u6DD4\u6E00\u6DC8\u6DE0\u6DDF\u6DD6\u6DBE\u6DE5\u6DDC\u6DDD\u6DDB\u6DF4\u6DCA\u6DBD\u6DED\u6DF0\u6DBA\u6DD5\u6DC2\u6DCF\u6DC9"],
      ["d640", "\u6DD0\u6DF2\u6DD3\u6DFD\u6DD7\u6DCD\u6DE3\u6DBB\u70FA\u710D\u70F7\u7117\u70F4\u710C\u70F0\u7104\u70F3\u7110\u70FC\u70FF\u7106\u7113\u7100\u70F8\u70F6\u710B\u7102\u710E\u727E\u727B\u727C\u727F\u731D\u7317\u7307\u7311\u7318\u730A\u7308\u72FF\u730F\u731E\u7388\u73F6\u73F8\u73F5\u7404\u7401\u73FD\u7407\u7400\u73FA\u73FC\u73FF\u740C\u740B\u73F4\u7408\u7564\u7563\u75CE\u75D2\u75CF"],
      ["d6a1", "\u75CB\u75CC\u75D1\u75D0\u768F\u7689\u76D3\u7739\u772F\u772D\u7731\u7732\u7734\u7733\u773D\u7725\u773B\u7735\u7848\u7852\u7849\u784D\u784A\u784C\u7826\u7845\u7850\u7964\u7967\u7969\u796A\u7963\u796B\u7961\u79BB\u79FA\u79F8\u79F6\u79F7\u7A8F\u7A94\u7A90\u7B35\u7B47\u7B34\u7B25\u7B30\u7B22\u7B24\u7B33\u7B18\u7B2A\u7B1D\u7B31\u7B2B\u7B2D\u7B2F\u7B32\u7B38\u7B1A\u7B23\u7C94\u7C98\u7C96\u7CA3\u7D35\u7D3D\u7D38\u7D36\u7D3A\u7D45\u7D2C\u7D29\u7D41\u7D47\u7D3E\u7D3F\u7D4A\u7D3B\u7D28\u7F63\u7F95\u7F9C\u7F9D\u7F9B\u7FCA\u7FCB\u7FCD\u7FD0\u7FD1\u7FC7\u7FCF\u7FC9\u801F"],
      ["d740", "\u801E\u801B\u8047\u8043\u8048\u8118\u8125\u8119\u811B\u812D\u811F\u812C\u811E\u8121\u8115\u8127\u811D\u8122\u8211\u8238\u8233\u823A\u8234\u8232\u8274\u8390\u83A3\u83A8\u838D\u837A\u8373\u83A4\u8374\u838F\u8381\u8395\u8399\u8375\u8394\u83A9\u837D\u8383\u838C\u839D\u839B\u83AA\u838B\u837E\u83A5\u83AF\u8388\u8397\u83B0\u837F\u83A6\u8387\u83AE\u8376\u839A\u8659\u8656\u86BF\u86B7"],
      ["d7a1", "\u86C2\u86C1\u86C5\u86BA\u86B0\u86C8\u86B9\u86B3\u86B8\u86CC\u86B4\u86BB\u86BC\u86C3\u86BD\u86BE\u8852\u8889\u8895\u88A8\u88A2\u88AA\u889A\u8891\u88A1\u889F\u8898\u88A7\u8899\u889B\u8897\u88A4\u88AC\u888C\u8893\u888E\u8982\u89D6\u89D9\u89D5\u8A30\u8A27\u8A2C\u8A1E\u8C39\u8C3B\u8C5C\u8C5D\u8C7D\u8CA5\u8D7D\u8D7B\u8D79\u8DBC\u8DC2\u8DB9\u8DBF\u8DC1\u8ED8\u8EDE\u8EDD\u8EDC\u8ED7\u8EE0\u8EE1\u9024\u900B\u9011\u901C\u900C\u9021\u90EF\u90EA\u90F0\u90F4\u90F2\u90F3\u90D4\u90EB\u90EC\u90E9\u9156\u9158\u915A\u9153\u9155\u91EC\u91F4\u91F1\u91F3\u91F8\u91E4\u91F9\u91EA"],
      ["d840", "\u91EB\u91F7\u91E8\u91EE\u957A\u9586\u9588\u967C\u966D\u966B\u9671\u966F\u96BF\u976A\u9804\u98E5\u9997\u509B\u5095\u5094\u509E\u508B\u50A3\u5083\u508C\u508E\u509D\u5068\u509C\u5092\u5082\u5087\u515F\u51D4\u5312\u5311\u53A4\u53A7\u5591\u55A8\u55A5\u55AD\u5577\u5645\u55A2\u5593\u5588\u558F\u55B5\u5581\u55A3\u5592\u55A4\u557D\u558C\u55A6\u557F\u5595\u55A1\u558E\u570C\u5829\u5837"],
      ["d8a1", "\u5819\u581E\u5827\u5823\u5828\u57F5\u5848\u5825\u581C\u581B\u5833\u583F\u5836\u582E\u5839\u5838\u582D\u582C\u583B\u5961\u5AAF\u5A94\u5A9F\u5A7A\u5AA2\u5A9E\u5A78\u5AA6\u5A7C\u5AA5\u5AAC\u5A95\u5AAE\u5A37\u5A84\u5A8A\u5A97\u5A83\u5A8B\u5AA9\u5A7B\u5A7D\u5A8C\u5A9C\u5A8F\u5A93\u5A9D\u5BEA\u5BCD\u5BCB\u5BD4\u5BD1\u5BCA\u5BCE\u5C0C\u5C30\u5D37\u5D43\u5D6B\u5D41\u5D4B\u5D3F\u5D35\u5D51\u5D4E\u5D55\u5D33\u5D3A\u5D52\u5D3D\u5D31\u5D59\u5D42\u5D39\u5D49\u5D38\u5D3C\u5D32\u5D36\u5D40\u5D45\u5E44\u5E41\u5F58\u5FA6\u5FA5\u5FAB\u60C9\u60B9\u60CC\u60E2\u60CE\u60C4\u6114"],
      ["d940", "\u60F2\u610A\u6116\u6105\u60F5\u6113\u60F8\u60FC\u60FE\u60C1\u6103\u6118\u611D\u6110\u60FF\u6104\u610B\u624A\u6394\u63B1\u63B0\u63CE\u63E5\u63E8\u63EF\u63C3\u649D\u63F3\u63CA\u63E0\u63F6\u63D5\u63F2\u63F5\u6461\u63DF\u63BE\u63DD\u63DC\u63C4\u63D8\u63D3\u63C2\u63C7\u63CC\u63CB\u63C8\u63F0\u63D7\u63D9\u6532\u6567\u656A\u6564\u655C\u6568\u6565\u658C\u659D\u659E\u65AE\u65D0\u65D2"],
      ["d9a1", "\u667C\u666C\u667B\u6680\u6671\u6679\u666A\u6672\u6701\u690C\u68D3\u6904\u68DC\u692A\u68EC\u68EA\u68F1\u690F\u68D6\u68F7\u68EB\u68E4\u68F6\u6913\u6910\u68F3\u68E1\u6907\u68CC\u6908\u6970\u68B4\u6911\u68EF\u68C6\u6914\u68F8\u68D0\u68FD\u68FC\u68E8\u690B\u690A\u6917\u68CE\u68C8\u68DD\u68DE\u68E6\u68F4\u68D1\u6906\u68D4\u68E9\u6915\u6925\u68C7\u6B39\u6B3B\u6B3F\u6B3C\u6B94\u6B97\u6B99\u6B95\u6BBD\u6BF0\u6BF2\u6BF3\u6C30\u6DFC\u6E46\u6E47\u6E1F\u6E49\u6E88\u6E3C\u6E3D\u6E45\u6E62\u6E2B\u6E3F\u6E41\u6E5D\u6E73\u6E1C\u6E33\u6E4B\u6E40\u6E51\u6E3B\u6E03\u6E2E\u6E5E"],
      ["da40", "\u6E68\u6E5C\u6E61\u6E31\u6E28\u6E60\u6E71\u6E6B\u6E39\u6E22\u6E30\u6E53\u6E65\u6E27\u6E78\u6E64\u6E77\u6E55\u6E79\u6E52\u6E66\u6E35\u6E36\u6E5A\u7120\u711E\u712F\u70FB\u712E\u7131\u7123\u7125\u7122\u7132\u711F\u7128\u713A\u711B\u724B\u725A\u7288\u7289\u7286\u7285\u728B\u7312\u730B\u7330\u7322\u7331\u7333\u7327\u7332\u732D\u7326\u7323\u7335\u730C\u742E\u742C\u7430\u742B\u7416"],
      ["daa1", "\u741A\u7421\u742D\u7431\u7424\u7423\u741D\u7429\u7420\u7432\u74FB\u752F\u756F\u756C\u75E7\u75DA\u75E1\u75E6\u75DD\u75DF\u75E4\u75D7\u7695\u7692\u76DA\u7746\u7747\u7744\u774D\u7745\u774A\u774E\u774B\u774C\u77DE\u77EC\u7860\u7864\u7865\u785C\u786D\u7871\u786A\u786E\u7870\u7869\u7868\u785E\u7862\u7974\u7973\u7972\u7970\u7A02\u7A0A\u7A03\u7A0C\u7A04\u7A99\u7AE6\u7AE4\u7B4A\u7B3B\u7B44\u7B48\u7B4C\u7B4E\u7B40\u7B58\u7B45\u7CA2\u7C9E\u7CA8\u7CA1\u7D58\u7D6F\u7D63\u7D53\u7D56\u7D67\u7D6A\u7D4F\u7D6D\u7D5C\u7D6B\u7D52\u7D54\u7D69\u7D51\u7D5F\u7D4E\u7F3E\u7F3F\u7F65"],
      ["db40", "\u7F66\u7FA2\u7FA0\u7FA1\u7FD7\u8051\u804F\u8050\u80FE\u80D4\u8143\u814A\u8152\u814F\u8147\u813D\u814D\u813A\u81E6\u81EE\u81F7\u81F8\u81F9\u8204\u823C\u823D\u823F\u8275\u833B\u83CF\u83F9\u8423\u83C0\u83E8\u8412\u83E7\u83E4\u83FC\u83F6\u8410\u83C6\u83C8\u83EB\u83E3\u83BF\u8401\u83DD\u83E5\u83D8\u83FF\u83E1\u83CB\u83CE\u83D6\u83F5\u83C9\u8409\u840F\u83DE\u8411\u8406\u83C2\u83F3"],
      ["dba1", "\u83D5\u83FA\u83C7\u83D1\u83EA\u8413\u83C3\u83EC\u83EE\u83C4\u83FB\u83D7\u83E2\u841B\u83DB\u83FE\u86D8\u86E2\u86E6\u86D3\u86E3\u86DA\u86EA\u86DD\u86EB\u86DC\u86EC\u86E9\u86D7\u86E8\u86D1\u8848\u8856\u8855\u88BA\u88D7\u88B9\u88B8\u88C0\u88BE\u88B6\u88BC\u88B7\u88BD\u88B2\u8901\u88C9\u8995\u8998\u8997\u89DD\u89DA\u89DB\u8A4E\u8A4D\u8A39\u8A59\u8A40\u8A57\u8A58\u8A44\u8A45\u8A52\u8A48\u8A51\u8A4A\u8A4C\u8A4F\u8C5F\u8C81\u8C80\u8CBA\u8CBE\u8CB0\u8CB9\u8CB5\u8D84\u8D80\u8D89\u8DD8\u8DD3\u8DCD\u8DC7\u8DD6\u8DDC\u8DCF\u8DD5\u8DD9\u8DC8\u8DD7\u8DC5\u8EEF\u8EF7\u8EFA"],
      ["dc40", "\u8EF9\u8EE6\u8EEE\u8EE5\u8EF5\u8EE7\u8EE8\u8EF6\u8EEB\u8EF1\u8EEC\u8EF4\u8EE9\u902D\u9034\u902F\u9106\u912C\u9104\u90FF\u90FC\u9108\u90F9\u90FB\u9101\u9100\u9107\u9105\u9103\u9161\u9164\u915F\u9162\u9160\u9201\u920A\u9225\u9203\u921A\u9226\u920F\u920C\u9200\u9212\u91FF\u91FD\u9206\u9204\u9227\u9202\u921C\u9224\u9219\u9217\u9205\u9216\u957B\u958D\u958C\u9590\u9687\u967E\u9688"],
      ["dca1", "\u9689\u9683\u9680\u96C2\u96C8\u96C3\u96F1\u96F0\u976C\u9770\u976E\u9807\u98A9\u98EB\u9CE6\u9EF9\u4E83\u4E84\u4EB6\u50BD\u50BF\u50C6\u50AE\u50C4\u50CA\u50B4\u50C8\u50C2\u50B0\u50C1\u50BA\u50B1\u50CB\u50C9\u50B6\u50B8\u51D7\u527A\u5278\u527B\u527C\u55C3\u55DB\u55CC\u55D0\u55CB\u55CA\u55DD\u55C0\u55D4\u55C4\u55E9\u55BF\u55D2\u558D\u55CF\u55D5\u55E2\u55D6\u55C8\u55F2\u55CD\u55D9\u55C2\u5714\u5853\u5868\u5864\u584F\u584D\u5849\u586F\u5855\u584E\u585D\u5859\u5865\u585B\u583D\u5863\u5871\u58FC\u5AC7\u5AC4\u5ACB\u5ABA\u5AB8\u5AB1\u5AB5\u5AB0\u5ABF\u5AC8\u5ABB\u5AC6"],
      ["dd40", "\u5AB7\u5AC0\u5ACA\u5AB4\u5AB6\u5ACD\u5AB9\u5A90\u5BD6\u5BD8\u5BD9\u5C1F\u5C33\u5D71\u5D63\u5D4A\u5D65\u5D72\u5D6C\u5D5E\u5D68\u5D67\u5D62\u5DF0\u5E4F\u5E4E\u5E4A\u5E4D\u5E4B\u5EC5\u5ECC\u5EC6\u5ECB\u5EC7\u5F40\u5FAF\u5FAD\u60F7\u6149\u614A\u612B\u6145\u6136\u6132\u612E\u6146\u612F\u614F\u6129\u6140\u6220\u9168\u6223\u6225\u6224\u63C5\u63F1\u63EB\u6410\u6412\u6409\u6420\u6424"],
      ["dda1", "\u6433\u6443\u641F\u6415\u6418\u6439\u6437\u6422\u6423\u640C\u6426\u6430\u6428\u6441\u6435\u642F\u640A\u641A\u6440\u6425\u6427\u640B\u63E7\u641B\u642E\u6421\u640E\u656F\u6592\u65D3\u6686\u668C\u6695\u6690\u668B\u668A\u6699\u6694\u6678\u6720\u6966\u695F\u6938\u694E\u6962\u6971\u693F\u6945\u696A\u6939\u6942\u6957\u6959\u697A\u6948\u6949\u6935\u696C\u6933\u693D\u6965\u68F0\u6978\u6934\u6969\u6940\u696F\u6944\u6976\u6958\u6941\u6974\u694C\u693B\u694B\u6937\u695C\u694F\u6951\u6932\u6952\u692F\u697B\u693C\u6B46\u6B45\u6B43\u6B42\u6B48\u6B41\u6B9B\uFA0D\u6BFB\u6BFC"],
      ["de40", "\u6BF9\u6BF7\u6BF8\u6E9B\u6ED6\u6EC8\u6E8F\u6EC0\u6E9F\u6E93\u6E94\u6EA0\u6EB1\u6EB9\u6EC6\u6ED2\u6EBD\u6EC1\u6E9E\u6EC9\u6EB7\u6EB0\u6ECD\u6EA6\u6ECF\u6EB2\u6EBE\u6EC3\u6EDC\u6ED8\u6E99\u6E92\u6E8E\u6E8D\u6EA4\u6EA1\u6EBF\u6EB3\u6ED0\u6ECA\u6E97\u6EAE\u6EA3\u7147\u7154\u7152\u7163\u7160\u7141\u715D\u7162\u7172\u7178\u716A\u7161\u7142\u7158\u7143\u714B\u7170\u715F\u7150\u7153"],
      ["dea1", "\u7144\u714D\u715A\u724F\u728D\u728C\u7291\u7290\u728E\u733C\u7342\u733B\u733A\u7340\u734A\u7349\u7444\u744A\u744B\u7452\u7451\u7457\u7440\u744F\u7450\u744E\u7442\u7446\u744D\u7454\u74E1\u74FF\u74FE\u74FD\u751D\u7579\u7577\u6983\u75EF\u760F\u7603\u75F7\u75FE\u75FC\u75F9\u75F8\u7610\u75FB\u75F6\u75ED\u75F5\u75FD\u7699\u76B5\u76DD\u7755\u775F\u7760\u7752\u7756\u775A\u7769\u7767\u7754\u7759\u776D\u77E0\u7887\u789A\u7894\u788F\u7884\u7895\u7885\u7886\u78A1\u7883\u7879\u7899\u7880\u7896\u787B\u797C\u7982\u797D\u7979\u7A11\u7A18\u7A19\u7A12\u7A17\u7A15\u7A22\u7A13"],
      ["df40", "\u7A1B\u7A10\u7AA3\u7AA2\u7A9E\u7AEB\u7B66\u7B64\u7B6D\u7B74\u7B69\u7B72\u7B65\u7B73\u7B71\u7B70\u7B61\u7B78\u7B76\u7B63\u7CB2\u7CB4\u7CAF\u7D88\u7D86\u7D80\u7D8D\u7D7F\u7D85\u7D7A\u7D8E\u7D7B\u7D83\u7D7C\u7D8C\u7D94\u7D84\u7D7D\u7D92\u7F6D\u7F6B\u7F67\u7F68\u7F6C\u7FA6\u7FA5\u7FA7\u7FDB\u7FDC\u8021\u8164\u8160\u8177\u815C\u8169\u815B\u8162\u8172\u6721\u815E\u8176\u8167\u816F"],
      ["dfa1", "\u8144\u8161\u821D\u8249\u8244\u8240\u8242\u8245\u84F1\u843F\u8456\u8476\u8479\u848F\u848D\u8465\u8451\u8440\u8486\u8467\u8430\u844D\u847D\u845A\u8459\u8474\u8473\u845D\u8507\u845E\u8437\u843A\u8434\u847A\u8443\u8478\u8432\u8445\u8429\u83D9\u844B\u842F\u8442\u842D\u845F\u8470\u8439\u844E\u844C\u8452\u846F\u84C5\u848E\u843B\u8447\u8436\u8433\u8468\u847E\u8444\u842B\u8460\u8454\u846E\u8450\u870B\u8704\u86F7\u870C\u86FA\u86D6\u86F5\u874D\u86F8\u870E\u8709\u8701\u86F6\u870D\u8705\u88D6\u88CB\u88CD\u88CE\u88DE\u88DB\u88DA\u88CC\u88D0\u8985\u899B\u89DF\u89E5\u89E4"],
      ["e040", "\u89E1\u89E0\u89E2\u89DC\u89E6\u8A76\u8A86\u8A7F\u8A61\u8A3F\u8A77\u8A82\u8A84\u8A75\u8A83\u8A81\u8A74\u8A7A\u8C3C\u8C4B\u8C4A\u8C65\u8C64\u8C66\u8C86\u8C84\u8C85\u8CCC\u8D68\u8D69\u8D91\u8D8C\u8D8E\u8D8F\u8D8D\u8D93\u8D94\u8D90\u8D92\u8DF0\u8DE0\u8DEC\u8DF1\u8DEE\u8DD0\u8DE9\u8DE3\u8DE2\u8DE7\u8DF2\u8DEB\u8DF4\u8F06\u8EFF\u8F01\u8F00\u8F05\u8F07\u8F08\u8F02\u8F0B\u9052\u903F"],
      ["e0a1", "\u9044\u9049\u903D\u9110\u910D\u910F\u9111\u9116\u9114\u910B\u910E\u916E\u916F\u9248\u9252\u9230\u923A\u9266\u9233\u9265\u925E\u9283\u922E\u924A\u9246\u926D\u926C\u924F\u9260\u9267\u926F\u9236\u9261\u9270\u9231\u9254\u9263\u9250\u9272\u924E\u9253\u924C\u9256\u9232\u959F\u959C\u959E\u959B\u9692\u9693\u9691\u9697\u96CE\u96FA\u96FD\u96F8\u96F5\u9773\u9777\u9778\u9772\u980F\u980D\u980E\u98AC\u98F6\u98F9\u99AF\u99B2\u99B0\u99B5\u9AAD\u9AAB\u9B5B\u9CEA\u9CED\u9CE7\u9E80\u9EFD\u50E6\u50D4\u50D7\u50E8\u50F3\u50DB\u50EA\u50DD\u50E4\u50D3\u50EC\u50F0\u50EF\u50E3\u50E0"],
      ["e140", "\u51D8\u5280\u5281\u52E9\u52EB\u5330\u53AC\u5627\u5615\u560C\u5612\u55FC\u560F\u561C\u5601\u5613\u5602\u55FA\u561D\u5604\u55FF\u55F9\u5889\u587C\u5890\u5898\u5886\u5881\u587F\u5874\u588B\u587A\u5887\u5891\u588E\u5876\u5882\u5888\u587B\u5894\u588F\u58FE\u596B\u5ADC\u5AEE\u5AE5\u5AD5\u5AEA\u5ADA\u5AED\u5AEB\u5AF3\u5AE2\u5AE0\u5ADB\u5AEC\u5ADE\u5ADD\u5AD9\u5AE8\u5ADF\u5B77\u5BE0"],
      ["e1a1", "\u5BE3\u5C63\u5D82\u5D80\u5D7D\u5D86\u5D7A\u5D81\u5D77\u5D8A\u5D89\u5D88\u5D7E\u5D7C\u5D8D\u5D79\u5D7F\u5E58\u5E59\u5E53\u5ED8\u5ED1\u5ED7\u5ECE\u5EDC\u5ED5\u5ED9\u5ED2\u5ED4\u5F44\u5F43\u5F6F\u5FB6\u612C\u6128\u6141\u615E\u6171\u6173\u6152\u6153\u6172\u616C\u6180\u6174\u6154\u617A\u615B\u6165\u613B\u616A\u6161\u6156\u6229\u6227\u622B\u642B\u644D\u645B\u645D\u6474\u6476\u6472\u6473\u647D\u6475\u6466\u64A6\u644E\u6482\u645E\u645C\u644B\u6453\u6460\u6450\u647F\u643F\u646C\u646B\u6459\u6465\u6477\u6573\u65A0\u66A1\u66A0\u669F\u6705\u6704\u6722\u69B1\u69B6\u69C9"],
      ["e240", "\u69A0\u69CE\u6996\u69B0\u69AC\u69BC\u6991\u6999\u698E\u69A7\u698D\u69A9\u69BE\u69AF\u69BF\u69C4\u69BD\u69A4\u69D4\u69B9\u69CA\u699A\u69CF\u69B3\u6993\u69AA\u69A1\u699E\u69D9\u6997\u6990\u69C2\u69B5\u69A5\u69C6\u6B4A\u6B4D\u6B4B\u6B9E\u6B9F\u6BA0\u6BC3\u6BC4\u6BFE\u6ECE\u6EF5\u6EF1\u6F03\u6F25\u6EF8\u6F37\u6EFB\u6F2E\u6F09\u6F4E\u6F19\u6F1A\u6F27\u6F18\u6F3B\u6F12\u6EED\u6F0A"],
      ["e2a1", "\u6F36\u6F73\u6EF9\u6EEE\u6F2D\u6F40\u6F30\u6F3C\u6F35\u6EEB\u6F07\u6F0E\u6F43\u6F05\u6EFD\u6EF6\u6F39\u6F1C\u6EFC\u6F3A\u6F1F\u6F0D\u6F1E\u6F08\u6F21\u7187\u7190\u7189\u7180\u7185\u7182\u718F\u717B\u7186\u7181\u7197\u7244\u7253\u7297\u7295\u7293\u7343\u734D\u7351\u734C\u7462\u7473\u7471\u7475\u7472\u7467\u746E\u7500\u7502\u7503\u757D\u7590\u7616\u7608\u760C\u7615\u7611\u760A\u7614\u76B8\u7781\u777C\u7785\u7782\u776E\u7780\u776F\u777E\u7783\u78B2\u78AA\u78B4\u78AD\u78A8\u787E\u78AB\u789E\u78A5\u78A0\u78AC\u78A2\u78A4\u7998\u798A\u798B\u7996\u7995\u7994\u7993"],
      ["e340", "\u7997\u7988\u7992\u7990\u7A2B\u7A4A\u7A30\u7A2F\u7A28\u7A26\u7AA8\u7AAB\u7AAC\u7AEE\u7B88\u7B9C\u7B8A\u7B91\u7B90\u7B96\u7B8D\u7B8C\u7B9B\u7B8E\u7B85\u7B98\u5284\u7B99\u7BA4\u7B82\u7CBB\u7CBF\u7CBC\u7CBA\u7DA7\u7DB7\u7DC2\u7DA3\u7DAA\u7DC1\u7DC0\u7DC5\u7D9D\u7DCE\u7DC4\u7DC6\u7DCB\u7DCC\u7DAF\u7DB9\u7D96\u7DBC\u7D9F\u7DA6\u7DAE\u7DA9\u7DA1\u7DC9\u7F73\u7FE2\u7FE3\u7FE5\u7FDE"],
      ["e3a1", "\u8024\u805D\u805C\u8189\u8186\u8183\u8187\u818D\u818C\u818B\u8215\u8497\u84A4\u84A1\u849F\u84BA\u84CE\u84C2\u84AC\u84AE\u84AB\u84B9\u84B4\u84C1\u84CD\u84AA\u849A\u84B1\u84D0\u849D\u84A7\u84BB\u84A2\u8494\u84C7\u84CC\u849B\u84A9\u84AF\u84A8\u84D6\u8498\u84B6\u84CF\u84A0\u84D7\u84D4\u84D2\u84DB\u84B0\u8491\u8661\u8733\u8723\u8728\u876B\u8740\u872E\u871E\u8721\u8719\u871B\u8743\u872C\u8741\u873E\u8746\u8720\u8732\u872A\u872D\u873C\u8712\u873A\u8731\u8735\u8742\u8726\u8727\u8738\u8724\u871A\u8730\u8711\u88F7\u88E7\u88F1\u88F2\u88FA\u88FE\u88EE\u88FC\u88F6\u88FB"],
      ["e440", "\u88F0\u88EC\u88EB\u899D\u89A1\u899F\u899E\u89E9\u89EB\u89E8\u8AAB\u8A99\u8A8B\u8A92\u8A8F\u8A96\u8C3D\u8C68\u8C69\u8CD5\u8CCF\u8CD7\u8D96\u8E09\u8E02\u8DFF\u8E0D\u8DFD\u8E0A\u8E03\u8E07\u8E06\u8E05\u8DFE\u8E00\u8E04\u8F10\u8F11\u8F0E\u8F0D\u9123\u911C\u9120\u9122\u911F\u911D\u911A\u9124\u9121\u911B\u917A\u9172\u9179\u9173\u92A5\u92A4\u9276\u929B\u927A\u92A0\u9294\u92AA\u928D"],
      ["e4a1", "\u92A6\u929A\u92AB\u9279\u9297\u927F\u92A3\u92EE\u928E\u9282\u9295\u92A2\u927D\u9288\u92A1\u928A\u9286\u928C\u9299\u92A7\u927E\u9287\u92A9\u929D\u928B\u922D\u969E\u96A1\u96FF\u9758\u977D\u977A\u977E\u9783\u9780\u9782\u977B\u9784\u9781\u977F\u97CE\u97CD\u9816\u98AD\u98AE\u9902\u9900\u9907\u999D\u999C\u99C3\u99B9\u99BB\u99BA\u99C2\u99BD\u99C7\u9AB1\u9AE3\u9AE7\u9B3E\u9B3F\u9B60\u9B61\u9B5F\u9CF1\u9CF2\u9CF5\u9EA7\u50FF\u5103\u5130\u50F8\u5106\u5107\u50F6\u50FE\u510B\u510C\u50FD\u510A\u528B\u528C\u52F1\u52EF\u5648\u5642\u564C\u5635\u5641\u564A\u5649\u5646\u5658"],
      ["e540", "\u565A\u5640\u5633\u563D\u562C\u563E\u5638\u562A\u563A\u571A\u58AB\u589D\u58B1\u58A0\u58A3\u58AF\u58AC\u58A5\u58A1\u58FF\u5AFF\u5AF4\u5AFD\u5AF7\u5AF6\u5B03\u5AF8\u5B02\u5AF9\u5B01\u5B07\u5B05\u5B0F\u5C67\u5D99\u5D97\u5D9F\u5D92\u5DA2\u5D93\u5D95\u5DA0\u5D9C\u5DA1\u5D9A\u5D9E\u5E69\u5E5D\u5E60\u5E5C\u7DF3\u5EDB\u5EDE\u5EE1\u5F49\u5FB2\u618B\u6183\u6179\u61B1\u61B0\u61A2\u6189"],
      ["e5a1", "\u619B\u6193\u61AF\u61AD\u619F\u6192\u61AA\u61A1\u618D\u6166\u61B3\u622D\u646E\u6470\u6496\u64A0\u6485\u6497\u649C\u648F\u648B\u648A\u648C\u64A3\u649F\u6468\u64B1\u6498\u6576\u657A\u6579\u657B\u65B2\u65B3\u66B5\u66B0\u66A9\u66B2\u66B7\u66AA\u66AF\u6A00\u6A06\u6A17\u69E5\u69F8\u6A15\u69F1\u69E4\u6A20\u69FF\u69EC\u69E2\u6A1B\u6A1D\u69FE\u6A27\u69F2\u69EE\u6A14\u69F7\u69E7\u6A40\u6A08\u69E6\u69FB\u6A0D\u69FC\u69EB\u6A09\u6A04\u6A18\u6A25\u6A0F\u69F6\u6A26\u6A07\u69F4\u6A16\u6B51\u6BA5\u6BA3\u6BA2\u6BA6\u6C01\u6C00\u6BFF\u6C02\u6F41\u6F26\u6F7E\u6F87\u6FC6\u6F92"],
      ["e640", "\u6F8D\u6F89\u6F8C\u6F62\u6F4F\u6F85\u6F5A\u6F96\u6F76\u6F6C\u6F82\u6F55\u6F72\u6F52\u6F50\u6F57\u6F94\u6F93\u6F5D\u6F00\u6F61\u6F6B\u6F7D\u6F67\u6F90\u6F53\u6F8B\u6F69\u6F7F\u6F95\u6F63\u6F77\u6F6A\u6F7B\u71B2\u71AF\u719B\u71B0\u71A0\u719A\u71A9\u71B5\u719D\u71A5\u719E\u71A4\u71A1\u71AA\u719C\u71A7\u71B3\u7298\u729A\u7358\u7352\u735E\u735F\u7360\u735D\u735B\u7361\u735A\u7359"],
      ["e6a1", "\u7362\u7487\u7489\u748A\u7486\u7481\u747D\u7485\u7488\u747C\u7479\u7508\u7507\u757E\u7625\u761E\u7619\u761D\u761C\u7623\u761A\u7628\u761B\u769C\u769D\u769E\u769B\u778D\u778F\u7789\u7788\u78CD\u78BB\u78CF\u78CC\u78D1\u78CE\u78D4\u78C8\u78C3\u78C4\u78C9\u799A\u79A1\u79A0\u799C\u79A2\u799B\u6B76\u7A39\u7AB2\u7AB4\u7AB3\u7BB7\u7BCB\u7BBE\u7BAC\u7BCE\u7BAF\u7BB9\u7BCA\u7BB5\u7CC5\u7CC8\u7CCC\u7CCB\u7DF7\u7DDB\u7DEA\u7DE7\u7DD7\u7DE1\u7E03\u7DFA\u7DE6\u7DF6\u7DF1\u7DF0\u7DEE\u7DDF\u7F76\u7FAC\u7FB0\u7FAD\u7FED\u7FEB\u7FEA\u7FEC\u7FE6\u7FE8\u8064\u8067\u81A3\u819F"],
      ["e740", "\u819E\u8195\u81A2\u8199\u8197\u8216\u824F\u8253\u8252\u8250\u824E\u8251\u8524\u853B\u850F\u8500\u8529\u850E\u8509\u850D\u851F\u850A\u8527\u851C\u84FB\u852B\u84FA\u8508\u850C\u84F4\u852A\u84F2\u8515\u84F7\u84EB\u84F3\u84FC\u8512\u84EA\u84E9\u8516\u84FE\u8528\u851D\u852E\u8502\u84FD\u851E\u84F6\u8531\u8526\u84E7\u84E8\u84F0\u84EF\u84F9\u8518\u8520\u8530\u850B\u8519\u852F\u8662"],
      ["e7a1", "\u8756\u8763\u8764\u8777\u87E1\u8773\u8758\u8754\u875B\u8752\u8761\u875A\u8751\u875E\u876D\u876A\u8750\u874E\u875F\u875D\u876F\u876C\u877A\u876E\u875C\u8765\u874F\u877B\u8775\u8762\u8767\u8769\u885A\u8905\u890C\u8914\u890B\u8917\u8918\u8919\u8906\u8916\u8911\u890E\u8909\u89A2\u89A4\u89A3\u89ED\u89F0\u89EC\u8ACF\u8AC6\u8AB8\u8AD3\u8AD1\u8AD4\u8AD5\u8ABB\u8AD7\u8ABE\u8AC0\u8AC5\u8AD8\u8AC3\u8ABA\u8ABD\u8AD9\u8C3E\u8C4D\u8C8F\u8CE5\u8CDF\u8CD9\u8CE8\u8CDA\u8CDD\u8CE7\u8DA0\u8D9C\u8DA1\u8D9B\u8E20\u8E23\u8E25\u8E24\u8E2E\u8E15\u8E1B\u8E16\u8E11\u8E19\u8E26\u8E27"],
      ["e840", "\u8E14\u8E12\u8E18\u8E13\u8E1C\u8E17\u8E1A\u8F2C\u8F24\u8F18\u8F1A\u8F20\u8F23\u8F16\u8F17\u9073\u9070\u906F\u9067\u906B\u912F\u912B\u9129\u912A\u9132\u9126\u912E\u9185\u9186\u918A\u9181\u9182\u9184\u9180\u92D0\u92C3\u92C4\u92C0\u92D9\u92B6\u92CF\u92F1\u92DF\u92D8\u92E9\u92D7\u92DD\u92CC\u92EF\u92C2\u92E8\u92CA\u92C8\u92CE\u92E6\u92CD\u92D5\u92C9\u92E0\u92DE\u92E7\u92D1\u92D3"],
      ["e8a1", "\u92B5\u92E1\u92C6\u92B4\u957C\u95AC\u95AB\u95AE\u95B0\u96A4\u96A2\u96D3\u9705\u9708\u9702\u975A\u978A\u978E\u9788\u97D0\u97CF\u981E\u981D\u9826\u9829\u9828\u9820\u981B\u9827\u98B2\u9908\u98FA\u9911\u9914\u9916\u9917\u9915\u99DC\u99CD\u99CF\u99D3\u99D4\u99CE\u99C9\u99D6\u99D8\u99CB\u99D7\u99CC\u9AB3\u9AEC\u9AEB\u9AF3\u9AF2\u9AF1\u9B46\u9B43\u9B67\u9B74\u9B71\u9B66\u9B76\u9B75\u9B70\u9B68\u9B64\u9B6C\u9CFC\u9CFA\u9CFD\u9CFF\u9CF7\u9D07\u9D00\u9CF9\u9CFB\u9D08\u9D05\u9D04\u9E83\u9ED3\u9F0F\u9F10\u511C\u5113\u5117\u511A\u5111\u51DE\u5334\u53E1\u5670\u5660\u566E"],
      ["e940", "\u5673\u5666\u5663\u566D\u5672\u565E\u5677\u571C\u571B\u58C8\u58BD\u58C9\u58BF\u58BA\u58C2\u58BC\u58C6\u5B17\u5B19\u5B1B\u5B21\u5B14\u5B13\u5B10\u5B16\u5B28\u5B1A\u5B20\u5B1E\u5BEF\u5DAC\u5DB1\u5DA9\u5DA7\u5DB5\u5DB0\u5DAE\u5DAA\u5DA8\u5DB2\u5DAD\u5DAF\u5DB4\u5E67\u5E68\u5E66\u5E6F\u5EE9\u5EE7\u5EE6\u5EE8\u5EE5\u5F4B\u5FBC\u619D\u61A8\u6196\u61C5\u61B4\u61C6\u61C1\u61CC\u61BA"],
      ["e9a1", "\u61BF\u61B8\u618C\u64D7\u64D6\u64D0\u64CF\u64C9\u64BD\u6489\u64C3\u64DB\u64F3\u64D9\u6533\u657F\u657C\u65A2\u66C8\u66BE\u66C0\u66CA\u66CB\u66CF\u66BD\u66BB\u66BA\u66CC\u6723\u6A34\u6A66\u6A49\u6A67\u6A32\u6A68\u6A3E\u6A5D\u6A6D\u6A76\u6A5B\u6A51\u6A28\u6A5A\u6A3B\u6A3F\u6A41\u6A6A\u6A64\u6A50\u6A4F\u6A54\u6A6F\u6A69\u6A60\u6A3C\u6A5E\u6A56\u6A55\u6A4D\u6A4E\u6A46\u6B55\u6B54\u6B56\u6BA7\u6BAA\u6BAB\u6BC8\u6BC7\u6C04\u6C03\u6C06\u6FAD\u6FCB\u6FA3\u6FC7\u6FBC\u6FCE\u6FC8\u6F5E\u6FC4\u6FBD\u6F9E\u6FCA\u6FA8\u7004\u6FA5\u6FAE\u6FBA\u6FAC\u6FAA\u6FCF\u6FBF\u6FB8"],
      ["ea40", "\u6FA2\u6FC9\u6FAB\u6FCD\u6FAF\u6FB2\u6FB0\u71C5\u71C2\u71BF\u71B8\u71D6\u71C0\u71C1\u71CB\u71D4\u71CA\u71C7\u71CF\u71BD\u71D8\u71BC\u71C6\u71DA\u71DB\u729D\u729E\u7369\u7366\u7367\u736C\u7365\u736B\u736A\u747F\u749A\u74A0\u7494\u7492\u7495\u74A1\u750B\u7580\u762F\u762D\u7631\u763D\u7633\u763C\u7635\u7632\u7630\u76BB\u76E6\u779A\u779D\u77A1\u779C\u779B\u77A2\u77A3\u7795\u7799"],
      ["eaa1", "\u7797\u78DD\u78E9\u78E5\u78EA\u78DE\u78E3\u78DB\u78E1\u78E2\u78ED\u78DF\u78E0\u79A4\u7A44\u7A48\u7A47\u7AB6\u7AB8\u7AB5\u7AB1\u7AB7\u7BDE\u7BE3\u7BE7\u7BDD\u7BD5\u7BE5\u7BDA\u7BE8\u7BF9\u7BD4\u7BEA\u7BE2\u7BDC\u7BEB\u7BD8\u7BDF\u7CD2\u7CD4\u7CD7\u7CD0\u7CD1\u7E12\u7E21\u7E17\u7E0C\u7E1F\u7E20\u7E13\u7E0E\u7E1C\u7E15\u7E1A\u7E22\u7E0B\u7E0F\u7E16\u7E0D\u7E14\u7E25\u7E24\u7F43\u7F7B\u7F7C\u7F7A\u7FB1\u7FEF\u802A\u8029\u806C\u81B1\u81A6\u81AE\u81B9\u81B5\u81AB\u81B0\u81AC\u81B4\u81B2\u81B7\u81A7\u81F2\u8255\u8256\u8257\u8556\u8545\u856B\u854D\u8553\u8561\u8558"],
      ["eb40", "\u8540\u8546\u8564\u8541\u8562\u8544\u8551\u8547\u8563\u853E\u855B\u8571\u854E\u856E\u8575\u8555\u8567\u8560\u858C\u8566\u855D\u8554\u8565\u856C\u8663\u8665\u8664\u879B\u878F\u8797\u8793\u8792\u8788\u8781\u8796\u8798\u8779\u8787\u87A3\u8785\u8790\u8791\u879D\u8784\u8794\u879C\u879A\u8789\u891E\u8926\u8930\u892D\u892E\u8927\u8931\u8922\u8929\u8923\u892F\u892C\u891F\u89F1\u8AE0"],
      ["eba1", "\u8AE2\u8AF2\u8AF4\u8AF5\u8ADD\u8B14\u8AE4\u8ADF\u8AF0\u8AC8\u8ADE\u8AE1\u8AE8\u8AFF\u8AEF\u8AFB\u8C91\u8C92\u8C90\u8CF5\u8CEE\u8CF1\u8CF0\u8CF3\u8D6C\u8D6E\u8DA5\u8DA7\u8E33\u8E3E\u8E38\u8E40\u8E45\u8E36\u8E3C\u8E3D\u8E41\u8E30\u8E3F\u8EBD\u8F36\u8F2E\u8F35\u8F32\u8F39\u8F37\u8F34\u9076\u9079\u907B\u9086\u90FA\u9133\u9135\u9136\u9193\u9190\u9191\u918D\u918F\u9327\u931E\u9308\u931F\u9306\u930F\u937A\u9338\u933C\u931B\u9323\u9312\u9301\u9346\u932D\u930E\u930D\u92CB\u931D\u92FA\u9325\u9313\u92F9\u92F7\u9334\u9302\u9324\u92FF\u9329\u9339\u9335\u932A\u9314\u930C"],
      ["ec40", "\u930B\u92FE\u9309\u9300\u92FB\u9316\u95BC\u95CD\u95BE\u95B9\u95BA\u95B6\u95BF\u95B5\u95BD\u96A9\u96D4\u970B\u9712\u9710\u9799\u9797\u9794\u97F0\u97F8\u9835\u982F\u9832\u9924\u991F\u9927\u9929\u999E\u99EE\u99EC\u99E5\u99E4\u99F0\u99E3\u99EA\u99E9\u99E7\u9AB9\u9ABF\u9AB4\u9ABB\u9AF6\u9AFA\u9AF9\u9AF7\u9B33\u9B80\u9B85\u9B87\u9B7C\u9B7E\u9B7B\u9B82\u9B93\u9B92\u9B90\u9B7A\u9B95"],
      ["eca1", "\u9B7D\u9B88\u9D25\u9D17\u9D20\u9D1E\u9D14\u9D29\u9D1D\u9D18\u9D22\u9D10\u9D19\u9D1F\u9E88\u9E86\u9E87\u9EAE\u9EAD\u9ED5\u9ED6\u9EFA\u9F12\u9F3D\u5126\u5125\u5122\u5124\u5120\u5129\u52F4\u5693\u568C\u568D\u5686\u5684\u5683\u567E\u5682\u567F\u5681\u58D6\u58D4\u58CF\u58D2\u5B2D\u5B25\u5B32\u5B23\u5B2C\u5B27\u5B26\u5B2F\u5B2E\u5B7B\u5BF1\u5BF2\u5DB7\u5E6C\u5E6A\u5FBE\u5FBB\u61C3\u61B5\u61BC\u61E7\u61E0\u61E5\u61E4\u61E8\u61DE\u64EF\u64E9\u64E3\u64EB\u64E4\u64E8\u6581\u6580\u65B6\u65DA\u66D2\u6A8D\u6A96\u6A81\u6AA5\u6A89\u6A9F\u6A9B\u6AA1\u6A9E\u6A87\u6A93\u6A8E"],
      ["ed40", "\u6A95\u6A83\u6AA8\u6AA4\u6A91\u6A7F\u6AA6\u6A9A\u6A85\u6A8C\u6A92\u6B5B\u6BAD\u6C09\u6FCC\u6FA9\u6FF4\u6FD4\u6FE3\u6FDC\u6FED\u6FE7\u6FE6\u6FDE\u6FF2\u6FDD\u6FE2\u6FE8\u71E1\u71F1\u71E8\u71F2\u71E4\u71F0\u71E2\u7373\u736E\u736F\u7497\u74B2\u74AB\u7490\u74AA\u74AD\u74B1\u74A5\u74AF\u7510\u7511\u7512\u750F\u7584\u7643\u7648\u7649\u7647\u76A4\u76E9\u77B5\u77AB\u77B2\u77B7\u77B6"],
      ["eda1", "\u77B4\u77B1\u77A8\u77F0\u78F3\u78FD\u7902\u78FB\u78FC\u78F2\u7905\u78F9\u78FE\u7904\u79AB\u79A8\u7A5C\u7A5B\u7A56\u7A58\u7A54\u7A5A\u7ABE\u7AC0\u7AC1\u7C05\u7C0F\u7BF2\u7C00\u7BFF\u7BFB\u7C0E\u7BF4\u7C0B\u7BF3\u7C02\u7C09\u7C03\u7C01\u7BF8\u7BFD\u7C06\u7BF0\u7BF1\u7C10\u7C0A\u7CE8\u7E2D\u7E3C\u7E42\u7E33\u9848\u7E38\u7E2A\u7E49\u7E40\u7E47\u7E29\u7E4C\u7E30\u7E3B\u7E36\u7E44\u7E3A\u7F45\u7F7F\u7F7E\u7F7D\u7FF4\u7FF2\u802C\u81BB\u81C4\u81CC\u81CA\u81C5\u81C7\u81BC\u81E9\u825B\u825A\u825C\u8583\u8580\u858F\u85A7\u8595\u85A0\u858B\u85A3\u857B\u85A4\u859A\u859E"],
      ["ee40", "\u8577\u857C\u8589\u85A1\u857A\u8578\u8557\u858E\u8596\u8586\u858D\u8599\u859D\u8581\u85A2\u8582\u8588\u8585\u8579\u8576\u8598\u8590\u859F\u8668\u87BE\u87AA\u87AD\u87C5\u87B0\u87AC\u87B9\u87B5\u87BC\u87AE\u87C9\u87C3\u87C2\u87CC\u87B7\u87AF\u87C4\u87CA\u87B4\u87B6\u87BF\u87B8\u87BD\u87DE\u87B2\u8935\u8933\u893C\u893E\u8941\u8952\u8937\u8942\u89AD\u89AF\u89AE\u89F2\u89F3\u8B1E"],
      ["eea1", "\u8B18\u8B16\u8B11\u8B05\u8B0B\u8B22\u8B0F\u8B12\u8B15\u8B07\u8B0D\u8B08\u8B06\u8B1C\u8B13\u8B1A\u8C4F\u8C70\u8C72\u8C71\u8C6F\u8C95\u8C94\u8CF9\u8D6F\u8E4E\u8E4D\u8E53\u8E50\u8E4C\u8E47\u8F43\u8F40\u9085\u907E\u9138\u919A\u91A2\u919B\u9199\u919F\u91A1\u919D\u91A0\u93A1\u9383\u93AF\u9364\u9356\u9347\u937C\u9358\u935C\u9376\u9349\u9350\u9351\u9360\u936D\u938F\u934C\u936A\u9379\u9357\u9355\u9352\u934F\u9371\u9377\u937B\u9361\u935E\u9363\u9367\u9380\u934E\u9359\u95C7\u95C0\u95C9\u95C3\u95C5\u95B7\u96AE\u96B0\u96AC\u9720\u971F\u9718\u971D\u9719\u979A\u97A1\u979C"],
      ["ef40", "\u979E\u979D\u97D5\u97D4\u97F1\u9841\u9844\u984A\u9849\u9845\u9843\u9925\u992B\u992C\u992A\u9933\u9932\u992F\u992D\u9931\u9930\u9998\u99A3\u99A1\u9A02\u99FA\u99F4\u99F7\u99F9\u99F8\u99F6\u99FB\u99FD\u99FE\u99FC\u9A03\u9ABE\u9AFE\u9AFD\u9B01\u9AFC\u9B48\u9B9A\u9BA8\u9B9E\u9B9B\u9BA6\u9BA1\u9BA5\u9BA4\u9B86\u9BA2\u9BA0\u9BAF\u9D33\u9D41\u9D67\u9D36\u9D2E\u9D2F\u9D31\u9D38\u9D30"],
      ["efa1", "\u9D45\u9D42\u9D43\u9D3E\u9D37\u9D40\u9D3D\u7FF5\u9D2D\u9E8A\u9E89\u9E8D\u9EB0\u9EC8\u9EDA\u9EFB\u9EFF\u9F24\u9F23\u9F22\u9F54\u9FA0\u5131\u512D\u512E\u5698\u569C\u5697\u569A\u569D\u5699\u5970\u5B3C\u5C69\u5C6A\u5DC0\u5E6D\u5E6E\u61D8\u61DF\u61ED\u61EE\u61F1\u61EA\u61F0\u61EB\u61D6\u61E9\u64FF\u6504\u64FD\u64F8\u6501\u6503\u64FC\u6594\u65DB\u66DA\u66DB\u66D8\u6AC5\u6AB9\u6ABD\u6AE1\u6AC6\u6ABA\u6AB6\u6AB7\u6AC7\u6AB4\u6AAD\u6B5E\u6BC9\u6C0B\u7007\u700C\u700D\u7001\u7005\u7014\u700E\u6FFF\u7000\u6FFB\u7026\u6FFC\u6FF7\u700A\u7201\u71FF\u71F9\u7203\u71FD\u7376"],
      ["f040", "\u74B8\u74C0\u74B5\u74C1\u74BE\u74B6\u74BB\u74C2\u7514\u7513\u765C\u7664\u7659\u7650\u7653\u7657\u765A\u76A6\u76BD\u76EC\u77C2\u77BA\u78FF\u790C\u7913\u7914\u7909\u7910\u7912\u7911\u79AD\u79AC\u7A5F\u7C1C\u7C29\u7C19\u7C20\u7C1F\u7C2D\u7C1D\u7C26\u7C28\u7C22\u7C25\u7C30\u7E5C\u7E50\u7E56\u7E63\u7E58\u7E62\u7E5F\u7E51\u7E60\u7E57\u7E53\u7FB5\u7FB3\u7FF7\u7FF8\u8075\u81D1\u81D2"],
      ["f0a1", "\u81D0\u825F\u825E\u85B4\u85C6\u85C0\u85C3\u85C2\u85B3\u85B5\u85BD\u85C7\u85C4\u85BF\u85CB\u85CE\u85C8\u85C5\u85B1\u85B6\u85D2\u8624\u85B8\u85B7\u85BE\u8669\u87E7\u87E6\u87E2\u87DB\u87EB\u87EA\u87E5\u87DF\u87F3\u87E4\u87D4\u87DC\u87D3\u87ED\u87D8\u87E3\u87A4\u87D7\u87D9\u8801\u87F4\u87E8\u87DD\u8953\u894B\u894F\u894C\u8946\u8950\u8951\u8949\u8B2A\u8B27\u8B23\u8B33\u8B30\u8B35\u8B47\u8B2F\u8B3C\u8B3E\u8B31\u8B25\u8B37\u8B26\u8B36\u8B2E\u8B24\u8B3B\u8B3D\u8B3A\u8C42\u8C75\u8C99\u8C98\u8C97\u8CFE\u8D04\u8D02\u8D00\u8E5C\u8E62\u8E60\u8E57\u8E56\u8E5E\u8E65\u8E67"],
      ["f140", "\u8E5B\u8E5A\u8E61\u8E5D\u8E69\u8E54\u8F46\u8F47\u8F48\u8F4B\u9128\u913A\u913B\u913E\u91A8\u91A5\u91A7\u91AF\u91AA\u93B5\u938C\u9392\u93B7\u939B\u939D\u9389\u93A7\u938E\u93AA\u939E\u93A6\u9395\u9388\u9399\u939F\u938D\u93B1\u9391\u93B2\u93A4\u93A8\u93B4\u93A3\u93A5\u95D2\u95D3\u95D1\u96B3\u96D7\u96DA\u5DC2\u96DF\u96D8\u96DD\u9723\u9722\u9725\u97AC\u97AE\u97A8\u97AB\u97A4\u97AA"],
      ["f1a1", "\u97A2\u97A5\u97D7\u97D9\u97D6\u97D8\u97FA\u9850\u9851\u9852\u98B8\u9941\u993C\u993A\u9A0F\u9A0B\u9A09\u9A0D\u9A04\u9A11\u9A0A\u9A05\u9A07\u9A06\u9AC0\u9ADC\u9B08\u9B04\u9B05\u9B29\u9B35\u9B4A\u9B4C\u9B4B\u9BC7\u9BC6\u9BC3\u9BBF\u9BC1\u9BB5\u9BB8\u9BD3\u9BB6\u9BC4\u9BB9\u9BBD\u9D5C\u9D53\u9D4F\u9D4A\u9D5B\u9D4B\u9D59\u9D56\u9D4C\u9D57\u9D52\u9D54\u9D5F\u9D58\u9D5A\u9E8E\u9E8C\u9EDF\u9F01\u9F00\u9F16\u9F25\u9F2B\u9F2A\u9F29\u9F28\u9F4C\u9F55\u5134\u5135\u5296\u52F7\u53B4\u56AB\u56AD\u56A6\u56A7\u56AA\u56AC\u58DA\u58DD\u58DB\u5912\u5B3D\u5B3E\u5B3F\u5DC3\u5E70"],
      ["f240", "\u5FBF\u61FB\u6507\u6510\u650D\u6509\u650C\u650E\u6584\u65DE\u65DD\u66DE\u6AE7\u6AE0\u6ACC\u6AD1\u6AD9\u6ACB\u6ADF\u6ADC\u6AD0\u6AEB\u6ACF\u6ACD\u6ADE\u6B60\u6BB0\u6C0C\u7019\u7027\u7020\u7016\u702B\u7021\u7022\u7023\u7029\u7017\u7024\u701C\u702A\u720C\u720A\u7207\u7202\u7205\u72A5\u72A6\u72A4\u72A3\u72A1\u74CB\u74C5\u74B7\u74C3\u7516\u7660\u77C9\u77CA\u77C4\u77F1\u791D\u791B"],
      ["f2a1", "\u7921\u791C\u7917\u791E\u79B0\u7A67\u7A68\u7C33\u7C3C\u7C39\u7C2C\u7C3B\u7CEC\u7CEA\u7E76\u7E75\u7E78\u7E70\u7E77\u7E6F\u7E7A\u7E72\u7E74\u7E68\u7F4B\u7F4A\u7F83\u7F86\u7FB7\u7FFD\u7FFE\u8078\u81D7\u81D5\u8264\u8261\u8263\u85EB\u85F1\u85ED\u85D9\u85E1\u85E8\u85DA\u85D7\u85EC\u85F2\u85F8\u85D8\u85DF\u85E3\u85DC\u85D1\u85F0\u85E6\u85EF\u85DE\u85E2\u8800\u87FA\u8803\u87F6\u87F7\u8809\u880C\u880B\u8806\u87FC\u8808\u87FF\u880A\u8802\u8962\u895A\u895B\u8957\u8961\u895C\u8958\u895D\u8959\u8988\u89B7\u89B6\u89F6\u8B50\u8B48\u8B4A\u8B40\u8B53\u8B56\u8B54\u8B4B\u8B55"],
      ["f340", "\u8B51\u8B42\u8B52\u8B57\u8C43\u8C77\u8C76\u8C9A\u8D06\u8D07\u8D09\u8DAC\u8DAA\u8DAD\u8DAB\u8E6D\u8E78\u8E73\u8E6A\u8E6F\u8E7B\u8EC2\u8F52\u8F51\u8F4F\u8F50\u8F53\u8FB4\u9140\u913F\u91B0\u91AD\u93DE\u93C7\u93CF\u93C2\u93DA\u93D0\u93F9\u93EC\u93CC\u93D9\u93A9\u93E6\u93CA\u93D4\u93EE\u93E3\u93D5\u93C4\u93CE\u93C0\u93D2\u93E7\u957D\u95DA\u95DB\u96E1\u9729\u972B\u972C\u9728\u9726"],
      ["f3a1", "\u97B3\u97B7\u97B6\u97DD\u97DE\u97DF\u985C\u9859\u985D\u9857\u98BF\u98BD\u98BB\u98BE\u9948\u9947\u9943\u99A6\u99A7\u9A1A\u9A15\u9A25\u9A1D\u9A24\u9A1B\u9A22\u9A20\u9A27\u9A23\u9A1E\u9A1C\u9A14\u9AC2\u9B0B\u9B0A\u9B0E\u9B0C\u9B37\u9BEA\u9BEB\u9BE0\u9BDE\u9BE4\u9BE6\u9BE2\u9BF0\u9BD4\u9BD7\u9BEC\u9BDC\u9BD9\u9BE5\u9BD5\u9BE1\u9BDA\u9D77\u9D81\u9D8A\u9D84\u9D88\u9D71\u9D80\u9D78\u9D86\u9D8B\u9D8C\u9D7D\u9D6B\u9D74\u9D75\u9D70\u9D69\u9D85\u9D73\u9D7B\u9D82\u9D6F\u9D79\u9D7F\u9D87\u9D68\u9E94\u9E91\u9EC0\u9EFC\u9F2D\u9F40\u9F41\u9F4D\u9F56\u9F57\u9F58\u5337\u56B2"],
      ["f440", "\u56B5\u56B3\u58E3\u5B45\u5DC6\u5DC7\u5EEE\u5EEF\u5FC0\u5FC1\u61F9\u6517\u6516\u6515\u6513\u65DF\u66E8\u66E3\u66E4\u6AF3\u6AF0\u6AEA\u6AE8\u6AF9\u6AF1\u6AEE\u6AEF\u703C\u7035\u702F\u7037\u7034\u7031\u7042\u7038\u703F\u703A\u7039\u7040\u703B\u7033\u7041\u7213\u7214\u72A8\u737D\u737C\u74BA\u76AB\u76AA\u76BE\u76ED\u77CC\u77CE\u77CF\u77CD\u77F2\u7925\u7923\u7927\u7928\u7924\u7929"],
      ["f4a1", "\u79B2\u7A6E\u7A6C\u7A6D\u7AF7\u7C49\u7C48\u7C4A\u7C47\u7C45\u7CEE\u7E7B\u7E7E\u7E81\u7E80\u7FBA\u7FFF\u8079\u81DB\u81D9\u820B\u8268\u8269\u8622\u85FF\u8601\u85FE\u861B\u8600\u85F6\u8604\u8609\u8605\u860C\u85FD\u8819\u8810\u8811\u8817\u8813\u8816\u8963\u8966\u89B9\u89F7\u8B60\u8B6A\u8B5D\u8B68\u8B63\u8B65\u8B67\u8B6D\u8DAE\u8E86\u8E88\u8E84\u8F59\u8F56\u8F57\u8F55\u8F58\u8F5A\u908D\u9143\u9141\u91B7\u91B5\u91B2\u91B3\u940B\u9413\u93FB\u9420\u940F\u9414\u93FE\u9415\u9410\u9428\u9419\u940D\u93F5\u9400\u93F7\u9407\u940E\u9416\u9412\u93FA\u9409\u93F8\u940A\u93FF"],
      ["f540", "\u93FC\u940C\u93F6\u9411\u9406\u95DE\u95E0\u95DF\u972E\u972F\u97B9\u97BB\u97FD\u97FE\u9860\u9862\u9863\u985F\u98C1\u98C2\u9950\u994E\u9959\u994C\u994B\u9953\u9A32\u9A34\u9A31\u9A2C\u9A2A\u9A36\u9A29\u9A2E\u9A38\u9A2D\u9AC7\u9ACA\u9AC6\u9B10\u9B12\u9B11\u9C0B\u9C08\u9BF7\u9C05\u9C12\u9BF8\u9C40\u9C07\u9C0E\u9C06\u9C17\u9C14\u9C09\u9D9F\u9D99\u9DA4\u9D9D\u9D92\u9D98\u9D90\u9D9B"],
      ["f5a1", "\u9DA0\u9D94\u9D9C\u9DAA\u9D97\u9DA1\u9D9A\u9DA2\u9DA8\u9D9E\u9DA3\u9DBF\u9DA9\u9D96\u9DA6\u9DA7\u9E99\u9E9B\u9E9A\u9EE5\u9EE4\u9EE7\u9EE6\u9F30\u9F2E\u9F5B\u9F60\u9F5E\u9F5D\u9F59\u9F91\u513A\u5139\u5298\u5297\u56C3\u56BD\u56BE\u5B48\u5B47\u5DCB\u5DCF\u5EF1\u61FD\u651B\u6B02\u6AFC\u6B03\u6AF8\u6B00\u7043\u7044\u704A\u7048\u7049\u7045\u7046\u721D\u721A\u7219\u737E\u7517\u766A\u77D0\u792D\u7931\u792F\u7C54\u7C53\u7CF2\u7E8A\u7E87\u7E88\u7E8B\u7E86\u7E8D\u7F4D\u7FBB\u8030\u81DD\u8618\u862A\u8626\u861F\u8623\u861C\u8619\u8627\u862E\u8621\u8620\u8629\u861E\u8625"],
      ["f640", "\u8829\u881D\u881B\u8820\u8824\u881C\u882B\u884A\u896D\u8969\u896E\u896B\u89FA\u8B79\u8B78\u8B45\u8B7A\u8B7B\u8D10\u8D14\u8DAF\u8E8E\u8E8C\u8F5E\u8F5B\u8F5D\u9146\u9144\u9145\u91B9\u943F\u943B\u9436\u9429\u943D\u943C\u9430\u9439\u942A\u9437\u942C\u9440\u9431\u95E5\u95E4\u95E3\u9735\u973A\u97BF\u97E1\u9864\u98C9\u98C6\u98C0\u9958\u9956\u9A39\u9A3D\u9A46\u9A44\u9A42\u9A41\u9A3A"],
      ["f6a1", "\u9A3F\u9ACD\u9B15\u9B17\u9B18\u9B16\u9B3A\u9B52\u9C2B\u9C1D\u9C1C\u9C2C\u9C23\u9C28\u9C29\u9C24\u9C21\u9DB7\u9DB6\u9DBC\u9DC1\u9DC7\u9DCA\u9DCF\u9DBE\u9DC5\u9DC3\u9DBB\u9DB5\u9DCE\u9DB9\u9DBA\u9DAC\u9DC8\u9DB1\u9DAD\u9DCC\u9DB3\u9DCD\u9DB2\u9E7A\u9E9C\u9EEB\u9EEE\u9EED\u9F1B\u9F18\u9F1A\u9F31\u9F4E\u9F65\u9F64\u9F92\u4EB9\u56C6\u56C5\u56CB\u5971\u5B4B\u5B4C\u5DD5\u5DD1\u5EF2\u6521\u6520\u6526\u6522\u6B0B\u6B08\u6B09\u6C0D\u7055\u7056\u7057\u7052\u721E\u721F\u72A9\u737F\u74D8\u74D5\u74D9\u74D7\u766D\u76AD\u7935\u79B4\u7A70\u7A71\u7C57\u7C5C\u7C59\u7C5B\u7C5A"],
      ["f740", "\u7CF4\u7CF1\u7E91\u7F4F\u7F87\u81DE\u826B\u8634\u8635\u8633\u862C\u8632\u8636\u882C\u8828\u8826\u882A\u8825\u8971\u89BF\u89BE\u89FB\u8B7E\u8B84\u8B82\u8B86\u8B85\u8B7F\u8D15\u8E95\u8E94\u8E9A\u8E92\u8E90\u8E96\u8E97\u8F60\u8F62\u9147\u944C\u9450\u944A\u944B\u944F\u9447\u9445\u9448\u9449\u9446\u973F\u97E3\u986A\u9869\u98CB\u9954\u995B\u9A4E\u9A53\u9A54\u9A4C\u9A4F\u9A48\u9A4A"],
      ["f7a1", "\u9A49\u9A52\u9A50\u9AD0\u9B19\u9B2B\u9B3B\u9B56\u9B55\u9C46\u9C48\u9C3F\u9C44\u9C39\u9C33\u9C41\u9C3C\u9C37\u9C34\u9C32\u9C3D\u9C36\u9DDB\u9DD2\u9DDE\u9DDA\u9DCB\u9DD0\u9DDC\u9DD1\u9DDF\u9DE9\u9DD9\u9DD8\u9DD6\u9DF5\u9DD5\u9DDD\u9EB6\u9EF0\u9F35\u9F33\u9F32\u9F42\u9F6B\u9F95\u9FA2\u513D\u5299\u58E8\u58E7\u5972\u5B4D\u5DD8\u882F\u5F4F\u6201\u6203\u6204\u6529\u6525\u6596\u66EB\u6B11\u6B12\u6B0F\u6BCA\u705B\u705A\u7222\u7382\u7381\u7383\u7670\u77D4\u7C67\u7C66\u7E95\u826C\u863A\u8640\u8639\u863C\u8631\u863B\u863E\u8830\u8832\u882E\u8833\u8976\u8974\u8973\u89FE"],
      ["f840", "\u8B8C\u8B8E\u8B8B\u8B88\u8C45\u8D19\u8E98\u8F64\u8F63\u91BC\u9462\u9455\u945D\u9457\u945E\u97C4\u97C5\u9800\u9A56\u9A59\u9B1E\u9B1F\u9B20\u9C52\u9C58\u9C50\u9C4A\u9C4D\u9C4B\u9C55\u9C59\u9C4C\u9C4E\u9DFB\u9DF7\u9DEF\u9DE3\u9DEB\u9DF8\u9DE4\u9DF6\u9DE1\u9DEE\u9DE6\u9DF2\u9DF0\u9DE2\u9DEC\u9DF4\u9DF3\u9DE8\u9DED\u9EC2\u9ED0\u9EF2\u9EF3\u9F06\u9F1C\u9F38\u9F37\u9F36\u9F43\u9F4F"],
      ["f8a1", "\u9F71\u9F70\u9F6E\u9F6F\u56D3\u56CD\u5B4E\u5C6D\u652D\u66ED\u66EE\u6B13\u705F\u7061\u705D\u7060\u7223\u74DB\u74E5\u77D5\u7938\u79B7\u79B6\u7C6A\u7E97\u7F89\u826D\u8643\u8838\u8837\u8835\u884B\u8B94\u8B95\u8E9E\u8E9F\u8EA0\u8E9D\u91BE\u91BD\u91C2\u946B\u9468\u9469\u96E5\u9746\u9743\u9747\u97C7\u97E5\u9A5E\u9AD5\u9B59\u9C63\u9C67\u9C66\u9C62\u9C5E\u9C60\u9E02\u9DFE\u9E07\u9E03\u9E06\u9E05\u9E00\u9E01\u9E09\u9DFF\u9DFD\u9E04\u9EA0\u9F1E\u9F46\u9F74\u9F75\u9F76\u56D4\u652E\u65B8\u6B18\u6B19\u6B17\u6B1A\u7062\u7226\u72AA\u77D8\u77D9\u7939\u7C69\u7C6B\u7CF6\u7E9A"],
      ["f940", "\u7E98\u7E9B\u7E99\u81E0\u81E1\u8646\u8647\u8648\u8979\u897A\u897C\u897B\u89FF\u8B98\u8B99\u8EA5\u8EA4\u8EA3\u946E\u946D\u946F\u9471\u9473\u9749\u9872\u995F\u9C68\u9C6E\u9C6D\u9E0B\u9E0D\u9E10\u9E0F\u9E12\u9E11\u9EA1\u9EF5\u9F09\u9F47\u9F78\u9F7B\u9F7A\u9F79\u571E\u7066\u7C6F\u883C\u8DB2\u8EA6\u91C3\u9474\u9478\u9476\u9475\u9A60\u9C74\u9C73\u9C71\u9C75\u9E14\u9E13\u9EF6\u9F0A"],
      ["f9a1", "\u9FA4\u7068\u7065\u7CF7\u866A\u883E\u883D\u883F\u8B9E\u8C9C\u8EA9\u8EC9\u974B\u9873\u9874\u98CC\u9961\u99AB\u9A64\u9A66\u9A67\u9B24\u9E15\u9E17\u9F48\u6207\u6B1E\u7227\u864C\u8EA8\u9482\u9480\u9481\u9A69\u9A68\u9B2E\u9E19\u7229\u864B\u8B9F\u9483\u9C79\u9EB7\u7675\u9A6B\u9C7A\u9E1D\u7069\u706A\u9EA4\u9F7E\u9F49\u9F98\u7881\u92B9\u88CF\u58BB\u6052\u7CA7\u5AFA\u2554\u2566\u2557\u2560\u256C\u2563\u255A\u2569\u255D\u2552\u2564\u2555\u255E\u256A\u2561\u2558\u2567\u255B\u2553\u2565\u2556\u255F\u256B\u2562\u2559\u2568\u255C\u2551\u2550\u256D\u256E\u2570\u256F\u2593"]
    ];
  }
});

// node_modules/iconv-lite/encodings/tables/big5-added.json
var require_big5_added = __commonJS({
  "node_modules/iconv-lite/encodings/tables/big5-added.json"(exports, module2) {
    module2.exports = [
      ["8740", "\u43F0\u4C32\u4603\u45A6\u4578\u{27267}\u4D77\u45B3\u{27CB1}\u4CE2\u{27CC5}\u3B95\u4736\u4744\u4C47\u4C40\u{242BF}\u{23617}\u{27352}\u{26E8B}\u{270D2}\u4C57\u{2A351}\u474F\u45DA\u4C85\u{27C6C}\u4D07\u4AA4\u46A1\u{26B23}\u7225\u{25A54}\u{21A63}\u{23E06}\u{23F61}\u664D\u56FB"],
      ["8767", "\u7D95\u591D\u{28BB9}\u3DF4\u9734\u{27BEF}\u5BDB\u{21D5E}\u5AA4\u3625\u{29EB0}\u5AD1\u5BB7\u5CFC\u676E\u8593\u{29945}\u7461\u749D\u3875\u{21D53}\u{2369E}\u{26021}\u3EEC"],
      ["87a1", "\u{258DE}\u3AF5\u7AFC\u9F97\u{24161}\u{2890D}\u{231EA}\u{20A8A}\u{2325E}\u430A\u8484\u9F96\u942F\u4930\u8613\u5896\u974A\u9218\u79D0\u7A32\u6660\u6A29\u889D\u744C\u7BC5\u6782\u7A2C\u524F\u9046\u34E6\u73C4\u{25DB9}\u74C6\u9FC7\u57B3\u492F\u544C\u4131\u{2368E}\u5818\u7A72\u{27B65}\u8B8F\u46AE\u{26E88}\u4181\u{25D99}\u7BAE\u{224BC}\u9FC8\u{224C1}\u{224C9}\u{224CC}\u9FC9\u8504\u{235BB}\u40B4\u9FCA\u44E1\u{2ADFF}\u62C1\u706E\u9FCB"],
      ["8840", "\u31C0", 4, "\u{2010C}\u31C5\u{200D1}\u{200CD}\u31C6\u31C7\u{200CB}\u{21FE8}\u31C8\u{200CA}\u31C9\u31CA\u31CB\u31CC\u{2010E}\u31CD\u31CE\u0100\xC1\u01CD\xC0\u0112\xC9\u011A\xC8\u014C\xD3\u01D1\xD2\u0FFF\xCA\u0304\u1EBE\u0FFF\xCA\u030C\u1EC0\xCA\u0101\xE1\u01CE\xE0\u0251\u0113\xE9\u011B\xE8\u012B\xED\u01D0\xEC\u014D\xF3\u01D2\xF2\u016B\xFA\u01D4\xF9\u01D6\u01D8\u01DA"],
      ["88a1", "\u01DC\xFC\u0FFF\xEA\u0304\u1EBF\u0FFF\xEA\u030C\u1EC1\xEA\u0261\u23DA\u23DB"],
      ["8940", "\u{2A3A9}\u{21145}"],
      ["8943", "\u650A"],
      ["8946", "\u4E3D\u6EDD\u9D4E\u91DF"],
      ["894c", "\u{27735}\u6491\u4F1A\u4F28\u4FA8\u5156\u5174\u519C\u51E4\u52A1\u52A8\u533B\u534E\u53D1\u53D8\u56E2\u58F0\u5904\u5907\u5932\u5934\u5B66\u5B9E\u5B9F\u5C9A\u5E86\u603B\u6589\u67FE\u6804\u6865\u6D4E\u70BC\u7535\u7EA4\u7EAC\u7EBA\u7EC7\u7ECF\u7EDF\u7F06\u7F37\u827A\u82CF\u836F\u89C6\u8BBE\u8BE2\u8F66\u8F67\u8F6E"],
      ["89a1", "\u7411\u7CFC\u7DCD\u6946\u7AC9\u5227"],
      ["89ab", "\u918C\u78B8\u915E\u80BC"],
      ["89b0", "\u8D0B\u80F6\u{209E7}"],
      ["89b5", "\u809F\u9EC7\u4CCD\u9DC9\u9E0C\u4C3E\u{29DF6}\u{2700E}\u9E0A\u{2A133}\u35C1"],
      ["89c1", "\u6E9A\u823E\u7519"],
      ["89c5", "\u4911\u9A6C\u9A8F\u9F99\u7987\u{2846C}\u{21DCA}\u{205D0}\u{22AE6}\u4E24\u4E81\u4E80\u4E87\u4EBF\u4EEB\u4F37\u344C\u4FBD\u3E48\u5003\u5088\u347D\u3493\u34A5\u5186\u5905\u51DB\u51FC\u5205\u4E89\u5279\u5290\u5327\u35C7\u53A9\u3551\u53B0\u3553\u53C2\u5423\u356D\u3572\u3681\u5493\u54A3\u54B4\u54B9\u54D0\u54EF\u5518\u5523\u5528\u3598\u553F\u35A5\u35BF\u55D7\u35C5"],
      ["8a40", "\u{27D84}\u5525"],
      ["8a43", "\u{20C42}\u{20D15}\u{2512B}\u5590\u{22CC6}\u39EC\u{20341}\u8E46\u{24DB8}\u{294E5}\u4053\u{280BE}\u777A\u{22C38}\u3A34\u47D5\u{2815D}\u{269F2}\u{24DEA}\u64DD\u{20D7C}\u{20FB4}\u{20CD5}\u{210F4}\u648D\u8E7E\u{20E96}\u{20C0B}\u{20F64}\u{22CA9}\u{28256}\u{244D3}"],
      ["8a64", "\u{20D46}\u{29A4D}\u{280E9}\u47F4\u{24EA7}\u{22CC2}\u9AB2\u3A67\u{295F4}\u3FED\u3506\u{252C7}\u{297D4}\u{278C8}\u{22D44}\u9D6E\u9815"],
      ["8a76", "\u43D9\u{260A5}\u64B4\u54E3\u{22D4C}\u{22BCA}\u{21077}\u39FB\u{2106F}"],
      ["8aa1", "\u{266DA}\u{26716}\u{279A0}\u64EA\u{25052}\u{20C43}\u8E68\u{221A1}\u{28B4C}\u{20731}"],
      ["8aac", "\u480B\u{201A9}\u3FFA\u5873\u{22D8D}"],
      ["8ab2", "\u{245C8}\u{204FC}\u{26097}\u{20F4C}\u{20D96}\u5579\u40BB\u43BA"],
      ["8abb", "\u4AB4\u{22A66}\u{2109D}\u81AA\u98F5\u{20D9C}\u6379\u39FE\u{22775}\u8DC0\u56A1\u647C\u3E43"],
      ["8ac9", "\u{2A601}\u{20E09}\u{22ACF}\u{22CC9}"],
      ["8ace", "\u{210C8}\u{239C2}\u3992\u3A06\u{2829B}\u3578\u{25E49}\u{220C7}\u5652\u{20F31}\u{22CB2}\u{29720}\u34BC\u6C3D\u{24E3B}"],
      ["8adf", "\u{27574}\u{22E8B}\u{22208}\u{2A65B}\u{28CCD}\u{20E7A}\u{20C34}\u{2681C}\u7F93\u{210CF}\u{22803}\u{22939}\u35FB\u{251E3}\u{20E8C}\u{20F8D}\u{20EAA}\u3F93\u{20F30}\u{20D47}\u{2114F}\u{20E4C}"],
      ["8af6", "\u{20EAB}\u{20BA9}\u{20D48}\u{210C0}\u{2113D}\u3FF9\u{22696}\u6432\u{20FAD}"],
      ["8b40", "\u{233F4}\u{27639}\u{22BCE}\u{20D7E}\u{20D7F}\u{22C51}\u{22C55}\u3A18\u{20E98}\u{210C7}\u{20F2E}\u{2A632}\u{26B50}\u{28CD2}\u{28D99}\u{28CCA}\u95AA\u54CC\u82C4\u55B9"],
      ["8b55", "\u{29EC3}\u9C26\u9AB6\u{2775E}\u{22DEE}\u7140\u816D\u80EC\u5C1C\u{26572}\u8134\u3797\u535F\u{280BD}\u91B6\u{20EFA}\u{20E0F}\u{20E77}\u{20EFB}\u35DD\u{24DEB}\u3609\u{20CD6}\u56AF\u{227B5}\u{210C9}\u{20E10}\u{20E78}\u{21078}\u{21148}\u{28207}\u{21455}\u{20E79}\u{24E50}\u{22DA4}\u5A54\u{2101D}\u{2101E}\u{210F5}\u{210F6}\u579C\u{20E11}"],
      ["8ba1", "\u{27694}\u{282CD}\u{20FB5}\u{20E7B}\u{2517E}\u3703\u{20FB6}\u{21180}\u{252D8}\u{2A2BD}\u{249DA}\u{2183A}\u{24177}\u{2827C}\u5899\u5268\u361A\u{2573D}\u7BB2\u5B68\u4800\u4B2C\u9F27\u49E7\u9C1F\u9B8D\u{25B74}\u{2313D}\u55FB\u35F2\u5689\u4E28\u5902\u{21BC1}\u{2F878}\u9751\u{20086}\u4E5B\u4EBB\u353E\u5C23\u5F51\u5FC4\u38FA\u624C\u6535\u6B7A\u6C35\u6C3A\u706C\u722B\u4E2C\u72AD\u{248E9}\u7F52\u793B\u7CF9\u7F53\u{2626A}\u34C1"],
      ["8bde", "\u{2634B}\u8002\u8080\u{26612}\u{26951}\u535D\u8864\u89C1\u{278B2}\u8BA0\u8D1D\u9485\u9578\u957F\u95E8\u{28E0F}\u97E6\u9875\u98CE\u98DE\u9963\u{29810}\u9C7C\u9E1F\u9EC4\u6B6F\uF907\u4E37\u{20087}\u961D\u6237\u94A2"],
      ["8c40", "\u503B\u6DFE\u{29C73}\u9FA6\u3DC9\u888F\u{2414E}\u7077\u5CF5\u4B20\u{251CD}\u3559\u{25D30}\u6122\u{28A32}\u8FA7\u91F6\u7191\u6719\u73BA\u{23281}\u{2A107}\u3C8B\u{21980}\u4B10\u78E4\u7402\u51AE\u{2870F}\u4009\u6A63\u{2A2BA}\u4223\u860F\u{20A6F}\u7A2A\u{29947}\u{28AEA}\u9755\u704D\u5324\u{2207E}\u93F4\u76D9\u{289E3}\u9FA7\u77DD\u4EA3\u4FF0\u50BC\u4E2F\u4F17\u9FA8\u5434\u7D8B\u5892\u58D0\u{21DB6}\u5E92\u5E99\u5FC2\u{22712}\u658B"],
      ["8ca1", "\u{233F9}\u6919\u6A43\u{23C63}\u6CFF"],
      ["8ca7", "\u7200\u{24505}\u738C\u3EDB\u{24A13}\u5B15\u74B9\u8B83\u{25CA4}\u{25695}\u7A93\u7BEC\u7CC3\u7E6C\u82F8\u8597\u9FA9\u8890\u9FAA\u8EB9\u9FAB\u8FCF\u855F\u99E0\u9221\u9FAC\u{28DB9}\u{2143F}\u4071\u42A2\u5A1A"],
      ["8cc9", "\u9868\u676B\u4276\u573D"],
      ["8cce", "\u85D6\u{2497B}\u82BF\u{2710D}\u4C81\u{26D74}\u5D7B\u{26B15}\u{26FBE}\u9FAD\u9FAE\u5B96\u9FAF\u66E7\u7E5B\u6E57\u79CA\u3D88\u44C3\u{23256}\u{22796}\u439A\u4536"],
      ["8ce6", "\u5CD5\u{23B1A}\u8AF9\u5C78\u3D12\u{23551}\u5D78\u9FB2\u7157\u4558\u{240EC}\u{21E23}\u4C77\u3978\u344A\u{201A4}\u{26C41}\u8ACC\u4FB4\u{20239}\u59BF\u816C\u9856\u{298FA}\u5F3B"],
      ["8d40", "\u{20B9F}"],
      ["8d42", "\u{221C1}\u{2896D}\u4102\u46BB\u{29079}\u3F07\u9FB3\u{2A1B5}\u40F8\u37D6\u46F7\u{26C46}\u417C\u{286B2}\u{273FF}\u456D\u38D4\u{2549A}\u4561\u451B\u4D89\u4C7B\u4D76\u45EA\u3FC8\u{24B0F}\u3661\u44DE\u44BD\u41ED\u5D3E\u5D48\u5D56\u3DFC\u380F\u5DA4\u5DB9\u3820\u3838\u5E42\u5EBD\u5F25\u5F83\u3908\u3914\u393F\u394D\u60D7\u613D\u5CE5\u3989\u61B7\u61B9\u61CF\u39B8\u622C\u6290\u62E5\u6318\u39F8\u56B1"],
      ["8da1", "\u3A03\u63E2\u63FB\u6407\u645A\u3A4B\u64C0\u5D15\u5621\u9F9F\u3A97\u6586\u3ABD\u65FF\u6653\u3AF2\u6692\u3B22\u6716\u3B42\u67A4\u6800\u3B58\u684A\u6884\u3B72\u3B71\u3B7B\u6909\u6943\u725C\u6964\u699F\u6985\u3BBC\u69D6\u3BDD\u6A65\u6A74\u6A71\u6A82\u3BEC\u6A99\u3BF2\u6AAB\u6AB5\u6AD4\u6AF6\u6B81\u6BC1\u6BEA\u6C75\u6CAA\u3CCB\u6D02\u6D06\u6D26\u6D81\u3CEF\u6DA4\u6DB1\u6E15\u6E18\u6E29\u6E86\u{289C0}\u6EBB\u6EE2\u6EDA\u9F7F\u6EE8\u6EE9\u6F24\u6F34\u3D46\u{23F41}\u6F81\u6FBE\u3D6A\u3D75\u71B7\u5C99\u3D8A\u702C\u3D91\u7050\u7054\u706F\u707F\u7089\u{20325}\u43C1\u35F1\u{20ED8}"],
      ["8e40", "\u{23ED7}\u57BE\u{26ED3}\u713E\u{257E0}\u364E\u69A2\u{28BE9}\u5B74\u7A49\u{258E1}\u{294D9}\u7A65\u7A7D\u{259AC}\u7ABB\u7AB0\u7AC2\u7AC3\u71D1\u{2648D}\u41CA\u7ADA\u7ADD\u7AEA\u41EF\u54B2\u{25C01}\u7B0B\u7B55\u7B29\u{2530E}\u{25CFE}\u7BA2\u7B6F\u839C\u{25BB4}\u{26C7F}\u7BD0\u8421\u7B92\u7BB8\u{25D20}\u3DAD\u{25C65}\u8492\u7BFA\u7C06\u7C35\u{25CC1}\u7C44\u7C83\u{24882}\u7CA6\u667D\u{24578}\u7CC9\u7CC7\u7CE6\u7C74\u7CF3\u7CF5\u7CCE"],
      ["8ea1", "\u7E67\u451D\u{26E44}\u7D5D\u{26ED6}\u748D\u7D89\u7DAB\u7135\u7DB3\u7DD2\u{24057}\u{26029}\u7DE4\u3D13\u7DF5\u{217F9}\u7DE5\u{2836D}\u7E1D\u{26121}\u{2615A}\u7E6E\u7E92\u432B\u946C\u7E27\u7F40\u7F41\u7F47\u7936\u{262D0}\u99E1\u7F97\u{26351}\u7FA3\u{21661}\u{20068}\u455C\u{23766}\u4503\u{2833A}\u7FFA\u{26489}\u8005\u8008\u801D\u8028\u802F\u{2A087}\u{26CC3}\u803B\u803C\u8061\u{22714}\u4989\u{26626}\u{23DE3}\u{266E8}\u6725\u80A7\u{28A48}\u8107\u811A\u58B0\u{226F6}\u6C7F\u{26498}\u{24FB8}\u64E7\u{2148A}\u8218\u{2185E}\u6A53\u{24A65}\u{24A95}\u447A\u8229\u{20B0D}\u{26A52}\u{23D7E}\u4FF9\u{214FD}\u84E2\u8362\u{26B0A}\u{249A7}\u{23530}\u{21773}\u{23DF8}\u82AA\u691B\u{2F994}\u41DB"],
      ["8f40", "\u854B\u82D0\u831A\u{20E16}\u{217B4}\u36C1\u{2317D}\u{2355A}\u827B\u82E2\u8318\u{23E8B}\u{26DA3}\u{26B05}\u{26B97}\u{235CE}\u3DBF\u831D\u55EC\u8385\u450B\u{26DA5}\u83AC\u83C1\u83D3\u347E\u{26ED4}\u6A57\u855A\u3496\u{26E42}\u{22EEF}\u8458\u{25BE4}\u8471\u3DD3\u44E4\u6AA7\u844A\u{23CB5}\u7958\u84A8\u{26B96}\u{26E77}\u{26E43}\u84DE\u840F\u8391\u44A0\u8493\u84E4\u{25C91}\u4240\u{25CC0}\u4543\u8534\u5AF2\u{26E99}\u4527\u8573\u4516\u67BF\u8616"],
      ["8fa1", "\u{28625}\u{2863B}\u85C1\u{27088}\u8602\u{21582}\u{270CD}\u{2F9B2}\u456A\u8628\u3648\u{218A2}\u53F7\u{2739A}\u867E\u8771\u{2A0F8}\u87EE\u{22C27}\u87B1\u87DA\u880F\u5661\u866C\u6856\u460F\u8845\u8846\u{275E0}\u{23DB9}\u{275E4}\u885E\u889C\u465B\u88B4\u88B5\u63C1\u88C5\u7777\u{2770F}\u8987\u898A\u89A6\u89A9\u89A7\u89BC\u{28A25}\u89E7\u{27924}\u{27ABD}\u8A9C\u7793\u91FE\u8A90\u{27A59}\u7AE9\u{27B3A}\u{23F8F}\u4713\u{27B38}\u717C\u8B0C\u8B1F\u{25430}\u{25565}\u8B3F\u8B4C\u8B4D\u8AA9\u{24A7A}\u8B90\u8B9B\u8AAF\u{216DF}\u4615\u884F\u8C9B\u{27D54}\u{27D8F}\u{2F9D4}\u3725\u{27D53}\u8CD6\u{27D98}\u{27DBD}\u8D12\u8D03\u{21910}\u8CDB\u705C\u8D11\u{24CC9}\u3ED0\u8D77"],
      ["9040", "\u8DA9\u{28002}\u{21014}\u{2498A}\u3B7C\u{281BC}\u{2710C}\u7AE7\u8EAD\u8EB6\u8EC3\u92D4\u8F19\u8F2D\u{28365}\u{28412}\u8FA5\u9303\u{2A29F}\u{20A50}\u8FB3\u492A\u{289DE}\u{2853D}\u{23DBB}\u5EF8\u{23262}\u8FF9\u{2A014}\u{286BC}\u{28501}\u{22325}\u3980\u{26ED7}\u9037\u{2853C}\u{27ABE}\u9061\u{2856C}\u{2860B}\u90A8\u{28713}\u90C4\u{286E6}\u90AE\u90FD\u9167\u3AF0\u91A9\u91C4\u7CAC\u{28933}\u{21E89}\u920E\u6C9F\u9241\u9262\u{255B9}\u92B9\u{28AC6}\u{23C9B}\u{28B0C}\u{255DB}"],
      ["90a1", "\u{20D31}\u932C\u936B\u{28AE1}\u{28BEB}\u708F\u5AC3\u{28AE2}\u{28AE5}\u4965\u9244\u{28BEC}\u{28C39}\u{28BFF}\u9373\u945B\u8EBC\u9585\u95A6\u9426\u95A0\u6FF6\u42B9\u{2267A}\u{286D8}\u{2127C}\u{23E2E}\u49DF\u6C1C\u967B\u9696\u416C\u96A3\u{26ED5}\u61DA\u96B6\u78F5\u{28AE0}\u96BD\u53CC\u49A1\u{26CB8}\u{20274}\u{26410}\u{290AF}\u{290E5}\u{24AD1}\u{21915}\u{2330A}\u9731\u8642\u9736\u4A0F\u453D\u4585\u{24AE9}\u7075\u5B41\u971B\u975C\u{291D5}\u9757\u5B4A\u{291EB}\u975F\u9425\u50D0\u{230B7}\u{230BC}\u9789\u979F\u97B1\u97BE\u97C0\u97D2\u97E0\u{2546C}\u97EE\u741C\u{29433}\u97FF\u97F5\u{2941D}\u{2797A}\u4AD1\u9834\u9833\u984B\u9866\u3B0E\u{27175}\u3D51\u{20630}\u{2415C}"],
      ["9140", "\u{25706}\u98CA\u98B7\u98C8\u98C7\u4AFF\u{26D27}\u{216D3}\u55B0\u98E1\u98E6\u98EC\u9378\u9939\u{24A29}\u4B72\u{29857}\u{29905}\u99F5\u9A0C\u9A3B\u9A10\u9A58\u{25725}\u36C4\u{290B1}\u{29BD5}\u9AE0\u9AE2\u{29B05}\u9AF4\u4C0E\u9B14\u9B2D\u{28600}\u5034\u9B34\u{269A8}\u38C3\u{2307D}\u9B50\u9B40\u{29D3E}\u5A45\u{21863}\u9B8E\u{2424B}\u9C02\u9BFF\u9C0C\u{29E68}\u9DD4\u{29FB7}\u{2A192}\u{2A1AB}\u{2A0E1}\u{2A123}\u{2A1DF}\u9D7E\u9D83\u{2A134}\u9E0E\u6888"],
      ["91a1", "\u9DC4\u{2215B}\u{2A193}\u{2A220}\u{2193B}\u{2A233}\u9D39\u{2A0B9}\u{2A2B4}\u9E90\u9E95\u9E9E\u9EA2\u4D34\u9EAA\u9EAF\u{24364}\u9EC1\u3B60\u39E5\u3D1D\u4F32\u37BE\u{28C2B}\u9F02\u9F08\u4B96\u9424\u{26DA2}\u9F17\u9F16\u9F39\u569F\u568A\u9F45\u99B8\u{2908B}\u97F2\u847F\u9F62\u9F69\u7ADC\u9F8E\u7216\u4BBE\u{24975}\u{249BB}\u7177\u{249F8}\u{24348}\u{24A51}\u739E\u{28BDA}\u{218FA}\u799F\u{2897E}\u{28E36}\u9369\u93F3\u{28A44}\u92EC\u9381\u93CB\u{2896C}\u{244B9}\u7217\u3EEB\u7772\u7A43\u70D0\u{24473}\u{243F8}\u717E\u{217EF}\u70A3\u{218BE}\u{23599}\u3EC7\u{21885}\u{2542F}\u{217F8}\u3722\u{216FB}\u{21839}\u36E1\u{21774}\u{218D1}\u{25F4B}\u3723\u{216C0}\u575B\u{24A25}\u{213FE}\u{212A8}"],
      ["9240", "\u{213C6}\u{214B6}\u8503\u{236A6}\u8503\u8455\u{24994}\u{27165}\u{23E31}\u{2555C}\u{23EFB}\u{27052}\u44F4\u{236EE}\u{2999D}\u{26F26}\u67F9\u3733\u3C15\u3DE7\u586C\u{21922}\u6810\u4057\u{2373F}\u{240E1}\u{2408B}\u{2410F}\u{26C21}\u54CB\u569E\u{266B1}\u5692\u{20FDF}\u{20BA8}\u{20E0D}\u93C6\u{28B13}\u939C\u4EF8\u512B\u3819\u{24436}\u4EBC\u{20465}\u{2037F}\u4F4B\u4F8A\u{25651}\u5A68\u{201AB}\u{203CB}\u3999\u{2030A}\u{20414}\u3435\u4F29\u{202C0}\u{28EB3}\u{20275}\u8ADA\u{2020C}\u4E98"],
      ["92a1", "\u50CD\u510D\u4FA2\u4F03\u{24A0E}\u{23E8A}\u4F42\u502E\u506C\u5081\u4FCC\u4FE5\u5058\u50FC\u5159\u515B\u515D\u515E\u6E76\u{23595}\u{23E39}\u{23EBF}\u6D72\u{21884}\u{23E89}\u51A8\u51C3\u{205E0}\u44DD\u{204A3}\u{20492}\u{20491}\u8D7A\u{28A9C}\u{2070E}\u5259\u52A4\u{20873}\u52E1\u936E\u467A\u718C\u{2438C}\u{20C20}\u{249AC}\u{210E4}\u69D1\u{20E1D}\u7479\u3EDE\u7499\u7414\u7456\u7398\u4B8E\u{24ABC}\u{2408D}\u53D0\u3584\u720F\u{240C9}\u55B4\u{20345}\u54CD\u{20BC6}\u571D\u925D\u96F4\u9366\u57DD\u578D\u577F\u363E\u58CB\u5A99\u{28A46}\u{216FA}\u{2176F}\u{21710}\u5A2C\u59B8\u928F\u5A7E\u5ACF\u5A12\u{25946}\u{219F3}\u{21861}\u{24295}\u36F5\u6D05\u7443\u5A21\u{25E83}"],
      ["9340", "\u5A81\u{28BD7}\u{20413}\u93E0\u748C\u{21303}\u7105\u4972\u9408\u{289FB}\u93BD\u37A0\u5C1E\u5C9E\u5E5E\u5E48\u{21996}\u{2197C}\u{23AEE}\u5ECD\u5B4F\u{21903}\u{21904}\u3701\u{218A0}\u36DD\u{216FE}\u36D3\u812A\u{28A47}\u{21DBA}\u{23472}\u{289A8}\u5F0C\u5F0E\u{21927}\u{217AB}\u5A6B\u{2173B}\u5B44\u8614\u{275FD}\u8860\u607E\u{22860}\u{2262B}\u5FDB\u3EB8\u{225AF}\u{225BE}\u{29088}\u{26F73}\u61C0\u{2003E}\u{20046}\u{2261B}\u6199\u6198\u6075\u{22C9B}\u{22D07}\u{246D4}\u{2914D}"],
      ["93a1", "\u6471\u{24665}\u{22B6A}\u3A29\u{22B22}\u{23450}\u{298EA}\u{22E78}\u6337\u{2A45B}\u64B6\u6331\u63D1\u{249E3}\u{22D67}\u62A4\u{22CA1}\u643B\u656B\u6972\u3BF4\u{2308E}\u{232AD}\u{24989}\u{232AB}\u550D\u{232E0}\u{218D9}\u{2943F}\u66CE\u{23289}\u{231B3}\u3AE0\u4190\u{25584}\u{28B22}\u{2558F}\u{216FC}\u{2555B}\u{25425}\u78EE\u{23103}\u{2182A}\u{23234}\u3464\u{2320F}\u{23182}\u{242C9}\u668E\u{26D24}\u666B\u4B93\u6630\u{27870}\u{21DEB}\u6663\u{232D2}\u{232E1}\u661E\u{25872}\u38D1\u{2383A}\u{237BC}\u3B99\u{237A2}\u{233FE}\u74D0\u3B96\u678F\u{2462A}\u68B6\u681E\u3BC4\u6ABE\u3863\u{237D5}\u{24487}\u6A33\u6A52\u6AC9\u6B05\u{21912}\u6511\u6898\u6A4C\u3BD7\u6A7A\u6B57\u{23FC0}\u{23C9A}\u93A0\u92F2\u{28BEA}\u{28ACB}"],
      ["9440", "\u9289\u{2801E}\u{289DC}\u9467\u6DA5\u6F0B\u{249EC}\u6D67\u{23F7F}\u3D8F\u6E04\u{2403C}\u5A3D\u6E0A\u5847\u6D24\u7842\u713B\u{2431A}\u{24276}\u70F1\u7250\u7287\u7294\u{2478F}\u{24725}\u5179\u{24AA4}\u{205EB}\u747A\u{23EF8}\u{2365F}\u{24A4A}\u{24917}\u{25FE1}\u3F06\u3EB1\u{24ADF}\u{28C23}\u{23F35}\u60A7\u3EF3\u74CC\u743C\u9387\u7437\u449F\u{26DEA}\u4551\u7583\u3F63\u{24CD9}\u{24D06}\u3F58\u7555\u7673\u{2A5C6}\u3B19\u7468\u{28ACC}\u{249AB}\u{2498E}\u3AFB"],
      ["94a1", "\u3DCD\u{24A4E}\u3EFF\u{249C5}\u{248F3}\u91FA\u5732\u9342\u{28AE3}\u{21864}\u50DF\u{25221}\u{251E7}\u7778\u{23232}\u770E\u770F\u777B\u{24697}\u{23781}\u3A5E\u{248F0}\u7438\u749B\u3EBF\u{24ABA}\u{24AC7}\u40C8\u{24A96}\u{261AE}\u9307\u{25581}\u781E\u788D\u7888\u78D2\u73D0\u7959\u{27741}\u{256E3}\u410E\u799B\u8496\u79A5\u6A2D\u{23EFA}\u7A3A\u79F4\u416E\u{216E6}\u4132\u9235\u79F1\u{20D4C}\u{2498C}\u{20299}\u{23DBA}\u{2176E}\u3597\u556B\u3570\u36AA\u{201D4}\u{20C0D}\u7AE2\u5A59\u{226F5}\u{25AAF}\u{25A9C}\u5A0D\u{2025B}\u78F0\u5A2A\u{25BC6}\u7AFE\u41F9\u7C5D\u7C6D\u4211\u{25BB3}\u{25EBC}\u{25EA6}\u7CCD\u{249F9}\u{217B0}\u7C8E\u7C7C\u7CAE\u6AB2\u7DDC\u7E07\u7DD3\u7F4E\u{26261}"],
      ["9540", "\u{2615C}\u{27B48}\u7D97\u{25E82}\u426A\u{26B75}\u{20916}\u67D6\u{2004E}\u{235CF}\u57C4\u{26412}\u{263F8}\u{24962}\u7FDD\u7B27\u{2082C}\u{25AE9}\u{25D43}\u7B0C\u{25E0E}\u99E6\u8645\u9A63\u6A1C\u{2343F}\u39E2\u{249F7}\u{265AD}\u9A1F\u{265A0}\u8480\u{27127}\u{26CD1}\u44EA\u8137\u4402\u80C6\u8109\u8142\u{267B4}\u98C3\u{26A42}\u8262\u8265\u{26A51}\u8453\u{26DA7}\u8610\u{2721B}\u5A86\u417F\u{21840}\u5B2B\u{218A1}\u5AE4\u{218D8}\u86A0\u{2F9BC}\u{23D8F}\u882D\u{27422}\u5A02"],
      ["95a1", "\u886E\u4F45\u8887\u88BF\u88E6\u8965\u894D\u{25683}\u8954\u{27785}\u{27784}\u{28BF5}\u{28BD9}\u{28B9C}\u{289F9}\u3EAD\u84A3\u46F5\u46CF\u37F2\u8A3D\u8A1C\u{29448}\u5F4D\u922B\u{24284}\u65D4\u7129\u70C4\u{21845}\u9D6D\u8C9F\u8CE9\u{27DDC}\u599A\u77C3\u59F0\u436E\u36D4\u8E2A\u8EA7\u{24C09}\u8F30\u8F4A\u42F4\u6C58\u6FBB\u{22321}\u489B\u6F79\u6E8B\u{217DA}\u9BE9\u36B5\u{2492F}\u90BB\u9097\u5571\u4906\u91BB\u9404\u{28A4B}\u4062\u{28AFC}\u9427\u{28C1D}\u{28C3B}\u84E5\u8A2B\u9599\u95A7\u9597\u9596\u{28D34}\u7445\u3EC2\u{248FF}\u{24A42}\u{243EA}\u3EE7\u{23225}\u968F\u{28EE7}\u{28E66}\u{28E65}\u3ECC\u{249ED}\u{24A78}\u{23FEE}\u7412\u746B\u3EFC\u9741\u{290B0}"],
      ["9640", "\u6847\u4A1D\u{29093}\u{257DF}\u975D\u9368\u{28989}\u{28C26}\u{28B2F}\u{263BE}\u92BA\u5B11\u8B69\u493C\u73F9\u{2421B}\u979B\u9771\u9938\u{20F26}\u5DC1\u{28BC5}\u{24AB2}\u981F\u{294DA}\u92F6\u{295D7}\u91E5\u44C0\u{28B50}\u{24A67}\u{28B64}\u98DC\u{28A45}\u3F00\u922A\u4925\u8414\u993B\u994D\u{27B06}\u3DFD\u999B\u4B6F\u99AA\u9A5C\u{28B65}\u{258C8}\u6A8F\u9A21\u5AFE\u9A2F\u{298F1}\u4B90\u{29948}\u99BC\u4BBD\u4B97\u937D\u5872\u{21302}\u5822\u{249B8}"],
      ["96a1", "\u{214E8}\u7844\u{2271F}\u{23DB8}\u68C5\u3D7D\u9458\u3927\u6150\u{22781}\u{2296B}\u6107\u9C4F\u9C53\u9C7B\u9C35\u9C10\u9B7F\u9BCF\u{29E2D}\u9B9F\u{2A1F5}\u{2A0FE}\u9D21\u4CAE\u{24104}\u9E18\u4CB0\u9D0C\u{2A1B4}\u{2A0ED}\u{2A0F3}\u{2992F}\u9DA5\u84BD\u{26E12}\u{26FDF}\u{26B82}\u85FC\u4533\u{26DA4}\u{26E84}\u{26DF0}\u8420\u85EE\u{26E00}\u{237D7}\u{26064}\u79E2\u{2359C}\u{23640}\u492D\u{249DE}\u3D62\u93DB\u92BE\u9348\u{202BF}\u78B9\u9277\u944D\u4FE4\u3440\u9064\u{2555D}\u783D\u7854\u78B6\u784B\u{21757}\u{231C9}\u{24941}\u369A\u4F72\u6FDA\u6FD9\u701E\u701E\u5414\u{241B5}\u57BB\u58F3\u578A\u9D16\u57D7\u7134\u34AF\u{241AC}\u71EB\u{26C40}\u{24F97}\u5B28\u{217B5}\u{28A49}"],
      ["9740", "\u610C\u5ACE\u5A0B\u42BC\u{24488}\u372C\u4B7B\u{289FC}\u93BB\u93B8\u{218D6}\u{20F1D}\u8472\u{26CC0}\u{21413}\u{242FA}\u{22C26}\u{243C1}\u5994\u{23DB7}\u{26741}\u7DA8\u{2615B}\u{260A4}\u{249B9}\u{2498B}\u{289FA}\u92E5\u73E2\u3EE9\u74B4\u{28B63}\u{2189F}\u3EE1\u{24AB3}\u6AD8\u73F3\u73FB\u3ED6\u{24A3E}\u{24A94}\u{217D9}\u{24A66}\u{203A7}\u{21424}\u{249E5}\u7448\u{24916}\u70A5\u{24976}\u9284\u73E6\u935F\u{204FE}\u9331\u{28ACE}\u{28A16}\u9386\u{28BE7}\u{255D5}\u4935\u{28A82}\u716B"],
      ["97a1", "\u{24943}\u{20CFF}\u56A4\u{2061A}\u{20BEB}\u{20CB8}\u5502\u79C4\u{217FA}\u7DFE\u{216C2}\u{24A50}\u{21852}\u452E\u9401\u370A\u{28AC0}\u{249AD}\u59B0\u{218BF}\u{21883}\u{27484}\u5AA1\u36E2\u{23D5B}\u36B0\u925F\u5A79\u{28A81}\u{21862}\u9374\u3CCD\u{20AB4}\u4A96\u398A\u50F4\u3D69\u3D4C\u{2139C}\u7175\u42FB\u{28218}\u6E0F\u{290E4}\u44EB\u6D57\u{27E4F}\u7067\u6CAF\u3CD6\u{23FED}\u{23E2D}\u6E02\u6F0C\u3D6F\u{203F5}\u7551\u36BC\u34C8\u4680\u3EDA\u4871\u59C4\u926E\u493E\u8F41\u{28C1C}\u{26BC0}\u5812\u57C8\u36D6\u{21452}\u70FE\u{24362}\u{24A71}\u{22FE3}\u{212B0}\u{223BD}\u68B9\u6967\u{21398}\u{234E5}\u{27BF4}\u{236DF}\u{28A83}\u{237D6}\u{233FA}\u{24C9F}\u6A1A\u{236AD}\u{26CB7}\u843E\u44DF\u44CE"],
      ["9840", "\u{26D26}\u{26D51}\u{26C82}\u{26FDE}\u6F17\u{27109}\u833D\u{2173A}\u83ED\u{26C80}\u{27053}\u{217DB}\u5989\u5A82\u{217B3}\u5A61\u5A71\u{21905}\u{241FC}\u372D\u59EF\u{2173C}\u36C7\u718E\u9390\u669A\u{242A5}\u5A6E\u5A2B\u{24293}\u6A2B\u{23EF9}\u{27736}\u{2445B}\u{242CA}\u711D\u{24259}\u{289E1}\u4FB0\u{26D28}\u5CC2\u{244CE}\u{27E4D}\u{243BD}\u6A0C\u{24256}\u{21304}\u70A6\u7133\u{243E9}\u3DA5\u6CDF\u{2F825}\u{24A4F}\u7E65\u59EB\u5D2F\u3DF3\u5F5C\u{24A5D}\u{217DF}\u7DA4\u8426"],
      ["98a1", "\u5485\u{23AFA}\u{23300}\u{20214}\u577E\u{208D5}\u{20619}\u3FE5\u{21F9E}\u{2A2B6}\u7003\u{2915B}\u5D70\u738F\u7CD3\u{28A59}\u{29420}\u4FC8\u7FE7\u72CD\u7310\u{27AF4}\u7338\u7339\u{256F6}\u7341\u7348\u3EA9\u{27B18}\u906C\u71F5\u{248F2}\u73E1\u81F6\u3ECA\u770C\u3ED1\u6CA2\u56FD\u7419\u741E\u741F\u3EE2\u3EF0\u3EF4\u3EFA\u74D3\u3F0E\u3F53\u7542\u756D\u7572\u758D\u3F7C\u75C8\u75DC\u3FC0\u764D\u3FD7\u7674\u3FDC\u767A\u{24F5C}\u7188\u5623\u8980\u5869\u401D\u7743\u4039\u6761\u4045\u35DB\u7798\u406A\u406F\u5C5E\u77BE\u77CB\u58F2\u7818\u70B9\u781C\u40A8\u7839\u7847\u7851\u7866\u8448\u{25535}\u7933\u6803\u7932\u4103"],
      ["9940", "\u4109\u7991\u7999\u8FBB\u7A06\u8FBC\u4167\u7A91\u41B2\u7ABC\u8279\u41C4\u7ACF\u7ADB\u41CF\u4E21\u7B62\u7B6C\u7B7B\u7C12\u7C1B\u4260\u427A\u7C7B\u7C9C\u428C\u7CB8\u4294\u7CED\u8F93\u70C0\u{20CCF}\u7DCF\u7DD4\u7DD0\u7DFD\u7FAE\u7FB4\u729F\u4397\u8020\u8025\u7B39\u802E\u8031\u8054\u3DCC\u57B4\u70A0\u80B7\u80E9\u43ED\u810C\u732A\u810E\u8112\u7560\u8114\u4401\u3B39\u8156\u8159\u815A"],
      ["99a1", "\u4413\u583A\u817C\u8184\u4425\u8193\u442D\u81A5\u57EF\u81C1\u81E4\u8254\u448F\u82A6\u8276\u82CA\u82D8\u82FF\u44B0\u8357\u9669\u698A\u8405\u70F5\u8464\u60E3\u8488\u4504\u84BE\u84E1\u84F8\u8510\u8538\u8552\u453B\u856F\u8570\u85E0\u4577\u8672\u8692\u86B2\u86EF\u9645\u878B\u4606\u4617\u88AE\u88FF\u8924\u8947\u8991\u{27967}\u8A29\u8A38\u8A94\u8AB4\u8C51\u8CD4\u8CF2\u8D1C\u4798\u585F\u8DC3\u47ED\u4EEE\u8E3A\u55D8\u5754\u8E71\u55F5\u8EB0\u4837\u8ECE\u8EE2\u8EE4\u8EED\u8EF2\u8FB7\u8FC1\u8FCA\u8FCC\u9033\u99C4\u48AD\u98E0\u9213\u491E\u9228\u9258\u926B\u92B1\u92AE\u92BF"],
      ["9a40", "\u92E3\u92EB\u92F3\u92F4\u92FD\u9343\u9384\u93AD\u4945\u4951\u9EBF\u9417\u5301\u941D\u942D\u943E\u496A\u9454\u9479\u952D\u95A2\u49A7\u95F4\u9633\u49E5\u67A0\u4A24\u9740\u4A35\u97B2\u97C2\u5654\u4AE4\u60E8\u98B9\u4B19\u98F1\u5844\u990E\u9919\u51B4\u991C\u9937\u9942\u995D\u9962\u4B70\u99C5\u4B9D\u9A3C\u9B0F\u7A83\u9B69\u9B81\u9BDD\u9BF1\u9BF4\u4C6D\u9C20\u376F\u{21BC2}\u9D49\u9C3A"],
      ["9aa1", "\u9EFE\u5650\u9D93\u9DBD\u9DC0\u9DFC\u94F6\u8FB6\u9E7B\u9EAC\u9EB1\u9EBD\u9EC6\u94DC\u9EE2\u9EF1\u9EF8\u7AC8\u9F44\u{20094}\u{202B7}\u{203A0}\u691A\u94C3\u59AC\u{204D7}\u5840\u94C1\u37B9\u{205D5}\u{20615}\u{20676}\u{216BA}\u5757\u7173\u{20AC2}\u{20ACD}\u{20BBF}\u546A\u{2F83B}\u{20BCB}\u549E\u{20BFB}\u{20C3B}\u{20C53}\u{20C65}\u{20C7C}\u60E7\u{20C8D}\u567A\u{20CB5}\u{20CDD}\u{20CED}\u{20D6F}\u{20DB2}\u{20DC8}\u6955\u9C2F\u87A5\u{20E04}\u{20E0E}\u{20ED7}\u{20F90}\u{20F2D}\u{20E73}\u5C20\u{20FBC}\u5E0B\u{2105C}\u{2104F}\u{21076}\u671E\u{2107B}\u{21088}\u{21096}\u3647\u{210BF}\u{210D3}\u{2112F}\u{2113B}\u5364\u84AD\u{212E3}\u{21375}\u{21336}\u8B81\u{21577}\u{21619}\u{217C3}\u{217C7}\u4E78\u70BB\u{2182D}\u{2196A}"],
      ["9b40", "\u{21A2D}\u{21A45}\u{21C2A}\u{21C70}\u{21CAC}\u{21EC8}\u62C3\u{21ED5}\u{21F15}\u7198\u6855\u{22045}\u69E9\u36C8\u{2227C}\u{223D7}\u{223FA}\u{2272A}\u{22871}\u{2294F}\u82FD\u{22967}\u{22993}\u{22AD5}\u89A5\u{22AE8}\u8FA0\u{22B0E}\u97B8\u{22B3F}\u9847\u9ABD\u{22C4C}"],
      ["9b62", "\u{22C88}\u{22CB7}\u{25BE8}\u{22D08}\u{22D12}\u{22DB7}\u{22D95}\u{22E42}\u{22F74}\u{22FCC}\u{23033}\u{23066}\u{2331F}\u{233DE}\u5FB1\u6648\u66BF\u{27A79}\u{23567}\u{235F3}\u7201\u{249BA}\u77D7\u{2361A}\u{23716}\u7E87\u{20346}\u58B5\u670E"],
      ["9ba1", "\u6918\u{23AA7}\u{27657}\u{25FE2}\u{23E11}\u{23EB9}\u{275FE}\u{2209A}\u48D0\u4AB8\u{24119}\u{28A9A}\u{242EE}\u{2430D}\u{2403B}\u{24334}\u{24396}\u{24A45}\u{205CA}\u51D2\u{20611}\u599F\u{21EA8}\u3BBE\u{23CFF}\u{24404}\u{244D6}\u5788\u{24674}\u399B\u{2472F}\u{285E8}\u{299C9}\u3762\u{221C3}\u8B5E\u{28B4E}\u99D6\u{24812}\u{248FB}\u{24A15}\u7209\u{24AC0}\u{20C78}\u5965\u{24EA5}\u{24F86}\u{20779}\u8EDA\u{2502C}\u528F\u573F\u7171\u{25299}\u{25419}\u{23F4A}\u{24AA7}\u55BC\u{25446}\u{2546E}\u{26B52}\u91D4\u3473\u{2553F}\u{27632}\u{2555E}\u4718\u{25562}\u{25566}\u{257C7}\u{2493F}\u{2585D}\u5066\u34FB\u{233CC}\u60DE\u{25903}\u477C\u{28948}\u{25AAE}\u{25B89}\u{25C06}\u{21D90}\u57A1\u7151\u6FB6\u{26102}\u{27C12}\u9056\u{261B2}\u{24F9A}\u8B62\u{26402}\u{2644A}"],
      ["9c40", "\u5D5B\u{26BF7}\u8F36\u{26484}\u{2191C}\u8AEA\u{249F6}\u{26488}\u{23FEF}\u{26512}\u4BC0\u{265BF}\u{266B5}\u{2271B}\u9465\u{257E1}\u6195\u5A27\u{2F8CD}\u4FBB\u56B9\u{24521}\u{266FC}\u4E6A\u{24934}\u9656\u6D8F\u{26CBD}\u3618\u8977\u{26799}\u{2686E}\u{26411}\u{2685E}\u71DF\u{268C7}\u7B42\u{290C0}\u{20A11}\u{26926}\u9104\u{26939}\u7A45\u9DF0\u{269FA}\u9A26\u{26A2D}\u365F\u{26469}\u{20021}\u7983\u{26A34}\u{26B5B}\u5D2C\u{23519}\u83CF\u{26B9D}\u46D0\u{26CA4}\u753B\u8865\u{26DAE}\u58B6"],
      ["9ca1", "\u371C\u{2258D}\u{2704B}\u{271CD}\u3C54\u{27280}\u{27285}\u9281\u{2217A}\u{2728B}\u9330\u{272E6}\u{249D0}\u6C39\u949F\u{27450}\u{20EF8}\u8827\u88F5\u{22926}\u{28473}\u{217B1}\u6EB8\u{24A2A}\u{21820}\u39A4\u36B9\u5C10\u79E3\u453F\u66B6\u{29CAD}\u{298A4}\u8943\u{277CC}\u{27858}\u56D6\u40DF\u{2160A}\u39A1\u{2372F}\u{280E8}\u{213C5}\u71AD\u8366\u{279DD}\u{291A8}\u5A67\u4CB7\u{270AF}\u{289AB}\u{279FD}\u{27A0A}\u{27B0B}\u{27D66}\u{2417A}\u7B43\u797E\u{28009}\u6FB5\u{2A2DF}\u6A03\u{28318}\u53A2\u{26E07}\u93BF\u6836\u975D\u{2816F}\u{28023}\u{269B5}\u{213ED}\u{2322F}\u{28048}\u5D85\u{28C30}\u{28083}\u5715\u9823\u{28949}\u5DAB\u{24988}\u65BE\u69D5\u53D2\u{24AA5}\u{23F81}\u3C11\u6736\u{28090}\u{280F4}\u{2812E}\u{21FA1}\u{2814F}"],
      ["9d40", "\u{28189}\u{281AF}\u{2821A}\u{28306}\u{2832F}\u{2838A}\u35CA\u{28468}\u{286AA}\u48FA\u63E6\u{28956}\u7808\u9255\u{289B8}\u43F2\u{289E7}\u43DF\u{289E8}\u{28B46}\u{28BD4}\u59F8\u{28C09}\u8F0B\u{28FC5}\u{290EC}\u7B51\u{29110}\u{2913C}\u3DF7\u{2915E}\u{24ACA}\u8FD0\u728F\u568B\u{294E7}\u{295E9}\u{295B0}\u{295B8}\u{29732}\u{298D1}\u{29949}\u{2996A}\u{299C3}\u{29A28}\u{29B0E}\u{29D5A}\u{29D9B}\u7E9F\u{29EF8}\u{29F23}\u4CA4\u9547\u{2A293}\u71A2\u{2A2FF}\u4D91\u9012\u{2A5CB}\u4D9C\u{20C9C}\u8FBE\u55C1"],
      ["9da1", "\u8FBA\u{224B0}\u8FB9\u{24A93}\u4509\u7E7F\u6F56\u6AB1\u4EEA\u34E4\u{28B2C}\u{2789D}\u373A\u8E80\u{217F5}\u{28024}\u{28B6C}\u{28B99}\u{27A3E}\u{266AF}\u3DEB\u{27655}\u{23CB7}\u{25635}\u{25956}\u4E9A\u{25E81}\u{26258}\u56BF\u{20E6D}\u8E0E\u5B6D\u{23E88}\u{24C9E}\u63DE\u62D0\u{217F6}\u{2187B}\u6530\u562D\u{25C4A}\u541A\u{25311}\u3DC6\u{29D98}\u4C7D\u5622\u561E\u7F49\u{25ED8}\u5975\u{23D40}\u8770\u4E1C\u{20FEA}\u{20D49}\u{236BA}\u8117\u9D5E\u8D18\u763B\u9C45\u764E\u77B9\u9345\u5432\u8148\u82F7\u5625\u8132\u8418\u80BD\u55EA\u7962\u5643\u5416\u{20E9D}\u35CE\u5605\u55F1\u66F1\u{282E2}\u362D\u7534\u55F0\u55BA\u5497\u5572\u{20C41}\u{20C96}\u5ED0\u{25148}\u{20E76}\u{22C62}"],
      ["9e40", "\u{20EA2}\u9EAB\u7D5A\u55DE\u{21075}\u629D\u976D\u5494\u8CCD\u71F6\u9176\u63FC\u63B9\u63FE\u5569\u{22B43}\u9C72\u{22EB3}\u519A\u34DF\u{20DA7}\u51A7\u544D\u551E\u5513\u7666\u8E2D\u{2688A}\u75B1\u80B6\u8804\u8786\u88C7\u81B6\u841C\u{210C1}\u44EC\u7304\u{24706}\u5B90\u830B\u{26893}\u567B\u{226F4}\u{27D2F}\u{241A3}\u{27D73}\u{26ED0}\u{272B6}\u9170\u{211D9}\u9208\u{23CFC}\u{2A6A9}\u{20EAC}\u{20EF9}\u7266\u{21CA2}\u474E\u{24FC2}\u{27FF9}\u{20FEB}\u40FA"],
      ["9ea1", "\u9C5D\u651F\u{22DA0}\u48F3\u{247E0}\u{29D7C}\u{20FEC}\u{20E0A}\u6062\u{275A3}\u{20FED}"],
      ["9ead", "\u{26048}\u{21187}\u71A3\u7E8E\u9D50\u4E1A\u4E04\u3577\u5B0D\u6CB2\u5367\u36AC\u39DC\u537D\u36A5\u{24618}\u589A\u{24B6E}\u822D\u544B\u57AA\u{25A95}\u{20979}"],
      ["9ec5", "\u3A52\u{22465}\u7374\u{29EAC}\u4D09\u9BED\u{23CFE}\u{29F30}\u4C5B\u{24FA9}\u{2959E}\u{29FDE}\u845C\u{23DB6}\u{272B2}\u{267B3}\u{23720}\u632E\u7D25\u{23EF7}\u{23E2C}\u3A2A\u9008\u52CC\u3E74\u367A\u45E9\u{2048E}\u7640\u5AF0\u{20EB6}\u787A\u{27F2E}\u58A7\u40BF\u567C\u9B8B\u5D74\u7654\u{2A434}\u9E85\u4CE1\u75F9\u37FB\u6119\u{230DA}\u{243F2}"],
      ["9ef5", "\u565D\u{212A9}\u57A7\u{24963}\u{29E06}\u5234\u{270AE}\u35AD\u6C4A\u9D7C"],
      ["9f40", "\u7C56\u9B39\u57DE\u{2176C}\u5C53\u64D3\u{294D0}\u{26335}\u{27164}\u86AD\u{20D28}\u{26D22}\u{24AE2}\u{20D71}"],
      ["9f4f", "\u51FE\u{21F0F}\u5D8E\u9703\u{21DD1}\u9E81\u904C\u7B1F\u9B02\u5CD1\u7BA3\u6268\u6335\u9AFF\u7BCF\u9B2A\u7C7E\u9B2E\u7C42\u7C86\u9C15\u7BFC\u9B09\u9F17\u9C1B\u{2493E}\u9F5A\u5573\u5BC3\u4FFD\u9E98\u4FF2\u5260\u3E06\u52D1\u5767\u5056\u59B7\u5E12\u97C8\u9DAB\u8F5C\u5469\u97B4\u9940\u97BA\u532C\u6130"],
      ["9fa1", "\u692C\u53DA\u9C0A\u9D02\u4C3B\u9641\u6980\u50A6\u7546\u{2176D}\u99DA\u5273"],
      ["9fae", "\u9159\u9681\u915C"],
      ["9fb2", "\u9151\u{28E97}\u637F\u{26D23}\u6ACA\u5611\u918E\u757A\u6285\u{203FC}\u734F\u7C70\u{25C21}\u{23CFD}"],
      ["9fc1", "\u{24919}\u76D6\u9B9D\u4E2A\u{20CD4}\u83BE\u8842"],
      ["9fc9", "\u5C4A\u69C0\u50ED\u577A\u521F\u5DF5\u4ECE\u6C31\u{201F2}\u4F39\u549C\u54DA\u529A\u8D82\u35FE\u5F0C\u35F3"],
      ["9fdb", "\u6B52\u917C\u9FA5\u9B97\u982E\u98B4\u9ABA\u9EA8\u9E84\u717A\u7B14"],
      ["9fe7", "\u6BFA\u8818\u7F78"],
      ["9feb", "\u5620\u{2A64A}\u8E77\u9F53"],
      ["9ff0", "\u8DD4\u8E4F\u9E1C\u8E01\u6282\u{2837D}\u8E28\u8E75\u7AD3\u{24A77}\u7A3E\u78D8\u6CEA\u8A67\u7607"],
      ["a040", "\u{28A5A}\u9F26\u6CCE\u87D6\u75C3\u{2A2B2}\u7853\u{2F840}\u8D0C\u72E2\u7371\u8B2D\u7302\u74F1\u8CEB\u{24ABB}\u862F\u5FBA\u88A0\u44B7"],
      ["a055", "\u{2183B}\u{26E05}"],
      ["a058", "\u8A7E\u{2251B}"],
      ["a05b", "\u60FD\u7667\u9AD7\u9D44\u936E\u9B8F\u87F5"],
      ["a063", "\u880F\u8CF7\u732C\u9721\u9BB0\u35D6\u72B2\u4C07\u7C51\u994A\u{26159}\u6159\u4C04\u9E96\u617D"],
      ["a073", "\u575F\u616F\u62A6\u6239\u62CE\u3A5C\u61E2\u53AA\u{233F5}\u6364\u6802\u35D2"],
      ["a0a1", "\u5D57\u{28BC2}\u8FDA\u{28E39}"],
      ["a0a6", "\u50D9\u{21D46}\u7906\u5332\u9638\u{20F3B}\u4065"],
      ["a0ae", "\u77FE"],
      ["a0b0", "\u7CC2\u{25F1A}\u7CDA\u7A2D\u8066\u8063\u7D4D\u7505\u74F2\u8994\u821A\u670C\u8062\u{27486}\u805B\u74F0\u8103\u7724\u8989\u{267CC}\u7553\u{26ED1}\u87A9\u87CE\u81C8\u878C\u8A49\u8CAD\u8B43\u772B\u74F8\u84DA\u3635\u69B2\u8DA6"],
      ["a0d4", "\u89A9\u7468\u6DB9\u87C1\u{24011}\u74E7\u3DDB\u7176\u60A4\u619C\u3CD1\u7162\u6077"],
      ["a0e2", "\u7F71\u{28B2D}\u7250\u60E9\u4B7E\u5220\u3C18\u{23CC7}\u{25ED7}\u{27656}\u{25531}\u{21944}\u{212FE}\u{29903}\u{26DDC}\u{270AD}\u5CC1\u{261AD}\u{28A0F}\u{23677}\u{200EE}\u{26846}\u{24F0E}\u4562\u5B1F\u{2634C}\u9F50\u9EA6\u{2626B}"],
      ["a3c0", "\u2400", 31, "\u2421"],
      ["c6a1", "\u2460", 9, "\u2474", 9, "\u2170", 9, "\u4E36\u4E3F\u4E85\u4EA0\u5182\u5196\u51AB\u52F9\u5338\u5369\u53B6\u590A\u5B80\u5DDB\u2F33\u5E7F\u5EF4\u5F50\u5F61\u6534\u65E0\u7592\u7676\u8FB5\u96B6\xA8\u02C6\u30FD\u30FE\u309D\u309E\u3003\u4EDD\u3005\u3006\u3007\u30FC\uFF3B\uFF3D\u273D\u3041", 23],
      ["c740", "\u3059", 58, "\u30A1\u30A2\u30A3\u30A4"],
      ["c7a1", "\u30A5", 81, "\u0410", 5, "\u0401\u0416", 4],
      ["c840", "\u041B", 26, "\u0451\u0436", 25, "\u21E7\u21B8\u21B9\u31CF\u{200CC}\u4E5A\u{2008A}\u5202\u4491"],
      ["c8a1", "\u9FB0\u5188\u9FB1\u{27607}"],
      ["c8cd", "\uFFE2\uFFE4\uFF07\uFF02\u3231\u2116\u2121\u309B\u309C\u2E80\u2E84\u2E86\u2E87\u2E88\u2E8A\u2E8C\u2E8D\u2E95\u2E9C\u2E9D\u2EA5\u2EA7\u2EAA\u2EAC\u2EAE\u2EB6\u2EBC\u2EBE\u2EC6\u2ECA\u2ECC\u2ECD\u2ECF\u2ED6\u2ED7\u2EDE\u2EE3"],
      ["c8f5", "\u0283\u0250\u025B\u0254\u0275\u0153\xF8\u014B\u028A\u026A"],
      ["f9fe", "\uFFED"],
      ["fa40", "\u{20547}\u92DB\u{205DF}\u{23FC5}\u854C\u42B5\u73EF\u51B5\u3649\u{24942}\u{289E4}\u9344\u{219DB}\u82EE\u{23CC8}\u783C\u6744\u62DF\u{24933}\u{289AA}\u{202A0}\u{26BB3}\u{21305}\u4FAB\u{224ED}\u5008\u{26D29}\u{27A84}\u{23600}\u{24AB1}\u{22513}\u5029\u{2037E}\u5FA4\u{20380}\u{20347}\u6EDB\u{2041F}\u507D\u5101\u347A\u510E\u986C\u3743\u8416\u{249A4}\u{20487}\u5160\u{233B4}\u516A\u{20BFF}\u{220FC}\u{202E5}\u{22530}\u{2058E}\u{23233}\u{21983}\u5B82\u877D\u{205B3}\u{23C99}\u51B2\u51B8"],
      ["faa1", "\u9D34\u51C9\u51CF\u51D1\u3CDC\u51D3\u{24AA6}\u51B3\u51E2\u5342\u51ED\u83CD\u693E\u{2372D}\u5F7B\u520B\u5226\u523C\u52B5\u5257\u5294\u52B9\u52C5\u7C15\u8542\u52E0\u860D\u{26B13}\u5305\u{28ADE}\u5549\u6ED9\u{23F80}\u{20954}\u{23FEC}\u5333\u5344\u{20BE2}\u6CCB\u{21726}\u681B\u73D5\u604A\u3EAA\u38CC\u{216E8}\u71DD\u44A2\u536D\u5374\u{286AB}\u537E\u537F\u{21596}\u{21613}\u77E6\u5393\u{28A9B}\u53A0\u53AB\u53AE\u73A7\u{25772}\u3F59\u739C\u53C1\u53C5\u6C49\u4E49\u57FE\u53D9\u3AAB\u{20B8F}\u53E0\u{23FEB}\u{22DA3}\u53F6\u{20C77}\u5413\u7079\u552B\u6657\u6D5B\u546D\u{26B53}\u{20D74}\u555D\u548F\u54A4\u47A6\u{2170D}\u{20EDD}\u3DB4\u{20D4D}"],
      ["fb40", "\u{289BC}\u{22698}\u5547\u4CED\u542F\u7417\u5586\u55A9\u5605\u{218D7}\u{2403A}\u4552\u{24435}\u66B3\u{210B4}\u5637\u66CD\u{2328A}\u66A4\u66AD\u564D\u564F\u78F1\u56F1\u9787\u53FE\u5700\u56EF\u56ED\u{28B66}\u3623\u{2124F}\u5746\u{241A5}\u6C6E\u708B\u5742\u36B1\u{26C7E}\u57E6\u{21416}\u5803\u{21454}\u{24363}\u5826\u{24BF5}\u585C\u58AA\u3561\u58E0\u58DC\u{2123C}\u58FB\u5BFF\u5743\u{2A150}\u{24278}\u93D3\u35A1\u591F\u68A6\u36C3\u6E59"],
      ["fba1", "\u{2163E}\u5A24\u5553\u{21692}\u8505\u59C9\u{20D4E}\u{26C81}\u{26D2A}\u{217DC}\u59D9\u{217FB}\u{217B2}\u{26DA6}\u6D71\u{21828}\u{216D5}\u59F9\u{26E45}\u5AAB\u5A63\u36E6\u{249A9}\u5A77\u3708\u5A96\u7465\u5AD3\u{26FA1}\u{22554}\u3D85\u{21911}\u3732\u{216B8}\u5E83\u52D0\u5B76\u6588\u5B7C\u{27A0E}\u4004\u485D\u{20204}\u5BD5\u6160\u{21A34}\u{259CC}\u{205A5}\u5BF3\u5B9D\u4D10\u5C05\u{21B44}\u5C13\u73CE\u5C14\u{21CA5}\u{26B28}\u5C49\u48DD\u5C85\u5CE9\u5CEF\u5D8B\u{21DF9}\u{21E37}\u5D10\u5D18\u5D46\u{21EA4}\u5CBA\u5DD7\u82FC\u382D\u{24901}\u{22049}\u{22173}\u8287\u3836\u3BC2\u5E2E\u6A8A\u5E75\u5E7A\u{244BC}\u{20CD3}\u53A6\u4EB7\u5ED0\u53A8\u{21771}\u5E09\u5EF4\u{28482}"],
      ["fc40", "\u5EF9\u5EFB\u38A0\u5EFC\u683E\u941B\u5F0D\u{201C1}\u{2F894}\u3ADE\u48AE\u{2133A}\u5F3A\u{26888}\u{223D0}\u5F58\u{22471}\u5F63\u97BD\u{26E6E}\u5F72\u9340\u{28A36}\u5FA7\u5DB6\u3D5F\u{25250}\u{21F6A}\u{270F8}\u{22668}\u91D6\u{2029E}\u{28A29}\u6031\u6685\u{21877}\u3963\u3DC7\u3639\u5790\u{227B4}\u7971\u3E40\u609E\u60A4\u60B3\u{24982}\u{2498F}\u{27A53}\u74A4\u50E1\u5AA0\u6164\u8424\u6142\u{2F8A6}\u{26ED2}\u6181\u51F4\u{20656}\u6187\u5BAA\u{23FB7}"],
      ["fca1", "\u{2285F}\u61D3\u{28B9D}\u{2995D}\u61D0\u3932\u{22980}\u{228C1}\u6023\u615C\u651E\u638B\u{20118}\u62C5\u{21770}\u62D5\u{22E0D}\u636C\u{249DF}\u3A17\u6438\u63F8\u{2138E}\u{217FC}\u6490\u6F8A\u{22E36}\u9814\u{2408C}\u{2571D}\u64E1\u64E5\u947B\u3A66\u643A\u3A57\u654D\u6F16\u{24A28}\u{24A23}\u6585\u656D\u655F\u{2307E}\u65B5\u{24940}\u4B37\u65D1\u40D8\u{21829}\u65E0\u65E3\u5FDF\u{23400}\u6618\u{231F7}\u{231F8}\u6644\u{231A4}\u{231A5}\u664B\u{20E75}\u6667\u{251E6}\u6673\u6674\u{21E3D}\u{23231}\u{285F4}\u{231C8}\u{25313}\u77C5\u{228F7}\u99A4\u6702\u{2439C}\u{24A21}\u3B2B\u69FA\u{237C2}\u675E\u6767\u6762\u{241CD}\u{290ED}\u67D7\u44E9\u6822\u6E50\u923C\u6801\u{233E6}\u{26DA0}\u685D"],
      ["fd40", "\u{2346F}\u69E1\u6A0B\u{28ADF}\u6973\u68C3\u{235CD}\u6901\u6900\u3D32\u3A01\u{2363C}\u3B80\u67AC\u6961\u{28A4A}\u42FC\u6936\u6998\u3BA1\u{203C9}\u8363\u5090\u69F9\u{23659}\u{2212A}\u6A45\u{23703}\u6A9D\u3BF3\u67B1\u6AC8\u{2919C}\u3C0D\u6B1D\u{20923}\u60DE\u6B35\u6B74\u{227CD}\u6EB5\u{23ADB}\u{203B5}\u{21958}\u3740\u5421\u{23B5A}\u6BE1\u{23EFC}\u6BDC\u6C37\u{2248B}\u{248F1}\u{26B51}\u6C5A\u8226\u6C79\u{23DBC}\u44C5\u{23DBD}\u{241A4}\u{2490C}\u{24900}"],
      ["fda1", "\u{23CC9}\u36E5\u3CEB\u{20D32}\u9B83\u{231F9}\u{22491}\u7F8F\u6837\u{26D25}\u{26DA1}\u{26DEB}\u6D96\u6D5C\u6E7C\u6F04\u{2497F}\u{24085}\u{26E72}\u8533\u{26F74}\u51C7\u6C9C\u6E1D\u842E\u{28B21}\u6E2F\u{23E2F}\u7453\u{23F82}\u79CC\u6E4F\u5A91\u{2304B}\u6FF8\u370D\u6F9D\u{23E30}\u6EFA\u{21497}\u{2403D}\u4555\u93F0\u6F44\u6F5C\u3D4E\u6F74\u{29170}\u3D3B\u6F9F\u{24144}\u6FD3\u{24091}\u{24155}\u{24039}\u{23FF0}\u{23FB4}\u{2413F}\u51DF\u{24156}\u{24157}\u{24140}\u{261DD}\u704B\u707E\u70A7\u7081\u70CC\u70D5\u70D6\u70DF\u4104\u3DE8\u71B4\u7196\u{24277}\u712B\u7145\u5A88\u714A\u716E\u5C9C\u{24365}\u714F\u9362\u{242C1}\u712C\u{2445A}\u{24A27}\u{24A22}\u71BA\u{28BE8}\u70BD\u720E"],
      ["fe40", "\u9442\u7215\u5911\u9443\u7224\u9341\u{25605}\u722E\u7240\u{24974}\u68BD\u7255\u7257\u3E55\u{23044}\u680D\u6F3D\u7282\u732A\u732B\u{24823}\u{2882B}\u48ED\u{28804}\u7328\u732E\u73CF\u73AA\u{20C3A}\u{26A2E}\u73C9\u7449\u{241E2}\u{216E7}\u{24A24}\u6623\u36C5\u{249B7}\u{2498D}\u{249FB}\u73F7\u7415\u6903\u{24A26}\u7439\u{205C3}\u3ED7\u745C\u{228AD}\u7460\u{28EB2}\u7447\u73E4\u7476\u83B9\u746C\u3730\u7474\u93F1\u6A2C\u7482\u4953\u{24A8C}"],
      ["fea1", "\u{2415F}\u{24A79}\u{28B8F}\u5B46\u{28C03}\u{2189E}\u74C8\u{21988}\u750E\u74E9\u751E\u{28ED9}\u{21A4B}\u5BD7\u{28EAC}\u9385\u754D\u754A\u7567\u756E\u{24F82}\u3F04\u{24D13}\u758E\u745D\u759E\u75B4\u7602\u762C\u7651\u764F\u766F\u7676\u{263F5}\u7690\u81EF\u37F8\u{26911}\u{2690E}\u76A1\u76A5\u76B7\u76CC\u{26F9F}\u8462\u{2509D}\u{2517D}\u{21E1C}\u771E\u7726\u7740\u64AF\u{25220}\u7758\u{232AC}\u77AF\u{28964}\u{28968}\u{216C1}\u77F4\u7809\u{21376}\u{24A12}\u68CA\u78AF\u78C7\u78D3\u96A5\u792E\u{255E0}\u78D7\u7934\u78B1\u{2760C}\u8FB8\u8884\u{28B2B}\u{26083}\u{2261C}\u7986\u8900\u6902\u7980\u{25857}\u799D\u{27B39}\u793C\u79A9\u6E2A\u{27126}\u3EA8\u79C6\u{2910D}\u79D4"]
    ];
  }
});

// node_modules/iconv-lite/encodings/dbcs-data.js
var require_dbcs_data = __commonJS({
  "node_modules/iconv-lite/encodings/dbcs-data.js"(exports, module2) {
    "use strict";
    module2.exports = {
      // == Japanese/ShiftJIS ====================================================
      // All japanese encodings are based on JIS X set of standards:
      // JIS X 0201 - Single-byte encoding of ASCII + ¥ + Kana chars at 0xA1-0xDF.
      // JIS X 0208 - Main set of 6879 characters, placed in 94x94 plane, to be encoded by 2 bytes. 
      //              Has several variations in 1978, 1983, 1990 and 1997.
      // JIS X 0212 - Supplementary plane of 6067 chars in 94x94 plane. 1990. Effectively dead.
      // JIS X 0213 - Extension and modern replacement of 0208 and 0212. Total chars: 11233.
      //              2 planes, first is superset of 0208, second - revised 0212.
      //              Introduced in 2000, revised 2004. Some characters are in Unicode Plane 2 (0x2xxxx)
      // Byte encodings are:
      //  * Shift_JIS: Compatible with 0201, uses not defined chars in top half as lead bytes for double-byte
      //               encoding of 0208. Lead byte ranges: 0x81-0x9F, 0xE0-0xEF; Trail byte ranges: 0x40-0x7E, 0x80-0x9E, 0x9F-0xFC.
      //               Windows CP932 is a superset of Shift_JIS. Some companies added more chars, notably KDDI.
      //  * EUC-JP:    Up to 3 bytes per character. Used mostly on *nixes.
      //               0x00-0x7F       - lower part of 0201
      //               0x8E, 0xA1-0xDF - upper part of 0201
      //               (0xA1-0xFE)x2   - 0208 plane (94x94).
      //               0x8F, (0xA1-0xFE)x2 - 0212 plane (94x94).
      //  * JIS X 208: 7-bit, direct encoding of 0208. Byte ranges: 0x21-0x7E (94 values). Uncommon.
      //               Used as-is in ISO2022 family.
      //  * ISO2022-JP: Stateful encoding, with escape sequences to switch between ASCII, 
      //                0201-1976 Roman, 0208-1978, 0208-1983.
      //  * ISO2022-JP-1: Adds esc seq for 0212-1990.
      //  * ISO2022-JP-2: Adds esc seq for GB2313-1980, KSX1001-1992, ISO8859-1, ISO8859-7.
      //  * ISO2022-JP-3: Adds esc seq for 0201-1976 Kana set, 0213-2000 Planes 1, 2.
      //  * ISO2022-JP-2004: Adds 0213-2004 Plane 1.
      //
      // After JIS X 0213 appeared, Shift_JIS-2004, EUC-JISX0213 and ISO2022-JP-2004 followed, with just changing the planes.
      //
      // Overall, it seems that it's a mess :( http://www8.plala.or.jp/tkubota1/unicode-symbols-map2.html
      "shiftjis": {
        type: "_dbcs",
        table: function() {
          return require_shiftjis();
        },
        encodeAdd: { "\xA5": 92, "\u203E": 126 },
        encodeSkipVals: [{ from: 60736, to: 63808 }]
      },
      "csshiftjis": "shiftjis",
      "mskanji": "shiftjis",
      "sjis": "shiftjis",
      "windows31j": "shiftjis",
      "ms31j": "shiftjis",
      "xsjis": "shiftjis",
      "windows932": "shiftjis",
      "ms932": "shiftjis",
      "932": "shiftjis",
      "cp932": "shiftjis",
      "eucjp": {
        type: "_dbcs",
        table: function() {
          return require_eucjp();
        },
        encodeAdd: { "\xA5": 92, "\u203E": 126 }
      },
      // TODO: KDDI extension to Shift_JIS
      // TODO: IBM CCSID 942 = CP932, but F0-F9 custom chars and other char changes.
      // TODO: IBM CCSID 943 = Shift_JIS = CP932 with original Shift_JIS lower 128 chars.
      // == Chinese/GBK ==========================================================
      // http://en.wikipedia.org/wiki/GBK
      // We mostly implement W3C recommendation: https://www.w3.org/TR/encoding/#gbk-encoder
      // Oldest GB2312 (1981, ~7600 chars) is a subset of CP936
      "gb2312": "cp936",
      "gb231280": "cp936",
      "gb23121980": "cp936",
      "csgb2312": "cp936",
      "csiso58gb231280": "cp936",
      "euccn": "cp936",
      // Microsoft's CP936 is a subset and approximation of GBK.
      "windows936": "cp936",
      "ms936": "cp936",
      "936": "cp936",
      "cp936": {
        type: "_dbcs",
        table: function() {
          return require_cp936();
        }
      },
      // GBK (~22000 chars) is an extension of CP936 that added user-mapped chars and some other.
      "gbk": {
        type: "_dbcs",
        table: function() {
          return require_cp936().concat(require_gbk_added());
        }
      },
      "xgbk": "gbk",
      "isoir58": "gbk",
      // GB18030 is an algorithmic extension of GBK.
      // Main source: https://www.w3.org/TR/encoding/#gbk-encoder
      // http://icu-project.org/docs/papers/gb18030.html
      // http://source.icu-project.org/repos/icu/data/trunk/charset/data/xml/gb-18030-2000.xml
      // http://www.khngai.com/chinese/charmap/tblgbk.php?page=0
      "gb18030": {
        type: "_dbcs",
        table: function() {
          return require_cp936().concat(require_gbk_added());
        },
        gb18030: function() {
          return require_gb18030_ranges();
        },
        encodeSkipVals: [128],
        encodeAdd: { "\u20AC": 41699 }
      },
      "chinese": "gb18030",
      // == Korean ===============================================================
      // EUC-KR, KS_C_5601 and KS X 1001 are exactly the same.
      "windows949": "cp949",
      "ms949": "cp949",
      "949": "cp949",
      "cp949": {
        type: "_dbcs",
        table: function() {
          return require_cp949();
        }
      },
      "cseuckr": "cp949",
      "csksc56011987": "cp949",
      "euckr": "cp949",
      "isoir149": "cp949",
      "korean": "cp949",
      "ksc56011987": "cp949",
      "ksc56011989": "cp949",
      "ksc5601": "cp949",
      // == Big5/Taiwan/Hong Kong ================================================
      // There are lots of tables for Big5 and cp950. Please see the following links for history:
      // http://moztw.org/docs/big5/  http://www.haible.de/bruno/charsets/conversion-tables/Big5.html
      // Variations, in roughly number of defined chars:
      //  * Windows CP 950: Microsoft variant of Big5. Canonical: http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP950.TXT
      //  * Windows CP 951: Microsoft variant of Big5-HKSCS-2001. Seems to be never public. http://me.abelcheung.org/articles/research/what-is-cp951/
      //  * Big5-2003 (Taiwan standard) almost superset of cp950.
      //  * Unicode-at-on (UAO) / Mozilla 1.8. Falling out of use on the Web. Not supported by other browsers.
      //  * Big5-HKSCS (-2001, -2004, -2008). Hong Kong standard. 
      //    many unicode code points moved from PUA to Supplementary plane (U+2XXXX) over the years.
      //    Plus, it has 4 combining sequences.
      //    Seems that Mozilla refused to support it for 10 yrs. https://bugzilla.mozilla.org/show_bug.cgi?id=162431 https://bugzilla.mozilla.org/show_bug.cgi?id=310299
      //    because big5-hkscs is the only encoding to include astral characters in non-algorithmic way.
      //    Implementations are not consistent within browsers; sometimes labeled as just big5.
      //    MS Internet Explorer switches from big5 to big5-hkscs when a patch applied.
      //    Great discussion & recap of what's going on https://bugzilla.mozilla.org/show_bug.cgi?id=912470#c31
      //    In the encoder, it might make sense to support encoding old PUA mappings to Big5 bytes seq-s.
      //    Official spec: http://www.ogcio.gov.hk/en/business/tech_promotion/ccli/terms/doc/2003cmp_2008.txt
      //                   http://www.ogcio.gov.hk/tc/business/tech_promotion/ccli/terms/doc/hkscs-2008-big5-iso.txt
      // 
      // Current understanding of how to deal with Big5(-HKSCS) is in the Encoding Standard, http://encoding.spec.whatwg.org/#big5-encoder
      // Unicode mapping (http://www.unicode.org/Public/MAPPINGS/OBSOLETE/EASTASIA/OTHER/BIG5.TXT) is said to be wrong.
      "windows950": "cp950",
      "ms950": "cp950",
      "950": "cp950",
      "cp950": {
        type: "_dbcs",
        table: function() {
          return require_cp950();
        }
      },
      // Big5 has many variations and is an extension of cp950. We use Encoding Standard's as a consensus.
      "big5": "big5hkscs",
      "big5hkscs": {
        type: "_dbcs",
        table: function() {
          return require_cp950().concat(require_big5_added());
        },
        encodeSkipVals: [41676]
      },
      "cnbig5": "big5hkscs",
      "csbig5": "big5hkscs",
      "xxbig5": "big5hkscs"
    };
  }
});

// node_modules/iconv-lite/encodings/index.js
var require_encodings = __commonJS({
  "node_modules/iconv-lite/encodings/index.js"(exports, module2) {
    "use strict";
    var modules = [
      require_internal(),
      require_utf16(),
      require_utf7(),
      require_sbcs_codec(),
      require_sbcs_data(),
      require_sbcs_data_generated(),
      require_dbcs_codec(),
      require_dbcs_data()
    ];
    for (i = 0; i < modules.length; i++) {
      module2 = modules[i];
      for (enc in module2)
        if (Object.prototype.hasOwnProperty.call(module2, enc))
          exports[enc] = module2[enc];
    }
    var module2;
    var enc;
    var i;
  }
});

// node_modules/iconv-lite/lib/streams.js
var require_streams = __commonJS({
  "node_modules/iconv-lite/lib/streams.js"(exports, module2) {
    "use strict";
    var Buffer2 = require("buffer").Buffer;
    var Transform2 = require("stream").Transform;
    module2.exports = function(iconv) {
      iconv.encodeStream = function encodeStream(encoding, options) {
        return new IconvLiteEncoderStream(iconv.getEncoder(encoding, options), options);
      };
      iconv.decodeStream = function decodeStream(encoding, options) {
        return new IconvLiteDecoderStream(iconv.getDecoder(encoding, options), options);
      };
      iconv.supportsStreams = true;
      iconv.IconvLiteEncoderStream = IconvLiteEncoderStream;
      iconv.IconvLiteDecoderStream = IconvLiteDecoderStream;
      iconv._collect = IconvLiteDecoderStream.prototype.collect;
    };
    function IconvLiteEncoderStream(conv, options) {
      this.conv = conv;
      options = options || {};
      options.decodeStrings = false;
      Transform2.call(this, options);
    }
    IconvLiteEncoderStream.prototype = Object.create(Transform2.prototype, {
      constructor: { value: IconvLiteEncoderStream }
    });
    IconvLiteEncoderStream.prototype._transform = function(chunk, encoding, done) {
      if (typeof chunk != "string")
        return done(new Error("Iconv encoding stream needs strings as its input."));
      try {
        var res = this.conv.write(chunk);
        if (res && res.length)
          this.push(res);
        done();
      } catch (e) {
        done(e);
      }
    };
    IconvLiteEncoderStream.prototype._flush = function(done) {
      try {
        var res = this.conv.end();
        if (res && res.length)
          this.push(res);
        done();
      } catch (e) {
        done(e);
      }
    };
    IconvLiteEncoderStream.prototype.collect = function(cb) {
      var chunks = [];
      this.on("error", cb);
      this.on("data", function(chunk) {
        chunks.push(chunk);
      });
      this.on("end", function() {
        cb(null, Buffer2.concat(chunks));
      });
      return this;
    };
    function IconvLiteDecoderStream(conv, options) {
      this.conv = conv;
      options = options || {};
      options.encoding = this.encoding = "utf8";
      Transform2.call(this, options);
    }
    IconvLiteDecoderStream.prototype = Object.create(Transform2.prototype, {
      constructor: { value: IconvLiteDecoderStream }
    });
    IconvLiteDecoderStream.prototype._transform = function(chunk, encoding, done) {
      if (!Buffer2.isBuffer(chunk))
        return done(new Error("Iconv decoding stream needs buffers as its input."));
      try {
        var res = this.conv.write(chunk);
        if (res && res.length)
          this.push(res, this.encoding);
        done();
      } catch (e) {
        done(e);
      }
    };
    IconvLiteDecoderStream.prototype._flush = function(done) {
      try {
        var res = this.conv.end();
        if (res && res.length)
          this.push(res, this.encoding);
        done();
      } catch (e) {
        done(e);
      }
    };
    IconvLiteDecoderStream.prototype.collect = function(cb) {
      var res = "";
      this.on("error", cb);
      this.on("data", function(chunk) {
        res += chunk;
      });
      this.on("end", function() {
        cb(null, res);
      });
      return this;
    };
  }
});

// node_modules/iconv-lite/lib/extend-node.js
var require_extend_node = __commonJS({
  "node_modules/iconv-lite/lib/extend-node.js"(exports, module2) {
    "use strict";
    var Buffer2 = require("buffer").Buffer;
    module2.exports = function(iconv) {
      var original = void 0;
      iconv.supportsNodeEncodingsExtension = !(Buffer2.from || new Buffer2(0) instanceof Uint8Array);
      iconv.extendNodeEncodings = function extendNodeEncodings() {
        if (original)
          return;
        original = {};
        if (!iconv.supportsNodeEncodingsExtension) {
          console.error("ACTION NEEDED: require('iconv-lite').extendNodeEncodings() is not supported in your version of Node");
          console.error("See more info at https://github.com/ashtuchkin/iconv-lite/wiki/Node-v4-compatibility");
          return;
        }
        var nodeNativeEncodings = {
          "hex": true,
          "utf8": true,
          "utf-8": true,
          "ascii": true,
          "binary": true,
          "base64": true,
          "ucs2": true,
          "ucs-2": true,
          "utf16le": true,
          "utf-16le": true
        };
        Buffer2.isNativeEncoding = function(enc) {
          return enc && nodeNativeEncodings[enc.toLowerCase()];
        };
        var SlowBuffer = require("buffer").SlowBuffer;
        original.SlowBufferToString = SlowBuffer.prototype.toString;
        SlowBuffer.prototype.toString = function(encoding, start, end) {
          encoding = String(encoding || "utf8").toLowerCase();
          if (Buffer2.isNativeEncoding(encoding))
            return original.SlowBufferToString.call(this, encoding, start, end);
          if (typeof start == "undefined")
            start = 0;
          if (typeof end == "undefined")
            end = this.length;
          return iconv.decode(this.slice(start, end), encoding);
        };
        original.SlowBufferWrite = SlowBuffer.prototype.write;
        SlowBuffer.prototype.write = function(string, offset, length, encoding) {
          if (isFinite(offset)) {
            if (!isFinite(length)) {
              encoding = length;
              length = void 0;
            }
          } else {
            var swap = encoding;
            encoding = offset;
            offset = length;
            length = swap;
          }
          offset = +offset || 0;
          var remaining = this.length - offset;
          if (!length) {
            length = remaining;
          } else {
            length = +length;
            if (length > remaining) {
              length = remaining;
            }
          }
          encoding = String(encoding || "utf8").toLowerCase();
          if (Buffer2.isNativeEncoding(encoding))
            return original.SlowBufferWrite.call(this, string, offset, length, encoding);
          if (string.length > 0 && (length < 0 || offset < 0))
            throw new RangeError("attempt to write beyond buffer bounds");
          var buf = iconv.encode(string, encoding);
          if (buf.length < length)
            length = buf.length;
          buf.copy(this, offset, 0, length);
          return length;
        };
        original.BufferIsEncoding = Buffer2.isEncoding;
        Buffer2.isEncoding = function(encoding) {
          return Buffer2.isNativeEncoding(encoding) || iconv.encodingExists(encoding);
        };
        original.BufferByteLength = Buffer2.byteLength;
        Buffer2.byteLength = SlowBuffer.byteLength = function(str, encoding) {
          encoding = String(encoding || "utf8").toLowerCase();
          if (Buffer2.isNativeEncoding(encoding))
            return original.BufferByteLength.call(this, str, encoding);
          return iconv.encode(str, encoding).length;
        };
        original.BufferToString = Buffer2.prototype.toString;
        Buffer2.prototype.toString = function(encoding, start, end) {
          encoding = String(encoding || "utf8").toLowerCase();
          if (Buffer2.isNativeEncoding(encoding))
            return original.BufferToString.call(this, encoding, start, end);
          if (typeof start == "undefined")
            start = 0;
          if (typeof end == "undefined")
            end = this.length;
          return iconv.decode(this.slice(start, end), encoding);
        };
        original.BufferWrite = Buffer2.prototype.write;
        Buffer2.prototype.write = function(string, offset, length, encoding) {
          var _offset = offset, _length = length, _encoding = encoding;
          if (isFinite(offset)) {
            if (!isFinite(length)) {
              encoding = length;
              length = void 0;
            }
          } else {
            var swap = encoding;
            encoding = offset;
            offset = length;
            length = swap;
          }
          encoding = String(encoding || "utf8").toLowerCase();
          if (Buffer2.isNativeEncoding(encoding))
            return original.BufferWrite.call(this, string, _offset, _length, _encoding);
          offset = +offset || 0;
          var remaining = this.length - offset;
          if (!length) {
            length = remaining;
          } else {
            length = +length;
            if (length > remaining) {
              length = remaining;
            }
          }
          if (string.length > 0 && (length < 0 || offset < 0))
            throw new RangeError("attempt to write beyond buffer bounds");
          var buf = iconv.encode(string, encoding);
          if (buf.length < length)
            length = buf.length;
          buf.copy(this, offset, 0, length);
          return length;
        };
        if (iconv.supportsStreams) {
          var Readable = require("stream").Readable;
          original.ReadableSetEncoding = Readable.prototype.setEncoding;
          Readable.prototype.setEncoding = function setEncoding(enc, options) {
            this._readableState.decoder = iconv.getDecoder(enc, options);
            this._readableState.encoding = enc;
          };
          Readable.prototype.collect = iconv._collect;
        }
      };
      iconv.undoExtendNodeEncodings = function undoExtendNodeEncodings() {
        if (!iconv.supportsNodeEncodingsExtension)
          return;
        if (!original)
          throw new Error("require('iconv-lite').undoExtendNodeEncodings(): Nothing to undo; extendNodeEncodings() is not called.");
        delete Buffer2.isNativeEncoding;
        var SlowBuffer = require("buffer").SlowBuffer;
        SlowBuffer.prototype.toString = original.SlowBufferToString;
        SlowBuffer.prototype.write = original.SlowBufferWrite;
        Buffer2.isEncoding = original.BufferIsEncoding;
        Buffer2.byteLength = original.BufferByteLength;
        Buffer2.prototype.toString = original.BufferToString;
        Buffer2.prototype.write = original.BufferWrite;
        if (iconv.supportsStreams) {
          var Readable = require("stream").Readable;
          Readable.prototype.setEncoding = original.ReadableSetEncoding;
          delete Readable.prototype.collect;
        }
        original = void 0;
      };
    };
  }
});

// node_modules/iconv-lite/lib/index.js
var require_lib = __commonJS({
  "node_modules/iconv-lite/lib/index.js"(exports, module2) {
    "use strict";
    var Buffer2 = require_safer().Buffer;
    var bomHandling = require_bom_handling();
    var iconv = module2.exports;
    iconv.encodings = null;
    iconv.defaultCharUnicode = "\uFFFD";
    iconv.defaultCharSingleByte = "?";
    iconv.encode = function encode(str, encoding, options) {
      str = "" + (str || "");
      var encoder = iconv.getEncoder(encoding, options);
      var res = encoder.write(str);
      var trail = encoder.end();
      return trail && trail.length > 0 ? Buffer2.concat([res, trail]) : res;
    };
    iconv.decode = function decode(buf, encoding, options) {
      if (typeof buf === "string") {
        if (!iconv.skipDecodeWarning) {
          console.error("Iconv-lite warning: decode()-ing strings is deprecated. Refer to https://github.com/ashtuchkin/iconv-lite/wiki/Use-Buffers-when-decoding");
          iconv.skipDecodeWarning = true;
        }
        buf = Buffer2.from("" + (buf || ""), "binary");
      }
      var decoder = iconv.getDecoder(encoding, options);
      var res = decoder.write(buf);
      var trail = decoder.end();
      return trail ? res + trail : res;
    };
    iconv.encodingExists = function encodingExists(enc) {
      try {
        iconv.getCodec(enc);
        return true;
      } catch (e) {
        return false;
      }
    };
    iconv.toEncoding = iconv.encode;
    iconv.fromEncoding = iconv.decode;
    iconv._codecDataCache = {};
    iconv.getCodec = function getCodec(encoding) {
      if (!iconv.encodings)
        iconv.encodings = require_encodings();
      var enc = iconv._canonicalizeEncoding(encoding);
      var codecOptions = {};
      while (true) {
        var codec = iconv._codecDataCache[enc];
        if (codec)
          return codec;
        var codecDef = iconv.encodings[enc];
        switch (typeof codecDef) {
          case "string":
            enc = codecDef;
            break;
          case "object":
            for (var key in codecDef)
              codecOptions[key] = codecDef[key];
            if (!codecOptions.encodingName)
              codecOptions.encodingName = enc;
            enc = codecDef.type;
            break;
          case "function":
            if (!codecOptions.encodingName)
              codecOptions.encodingName = enc;
            codec = new codecDef(codecOptions, iconv);
            iconv._codecDataCache[codecOptions.encodingName] = codec;
            return codec;
          default:
            throw new Error("Encoding not recognized: '" + encoding + "' (searched as: '" + enc + "')");
        }
      }
    };
    iconv._canonicalizeEncoding = function(encoding) {
      return ("" + encoding).toLowerCase().replace(/:\d{4}$|[^0-9a-z]/g, "");
    };
    iconv.getEncoder = function getEncoder(encoding, options) {
      var codec = iconv.getCodec(encoding), encoder = new codec.encoder(options, codec);
      if (codec.bomAware && options && options.addBOM)
        encoder = new bomHandling.PrependBOM(encoder, options);
      return encoder;
    };
    iconv.getDecoder = function getDecoder(encoding, options) {
      var codec = iconv.getCodec(encoding), decoder = new codec.decoder(options, codec);
      if (codec.bomAware && !(options && options.stripBOM === false))
        decoder = new bomHandling.StripBOM(decoder, options);
      return decoder;
    };
    var nodeVer = typeof process !== "undefined" && process.versions && process.versions.node;
    if (nodeVer) {
      nodeVerArr = nodeVer.split(".").map(Number);
      if (nodeVerArr[0] > 0 || nodeVerArr[1] >= 10) {
        require_streams()(iconv);
      }
      require_extend_node()(iconv);
    }
    var nodeVerArr;
    if (false) {
      console.error("iconv-lite warning: javascript files use encoding different from utf-8. See https://github.com/ashtuchkin/iconv-lite/wiki/Javascript-source-file-encodings for more info.");
    }
  }
});

// node_modules/os-tmpdir/index.js
var require_os_tmpdir = __commonJS({
  "node_modules/os-tmpdir/index.js"(exports, module2) {
    "use strict";
    var isWindows = process.platform === "win32";
    var trailingSlashRe = isWindows ? /[^:]\\$/ : /.\/$/;
    module2.exports = function() {
      var path2;
      if (isWindows) {
        path2 = process.env.TEMP || process.env.TMP || (process.env.SystemRoot || process.env.windir) + "\\temp";
      } else {
        path2 = process.env.TMPDIR || process.env.TMP || process.env.TEMP || "/tmp";
      }
      if (trailingSlashRe.test(path2)) {
        path2 = path2.slice(0, -1);
      }
      return path2;
    };
  }
});

// node_modules/tmp/lib/tmp.js
var require_tmp = __commonJS({
  "node_modules/tmp/lib/tmp.js"(exports, module2) {
    var fs2 = require("fs");
    var path2 = require("path");
    var crypto = require("crypto");
    var osTmpDir = require_os_tmpdir();
    var _c = process.binding("constants");
    var tmpDir = osTmpDir();
    var RANDOM_CHARS = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
    var TEMPLATE_PATTERN = /XXXXXX/;
    var DEFAULT_TRIES = 3;
    var CREATE_FLAGS = (_c.O_CREAT || _c.fs.O_CREAT) | (_c.O_EXCL || _c.fs.O_EXCL) | (_c.O_RDWR || _c.fs.O_RDWR);
    var EBADF = _c.EBADF || _c.os.errno.EBADF;
    var ENOENT = _c.ENOENT || _c.os.errno.ENOENT;
    var DIR_MODE = 448;
    var FILE_MODE = 384;
    var _removeObjects = [];
    var _gracefulCleanup = false;
    var _uncaughtException = false;
    function _randomChars(howMany) {
      var value2 = [], rnd = null;
      try {
        rnd = crypto.randomBytes(howMany);
      } catch (e) {
        rnd = crypto.pseudoRandomBytes(howMany);
      }
      for (var i = 0; i < howMany; i++) {
        value2.push(RANDOM_CHARS[rnd[i] % RANDOM_CHARS.length]);
      }
      return value2.join("");
    }
    function _isUndefined(obj) {
      return typeof obj === "undefined";
    }
    function _parseArguments(options, callback) {
      if (typeof options == "function") {
        return [callback || {}, options];
      }
      if (_isUndefined(options)) {
        return [{}, callback];
      }
      return [options, callback];
    }
    function _generateTmpName(opts) {
      if (opts.name) {
        return path2.join(opts.dir || tmpDir, opts.name);
      }
      if (opts.template) {
        return opts.template.replace(TEMPLATE_PATTERN, _randomChars(6));
      }
      const name = [
        opts.prefix || "tmp-",
        process.pid,
        _randomChars(12),
        opts.postfix || ""
      ].join("");
      return path2.join(opts.dir || tmpDir, name);
    }
    function tmpName(options, callback) {
      var args = _parseArguments(options, callback), opts = args[0], cb = args[1], tries = opts.name ? 1 : opts.tries || DEFAULT_TRIES;
      if (isNaN(tries) || tries < 0)
        return cb(new Error("Invalid tries"));
      if (opts.template && !opts.template.match(TEMPLATE_PATTERN))
        return cb(new Error("Invalid template provided"));
      (function _getUniqueName() {
        const name = _generateTmpName(opts);
        fs2.stat(name, function(err) {
          if (!err) {
            if (tries-- > 0)
              return _getUniqueName();
            return cb(new Error("Could not get a unique tmp filename, max tries reached " + name));
          }
          cb(null, name);
        });
      })();
    }
    function tmpNameSync(options) {
      var args = _parseArguments(options), opts = args[0], tries = opts.name ? 1 : opts.tries || DEFAULT_TRIES;
      if (isNaN(tries) || tries < 0)
        throw new Error("Invalid tries");
      if (opts.template && !opts.template.match(TEMPLATE_PATTERN))
        throw new Error("Invalid template provided");
      do {
        const name = _generateTmpName(opts);
        try {
          fs2.statSync(name);
        } catch (e) {
          return name;
        }
      } while (tries-- > 0);
      throw new Error("Could not get a unique tmp filename, max tries reached");
    }
    function file(options, callback) {
      var args = _parseArguments(options, callback), opts = args[0], cb = args[1];
      opts.postfix = _isUndefined(opts.postfix) ? ".tmp" : opts.postfix;
      tmpName(opts, function _tmpNameCreated(err, name) {
        if (err)
          return cb(err);
        fs2.open(name, CREATE_FLAGS, opts.mode || FILE_MODE, function _fileCreated(err2, fd) {
          if (err2)
            return cb(err2);
          if (opts.discardDescriptor) {
            return fs2.close(fd, function _discardCallback(err3) {
              if (err3) {
                try {
                  fs2.unlinkSync(name);
                } catch (e) {
                  if (!isENOENT(e)) {
                    err3 = e;
                  }
                }
                return cb(err3);
              }
              cb(null, name, void 0, _prepareTmpFileRemoveCallback(name, -1, opts));
            });
          }
          if (opts.detachDescriptor) {
            return cb(null, name, fd, _prepareTmpFileRemoveCallback(name, -1, opts));
          }
          cb(null, name, fd, _prepareTmpFileRemoveCallback(name, fd, opts));
        });
      });
    }
    function fileSync(options) {
      var args = _parseArguments(options), opts = args[0];
      opts.postfix = opts.postfix || ".tmp";
      const discardOrDetachDescriptor = opts.discardDescriptor || opts.detachDescriptor;
      const name = tmpNameSync(opts);
      var fd = fs2.openSync(name, CREATE_FLAGS, opts.mode || FILE_MODE);
      if (opts.discardDescriptor) {
        fs2.closeSync(fd);
        fd = void 0;
      }
      return {
        name,
        fd,
        removeCallback: _prepareTmpFileRemoveCallback(name, discardOrDetachDescriptor ? -1 : fd, opts)
      };
    }
    function _rmdirRecursiveSync(root2) {
      const dirs = [root2];
      do {
        var dir2 = dirs.pop(), deferred = false, files = fs2.readdirSync(dir2);
        for (var i = 0, length = files.length; i < length; i++) {
          var file2 = path2.join(dir2, files[i]), stat = fs2.lstatSync(file2);
          if (stat.isDirectory()) {
            if (!deferred) {
              deferred = true;
              dirs.push(dir2);
            }
            dirs.push(file2);
          } else {
            fs2.unlinkSync(file2);
          }
        }
        if (!deferred) {
          fs2.rmdirSync(dir2);
        }
      } while (dirs.length !== 0);
    }
    function dir(options, callback) {
      var args = _parseArguments(options, callback), opts = args[0], cb = args[1];
      tmpName(opts, function _tmpNameCreated(err, name) {
        if (err)
          return cb(err);
        fs2.mkdir(name, opts.mode || DIR_MODE, function _dirCreated(err2) {
          if (err2)
            return cb(err2);
          cb(null, name, _prepareTmpDirRemoveCallback(name, opts));
        });
      });
    }
    function dirSync(options) {
      var args = _parseArguments(options), opts = args[0];
      const name = tmpNameSync(opts);
      fs2.mkdirSync(name, opts.mode || DIR_MODE);
      return {
        name,
        removeCallback: _prepareTmpDirRemoveCallback(name, opts)
      };
    }
    function _prepareTmpFileRemoveCallback(name, fd, opts) {
      const removeCallback = _prepareRemoveCallback(function _removeCallback(fdPath) {
        try {
          if (0 <= fdPath[0]) {
            fs2.closeSync(fdPath[0]);
          }
        } catch (e) {
          if (!isEBADF(e) && !isENOENT(e)) {
            throw e;
          }
        }
        try {
          fs2.unlinkSync(fdPath[1]);
        } catch (e) {
          if (!isENOENT(e)) {
            throw e;
          }
        }
      }, [fd, name]);
      if (!opts.keep) {
        _removeObjects.unshift(removeCallback);
      }
      return removeCallback;
    }
    function _prepareTmpDirRemoveCallback(name, opts) {
      const removeFunction = opts.unsafeCleanup ? _rmdirRecursiveSync : fs2.rmdirSync.bind(fs2);
      const removeCallback = _prepareRemoveCallback(removeFunction, name);
      if (!opts.keep) {
        _removeObjects.unshift(removeCallback);
      }
      return removeCallback;
    }
    function _prepareRemoveCallback(removeFunction, arg) {
      var called = false;
      return function _cleanupCallback(next) {
        if (!called) {
          const index = _removeObjects.indexOf(_cleanupCallback);
          if (index >= 0) {
            _removeObjects.splice(index, 1);
          }
          called = true;
          removeFunction(arg);
        }
        if (next)
          next(null);
      };
    }
    function _garbageCollector() {
      if (_uncaughtException && !_gracefulCleanup) {
        return;
      }
      while (_removeObjects.length) {
        try {
          _removeObjects[0].call(null);
        } catch (e) {
        }
      }
    }
    function isEBADF(error) {
      return isExpectedError(error, -EBADF, "EBADF");
    }
    function isENOENT(error) {
      return isExpectedError(error, -ENOENT, "ENOENT");
    }
    function isExpectedError(error, code, errno) {
      return error.code == code || error.code == errno;
    }
    function setGracefulCleanup() {
      _gracefulCleanup = true;
    }
    var version2 = process.versions.node.split(".").map(function(value2) {
      return parseInt(value2, 10);
    });
    if (version2[0] === 0 && (version2[1] < 9 || version2[1] === 9 && version2[2] < 5)) {
      process.addListener("uncaughtException", function _uncaughtExceptionThrown(err) {
        _uncaughtException = true;
        _garbageCollector();
        throw err;
      });
    }
    process.addListener("exit", function _exit(code) {
      if (code)
        _uncaughtException = true;
      _garbageCollector();
    });
    module2.exports.tmpdir = tmpDir;
    module2.exports.dir = dir;
    module2.exports.dirSync = dirSync;
    module2.exports.file = file;
    module2.exports.fileSync = fileSync;
    module2.exports.tmpName = tmpName;
    module2.exports.tmpNameSync = tmpNameSync;
    module2.exports.setGracefulCleanup = setGracefulCleanup;
  }
});

// node_modules/external-editor/main/errors/CreateFileError.js
var require_CreateFileError = __commonJS({
  "node_modules/external-editor/main/errors/CreateFileError.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (b2.hasOwnProperty(p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    var CreateFileError = (
      /** @class */
      function(_super) {
        __extends(CreateFileError2, _super);
        function CreateFileError2(originalError) {
          var _newTarget = this.constructor;
          var _this = _super.call(this, "Failed to create temporary file for editor") || this;
          _this.originalError = originalError;
          var proto = _newTarget.prototype;
          if (Object.setPrototypeOf) {
            Object.setPrototypeOf(_this, proto);
          } else {
            _this.__proto__ = _newTarget.prototype;
          }
          return _this;
        }
        return CreateFileError2;
      }(Error)
    );
    exports.CreateFileError = CreateFileError;
  }
});

// node_modules/external-editor/main/errors/LaunchEditorError.js
var require_LaunchEditorError = __commonJS({
  "node_modules/external-editor/main/errors/LaunchEditorError.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (b2.hasOwnProperty(p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    var LaunchEditorError = (
      /** @class */
      function(_super) {
        __extends(LaunchEditorError2, _super);
        function LaunchEditorError2(originalError) {
          var _newTarget = this.constructor;
          var _this = _super.call(this, "Failed launch editor") || this;
          _this.originalError = originalError;
          var proto = _newTarget.prototype;
          if (Object.setPrototypeOf) {
            Object.setPrototypeOf(_this, proto);
          } else {
            _this.__proto__ = _newTarget.prototype;
          }
          return _this;
        }
        return LaunchEditorError2;
      }(Error)
    );
    exports.LaunchEditorError = LaunchEditorError;
  }
});

// node_modules/external-editor/main/errors/ReadFileError.js
var require_ReadFileError = __commonJS({
  "node_modules/external-editor/main/errors/ReadFileError.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (b2.hasOwnProperty(p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    var ReadFileError = (
      /** @class */
      function(_super) {
        __extends(ReadFileError2, _super);
        function ReadFileError2(originalError) {
          var _newTarget = this.constructor;
          var _this = _super.call(this, "Failed to read temporary file") || this;
          _this.originalError = originalError;
          var proto = _newTarget.prototype;
          if (Object.setPrototypeOf) {
            Object.setPrototypeOf(_this, proto);
          } else {
            _this.__proto__ = _newTarget.prototype;
          }
          return _this;
        }
        return ReadFileError2;
      }(Error)
    );
    exports.ReadFileError = ReadFileError;
  }
});

// node_modules/external-editor/main/errors/RemoveFileError.js
var require_RemoveFileError = __commonJS({
  "node_modules/external-editor/main/errors/RemoveFileError.js"(exports) {
    "use strict";
    var __extends = exports && exports.__extends || function() {
      var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d2, b2) {
          d2.__proto__ = b2;
        } || function(d2, b2) {
          for (var p in b2)
            if (b2.hasOwnProperty(p))
              d2[p] = b2[p];
        };
        return extendStatics(d, b);
      };
      return function(d, b) {
        extendStatics(d, b);
        function __() {
          this.constructor = d;
        }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
    }();
    Object.defineProperty(exports, "__esModule", { value: true });
    var RemoveFileError = (
      /** @class */
      function(_super) {
        __extends(RemoveFileError2, _super);
        function RemoveFileError2(originalError) {
          var _newTarget = this.constructor;
          var _this = _super.call(this, "Failed to cleanup temporary file") || this;
          _this.originalError = originalError;
          var proto = _newTarget.prototype;
          if (Object.setPrototypeOf) {
            Object.setPrototypeOf(_this, proto);
          } else {
            _this.__proto__ = _newTarget.prototype;
          }
          return _this;
        }
        return RemoveFileError2;
      }(Error)
    );
    exports.RemoveFileError = RemoveFileError;
  }
});

// node_modules/external-editor/main/index.js
var require_main = __commonJS({
  "node_modules/external-editor/main/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var chardet_1 = require_chardet();
    var child_process_1 = require("child_process");
    var fs_1 = require("fs");
    var iconv_lite_1 = require_lib();
    var tmp_1 = require_tmp();
    var CreateFileError_1 = require_CreateFileError();
    exports.CreateFileError = CreateFileError_1.CreateFileError;
    var LaunchEditorError_1 = require_LaunchEditorError();
    exports.LaunchEditorError = LaunchEditorError_1.LaunchEditorError;
    var ReadFileError_1 = require_ReadFileError();
    exports.ReadFileError = ReadFileError_1.ReadFileError;
    var RemoveFileError_1 = require_RemoveFileError();
    exports.RemoveFileError = RemoveFileError_1.RemoveFileError;
    function edit(text, fileOptions) {
      if (text === void 0) {
        text = "";
      }
      var editor = new ExternalEditor(text, fileOptions);
      editor.run();
      editor.cleanup();
      return editor.text;
    }
    exports.edit = edit;
    function editAsync(text, callback, fileOptions) {
      if (text === void 0) {
        text = "";
      }
      var editor = new ExternalEditor(text, fileOptions);
      editor.runAsync(function(err, result) {
        if (err) {
          setImmediate(callback, err, null);
        } else {
          try {
            editor.cleanup();
            setImmediate(callback, null, result);
          } catch (cleanupError) {
            setImmediate(callback, cleanupError, null);
          }
        }
      });
    }
    exports.editAsync = editAsync;
    var ExternalEditor = (
      /** @class */
      function() {
        function ExternalEditor2(text, fileOptions) {
          if (text === void 0) {
            text = "";
          }
          this.text = "";
          this.fileOptions = {};
          this.text = text;
          if (fileOptions) {
            this.fileOptions = fileOptions;
          }
          this.determineEditor();
          this.createTemporaryFile();
        }
        ExternalEditor2.splitStringBySpace = function(str) {
          var pieces = [];
          var currentString = "";
          for (var strIndex = 0; strIndex < str.length; strIndex++) {
            var currentLetter = str[strIndex];
            if (strIndex > 0 && currentLetter === " " && str[strIndex - 1] !== "\\" && currentString.length > 0) {
              pieces.push(currentString);
              currentString = "";
            } else {
              currentString += currentLetter;
            }
          }
          if (currentString.length > 0) {
            pieces.push(currentString);
          }
          return pieces;
        };
        Object.defineProperty(ExternalEditor2.prototype, "temp_file", {
          get: function() {
            console.log("DEPRECATED: temp_file. Use tempFile moving forward.");
            return this.tempFile;
          },
          enumerable: true,
          configurable: true
        });
        Object.defineProperty(ExternalEditor2.prototype, "last_exit_status", {
          get: function() {
            console.log("DEPRECATED: last_exit_status. Use lastExitStatus moving forward.");
            return this.lastExitStatus;
          },
          enumerable: true,
          configurable: true
        });
        ExternalEditor2.prototype.run = function() {
          this.launchEditor();
          this.readTemporaryFile();
          return this.text;
        };
        ExternalEditor2.prototype.runAsync = function(callback) {
          var _this = this;
          try {
            this.launchEditorAsync(function() {
              try {
                _this.readTemporaryFile();
                setImmediate(callback, null, _this.text);
              } catch (readError) {
                setImmediate(callback, readError, null);
              }
            });
          } catch (launchError) {
            setImmediate(callback, launchError, null);
          }
        };
        ExternalEditor2.prototype.cleanup = function() {
          this.removeTemporaryFile();
        };
        ExternalEditor2.prototype.determineEditor = function() {
          var editor = process.env.VISUAL ? process.env.VISUAL : process.env.EDITOR ? process.env.EDITOR : /^win/.test(process.platform) ? "notepad" : "vim";
          var editorOpts = ExternalEditor2.splitStringBySpace(editor).map(function(piece) {
            return piece.replace("\\ ", " ");
          });
          var bin = editorOpts.shift();
          this.editor = { args: editorOpts, bin };
        };
        ExternalEditor2.prototype.createTemporaryFile = function() {
          try {
            this.tempFile = tmp_1.tmpNameSync(this.fileOptions);
            var opt = { encoding: "utf8" };
            if (this.fileOptions.hasOwnProperty("mode")) {
              opt.mode = this.fileOptions.mode;
            }
            fs_1.writeFileSync(this.tempFile, this.text, opt);
          } catch (createFileError) {
            throw new CreateFileError_1.CreateFileError(createFileError);
          }
        };
        ExternalEditor2.prototype.readTemporaryFile = function() {
          try {
            var tempFileBuffer = fs_1.readFileSync(this.tempFile);
            if (tempFileBuffer.length === 0) {
              this.text = "";
            } else {
              var encoding = chardet_1.detect(tempFileBuffer).toString();
              if (!iconv_lite_1.encodingExists(encoding)) {
                encoding = "utf8";
              }
              this.text = iconv_lite_1.decode(tempFileBuffer, encoding);
            }
          } catch (readFileError) {
            throw new ReadFileError_1.ReadFileError(readFileError);
          }
        };
        ExternalEditor2.prototype.removeTemporaryFile = function() {
          try {
            fs_1.unlinkSync(this.tempFile);
          } catch (removeFileError) {
            throw new RemoveFileError_1.RemoveFileError(removeFileError);
          }
        };
        ExternalEditor2.prototype.launchEditor = function() {
          try {
            var editorProcess = child_process_1.spawnSync(this.editor.bin, this.editor.args.concat([this.tempFile]), { stdio: "inherit" });
            this.lastExitStatus = editorProcess.status;
          } catch (launchError) {
            throw new LaunchEditorError_1.LaunchEditorError(launchError);
          }
        };
        ExternalEditor2.prototype.launchEditorAsync = function(callback) {
          var _this = this;
          try {
            var editorProcess = child_process_1.spawn(this.editor.bin, this.editor.args.concat([this.tempFile]), { stdio: "inherit" });
            editorProcess.on("exit", function(code) {
              _this.lastExitStatus = code;
              setImmediate(callback);
            });
          } catch (launchError) {
            throw new LaunchEditorError_1.LaunchEditorError(launchError);
          }
        };
        return ExternalEditor2;
      }()
    );
    exports.ExternalEditor = ExternalEditor;
  }
});

// node_modules/inquirer/lib/prompts/editor.js
var require_editor = __commonJS({
  "node_modules/inquirer/lib/prompts/editor.js"(exports, module2) {
    "use strict";
    var chalk3 = require_source();
    var { editAsync } = require_main();
    var Base = require_base();
    var observe = require_events();
    var { Subject } = require_cjs();
    var EditorPrompt = class extends Base {
      /**
       * Start the Inquiry session
       * @param  {Function} cb      Callback when prompt is done
       * @return {this}
       */
      _run(cb) {
        this.done = cb;
        this.editorResult = new Subject();
        const events = observe(this.rl);
        this.lineSubscription = events.line.subscribe(this.startExternalEditor.bind(this));
        const validation = this.handleSubmitEvents(this.editorResult);
        validation.success.forEach(this.onEnd.bind(this));
        validation.error.forEach(this.onError.bind(this));
        this.currentText = this.opt.default;
        this.opt.default = null;
        this.render();
        return this;
      }
      /**
       * Render the prompt to screen
       * @return {EditorPrompt} self
       */
      render(error) {
        let bottomContent = "";
        let message = this.getQuestion();
        if (this.status === "answered") {
          message += chalk3.dim("Received");
        } else {
          message += chalk3.dim("Press <enter> to launch your preferred editor.");
        }
        if (error) {
          bottomContent = chalk3.red(">> ") + error;
        }
        this.screen.render(message, bottomContent);
      }
      /**
       * Launch $EDITOR on user press enter
       */
      startExternalEditor() {
        this.rl.pause();
        editAsync(this.currentText, this.endExternalEditor.bind(this));
      }
      endExternalEditor(error, result) {
        this.rl.resume();
        if (error) {
          this.editorResult.error(error);
        } else {
          this.editorResult.next(result);
        }
      }
      onEnd(state) {
        this.editorResult.unsubscribe();
        this.lineSubscription.unsubscribe();
        this.answer = state.value;
        this.status = "answered";
        this.render();
        this.screen.done();
        this.done(this.answer);
      }
      onError(state) {
        this.render(state.isValid);
      }
    };
    module2.exports = EditorPrompt;
  }
});

// node_modules/inquirer/lib/inquirer.js
var require_inquirer = __commonJS({
  "node_modules/inquirer/lib/inquirer.js"(exports, module2) {
    "use strict";
    var inquirer2 = module2.exports;
    inquirer2.prompts = {};
    inquirer2.Separator = require_separator();
    inquirer2.ui = {
      BottomBar: require_bottom_bar(),
      Prompt: require_prompt()
    };
    inquirer2.createPromptModule = function(opt) {
      const promptModule = function(questions, answers) {
        let ui;
        try {
          ui = new inquirer2.ui.Prompt(promptModule.prompts, opt);
        } catch (error) {
          return Promise.reject(error);
        }
        const promise = ui.run(questions, answers);
        promise.ui = ui;
        return promise;
      };
      promptModule.prompts = {};
      promptModule.registerPrompt = function(name, prompt) {
        promptModule.prompts[name] = prompt;
        return this;
      };
      promptModule.restoreDefaultPrompts = function() {
        this.registerPrompt("list", require_list());
        this.registerPrompt("input", require_input());
        this.registerPrompt("number", require_number());
        this.registerPrompt("confirm", require_confirm());
        this.registerPrompt("rawlist", require_rawlist());
        this.registerPrompt("expand", require_expand2());
        this.registerPrompt("checkbox", require_checkbox());
        this.registerPrompt("password", require_password());
        this.registerPrompt("editor", require_editor());
      };
      promptModule.restoreDefaultPrompts();
      return promptModule;
    };
    inquirer2.prompt = inquirer2.createPromptModule();
    inquirer2.registerPrompt = function(name, prompt) {
      inquirer2.prompt.registerPrompt(name, prompt);
    };
    inquirer2.restoreDefaultPrompts = function() {
      inquirer2.prompt.restoreDefaultPrompts();
    };
  }
});

// node_modules/@babel/parser/lib/index.js
var require_lib2 = __commonJS({
  "node_modules/@babel/parser/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function _objectWithoutPropertiesLoose(source, excluded) {
      if (source == null)
        return {};
      var target = {};
      var sourceKeys = Object.keys(source);
      var key, i;
      for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0)
          continue;
        target[key] = source[key];
      }
      return target;
    }
    var Position = class {
      constructor(line, col, index) {
        this.line = void 0;
        this.column = void 0;
        this.index = void 0;
        this.line = line;
        this.column = col;
        this.index = index;
      }
    };
    var SourceLocation = class {
      constructor(start, end) {
        this.start = void 0;
        this.end = void 0;
        this.filename = void 0;
        this.identifierName = void 0;
        this.start = start;
        this.end = end;
      }
    };
    function createPositionWithColumnOffset(position, columnOffset) {
      const {
        line,
        column,
        index
      } = position;
      return new Position(line, column + columnOffset, index + columnOffset);
    }
    var ParseErrorCode = {
      SyntaxError: "BABEL_PARSER_SYNTAX_ERROR",
      SourceTypeModuleError: "BABEL_PARSER_SOURCETYPE_MODULE_REQUIRED"
    };
    var reflect = (keys3, last2 = keys3.length - 1) => ({
      get() {
        return keys3.reduce((object, key) => object[key], this);
      },
      set(value2) {
        keys3.reduce(
          (item, key, i) => i === last2 ? item[key] = value2 : item[key],
          this
        );
      }
    });
    var instantiate = (constructor, properties, descriptors) => Object.keys(descriptors).map((key) => [key, descriptors[key]]).filter(([, descriptor]) => !!descriptor).map(([key, descriptor]) => [key, typeof descriptor === "function" ? {
      value: descriptor,
      enumerable: false
    } : typeof descriptor.reflect === "string" ? Object.assign({}, descriptor, reflect(descriptor.reflect.split("."))) : descriptor]).reduce((instance, [key, descriptor]) => Object.defineProperty(instance, key, Object.assign({
      configurable: true
    }, descriptor)), Object.assign(new constructor(), properties));
    var ModuleErrors = {
      ImportMetaOutsideModule: {
        message: `import.meta may appear only with 'sourceType: "module"'`,
        code: ParseErrorCode.SourceTypeModuleError
      },
      ImportOutsideModule: {
        message: `'import' and 'export' may appear only with 'sourceType: "module"'`,
        code: ParseErrorCode.SourceTypeModuleError
      }
    };
    var NodeDescriptions = {
      ArrayPattern: "array destructuring pattern",
      AssignmentExpression: "assignment expression",
      AssignmentPattern: "assignment expression",
      ArrowFunctionExpression: "arrow function expression",
      ConditionalExpression: "conditional expression",
      CatchClause: "catch clause",
      ForOfStatement: "for-of statement",
      ForInStatement: "for-in statement",
      ForStatement: "for-loop",
      FormalParameters: "function parameter list",
      Identifier: "identifier",
      ImportSpecifier: "import specifier",
      ImportDefaultSpecifier: "import default specifier",
      ImportNamespaceSpecifier: "import namespace specifier",
      ObjectPattern: "object destructuring pattern",
      ParenthesizedExpression: "parenthesized expression",
      RestElement: "rest element",
      UpdateExpression: {
        true: "prefix operation",
        false: "postfix operation"
      },
      VariableDeclarator: "variable declaration",
      YieldExpression: "yield expression"
    };
    var toNodeDescription = ({
      type,
      prefix: prefix2
    }) => type === "UpdateExpression" ? NodeDescriptions.UpdateExpression[String(prefix2)] : NodeDescriptions[type];
    var StandardErrors = {
      AccessorIsGenerator: ({
        kind
      }) => `A ${kind}ter cannot be a generator.`,
      ArgumentsInClass: "'arguments' is only allowed in functions and class methods.",
      AsyncFunctionInSingleStatementContext: "Async functions can only be declared at the top level or inside a block.",
      AwaitBindingIdentifier: "Can not use 'await' as identifier inside an async function.",
      AwaitBindingIdentifierInStaticBlock: "Can not use 'await' as identifier inside a static block.",
      AwaitExpressionFormalParameter: "'await' is not allowed in async function parameters.",
      AwaitNotInAsyncContext: "'await' is only allowed within async functions and at the top levels of modules.",
      AwaitNotInAsyncFunction: "'await' is only allowed within async functions.",
      BadGetterArity: "A 'get' accessor must not have any formal parameters.",
      BadSetterArity: "A 'set' accessor must have exactly one formal parameter.",
      BadSetterRestParameter: "A 'set' accessor function argument must not be a rest parameter.",
      ConstructorClassField: "Classes may not have a field named 'constructor'.",
      ConstructorClassPrivateField: "Classes may not have a private field named '#constructor'.",
      ConstructorIsAccessor: "Class constructor may not be an accessor.",
      ConstructorIsAsync: "Constructor can't be an async function.",
      ConstructorIsGenerator: "Constructor can't be a generator.",
      DeclarationMissingInitializer: ({
        kind
      }) => `Missing initializer in ${kind} declaration.`,
      DecoratorArgumentsOutsideParentheses: "Decorator arguments must be moved inside parentheses: use '@(decorator(args))' instead of '@(decorator)(args)'.",
      DecoratorBeforeExport: "Decorators must be placed *before* the 'export' keyword. You can set the 'decoratorsBeforeExport' option to false to use the 'export @decorator class {}' syntax.",
      DecoratorConstructor: "Decorators can't be used with a constructor. Did you mean '@dec class { ... }'?",
      DecoratorExportClass: "Using the export keyword between a decorator and a class is not allowed. Please use `export @dec class` instead.",
      DecoratorSemicolon: "Decorators must not be followed by a semicolon.",
      DecoratorStaticBlock: "Decorators can't be used with a static block.",
      DeletePrivateField: "Deleting a private field is not allowed.",
      DestructureNamedImport: "ES2015 named imports do not destructure. Use another statement for destructuring after the import.",
      DuplicateConstructor: "Duplicate constructor in the same class.",
      DuplicateDefaultExport: "Only one default export allowed per module.",
      DuplicateExport: ({
        exportName
      }) => `\`${exportName}\` has already been exported. Exported identifiers must be unique.`,
      DuplicateProto: "Redefinition of __proto__ property.",
      DuplicateRegExpFlags: "Duplicate regular expression flag.",
      ElementAfterRest: "Rest element must be last element.",
      EscapedCharNotAnIdentifier: "Invalid Unicode escape.",
      ExportBindingIsString: ({
        localName,
        exportName
      }) => `A string literal cannot be used as an exported binding without \`from\`.
- Did you mean \`export { '${localName}' as '${exportName}' } from 'some-module'\`?`,
      ExportDefaultFromAsIdentifier: "'from' is not allowed as an identifier after 'export default'.",
      ForInOfLoopInitializer: ({
        type
      }) => `'${type === "ForInStatement" ? "for-in" : "for-of"}' loop variable declaration may not have an initializer.`,
      ForInUsing: "For-in loop may not start with 'using' declaration.",
      ForOfAsync: "The left-hand side of a for-of loop may not be 'async'.",
      ForOfLet: "The left-hand side of a for-of loop may not start with 'let'.",
      GeneratorInSingleStatementContext: "Generators can only be declared at the top level or inside a block.",
      IllegalBreakContinue: ({
        type
      }) => `Unsyntactic ${type === "BreakStatement" ? "break" : "continue"}.`,
      IllegalLanguageModeDirective: "Illegal 'use strict' directive in function with non-simple parameter list.",
      IllegalReturn: "'return' outside of function.",
      ImportBindingIsString: ({
        importName
      }) => `A string literal cannot be used as an imported binding.
- Did you mean \`import { "${importName}" as foo }\`?`,
      ImportCallArgumentTrailingComma: "Trailing comma is disallowed inside import(...) arguments.",
      ImportCallArity: ({
        maxArgumentCount
      }) => `\`import()\` requires exactly ${maxArgumentCount === 1 ? "one argument" : "one or two arguments"}.`,
      ImportCallNotNewExpression: "Cannot use new with import(...).",
      ImportCallSpreadArgument: "`...` is not allowed in `import()`.",
      ImportJSONBindingNotDefault: "A JSON module can only be imported with `default`.",
      ImportReflectionHasAssertion: "`import module x` cannot have assertions.",
      ImportReflectionNotBinding: 'Only `import module x from "./module"` is valid.',
      IncompatibleRegExpUVFlags: "The 'u' and 'v' regular expression flags cannot be enabled at the same time.",
      InvalidBigIntLiteral: "Invalid BigIntLiteral.",
      InvalidCodePoint: "Code point out of bounds.",
      InvalidCoverInitializedName: "Invalid shorthand property initializer.",
      InvalidDecimal: "Invalid decimal.",
      InvalidDigit: ({
        radix
      }) => `Expected number in radix ${radix}.`,
      InvalidEscapeSequence: "Bad character escape sequence.",
      InvalidEscapeSequenceTemplate: "Invalid escape sequence in template.",
      InvalidEscapedReservedWord: ({
        reservedWord
      }) => `Escape sequence in keyword ${reservedWord}.`,
      InvalidIdentifier: ({
        identifierName
      }) => `Invalid identifier ${identifierName}.`,
      InvalidLhs: ({
        ancestor
      }) => `Invalid left-hand side in ${toNodeDescription(ancestor)}.`,
      InvalidLhsBinding: ({
        ancestor
      }) => `Binding invalid left-hand side in ${toNodeDescription(ancestor)}.`,
      InvalidNumber: "Invalid number.",
      InvalidOrMissingExponent: "Floating-point numbers require a valid exponent after the 'e'.",
      InvalidOrUnexpectedToken: ({
        unexpected
      }) => `Unexpected character '${unexpected}'.`,
      InvalidParenthesizedAssignment: "Invalid parenthesized assignment pattern.",
      InvalidPrivateFieldResolution: ({
        identifierName
      }) => `Private name #${identifierName} is not defined.`,
      InvalidPropertyBindingPattern: "Binding member expression.",
      InvalidRecordProperty: "Only properties and spread elements are allowed in record definitions.",
      InvalidRestAssignmentPattern: "Invalid rest operator's argument.",
      LabelRedeclaration: ({
        labelName
      }) => `Label '${labelName}' is already declared.`,
      LetInLexicalBinding: "'let' is not allowed to be used as a name in 'let' or 'const' declarations.",
      LineTerminatorBeforeArrow: "No line break is allowed before '=>'.",
      MalformedRegExpFlags: "Invalid regular expression flag.",
      MissingClassName: "A class name is required.",
      MissingEqInAssignment: "Only '=' operator can be used for specifying default value.",
      MissingSemicolon: "Missing semicolon.",
      MissingPlugin: ({
        missingPlugin
      }) => `This experimental syntax requires enabling the parser plugin: ${missingPlugin.map((name) => JSON.stringify(name)).join(", ")}.`,
      MissingOneOfPlugins: ({
        missingPlugin
      }) => `This experimental syntax requires enabling one of the following parser plugin(s): ${missingPlugin.map((name) => JSON.stringify(name)).join(", ")}.`,
      MissingUnicodeEscape: "Expecting Unicode escape sequence \\uXXXX.",
      MixingCoalesceWithLogical: "Nullish coalescing operator(??) requires parens when mixing with logical operators.",
      ModuleAttributeDifferentFromType: "The only accepted module attribute is `type`.",
      ModuleAttributeInvalidValue: "Only string literals are allowed as module attribute values.",
      ModuleAttributesWithDuplicateKeys: ({
        key
      }) => `Duplicate key "${key}" is not allowed in module attributes.`,
      ModuleExportNameHasLoneSurrogate: ({
        surrogateCharCode
      }) => `An export name cannot include a lone surrogate, found '\\u${surrogateCharCode.toString(16)}'.`,
      ModuleExportUndefined: ({
        localName
      }) => `Export '${localName}' is not defined.`,
      MultipleDefaultsInSwitch: "Multiple default clauses.",
      NewlineAfterThrow: "Illegal newline after throw.",
      NoCatchOrFinally: "Missing catch or finally clause.",
      NumberIdentifier: "Identifier directly after number.",
      NumericSeparatorInEscapeSequence: "Numeric separators are not allowed inside unicode escape sequences or hex escape sequences.",
      ObsoleteAwaitStar: "'await*' has been removed from the async functions proposal. Use Promise.all() instead.",
      OptionalChainingNoNew: "Constructors in/after an Optional Chain are not allowed.",
      OptionalChainingNoTemplate: "Tagged Template Literals are not allowed in optionalChain.",
      OverrideOnConstructor: "'override' modifier cannot appear on a constructor declaration.",
      ParamDupe: "Argument name clash.",
      PatternHasAccessor: "Object pattern can't contain getter or setter.",
      PatternHasMethod: "Object pattern can't contain methods.",
      PrivateInExpectedIn: ({
        identifierName
      }) => `Private names are only allowed in property accesses (\`obj.#${identifierName}\`) or in \`in\` expressions (\`#${identifierName} in obj\`).`,
      PrivateNameRedeclaration: ({
        identifierName
      }) => `Duplicate private name #${identifierName}.`,
      RecordExpressionBarIncorrectEndSyntaxType: "Record expressions ending with '|}' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
      RecordExpressionBarIncorrectStartSyntaxType: "Record expressions starting with '{|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
      RecordExpressionHashIncorrectStartSyntaxType: "Record expressions starting with '#{' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.",
      RecordNoProto: "'__proto__' is not allowed in Record expressions.",
      RestTrailingComma: "Unexpected trailing comma after rest element.",
      SloppyFunction: "In non-strict mode code, functions can only be declared at top level, inside a block, or as the body of an if statement.",
      StaticPrototype: "Classes may not have static property named prototype.",
      SuperNotAllowed: "`super()` is only valid inside a class constructor of a subclass. Maybe a typo in the method name ('constructor') or not extending another class?",
      SuperPrivateField: "Private fields can't be accessed on super.",
      TrailingDecorator: "Decorators must be attached to a class element.",
      TupleExpressionBarIncorrectEndSyntaxType: "Tuple expressions ending with '|]' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
      TupleExpressionBarIncorrectStartSyntaxType: "Tuple expressions starting with '[|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
      TupleExpressionHashIncorrectStartSyntaxType: "Tuple expressions starting with '#[' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.",
      UnexpectedArgumentPlaceholder: "Unexpected argument placeholder.",
      UnexpectedAwaitAfterPipelineBody: 'Unexpected "await" after pipeline body; await must have parentheses in minimal proposal.',
      UnexpectedDigitAfterHash: "Unexpected digit after hash token.",
      UnexpectedImportExport: "'import' and 'export' may only appear at the top level.",
      UnexpectedKeyword: ({
        keyword
      }) => `Unexpected keyword '${keyword}'.`,
      UnexpectedLeadingDecorator: "Leading decorators must be attached to a class declaration.",
      UnexpectedLexicalDeclaration: "Lexical declaration cannot appear in a single-statement context.",
      UnexpectedNewTarget: "`new.target` can only be used in functions or class properties.",
      UnexpectedNumericSeparator: "A numeric separator is only allowed between two digits.",
      UnexpectedPrivateField: "Unexpected private name.",
      UnexpectedReservedWord: ({
        reservedWord
      }) => `Unexpected reserved word '${reservedWord}'.`,
      UnexpectedSuper: "'super' is only allowed in object methods and classes.",
      UnexpectedToken: ({
        expected,
        unexpected
      }) => `Unexpected token${unexpected ? ` '${unexpected}'.` : ""}${expected ? `, expected "${expected}"` : ""}`,
      UnexpectedTokenUnaryExponentiation: "Illegal expression. Wrap left hand side or entire exponentiation in parentheses.",
      UnexpectedUsingDeclaration: "Using declaration cannot appear in the top level when source type is `script`.",
      UnsupportedBind: "Binding should be performed on object property.",
      UnsupportedDecoratorExport: "A decorated export must export a class declaration.",
      UnsupportedDefaultExport: "Only expressions, functions or classes are allowed as the `default` export.",
      UnsupportedImport: "`import` can only be used in `import()` or `import.meta`.",
      UnsupportedMetaProperty: ({
        target,
        onlyValidPropertyName
      }) => `The only valid meta property for ${target} is ${target}.${onlyValidPropertyName}.`,
      UnsupportedParameterDecorator: "Decorators cannot be used to decorate parameters.",
      UnsupportedPropertyDecorator: "Decorators cannot be used to decorate object literal properties.",
      UnsupportedSuper: "'super' can only be used with function calls (i.e. super()) or in property accesses (i.e. super.prop or super[prop]).",
      UnterminatedComment: "Unterminated comment.",
      UnterminatedRegExp: "Unterminated regular expression.",
      UnterminatedString: "Unterminated string constant.",
      UnterminatedTemplate: "Unterminated template.",
      UsingDeclarationHasBindingPattern: "Using declaration cannot have destructuring patterns.",
      VarRedeclaration: ({
        identifierName
      }) => `Identifier '${identifierName}' has already been declared.`,
      YieldBindingIdentifier: "Can not use 'yield' as identifier inside a generator.",
      YieldInParameter: "Yield expression is not allowed in formal parameters.",
      ZeroDigitNumericSeparator: "Numeric separator can not be used after leading 0."
    };
    var StrictModeErrors = {
      StrictDelete: "Deleting local variable in strict mode.",
      StrictEvalArguments: ({
        referenceName
      }) => `Assigning to '${referenceName}' in strict mode.`,
      StrictEvalArgumentsBinding: ({
        bindingName
      }) => `Binding '${bindingName}' in strict mode.`,
      StrictFunction: "In strict mode code, functions can only be declared at top level or inside a block.",
      StrictNumericEscape: "The only valid numeric escape in strict mode is '\\0'.",
      StrictOctalLiteral: "Legacy octal literals are not allowed in strict mode.",
      StrictWith: "'with' in strict mode."
    };
    var UnparenthesizedPipeBodyDescriptions = /* @__PURE__ */ new Set(["ArrowFunctionExpression", "AssignmentExpression", "ConditionalExpression", "YieldExpression"]);
    var PipelineOperatorErrors = {
      PipeBodyIsTighter: "Unexpected yield after pipeline body; any yield expression acting as Hack-style pipe body must be parenthesized due to its loose operator precedence.",
      PipeTopicRequiresHackPipes: 'Topic reference is used, but the pipelineOperator plugin was not passed a "proposal": "hack" or "smart" option.',
      PipeTopicUnbound: "Topic reference is unbound; it must be inside a pipe body.",
      PipeTopicUnconfiguredToken: ({
        token
      }) => `Invalid topic token ${token}. In order to use ${token} as a topic reference, the pipelineOperator plugin must be configured with { "proposal": "hack", "topicToken": "${token}" }.`,
      PipeTopicUnused: "Hack-style pipe body does not contain a topic reference; Hack-style pipes must use topic at least once.",
      PipeUnparenthesizedBody: ({
        type
      }) => `Hack-style pipe body cannot be an unparenthesized ${toNodeDescription({
        type
      })}; please wrap it in parentheses.`,
      PipelineBodyNoArrow: 'Unexpected arrow "=>" after pipeline body; arrow function in pipeline body must be parenthesized.',
      PipelineBodySequenceExpression: "Pipeline body may not be a comma-separated sequence expression.",
      PipelineHeadSequenceExpression: "Pipeline head should not be a comma-separated sequence expression.",
      PipelineTopicUnused: "Pipeline is in topic style but does not use topic reference.",
      PrimaryTopicNotAllowed: "Topic reference was used in a lexical context without topic binding.",
      PrimaryTopicRequiresSmartPipeline: 'Topic reference is used, but the pipelineOperator plugin was not passed a "proposal": "hack" or "smart" option.'
    };
    var _excluded$1 = ["toMessage"];
    var _excluded2$1 = ["message"];
    function toParseErrorConstructor(_ref) {
      let {
        toMessage
      } = _ref, properties = _objectWithoutPropertiesLoose(_ref, _excluded$1);
      return function constructor({
        loc,
        details
      }) {
        return instantiate(SyntaxError, Object.assign({}, properties, {
          loc
        }), {
          clone(overrides = {}) {
            const loc2 = overrides.loc || {};
            return constructor({
              loc: new Position("line" in loc2 ? loc2.line : this.loc.line, "column" in loc2 ? loc2.column : this.loc.column, "index" in loc2 ? loc2.index : this.loc.index),
              details: Object.assign({}, this.details, overrides.details)
            });
          },
          details: {
            value: details,
            enumerable: false
          },
          message: {
            get() {
              return `${toMessage(this.details)} (${this.loc.line}:${this.loc.column})`;
            },
            set(value2) {
              Object.defineProperty(this, "message", {
                value: value2
              });
            }
          },
          pos: {
            reflect: "loc.index",
            enumerable: true
          },
          missingPlugin: "missingPlugin" in details && {
            reflect: "details.missingPlugin",
            enumerable: true
          }
        });
      };
    }
    function ParseErrorEnum(argument, syntaxPlugin) {
      if (Array.isArray(argument)) {
        return (parseErrorTemplates) => ParseErrorEnum(parseErrorTemplates, argument[0]);
      }
      const ParseErrorConstructors = {};
      for (const reasonCode of Object.keys(argument)) {
        const template = argument[reasonCode];
        const _ref2 = typeof template === "string" ? {
          message: () => template
        } : typeof template === "function" ? {
          message: template
        } : template, {
          message
        } = _ref2, rest = _objectWithoutPropertiesLoose(_ref2, _excluded2$1);
        const toMessage = typeof message === "string" ? () => message : message;
        ParseErrorConstructors[reasonCode] = toParseErrorConstructor(Object.assign({
          code: ParseErrorCode.SyntaxError,
          reasonCode,
          toMessage
        }, syntaxPlugin ? {
          syntaxPlugin
        } : {}, rest));
      }
      return ParseErrorConstructors;
    }
    var Errors = Object.assign({}, ParseErrorEnum(ModuleErrors), ParseErrorEnum(StandardErrors), ParseErrorEnum(StrictModeErrors), ParseErrorEnum`pipelineOperator`(PipelineOperatorErrors));
    var {
      defineProperty
    } = Object;
    var toUnenumerable = (object, key) => defineProperty(object, key, {
      enumerable: false,
      value: object[key]
    });
    function toESTreeLocation(node) {
      node.loc.start && toUnenumerable(node.loc.start, "index");
      node.loc.end && toUnenumerable(node.loc.end, "index");
      return node;
    }
    var estree = (superClass) => class ESTreeParserMixin extends superClass {
      parse() {
        const file = toESTreeLocation(super.parse());
        if (this.options.tokens) {
          file.tokens = file.tokens.map(toESTreeLocation);
        }
        return file;
      }
      parseRegExpLiteral({
        pattern,
        flags
      }) {
        let regex = null;
        try {
          regex = new RegExp(pattern, flags);
        } catch (e) {
        }
        const node = this.estreeParseLiteral(regex);
        node.regex = {
          pattern,
          flags
        };
        return node;
      }
      parseBigIntLiteral(value2) {
        let bigInt;
        try {
          bigInt = BigInt(value2);
        } catch (_unused) {
          bigInt = null;
        }
        const node = this.estreeParseLiteral(bigInt);
        node.bigint = String(node.value || value2);
        return node;
      }
      parseDecimalLiteral(value2) {
        const decimal = null;
        const node = this.estreeParseLiteral(decimal);
        node.decimal = String(node.value || value2);
        return node;
      }
      estreeParseLiteral(value2) {
        return this.parseLiteral(value2, "Literal");
      }
      parseStringLiteral(value2) {
        return this.estreeParseLiteral(value2);
      }
      parseNumericLiteral(value2) {
        return this.estreeParseLiteral(value2);
      }
      parseNullLiteral() {
        return this.estreeParseLiteral(null);
      }
      parseBooleanLiteral(value2) {
        return this.estreeParseLiteral(value2);
      }
      directiveToStmt(directive) {
        const expression = directive.value;
        delete directive.value;
        expression.type = "Literal";
        expression.raw = expression.extra.raw;
        expression.value = expression.extra.expressionValue;
        const stmt = directive;
        stmt.type = "ExpressionStatement";
        stmt.expression = expression;
        stmt.directive = expression.extra.rawValue;
        delete expression.extra;
        return stmt;
      }
      initFunction(node, isAsync) {
        super.initFunction(node, isAsync);
        node.expression = false;
      }
      checkDeclaration(node) {
        if (node != null && this.isObjectProperty(node)) {
          this.checkDeclaration(node.value);
        } else {
          super.checkDeclaration(node);
        }
      }
      getObjectOrClassMethodParams(method) {
        return method.value.params;
      }
      isValidDirective(stmt) {
        var _stmt$expression$extr;
        return stmt.type === "ExpressionStatement" && stmt.expression.type === "Literal" && typeof stmt.expression.value === "string" && !((_stmt$expression$extr = stmt.expression.extra) != null && _stmt$expression$extr.parenthesized);
      }
      parseBlockBody(node, allowDirectives, topLevel, end, afterBlockParse) {
        super.parseBlockBody(node, allowDirectives, topLevel, end, afterBlockParse);
        const directiveStatements = node.directives.map((d) => this.directiveToStmt(d));
        node.body = directiveStatements.concat(node.body);
        delete node.directives;
      }
      pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper) {
        this.parseMethod(method, isGenerator, isAsync, isConstructor, allowsDirectSuper, "ClassMethod", true);
        if (method.typeParameters) {
          method.value.typeParameters = method.typeParameters;
          delete method.typeParameters;
        }
        classBody.body.push(method);
      }
      parsePrivateName() {
        const node = super.parsePrivateName();
        {
          if (!this.getPluginOption("estree", "classFeatures")) {
            return node;
          }
        }
        return this.convertPrivateNameToPrivateIdentifier(node);
      }
      convertPrivateNameToPrivateIdentifier(node) {
        const name = super.getPrivateNameSV(node);
        node = node;
        delete node.id;
        node.name = name;
        node.type = "PrivateIdentifier";
        return node;
      }
      isPrivateName(node) {
        {
          if (!this.getPluginOption("estree", "classFeatures")) {
            return super.isPrivateName(node);
          }
        }
        return node.type === "PrivateIdentifier";
      }
      getPrivateNameSV(node) {
        {
          if (!this.getPluginOption("estree", "classFeatures")) {
            return super.getPrivateNameSV(node);
          }
        }
        return node.name;
      }
      parseLiteral(value2, type) {
        const node = super.parseLiteral(value2, type);
        node.raw = node.extra.raw;
        delete node.extra;
        return node;
      }
      parseFunctionBody(node, allowExpression, isMethod = false) {
        super.parseFunctionBody(node, allowExpression, isMethod);
        node.expression = node.body.type !== "BlockStatement";
      }
      parseMethod(node, isGenerator, isAsync, isConstructor, allowDirectSuper, type, inClassScope = false) {
        let funcNode = this.startNode();
        funcNode.kind = node.kind;
        funcNode = super.parseMethod(
          funcNode,
          isGenerator,
          isAsync,
          isConstructor,
          allowDirectSuper,
          type,
          inClassScope
        );
        funcNode.type = "FunctionExpression";
        delete funcNode.kind;
        node.value = funcNode;
        if (type === "ClassPrivateMethod") {
          node.computed = false;
        }
        return this.finishNode(
          node,
          "MethodDefinition"
        );
      }
      parseClassProperty(...args) {
        const propertyNode = super.parseClassProperty(...args);
        {
          if (!this.getPluginOption("estree", "classFeatures")) {
            return propertyNode;
          }
        }
        propertyNode.type = "PropertyDefinition";
        return propertyNode;
      }
      parseClassPrivateProperty(...args) {
        const propertyNode = super.parseClassPrivateProperty(...args);
        {
          if (!this.getPluginOption("estree", "classFeatures")) {
            return propertyNode;
          }
        }
        propertyNode.type = "PropertyDefinition";
        propertyNode.computed = false;
        return propertyNode;
      }
      parseObjectMethod(prop, isGenerator, isAsync, isPattern, isAccessor) {
        const node = super.parseObjectMethod(prop, isGenerator, isAsync, isPattern, isAccessor);
        if (node) {
          node.type = "Property";
          if (node.kind === "method") {
            node.kind = "init";
          }
          node.shorthand = false;
        }
        return node;
      }
      parseObjectProperty(prop, startLoc, isPattern, refExpressionErrors) {
        const node = super.parseObjectProperty(prop, startLoc, isPattern, refExpressionErrors);
        if (node) {
          node.kind = "init";
          node.type = "Property";
        }
        return node;
      }
      isValidLVal(type, isUnparenthesizedInAssign, binding) {
        return type === "Property" ? "value" : super.isValidLVal(type, isUnparenthesizedInAssign, binding);
      }
      isAssignable(node, isBinding) {
        if (node != null && this.isObjectProperty(node)) {
          return this.isAssignable(node.value, isBinding);
        }
        return super.isAssignable(node, isBinding);
      }
      toAssignable(node, isLHS = false) {
        if (node != null && this.isObjectProperty(node)) {
          const {
            key,
            value: value2
          } = node;
          if (this.isPrivateName(key)) {
            this.classScope.usePrivateName(this.getPrivateNameSV(key), key.loc.start);
          }
          this.toAssignable(value2, isLHS);
        } else {
          super.toAssignable(node, isLHS);
        }
      }
      toAssignableObjectExpressionProp(prop, isLast, isLHS) {
        if (prop.kind === "get" || prop.kind === "set") {
          this.raise(Errors.PatternHasAccessor, {
            at: prop.key
          });
        } else if (prop.method) {
          this.raise(Errors.PatternHasMethod, {
            at: prop.key
          });
        } else {
          super.toAssignableObjectExpressionProp(prop, isLast, isLHS);
        }
      }
      finishCallExpression(unfinished, optional) {
        const node = super.finishCallExpression(unfinished, optional);
        if (node.callee.type === "Import") {
          node.type = "ImportExpression";
          node.source = node.arguments[0];
          if (this.hasPlugin("importAssertions")) {
            var _node$arguments$;
            node.attributes = (_node$arguments$ = node.arguments[1]) != null ? _node$arguments$ : null;
          }
          delete node.arguments;
          delete node.callee;
        }
        return node;
      }
      toReferencedArguments(node) {
        if (node.type === "ImportExpression") {
          return;
        }
        super.toReferencedArguments(node);
      }
      parseExport(unfinished, decorators) {
        const exportStartLoc = this.state.lastTokStartLoc;
        const node = super.parseExport(unfinished, decorators);
        switch (node.type) {
          case "ExportAllDeclaration":
            node.exported = null;
            break;
          case "ExportNamedDeclaration":
            if (node.specifiers.length === 1 && node.specifiers[0].type === "ExportNamespaceSpecifier") {
              node.type = "ExportAllDeclaration";
              node.exported = node.specifiers[0].exported;
              delete node.specifiers;
            }
          case "ExportDefaultDeclaration":
            {
              var _declaration$decorato;
              const {
                declaration
              } = node;
              if ((declaration == null ? void 0 : declaration.type) === "ClassDeclaration" && ((_declaration$decorato = declaration.decorators) == null ? void 0 : _declaration$decorato.length) > 0 && declaration.start === node.start) {
                this.resetStartLocation(
                  node,
                  exportStartLoc
                );
              }
            }
            break;
        }
        return node;
      }
      parseSubscript(base, startLoc, noCalls, state) {
        const node = super.parseSubscript(base, startLoc, noCalls, state);
        if (state.optionalChainMember) {
          if (node.type === "OptionalMemberExpression" || node.type === "OptionalCallExpression") {
            node.type = node.type.substring(8);
          }
          if (state.stop) {
            const chain = this.startNodeAtNode(node);
            chain.expression = node;
            return this.finishNode(chain, "ChainExpression");
          }
        } else if (node.type === "MemberExpression" || node.type === "CallExpression") {
          node.optional = false;
        }
        return node;
      }
      hasPropertyAsPrivateName(node) {
        if (node.type === "ChainExpression") {
          node = node.expression;
        }
        return super.hasPropertyAsPrivateName(node);
      }
      isOptionalChain(node) {
        return node.type === "ChainExpression";
      }
      isObjectProperty(node) {
        return node.type === "Property" && node.kind === "init" && !node.method;
      }
      isObjectMethod(node) {
        return node.method || node.kind === "get" || node.kind === "set";
      }
      finishNodeAt(node, type, endLoc) {
        return toESTreeLocation(super.finishNodeAt(node, type, endLoc));
      }
      resetStartLocation(node, startLoc) {
        super.resetStartLocation(node, startLoc);
        toESTreeLocation(node);
      }
      resetEndLocation(node, endLoc = this.state.lastTokEndLoc) {
        super.resetEndLocation(node, endLoc);
        toESTreeLocation(node);
      }
    };
    var TokContext = class {
      constructor(token, preserveSpace) {
        this.token = void 0;
        this.preserveSpace = void 0;
        this.token = token;
        this.preserveSpace = !!preserveSpace;
      }
    };
    var types = {
      brace: new TokContext("{"),
      j_oTag: new TokContext("<tag"),
      j_cTag: new TokContext("</tag"),
      j_expr: new TokContext("<tag>...</tag>", true)
    };
    {
      types.template = new TokContext("`", true);
    }
    var beforeExpr = true;
    var startsExpr = true;
    var isLoop = true;
    var isAssign = true;
    var prefix = true;
    var postfix = true;
    var ExportedTokenType = class {
      constructor(label, conf = {}) {
        this.label = void 0;
        this.keyword = void 0;
        this.beforeExpr = void 0;
        this.startsExpr = void 0;
        this.rightAssociative = void 0;
        this.isLoop = void 0;
        this.isAssign = void 0;
        this.prefix = void 0;
        this.postfix = void 0;
        this.binop = void 0;
        this.label = label;
        this.keyword = conf.keyword;
        this.beforeExpr = !!conf.beforeExpr;
        this.startsExpr = !!conf.startsExpr;
        this.rightAssociative = !!conf.rightAssociative;
        this.isLoop = !!conf.isLoop;
        this.isAssign = !!conf.isAssign;
        this.prefix = !!conf.prefix;
        this.postfix = !!conf.postfix;
        this.binop = conf.binop != null ? conf.binop : null;
        {
          this.updateContext = null;
        }
      }
    };
    var keywords$1 = /* @__PURE__ */ new Map();
    function createKeyword(name, options = {}) {
      options.keyword = name;
      const token = createToken(name, options);
      keywords$1.set(name, token);
      return token;
    }
    function createBinop(name, binop) {
      return createToken(name, {
        beforeExpr,
        binop
      });
    }
    var tokenTypeCounter = -1;
    var tokenTypes = [];
    var tokenLabels = [];
    var tokenBinops = [];
    var tokenBeforeExprs = [];
    var tokenStartsExprs = [];
    var tokenPrefixes = [];
    function createToken(name, options = {}) {
      var _options$binop, _options$beforeExpr, _options$startsExpr, _options$prefix;
      ++tokenTypeCounter;
      tokenLabels.push(name);
      tokenBinops.push((_options$binop = options.binop) != null ? _options$binop : -1);
      tokenBeforeExprs.push((_options$beforeExpr = options.beforeExpr) != null ? _options$beforeExpr : false);
      tokenStartsExprs.push((_options$startsExpr = options.startsExpr) != null ? _options$startsExpr : false);
      tokenPrefixes.push((_options$prefix = options.prefix) != null ? _options$prefix : false);
      tokenTypes.push(new ExportedTokenType(name, options));
      return tokenTypeCounter;
    }
    function createKeywordLike(name, options = {}) {
      var _options$binop2, _options$beforeExpr2, _options$startsExpr2, _options$prefix2;
      ++tokenTypeCounter;
      keywords$1.set(name, tokenTypeCounter);
      tokenLabels.push(name);
      tokenBinops.push((_options$binop2 = options.binop) != null ? _options$binop2 : -1);
      tokenBeforeExprs.push((_options$beforeExpr2 = options.beforeExpr) != null ? _options$beforeExpr2 : false);
      tokenStartsExprs.push((_options$startsExpr2 = options.startsExpr) != null ? _options$startsExpr2 : false);
      tokenPrefixes.push((_options$prefix2 = options.prefix) != null ? _options$prefix2 : false);
      tokenTypes.push(new ExportedTokenType("name", options));
      return tokenTypeCounter;
    }
    var tt = {
      bracketL: createToken("[", {
        beforeExpr,
        startsExpr
      }),
      bracketHashL: createToken("#[", {
        beforeExpr,
        startsExpr
      }),
      bracketBarL: createToken("[|", {
        beforeExpr,
        startsExpr
      }),
      bracketR: createToken("]"),
      bracketBarR: createToken("|]"),
      braceL: createToken("{", {
        beforeExpr,
        startsExpr
      }),
      braceBarL: createToken("{|", {
        beforeExpr,
        startsExpr
      }),
      braceHashL: createToken("#{", {
        beforeExpr,
        startsExpr
      }),
      braceR: createToken("}"),
      braceBarR: createToken("|}"),
      parenL: createToken("(", {
        beforeExpr,
        startsExpr
      }),
      parenR: createToken(")"),
      comma: createToken(",", {
        beforeExpr
      }),
      semi: createToken(";", {
        beforeExpr
      }),
      colon: createToken(":", {
        beforeExpr
      }),
      doubleColon: createToken("::", {
        beforeExpr
      }),
      dot: createToken("."),
      question: createToken("?", {
        beforeExpr
      }),
      questionDot: createToken("?."),
      arrow: createToken("=>", {
        beforeExpr
      }),
      template: createToken("template"),
      ellipsis: createToken("...", {
        beforeExpr
      }),
      backQuote: createToken("`", {
        startsExpr
      }),
      dollarBraceL: createToken("${", {
        beforeExpr,
        startsExpr
      }),
      templateTail: createToken("...`", {
        startsExpr
      }),
      templateNonTail: createToken("...${", {
        beforeExpr,
        startsExpr
      }),
      at: createToken("@"),
      hash: createToken("#", {
        startsExpr
      }),
      interpreterDirective: createToken("#!..."),
      eq: createToken("=", {
        beforeExpr,
        isAssign
      }),
      assign: createToken("_=", {
        beforeExpr,
        isAssign
      }),
      slashAssign: createToken("_=", {
        beforeExpr,
        isAssign
      }),
      xorAssign: createToken("_=", {
        beforeExpr,
        isAssign
      }),
      moduloAssign: createToken("_=", {
        beforeExpr,
        isAssign
      }),
      incDec: createToken("++/--", {
        prefix,
        postfix,
        startsExpr
      }),
      bang: createToken("!", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      tilde: createToken("~", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      doubleCaret: createToken("^^", {
        startsExpr
      }),
      doubleAt: createToken("@@", {
        startsExpr
      }),
      pipeline: createBinop("|>", 0),
      nullishCoalescing: createBinop("??", 1),
      logicalOR: createBinop("||", 1),
      logicalAND: createBinop("&&", 2),
      bitwiseOR: createBinop("|", 3),
      bitwiseXOR: createBinop("^", 4),
      bitwiseAND: createBinop("&", 5),
      equality: createBinop("==/!=/===/!==", 6),
      lt: createBinop("</>/<=/>=", 7),
      gt: createBinop("</>/<=/>=", 7),
      relational: createBinop("</>/<=/>=", 7),
      bitShift: createBinop("<</>>/>>>", 8),
      bitShiftL: createBinop("<</>>/>>>", 8),
      bitShiftR: createBinop("<</>>/>>>", 8),
      plusMin: createToken("+/-", {
        beforeExpr,
        binop: 9,
        prefix,
        startsExpr
      }),
      modulo: createToken("%", {
        binop: 10,
        startsExpr
      }),
      star: createToken("*", {
        binop: 10
      }),
      slash: createBinop("/", 10),
      exponent: createToken("**", {
        beforeExpr,
        binop: 11,
        rightAssociative: true
      }),
      _in: createKeyword("in", {
        beforeExpr,
        binop: 7
      }),
      _instanceof: createKeyword("instanceof", {
        beforeExpr,
        binop: 7
      }),
      _break: createKeyword("break"),
      _case: createKeyword("case", {
        beforeExpr
      }),
      _catch: createKeyword("catch"),
      _continue: createKeyword("continue"),
      _debugger: createKeyword("debugger"),
      _default: createKeyword("default", {
        beforeExpr
      }),
      _else: createKeyword("else", {
        beforeExpr
      }),
      _finally: createKeyword("finally"),
      _function: createKeyword("function", {
        startsExpr
      }),
      _if: createKeyword("if"),
      _return: createKeyword("return", {
        beforeExpr
      }),
      _switch: createKeyword("switch"),
      _throw: createKeyword("throw", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      _try: createKeyword("try"),
      _var: createKeyword("var"),
      _const: createKeyword("const"),
      _with: createKeyword("with"),
      _new: createKeyword("new", {
        beforeExpr,
        startsExpr
      }),
      _this: createKeyword("this", {
        startsExpr
      }),
      _super: createKeyword("super", {
        startsExpr
      }),
      _class: createKeyword("class", {
        startsExpr
      }),
      _extends: createKeyword("extends", {
        beforeExpr
      }),
      _export: createKeyword("export"),
      _import: createKeyword("import", {
        startsExpr
      }),
      _null: createKeyword("null", {
        startsExpr
      }),
      _true: createKeyword("true", {
        startsExpr
      }),
      _false: createKeyword("false", {
        startsExpr
      }),
      _typeof: createKeyword("typeof", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      _void: createKeyword("void", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      _delete: createKeyword("delete", {
        beforeExpr,
        prefix,
        startsExpr
      }),
      _do: createKeyword("do", {
        isLoop,
        beforeExpr
      }),
      _for: createKeyword("for", {
        isLoop
      }),
      _while: createKeyword("while", {
        isLoop
      }),
      _as: createKeywordLike("as", {
        startsExpr
      }),
      _assert: createKeywordLike("assert", {
        startsExpr
      }),
      _async: createKeywordLike("async", {
        startsExpr
      }),
      _await: createKeywordLike("await", {
        startsExpr
      }),
      _from: createKeywordLike("from", {
        startsExpr
      }),
      _get: createKeywordLike("get", {
        startsExpr
      }),
      _let: createKeywordLike("let", {
        startsExpr
      }),
      _meta: createKeywordLike("meta", {
        startsExpr
      }),
      _of: createKeywordLike("of", {
        startsExpr
      }),
      _sent: createKeywordLike("sent", {
        startsExpr
      }),
      _set: createKeywordLike("set", {
        startsExpr
      }),
      _static: createKeywordLike("static", {
        startsExpr
      }),
      _using: createKeywordLike("using", {
        startsExpr
      }),
      _yield: createKeywordLike("yield", {
        startsExpr
      }),
      _asserts: createKeywordLike("asserts", {
        startsExpr
      }),
      _checks: createKeywordLike("checks", {
        startsExpr
      }),
      _exports: createKeywordLike("exports", {
        startsExpr
      }),
      _global: createKeywordLike("global", {
        startsExpr
      }),
      _implements: createKeywordLike("implements", {
        startsExpr
      }),
      _intrinsic: createKeywordLike("intrinsic", {
        startsExpr
      }),
      _infer: createKeywordLike("infer", {
        startsExpr
      }),
      _is: createKeywordLike("is", {
        startsExpr
      }),
      _mixins: createKeywordLike("mixins", {
        startsExpr
      }),
      _proto: createKeywordLike("proto", {
        startsExpr
      }),
      _require: createKeywordLike("require", {
        startsExpr
      }),
      _satisfies: createKeywordLike("satisfies", {
        startsExpr
      }),
      _keyof: createKeywordLike("keyof", {
        startsExpr
      }),
      _readonly: createKeywordLike("readonly", {
        startsExpr
      }),
      _unique: createKeywordLike("unique", {
        startsExpr
      }),
      _abstract: createKeywordLike("abstract", {
        startsExpr
      }),
      _declare: createKeywordLike("declare", {
        startsExpr
      }),
      _enum: createKeywordLike("enum", {
        startsExpr
      }),
      _module: createKeywordLike("module", {
        startsExpr
      }),
      _namespace: createKeywordLike("namespace", {
        startsExpr
      }),
      _interface: createKeywordLike("interface", {
        startsExpr
      }),
      _type: createKeywordLike("type", {
        startsExpr
      }),
      _opaque: createKeywordLike("opaque", {
        startsExpr
      }),
      name: createToken("name", {
        startsExpr
      }),
      string: createToken("string", {
        startsExpr
      }),
      num: createToken("num", {
        startsExpr
      }),
      bigint: createToken("bigint", {
        startsExpr
      }),
      decimal: createToken("decimal", {
        startsExpr
      }),
      regexp: createToken("regexp", {
        startsExpr
      }),
      privateName: createToken("#name", {
        startsExpr
      }),
      eof: createToken("eof"),
      jsxName: createToken("jsxName"),
      jsxText: createToken("jsxText", {
        beforeExpr: true
      }),
      jsxTagStart: createToken("jsxTagStart", {
        startsExpr: true
      }),
      jsxTagEnd: createToken("jsxTagEnd"),
      placeholder: createToken("%%", {
        startsExpr: true
      })
    };
    function tokenIsIdentifier(token) {
      return token >= 93 && token <= 130;
    }
    function tokenKeywordOrIdentifierIsKeyword(token) {
      return token <= 92;
    }
    function tokenIsKeywordOrIdentifier(token) {
      return token >= 58 && token <= 130;
    }
    function tokenIsLiteralPropertyName(token) {
      return token >= 58 && token <= 134;
    }
    function tokenComesBeforeExpression(token) {
      return tokenBeforeExprs[token];
    }
    function tokenCanStartExpression(token) {
      return tokenStartsExprs[token];
    }
    function tokenIsAssignment(token) {
      return token >= 29 && token <= 33;
    }
    function tokenIsFlowInterfaceOrTypeOrOpaque(token) {
      return token >= 127 && token <= 129;
    }
    function tokenIsLoop(token) {
      return token >= 90 && token <= 92;
    }
    function tokenIsKeyword(token) {
      return token >= 58 && token <= 92;
    }
    function tokenIsOperator(token) {
      return token >= 39 && token <= 59;
    }
    function tokenIsPostfix(token) {
      return token === 34;
    }
    function tokenIsPrefix(token) {
      return tokenPrefixes[token];
    }
    function tokenIsTSTypeOperator(token) {
      return token >= 119 && token <= 121;
    }
    function tokenIsTSDeclarationStart(token) {
      return token >= 122 && token <= 128;
    }
    function tokenLabelName(token) {
      return tokenLabels[token];
    }
    function tokenOperatorPrecedence(token) {
      return tokenBinops[token];
    }
    function tokenIsRightAssociative(token) {
      return token === 57;
    }
    function tokenIsTemplate(token) {
      return token >= 24 && token <= 25;
    }
    function getExportedToken(token) {
      return tokenTypes[token];
    }
    {
      tokenTypes[8].updateContext = (context) => {
        context.pop();
      };
      tokenTypes[5].updateContext = tokenTypes[7].updateContext = tokenTypes[23].updateContext = (context) => {
        context.push(types.brace);
      };
      tokenTypes[22].updateContext = (context) => {
        if (context[context.length - 1] === types.template) {
          context.pop();
        } else {
          context.push(types.template);
        }
      };
      tokenTypes[140].updateContext = (context) => {
        context.push(types.j_expr, types.j_oTag);
      };
    }
    var nonASCIIidentifierStartChars = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC";
    var nonASCIIidentifierChars = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F";
    var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
    var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
    nonASCIIidentifierStartChars = nonASCIIidentifierChars = null;
    var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
    var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
    function isInAstralSet(code, set) {
      let pos = 65536;
      for (let i = 0, length = set.length; i < length; i += 2) {
        pos += set[i];
        if (pos > code)
          return false;
        pos += set[i + 1];
        if (pos >= code)
          return true;
      }
      return false;
    }
    function isIdentifierStart(code) {
      if (code < 65)
        return code === 36;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifierStart.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes);
    }
    function isIdentifierChar(code) {
      if (code < 48)
        return code === 36;
      if (code < 58)
        return true;
      if (code < 65)
        return false;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifier.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
    }
    var reservedWords = {
      keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"],
      strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"],
      strictBind: ["eval", "arguments"]
    };
    var keywords = new Set(reservedWords.keyword);
    var reservedWordsStrictSet = new Set(reservedWords.strict);
    var reservedWordsStrictBindSet = new Set(reservedWords.strictBind);
    function isReservedWord(word, inModule) {
      return inModule && word === "await" || word === "enum";
    }
    function isStrictReservedWord(word, inModule) {
      return isReservedWord(word, inModule) || reservedWordsStrictSet.has(word);
    }
    function isStrictBindOnlyReservedWord(word) {
      return reservedWordsStrictBindSet.has(word);
    }
    function isStrictBindReservedWord(word, inModule) {
      return isStrictReservedWord(word, inModule) || isStrictBindOnlyReservedWord(word);
    }
    function isKeyword(word) {
      return keywords.has(word);
    }
    function isIteratorStart(current, next, next2) {
      return current === 64 && next === 64 && isIdentifierStart(next2);
    }
    var reservedWordLikeSet = /* @__PURE__ */ new Set([
      "break",
      "case",
      "catch",
      "continue",
      "debugger",
      "default",
      "do",
      "else",
      "finally",
      "for",
      "function",
      "if",
      "return",
      "switch",
      "throw",
      "try",
      "var",
      "const",
      "while",
      "with",
      "new",
      "this",
      "super",
      "class",
      "extends",
      "export",
      "import",
      "null",
      "true",
      "false",
      "in",
      "instanceof",
      "typeof",
      "void",
      "delete",
      "implements",
      "interface",
      "let",
      "package",
      "private",
      "protected",
      "public",
      "static",
      "yield",
      "eval",
      "arguments",
      "enum",
      "await"
    ]);
    function canBeReservedWord(word) {
      return reservedWordLikeSet.has(word);
    }
    var SCOPE_OTHER = 0;
    var SCOPE_PROGRAM = 1;
    var SCOPE_FUNCTION = 2;
    var SCOPE_ARROW = 4;
    var SCOPE_SIMPLE_CATCH = 8;
    var SCOPE_SUPER = 16;
    var SCOPE_DIRECT_SUPER = 32;
    var SCOPE_CLASS = 64;
    var SCOPE_STATIC_BLOCK = 128;
    var SCOPE_TS_MODULE = 256;
    var SCOPE_VAR = SCOPE_PROGRAM | SCOPE_FUNCTION | SCOPE_STATIC_BLOCK | SCOPE_TS_MODULE;
    var BIND_KIND_VALUE = 1;
    var BIND_KIND_TYPE = 2;
    var BIND_SCOPE_VAR = 4;
    var BIND_SCOPE_LEXICAL = 8;
    var BIND_SCOPE_FUNCTION = 16;
    var BIND_FLAGS_NONE = 64;
    var BIND_FLAGS_CLASS = 128;
    var BIND_FLAGS_TS_ENUM = 256;
    var BIND_FLAGS_TS_CONST_ENUM = 512;
    var BIND_FLAGS_TS_EXPORT_ONLY = 1024;
    var BIND_FLAGS_FLOW_DECLARE_FN = 2048;
    var BIND_FLAGS_TS_IMPORT = 4096;
    var BIND_CLASS = BIND_KIND_VALUE | BIND_KIND_TYPE | BIND_SCOPE_LEXICAL | BIND_FLAGS_CLASS;
    var BIND_LEXICAL = BIND_KIND_VALUE | 0 | BIND_SCOPE_LEXICAL | 0;
    var BIND_VAR = BIND_KIND_VALUE | 0 | BIND_SCOPE_VAR | 0;
    var BIND_FUNCTION = BIND_KIND_VALUE | 0 | BIND_SCOPE_FUNCTION | 0;
    var BIND_TS_INTERFACE = 0 | BIND_KIND_TYPE | 0 | BIND_FLAGS_CLASS;
    var BIND_TS_TYPE = 0 | BIND_KIND_TYPE | 0 | 0;
    var BIND_TS_ENUM = BIND_KIND_VALUE | BIND_KIND_TYPE | BIND_SCOPE_LEXICAL | BIND_FLAGS_TS_ENUM;
    var BIND_TS_AMBIENT = 0 | 0 | 0 | BIND_FLAGS_TS_EXPORT_ONLY;
    var BIND_NONE = 0 | 0 | 0 | BIND_FLAGS_NONE;
    var BIND_OUTSIDE = BIND_KIND_VALUE | 0 | 0 | BIND_FLAGS_NONE;
    var BIND_TS_CONST_ENUM = BIND_TS_ENUM | BIND_FLAGS_TS_CONST_ENUM;
    var BIND_TS_NAMESPACE = 0 | 0 | 0 | BIND_FLAGS_TS_EXPORT_ONLY;
    var BIND_TS_TYPE_IMPORT = 0 | BIND_KIND_TYPE | 0 | BIND_FLAGS_TS_IMPORT;
    var BIND_FLOW_DECLARE_FN = BIND_FLAGS_FLOW_DECLARE_FN;
    var CLASS_ELEMENT_FLAG_STATIC = 4;
    var CLASS_ELEMENT_KIND_GETTER = 2;
    var CLASS_ELEMENT_KIND_SETTER = 1;
    var CLASS_ELEMENT_KIND_ACCESSOR = CLASS_ELEMENT_KIND_GETTER | CLASS_ELEMENT_KIND_SETTER;
    var CLASS_ELEMENT_STATIC_GETTER = CLASS_ELEMENT_KIND_GETTER | CLASS_ELEMENT_FLAG_STATIC;
    var CLASS_ELEMENT_STATIC_SETTER = CLASS_ELEMENT_KIND_SETTER | CLASS_ELEMENT_FLAG_STATIC;
    var CLASS_ELEMENT_INSTANCE_GETTER = CLASS_ELEMENT_KIND_GETTER;
    var CLASS_ELEMENT_INSTANCE_SETTER = CLASS_ELEMENT_KIND_SETTER;
    var CLASS_ELEMENT_OTHER = 0;
    var Scope = class {
      constructor(flags) {
        this.var = /* @__PURE__ */ new Set();
        this.lexical = /* @__PURE__ */ new Set();
        this.functions = /* @__PURE__ */ new Set();
        this.flags = flags;
      }
    };
    var ScopeHandler = class {
      constructor(parser, inModule) {
        this.parser = void 0;
        this.scopeStack = [];
        this.inModule = void 0;
        this.undefinedExports = /* @__PURE__ */ new Map();
        this.parser = parser;
        this.inModule = inModule;
      }
      get inTopLevel() {
        return (this.currentScope().flags & SCOPE_PROGRAM) > 0;
      }
      get inFunction() {
        return (this.currentVarScopeFlags() & SCOPE_FUNCTION) > 0;
      }
      get allowSuper() {
        return (this.currentThisScopeFlags() & SCOPE_SUPER) > 0;
      }
      get allowDirectSuper() {
        return (this.currentThisScopeFlags() & SCOPE_DIRECT_SUPER) > 0;
      }
      get inClass() {
        return (this.currentThisScopeFlags() & SCOPE_CLASS) > 0;
      }
      get inClassAndNotInNonArrowFunction() {
        const flags = this.currentThisScopeFlags();
        return (flags & SCOPE_CLASS) > 0 && (flags & SCOPE_FUNCTION) === 0;
      }
      get inStaticBlock() {
        for (let i = this.scopeStack.length - 1; ; i--) {
          const {
            flags
          } = this.scopeStack[i];
          if (flags & SCOPE_STATIC_BLOCK) {
            return true;
          }
          if (flags & (SCOPE_VAR | SCOPE_CLASS)) {
            return false;
          }
        }
      }
      get inNonArrowFunction() {
        return (this.currentThisScopeFlags() & SCOPE_FUNCTION) > 0;
      }
      get treatFunctionsAsVar() {
        return this.treatFunctionsAsVarInScope(this.currentScope());
      }
      createScope(flags) {
        return new Scope(flags);
      }
      enter(flags) {
        this.scopeStack.push(this.createScope(flags));
      }
      exit() {
        const scope = this.scopeStack.pop();
        return scope.flags;
      }
      treatFunctionsAsVarInScope(scope) {
        return !!(scope.flags & (SCOPE_FUNCTION | SCOPE_STATIC_BLOCK) || !this.parser.inModule && scope.flags & SCOPE_PROGRAM);
      }
      declareName(name, bindingType, loc) {
        let scope = this.currentScope();
        if (bindingType & BIND_SCOPE_LEXICAL || bindingType & BIND_SCOPE_FUNCTION) {
          this.checkRedeclarationInScope(scope, name, bindingType, loc);
          if (bindingType & BIND_SCOPE_FUNCTION) {
            scope.functions.add(name);
          } else {
            scope.lexical.add(name);
          }
          if (bindingType & BIND_SCOPE_LEXICAL) {
            this.maybeExportDefined(scope, name);
          }
        } else if (bindingType & BIND_SCOPE_VAR) {
          for (let i = this.scopeStack.length - 1; i >= 0; --i) {
            scope = this.scopeStack[i];
            this.checkRedeclarationInScope(scope, name, bindingType, loc);
            scope.var.add(name);
            this.maybeExportDefined(scope, name);
            if (scope.flags & SCOPE_VAR)
              break;
          }
        }
        if (this.parser.inModule && scope.flags & SCOPE_PROGRAM) {
          this.undefinedExports.delete(name);
        }
      }
      maybeExportDefined(scope, name) {
        if (this.parser.inModule && scope.flags & SCOPE_PROGRAM) {
          this.undefinedExports.delete(name);
        }
      }
      checkRedeclarationInScope(scope, name, bindingType, loc) {
        if (this.isRedeclaredInScope(scope, name, bindingType)) {
          this.parser.raise(Errors.VarRedeclaration, {
            at: loc,
            identifierName: name
          });
        }
      }
      isRedeclaredInScope(scope, name, bindingType) {
        if (!(bindingType & BIND_KIND_VALUE))
          return false;
        if (bindingType & BIND_SCOPE_LEXICAL) {
          return scope.lexical.has(name) || scope.functions.has(name) || scope.var.has(name);
        }
        if (bindingType & BIND_SCOPE_FUNCTION) {
          return scope.lexical.has(name) || !this.treatFunctionsAsVarInScope(scope) && scope.var.has(name);
        }
        return scope.lexical.has(name) && !(scope.flags & SCOPE_SIMPLE_CATCH && scope.lexical.values().next().value === name) || !this.treatFunctionsAsVarInScope(scope) && scope.functions.has(name);
      }
      checkLocalExport(id) {
        const {
          name
        } = id;
        const topLevelScope = this.scopeStack[0];
        if (!topLevelScope.lexical.has(name) && !topLevelScope.var.has(name) && !topLevelScope.functions.has(name)) {
          this.undefinedExports.set(name, id.loc.start);
        }
      }
      currentScope() {
        return this.scopeStack[this.scopeStack.length - 1];
      }
      currentVarScopeFlags() {
        for (let i = this.scopeStack.length - 1; ; i--) {
          const {
            flags
          } = this.scopeStack[i];
          if (flags & SCOPE_VAR) {
            return flags;
          }
        }
      }
      currentThisScopeFlags() {
        for (let i = this.scopeStack.length - 1; ; i--) {
          const {
            flags
          } = this.scopeStack[i];
          if (flags & (SCOPE_VAR | SCOPE_CLASS) && !(flags & SCOPE_ARROW)) {
            return flags;
          }
        }
      }
    };
    var FlowScope = class extends Scope {
      constructor(...args) {
        super(...args);
        this.declareFunctions = /* @__PURE__ */ new Set();
      }
    };
    var FlowScopeHandler = class extends ScopeHandler {
      createScope(flags) {
        return new FlowScope(flags);
      }
      declareName(name, bindingType, loc) {
        const scope = this.currentScope();
        if (bindingType & BIND_FLAGS_FLOW_DECLARE_FN) {
          this.checkRedeclarationInScope(scope, name, bindingType, loc);
          this.maybeExportDefined(scope, name);
          scope.declareFunctions.add(name);
          return;
        }
        super.declareName(name, bindingType, loc);
      }
      isRedeclaredInScope(scope, name, bindingType) {
        if (super.isRedeclaredInScope(scope, name, bindingType))
          return true;
        if (bindingType & BIND_FLAGS_FLOW_DECLARE_FN) {
          return !scope.declareFunctions.has(name) && (scope.lexical.has(name) || scope.functions.has(name));
        }
        return false;
      }
      checkLocalExport(id) {
        if (!this.scopeStack[0].declareFunctions.has(id.name)) {
          super.checkLocalExport(id);
        }
      }
    };
    var BaseParser = class {
      constructor() {
        this.sawUnambiguousESM = false;
        this.ambiguousScriptDifferentAst = false;
      }
      hasPlugin(pluginConfig) {
        if (typeof pluginConfig === "string") {
          return this.plugins.has(pluginConfig);
        } else {
          const [pluginName, pluginOptions] = pluginConfig;
          if (!this.hasPlugin(pluginName)) {
            return false;
          }
          const actualOptions = this.plugins.get(pluginName);
          for (const key of Object.keys(pluginOptions)) {
            if ((actualOptions == null ? void 0 : actualOptions[key]) !== pluginOptions[key]) {
              return false;
            }
          }
          return true;
        }
      }
      getPluginOption(plugin, name) {
        var _this$plugins$get;
        return (_this$plugins$get = this.plugins.get(plugin)) == null ? void 0 : _this$plugins$get[name];
      }
    };
    function setTrailingComments(node, comments) {
      if (node.trailingComments === void 0) {
        node.trailingComments = comments;
      } else {
        node.trailingComments.unshift(...comments);
      }
    }
    function setLeadingComments(node, comments) {
      if (node.leadingComments === void 0) {
        node.leadingComments = comments;
      } else {
        node.leadingComments.unshift(...comments);
      }
    }
    function setInnerComments(node, comments) {
      if (node.innerComments === void 0) {
        node.innerComments = comments;
      } else {
        node.innerComments.unshift(...comments);
      }
    }
    function adjustInnerComments(node, elements, commentWS) {
      let lastElement = null;
      let i = elements.length;
      while (lastElement === null && i > 0) {
        lastElement = elements[--i];
      }
      if (lastElement === null || lastElement.start > commentWS.start) {
        setInnerComments(node, commentWS.comments);
      } else {
        setTrailingComments(lastElement, commentWS.comments);
      }
    }
    var CommentsParser = class extends BaseParser {
      addComment(comment) {
        if (this.filename)
          comment.loc.filename = this.filename;
        this.state.comments.push(comment);
      }
      processComment(node) {
        const {
          commentStack
        } = this.state;
        const commentStackLength = commentStack.length;
        if (commentStackLength === 0)
          return;
        let i = commentStackLength - 1;
        const lastCommentWS = commentStack[i];
        if (lastCommentWS.start === node.end) {
          lastCommentWS.leadingNode = node;
          i--;
        }
        const {
          start: nodeStart
        } = node;
        for (; i >= 0; i--) {
          const commentWS = commentStack[i];
          const commentEnd = commentWS.end;
          if (commentEnd > nodeStart) {
            commentWS.containingNode = node;
            this.finalizeComment(commentWS);
            commentStack.splice(i, 1);
          } else {
            if (commentEnd === nodeStart) {
              commentWS.trailingNode = node;
            }
            break;
          }
        }
      }
      finalizeComment(commentWS) {
        const {
          comments
        } = commentWS;
        if (commentWS.leadingNode !== null || commentWS.trailingNode !== null) {
          if (commentWS.leadingNode !== null) {
            setTrailingComments(commentWS.leadingNode, comments);
          }
          if (commentWS.trailingNode !== null) {
            setLeadingComments(commentWS.trailingNode, comments);
          }
        } else {
          const {
            containingNode: node,
            start: commentStart
          } = commentWS;
          if (this.input.charCodeAt(commentStart - 1) === 44) {
            switch (node.type) {
              case "ObjectExpression":
              case "ObjectPattern":
              case "RecordExpression":
                adjustInnerComments(node, node.properties, commentWS);
                break;
              case "CallExpression":
              case "OptionalCallExpression":
                adjustInnerComments(node, node.arguments, commentWS);
                break;
              case "FunctionDeclaration":
              case "FunctionExpression":
              case "ArrowFunctionExpression":
              case "ObjectMethod":
              case "ClassMethod":
              case "ClassPrivateMethod":
                adjustInnerComments(node, node.params, commentWS);
                break;
              case "ArrayExpression":
              case "ArrayPattern":
              case "TupleExpression":
                adjustInnerComments(node, node.elements, commentWS);
                break;
              case "ExportNamedDeclaration":
              case "ImportDeclaration":
                adjustInnerComments(node, node.specifiers, commentWS);
                break;
              default: {
                setInnerComments(node, comments);
              }
            }
          } else {
            setInnerComments(node, comments);
          }
        }
      }
      finalizeRemainingComments() {
        const {
          commentStack
        } = this.state;
        for (let i = commentStack.length - 1; i >= 0; i--) {
          this.finalizeComment(commentStack[i]);
        }
        this.state.commentStack = [];
      }
      resetPreviousNodeTrailingComments(node) {
        const {
          commentStack
        } = this.state;
        const {
          length
        } = commentStack;
        if (length === 0)
          return;
        const commentWS = commentStack[length - 1];
        if (commentWS.leadingNode === node) {
          commentWS.leadingNode = null;
        }
      }
      takeSurroundingComments(node, start, end) {
        const {
          commentStack
        } = this.state;
        const commentStackLength = commentStack.length;
        if (commentStackLength === 0)
          return;
        let i = commentStackLength - 1;
        for (; i >= 0; i--) {
          const commentWS = commentStack[i];
          const commentEnd = commentWS.end;
          const commentStart = commentWS.start;
          if (commentStart === end) {
            commentWS.leadingNode = node;
          } else if (commentEnd === start) {
            commentWS.trailingNode = node;
          } else if (commentEnd < start) {
            break;
          }
        }
      }
    };
    var lineBreak = /\r\n?|[\n\u2028\u2029]/;
    var lineBreakG = new RegExp(lineBreak.source, "g");
    function isNewLine(code) {
      switch (code) {
        case 10:
        case 13:
        case 8232:
        case 8233:
          return true;
        default:
          return false;
      }
    }
    var skipWhiteSpace = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g;
    var skipWhiteSpaceInLine = /(?:[^\S\n\r\u2028\u2029]|\/\/.*|\/\*.*?\*\/)*/y;
    var skipWhiteSpaceToLineBreak = new RegExp(
      "(?=(" + skipWhiteSpaceInLine.source + "))\\1" + /(?=[\n\r\u2028\u2029]|\/\*(?!.*?\*\/)|$)/.source,
      "y"
    );
    function isWhitespace(code) {
      switch (code) {
        case 9:
        case 11:
        case 12:
        case 32:
        case 160:
        case 5760:
        case 8192:
        case 8193:
        case 8194:
        case 8195:
        case 8196:
        case 8197:
        case 8198:
        case 8199:
        case 8200:
        case 8201:
        case 8202:
        case 8239:
        case 8287:
        case 12288:
        case 65279:
          return true;
        default:
          return false;
      }
    }
    var State = class _State {
      constructor() {
        this.strict = void 0;
        this.curLine = void 0;
        this.lineStart = void 0;
        this.startLoc = void 0;
        this.endLoc = void 0;
        this.errors = [];
        this.potentialArrowAt = -1;
        this.noArrowAt = [];
        this.noArrowParamsConversionAt = [];
        this.maybeInArrowParameters = false;
        this.inType = false;
        this.noAnonFunctionType = false;
        this.hasFlowComment = false;
        this.isAmbientContext = false;
        this.inAbstractClass = false;
        this.inDisallowConditionalTypesContext = false;
        this.topicContext = {
          maxNumOfResolvableTopics: 0,
          maxTopicIndex: null
        };
        this.soloAwait = false;
        this.inFSharpPipelineDirectBody = false;
        this.labels = [];
        this.comments = [];
        this.commentStack = [];
        this.pos = 0;
        this.type = 137;
        this.value = null;
        this.start = 0;
        this.end = 0;
        this.lastTokEndLoc = null;
        this.lastTokStartLoc = null;
        this.lastTokStart = 0;
        this.context = [types.brace];
        this.canStartJSXElement = true;
        this.containsEsc = false;
        this.firstInvalidTemplateEscapePos = null;
        this.strictErrors = /* @__PURE__ */ new Map();
        this.tokensLength = 0;
      }
      init({
        strictMode,
        sourceType,
        startLine,
        startColumn
      }) {
        this.strict = strictMode === false ? false : strictMode === true ? true : sourceType === "module";
        this.curLine = startLine;
        this.lineStart = -startColumn;
        this.startLoc = this.endLoc = new Position(startLine, startColumn, 0);
      }
      curPosition() {
        return new Position(this.curLine, this.pos - this.lineStart, this.pos);
      }
      clone(skipArrays) {
        const state = new _State();
        const keys3 = Object.keys(this);
        for (let i = 0, length = keys3.length; i < length; i++) {
          const key = keys3[i];
          let val = this[key];
          if (!skipArrays && Array.isArray(val)) {
            val = val.slice();
          }
          state[key] = val;
        }
        return state;
      }
    };
    var _isDigit = function isDigit(code) {
      return code >= 48 && code <= 57;
    };
    var forbiddenNumericSeparatorSiblings = {
      decBinOct: /* @__PURE__ */ new Set([46, 66, 69, 79, 95, 98, 101, 111]),
      hex: /* @__PURE__ */ new Set([46, 88, 95, 120])
    };
    var isAllowedNumericSeparatorSibling = {
      bin: (ch) => ch === 48 || ch === 49,
      oct: (ch) => ch >= 48 && ch <= 55,
      dec: (ch) => ch >= 48 && ch <= 57,
      hex: (ch) => ch >= 48 && ch <= 57 || ch >= 65 && ch <= 70 || ch >= 97 && ch <= 102
    };
    function readStringContents(type, input, pos, lineStart, curLine, errors) {
      const initialPos = pos;
      const initialLineStart = lineStart;
      const initialCurLine = curLine;
      let out = "";
      let firstInvalidLoc = null;
      let chunkStart = pos;
      const {
        length
      } = input;
      for (; ; ) {
        if (pos >= length) {
          errors.unterminated(initialPos, initialLineStart, initialCurLine);
          out += input.slice(chunkStart, pos);
          break;
        }
        const ch = input.charCodeAt(pos);
        if (isStringEnd(type, ch, input, pos)) {
          out += input.slice(chunkStart, pos);
          break;
        }
        if (ch === 92) {
          out += input.slice(chunkStart, pos);
          const res = readEscapedChar(input, pos, lineStart, curLine, type === "template", errors);
          if (res.ch === null && !firstInvalidLoc) {
            firstInvalidLoc = {
              pos,
              lineStart,
              curLine
            };
          } else {
            out += res.ch;
          }
          ({
            pos,
            lineStart,
            curLine
          } = res);
          chunkStart = pos;
        } else if (ch === 8232 || ch === 8233) {
          ++pos;
          ++curLine;
          lineStart = pos;
        } else if (ch === 10 || ch === 13) {
          if (type === "template") {
            out += input.slice(chunkStart, pos) + "\n";
            ++pos;
            if (ch === 13 && input.charCodeAt(pos) === 10) {
              ++pos;
            }
            ++curLine;
            chunkStart = lineStart = pos;
          } else {
            errors.unterminated(initialPos, initialLineStart, initialCurLine);
          }
        } else {
          ++pos;
        }
      }
      return {
        pos,
        str: out,
        firstInvalidLoc,
        lineStart,
        curLine,
        containsInvalid: !!firstInvalidLoc
      };
    }
    function isStringEnd(type, ch, input, pos) {
      if (type === "template") {
        return ch === 96 || ch === 36 && input.charCodeAt(pos + 1) === 123;
      }
      return ch === (type === "double" ? 34 : 39);
    }
    function readEscapedChar(input, pos, lineStart, curLine, inTemplate, errors) {
      const throwOnInvalid = !inTemplate;
      pos++;
      const res = (ch2) => ({
        pos,
        ch: ch2,
        lineStart,
        curLine
      });
      const ch = input.charCodeAt(pos++);
      switch (ch) {
        case 110:
          return res("\n");
        case 114:
          return res("\r");
        case 120: {
          let code;
          ({
            code,
            pos
          } = readHexChar(input, pos, lineStart, curLine, 2, false, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCharCode(code));
        }
        case 117: {
          let code;
          ({
            code,
            pos
          } = readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCodePoint(code));
        }
        case 116:
          return res("	");
        case 98:
          return res("\b");
        case 118:
          return res("\v");
        case 102:
          return res("\f");
        case 13:
          if (input.charCodeAt(pos) === 10) {
            ++pos;
          }
        case 10:
          lineStart = pos;
          ++curLine;
        case 8232:
        case 8233:
          return res("");
        case 56:
        case 57:
          if (inTemplate) {
            return res(null);
          } else {
            errors.strictNumericEscape(pos - 1, lineStart, curLine);
          }
        default:
          if (ch >= 48 && ch <= 55) {
            const startPos = pos - 1;
            const match = input.slice(startPos, pos + 2).match(/^[0-7]+/);
            let octalStr = match[0];
            let octal = parseInt(octalStr, 8);
            if (octal > 255) {
              octalStr = octalStr.slice(0, -1);
              octal = parseInt(octalStr, 8);
            }
            pos += octalStr.length - 1;
            const next = input.charCodeAt(pos);
            if (octalStr !== "0" || next === 56 || next === 57) {
              if (inTemplate) {
                return res(null);
              } else {
                errors.strictNumericEscape(startPos, lineStart, curLine);
              }
            }
            return res(String.fromCharCode(octal));
          }
          return res(String.fromCharCode(ch));
      }
    }
    function readHexChar(input, pos, lineStart, curLine, len, forceLen, throwOnInvalid, errors) {
      const initialPos = pos;
      let n;
      ({
        n,
        pos
      } = readInt(input, pos, lineStart, curLine, 16, len, forceLen, false, errors, !throwOnInvalid));
      if (n === null) {
        if (throwOnInvalid) {
          errors.invalidEscapeSequence(initialPos, lineStart, curLine);
        } else {
          pos = initialPos - 1;
        }
      }
      return {
        code: n,
        pos
      };
    }
    function readInt(input, pos, lineStart, curLine, radix, len, forceLen, allowNumSeparator, errors, bailOnError) {
      const start = pos;
      const forbiddenSiblings = radix === 16 ? forbiddenNumericSeparatorSiblings.hex : forbiddenNumericSeparatorSiblings.decBinOct;
      const isAllowedSibling = radix === 16 ? isAllowedNumericSeparatorSibling.hex : radix === 10 ? isAllowedNumericSeparatorSibling.dec : radix === 8 ? isAllowedNumericSeparatorSibling.oct : isAllowedNumericSeparatorSibling.bin;
      let invalid = false;
      let total = 0;
      for (let i = 0, e = len == null ? Infinity : len; i < e; ++i) {
        const code = input.charCodeAt(pos);
        let val;
        if (code === 95 && allowNumSeparator !== "bail") {
          const prev = input.charCodeAt(pos - 1);
          const next = input.charCodeAt(pos + 1);
          if (!allowNumSeparator) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.numericSeparatorInEscapeSequence(pos, lineStart, curLine);
          } else if (Number.isNaN(next) || !isAllowedSibling(next) || forbiddenSiblings.has(prev) || forbiddenSiblings.has(next)) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.unexpectedNumericSeparator(pos, lineStart, curLine);
          }
          ++pos;
          continue;
        }
        if (code >= 97) {
          val = code - 97 + 10;
        } else if (code >= 65) {
          val = code - 65 + 10;
        } else if (_isDigit(code)) {
          val = code - 48;
        } else {
          val = Infinity;
        }
        if (val >= radix) {
          if (val <= 9 && bailOnError) {
            return {
              n: null,
              pos
            };
          } else if (val <= 9 && errors.invalidDigit(pos, lineStart, curLine, radix)) {
            val = 0;
          } else if (forceLen) {
            val = 0;
            invalid = true;
          } else {
            break;
          }
        }
        ++pos;
        total = total * radix + val;
      }
      if (pos === start || len != null && pos - start !== len || invalid) {
        return {
          n: null,
          pos
        };
      }
      return {
        n: total,
        pos
      };
    }
    function readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors) {
      const ch = input.charCodeAt(pos);
      let code;
      if (ch === 123) {
        ++pos;
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, input.indexOf("}", pos) - pos, true, throwOnInvalid, errors));
        ++pos;
        if (code !== null && code > 1114111) {
          if (throwOnInvalid) {
            errors.invalidCodePoint(pos, lineStart, curLine);
          } else {
            return {
              code: null,
              pos
            };
          }
        }
      } else {
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, 4, false, throwOnInvalid, errors));
      }
      return {
        code,
        pos
      };
    }
    var _excluded = ["at"];
    var _excluded2 = ["at"];
    function buildPosition(pos, lineStart, curLine) {
      return new Position(curLine, pos - lineStart, pos);
    }
    var VALID_REGEX_FLAGS = /* @__PURE__ */ new Set([103, 109, 115, 105, 121, 117, 100, 118]);
    var Token = class {
      constructor(state) {
        this.type = state.type;
        this.value = state.value;
        this.start = state.start;
        this.end = state.end;
        this.loc = new SourceLocation(state.startLoc, state.endLoc);
      }
    };
    var Tokenizer = class extends CommentsParser {
      constructor(options, input) {
        super();
        this.isLookahead = void 0;
        this.tokens = [];
        this.errorHandlers_readInt = {
          invalidDigit: (pos, lineStart, curLine, radix) => {
            if (!this.options.errorRecovery)
              return false;
            this.raise(Errors.InvalidDigit, {
              at: buildPosition(pos, lineStart, curLine),
              radix
            });
            return true;
          },
          numericSeparatorInEscapeSequence: this.errorBuilder(Errors.NumericSeparatorInEscapeSequence),
          unexpectedNumericSeparator: this.errorBuilder(Errors.UnexpectedNumericSeparator)
        };
        this.errorHandlers_readCodePoint = Object.assign({}, this.errorHandlers_readInt, {
          invalidEscapeSequence: this.errorBuilder(Errors.InvalidEscapeSequence),
          invalidCodePoint: this.errorBuilder(Errors.InvalidCodePoint)
        });
        this.errorHandlers_readStringContents_string = Object.assign({}, this.errorHandlers_readCodePoint, {
          strictNumericEscape: (pos, lineStart, curLine) => {
            this.recordStrictModeErrors(Errors.StrictNumericEscape, {
              at: buildPosition(pos, lineStart, curLine)
            });
          },
          unterminated: (pos, lineStart, curLine) => {
            throw this.raise(Errors.UnterminatedString, {
              at: buildPosition(pos - 1, lineStart, curLine)
            });
          }
        });
        this.errorHandlers_readStringContents_template = Object.assign({}, this.errorHandlers_readCodePoint, {
          strictNumericEscape: this.errorBuilder(Errors.StrictNumericEscape),
          unterminated: (pos, lineStart, curLine) => {
            throw this.raise(Errors.UnterminatedTemplate, {
              at: buildPosition(pos, lineStart, curLine)
            });
          }
        });
        this.state = new State();
        this.state.init(options);
        this.input = input;
        this.length = input.length;
        this.isLookahead = false;
      }
      pushToken(token) {
        this.tokens.length = this.state.tokensLength;
        this.tokens.push(token);
        ++this.state.tokensLength;
      }
      next() {
        this.checkKeywordEscapes();
        if (this.options.tokens) {
          this.pushToken(new Token(this.state));
        }
        this.state.lastTokStart = this.state.start;
        this.state.lastTokEndLoc = this.state.endLoc;
        this.state.lastTokStartLoc = this.state.startLoc;
        this.nextToken();
      }
      eat(type) {
        if (this.match(type)) {
          this.next();
          return true;
        } else {
          return false;
        }
      }
      match(type) {
        return this.state.type === type;
      }
      createLookaheadState(state) {
        return {
          pos: state.pos,
          value: null,
          type: state.type,
          start: state.start,
          end: state.end,
          context: [this.curContext()],
          inType: state.inType,
          startLoc: state.startLoc,
          lastTokEndLoc: state.lastTokEndLoc,
          curLine: state.curLine,
          lineStart: state.lineStart,
          curPosition: state.curPosition
        };
      }
      lookahead() {
        const old = this.state;
        this.state = this.createLookaheadState(old);
        this.isLookahead = true;
        this.nextToken();
        this.isLookahead = false;
        const curr = this.state;
        this.state = old;
        return curr;
      }
      nextTokenStart() {
        return this.nextTokenStartSince(this.state.pos);
      }
      nextTokenStartSince(pos) {
        skipWhiteSpace.lastIndex = pos;
        return skipWhiteSpace.test(this.input) ? skipWhiteSpace.lastIndex : pos;
      }
      lookaheadCharCode() {
        return this.input.charCodeAt(this.nextTokenStart());
      }
      codePointAtPos(pos) {
        let cp = this.input.charCodeAt(pos);
        if ((cp & 64512) === 55296 && ++pos < this.input.length) {
          const trail = this.input.charCodeAt(pos);
          if ((trail & 64512) === 56320) {
            cp = 65536 + ((cp & 1023) << 10) + (trail & 1023);
          }
        }
        return cp;
      }
      setStrict(strict) {
        this.state.strict = strict;
        if (strict) {
          this.state.strictErrors.forEach(([toParseError, at]) => this.raise(toParseError, {
            at
          }));
          this.state.strictErrors.clear();
        }
      }
      curContext() {
        return this.state.context[this.state.context.length - 1];
      }
      nextToken() {
        this.skipSpace();
        this.state.start = this.state.pos;
        if (!this.isLookahead)
          this.state.startLoc = this.state.curPosition();
        if (this.state.pos >= this.length) {
          this.finishToken(137);
          return;
        }
        this.getTokenFromCode(this.codePointAtPos(this.state.pos));
      }
      skipBlockComment(commentEnd) {
        let startLoc;
        if (!this.isLookahead)
          startLoc = this.state.curPosition();
        const start = this.state.pos;
        const end = this.input.indexOf(commentEnd, start + 2);
        if (end === -1) {
          throw this.raise(Errors.UnterminatedComment, {
            at: this.state.curPosition()
          });
        }
        this.state.pos = end + commentEnd.length;
        lineBreakG.lastIndex = start + 2;
        while (lineBreakG.test(this.input) && lineBreakG.lastIndex <= end) {
          ++this.state.curLine;
          this.state.lineStart = lineBreakG.lastIndex;
        }
        if (this.isLookahead)
          return;
        const comment = {
          type: "CommentBlock",
          value: this.input.slice(start + 2, end),
          start,
          end: end + commentEnd.length,
          loc: new SourceLocation(startLoc, this.state.curPosition())
        };
        if (this.options.tokens)
          this.pushToken(comment);
        return comment;
      }
      skipLineComment(startSkip) {
        const start = this.state.pos;
        let startLoc;
        if (!this.isLookahead)
          startLoc = this.state.curPosition();
        let ch = this.input.charCodeAt(this.state.pos += startSkip);
        if (this.state.pos < this.length) {
          while (!isNewLine(ch) && ++this.state.pos < this.length) {
            ch = this.input.charCodeAt(this.state.pos);
          }
        }
        if (this.isLookahead)
          return;
        const end = this.state.pos;
        const value2 = this.input.slice(start + startSkip, end);
        const comment = {
          type: "CommentLine",
          value: value2,
          start,
          end,
          loc: new SourceLocation(startLoc, this.state.curPosition())
        };
        if (this.options.tokens)
          this.pushToken(comment);
        return comment;
      }
      skipSpace() {
        const spaceStart = this.state.pos;
        const comments = [];
        loop:
          while (this.state.pos < this.length) {
            const ch = this.input.charCodeAt(this.state.pos);
            switch (ch) {
              case 32:
              case 160:
              case 9:
                ++this.state.pos;
                break;
              case 13:
                if (this.input.charCodeAt(this.state.pos + 1) === 10) {
                  ++this.state.pos;
                }
              case 10:
              case 8232:
              case 8233:
                ++this.state.pos;
                ++this.state.curLine;
                this.state.lineStart = this.state.pos;
                break;
              case 47:
                switch (this.input.charCodeAt(this.state.pos + 1)) {
                  case 42: {
                    const comment = this.skipBlockComment("*/");
                    if (comment !== void 0) {
                      this.addComment(comment);
                      if (this.options.attachComment)
                        comments.push(comment);
                    }
                    break;
                  }
                  case 47: {
                    const comment = this.skipLineComment(2);
                    if (comment !== void 0) {
                      this.addComment(comment);
                      if (this.options.attachComment)
                        comments.push(comment);
                    }
                    break;
                  }
                  default:
                    break loop;
                }
                break;
              default:
                if (isWhitespace(ch)) {
                  ++this.state.pos;
                } else if (ch === 45 && !this.inModule) {
                  const pos = this.state.pos;
                  if (this.input.charCodeAt(pos + 1) === 45 && this.input.charCodeAt(pos + 2) === 62 && (spaceStart === 0 || this.state.lineStart > spaceStart)) {
                    const comment = this.skipLineComment(3);
                    if (comment !== void 0) {
                      this.addComment(comment);
                      if (this.options.attachComment)
                        comments.push(comment);
                    }
                  } else {
                    break loop;
                  }
                } else if (ch === 60 && !this.inModule) {
                  const pos = this.state.pos;
                  if (this.input.charCodeAt(pos + 1) === 33 && this.input.charCodeAt(pos + 2) === 45 && this.input.charCodeAt(pos + 3) === 45) {
                    const comment = this.skipLineComment(4);
                    if (comment !== void 0) {
                      this.addComment(comment);
                      if (this.options.attachComment)
                        comments.push(comment);
                    }
                  } else {
                    break loop;
                  }
                } else {
                  break loop;
                }
            }
          }
        if (comments.length > 0) {
          const end = this.state.pos;
          const commentWhitespace = {
            start: spaceStart,
            end,
            comments,
            leadingNode: null,
            trailingNode: null,
            containingNode: null
          };
          this.state.commentStack.push(commentWhitespace);
        }
      }
      finishToken(type, val) {
        this.state.end = this.state.pos;
        this.state.endLoc = this.state.curPosition();
        const prevType = this.state.type;
        this.state.type = type;
        this.state.value = val;
        if (!this.isLookahead) {
          this.updateContext(prevType);
        }
      }
      replaceToken(type) {
        this.state.type = type;
        this.updateContext();
      }
      readToken_numberSign() {
        if (this.state.pos === 0 && this.readToken_interpreter()) {
          return;
        }
        const nextPos = this.state.pos + 1;
        const next = this.codePointAtPos(nextPos);
        if (next >= 48 && next <= 57) {
          throw this.raise(Errors.UnexpectedDigitAfterHash, {
            at: this.state.curPosition()
          });
        }
        if (next === 123 || next === 91 && this.hasPlugin("recordAndTuple")) {
          this.expectPlugin("recordAndTuple");
          if (this.getPluginOption("recordAndTuple", "syntaxType") === "bar") {
            throw this.raise(next === 123 ? Errors.RecordExpressionHashIncorrectStartSyntaxType : Errors.TupleExpressionHashIncorrectStartSyntaxType, {
              at: this.state.curPosition()
            });
          }
          this.state.pos += 2;
          if (next === 123) {
            this.finishToken(7);
          } else {
            this.finishToken(1);
          }
        } else if (isIdentifierStart(next)) {
          ++this.state.pos;
          this.finishToken(136, this.readWord1(next));
        } else if (next === 92) {
          ++this.state.pos;
          this.finishToken(136, this.readWord1());
        } else {
          this.finishOp(27, 1);
        }
      }
      readToken_dot() {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next >= 48 && next <= 57) {
          this.readNumber(true);
          return;
        }
        if (next === 46 && this.input.charCodeAt(this.state.pos + 2) === 46) {
          this.state.pos += 3;
          this.finishToken(21);
        } else {
          ++this.state.pos;
          this.finishToken(16);
        }
      }
      readToken_slash() {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === 61) {
          this.finishOp(31, 2);
        } else {
          this.finishOp(56, 1);
        }
      }
      readToken_interpreter() {
        if (this.state.pos !== 0 || this.length < 2)
          return false;
        let ch = this.input.charCodeAt(this.state.pos + 1);
        if (ch !== 33)
          return false;
        const start = this.state.pos;
        this.state.pos += 1;
        while (!isNewLine(ch) && ++this.state.pos < this.length) {
          ch = this.input.charCodeAt(this.state.pos);
        }
        const value2 = this.input.slice(start + 2, this.state.pos);
        this.finishToken(28, value2);
        return true;
      }
      readToken_mult_modulo(code) {
        let type = code === 42 ? 55 : 54;
        let width = 1;
        let next = this.input.charCodeAt(this.state.pos + 1);
        if (code === 42 && next === 42) {
          width++;
          next = this.input.charCodeAt(this.state.pos + 2);
          type = 57;
        }
        if (next === 61 && !this.state.inType) {
          width++;
          type = code === 37 ? 33 : 30;
        }
        this.finishOp(type, width);
      }
      readToken_pipe_amp(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === code) {
          if (this.input.charCodeAt(this.state.pos + 2) === 61) {
            this.finishOp(30, 3);
          } else {
            this.finishOp(code === 124 ? 41 : 42, 2);
          }
          return;
        }
        if (code === 124) {
          if (next === 62) {
            this.finishOp(39, 2);
            return;
          }
          if (this.hasPlugin("recordAndTuple") && next === 125) {
            if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar") {
              throw this.raise(Errors.RecordExpressionBarIncorrectEndSyntaxType, {
                at: this.state.curPosition()
              });
            }
            this.state.pos += 2;
            this.finishToken(9);
            return;
          }
          if (this.hasPlugin("recordAndTuple") && next === 93) {
            if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar") {
              throw this.raise(Errors.TupleExpressionBarIncorrectEndSyntaxType, {
                at: this.state.curPosition()
              });
            }
            this.state.pos += 2;
            this.finishToken(4);
            return;
          }
        }
        if (next === 61) {
          this.finishOp(30, 2);
          return;
        }
        this.finishOp(code === 124 ? 43 : 45, 1);
      }
      readToken_caret() {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === 61 && !this.state.inType) {
          this.finishOp(32, 2);
        } else if (next === 94 && this.hasPlugin(["pipelineOperator", {
          proposal: "hack",
          topicToken: "^^"
        }])) {
          this.finishOp(37, 2);
          const lookaheadCh = this.input.codePointAt(this.state.pos);
          if (lookaheadCh === 94) {
            throw this.unexpected();
          }
        } else {
          this.finishOp(44, 1);
        }
      }
      readToken_atSign() {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === 64 && this.hasPlugin(["pipelineOperator", {
          proposal: "hack",
          topicToken: "@@"
        }])) {
          this.finishOp(38, 2);
        } else {
          this.finishOp(26, 1);
        }
      }
      readToken_plus_min(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === code) {
          this.finishOp(34, 2);
          return;
        }
        if (next === 61) {
          this.finishOp(30, 2);
        } else {
          this.finishOp(53, 1);
        }
      }
      readToken_lt() {
        const {
          pos
        } = this.state;
        const next = this.input.charCodeAt(pos + 1);
        if (next === 60) {
          if (this.input.charCodeAt(pos + 2) === 61) {
            this.finishOp(30, 3);
            return;
          }
          this.finishOp(51, 2);
          return;
        }
        if (next === 61) {
          this.finishOp(49, 2);
          return;
        }
        this.finishOp(47, 1);
      }
      readToken_gt() {
        const {
          pos
        } = this.state;
        const next = this.input.charCodeAt(pos + 1);
        if (next === 62) {
          const size = this.input.charCodeAt(pos + 2) === 62 ? 3 : 2;
          if (this.input.charCodeAt(pos + size) === 61) {
            this.finishOp(30, size + 1);
            return;
          }
          this.finishOp(52, size);
          return;
        }
        if (next === 61) {
          this.finishOp(49, 2);
          return;
        }
        this.finishOp(48, 1);
      }
      readToken_eq_excl(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (next === 61) {
          this.finishOp(46, this.input.charCodeAt(this.state.pos + 2) === 61 ? 3 : 2);
          return;
        }
        if (code === 61 && next === 62) {
          this.state.pos += 2;
          this.finishToken(19);
          return;
        }
        this.finishOp(code === 61 ? 29 : 35, 1);
      }
      readToken_question() {
        const next = this.input.charCodeAt(this.state.pos + 1);
        const next2 = this.input.charCodeAt(this.state.pos + 2);
        if (next === 63) {
          if (next2 === 61) {
            this.finishOp(30, 3);
          } else {
            this.finishOp(40, 2);
          }
        } else if (next === 46 && !(next2 >= 48 && next2 <= 57)) {
          this.state.pos += 2;
          this.finishToken(18);
        } else {
          ++this.state.pos;
          this.finishToken(17);
        }
      }
      getTokenFromCode(code) {
        switch (code) {
          case 46:
            this.readToken_dot();
            return;
          case 40:
            ++this.state.pos;
            this.finishToken(10);
            return;
          case 41:
            ++this.state.pos;
            this.finishToken(11);
            return;
          case 59:
            ++this.state.pos;
            this.finishToken(13);
            return;
          case 44:
            ++this.state.pos;
            this.finishToken(12);
            return;
          case 91:
            if (this.hasPlugin("recordAndTuple") && this.input.charCodeAt(this.state.pos + 1) === 124) {
              if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar") {
                throw this.raise(Errors.TupleExpressionBarIncorrectStartSyntaxType, {
                  at: this.state.curPosition()
                });
              }
              this.state.pos += 2;
              this.finishToken(2);
            } else {
              ++this.state.pos;
              this.finishToken(0);
            }
            return;
          case 93:
            ++this.state.pos;
            this.finishToken(3);
            return;
          case 123:
            if (this.hasPlugin("recordAndTuple") && this.input.charCodeAt(this.state.pos + 1) === 124) {
              if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar") {
                throw this.raise(Errors.RecordExpressionBarIncorrectStartSyntaxType, {
                  at: this.state.curPosition()
                });
              }
              this.state.pos += 2;
              this.finishToken(6);
            } else {
              ++this.state.pos;
              this.finishToken(5);
            }
            return;
          case 125:
            ++this.state.pos;
            this.finishToken(8);
            return;
          case 58:
            if (this.hasPlugin("functionBind") && this.input.charCodeAt(this.state.pos + 1) === 58) {
              this.finishOp(15, 2);
            } else {
              ++this.state.pos;
              this.finishToken(14);
            }
            return;
          case 63:
            this.readToken_question();
            return;
          case 96:
            this.readTemplateToken();
            return;
          case 48: {
            const next = this.input.charCodeAt(this.state.pos + 1);
            if (next === 120 || next === 88) {
              this.readRadixNumber(16);
              return;
            }
            if (next === 111 || next === 79) {
              this.readRadixNumber(8);
              return;
            }
            if (next === 98 || next === 66) {
              this.readRadixNumber(2);
              return;
            }
          }
          case 49:
          case 50:
          case 51:
          case 52:
          case 53:
          case 54:
          case 55:
          case 56:
          case 57:
            this.readNumber(false);
            return;
          case 34:
          case 39:
            this.readString(code);
            return;
          case 47:
            this.readToken_slash();
            return;
          case 37:
          case 42:
            this.readToken_mult_modulo(code);
            return;
          case 124:
          case 38:
            this.readToken_pipe_amp(code);
            return;
          case 94:
            this.readToken_caret();
            return;
          case 43:
          case 45:
            this.readToken_plus_min(code);
            return;
          case 60:
            this.readToken_lt();
            return;
          case 62:
            this.readToken_gt();
            return;
          case 61:
          case 33:
            this.readToken_eq_excl(code);
            return;
          case 126:
            this.finishOp(36, 1);
            return;
          case 64:
            this.readToken_atSign();
            return;
          case 35:
            this.readToken_numberSign();
            return;
          case 92:
            this.readWord();
            return;
          default:
            if (isIdentifierStart(code)) {
              this.readWord(code);
              return;
            }
        }
        throw this.raise(Errors.InvalidOrUnexpectedToken, {
          at: this.state.curPosition(),
          unexpected: String.fromCodePoint(code)
        });
      }
      finishOp(type, size) {
        const str = this.input.slice(this.state.pos, this.state.pos + size);
        this.state.pos += size;
        this.finishToken(type, str);
      }
      readRegexp() {
        const startLoc = this.state.startLoc;
        const start = this.state.start + 1;
        let escaped, inClass;
        let {
          pos
        } = this.state;
        for (; ; ++pos) {
          if (pos >= this.length) {
            throw this.raise(Errors.UnterminatedRegExp, {
              at: createPositionWithColumnOffset(startLoc, 1)
            });
          }
          const ch = this.input.charCodeAt(pos);
          if (isNewLine(ch)) {
            throw this.raise(Errors.UnterminatedRegExp, {
              at: createPositionWithColumnOffset(startLoc, 1)
            });
          }
          if (escaped) {
            escaped = false;
          } else {
            if (ch === 91) {
              inClass = true;
            } else if (ch === 93 && inClass) {
              inClass = false;
            } else if (ch === 47 && !inClass) {
              break;
            }
            escaped = ch === 92;
          }
        }
        const content = this.input.slice(start, pos);
        ++pos;
        let mods = "";
        const nextPos = () => createPositionWithColumnOffset(startLoc, pos + 2 - start);
        while (pos < this.length) {
          const cp = this.codePointAtPos(pos);
          const char = String.fromCharCode(cp);
          if (VALID_REGEX_FLAGS.has(cp)) {
            if (cp === 118) {
              this.expectPlugin("regexpUnicodeSets", nextPos());
              if (mods.includes("u")) {
                this.raise(Errors.IncompatibleRegExpUVFlags, {
                  at: nextPos()
                });
              }
            } else if (cp === 117) {
              if (mods.includes("v")) {
                this.raise(Errors.IncompatibleRegExpUVFlags, {
                  at: nextPos()
                });
              }
            }
            if (mods.includes(char)) {
              this.raise(Errors.DuplicateRegExpFlags, {
                at: nextPos()
              });
            }
          } else if (isIdentifierChar(cp) || cp === 92) {
            this.raise(Errors.MalformedRegExpFlags, {
              at: nextPos()
            });
          } else {
            break;
          }
          ++pos;
          mods += char;
        }
        this.state.pos = pos;
        this.finishToken(135, {
          pattern: content,
          flags: mods
        });
      }
      readInt(radix, len, forceLen = false, allowNumSeparator = true) {
        const {
          n,
          pos
        } = readInt(this.input, this.state.pos, this.state.lineStart, this.state.curLine, radix, len, forceLen, allowNumSeparator, this.errorHandlers_readInt, false);
        this.state.pos = pos;
        return n;
      }
      readRadixNumber(radix) {
        const startLoc = this.state.curPosition();
        let isBigInt = false;
        this.state.pos += 2;
        const val = this.readInt(radix);
        if (val == null) {
          this.raise(Errors.InvalidDigit, {
            at: createPositionWithColumnOffset(startLoc, 2),
            radix
          });
        }
        const next = this.input.charCodeAt(this.state.pos);
        if (next === 110) {
          ++this.state.pos;
          isBigInt = true;
        } else if (next === 109) {
          throw this.raise(Errors.InvalidDecimal, {
            at: startLoc
          });
        }
        if (isIdentifierStart(this.codePointAtPos(this.state.pos))) {
          throw this.raise(Errors.NumberIdentifier, {
            at: this.state.curPosition()
          });
        }
        if (isBigInt) {
          const str = this.input.slice(startLoc.index, this.state.pos).replace(/[_n]/g, "");
          this.finishToken(133, str);
          return;
        }
        this.finishToken(132, val);
      }
      readNumber(startsWithDot) {
        const start = this.state.pos;
        const startLoc = this.state.curPosition();
        let isFloat = false;
        let isBigInt = false;
        let isDecimal = false;
        let hasExponent = false;
        let isOctal = false;
        if (!startsWithDot && this.readInt(10) === null) {
          this.raise(Errors.InvalidNumber, {
            at: this.state.curPosition()
          });
        }
        const hasLeadingZero = this.state.pos - start >= 2 && this.input.charCodeAt(start) === 48;
        if (hasLeadingZero) {
          const integer = this.input.slice(start, this.state.pos);
          this.recordStrictModeErrors(Errors.StrictOctalLiteral, {
            at: startLoc
          });
          if (!this.state.strict) {
            const underscorePos = integer.indexOf("_");
            if (underscorePos > 0) {
              this.raise(Errors.ZeroDigitNumericSeparator, {
                at: createPositionWithColumnOffset(startLoc, underscorePos)
              });
            }
          }
          isOctal = hasLeadingZero && !/[89]/.test(integer);
        }
        let next = this.input.charCodeAt(this.state.pos);
        if (next === 46 && !isOctal) {
          ++this.state.pos;
          this.readInt(10);
          isFloat = true;
          next = this.input.charCodeAt(this.state.pos);
        }
        if ((next === 69 || next === 101) && !isOctal) {
          next = this.input.charCodeAt(++this.state.pos);
          if (next === 43 || next === 45) {
            ++this.state.pos;
          }
          if (this.readInt(10) === null) {
            this.raise(Errors.InvalidOrMissingExponent, {
              at: startLoc
            });
          }
          isFloat = true;
          hasExponent = true;
          next = this.input.charCodeAt(this.state.pos);
        }
        if (next === 110) {
          if (isFloat || hasLeadingZero) {
            this.raise(Errors.InvalidBigIntLiteral, {
              at: startLoc
            });
          }
          ++this.state.pos;
          isBigInt = true;
        }
        if (next === 109) {
          this.expectPlugin("decimal", this.state.curPosition());
          if (hasExponent || hasLeadingZero) {
            this.raise(Errors.InvalidDecimal, {
              at: startLoc
            });
          }
          ++this.state.pos;
          isDecimal = true;
        }
        if (isIdentifierStart(this.codePointAtPos(this.state.pos))) {
          throw this.raise(Errors.NumberIdentifier, {
            at: this.state.curPosition()
          });
        }
        const str = this.input.slice(start, this.state.pos).replace(/[_mn]/g, "");
        if (isBigInt) {
          this.finishToken(133, str);
          return;
        }
        if (isDecimal) {
          this.finishToken(134, str);
          return;
        }
        const val = isOctal ? parseInt(str, 8) : parseFloat(str);
        this.finishToken(132, val);
      }
      readCodePoint(throwOnInvalid) {
        const {
          code,
          pos
        } = readCodePoint(this.input, this.state.pos, this.state.lineStart, this.state.curLine, throwOnInvalid, this.errorHandlers_readCodePoint);
        this.state.pos = pos;
        return code;
      }
      readString(quote) {
        const {
          str,
          pos,
          curLine,
          lineStart
        } = readStringContents(
          quote === 34 ? "double" : "single",
          this.input,
          this.state.pos + 1,
          this.state.lineStart,
          this.state.curLine,
          this.errorHandlers_readStringContents_string
        );
        this.state.pos = pos + 1;
        this.state.lineStart = lineStart;
        this.state.curLine = curLine;
        this.finishToken(131, str);
      }
      readTemplateContinuation() {
        if (!this.match(8)) {
          this.unexpected(null, 8);
        }
        this.state.pos--;
        this.readTemplateToken();
      }
      readTemplateToken() {
        const opening = this.input[this.state.pos];
        const {
          str,
          firstInvalidLoc,
          pos,
          curLine,
          lineStart
        } = readStringContents(
          "template",
          this.input,
          this.state.pos + 1,
          this.state.lineStart,
          this.state.curLine,
          this.errorHandlers_readStringContents_template
        );
        this.state.pos = pos + 1;
        this.state.lineStart = lineStart;
        this.state.curLine = curLine;
        if (firstInvalidLoc) {
          this.state.firstInvalidTemplateEscapePos = new Position(firstInvalidLoc.curLine, firstInvalidLoc.pos - firstInvalidLoc.lineStart, firstInvalidLoc.pos);
        }
        if (this.input.codePointAt(pos) === 96) {
          this.finishToken(24, firstInvalidLoc ? null : opening + str + "`");
        } else {
          this.state.pos++;
          this.finishToken(25, firstInvalidLoc ? null : opening + str + "${");
        }
      }
      recordStrictModeErrors(toParseError, {
        at
      }) {
        const index = at.index;
        if (this.state.strict && !this.state.strictErrors.has(index)) {
          this.raise(toParseError, {
            at
          });
        } else {
          this.state.strictErrors.set(index, [toParseError, at]);
        }
      }
      readWord1(firstCode) {
        this.state.containsEsc = false;
        let word = "";
        const start = this.state.pos;
        let chunkStart = this.state.pos;
        if (firstCode !== void 0) {
          this.state.pos += firstCode <= 65535 ? 1 : 2;
        }
        while (this.state.pos < this.length) {
          const ch = this.codePointAtPos(this.state.pos);
          if (isIdentifierChar(ch)) {
            this.state.pos += ch <= 65535 ? 1 : 2;
          } else if (ch === 92) {
            this.state.containsEsc = true;
            word += this.input.slice(chunkStart, this.state.pos);
            const escStart = this.state.curPosition();
            const identifierCheck = this.state.pos === start ? isIdentifierStart : isIdentifierChar;
            if (this.input.charCodeAt(++this.state.pos) !== 117) {
              this.raise(Errors.MissingUnicodeEscape, {
                at: this.state.curPosition()
              });
              chunkStart = this.state.pos - 1;
              continue;
            }
            ++this.state.pos;
            const esc = this.readCodePoint(true);
            if (esc !== null) {
              if (!identifierCheck(esc)) {
                this.raise(Errors.EscapedCharNotAnIdentifier, {
                  at: escStart
                });
              }
              word += String.fromCodePoint(esc);
            }
            chunkStart = this.state.pos;
          } else {
            break;
          }
        }
        return word + this.input.slice(chunkStart, this.state.pos);
      }
      readWord(firstCode) {
        const word = this.readWord1(firstCode);
        const type = keywords$1.get(word);
        if (type !== void 0) {
          this.finishToken(type, tokenLabelName(type));
        } else {
          this.finishToken(130, word);
        }
      }
      checkKeywordEscapes() {
        const {
          type
        } = this.state;
        if (tokenIsKeyword(type) && this.state.containsEsc) {
          this.raise(Errors.InvalidEscapedReservedWord, {
            at: this.state.startLoc,
            reservedWord: tokenLabelName(type)
          });
        }
      }
      raise(toParseError, raiseProperties) {
        const {
          at
        } = raiseProperties, details = _objectWithoutPropertiesLoose(raiseProperties, _excluded);
        const loc = at instanceof Position ? at : at.loc.start;
        const error = toParseError({
          loc,
          details
        });
        if (!this.options.errorRecovery)
          throw error;
        if (!this.isLookahead)
          this.state.errors.push(error);
        return error;
      }
      raiseOverwrite(toParseError, raiseProperties) {
        const {
          at
        } = raiseProperties, details = _objectWithoutPropertiesLoose(raiseProperties, _excluded2);
        const loc = at instanceof Position ? at : at.loc.start;
        const pos = loc.index;
        const errors = this.state.errors;
        for (let i = errors.length - 1; i >= 0; i--) {
          const error = errors[i];
          if (error.loc.index === pos) {
            return errors[i] = toParseError({
              loc,
              details
            });
          }
          if (error.loc.index < pos)
            break;
        }
        return this.raise(toParseError, raiseProperties);
      }
      updateContext(prevType) {
      }
      unexpected(loc, type) {
        throw this.raise(Errors.UnexpectedToken, {
          expected: type ? tokenLabelName(type) : null,
          at: loc != null ? loc : this.state.startLoc
        });
      }
      expectPlugin(pluginName, loc) {
        if (this.hasPlugin(pluginName)) {
          return true;
        }
        throw this.raise(Errors.MissingPlugin, {
          at: loc != null ? loc : this.state.startLoc,
          missingPlugin: [pluginName]
        });
      }
      expectOnePlugin(pluginNames) {
        if (!pluginNames.some((name) => this.hasPlugin(name))) {
          throw this.raise(Errors.MissingOneOfPlugins, {
            at: this.state.startLoc,
            missingPlugin: pluginNames
          });
        }
      }
      errorBuilder(error) {
        return (pos, lineStart, curLine) => {
          this.raise(error, {
            at: buildPosition(pos, lineStart, curLine)
          });
        };
      }
    };
    var ClassScope = class {
      constructor() {
        this.privateNames = /* @__PURE__ */ new Set();
        this.loneAccessors = /* @__PURE__ */ new Map();
        this.undefinedPrivateNames = /* @__PURE__ */ new Map();
      }
    };
    var ClassScopeHandler = class {
      constructor(parser) {
        this.parser = void 0;
        this.stack = [];
        this.undefinedPrivateNames = /* @__PURE__ */ new Map();
        this.parser = parser;
      }
      current() {
        return this.stack[this.stack.length - 1];
      }
      enter() {
        this.stack.push(new ClassScope());
      }
      exit() {
        const oldClassScope = this.stack.pop();
        const current = this.current();
        for (const [name, loc] of Array.from(oldClassScope.undefinedPrivateNames)) {
          if (current) {
            if (!current.undefinedPrivateNames.has(name)) {
              current.undefinedPrivateNames.set(name, loc);
            }
          } else {
            this.parser.raise(Errors.InvalidPrivateFieldResolution, {
              at: loc,
              identifierName: name
            });
          }
        }
      }
      declarePrivateName(name, elementType, loc) {
        const {
          privateNames,
          loneAccessors,
          undefinedPrivateNames
        } = this.current();
        let redefined = privateNames.has(name);
        if (elementType & CLASS_ELEMENT_KIND_ACCESSOR) {
          const accessor = redefined && loneAccessors.get(name);
          if (accessor) {
            const oldStatic = accessor & CLASS_ELEMENT_FLAG_STATIC;
            const newStatic = elementType & CLASS_ELEMENT_FLAG_STATIC;
            const oldKind = accessor & CLASS_ELEMENT_KIND_ACCESSOR;
            const newKind = elementType & CLASS_ELEMENT_KIND_ACCESSOR;
            redefined = oldKind === newKind || oldStatic !== newStatic;
            if (!redefined)
              loneAccessors.delete(name);
          } else if (!redefined) {
            loneAccessors.set(name, elementType);
          }
        }
        if (redefined) {
          this.parser.raise(Errors.PrivateNameRedeclaration, {
            at: loc,
            identifierName: name
          });
        }
        privateNames.add(name);
        undefinedPrivateNames.delete(name);
      }
      usePrivateName(name, loc) {
        let classScope;
        for (classScope of this.stack) {
          if (classScope.privateNames.has(name))
            return;
        }
        if (classScope) {
          classScope.undefinedPrivateNames.set(name, loc);
        } else {
          this.parser.raise(Errors.InvalidPrivateFieldResolution, {
            at: loc,
            identifierName: name
          });
        }
      }
    };
    var kExpression = 0;
    var kMaybeArrowParameterDeclaration = 1;
    var kMaybeAsyncArrowParameterDeclaration = 2;
    var kParameterDeclaration = 3;
    var ExpressionScope = class {
      constructor(type = kExpression) {
        this.type = void 0;
        this.type = type;
      }
      canBeArrowParameterDeclaration() {
        return this.type === kMaybeAsyncArrowParameterDeclaration || this.type === kMaybeArrowParameterDeclaration;
      }
      isCertainlyParameterDeclaration() {
        return this.type === kParameterDeclaration;
      }
    };
    var ArrowHeadParsingScope = class extends ExpressionScope {
      constructor(type) {
        super(type);
        this.declarationErrors = /* @__PURE__ */ new Map();
      }
      recordDeclarationError(ParsingErrorClass, {
        at
      }) {
        const index = at.index;
        this.declarationErrors.set(index, [ParsingErrorClass, at]);
      }
      clearDeclarationError(index) {
        this.declarationErrors.delete(index);
      }
      iterateErrors(iterator) {
        this.declarationErrors.forEach(iterator);
      }
    };
    var ExpressionScopeHandler = class {
      constructor(parser) {
        this.parser = void 0;
        this.stack = [new ExpressionScope()];
        this.parser = parser;
      }
      enter(scope) {
        this.stack.push(scope);
      }
      exit() {
        this.stack.pop();
      }
      recordParameterInitializerError(toParseError, {
        at: node
      }) {
        const origin = {
          at: node.loc.start
        };
        const {
          stack
        } = this;
        let i = stack.length - 1;
        let scope = stack[i];
        while (!scope.isCertainlyParameterDeclaration()) {
          if (scope.canBeArrowParameterDeclaration()) {
            scope.recordDeclarationError(toParseError, origin);
          } else {
            return;
          }
          scope = stack[--i];
        }
        this.parser.raise(toParseError, origin);
      }
      recordArrowParameterBindingError(error, {
        at: node
      }) {
        const {
          stack
        } = this;
        const scope = stack[stack.length - 1];
        const origin = {
          at: node.loc.start
        };
        if (scope.isCertainlyParameterDeclaration()) {
          this.parser.raise(error, origin);
        } else if (scope.canBeArrowParameterDeclaration()) {
          scope.recordDeclarationError(error, origin);
        } else {
          return;
        }
      }
      recordAsyncArrowParametersError({
        at
      }) {
        const {
          stack
        } = this;
        let i = stack.length - 1;
        let scope = stack[i];
        while (scope.canBeArrowParameterDeclaration()) {
          if (scope.type === kMaybeAsyncArrowParameterDeclaration) {
            scope.recordDeclarationError(Errors.AwaitBindingIdentifier, {
              at
            });
          }
          scope = stack[--i];
        }
      }
      validateAsPattern() {
        const {
          stack
        } = this;
        const currentScope = stack[stack.length - 1];
        if (!currentScope.canBeArrowParameterDeclaration())
          return;
        currentScope.iterateErrors(([toParseError, loc]) => {
          this.parser.raise(toParseError, {
            at: loc
          });
          let i = stack.length - 2;
          let scope = stack[i];
          while (scope.canBeArrowParameterDeclaration()) {
            scope.clearDeclarationError(loc.index);
            scope = stack[--i];
          }
        });
      }
    };
    function newParameterDeclarationScope() {
      return new ExpressionScope(kParameterDeclaration);
    }
    function newArrowHeadScope() {
      return new ArrowHeadParsingScope(kMaybeArrowParameterDeclaration);
    }
    function newAsyncArrowScope() {
      return new ArrowHeadParsingScope(kMaybeAsyncArrowParameterDeclaration);
    }
    function newExpressionScope() {
      return new ExpressionScope();
    }
    var PARAM = 0;
    var PARAM_YIELD = 1;
    var PARAM_AWAIT = 2;
    var PARAM_RETURN = 4;
    var PARAM_IN = 8;
    var ProductionParameterHandler = class {
      constructor() {
        this.stacks = [];
      }
      enter(flags) {
        this.stacks.push(flags);
      }
      exit() {
        this.stacks.pop();
      }
      currentFlags() {
        return this.stacks[this.stacks.length - 1];
      }
      get hasAwait() {
        return (this.currentFlags() & PARAM_AWAIT) > 0;
      }
      get hasYield() {
        return (this.currentFlags() & PARAM_YIELD) > 0;
      }
      get hasReturn() {
        return (this.currentFlags() & PARAM_RETURN) > 0;
      }
      get hasIn() {
        return (this.currentFlags() & PARAM_IN) > 0;
      }
    };
    function functionFlags(isAsync, isGenerator) {
      return (isAsync ? PARAM_AWAIT : 0) | (isGenerator ? PARAM_YIELD : 0);
    }
    var UtilParser = class extends Tokenizer {
      addExtra(node, key, value2, enumerable = true) {
        if (!node)
          return;
        const extra = node.extra = node.extra || {};
        if (enumerable) {
          extra[key] = value2;
        } else {
          Object.defineProperty(extra, key, {
            enumerable,
            value: value2
          });
        }
      }
      isContextual(token) {
        return this.state.type === token && !this.state.containsEsc;
      }
      isUnparsedContextual(nameStart, name) {
        const nameEnd = nameStart + name.length;
        if (this.input.slice(nameStart, nameEnd) === name) {
          const nextCh = this.input.charCodeAt(nameEnd);
          return !(isIdentifierChar(nextCh) || (nextCh & 64512) === 55296);
        }
        return false;
      }
      isLookaheadContextual(name) {
        const next = this.nextTokenStart();
        return this.isUnparsedContextual(next, name);
      }
      eatContextual(token) {
        if (this.isContextual(token)) {
          this.next();
          return true;
        }
        return false;
      }
      expectContextual(token, toParseError) {
        if (!this.eatContextual(token)) {
          if (toParseError != null) {
            throw this.raise(toParseError, {
              at: this.state.startLoc
            });
          }
          throw this.unexpected(null, token);
        }
      }
      canInsertSemicolon() {
        return this.match(137) || this.match(8) || this.hasPrecedingLineBreak();
      }
      hasPrecedingLineBreak() {
        return lineBreak.test(this.input.slice(this.state.lastTokEndLoc.index, this.state.start));
      }
      hasFollowingLineBreak() {
        skipWhiteSpaceToLineBreak.lastIndex = this.state.end;
        return skipWhiteSpaceToLineBreak.test(this.input);
      }
      isLineTerminator() {
        return this.eat(13) || this.canInsertSemicolon();
      }
      semicolon(allowAsi = true) {
        if (allowAsi ? this.isLineTerminator() : this.eat(13))
          return;
        this.raise(Errors.MissingSemicolon, {
          at: this.state.lastTokEndLoc
        });
      }
      expect(type, loc) {
        this.eat(type) || this.unexpected(loc, type);
      }
      tryParse(fn, oldState = this.state.clone()) {
        const abortSignal = {
          node: null
        };
        try {
          const node = fn((node2 = null) => {
            abortSignal.node = node2;
            throw abortSignal;
          });
          if (this.state.errors.length > oldState.errors.length) {
            const failState = this.state;
            this.state = oldState;
            this.state.tokensLength = failState.tokensLength;
            return {
              node,
              error: failState.errors[oldState.errors.length],
              thrown: false,
              aborted: false,
              failState
            };
          }
          return {
            node,
            error: null,
            thrown: false,
            aborted: false,
            failState: null
          };
        } catch (error) {
          const failState = this.state;
          this.state = oldState;
          if (error instanceof SyntaxError) {
            return {
              node: null,
              error,
              thrown: true,
              aborted: false,
              failState
            };
          }
          if (error === abortSignal) {
            return {
              node: abortSignal.node,
              error: null,
              thrown: false,
              aborted: true,
              failState
            };
          }
          throw error;
        }
      }
      checkExpressionErrors(refExpressionErrors, andThrow) {
        if (!refExpressionErrors)
          return false;
        const {
          shorthandAssignLoc,
          doubleProtoLoc,
          privateKeyLoc,
          optionalParametersLoc
        } = refExpressionErrors;
        const hasErrors = !!shorthandAssignLoc || !!doubleProtoLoc || !!optionalParametersLoc || !!privateKeyLoc;
        if (!andThrow) {
          return hasErrors;
        }
        if (shorthandAssignLoc != null) {
          this.raise(Errors.InvalidCoverInitializedName, {
            at: shorthandAssignLoc
          });
        }
        if (doubleProtoLoc != null) {
          this.raise(Errors.DuplicateProto, {
            at: doubleProtoLoc
          });
        }
        if (privateKeyLoc != null) {
          this.raise(Errors.UnexpectedPrivateField, {
            at: privateKeyLoc
          });
        }
        if (optionalParametersLoc != null) {
          this.unexpected(optionalParametersLoc);
        }
      }
      isLiteralPropertyName() {
        return tokenIsLiteralPropertyName(this.state.type);
      }
      isPrivateName(node) {
        return node.type === "PrivateName";
      }
      getPrivateNameSV(node) {
        return node.id.name;
      }
      hasPropertyAsPrivateName(node) {
        return (node.type === "MemberExpression" || node.type === "OptionalMemberExpression") && this.isPrivateName(node.property);
      }
      isOptionalChain(node) {
        return node.type === "OptionalMemberExpression" || node.type === "OptionalCallExpression";
      }
      isObjectProperty(node) {
        return node.type === "ObjectProperty";
      }
      isObjectMethod(node) {
        return node.type === "ObjectMethod";
      }
      initializeScopes(inModule = this.options.sourceType === "module") {
        const oldLabels = this.state.labels;
        this.state.labels = [];
        const oldExportedIdentifiers = this.exportedIdentifiers;
        this.exportedIdentifiers = /* @__PURE__ */ new Set();
        const oldInModule = this.inModule;
        this.inModule = inModule;
        const oldScope = this.scope;
        const ScopeHandler2 = this.getScopeHandler();
        this.scope = new ScopeHandler2(this, inModule);
        const oldProdParam = this.prodParam;
        this.prodParam = new ProductionParameterHandler();
        const oldClassScope = this.classScope;
        this.classScope = new ClassScopeHandler(this);
        const oldExpressionScope = this.expressionScope;
        this.expressionScope = new ExpressionScopeHandler(this);
        return () => {
          this.state.labels = oldLabels;
          this.exportedIdentifiers = oldExportedIdentifiers;
          this.inModule = oldInModule;
          this.scope = oldScope;
          this.prodParam = oldProdParam;
          this.classScope = oldClassScope;
          this.expressionScope = oldExpressionScope;
        };
      }
      enterInitialScopes() {
        let paramFlags = PARAM;
        if (this.inModule) {
          paramFlags |= PARAM_AWAIT;
        }
        this.scope.enter(SCOPE_PROGRAM);
        this.prodParam.enter(paramFlags);
      }
      checkDestructuringPrivate(refExpressionErrors) {
        const {
          privateKeyLoc
        } = refExpressionErrors;
        if (privateKeyLoc !== null) {
          this.expectPlugin("destructuringPrivate", privateKeyLoc);
        }
      }
    };
    var ExpressionErrors = class {
      constructor() {
        this.shorthandAssignLoc = null;
        this.doubleProtoLoc = null;
        this.privateKeyLoc = null;
        this.optionalParametersLoc = null;
      }
    };
    var Node2 = class {
      constructor(parser, pos, loc) {
        this.type = "";
        this.start = pos;
        this.end = 0;
        this.loc = new SourceLocation(loc);
        if (parser != null && parser.options.ranges)
          this.range = [pos, 0];
        if (parser != null && parser.filename)
          this.loc.filename = parser.filename;
      }
    };
    var NodePrototype = Node2.prototype;
    {
      NodePrototype.__clone = function() {
        const newNode = new Node2(void 0, this.start, this.loc.start);
        const keys3 = Object.keys(this);
        for (let i = 0, length = keys3.length; i < length; i++) {
          const key = keys3[i];
          if (key !== "leadingComments" && key !== "trailingComments" && key !== "innerComments") {
            newNode[key] = this[key];
          }
        }
        return newNode;
      };
    }
    function clonePlaceholder(node) {
      return cloneIdentifier(node);
    }
    function cloneIdentifier(node) {
      const {
        type,
        start,
        end,
        loc,
        range,
        extra,
        name
      } = node;
      const cloned = Object.create(NodePrototype);
      cloned.type = type;
      cloned.start = start;
      cloned.end = end;
      cloned.loc = loc;
      cloned.range = range;
      cloned.extra = extra;
      cloned.name = name;
      if (type === "Placeholder") {
        cloned.expectedNode = node.expectedNode;
      }
      return cloned;
    }
    function cloneStringLiteral(node) {
      const {
        type,
        start,
        end,
        loc,
        range,
        extra
      } = node;
      if (type === "Placeholder") {
        return clonePlaceholder(node);
      }
      const cloned = Object.create(NodePrototype);
      cloned.type = type;
      cloned.start = start;
      cloned.end = end;
      cloned.loc = loc;
      cloned.range = range;
      if (node.raw !== void 0) {
        cloned.raw = node.raw;
      } else {
        cloned.extra = extra;
      }
      cloned.value = node.value;
      return cloned;
    }
    var NodeUtils = class extends UtilParser {
      startNode() {
        return new Node2(this, this.state.start, this.state.startLoc);
      }
      startNodeAt(loc) {
        return new Node2(this, loc.index, loc);
      }
      startNodeAtNode(type) {
        return this.startNodeAt(type.loc.start);
      }
      finishNode(node, type) {
        return this.finishNodeAt(node, type, this.state.lastTokEndLoc);
      }
      finishNodeAt(node, type, endLoc) {
        node.type = type;
        node.end = endLoc.index;
        node.loc.end = endLoc;
        if (this.options.ranges)
          node.range[1] = endLoc.index;
        if (this.options.attachComment)
          this.processComment(node);
        return node;
      }
      resetStartLocation(node, startLoc) {
        node.start = startLoc.index;
        node.loc.start = startLoc;
        if (this.options.ranges)
          node.range[0] = startLoc.index;
      }
      resetEndLocation(node, endLoc = this.state.lastTokEndLoc) {
        node.end = endLoc.index;
        node.loc.end = endLoc;
        if (this.options.ranges)
          node.range[1] = endLoc.index;
      }
      resetStartLocationFromNode(node, locationNode) {
        this.resetStartLocation(node, locationNode.loc.start);
      }
    };
    var reservedTypes = /* @__PURE__ */ new Set(["_", "any", "bool", "boolean", "empty", "extends", "false", "interface", "mixed", "null", "number", "static", "string", "true", "typeof", "void"]);
    var FlowErrors = ParseErrorEnum`flow`({
      AmbiguousConditionalArrow: "Ambiguous expression: wrap the arrow functions in parentheses to disambiguate.",
      AmbiguousDeclareModuleKind: "Found both `declare module.exports` and `declare export` in the same module. Modules can only have 1 since they are either an ES module or they are a CommonJS module.",
      AssignReservedType: ({
        reservedType
      }) => `Cannot overwrite reserved type ${reservedType}.`,
      DeclareClassElement: "The `declare` modifier can only appear on class fields.",
      DeclareClassFieldInitializer: "Initializers are not allowed in fields with the `declare` modifier.",
      DuplicateDeclareModuleExports: "Duplicate `declare module.exports` statement.",
      EnumBooleanMemberNotInitialized: ({
        memberName,
        enumName
      }) => `Boolean enum members need to be initialized. Use either \`${memberName} = true,\` or \`${memberName} = false,\` in enum \`${enumName}\`.`,
      EnumDuplicateMemberName: ({
        memberName,
        enumName
      }) => `Enum member names need to be unique, but the name \`${memberName}\` has already been used before in enum \`${enumName}\`.`,
      EnumInconsistentMemberValues: ({
        enumName
      }) => `Enum \`${enumName}\` has inconsistent member initializers. Either use no initializers, or consistently use literals (either booleans, numbers, or strings) for all member initializers.`,
      EnumInvalidExplicitType: ({
        invalidEnumType,
        enumName
      }) => `Enum type \`${invalidEnumType}\` is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${enumName}\`.`,
      EnumInvalidExplicitTypeUnknownSupplied: ({
        enumName
      }) => `Supplied enum type is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${enumName}\`.`,
      EnumInvalidMemberInitializerPrimaryType: ({
        enumName,
        memberName,
        explicitType
      }) => `Enum \`${enumName}\` has type \`${explicitType}\`, so the initializer of \`${memberName}\` needs to be a ${explicitType} literal.`,
      EnumInvalidMemberInitializerSymbolType: ({
        enumName,
        memberName
      }) => `Symbol enum members cannot be initialized. Use \`${memberName},\` in enum \`${enumName}\`.`,
      EnumInvalidMemberInitializerUnknownType: ({
        enumName,
        memberName
      }) => `The enum member initializer for \`${memberName}\` needs to be a literal (either a boolean, number, or string) in enum \`${enumName}\`.`,
      EnumInvalidMemberName: ({
        enumName,
        memberName,
        suggestion
      }) => `Enum member names cannot start with lowercase 'a' through 'z'. Instead of using \`${memberName}\`, consider using \`${suggestion}\`, in enum \`${enumName}\`.`,
      EnumNumberMemberNotInitialized: ({
        enumName,
        memberName
      }) => `Number enum members need to be initialized, e.g. \`${memberName} = 1\` in enum \`${enumName}\`.`,
      EnumStringMemberInconsistentlyInitailized: ({
        enumName
      }) => `String enum members need to consistently either all use initializers, or use no initializers, in enum \`${enumName}\`.`,
      GetterMayNotHaveThisParam: "A getter cannot have a `this` parameter.",
      ImportReflectionHasImportType: "An `import module` declaration can not use `type` or `typeof` keyword.",
      ImportTypeShorthandOnlyInPureImport: "The `type` and `typeof` keywords on named imports can only be used on regular `import` statements. It cannot be used with `import type` or `import typeof` statements.",
      InexactInsideExact: "Explicit inexact syntax cannot appear inside an explicit exact object type.",
      InexactInsideNonObject: "Explicit inexact syntax cannot appear in class or interface definitions.",
      InexactVariance: "Explicit inexact syntax cannot have variance.",
      InvalidNonTypeImportInDeclareModule: "Imports within a `declare module` body must always be `import type` or `import typeof`.",
      MissingTypeParamDefault: "Type parameter declaration needs a default, since a preceding type parameter declaration has a default.",
      NestedDeclareModule: "`declare module` cannot be used inside another `declare module`.",
      NestedFlowComment: "Cannot have a flow comment inside another flow comment.",
      PatternIsOptional: Object.assign({
        message: "A binding pattern parameter cannot be optional in an implementation signature."
      }, {
        reasonCode: "OptionalBindingPattern"
      }),
      SetterMayNotHaveThisParam: "A setter cannot have a `this` parameter.",
      SpreadVariance: "Spread properties cannot have variance.",
      ThisParamAnnotationRequired: "A type annotation is required for the `this` parameter.",
      ThisParamBannedInConstructor: "Constructors cannot have a `this` parameter; constructors don't bind `this` like other functions.",
      ThisParamMayNotBeOptional: "The `this` parameter cannot be optional.",
      ThisParamMustBeFirst: "The `this` parameter must be the first function parameter.",
      ThisParamNoDefault: "The `this` parameter may not have a default value.",
      TypeBeforeInitializer: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.",
      TypeCastInPattern: "The type cast expression is expected to be wrapped with parenthesis.",
      UnexpectedExplicitInexactInObject: "Explicit inexact syntax must appear at the end of an inexact object.",
      UnexpectedReservedType: ({
        reservedType
      }) => `Unexpected reserved type ${reservedType}.`,
      UnexpectedReservedUnderscore: "`_` is only allowed as a type argument to call or new.",
      UnexpectedSpaceBetweenModuloChecks: "Spaces between `%` and `checks` are not allowed here.",
      UnexpectedSpreadType: "Spread operator cannot appear in class or interface definitions.",
      UnexpectedSubtractionOperand: 'Unexpected token, expected "number" or "bigint".',
      UnexpectedTokenAfterTypeParameter: "Expected an arrow function after this type parameter declaration.",
      UnexpectedTypeParameterBeforeAsyncArrowFunction: "Type parameters must come after the async keyword, e.g. instead of `<T> async () => {}`, use `async <T>() => {}`.",
      UnsupportedDeclareExportKind: ({
        unsupportedExportKind,
        suggestion
      }) => `\`declare export ${unsupportedExportKind}\` is not supported. Use \`${suggestion}\` instead.`,
      UnsupportedStatementInDeclareModule: "Only declares and type imports are allowed inside declare module.",
      UnterminatedFlowComment: "Unterminated flow-comment."
    });
    function isEsModuleType(bodyElement) {
      return bodyElement.type === "DeclareExportAllDeclaration" || bodyElement.type === "DeclareExportDeclaration" && (!bodyElement.declaration || bodyElement.declaration.type !== "TypeAlias" && bodyElement.declaration.type !== "InterfaceDeclaration");
    }
    function hasTypeImportKind(node) {
      return node.importKind === "type" || node.importKind === "typeof";
    }
    function isMaybeDefaultImport(type) {
      return tokenIsKeywordOrIdentifier(type) && type !== 97;
    }
    var exportSuggestions = {
      const: "declare export var",
      let: "declare export var",
      type: "export type",
      interface: "export interface"
    };
    function partition(list, test) {
      const list1 = [];
      const list2 = [];
      for (let i = 0; i < list.length; i++) {
        (test(list[i], i, list) ? list1 : list2).push(list[i]);
      }
      return [list1, list2];
    }
    var FLOW_PRAGMA_REGEX = /\*?\s*@((?:no)?flow)\b/;
    var flow = (superClass) => class FlowParserMixin extends superClass {
      constructor(...args) {
        super(...args);
        this.flowPragma = void 0;
      }
      getScopeHandler() {
        return FlowScopeHandler;
      }
      shouldParseTypes() {
        return this.getPluginOption("flow", "all") || this.flowPragma === "flow";
      }
      shouldParseEnums() {
        return !!this.getPluginOption("flow", "enums");
      }
      finishToken(type, val) {
        if (type !== 131 && type !== 13 && type !== 28) {
          if (this.flowPragma === void 0) {
            this.flowPragma = null;
          }
        }
        return super.finishToken(type, val);
      }
      addComment(comment) {
        if (this.flowPragma === void 0) {
          const matches = FLOW_PRAGMA_REGEX.exec(comment.value);
          if (!matches)
            ;
          else if (matches[1] === "flow") {
            this.flowPragma = "flow";
          } else if (matches[1] === "noflow") {
            this.flowPragma = "noflow";
          } else {
            throw new Error("Unexpected flow pragma");
          }
        }
        return super.addComment(comment);
      }
      flowParseTypeInitialiser(tok) {
        const oldInType = this.state.inType;
        this.state.inType = true;
        this.expect(tok || 14);
        const type = this.flowParseType();
        this.state.inType = oldInType;
        return type;
      }
      flowParsePredicate() {
        const node = this.startNode();
        const moduloLoc = this.state.startLoc;
        this.next();
        this.expectContextual(108);
        if (this.state.lastTokStart > moduloLoc.index + 1) {
          this.raise(FlowErrors.UnexpectedSpaceBetweenModuloChecks, {
            at: moduloLoc
          });
        }
        if (this.eat(10)) {
          node.value = super.parseExpression();
          this.expect(11);
          return this.finishNode(node, "DeclaredPredicate");
        } else {
          return this.finishNode(node, "InferredPredicate");
        }
      }
      flowParseTypeAndPredicateInitialiser() {
        const oldInType = this.state.inType;
        this.state.inType = true;
        this.expect(14);
        let type = null;
        let predicate = null;
        if (this.match(54)) {
          this.state.inType = oldInType;
          predicate = this.flowParsePredicate();
        } else {
          type = this.flowParseType();
          this.state.inType = oldInType;
          if (this.match(54)) {
            predicate = this.flowParsePredicate();
          }
        }
        return [type, predicate];
      }
      flowParseDeclareClass(node) {
        this.next();
        this.flowParseInterfaceish(node, true);
        return this.finishNode(node, "DeclareClass");
      }
      flowParseDeclareFunction(node) {
        this.next();
        const id = node.id = this.parseIdentifier();
        const typeNode = this.startNode();
        const typeContainer = this.startNode();
        if (this.match(47)) {
          typeNode.typeParameters = this.flowParseTypeParameterDeclaration();
        } else {
          typeNode.typeParameters = null;
        }
        this.expect(10);
        const tmp = this.flowParseFunctionTypeParams();
        typeNode.params = tmp.params;
        typeNode.rest = tmp.rest;
        typeNode.this = tmp._this;
        this.expect(11);
        [typeNode.returnType, node.predicate] = this.flowParseTypeAndPredicateInitialiser();
        typeContainer.typeAnnotation = this.finishNode(typeNode, "FunctionTypeAnnotation");
        id.typeAnnotation = this.finishNode(typeContainer, "TypeAnnotation");
        this.resetEndLocation(id);
        this.semicolon();
        this.scope.declareName(node.id.name, BIND_FLOW_DECLARE_FN, node.id.loc.start);
        return this.finishNode(node, "DeclareFunction");
      }
      flowParseDeclare(node, insideModule) {
        if (this.match(80)) {
          return this.flowParseDeclareClass(node);
        } else if (this.match(68)) {
          return this.flowParseDeclareFunction(node);
        } else if (this.match(74)) {
          return this.flowParseDeclareVariable(node);
        } else if (this.eatContextual(125)) {
          if (this.match(16)) {
            return this.flowParseDeclareModuleExports(node);
          } else {
            if (insideModule) {
              this.raise(FlowErrors.NestedDeclareModule, {
                at: this.state.lastTokStartLoc
              });
            }
            return this.flowParseDeclareModule(node);
          }
        } else if (this.isContextual(128)) {
          return this.flowParseDeclareTypeAlias(node);
        } else if (this.isContextual(129)) {
          return this.flowParseDeclareOpaqueType(node);
        } else if (this.isContextual(127)) {
          return this.flowParseDeclareInterface(node);
        } else if (this.match(82)) {
          return this.flowParseDeclareExportDeclaration(node, insideModule);
        } else {
          throw this.unexpected();
        }
      }
      flowParseDeclareVariable(node) {
        this.next();
        node.id = this.flowParseTypeAnnotatableIdentifier(true);
        this.scope.declareName(node.id.name, BIND_VAR, node.id.loc.start);
        this.semicolon();
        return this.finishNode(node, "DeclareVariable");
      }
      flowParseDeclareModule(node) {
        this.scope.enter(SCOPE_OTHER);
        if (this.match(131)) {
          node.id = super.parseExprAtom();
        } else {
          node.id = this.parseIdentifier();
        }
        const bodyNode = node.body = this.startNode();
        const body = bodyNode.body = [];
        this.expect(5);
        while (!this.match(8)) {
          let bodyNode2 = this.startNode();
          if (this.match(83)) {
            this.next();
            if (!this.isContextual(128) && !this.match(87)) {
              this.raise(FlowErrors.InvalidNonTypeImportInDeclareModule, {
                at: this.state.lastTokStartLoc
              });
            }
            super.parseImport(bodyNode2);
          } else {
            this.expectContextual(123, FlowErrors.UnsupportedStatementInDeclareModule);
            bodyNode2 = this.flowParseDeclare(bodyNode2, true);
          }
          body.push(bodyNode2);
        }
        this.scope.exit();
        this.expect(8);
        this.finishNode(bodyNode, "BlockStatement");
        let kind = null;
        let hasModuleExport = false;
        body.forEach((bodyElement) => {
          if (isEsModuleType(bodyElement)) {
            if (kind === "CommonJS") {
              this.raise(FlowErrors.AmbiguousDeclareModuleKind, {
                at: bodyElement
              });
            }
            kind = "ES";
          } else if (bodyElement.type === "DeclareModuleExports") {
            if (hasModuleExport) {
              this.raise(FlowErrors.DuplicateDeclareModuleExports, {
                at: bodyElement
              });
            }
            if (kind === "ES") {
              this.raise(FlowErrors.AmbiguousDeclareModuleKind, {
                at: bodyElement
              });
            }
            kind = "CommonJS";
            hasModuleExport = true;
          }
        });
        node.kind = kind || "CommonJS";
        return this.finishNode(node, "DeclareModule");
      }
      flowParseDeclareExportDeclaration(node, insideModule) {
        this.expect(82);
        if (this.eat(65)) {
          if (this.match(68) || this.match(80)) {
            node.declaration = this.flowParseDeclare(this.startNode());
          } else {
            node.declaration = this.flowParseType();
            this.semicolon();
          }
          node.default = true;
          return this.finishNode(node, "DeclareExportDeclaration");
        } else {
          if (this.match(75) || this.isLet() || (this.isContextual(128) || this.isContextual(127)) && !insideModule) {
            const label = this.state.value;
            throw this.raise(FlowErrors.UnsupportedDeclareExportKind, {
              at: this.state.startLoc,
              unsupportedExportKind: label,
              suggestion: exportSuggestions[label]
            });
          }
          if (this.match(74) || this.match(68) || this.match(80) || this.isContextual(129)) {
            node.declaration = this.flowParseDeclare(this.startNode());
            node.default = false;
            return this.finishNode(node, "DeclareExportDeclaration");
          } else if (this.match(55) || this.match(5) || this.isContextual(127) || this.isContextual(128) || this.isContextual(129)) {
            node = this.parseExport(node, null);
            if (node.type === "ExportNamedDeclaration") {
              node.type = "ExportDeclaration";
              node.default = false;
              delete node.exportKind;
            }
            node.type = "Declare" + node.type;
            return node;
          }
        }
        throw this.unexpected();
      }
      flowParseDeclareModuleExports(node) {
        this.next();
        this.expectContextual(109);
        node.typeAnnotation = this.flowParseTypeAnnotation();
        this.semicolon();
        return this.finishNode(node, "DeclareModuleExports");
      }
      flowParseDeclareTypeAlias(node) {
        this.next();
        const finished = this.flowParseTypeAlias(node);
        finished.type = "DeclareTypeAlias";
        return finished;
      }
      flowParseDeclareOpaqueType(node) {
        this.next();
        const finished = this.flowParseOpaqueType(node, true);
        finished.type = "DeclareOpaqueType";
        return finished;
      }
      flowParseDeclareInterface(node) {
        this.next();
        this.flowParseInterfaceish(node);
        return this.finishNode(node, "DeclareInterface");
      }
      flowParseInterfaceish(node, isClass = false) {
        node.id = this.flowParseRestrictedIdentifier(!isClass, true);
        this.scope.declareName(node.id.name, isClass ? BIND_FUNCTION : BIND_LEXICAL, node.id.loc.start);
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        } else {
          node.typeParameters = null;
        }
        node.extends = [];
        node.implements = [];
        node.mixins = [];
        if (this.eat(81)) {
          do {
            node.extends.push(this.flowParseInterfaceExtends());
          } while (!isClass && this.eat(12));
        }
        if (this.isContextual(115)) {
          this.next();
          do {
            node.mixins.push(this.flowParseInterfaceExtends());
          } while (this.eat(12));
        }
        if (this.isContextual(111)) {
          this.next();
          do {
            node.implements.push(this.flowParseInterfaceExtends());
          } while (this.eat(12));
        }
        node.body = this.flowParseObjectType({
          allowStatic: isClass,
          allowExact: false,
          allowSpread: false,
          allowProto: isClass,
          allowInexact: false
        });
      }
      flowParseInterfaceExtends() {
        const node = this.startNode();
        node.id = this.flowParseQualifiedTypeIdentifier();
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterInstantiation();
        } else {
          node.typeParameters = null;
        }
        return this.finishNode(node, "InterfaceExtends");
      }
      flowParseInterface(node) {
        this.flowParseInterfaceish(node);
        return this.finishNode(node, "InterfaceDeclaration");
      }
      checkNotUnderscore(word) {
        if (word === "_") {
          this.raise(FlowErrors.UnexpectedReservedUnderscore, {
            at: this.state.startLoc
          });
        }
      }
      checkReservedType(word, startLoc, declaration) {
        if (!reservedTypes.has(word))
          return;
        this.raise(declaration ? FlowErrors.AssignReservedType : FlowErrors.UnexpectedReservedType, {
          at: startLoc,
          reservedType: word
        });
      }
      flowParseRestrictedIdentifier(liberal, declaration) {
        this.checkReservedType(this.state.value, this.state.startLoc, declaration);
        return this.parseIdentifier(liberal);
      }
      flowParseTypeAlias(node) {
        node.id = this.flowParseRestrictedIdentifier(false, true);
        this.scope.declareName(node.id.name, BIND_LEXICAL, node.id.loc.start);
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        } else {
          node.typeParameters = null;
        }
        node.right = this.flowParseTypeInitialiser(29);
        this.semicolon();
        return this.finishNode(node, "TypeAlias");
      }
      flowParseOpaqueType(node, declare) {
        this.expectContextual(128);
        node.id = this.flowParseRestrictedIdentifier(true, true);
        this.scope.declareName(node.id.name, BIND_LEXICAL, node.id.loc.start);
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        } else {
          node.typeParameters = null;
        }
        node.supertype = null;
        if (this.match(14)) {
          node.supertype = this.flowParseTypeInitialiser(14);
        }
        node.impltype = null;
        if (!declare) {
          node.impltype = this.flowParseTypeInitialiser(29);
        }
        this.semicolon();
        return this.finishNode(node, "OpaqueType");
      }
      flowParseTypeParameter(requireDefault = false) {
        const nodeStartLoc = this.state.startLoc;
        const node = this.startNode();
        const variance = this.flowParseVariance();
        const ident = this.flowParseTypeAnnotatableIdentifier();
        node.name = ident.name;
        node.variance = variance;
        node.bound = ident.typeAnnotation;
        if (this.match(29)) {
          this.eat(29);
          node.default = this.flowParseType();
        } else {
          if (requireDefault) {
            this.raise(FlowErrors.MissingTypeParamDefault, {
              at: nodeStartLoc
            });
          }
        }
        return this.finishNode(node, "TypeParameter");
      }
      flowParseTypeParameterDeclaration() {
        const oldInType = this.state.inType;
        const node = this.startNode();
        node.params = [];
        this.state.inType = true;
        if (this.match(47) || this.match(140)) {
          this.next();
        } else {
          this.unexpected();
        }
        let defaultRequired = false;
        do {
          const typeParameter = this.flowParseTypeParameter(defaultRequired);
          node.params.push(typeParameter);
          if (typeParameter.default) {
            defaultRequired = true;
          }
          if (!this.match(48)) {
            this.expect(12);
          }
        } while (!this.match(48));
        this.expect(48);
        this.state.inType = oldInType;
        return this.finishNode(node, "TypeParameterDeclaration");
      }
      flowParseTypeParameterInstantiation() {
        const node = this.startNode();
        const oldInType = this.state.inType;
        node.params = [];
        this.state.inType = true;
        this.expect(47);
        const oldNoAnonFunctionType = this.state.noAnonFunctionType;
        this.state.noAnonFunctionType = false;
        while (!this.match(48)) {
          node.params.push(this.flowParseType());
          if (!this.match(48)) {
            this.expect(12);
          }
        }
        this.state.noAnonFunctionType = oldNoAnonFunctionType;
        this.expect(48);
        this.state.inType = oldInType;
        return this.finishNode(node, "TypeParameterInstantiation");
      }
      flowParseTypeParameterInstantiationCallOrNew() {
        const node = this.startNode();
        const oldInType = this.state.inType;
        node.params = [];
        this.state.inType = true;
        this.expect(47);
        while (!this.match(48)) {
          node.params.push(this.flowParseTypeOrImplicitInstantiation());
          if (!this.match(48)) {
            this.expect(12);
          }
        }
        this.expect(48);
        this.state.inType = oldInType;
        return this.finishNode(node, "TypeParameterInstantiation");
      }
      flowParseInterfaceType() {
        const node = this.startNode();
        this.expectContextual(127);
        node.extends = [];
        if (this.eat(81)) {
          do {
            node.extends.push(this.flowParseInterfaceExtends());
          } while (this.eat(12));
        }
        node.body = this.flowParseObjectType({
          allowStatic: false,
          allowExact: false,
          allowSpread: false,
          allowProto: false,
          allowInexact: false
        });
        return this.finishNode(node, "InterfaceTypeAnnotation");
      }
      flowParseObjectPropertyKey() {
        return this.match(132) || this.match(131) ? super.parseExprAtom() : this.parseIdentifier(true);
      }
      flowParseObjectTypeIndexer(node, isStatic, variance) {
        node.static = isStatic;
        if (this.lookahead().type === 14) {
          node.id = this.flowParseObjectPropertyKey();
          node.key = this.flowParseTypeInitialiser();
        } else {
          node.id = null;
          node.key = this.flowParseType();
        }
        this.expect(3);
        node.value = this.flowParseTypeInitialiser();
        node.variance = variance;
        return this.finishNode(node, "ObjectTypeIndexer");
      }
      flowParseObjectTypeInternalSlot(node, isStatic) {
        node.static = isStatic;
        node.id = this.flowParseObjectPropertyKey();
        this.expect(3);
        this.expect(3);
        if (this.match(47) || this.match(10)) {
          node.method = true;
          node.optional = false;
          node.value = this.flowParseObjectTypeMethodish(this.startNodeAt(node.loc.start));
        } else {
          node.method = false;
          if (this.eat(17)) {
            node.optional = true;
          }
          node.value = this.flowParseTypeInitialiser();
        }
        return this.finishNode(node, "ObjectTypeInternalSlot");
      }
      flowParseObjectTypeMethodish(node) {
        node.params = [];
        node.rest = null;
        node.typeParameters = null;
        node.this = null;
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        }
        this.expect(10);
        if (this.match(78)) {
          node.this = this.flowParseFunctionTypeParam(true);
          node.this.name = null;
          if (!this.match(11)) {
            this.expect(12);
          }
        }
        while (!this.match(11) && !this.match(21)) {
          node.params.push(this.flowParseFunctionTypeParam(false));
          if (!this.match(11)) {
            this.expect(12);
          }
        }
        if (this.eat(21)) {
          node.rest = this.flowParseFunctionTypeParam(false);
        }
        this.expect(11);
        node.returnType = this.flowParseTypeInitialiser();
        return this.finishNode(node, "FunctionTypeAnnotation");
      }
      flowParseObjectTypeCallProperty(node, isStatic) {
        const valueNode = this.startNode();
        node.static = isStatic;
        node.value = this.flowParseObjectTypeMethodish(valueNode);
        return this.finishNode(node, "ObjectTypeCallProperty");
      }
      flowParseObjectType({
        allowStatic,
        allowExact,
        allowSpread,
        allowProto,
        allowInexact
      }) {
        const oldInType = this.state.inType;
        this.state.inType = true;
        const nodeStart = this.startNode();
        nodeStart.callProperties = [];
        nodeStart.properties = [];
        nodeStart.indexers = [];
        nodeStart.internalSlots = [];
        let endDelim;
        let exact;
        let inexact = false;
        if (allowExact && this.match(6)) {
          this.expect(6);
          endDelim = 9;
          exact = true;
        } else {
          this.expect(5);
          endDelim = 8;
          exact = false;
        }
        nodeStart.exact = exact;
        while (!this.match(endDelim)) {
          let isStatic = false;
          let protoStartLoc = null;
          let inexactStartLoc = null;
          const node = this.startNode();
          if (allowProto && this.isContextual(116)) {
            const lookahead = this.lookahead();
            if (lookahead.type !== 14 && lookahead.type !== 17) {
              this.next();
              protoStartLoc = this.state.startLoc;
              allowStatic = false;
            }
          }
          if (allowStatic && this.isContextual(104)) {
            const lookahead = this.lookahead();
            if (lookahead.type !== 14 && lookahead.type !== 17) {
              this.next();
              isStatic = true;
            }
          }
          const variance = this.flowParseVariance();
          if (this.eat(0)) {
            if (protoStartLoc != null) {
              this.unexpected(protoStartLoc);
            }
            if (this.eat(0)) {
              if (variance) {
                this.unexpected(variance.loc.start);
              }
              nodeStart.internalSlots.push(this.flowParseObjectTypeInternalSlot(node, isStatic));
            } else {
              nodeStart.indexers.push(this.flowParseObjectTypeIndexer(node, isStatic, variance));
            }
          } else if (this.match(10) || this.match(47)) {
            if (protoStartLoc != null) {
              this.unexpected(protoStartLoc);
            }
            if (variance) {
              this.unexpected(variance.loc.start);
            }
            nodeStart.callProperties.push(this.flowParseObjectTypeCallProperty(node, isStatic));
          } else {
            let kind = "init";
            if (this.isContextual(98) || this.isContextual(103)) {
              const lookahead = this.lookahead();
              if (tokenIsLiteralPropertyName(lookahead.type)) {
                kind = this.state.value;
                this.next();
              }
            }
            const propOrInexact = this.flowParseObjectTypeProperty(node, isStatic, protoStartLoc, variance, kind, allowSpread, allowInexact != null ? allowInexact : !exact);
            if (propOrInexact === null) {
              inexact = true;
              inexactStartLoc = this.state.lastTokStartLoc;
            } else {
              nodeStart.properties.push(propOrInexact);
            }
          }
          this.flowObjectTypeSemicolon();
          if (inexactStartLoc && !this.match(8) && !this.match(9)) {
            this.raise(FlowErrors.UnexpectedExplicitInexactInObject, {
              at: inexactStartLoc
            });
          }
        }
        this.expect(endDelim);
        if (allowSpread) {
          nodeStart.inexact = inexact;
        }
        const out = this.finishNode(nodeStart, "ObjectTypeAnnotation");
        this.state.inType = oldInType;
        return out;
      }
      flowParseObjectTypeProperty(node, isStatic, protoStartLoc, variance, kind, allowSpread, allowInexact) {
        if (this.eat(21)) {
          const isInexactToken = this.match(12) || this.match(13) || this.match(8) || this.match(9);
          if (isInexactToken) {
            if (!allowSpread) {
              this.raise(FlowErrors.InexactInsideNonObject, {
                at: this.state.lastTokStartLoc
              });
            } else if (!allowInexact) {
              this.raise(FlowErrors.InexactInsideExact, {
                at: this.state.lastTokStartLoc
              });
            }
            if (variance) {
              this.raise(FlowErrors.InexactVariance, {
                at: variance
              });
            }
            return null;
          }
          if (!allowSpread) {
            this.raise(FlowErrors.UnexpectedSpreadType, {
              at: this.state.lastTokStartLoc
            });
          }
          if (protoStartLoc != null) {
            this.unexpected(protoStartLoc);
          }
          if (variance) {
            this.raise(FlowErrors.SpreadVariance, {
              at: variance
            });
          }
          node.argument = this.flowParseType();
          return this.finishNode(node, "ObjectTypeSpreadProperty");
        } else {
          node.key = this.flowParseObjectPropertyKey();
          node.static = isStatic;
          node.proto = protoStartLoc != null;
          node.kind = kind;
          let optional = false;
          if (this.match(47) || this.match(10)) {
            node.method = true;
            if (protoStartLoc != null) {
              this.unexpected(protoStartLoc);
            }
            if (variance) {
              this.unexpected(variance.loc.start);
            }
            node.value = this.flowParseObjectTypeMethodish(this.startNodeAt(node.loc.start));
            if (kind === "get" || kind === "set") {
              this.flowCheckGetterSetterParams(node);
            }
            if (!allowSpread && node.key.name === "constructor" && node.value.this) {
              this.raise(FlowErrors.ThisParamBannedInConstructor, {
                at: node.value.this
              });
            }
          } else {
            if (kind !== "init")
              this.unexpected();
            node.method = false;
            if (this.eat(17)) {
              optional = true;
            }
            node.value = this.flowParseTypeInitialiser();
            node.variance = variance;
          }
          node.optional = optional;
          return this.finishNode(node, "ObjectTypeProperty");
        }
      }
      flowCheckGetterSetterParams(property) {
        const paramCount = property.kind === "get" ? 0 : 1;
        const length = property.value.params.length + (property.value.rest ? 1 : 0);
        if (property.value.this) {
          this.raise(property.kind === "get" ? FlowErrors.GetterMayNotHaveThisParam : FlowErrors.SetterMayNotHaveThisParam, {
            at: property.value.this
          });
        }
        if (length !== paramCount) {
          this.raise(property.kind === "get" ? Errors.BadGetterArity : Errors.BadSetterArity, {
            at: property
          });
        }
        if (property.kind === "set" && property.value.rest) {
          this.raise(Errors.BadSetterRestParameter, {
            at: property
          });
        }
      }
      flowObjectTypeSemicolon() {
        if (!this.eat(13) && !this.eat(12) && !this.match(8) && !this.match(9)) {
          this.unexpected();
        }
      }
      flowParseQualifiedTypeIdentifier(startLoc, id) {
        var _startLoc;
        (_startLoc = startLoc) != null ? _startLoc : startLoc = this.state.startLoc;
        let node = id || this.flowParseRestrictedIdentifier(true);
        while (this.eat(16)) {
          const node2 = this.startNodeAt(startLoc);
          node2.qualification = node;
          node2.id = this.flowParseRestrictedIdentifier(true);
          node = this.finishNode(node2, "QualifiedTypeIdentifier");
        }
        return node;
      }
      flowParseGenericType(startLoc, id) {
        const node = this.startNodeAt(startLoc);
        node.typeParameters = null;
        node.id = this.flowParseQualifiedTypeIdentifier(startLoc, id);
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterInstantiation();
        }
        return this.finishNode(node, "GenericTypeAnnotation");
      }
      flowParseTypeofType() {
        const node = this.startNode();
        this.expect(87);
        node.argument = this.flowParsePrimaryType();
        return this.finishNode(node, "TypeofTypeAnnotation");
      }
      flowParseTupleType() {
        const node = this.startNode();
        node.types = [];
        this.expect(0);
        while (this.state.pos < this.length && !this.match(3)) {
          node.types.push(this.flowParseType());
          if (this.match(3))
            break;
          this.expect(12);
        }
        this.expect(3);
        return this.finishNode(node, "TupleTypeAnnotation");
      }
      flowParseFunctionTypeParam(first2) {
        let name = null;
        let optional = false;
        let typeAnnotation = null;
        const node = this.startNode();
        const lh = this.lookahead();
        const isThis = this.state.type === 78;
        if (lh.type === 14 || lh.type === 17) {
          if (isThis && !first2) {
            this.raise(FlowErrors.ThisParamMustBeFirst, {
              at: node
            });
          }
          name = this.parseIdentifier(isThis);
          if (this.eat(17)) {
            optional = true;
            if (isThis) {
              this.raise(FlowErrors.ThisParamMayNotBeOptional, {
                at: node
              });
            }
          }
          typeAnnotation = this.flowParseTypeInitialiser();
        } else {
          typeAnnotation = this.flowParseType();
        }
        node.name = name;
        node.optional = optional;
        node.typeAnnotation = typeAnnotation;
        return this.finishNode(node, "FunctionTypeParam");
      }
      reinterpretTypeAsFunctionTypeParam(type) {
        const node = this.startNodeAt(type.loc.start);
        node.name = null;
        node.optional = false;
        node.typeAnnotation = type;
        return this.finishNode(node, "FunctionTypeParam");
      }
      flowParseFunctionTypeParams(params = []) {
        let rest = null;
        let _this = null;
        if (this.match(78)) {
          _this = this.flowParseFunctionTypeParam(true);
          _this.name = null;
          if (!this.match(11)) {
            this.expect(12);
          }
        }
        while (!this.match(11) && !this.match(21)) {
          params.push(this.flowParseFunctionTypeParam(false));
          if (!this.match(11)) {
            this.expect(12);
          }
        }
        if (this.eat(21)) {
          rest = this.flowParseFunctionTypeParam(false);
        }
        return {
          params,
          rest,
          _this
        };
      }
      flowIdentToTypeAnnotation(startLoc, node, id) {
        switch (id.name) {
          case "any":
            return this.finishNode(node, "AnyTypeAnnotation");
          case "bool":
          case "boolean":
            return this.finishNode(node, "BooleanTypeAnnotation");
          case "mixed":
            return this.finishNode(node, "MixedTypeAnnotation");
          case "empty":
            return this.finishNode(node, "EmptyTypeAnnotation");
          case "number":
            return this.finishNode(node, "NumberTypeAnnotation");
          case "string":
            return this.finishNode(node, "StringTypeAnnotation");
          case "symbol":
            return this.finishNode(node, "SymbolTypeAnnotation");
          default:
            this.checkNotUnderscore(id.name);
            return this.flowParseGenericType(startLoc, id);
        }
      }
      flowParsePrimaryType() {
        const startLoc = this.state.startLoc;
        const node = this.startNode();
        let tmp;
        let type;
        let isGroupedType = false;
        const oldNoAnonFunctionType = this.state.noAnonFunctionType;
        switch (this.state.type) {
          case 5:
            return this.flowParseObjectType({
              allowStatic: false,
              allowExact: false,
              allowSpread: true,
              allowProto: false,
              allowInexact: true
            });
          case 6:
            return this.flowParseObjectType({
              allowStatic: false,
              allowExact: true,
              allowSpread: true,
              allowProto: false,
              allowInexact: false
            });
          case 0:
            this.state.noAnonFunctionType = false;
            type = this.flowParseTupleType();
            this.state.noAnonFunctionType = oldNoAnonFunctionType;
            return type;
          case 47:
            node.typeParameters = this.flowParseTypeParameterDeclaration();
            this.expect(10);
            tmp = this.flowParseFunctionTypeParams();
            node.params = tmp.params;
            node.rest = tmp.rest;
            node.this = tmp._this;
            this.expect(11);
            this.expect(19);
            node.returnType = this.flowParseType();
            return this.finishNode(node, "FunctionTypeAnnotation");
          case 10:
            this.next();
            if (!this.match(11) && !this.match(21)) {
              if (tokenIsIdentifier(this.state.type) || this.match(78)) {
                const token = this.lookahead().type;
                isGroupedType = token !== 17 && token !== 14;
              } else {
                isGroupedType = true;
              }
            }
            if (isGroupedType) {
              this.state.noAnonFunctionType = false;
              type = this.flowParseType();
              this.state.noAnonFunctionType = oldNoAnonFunctionType;
              if (this.state.noAnonFunctionType || !(this.match(12) || this.match(11) && this.lookahead().type === 19)) {
                this.expect(11);
                return type;
              } else {
                this.eat(12);
              }
            }
            if (type) {
              tmp = this.flowParseFunctionTypeParams([this.reinterpretTypeAsFunctionTypeParam(type)]);
            } else {
              tmp = this.flowParseFunctionTypeParams();
            }
            node.params = tmp.params;
            node.rest = tmp.rest;
            node.this = tmp._this;
            this.expect(11);
            this.expect(19);
            node.returnType = this.flowParseType();
            node.typeParameters = null;
            return this.finishNode(node, "FunctionTypeAnnotation");
          case 131:
            return this.parseLiteral(this.state.value, "StringLiteralTypeAnnotation");
          case 85:
          case 86:
            node.value = this.match(85);
            this.next();
            return this.finishNode(node, "BooleanLiteralTypeAnnotation");
          case 53:
            if (this.state.value === "-") {
              this.next();
              if (this.match(132)) {
                return this.parseLiteralAtNode(-this.state.value, "NumberLiteralTypeAnnotation", node);
              }
              if (this.match(133)) {
                return this.parseLiteralAtNode(-this.state.value, "BigIntLiteralTypeAnnotation", node);
              }
              throw this.raise(FlowErrors.UnexpectedSubtractionOperand, {
                at: this.state.startLoc
              });
            }
            throw this.unexpected();
          case 132:
            return this.parseLiteral(this.state.value, "NumberLiteralTypeAnnotation");
          case 133:
            return this.parseLiteral(this.state.value, "BigIntLiteralTypeAnnotation");
          case 88:
            this.next();
            return this.finishNode(node, "VoidTypeAnnotation");
          case 84:
            this.next();
            return this.finishNode(node, "NullLiteralTypeAnnotation");
          case 78:
            this.next();
            return this.finishNode(node, "ThisTypeAnnotation");
          case 55:
            this.next();
            return this.finishNode(node, "ExistsTypeAnnotation");
          case 87:
            return this.flowParseTypeofType();
          default:
            if (tokenIsKeyword(this.state.type)) {
              const label = tokenLabelName(this.state.type);
              this.next();
              return super.createIdentifier(node, label);
            } else if (tokenIsIdentifier(this.state.type)) {
              if (this.isContextual(127)) {
                return this.flowParseInterfaceType();
              }
              return this.flowIdentToTypeAnnotation(startLoc, node, this.parseIdentifier());
            }
        }
        throw this.unexpected();
      }
      flowParsePostfixType() {
        const startLoc = this.state.startLoc;
        let type = this.flowParsePrimaryType();
        let seenOptionalIndexedAccess = false;
        while ((this.match(0) || this.match(18)) && !this.canInsertSemicolon()) {
          const node = this.startNodeAt(startLoc);
          const optional = this.eat(18);
          seenOptionalIndexedAccess = seenOptionalIndexedAccess || optional;
          this.expect(0);
          if (!optional && this.match(3)) {
            node.elementType = type;
            this.next();
            type = this.finishNode(node, "ArrayTypeAnnotation");
          } else {
            node.objectType = type;
            node.indexType = this.flowParseType();
            this.expect(3);
            if (seenOptionalIndexedAccess) {
              node.optional = optional;
              type = this.finishNode(
                node,
                "OptionalIndexedAccessType"
              );
            } else {
              type = this.finishNode(
                node,
                "IndexedAccessType"
              );
            }
          }
        }
        return type;
      }
      flowParsePrefixType() {
        const node = this.startNode();
        if (this.eat(17)) {
          node.typeAnnotation = this.flowParsePrefixType();
          return this.finishNode(node, "NullableTypeAnnotation");
        } else {
          return this.flowParsePostfixType();
        }
      }
      flowParseAnonFunctionWithoutParens() {
        const param = this.flowParsePrefixType();
        if (!this.state.noAnonFunctionType && this.eat(19)) {
          const node = this.startNodeAt(param.loc.start);
          node.params = [this.reinterpretTypeAsFunctionTypeParam(param)];
          node.rest = null;
          node.this = null;
          node.returnType = this.flowParseType();
          node.typeParameters = null;
          return this.finishNode(node, "FunctionTypeAnnotation");
        }
        return param;
      }
      flowParseIntersectionType() {
        const node = this.startNode();
        this.eat(45);
        const type = this.flowParseAnonFunctionWithoutParens();
        node.types = [type];
        while (this.eat(45)) {
          node.types.push(this.flowParseAnonFunctionWithoutParens());
        }
        return node.types.length === 1 ? type : this.finishNode(node, "IntersectionTypeAnnotation");
      }
      flowParseUnionType() {
        const node = this.startNode();
        this.eat(43);
        const type = this.flowParseIntersectionType();
        node.types = [type];
        while (this.eat(43)) {
          node.types.push(this.flowParseIntersectionType());
        }
        return node.types.length === 1 ? type : this.finishNode(node, "UnionTypeAnnotation");
      }
      flowParseType() {
        const oldInType = this.state.inType;
        this.state.inType = true;
        const type = this.flowParseUnionType();
        this.state.inType = oldInType;
        return type;
      }
      flowParseTypeOrImplicitInstantiation() {
        if (this.state.type === 130 && this.state.value === "_") {
          const startLoc = this.state.startLoc;
          const node = this.parseIdentifier();
          return this.flowParseGenericType(startLoc, node);
        } else {
          return this.flowParseType();
        }
      }
      flowParseTypeAnnotation() {
        const node = this.startNode();
        node.typeAnnotation = this.flowParseTypeInitialiser();
        return this.finishNode(node, "TypeAnnotation");
      }
      flowParseTypeAnnotatableIdentifier(allowPrimitiveOverride) {
        const ident = allowPrimitiveOverride ? this.parseIdentifier() : this.flowParseRestrictedIdentifier();
        if (this.match(14)) {
          ident.typeAnnotation = this.flowParseTypeAnnotation();
          this.resetEndLocation(ident);
        }
        return ident;
      }
      typeCastToParameter(node) {
        node.expression.typeAnnotation = node.typeAnnotation;
        this.resetEndLocation(node.expression, node.typeAnnotation.loc.end);
        return node.expression;
      }
      flowParseVariance() {
        let variance = null;
        if (this.match(53)) {
          variance = this.startNode();
          if (this.state.value === "+") {
            variance.kind = "plus";
          } else {
            variance.kind = "minus";
          }
          this.next();
          return this.finishNode(variance, "Variance");
        }
        return variance;
      }
      parseFunctionBody(node, allowExpressionBody, isMethod = false) {
        if (allowExpressionBody) {
          return this.forwardNoArrowParamsConversionAt(node, () => super.parseFunctionBody(node, true, isMethod));
        }
        return super.parseFunctionBody(node, false, isMethod);
      }
      parseFunctionBodyAndFinish(node, type, isMethod = false) {
        if (this.match(14)) {
          const typeNode = this.startNode();
          [
            typeNode.typeAnnotation,
            node.predicate
          ] = this.flowParseTypeAndPredicateInitialiser();
          node.returnType = typeNode.typeAnnotation ? this.finishNode(typeNode, "TypeAnnotation") : null;
        }
        return super.parseFunctionBodyAndFinish(node, type, isMethod);
      }
      parseStatementLike(flags) {
        if (this.state.strict && this.isContextual(127)) {
          const lookahead = this.lookahead();
          if (tokenIsKeywordOrIdentifier(lookahead.type)) {
            const node = this.startNode();
            this.next();
            return this.flowParseInterface(node);
          }
        } else if (this.shouldParseEnums() && this.isContextual(124)) {
          const node = this.startNode();
          this.next();
          return this.flowParseEnumDeclaration(node);
        }
        const stmt = super.parseStatementLike(flags);
        if (this.flowPragma === void 0 && !this.isValidDirective(stmt)) {
          this.flowPragma = null;
        }
        return stmt;
      }
      parseExpressionStatement(node, expr, decorators) {
        if (expr.type === "Identifier") {
          if (expr.name === "declare") {
            if (this.match(80) || tokenIsIdentifier(this.state.type) || this.match(68) || this.match(74) || this.match(82)) {
              return this.flowParseDeclare(node);
            }
          } else if (tokenIsIdentifier(this.state.type)) {
            if (expr.name === "interface") {
              return this.flowParseInterface(node);
            } else if (expr.name === "type") {
              return this.flowParseTypeAlias(node);
            } else if (expr.name === "opaque") {
              return this.flowParseOpaqueType(node, false);
            }
          }
        }
        return super.parseExpressionStatement(node, expr, decorators);
      }
      shouldParseExportDeclaration() {
        const {
          type
        } = this.state;
        if (tokenIsFlowInterfaceOrTypeOrOpaque(type) || this.shouldParseEnums() && type === 124) {
          return !this.state.containsEsc;
        }
        return super.shouldParseExportDeclaration();
      }
      isExportDefaultSpecifier() {
        const {
          type
        } = this.state;
        if (tokenIsFlowInterfaceOrTypeOrOpaque(type) || this.shouldParseEnums() && type === 124) {
          return this.state.containsEsc;
        }
        return super.isExportDefaultSpecifier();
      }
      parseExportDefaultExpression() {
        if (this.shouldParseEnums() && this.isContextual(124)) {
          const node = this.startNode();
          this.next();
          return this.flowParseEnumDeclaration(node);
        }
        return super.parseExportDefaultExpression();
      }
      parseConditional(expr, startLoc, refExpressionErrors) {
        if (!this.match(17))
          return expr;
        if (this.state.maybeInArrowParameters) {
          const nextCh = this.lookaheadCharCode();
          if (nextCh === 44 || nextCh === 61 || nextCh === 58 || nextCh === 41) {
            this.setOptionalParametersError(refExpressionErrors);
            return expr;
          }
        }
        this.expect(17);
        const state = this.state.clone();
        const originalNoArrowAt = this.state.noArrowAt;
        const node = this.startNodeAt(startLoc);
        let {
          consequent,
          failed
        } = this.tryParseConditionalConsequent();
        let [valid, invalid] = this.getArrowLikeExpressions(consequent);
        if (failed || invalid.length > 0) {
          const noArrowAt = [...originalNoArrowAt];
          if (invalid.length > 0) {
            this.state = state;
            this.state.noArrowAt = noArrowAt;
            for (let i = 0; i < invalid.length; i++) {
              noArrowAt.push(invalid[i].start);
            }
            ({
              consequent,
              failed
            } = this.tryParseConditionalConsequent());
            [valid, invalid] = this.getArrowLikeExpressions(consequent);
          }
          if (failed && valid.length > 1) {
            this.raise(FlowErrors.AmbiguousConditionalArrow, {
              at: state.startLoc
            });
          }
          if (failed && valid.length === 1) {
            this.state = state;
            noArrowAt.push(valid[0].start);
            this.state.noArrowAt = noArrowAt;
            ({
              consequent,
              failed
            } = this.tryParseConditionalConsequent());
          }
        }
        this.getArrowLikeExpressions(consequent, true);
        this.state.noArrowAt = originalNoArrowAt;
        this.expect(14);
        node.test = expr;
        node.consequent = consequent;
        node.alternate = this.forwardNoArrowParamsConversionAt(node, () => this.parseMaybeAssign(void 0, void 0));
        return this.finishNode(node, "ConditionalExpression");
      }
      tryParseConditionalConsequent() {
        this.state.noArrowParamsConversionAt.push(this.state.start);
        const consequent = this.parseMaybeAssignAllowIn();
        const failed = !this.match(14);
        this.state.noArrowParamsConversionAt.pop();
        return {
          consequent,
          failed
        };
      }
      getArrowLikeExpressions(node, disallowInvalid) {
        const stack = [node];
        const arrows = [];
        while (stack.length !== 0) {
          const node2 = stack.pop();
          if (node2.type === "ArrowFunctionExpression") {
            if (node2.typeParameters || !node2.returnType) {
              this.finishArrowValidation(node2);
            } else {
              arrows.push(node2);
            }
            stack.push(node2.body);
          } else if (node2.type === "ConditionalExpression") {
            stack.push(node2.consequent);
            stack.push(node2.alternate);
          }
        }
        if (disallowInvalid) {
          arrows.forEach((node2) => this.finishArrowValidation(node2));
          return [arrows, []];
        }
        return partition(arrows, (node2) => node2.params.every((param) => this.isAssignable(param, true)));
      }
      finishArrowValidation(node) {
        var _node$extra;
        this.toAssignableList(
          node.params,
          (_node$extra = node.extra) == null ? void 0 : _node$extra.trailingCommaLoc,
          false
        );
        this.scope.enter(SCOPE_FUNCTION | SCOPE_ARROW);
        super.checkParams(node, false, true);
        this.scope.exit();
      }
      forwardNoArrowParamsConversionAt(node, parse4) {
        let result;
        if (this.state.noArrowParamsConversionAt.indexOf(node.start) !== -1) {
          this.state.noArrowParamsConversionAt.push(this.state.start);
          result = parse4();
          this.state.noArrowParamsConversionAt.pop();
        } else {
          result = parse4();
        }
        return result;
      }
      parseParenItem(node, startLoc) {
        node = super.parseParenItem(node, startLoc);
        if (this.eat(17)) {
          node.optional = true;
          this.resetEndLocation(node);
        }
        if (this.match(14)) {
          const typeCastNode = this.startNodeAt(startLoc);
          typeCastNode.expression = node;
          typeCastNode.typeAnnotation = this.flowParseTypeAnnotation();
          return this.finishNode(typeCastNode, "TypeCastExpression");
        }
        return node;
      }
      assertModuleNodeAllowed(node) {
        if (node.type === "ImportDeclaration" && (node.importKind === "type" || node.importKind === "typeof") || node.type === "ExportNamedDeclaration" && node.exportKind === "type" || node.type === "ExportAllDeclaration" && node.exportKind === "type") {
          return;
        }
        super.assertModuleNodeAllowed(node);
      }
      parseExport(node, decorators) {
        const decl = super.parseExport(node, decorators);
        if (decl.type === "ExportNamedDeclaration" || decl.type === "ExportAllDeclaration") {
          decl.exportKind = decl.exportKind || "value";
        }
        return decl;
      }
      parseExportDeclaration(node) {
        if (this.isContextual(128)) {
          node.exportKind = "type";
          const declarationNode = this.startNode();
          this.next();
          if (this.match(5)) {
            node.specifiers = this.parseExportSpecifiers(true);
            super.parseExportFrom(node);
            return null;
          } else {
            return this.flowParseTypeAlias(declarationNode);
          }
        } else if (this.isContextual(129)) {
          node.exportKind = "type";
          const declarationNode = this.startNode();
          this.next();
          return this.flowParseOpaqueType(declarationNode, false);
        } else if (this.isContextual(127)) {
          node.exportKind = "type";
          const declarationNode = this.startNode();
          this.next();
          return this.flowParseInterface(declarationNode);
        } else if (this.shouldParseEnums() && this.isContextual(124)) {
          node.exportKind = "value";
          const declarationNode = this.startNode();
          this.next();
          return this.flowParseEnumDeclaration(declarationNode);
        } else {
          return super.parseExportDeclaration(node);
        }
      }
      eatExportStar(node) {
        if (super.eatExportStar(node))
          return true;
        if (this.isContextual(128) && this.lookahead().type === 55) {
          node.exportKind = "type";
          this.next();
          this.next();
          return true;
        }
        return false;
      }
      maybeParseExportNamespaceSpecifier(node) {
        const {
          startLoc
        } = this.state;
        const hasNamespace = super.maybeParseExportNamespaceSpecifier(node);
        if (hasNamespace && node.exportKind === "type") {
          this.unexpected(startLoc);
        }
        return hasNamespace;
      }
      parseClassId(node, isStatement, optionalId) {
        super.parseClassId(node, isStatement, optionalId);
        if (this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        }
      }
      parseClassMember(classBody, member, state) {
        const {
          startLoc
        } = this.state;
        if (this.isContextual(123)) {
          if (super.parseClassMemberFromModifier(classBody, member)) {
            return;
          }
          member.declare = true;
        }
        super.parseClassMember(classBody, member, state);
        if (member.declare) {
          if (member.type !== "ClassProperty" && member.type !== "ClassPrivateProperty" && member.type !== "PropertyDefinition") {
            this.raise(FlowErrors.DeclareClassElement, {
              at: startLoc
            });
          } else if (member.value) {
            this.raise(FlowErrors.DeclareClassFieldInitializer, {
              at: member.value
            });
          }
        }
      }
      isIterator(word) {
        return word === "iterator" || word === "asyncIterator";
      }
      readIterator() {
        const word = super.readWord1();
        const fullWord = "@@" + word;
        if (!this.isIterator(word) || !this.state.inType) {
          this.raise(Errors.InvalidIdentifier, {
            at: this.state.curPosition(),
            identifierName: fullWord
          });
        }
        this.finishToken(130, fullWord);
      }
      getTokenFromCode(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (code === 123 && next === 124) {
          return this.finishOp(6, 2);
        } else if (this.state.inType && (code === 62 || code === 60)) {
          return this.finishOp(code === 62 ? 48 : 47, 1);
        } else if (this.state.inType && code === 63) {
          if (next === 46) {
            return this.finishOp(18, 2);
          }
          return this.finishOp(17, 1);
        } else if (isIteratorStart(code, next, this.input.charCodeAt(this.state.pos + 2))) {
          this.state.pos += 2;
          return this.readIterator();
        } else {
          return super.getTokenFromCode(code);
        }
      }
      isAssignable(node, isBinding) {
        if (node.type === "TypeCastExpression") {
          return this.isAssignable(node.expression, isBinding);
        } else {
          return super.isAssignable(node, isBinding);
        }
      }
      toAssignable(node, isLHS = false) {
        if (!isLHS && node.type === "AssignmentExpression" && node.left.type === "TypeCastExpression") {
          node.left = this.typeCastToParameter(node.left);
        }
        super.toAssignable(node, isLHS);
      }
      toAssignableList(exprList, trailingCommaLoc, isLHS) {
        for (let i = 0; i < exprList.length; i++) {
          const expr = exprList[i];
          if ((expr == null ? void 0 : expr.type) === "TypeCastExpression") {
            exprList[i] = this.typeCastToParameter(expr);
          }
        }
        super.toAssignableList(exprList, trailingCommaLoc, isLHS);
      }
      toReferencedList(exprList, isParenthesizedExpr) {
        for (let i = 0; i < exprList.length; i++) {
          var _expr$extra;
          const expr = exprList[i];
          if (expr && expr.type === "TypeCastExpression" && !((_expr$extra = expr.extra) != null && _expr$extra.parenthesized) && (exprList.length > 1 || !isParenthesizedExpr)) {
            this.raise(FlowErrors.TypeCastInPattern, {
              at: expr.typeAnnotation
            });
          }
        }
        return exprList;
      }
      parseArrayLike(close, canBePattern, isTuple, refExpressionErrors) {
        const node = super.parseArrayLike(close, canBePattern, isTuple, refExpressionErrors);
        if (canBePattern && !this.state.maybeInArrowParameters) {
          this.toReferencedList(node.elements);
        }
        return node;
      }
      isValidLVal(type, isParenthesized, binding) {
        return type === "TypeCastExpression" || super.isValidLVal(type, isParenthesized, binding);
      }
      parseClassProperty(node) {
        if (this.match(14)) {
          node.typeAnnotation = this.flowParseTypeAnnotation();
        }
        return super.parseClassProperty(node);
      }
      parseClassPrivateProperty(node) {
        if (this.match(14)) {
          node.typeAnnotation = this.flowParseTypeAnnotation();
        }
        return super.parseClassPrivateProperty(node);
      }
      isClassMethod() {
        return this.match(47) || super.isClassMethod();
      }
      isClassProperty() {
        return this.match(14) || super.isClassProperty();
      }
      isNonstaticConstructor(method) {
        return !this.match(14) && super.isNonstaticConstructor(method);
      }
      pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper) {
        if (method.variance) {
          this.unexpected(method.variance.loc.start);
        }
        delete method.variance;
        if (this.match(47)) {
          method.typeParameters = this.flowParseTypeParameterDeclaration();
        }
        super.pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper);
        if (method.params && isConstructor) {
          const params = method.params;
          if (params.length > 0 && this.isThisParam(params[0])) {
            this.raise(FlowErrors.ThisParamBannedInConstructor, {
              at: method
            });
          }
        } else if (method.type === "MethodDefinition" && isConstructor && method.value.params) {
          const params = method.value.params;
          if (params.length > 0 && this.isThisParam(params[0])) {
            this.raise(FlowErrors.ThisParamBannedInConstructor, {
              at: method
            });
          }
        }
      }
      pushClassPrivateMethod(classBody, method, isGenerator, isAsync) {
        if (method.variance) {
          this.unexpected(method.variance.loc.start);
        }
        delete method.variance;
        if (this.match(47)) {
          method.typeParameters = this.flowParseTypeParameterDeclaration();
        }
        super.pushClassPrivateMethod(classBody, method, isGenerator, isAsync);
      }
      parseClassSuper(node) {
        super.parseClassSuper(node);
        if (node.superClass && this.match(47)) {
          node.superTypeParameters = this.flowParseTypeParameterInstantiation();
        }
        if (this.isContextual(111)) {
          this.next();
          const implemented = node.implements = [];
          do {
            const node2 = this.startNode();
            node2.id = this.flowParseRestrictedIdentifier(true);
            if (this.match(47)) {
              node2.typeParameters = this.flowParseTypeParameterInstantiation();
            } else {
              node2.typeParameters = null;
            }
            implemented.push(this.finishNode(node2, "ClassImplements"));
          } while (this.eat(12));
        }
      }
      checkGetterSetterParams(method) {
        super.checkGetterSetterParams(method);
        const params = this.getObjectOrClassMethodParams(method);
        if (params.length > 0) {
          const param = params[0];
          if (this.isThisParam(param) && method.kind === "get") {
            this.raise(FlowErrors.GetterMayNotHaveThisParam, {
              at: param
            });
          } else if (this.isThisParam(param)) {
            this.raise(FlowErrors.SetterMayNotHaveThisParam, {
              at: param
            });
          }
        }
      }
      parsePropertyNamePrefixOperator(node) {
        node.variance = this.flowParseVariance();
      }
      parseObjPropValue(prop, startLoc, isGenerator, isAsync, isPattern, isAccessor, refExpressionErrors) {
        if (prop.variance) {
          this.unexpected(prop.variance.loc.start);
        }
        delete prop.variance;
        let typeParameters;
        if (this.match(47) && !isAccessor) {
          typeParameters = this.flowParseTypeParameterDeclaration();
          if (!this.match(10))
            this.unexpected();
        }
        const result = super.parseObjPropValue(prop, startLoc, isGenerator, isAsync, isPattern, isAccessor, refExpressionErrors);
        if (typeParameters) {
          (result.value || result).typeParameters = typeParameters;
        }
        return result;
      }
      parseAssignableListItemTypes(param) {
        if (this.eat(17)) {
          if (param.type !== "Identifier") {
            this.raise(FlowErrors.PatternIsOptional, {
              at: param
            });
          }
          if (this.isThisParam(param)) {
            this.raise(FlowErrors.ThisParamMayNotBeOptional, {
              at: param
            });
          }
          param.optional = true;
        }
        if (this.match(14)) {
          param.typeAnnotation = this.flowParseTypeAnnotation();
        } else if (this.isThisParam(param)) {
          this.raise(FlowErrors.ThisParamAnnotationRequired, {
            at: param
          });
        }
        if (this.match(29) && this.isThisParam(param)) {
          this.raise(FlowErrors.ThisParamNoDefault, {
            at: param
          });
        }
        this.resetEndLocation(param);
        return param;
      }
      parseMaybeDefault(startLoc, left) {
        const node = super.parseMaybeDefault(startLoc, left);
        if (node.type === "AssignmentPattern" && node.typeAnnotation && node.right.start < node.typeAnnotation.start) {
          this.raise(FlowErrors.TypeBeforeInitializer, {
            at: node.typeAnnotation
          });
        }
        return node;
      }
      shouldParseDefaultImport(node) {
        if (!hasTypeImportKind(node)) {
          return super.shouldParseDefaultImport(node);
        }
        return isMaybeDefaultImport(this.state.type);
      }
      checkImportReflection(node) {
        super.checkImportReflection(node);
        if (node.module && node.importKind !== "value") {
          this.raise(FlowErrors.ImportReflectionHasImportType, {
            at: node.specifiers[0].loc.start
          });
        }
      }
      parseImportSpecifierLocal(node, specifier, type) {
        specifier.local = hasTypeImportKind(node) ? this.flowParseRestrictedIdentifier(true, true) : this.parseIdentifier();
        node.specifiers.push(this.finishImportSpecifier(specifier, type));
      }
      maybeParseDefaultImportSpecifier(node) {
        node.importKind = "value";
        let kind = null;
        if (this.match(87)) {
          kind = "typeof";
        } else if (this.isContextual(128)) {
          kind = "type";
        }
        if (kind) {
          const lh = this.lookahead();
          const {
            type
          } = lh;
          if (kind === "type" && type === 55) {
            this.unexpected(null, lh.type);
          }
          if (isMaybeDefaultImport(type) || type === 5 || type === 55) {
            this.next();
            node.importKind = kind;
          }
        }
        return super.maybeParseDefaultImportSpecifier(node);
      }
      parseImportSpecifier(specifier, importedIsString, isInTypeOnlyImport, isMaybeTypeOnly, bindingType) {
        const firstIdent = specifier.imported;
        let specifierTypeKind = null;
        if (firstIdent.type === "Identifier") {
          if (firstIdent.name === "type") {
            specifierTypeKind = "type";
          } else if (firstIdent.name === "typeof") {
            specifierTypeKind = "typeof";
          }
        }
        let isBinding = false;
        if (this.isContextual(93) && !this.isLookaheadContextual("as")) {
          const as_ident = this.parseIdentifier(true);
          if (specifierTypeKind !== null && !tokenIsKeywordOrIdentifier(this.state.type)) {
            specifier.imported = as_ident;
            specifier.importKind = specifierTypeKind;
            specifier.local = cloneIdentifier(as_ident);
          } else {
            specifier.imported = firstIdent;
            specifier.importKind = null;
            specifier.local = this.parseIdentifier();
          }
        } else {
          if (specifierTypeKind !== null && tokenIsKeywordOrIdentifier(this.state.type)) {
            specifier.imported = this.parseIdentifier(true);
            specifier.importKind = specifierTypeKind;
          } else {
            if (importedIsString) {
              throw this.raise(Errors.ImportBindingIsString, {
                at: specifier,
                importName: firstIdent.value
              });
            }
            specifier.imported = firstIdent;
            specifier.importKind = null;
          }
          if (this.eatContextual(93)) {
            specifier.local = this.parseIdentifier();
          } else {
            isBinding = true;
            specifier.local = cloneIdentifier(specifier.imported);
          }
        }
        const specifierIsTypeImport = hasTypeImportKind(specifier);
        if (isInTypeOnlyImport && specifierIsTypeImport) {
          this.raise(FlowErrors.ImportTypeShorthandOnlyInPureImport, {
            at: specifier
          });
        }
        if (isInTypeOnlyImport || specifierIsTypeImport) {
          this.checkReservedType(specifier.local.name, specifier.local.loc.start, true);
        }
        if (isBinding && !isInTypeOnlyImport && !specifierIsTypeImport) {
          this.checkReservedWord(specifier.local.name, specifier.loc.start, true, true);
        }
        return this.finishImportSpecifier(specifier, "ImportSpecifier");
      }
      parseBindingAtom() {
        switch (this.state.type) {
          case 78:
            return this.parseIdentifier(true);
          default:
            return super.parseBindingAtom();
        }
      }
      parseFunctionParams(node, allowModifiers) {
        const kind = node.kind;
        if (kind !== "get" && kind !== "set" && this.match(47)) {
          node.typeParameters = this.flowParseTypeParameterDeclaration();
        }
        super.parseFunctionParams(node, allowModifiers);
      }
      parseVarId(decl, kind) {
        super.parseVarId(decl, kind);
        if (this.match(14)) {
          decl.id.typeAnnotation = this.flowParseTypeAnnotation();
          this.resetEndLocation(decl.id);
        }
      }
      parseAsyncArrowFromCallExpression(node, call) {
        if (this.match(14)) {
          const oldNoAnonFunctionType = this.state.noAnonFunctionType;
          this.state.noAnonFunctionType = true;
          node.returnType = this.flowParseTypeAnnotation();
          this.state.noAnonFunctionType = oldNoAnonFunctionType;
        }
        return super.parseAsyncArrowFromCallExpression(node, call);
      }
      shouldParseAsyncArrow() {
        return this.match(14) || super.shouldParseAsyncArrow();
      }
      parseMaybeAssign(refExpressionErrors, afterLeftParse) {
        var _jsx;
        let state = null;
        let jsx2;
        if (this.hasPlugin("jsx") && (this.match(140) || this.match(47))) {
          state = this.state.clone();
          jsx2 = this.tryParse(() => super.parseMaybeAssign(refExpressionErrors, afterLeftParse), state);
          if (!jsx2.error)
            return jsx2.node;
          const {
            context
          } = this.state;
          const currentContext = context[context.length - 1];
          if (currentContext === types.j_oTag || currentContext === types.j_expr) {
            context.pop();
          }
        }
        if ((_jsx = jsx2) != null && _jsx.error || this.match(47)) {
          var _jsx2, _jsx3;
          state = state || this.state.clone();
          let typeParameters;
          const arrow = this.tryParse((abort) => {
            var _arrowExpression$extr;
            typeParameters = this.flowParseTypeParameterDeclaration();
            const arrowExpression2 = this.forwardNoArrowParamsConversionAt(typeParameters, () => {
              const result = super.parseMaybeAssign(refExpressionErrors, afterLeftParse);
              this.resetStartLocationFromNode(result, typeParameters);
              return result;
            });
            if ((_arrowExpression$extr = arrowExpression2.extra) != null && _arrowExpression$extr.parenthesized)
              abort();
            const expr = this.maybeUnwrapTypeCastExpression(arrowExpression2);
            if (expr.type !== "ArrowFunctionExpression")
              abort();
            expr.typeParameters = typeParameters;
            this.resetStartLocationFromNode(expr, typeParameters);
            return arrowExpression2;
          }, state);
          let arrowExpression = null;
          if (arrow.node && this.maybeUnwrapTypeCastExpression(arrow.node).type === "ArrowFunctionExpression") {
            if (!arrow.error && !arrow.aborted) {
              if (arrow.node.async) {
                this.raise(FlowErrors.UnexpectedTypeParameterBeforeAsyncArrowFunction, {
                  at: typeParameters
                });
              }
              return arrow.node;
            }
            arrowExpression = arrow.node;
          }
          if ((_jsx2 = jsx2) != null && _jsx2.node) {
            this.state = jsx2.failState;
            return jsx2.node;
          }
          if (arrowExpression) {
            this.state = arrow.failState;
            return arrowExpression;
          }
          if ((_jsx3 = jsx2) != null && _jsx3.thrown)
            throw jsx2.error;
          if (arrow.thrown)
            throw arrow.error;
          throw this.raise(FlowErrors.UnexpectedTokenAfterTypeParameter, {
            at: typeParameters
          });
        }
        return super.parseMaybeAssign(refExpressionErrors, afterLeftParse);
      }
      parseArrow(node) {
        if (this.match(14)) {
          const result = this.tryParse(() => {
            const oldNoAnonFunctionType = this.state.noAnonFunctionType;
            this.state.noAnonFunctionType = true;
            const typeNode = this.startNode();
            [
              typeNode.typeAnnotation,
              node.predicate
            ] = this.flowParseTypeAndPredicateInitialiser();
            this.state.noAnonFunctionType = oldNoAnonFunctionType;
            if (this.canInsertSemicolon())
              this.unexpected();
            if (!this.match(19))
              this.unexpected();
            return typeNode;
          });
          if (result.thrown)
            return null;
          if (result.error)
            this.state = result.failState;
          node.returnType = result.node.typeAnnotation ? this.finishNode(result.node, "TypeAnnotation") : null;
        }
        return super.parseArrow(node);
      }
      shouldParseArrow(params) {
        return this.match(14) || super.shouldParseArrow(params);
      }
      setArrowFunctionParameters(node, params) {
        if (this.state.noArrowParamsConversionAt.indexOf(node.start) !== -1) {
          node.params = params;
        } else {
          super.setArrowFunctionParameters(node, params);
        }
      }
      checkParams(node, allowDuplicates, isArrowFunction, strictModeChanged = true) {
        if (isArrowFunction && this.state.noArrowParamsConversionAt.indexOf(node.start) !== -1) {
          return;
        }
        for (let i = 0; i < node.params.length; i++) {
          if (this.isThisParam(node.params[i]) && i > 0) {
            this.raise(FlowErrors.ThisParamMustBeFirst, {
              at: node.params[i]
            });
          }
        }
        return super.checkParams(node, allowDuplicates, isArrowFunction, strictModeChanged);
      }
      parseParenAndDistinguishExpression(canBeArrow) {
        return super.parseParenAndDistinguishExpression(canBeArrow && this.state.noArrowAt.indexOf(this.state.start) === -1);
      }
      parseSubscripts(base, startLoc, noCalls) {
        if (base.type === "Identifier" && base.name === "async" && this.state.noArrowAt.indexOf(startLoc.index) !== -1) {
          this.next();
          const node = this.startNodeAt(startLoc);
          node.callee = base;
          node.arguments = super.parseCallExpressionArguments(11, false);
          base = this.finishNode(node, "CallExpression");
        } else if (base.type === "Identifier" && base.name === "async" && this.match(47)) {
          const state = this.state.clone();
          const arrow = this.tryParse((abort) => this.parseAsyncArrowWithTypeParameters(startLoc) || abort(), state);
          if (!arrow.error && !arrow.aborted)
            return arrow.node;
          const result = this.tryParse(() => super.parseSubscripts(base, startLoc, noCalls), state);
          if (result.node && !result.error)
            return result.node;
          if (arrow.node) {
            this.state = arrow.failState;
            return arrow.node;
          }
          if (result.node) {
            this.state = result.failState;
            return result.node;
          }
          throw arrow.error || result.error;
        }
        return super.parseSubscripts(base, startLoc, noCalls);
      }
      parseSubscript(base, startLoc, noCalls, subscriptState) {
        if (this.match(18) && this.isLookaheadToken_lt()) {
          subscriptState.optionalChainMember = true;
          if (noCalls) {
            subscriptState.stop = true;
            return base;
          }
          this.next();
          const node = this.startNodeAt(startLoc);
          node.callee = base;
          node.typeArguments = this.flowParseTypeParameterInstantiation();
          this.expect(10);
          node.arguments = this.parseCallExpressionArguments(11, false);
          node.optional = true;
          return this.finishCallExpression(node, true);
        } else if (!noCalls && this.shouldParseTypes() && this.match(47)) {
          const node = this.startNodeAt(startLoc);
          node.callee = base;
          const result = this.tryParse(() => {
            node.typeArguments = this.flowParseTypeParameterInstantiationCallOrNew();
            this.expect(10);
            node.arguments = super.parseCallExpressionArguments(11, false);
            if (subscriptState.optionalChainMember) {
              node.optional = false;
            }
            return this.finishCallExpression(node, subscriptState.optionalChainMember);
          });
          if (result.node) {
            if (result.error)
              this.state = result.failState;
            return result.node;
          }
        }
        return super.parseSubscript(base, startLoc, noCalls, subscriptState);
      }
      parseNewCallee(node) {
        super.parseNewCallee(node);
        let targs = null;
        if (this.shouldParseTypes() && this.match(47)) {
          targs = this.tryParse(() => this.flowParseTypeParameterInstantiationCallOrNew()).node;
        }
        node.typeArguments = targs;
      }
      parseAsyncArrowWithTypeParameters(startLoc) {
        const node = this.startNodeAt(startLoc);
        this.parseFunctionParams(node);
        if (!this.parseArrow(node))
          return;
        return super.parseArrowExpression(node, void 0, true);
      }
      readToken_mult_modulo(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (code === 42 && next === 47 && this.state.hasFlowComment) {
          this.state.hasFlowComment = false;
          this.state.pos += 2;
          this.nextToken();
          return;
        }
        super.readToken_mult_modulo(code);
      }
      readToken_pipe_amp(code) {
        const next = this.input.charCodeAt(this.state.pos + 1);
        if (code === 124 && next === 125) {
          this.finishOp(9, 2);
          return;
        }
        super.readToken_pipe_amp(code);
      }
      parseTopLevel(file, program2) {
        const fileNode = super.parseTopLevel(file, program2);
        if (this.state.hasFlowComment) {
          this.raise(FlowErrors.UnterminatedFlowComment, {
            at: this.state.curPosition()
          });
        }
        return fileNode;
      }
      skipBlockComment() {
        if (this.hasPlugin("flowComments") && this.skipFlowComment()) {
          if (this.state.hasFlowComment) {
            throw this.raise(FlowErrors.NestedFlowComment, {
              at: this.state.startLoc
            });
          }
          this.hasFlowCommentCompletion();
          const commentSkip = this.skipFlowComment();
          if (commentSkip) {
            this.state.pos += commentSkip;
            this.state.hasFlowComment = true;
          }
          return;
        }
        return super.skipBlockComment(this.state.hasFlowComment ? "*-/" : "*/");
      }
      skipFlowComment() {
        const {
          pos
        } = this.state;
        let shiftToFirstNonWhiteSpace = 2;
        while ([32, 9].includes(
          this.input.charCodeAt(pos + shiftToFirstNonWhiteSpace)
        )) {
          shiftToFirstNonWhiteSpace++;
        }
        const ch2 = this.input.charCodeAt(shiftToFirstNonWhiteSpace + pos);
        const ch3 = this.input.charCodeAt(shiftToFirstNonWhiteSpace + pos + 1);
        if (ch2 === 58 && ch3 === 58) {
          return shiftToFirstNonWhiteSpace + 2;
        }
        if (this.input.slice(shiftToFirstNonWhiteSpace + pos, shiftToFirstNonWhiteSpace + pos + 12) === "flow-include") {
          return shiftToFirstNonWhiteSpace + 12;
        }
        if (ch2 === 58 && ch3 !== 58) {
          return shiftToFirstNonWhiteSpace;
        }
        return false;
      }
      hasFlowCommentCompletion() {
        const end = this.input.indexOf("*/", this.state.pos);
        if (end === -1) {
          throw this.raise(Errors.UnterminatedComment, {
            at: this.state.curPosition()
          });
        }
      }
      flowEnumErrorBooleanMemberNotInitialized(loc, {
        enumName,
        memberName
      }) {
        this.raise(FlowErrors.EnumBooleanMemberNotInitialized, {
          at: loc,
          memberName,
          enumName
        });
      }
      flowEnumErrorInvalidMemberInitializer(loc, enumContext) {
        return this.raise(!enumContext.explicitType ? FlowErrors.EnumInvalidMemberInitializerUnknownType : enumContext.explicitType === "symbol" ? FlowErrors.EnumInvalidMemberInitializerSymbolType : FlowErrors.EnumInvalidMemberInitializerPrimaryType, Object.assign({
          at: loc
        }, enumContext));
      }
      flowEnumErrorNumberMemberNotInitialized(loc, {
        enumName,
        memberName
      }) {
        this.raise(FlowErrors.EnumNumberMemberNotInitialized, {
          at: loc,
          enumName,
          memberName
        });
      }
      flowEnumErrorStringMemberInconsistentlyInitailized(node, {
        enumName
      }) {
        this.raise(FlowErrors.EnumStringMemberInconsistentlyInitailized, {
          at: node,
          enumName
        });
      }
      flowEnumMemberInit() {
        const startLoc = this.state.startLoc;
        const endOfInit = () => this.match(12) || this.match(8);
        switch (this.state.type) {
          case 132: {
            const literal = this.parseNumericLiteral(this.state.value);
            if (endOfInit()) {
              return {
                type: "number",
                loc: literal.loc.start,
                value: literal
              };
            }
            return {
              type: "invalid",
              loc: startLoc
            };
          }
          case 131: {
            const literal = this.parseStringLiteral(this.state.value);
            if (endOfInit()) {
              return {
                type: "string",
                loc: literal.loc.start,
                value: literal
              };
            }
            return {
              type: "invalid",
              loc: startLoc
            };
          }
          case 85:
          case 86: {
            const literal = this.parseBooleanLiteral(this.match(85));
            if (endOfInit()) {
              return {
                type: "boolean",
                loc: literal.loc.start,
                value: literal
              };
            }
            return {
              type: "invalid",
              loc: startLoc
            };
          }
          default:
            return {
              type: "invalid",
              loc: startLoc
            };
        }
      }
      flowEnumMemberRaw() {
        const loc = this.state.startLoc;
        const id = this.parseIdentifier(true);
        const init = this.eat(29) ? this.flowEnumMemberInit() : {
          type: "none",
          loc
        };
        return {
          id,
          init
        };
      }
      flowEnumCheckExplicitTypeMismatch(loc, context, expectedType) {
        const {
          explicitType
        } = context;
        if (explicitType === null) {
          return;
        }
        if (explicitType !== expectedType) {
          this.flowEnumErrorInvalidMemberInitializer(loc, context);
        }
      }
      flowEnumMembers({
        enumName,
        explicitType
      }) {
        const seenNames = /* @__PURE__ */ new Set();
        const members = {
          booleanMembers: [],
          numberMembers: [],
          stringMembers: [],
          defaultedMembers: []
        };
        let hasUnknownMembers = false;
        while (!this.match(8)) {
          if (this.eat(21)) {
            hasUnknownMembers = true;
            break;
          }
          const memberNode = this.startNode();
          const {
            id,
            init
          } = this.flowEnumMemberRaw();
          const memberName = id.name;
          if (memberName === "") {
            continue;
          }
          if (/^[a-z]/.test(memberName)) {
            this.raise(FlowErrors.EnumInvalidMemberName, {
              at: id,
              memberName,
              suggestion: memberName[0].toUpperCase() + memberName.slice(1),
              enumName
            });
          }
          if (seenNames.has(memberName)) {
            this.raise(FlowErrors.EnumDuplicateMemberName, {
              at: id,
              memberName,
              enumName
            });
          }
          seenNames.add(memberName);
          const context = {
            enumName,
            explicitType,
            memberName
          };
          memberNode.id = id;
          switch (init.type) {
            case "boolean": {
              this.flowEnumCheckExplicitTypeMismatch(init.loc, context, "boolean");
              memberNode.init = init.value;
              members.booleanMembers.push(this.finishNode(memberNode, "EnumBooleanMember"));
              break;
            }
            case "number": {
              this.flowEnumCheckExplicitTypeMismatch(init.loc, context, "number");
              memberNode.init = init.value;
              members.numberMembers.push(this.finishNode(memberNode, "EnumNumberMember"));
              break;
            }
            case "string": {
              this.flowEnumCheckExplicitTypeMismatch(init.loc, context, "string");
              memberNode.init = init.value;
              members.stringMembers.push(this.finishNode(memberNode, "EnumStringMember"));
              break;
            }
            case "invalid": {
              throw this.flowEnumErrorInvalidMemberInitializer(init.loc, context);
            }
            case "none": {
              switch (explicitType) {
                case "boolean":
                  this.flowEnumErrorBooleanMemberNotInitialized(init.loc, context);
                  break;
                case "number":
                  this.flowEnumErrorNumberMemberNotInitialized(init.loc, context);
                  break;
                default:
                  members.defaultedMembers.push(this.finishNode(memberNode, "EnumDefaultedMember"));
              }
            }
          }
          if (!this.match(8)) {
            this.expect(12);
          }
        }
        return {
          members,
          hasUnknownMembers
        };
      }
      flowEnumStringMembers(initializedMembers, defaultedMembers, {
        enumName
      }) {
        if (initializedMembers.length === 0) {
          return defaultedMembers;
        } else if (defaultedMembers.length === 0) {
          return initializedMembers;
        } else if (defaultedMembers.length > initializedMembers.length) {
          for (const member of initializedMembers) {
            this.flowEnumErrorStringMemberInconsistentlyInitailized(member, {
              enumName
            });
          }
          return defaultedMembers;
        } else {
          for (const member of defaultedMembers) {
            this.flowEnumErrorStringMemberInconsistentlyInitailized(member, {
              enumName
            });
          }
          return initializedMembers;
        }
      }
      flowEnumParseExplicitType({
        enumName
      }) {
        if (!this.eatContextual(101))
          return null;
        if (!tokenIsIdentifier(this.state.type)) {
          throw this.raise(FlowErrors.EnumInvalidExplicitTypeUnknownSupplied, {
            at: this.state.startLoc,
            enumName
          });
        }
        const {
          value: value2
        } = this.state;
        this.next();
        if (value2 !== "boolean" && value2 !== "number" && value2 !== "string" && value2 !== "symbol") {
          this.raise(FlowErrors.EnumInvalidExplicitType, {
            at: this.state.startLoc,
            enumName,
            invalidEnumType: value2
          });
        }
        return value2;
      }
      flowEnumBody(node, id) {
        const enumName = id.name;
        const nameLoc = id.loc.start;
        const explicitType = this.flowEnumParseExplicitType({
          enumName
        });
        this.expect(5);
        const {
          members,
          hasUnknownMembers
        } = this.flowEnumMembers({
          enumName,
          explicitType
        });
        node.hasUnknownMembers = hasUnknownMembers;
        switch (explicitType) {
          case "boolean":
            node.explicitType = true;
            node.members = members.booleanMembers;
            this.expect(8);
            return this.finishNode(node, "EnumBooleanBody");
          case "number":
            node.explicitType = true;
            node.members = members.numberMembers;
            this.expect(8);
            return this.finishNode(node, "EnumNumberBody");
          case "string":
            node.explicitType = true;
            node.members = this.flowEnumStringMembers(members.stringMembers, members.defaultedMembers, {
              enumName
            });
            this.expect(8);
            return this.finishNode(node, "EnumStringBody");
          case "symbol":
            node.members = members.defaultedMembers;
            this.expect(8);
            return this.finishNode(node, "EnumSymbolBody");
          default: {
            const empty = () => {
              node.members = [];
              this.expect(8);
              return this.finishNode(node, "EnumStringBody");
            };
            node.explicitType = false;
            const boolsLen = members.booleanMembers.length;
            const numsLen = members.numberMembers.length;
            const strsLen = members.stringMembers.length;
            const defaultedLen = members.defaultedMembers.length;
            if (!boolsLen && !numsLen && !strsLen && !defaultedLen) {
              return empty();
            } else if (!boolsLen && !numsLen) {
              node.members = this.flowEnumStringMembers(members.stringMembers, members.defaultedMembers, {
                enumName
              });
              this.expect(8);
              return this.finishNode(node, "EnumStringBody");
            } else if (!numsLen && !strsLen && boolsLen >= defaultedLen) {
              for (const member of members.defaultedMembers) {
                this.flowEnumErrorBooleanMemberNotInitialized(member.loc.start, {
                  enumName,
                  memberName: member.id.name
                });
              }
              node.members = members.booleanMembers;
              this.expect(8);
              return this.finishNode(node, "EnumBooleanBody");
            } else if (!boolsLen && !strsLen && numsLen >= defaultedLen) {
              for (const member of members.defaultedMembers) {
                this.flowEnumErrorNumberMemberNotInitialized(member.loc.start, {
                  enumName,
                  memberName: member.id.name
                });
              }
              node.members = members.numberMembers;
              this.expect(8);
              return this.finishNode(node, "EnumNumberBody");
            } else {
              this.raise(FlowErrors.EnumInconsistentMemberValues, {
                at: nameLoc,
                enumName
              });
              return empty();
            }
          }
        }
      }
      flowParseEnumDeclaration(node) {
        const id = this.parseIdentifier();
        node.id = id;
        node.body = this.flowEnumBody(this.startNode(), id);
        return this.finishNode(node, "EnumDeclaration");
      }
      isLookaheadToken_lt() {
        const next = this.nextTokenStart();
        if (this.input.charCodeAt(next) === 60) {
          const afterNext = this.input.charCodeAt(next + 1);
          return afterNext !== 60 && afterNext !== 61;
        }
        return false;
      }
      maybeUnwrapTypeCastExpression(node) {
        return node.type === "TypeCastExpression" ? node.expression : node;
      }
    };
    var entities = {
      __proto__: null,
      quot: '"',
      amp: "&",
      apos: "'",
      lt: "<",
      gt: ">",
      nbsp: "\xA0",
      iexcl: "\xA1",
      cent: "\xA2",
      pound: "\xA3",
      curren: "\xA4",
      yen: "\xA5",
      brvbar: "\xA6",
      sect: "\xA7",
      uml: "\xA8",
      copy: "\xA9",
      ordf: "\xAA",
      laquo: "\xAB",
      not: "\xAC",
      shy: "\xAD",
      reg: "\xAE",
      macr: "\xAF",
      deg: "\xB0",
      plusmn: "\xB1",
      sup2: "\xB2",
      sup3: "\xB3",
      acute: "\xB4",
      micro: "\xB5",
      para: "\xB6",
      middot: "\xB7",
      cedil: "\xB8",
      sup1: "\xB9",
      ordm: "\xBA",
      raquo: "\xBB",
      frac14: "\xBC",
      frac12: "\xBD",
      frac34: "\xBE",
      iquest: "\xBF",
      Agrave: "\xC0",
      Aacute: "\xC1",
      Acirc: "\xC2",
      Atilde: "\xC3",
      Auml: "\xC4",
      Aring: "\xC5",
      AElig: "\xC6",
      Ccedil: "\xC7",
      Egrave: "\xC8",
      Eacute: "\xC9",
      Ecirc: "\xCA",
      Euml: "\xCB",
      Igrave: "\xCC",
      Iacute: "\xCD",
      Icirc: "\xCE",
      Iuml: "\xCF",
      ETH: "\xD0",
      Ntilde: "\xD1",
      Ograve: "\xD2",
      Oacute: "\xD3",
      Ocirc: "\xD4",
      Otilde: "\xD5",
      Ouml: "\xD6",
      times: "\xD7",
      Oslash: "\xD8",
      Ugrave: "\xD9",
      Uacute: "\xDA",
      Ucirc: "\xDB",
      Uuml: "\xDC",
      Yacute: "\xDD",
      THORN: "\xDE",
      szlig: "\xDF",
      agrave: "\xE0",
      aacute: "\xE1",
      acirc: "\xE2",
      atilde: "\xE3",
      auml: "\xE4",
      aring: "\xE5",
      aelig: "\xE6",
      ccedil: "\xE7",
      egrave: "\xE8",
      eacute: "\xE9",
      ecirc: "\xEA",
      euml: "\xEB",
      igrave: "\xEC",
      iacute: "\xED",
      icirc: "\xEE",
      iuml: "\xEF",
      eth: "\xF0",
      ntilde: "\xF1",
      ograve: "\xF2",
      oacute: "\xF3",
      ocirc: "\xF4",
      otilde: "\xF5",
      ouml: "\xF6",
      divide: "\xF7",
      oslash: "\xF8",
      ugrave: "\xF9",
      uacute: "\xFA",
      ucirc: "\xFB",
      uuml: "\xFC",
      yacute: "\xFD",
      thorn: "\xFE",
      yuml: "\xFF",
      OElig: "\u0152",
      oelig: "\u0153",
      Scaron: "\u0160",
      scaron: "\u0161",
      Yuml: "\u0178",
      fnof: "\u0192",
      circ: "\u02C6",
      tilde: "\u02DC",
      Alpha: "\u0391",
      Beta: "\u0392",
      Gamma: "\u0393",
      Delta: "\u0394",
      Epsilon: "\u0395",
      Zeta: "\u0396",
      Eta: "\u0397",
      Theta: "\u0398",
      Iota: "\u0399",
      Kappa: "\u039A",
      Lambda: "\u039B",
      Mu: "\u039C",
      Nu: "\u039D",
      Xi: "\u039E",
      Omicron: "\u039F",
      Pi: "\u03A0",
      Rho: "\u03A1",
      Sigma: "\u03A3",
      Tau: "\u03A4",
      Upsilon: "\u03A5",
      Phi: "\u03A6",
      Chi: "\u03A7",
      Psi: "\u03A8",
      Omega: "\u03A9",
      alpha: "\u03B1",
      beta: "\u03B2",
      gamma: "\u03B3",
      delta: "\u03B4",
      epsilon: "\u03B5",
      zeta: "\u03B6",
      eta: "\u03B7",
      theta: "\u03B8",
      iota: "\u03B9",
      kappa: "\u03BA",
      lambda: "\u03BB",
      mu: "\u03BC",
      nu: "\u03BD",
      xi: "\u03BE",
      omicron: "\u03BF",
      pi: "\u03C0",
      rho: "\u03C1",
      sigmaf: "\u03C2",
      sigma: "\u03C3",
      tau: "\u03C4",
      upsilon: "\u03C5",
      phi: "\u03C6",
      chi: "\u03C7",
      psi: "\u03C8",
      omega: "\u03C9",
      thetasym: "\u03D1",
      upsih: "\u03D2",
      piv: "\u03D6",
      ensp: "\u2002",
      emsp: "\u2003",
      thinsp: "\u2009",
      zwnj: "\u200C",
      zwj: "\u200D",
      lrm: "\u200E",
      rlm: "\u200F",
      ndash: "\u2013",
      mdash: "\u2014",
      lsquo: "\u2018",
      rsquo: "\u2019",
      sbquo: "\u201A",
      ldquo: "\u201C",
      rdquo: "\u201D",
      bdquo: "\u201E",
      dagger: "\u2020",
      Dagger: "\u2021",
      bull: "\u2022",
      hellip: "\u2026",
      permil: "\u2030",
      prime: "\u2032",
      Prime: "\u2033",
      lsaquo: "\u2039",
      rsaquo: "\u203A",
      oline: "\u203E",
      frasl: "\u2044",
      euro: "\u20AC",
      image: "\u2111",
      weierp: "\u2118",
      real: "\u211C",
      trade: "\u2122",
      alefsym: "\u2135",
      larr: "\u2190",
      uarr: "\u2191",
      rarr: "\u2192",
      darr: "\u2193",
      harr: "\u2194",
      crarr: "\u21B5",
      lArr: "\u21D0",
      uArr: "\u21D1",
      rArr: "\u21D2",
      dArr: "\u21D3",
      hArr: "\u21D4",
      forall: "\u2200",
      part: "\u2202",
      exist: "\u2203",
      empty: "\u2205",
      nabla: "\u2207",
      isin: "\u2208",
      notin: "\u2209",
      ni: "\u220B",
      prod: "\u220F",
      sum: "\u2211",
      minus: "\u2212",
      lowast: "\u2217",
      radic: "\u221A",
      prop: "\u221D",
      infin: "\u221E",
      ang: "\u2220",
      and: "\u2227",
      or: "\u2228",
      cap: "\u2229",
      cup: "\u222A",
      int: "\u222B",
      there4: "\u2234",
      sim: "\u223C",
      cong: "\u2245",
      asymp: "\u2248",
      ne: "\u2260",
      equiv: "\u2261",
      le: "\u2264",
      ge: "\u2265",
      sub: "\u2282",
      sup: "\u2283",
      nsub: "\u2284",
      sube: "\u2286",
      supe: "\u2287",
      oplus: "\u2295",
      otimes: "\u2297",
      perp: "\u22A5",
      sdot: "\u22C5",
      lceil: "\u2308",
      rceil: "\u2309",
      lfloor: "\u230A",
      rfloor: "\u230B",
      lang: "\u2329",
      rang: "\u232A",
      loz: "\u25CA",
      spades: "\u2660",
      clubs: "\u2663",
      hearts: "\u2665",
      diams: "\u2666"
    };
    var JsxErrors = ParseErrorEnum`jsx`({
      AttributeIsEmpty: "JSX attributes must only be assigned a non-empty expression.",
      MissingClosingTagElement: ({
        openingTagName
      }) => `Expected corresponding JSX closing tag for <${openingTagName}>.`,
      MissingClosingTagFragment: "Expected corresponding JSX closing tag for <>.",
      UnexpectedSequenceExpression: "Sequence expressions cannot be directly nested inside JSX. Did you mean to wrap it in parentheses (...)?",
      UnexpectedToken: ({
        unexpected,
        HTMLEntity
      }) => `Unexpected token \`${unexpected}\`. Did you mean \`${HTMLEntity}\` or \`{'${unexpected}'}\`?`,
      UnsupportedJsxValue: "JSX value should be either an expression or a quoted JSX text.",
      UnterminatedJsxContent: "Unterminated JSX contents.",
      UnwrappedAdjacentJSXElements: "Adjacent JSX elements must be wrapped in an enclosing tag. Did you want a JSX fragment <>...</>?"
    });
    function isFragment(object) {
      return object ? object.type === "JSXOpeningFragment" || object.type === "JSXClosingFragment" : false;
    }
    function getQualifiedJSXName(object) {
      if (object.type === "JSXIdentifier") {
        return object.name;
      }
      if (object.type === "JSXNamespacedName") {
        return object.namespace.name + ":" + object.name.name;
      }
      if (object.type === "JSXMemberExpression") {
        return getQualifiedJSXName(object.object) + "." + getQualifiedJSXName(object.property);
      }
      throw new Error("Node had unexpected type: " + object.type);
    }
    var jsx = (superClass) => class JSXParserMixin extends superClass {
      jsxReadToken() {
        let out = "";
        let chunkStart = this.state.pos;
        for (; ; ) {
          if (this.state.pos >= this.length) {
            throw this.raise(JsxErrors.UnterminatedJsxContent, {
              at: this.state.startLoc
            });
          }
          const ch = this.input.charCodeAt(this.state.pos);
          switch (ch) {
            case 60:
            case 123:
              if (this.state.pos === this.state.start) {
                if (ch === 60 && this.state.canStartJSXElement) {
                  ++this.state.pos;
                  return this.finishToken(140);
                }
                return super.getTokenFromCode(ch);
              }
              out += this.input.slice(chunkStart, this.state.pos);
              return this.finishToken(139, out);
            case 38:
              out += this.input.slice(chunkStart, this.state.pos);
              out += this.jsxReadEntity();
              chunkStart = this.state.pos;
              break;
            case 62:
            case 125:
            default:
              if (isNewLine(ch)) {
                out += this.input.slice(chunkStart, this.state.pos);
                out += this.jsxReadNewLine(true);
                chunkStart = this.state.pos;
              } else {
                ++this.state.pos;
              }
          }
        }
      }
      jsxReadNewLine(normalizeCRLF) {
        const ch = this.input.charCodeAt(this.state.pos);
        let out;
        ++this.state.pos;
        if (ch === 13 && this.input.charCodeAt(this.state.pos) === 10) {
          ++this.state.pos;
          out = normalizeCRLF ? "\n" : "\r\n";
        } else {
          out = String.fromCharCode(ch);
        }
        ++this.state.curLine;
        this.state.lineStart = this.state.pos;
        return out;
      }
      jsxReadString(quote) {
        let out = "";
        let chunkStart = ++this.state.pos;
        for (; ; ) {
          if (this.state.pos >= this.length) {
            throw this.raise(Errors.UnterminatedString, {
              at: this.state.startLoc
            });
          }
          const ch = this.input.charCodeAt(this.state.pos);
          if (ch === quote)
            break;
          if (ch === 38) {
            out += this.input.slice(chunkStart, this.state.pos);
            out += this.jsxReadEntity();
            chunkStart = this.state.pos;
          } else if (isNewLine(ch)) {
            out += this.input.slice(chunkStart, this.state.pos);
            out += this.jsxReadNewLine(false);
            chunkStart = this.state.pos;
          } else {
            ++this.state.pos;
          }
        }
        out += this.input.slice(chunkStart, this.state.pos++);
        return this.finishToken(131, out);
      }
      jsxReadEntity() {
        const startPos = ++this.state.pos;
        if (this.codePointAtPos(this.state.pos) === 35) {
          ++this.state.pos;
          let radix = 10;
          if (this.codePointAtPos(this.state.pos) === 120) {
            radix = 16;
            ++this.state.pos;
          }
          const codePoint = this.readInt(radix, void 0, false, "bail");
          if (codePoint !== null && this.codePointAtPos(this.state.pos) === 59) {
            ++this.state.pos;
            return String.fromCodePoint(codePoint);
          }
        } else {
          let count = 0;
          let semi = false;
          while (count++ < 10 && this.state.pos < this.length && !(semi = this.codePointAtPos(this.state.pos) == 59)) {
            ++this.state.pos;
          }
          if (semi) {
            const desc = this.input.slice(startPos, this.state.pos);
            const entity = entities[desc];
            ++this.state.pos;
            if (entity) {
              return entity;
            }
          }
        }
        this.state.pos = startPos;
        return "&";
      }
      jsxReadWord() {
        let ch;
        const start = this.state.pos;
        do {
          ch = this.input.charCodeAt(++this.state.pos);
        } while (isIdentifierChar(ch) || ch === 45);
        return this.finishToken(138, this.input.slice(start, this.state.pos));
      }
      jsxParseIdentifier() {
        const node = this.startNode();
        if (this.match(138)) {
          node.name = this.state.value;
        } else if (tokenIsKeyword(this.state.type)) {
          node.name = tokenLabelName(this.state.type);
        } else {
          this.unexpected();
        }
        this.next();
        return this.finishNode(node, "JSXIdentifier");
      }
      jsxParseNamespacedName() {
        const startLoc = this.state.startLoc;
        const name = this.jsxParseIdentifier();
        if (!this.eat(14))
          return name;
        const node = this.startNodeAt(startLoc);
        node.namespace = name;
        node.name = this.jsxParseIdentifier();
        return this.finishNode(node, "JSXNamespacedName");
      }
      jsxParseElementName() {
        const startLoc = this.state.startLoc;
        let node = this.jsxParseNamespacedName();
        if (node.type === "JSXNamespacedName") {
          return node;
        }
        while (this.eat(16)) {
          const newNode = this.startNodeAt(startLoc);
          newNode.object = node;
          newNode.property = this.jsxParseIdentifier();
          node = this.finishNode(newNode, "JSXMemberExpression");
        }
        return node;
      }
      jsxParseAttributeValue() {
        let node;
        switch (this.state.type) {
          case 5:
            node = this.startNode();
            this.setContext(types.brace);
            this.next();
            node = this.jsxParseExpressionContainer(node, types.j_oTag);
            if (node.expression.type === "JSXEmptyExpression") {
              this.raise(JsxErrors.AttributeIsEmpty, {
                at: node
              });
            }
            return node;
          case 140:
          case 131:
            return this.parseExprAtom();
          default:
            throw this.raise(JsxErrors.UnsupportedJsxValue, {
              at: this.state.startLoc
            });
        }
      }
      jsxParseEmptyExpression() {
        const node = this.startNodeAt(this.state.lastTokEndLoc);
        return this.finishNodeAt(node, "JSXEmptyExpression", this.state.startLoc);
      }
      jsxParseSpreadChild(node) {
        this.next();
        node.expression = this.parseExpression();
        this.setContext(types.j_expr);
        this.state.canStartJSXElement = true;
        this.expect(8);
        return this.finishNode(node, "JSXSpreadChild");
      }
      jsxParseExpressionContainer(node, previousContext) {
        if (this.match(8)) {
          node.expression = this.jsxParseEmptyExpression();
        } else {
          const expression = this.parseExpression();
          node.expression = expression;
        }
        this.setContext(previousContext);
        this.state.canStartJSXElement = true;
        this.expect(8);
        return this.finishNode(node, "JSXExpressionContainer");
      }
      jsxParseAttribute() {
        const node = this.startNode();
        if (this.match(5)) {
          this.setContext(types.brace);
          this.next();
          this.expect(21);
          node.argument = this.parseMaybeAssignAllowIn();
          this.setContext(types.j_oTag);
          this.state.canStartJSXElement = true;
          this.expect(8);
          return this.finishNode(node, "JSXSpreadAttribute");
        }
        node.name = this.jsxParseNamespacedName();
        node.value = this.eat(29) ? this.jsxParseAttributeValue() : null;
        return this.finishNode(node, "JSXAttribute");
      }
      jsxParseOpeningElementAt(startLoc) {
        const node = this.startNodeAt(startLoc);
        if (this.eat(141)) {
          return this.finishNode(node, "JSXOpeningFragment");
        }
        node.name = this.jsxParseElementName();
        return this.jsxParseOpeningElementAfterName(node);
      }
      jsxParseOpeningElementAfterName(node) {
        const attributes = [];
        while (!this.match(56) && !this.match(141)) {
          attributes.push(this.jsxParseAttribute());
        }
        node.attributes = attributes;
        node.selfClosing = this.eat(56);
        this.expect(141);
        return this.finishNode(node, "JSXOpeningElement");
      }
      jsxParseClosingElementAt(startLoc) {
        const node = this.startNodeAt(startLoc);
        if (this.eat(141)) {
          return this.finishNode(node, "JSXClosingFragment");
        }
        node.name = this.jsxParseElementName();
        this.expect(141);
        return this.finishNode(node, "JSXClosingElement");
      }
      jsxParseElementAt(startLoc) {
        const node = this.startNodeAt(startLoc);
        const children = [];
        const openingElement = this.jsxParseOpeningElementAt(startLoc);
        let closingElement = null;
        if (!openingElement.selfClosing) {
          contents:
            for (; ; ) {
              switch (this.state.type) {
                case 140:
                  startLoc = this.state.startLoc;
                  this.next();
                  if (this.eat(56)) {
                    closingElement = this.jsxParseClosingElementAt(startLoc);
                    break contents;
                  }
                  children.push(this.jsxParseElementAt(startLoc));
                  break;
                case 139:
                  children.push(this.parseExprAtom());
                  break;
                case 5: {
                  const node2 = this.startNode();
                  this.setContext(types.brace);
                  this.next();
                  if (this.match(21)) {
                    children.push(this.jsxParseSpreadChild(node2));
                  } else {
                    children.push(this.jsxParseExpressionContainer(node2, types.j_expr));
                  }
                  break;
                }
                default:
                  throw this.unexpected();
              }
            }
          if (isFragment(openingElement) && !isFragment(closingElement) && closingElement !== null) {
            this.raise(JsxErrors.MissingClosingTagFragment, {
              at: closingElement
            });
          } else if (!isFragment(openingElement) && isFragment(closingElement)) {
            this.raise(JsxErrors.MissingClosingTagElement, {
              at: closingElement,
              openingTagName: getQualifiedJSXName(openingElement.name)
            });
          } else if (!isFragment(openingElement) && !isFragment(closingElement)) {
            if (getQualifiedJSXName(closingElement.name) !== getQualifiedJSXName(openingElement.name)) {
              this.raise(JsxErrors.MissingClosingTagElement, {
                at: closingElement,
                openingTagName: getQualifiedJSXName(openingElement.name)
              });
            }
          }
        }
        if (isFragment(openingElement)) {
          node.openingFragment = openingElement;
          node.closingFragment = closingElement;
        } else {
          node.openingElement = openingElement;
          node.closingElement = closingElement;
        }
        node.children = children;
        if (this.match(47)) {
          throw this.raise(JsxErrors.UnwrappedAdjacentJSXElements, {
            at: this.state.startLoc
          });
        }
        return isFragment(openingElement) ? this.finishNode(node, "JSXFragment") : this.finishNode(node, "JSXElement");
      }
      jsxParseElement() {
        const startLoc = this.state.startLoc;
        this.next();
        return this.jsxParseElementAt(startLoc);
      }
      setContext(newContext) {
        const {
          context
        } = this.state;
        context[context.length - 1] = newContext;
      }
      parseExprAtom(refExpressionErrors) {
        if (this.match(139)) {
          return this.parseLiteral(this.state.value, "JSXText");
        } else if (this.match(140)) {
          return this.jsxParseElement();
        } else if (this.match(47) && this.input.charCodeAt(this.state.pos) !== 33) {
          this.replaceToken(140);
          return this.jsxParseElement();
        } else {
          return super.parseExprAtom(refExpressionErrors);
        }
      }
      skipSpace() {
        const curContext = this.curContext();
        if (!curContext.preserveSpace)
          super.skipSpace();
      }
      getTokenFromCode(code) {
        const context = this.curContext();
        if (context === types.j_expr) {
          return this.jsxReadToken();
        }
        if (context === types.j_oTag || context === types.j_cTag) {
          if (isIdentifierStart(code)) {
            return this.jsxReadWord();
          }
          if (code === 62) {
            ++this.state.pos;
            return this.finishToken(141);
          }
          if ((code === 34 || code === 39) && context === types.j_oTag) {
            return this.jsxReadString(code);
          }
        }
        if (code === 60 && this.state.canStartJSXElement && this.input.charCodeAt(this.state.pos + 1) !== 33) {
          ++this.state.pos;
          return this.finishToken(140);
        }
        return super.getTokenFromCode(code);
      }
      updateContext(prevType) {
        const {
          context,
          type
        } = this.state;
        if (type === 56 && prevType === 140) {
          context.splice(-2, 2, types.j_cTag);
          this.state.canStartJSXElement = false;
        } else if (type === 140) {
          context.push(types.j_oTag);
        } else if (type === 141) {
          const out = context[context.length - 1];
          if (out === types.j_oTag && prevType === 56 || out === types.j_cTag) {
            context.pop();
            this.state.canStartJSXElement = context[context.length - 1] === types.j_expr;
          } else {
            this.setContext(types.j_expr);
            this.state.canStartJSXElement = true;
          }
        } else {
          this.state.canStartJSXElement = tokenComesBeforeExpression(type);
        }
      }
    };
    var TypeScriptScope = class extends Scope {
      constructor(...args) {
        super(...args);
        this.types = /* @__PURE__ */ new Set();
        this.enums = /* @__PURE__ */ new Set();
        this.constEnums = /* @__PURE__ */ new Set();
        this.classes = /* @__PURE__ */ new Set();
        this.exportOnlyBindings = /* @__PURE__ */ new Set();
      }
    };
    var TypeScriptScopeHandler = class extends ScopeHandler {
      constructor(...args) {
        super(...args);
        this.importsStack = [];
      }
      createScope(flags) {
        this.importsStack.push(/* @__PURE__ */ new Set());
        return new TypeScriptScope(flags);
      }
      enter(flags) {
        if (flags == SCOPE_TS_MODULE) {
          this.importsStack.push(/* @__PURE__ */ new Set());
        }
        super.enter(flags);
      }
      exit() {
        const flags = super.exit();
        if (flags == SCOPE_TS_MODULE) {
          this.importsStack.pop();
        }
        return flags;
      }
      hasImport(name, allowShadow) {
        const len = this.importsStack.length;
        if (this.importsStack[len - 1].has(name)) {
          return true;
        }
        if (!allowShadow && len > 1) {
          for (let i = 0; i < len - 1; i++) {
            if (this.importsStack[i].has(name))
              return true;
          }
        }
        return false;
      }
      declareName(name, bindingType, loc) {
        if (bindingType & BIND_FLAGS_TS_IMPORT) {
          if (this.hasImport(name, true)) {
            this.parser.raise(Errors.VarRedeclaration, {
              at: loc,
              identifierName: name
            });
          }
          this.importsStack[this.importsStack.length - 1].add(name);
          return;
        }
        const scope = this.currentScope();
        if (bindingType & BIND_FLAGS_TS_EXPORT_ONLY) {
          this.maybeExportDefined(scope, name);
          scope.exportOnlyBindings.add(name);
          return;
        }
        super.declareName(name, bindingType, loc);
        if (bindingType & BIND_KIND_TYPE) {
          if (!(bindingType & BIND_KIND_VALUE)) {
            this.checkRedeclarationInScope(scope, name, bindingType, loc);
            this.maybeExportDefined(scope, name);
          }
          scope.types.add(name);
        }
        if (bindingType & BIND_FLAGS_TS_ENUM)
          scope.enums.add(name);
        if (bindingType & BIND_FLAGS_TS_CONST_ENUM)
          scope.constEnums.add(name);
        if (bindingType & BIND_FLAGS_CLASS)
          scope.classes.add(name);
      }
      isRedeclaredInScope(scope, name, bindingType) {
        if (scope.enums.has(name)) {
          if (bindingType & BIND_FLAGS_TS_ENUM) {
            const isConst = !!(bindingType & BIND_FLAGS_TS_CONST_ENUM);
            const wasConst = scope.constEnums.has(name);
            return isConst !== wasConst;
          }
          return true;
        }
        if (bindingType & BIND_FLAGS_CLASS && scope.classes.has(name)) {
          if (scope.lexical.has(name)) {
            return !!(bindingType & BIND_KIND_VALUE);
          } else {
            return false;
          }
        }
        if (bindingType & BIND_KIND_TYPE && scope.types.has(name)) {
          return true;
        }
        return super.isRedeclaredInScope(scope, name, bindingType);
      }
      checkLocalExport(id) {
        const {
          name
        } = id;
        if (this.hasImport(name))
          return;
        const len = this.scopeStack.length;
        for (let i = len - 1; i >= 0; i--) {
          const scope = this.scopeStack[i];
          if (scope.types.has(name) || scope.exportOnlyBindings.has(name))
            return;
        }
        super.checkLocalExport(id);
      }
    };
    var getOwn$1 = (object, key) => Object.hasOwnProperty.call(object, key) && object[key];
    function nonNull(x) {
      if (x == null) {
        throw new Error(`Unexpected ${x} value.`);
      }
      return x;
    }
    function assert(x) {
      if (!x) {
        throw new Error("Assert fail");
      }
    }
    var TSErrors = ParseErrorEnum`typescript`({
      AbstractMethodHasImplementation: ({
        methodName
      }) => `Method '${methodName}' cannot have an implementation because it is marked abstract.`,
      AbstractPropertyHasInitializer: ({
        propertyName
      }) => `Property '${propertyName}' cannot have an initializer because it is marked abstract.`,
      AccesorCannotDeclareThisParameter: "'get' and 'set' accessors cannot declare 'this' parameters.",
      AccesorCannotHaveTypeParameters: "An accessor cannot have type parameters.",
      AccessorCannotBeOptional: "An 'accessor' property cannot be declared optional.",
      ClassMethodHasDeclare: "Class methods cannot have the 'declare' modifier.",
      ClassMethodHasReadonly: "Class methods cannot have the 'readonly' modifier.",
      ConstInitiailizerMustBeStringOrNumericLiteralOrLiteralEnumReference: "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference.",
      ConstructorHasTypeParameters: "Type parameters cannot appear on a constructor declaration.",
      DeclareAccessor: ({
        kind
      }) => `'declare' is not allowed in ${kind}ters.`,
      DeclareClassFieldHasInitializer: "Initializers are not allowed in ambient contexts.",
      DeclareFunctionHasImplementation: "An implementation cannot be declared in ambient contexts.",
      DuplicateAccessibilityModifier: ({
        modifier
      }) => `Accessibility modifier already seen.`,
      DuplicateModifier: ({
        modifier
      }) => `Duplicate modifier: '${modifier}'.`,
      EmptyHeritageClauseType: ({
        token
      }) => `'${token}' list cannot be empty.`,
      EmptyTypeArguments: "Type argument list cannot be empty.",
      EmptyTypeParameters: "Type parameter list cannot be empty.",
      ExpectedAmbientAfterExportDeclare: "'export declare' must be followed by an ambient declaration.",
      ImportAliasHasImportType: "An import alias can not use 'import type'.",
      ImportReflectionHasImportType: "An `import module` declaration can not use `type` modifier",
      IncompatibleModifiers: ({
        modifiers
      }) => `'${modifiers[0]}' modifier cannot be used with '${modifiers[1]}' modifier.`,
      IndexSignatureHasAbstract: "Index signatures cannot have the 'abstract' modifier.",
      IndexSignatureHasAccessibility: ({
        modifier
      }) => `Index signatures cannot have an accessibility modifier ('${modifier}').`,
      IndexSignatureHasDeclare: "Index signatures cannot have the 'declare' modifier.",
      IndexSignatureHasOverride: "'override' modifier cannot appear on an index signature.",
      IndexSignatureHasStatic: "Index signatures cannot have the 'static' modifier.",
      InitializerNotAllowedInAmbientContext: "Initializers are not allowed in ambient contexts.",
      InvalidModifierOnTypeMember: ({
        modifier
      }) => `'${modifier}' modifier cannot appear on a type member.`,
      InvalidModifierOnTypeParameter: ({
        modifier
      }) => `'${modifier}' modifier cannot appear on a type parameter.`,
      InvalidModifierOnTypeParameterPositions: ({
        modifier
      }) => `'${modifier}' modifier can only appear on a type parameter of a class, interface or type alias.`,
      InvalidModifiersOrder: ({
        orderedModifiers
      }) => `'${orderedModifiers[0]}' modifier must precede '${orderedModifiers[1]}' modifier.`,
      InvalidPropertyAccessAfterInstantiationExpression: "Invalid property access after an instantiation expression. You can either wrap the instantiation expression in parentheses, or delete the type arguments.",
      InvalidTupleMemberLabel: "Tuple members must be labeled with a simple identifier.",
      MissingInterfaceName: "'interface' declarations must be followed by an identifier.",
      MixedLabeledAndUnlabeledElements: "Tuple members must all have names or all not have names.",
      NonAbstractClassHasAbstractMethod: "Abstract methods can only appear within an abstract class.",
      NonClassMethodPropertyHasAbstractModifer: "'abstract' modifier can only appear on a class, method, or property declaration.",
      OptionalTypeBeforeRequired: "A required element cannot follow an optional element.",
      OverrideNotInSubClass: "This member cannot have an 'override' modifier because its containing class does not extend another class.",
      PatternIsOptional: "A binding pattern parameter cannot be optional in an implementation signature.",
      PrivateElementHasAbstract: "Private elements cannot have the 'abstract' modifier.",
      PrivateElementHasAccessibility: ({
        modifier
      }) => `Private elements cannot have an accessibility modifier ('${modifier}').`,
      ReadonlyForMethodSignature: "'readonly' modifier can only appear on a property declaration or index signature.",
      ReservedArrowTypeParam: "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma, as in `<T,>() => ...`.",
      ReservedTypeAssertion: "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead.",
      SetAccesorCannotHaveOptionalParameter: "A 'set' accessor cannot have an optional parameter.",
      SetAccesorCannotHaveRestParameter: "A 'set' accessor cannot have rest parameter.",
      SetAccesorCannotHaveReturnType: "A 'set' accessor cannot have a return type annotation.",
      SingleTypeParameterWithoutTrailingComma: ({
        typeParameterName
      }) => `Single type parameter ${typeParameterName} should have a trailing comma. Example usage: <${typeParameterName},>.`,
      StaticBlockCannotHaveModifier: "Static class blocks cannot have any modifier.",
      TypeAnnotationAfterAssign: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.",
      TypeImportCannotSpecifyDefaultAndNamed: "A type-only import can specify a default import or named bindings, but not both.",
      TypeModifierIsUsedInTypeExports: "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement.",
      TypeModifierIsUsedInTypeImports: "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement.",
      UnexpectedParameterModifier: "A parameter property is only allowed in a constructor implementation.",
      UnexpectedReadonly: "'readonly' type modifier is only permitted on array and tuple literal types.",
      UnexpectedTypeAnnotation: "Did not expect a type annotation here.",
      UnexpectedTypeCastInParameter: "Unexpected type cast in parameter position.",
      UnsupportedImportTypeArgument: "Argument in a type import must be a string literal.",
      UnsupportedParameterPropertyKind: "A parameter property may not be declared using a binding pattern.",
      UnsupportedSignatureParameterKind: ({
        type
      }) => `Name in a signature must be an Identifier, ObjectPattern or ArrayPattern, instead got ${type}.`
    });
    function keywordTypeFromName(value2) {
      switch (value2) {
        case "any":
          return "TSAnyKeyword";
        case "boolean":
          return "TSBooleanKeyword";
        case "bigint":
          return "TSBigIntKeyword";
        case "never":
          return "TSNeverKeyword";
        case "number":
          return "TSNumberKeyword";
        case "object":
          return "TSObjectKeyword";
        case "string":
          return "TSStringKeyword";
        case "symbol":
          return "TSSymbolKeyword";
        case "undefined":
          return "TSUndefinedKeyword";
        case "unknown":
          return "TSUnknownKeyword";
        default:
          return void 0;
      }
    }
    function tsIsAccessModifier(modifier) {
      return modifier === "private" || modifier === "public" || modifier === "protected";
    }
    function tsIsVarianceAnnotations(modifier) {
      return modifier === "in" || modifier === "out";
    }
    var typescript = (superClass) => class TypeScriptParserMixin extends superClass {
      getScopeHandler() {
        return TypeScriptScopeHandler;
      }
      tsIsIdentifier() {
        return tokenIsIdentifier(this.state.type);
      }
      tsTokenCanFollowModifier() {
        return (this.match(0) || this.match(5) || this.match(55) || this.match(21) || this.match(136) || this.isLiteralPropertyName()) && !this.hasPrecedingLineBreak();
      }
      tsNextTokenCanFollowModifier() {
        this.next();
        return this.tsTokenCanFollowModifier();
      }
      tsParseModifier(allowedModifiers, stopOnStartOfClassStaticBlock) {
        if (!tokenIsIdentifier(this.state.type) && this.state.type !== 58) {
          return void 0;
        }
        const modifier = this.state.value;
        if (allowedModifiers.indexOf(modifier) !== -1) {
          if (stopOnStartOfClassStaticBlock && this.tsIsStartOfStaticBlocks()) {
            return void 0;
          }
          if (this.tsTryParse(this.tsNextTokenCanFollowModifier.bind(this))) {
            return modifier;
          }
        }
        return void 0;
      }
      tsParseModifiers({
        modified,
        allowedModifiers,
        disallowedModifiers,
        stopOnStartOfClassStaticBlock,
        errorTemplate = TSErrors.InvalidModifierOnTypeMember
      }) {
        const enforceOrder = (loc, modifier, before, after) => {
          if (modifier === before && modified[after]) {
            this.raise(TSErrors.InvalidModifiersOrder, {
              at: loc,
              orderedModifiers: [before, after]
            });
          }
        };
        const incompatible = (loc, modifier, mod1, mod2) => {
          if (modified[mod1] && modifier === mod2 || modified[mod2] && modifier === mod1) {
            this.raise(TSErrors.IncompatibleModifiers, {
              at: loc,
              modifiers: [mod1, mod2]
            });
          }
        };
        for (; ; ) {
          const {
            startLoc
          } = this.state;
          const modifier = this.tsParseModifier(allowedModifiers.concat(disallowedModifiers != null ? disallowedModifiers : []), stopOnStartOfClassStaticBlock);
          if (!modifier)
            break;
          if (tsIsAccessModifier(modifier)) {
            if (modified.accessibility) {
              this.raise(TSErrors.DuplicateAccessibilityModifier, {
                at: startLoc,
                modifier
              });
            } else {
              enforceOrder(startLoc, modifier, modifier, "override");
              enforceOrder(startLoc, modifier, modifier, "static");
              enforceOrder(startLoc, modifier, modifier, "readonly");
              modified.accessibility = modifier;
            }
          } else if (tsIsVarianceAnnotations(modifier)) {
            if (modified[modifier]) {
              this.raise(TSErrors.DuplicateModifier, {
                at: startLoc,
                modifier
              });
            }
            modified[modifier] = true;
            enforceOrder(startLoc, modifier, "in", "out");
          } else {
            if (Object.hasOwnProperty.call(modified, modifier)) {
              this.raise(TSErrors.DuplicateModifier, {
                at: startLoc,
                modifier
              });
            } else {
              enforceOrder(startLoc, modifier, "static", "readonly");
              enforceOrder(startLoc, modifier, "static", "override");
              enforceOrder(startLoc, modifier, "override", "readonly");
              enforceOrder(startLoc, modifier, "abstract", "override");
              incompatible(startLoc, modifier, "declare", "override");
              incompatible(startLoc, modifier, "static", "abstract");
            }
            modified[modifier] = true;
          }
          if (disallowedModifiers != null && disallowedModifiers.includes(modifier)) {
            this.raise(errorTemplate, {
              at: startLoc,
              modifier
            });
          }
        }
      }
      tsIsListTerminator(kind) {
        switch (kind) {
          case "EnumMembers":
          case "TypeMembers":
            return this.match(8);
          case "HeritageClauseElement":
            return this.match(5);
          case "TupleElementTypes":
            return this.match(3);
          case "TypeParametersOrArguments":
            return this.match(48);
        }
        throw new Error("Unreachable");
      }
      tsParseList(kind, parseElement) {
        const result = [];
        while (!this.tsIsListTerminator(kind)) {
          result.push(parseElement());
        }
        return result;
      }
      tsParseDelimitedList(kind, parseElement, refTrailingCommaPos) {
        return nonNull(this.tsParseDelimitedListWorker(kind, parseElement, true, refTrailingCommaPos));
      }
      tsParseDelimitedListWorker(kind, parseElement, expectSuccess, refTrailingCommaPos) {
        const result = [];
        let trailingCommaPos = -1;
        for (; ; ) {
          if (this.tsIsListTerminator(kind)) {
            break;
          }
          trailingCommaPos = -1;
          const element = parseElement();
          if (element == null) {
            return void 0;
          }
          result.push(element);
          if (this.eat(12)) {
            trailingCommaPos = this.state.lastTokStart;
            continue;
          }
          if (this.tsIsListTerminator(kind)) {
            break;
          }
          if (expectSuccess) {
            this.expect(12);
          }
          return void 0;
        }
        if (refTrailingCommaPos) {
          refTrailingCommaPos.value = trailingCommaPos;
        }
        return result;
      }
      tsParseBracketedList(kind, parseElement, bracket, skipFirstToken, refTrailingCommaPos) {
        if (!skipFirstToken) {
          if (bracket) {
            this.expect(0);
          } else {
            this.expect(47);
          }
        }
        const result = this.tsParseDelimitedList(kind, parseElement, refTrailingCommaPos);
        if (bracket) {
          this.expect(3);
        } else {
          this.expect(48);
        }
        return result;
      }
      tsParseImportType() {
        const node = this.startNode();
        this.expect(83);
        this.expect(10);
        if (!this.match(131)) {
          this.raise(TSErrors.UnsupportedImportTypeArgument, {
            at: this.state.startLoc
          });
        }
        node.argument = super.parseExprAtom();
        this.expect(11);
        if (this.eat(16)) {
          node.qualifier = this.tsParseEntityName();
        }
        if (this.match(47)) {
          node.typeParameters = this.tsParseTypeArguments();
        }
        return this.finishNode(node, "TSImportType");
      }
      tsParseEntityName(allowReservedWords = true) {
        let entity = this.parseIdentifier(allowReservedWords);
        while (this.eat(16)) {
          const node = this.startNodeAtNode(entity);
          node.left = entity;
          node.right = this.parseIdentifier(allowReservedWords);
          entity = this.finishNode(node, "TSQualifiedName");
        }
        return entity;
      }
      tsParseTypeReference() {
        const node = this.startNode();
        node.typeName = this.tsParseEntityName();
        if (!this.hasPrecedingLineBreak() && this.match(47)) {
          node.typeParameters = this.tsParseTypeArguments();
        }
        return this.finishNode(node, "TSTypeReference");
      }
      tsParseThisTypePredicate(lhs) {
        this.next();
        const node = this.startNodeAtNode(lhs);
        node.parameterName = lhs;
        node.typeAnnotation = this.tsParseTypeAnnotation(false);
        node.asserts = false;
        return this.finishNode(node, "TSTypePredicate");
      }
      tsParseThisTypeNode() {
        const node = this.startNode();
        this.next();
        return this.finishNode(node, "TSThisType");
      }
      tsParseTypeQuery() {
        const node = this.startNode();
        this.expect(87);
        if (this.match(83)) {
          node.exprName = this.tsParseImportType();
        } else {
          node.exprName = this.tsParseEntityName();
        }
        if (!this.hasPrecedingLineBreak() && this.match(47)) {
          node.typeParameters = this.tsParseTypeArguments();
        }
        return this.finishNode(node, "TSTypeQuery");
      }
      tsParseInOutModifiers(node) {
        this.tsParseModifiers({
          modified: node,
          allowedModifiers: ["in", "out"],
          disallowedModifiers: ["public", "private", "protected", "readonly", "declare", "abstract", "override"],
          errorTemplate: TSErrors.InvalidModifierOnTypeParameter
        });
      }
      tsParseNoneModifiers(node) {
        this.tsParseModifiers({
          modified: node,
          allowedModifiers: [],
          disallowedModifiers: ["in", "out"],
          errorTemplate: TSErrors.InvalidModifierOnTypeParameterPositions
        });
      }
      tsParseTypeParameter(parseModifiers = this.tsParseNoneModifiers.bind(this)) {
        const node = this.startNode();
        parseModifiers(node);
        node.name = this.tsParseTypeParameterName();
        node.constraint = this.tsEatThenParseType(81);
        node.default = this.tsEatThenParseType(29);
        return this.finishNode(node, "TSTypeParameter");
      }
      tsTryParseTypeParameters(parseModifiers) {
        if (this.match(47)) {
          return this.tsParseTypeParameters(parseModifiers);
        }
      }
      tsParseTypeParameters(parseModifiers) {
        const node = this.startNode();
        if (this.match(47) || this.match(140)) {
          this.next();
        } else {
          this.unexpected();
        }
        const refTrailingCommaPos = {
          value: -1
        };
        node.params = this.tsParseBracketedList(
          "TypeParametersOrArguments",
          this.tsParseTypeParameter.bind(this, parseModifiers),
          false,
          true,
          refTrailingCommaPos
        );
        if (node.params.length === 0) {
          this.raise(TSErrors.EmptyTypeParameters, {
            at: node
          });
        }
        if (refTrailingCommaPos.value !== -1) {
          this.addExtra(node, "trailingComma", refTrailingCommaPos.value);
        }
        return this.finishNode(node, "TSTypeParameterDeclaration");
      }
      tsFillSignature(returnToken, signature) {
        const returnTokenRequired = returnToken === 19;
        const paramsKey = "parameters";
        const returnTypeKey = "typeAnnotation";
        signature.typeParameters = this.tsTryParseTypeParameters();
        this.expect(10);
        signature[paramsKey] = this.tsParseBindingListForSignature();
        if (returnTokenRequired) {
          signature[returnTypeKey] = this.tsParseTypeOrTypePredicateAnnotation(returnToken);
        } else if (this.match(returnToken)) {
          signature[returnTypeKey] = this.tsParseTypeOrTypePredicateAnnotation(returnToken);
        }
      }
      tsParseBindingListForSignature() {
        return super.parseBindingList(11, 41).map((pattern) => {
          if (pattern.type !== "Identifier" && pattern.type !== "RestElement" && pattern.type !== "ObjectPattern" && pattern.type !== "ArrayPattern") {
            this.raise(TSErrors.UnsupportedSignatureParameterKind, {
              at: pattern,
              type: pattern.type
            });
          }
          return pattern;
        });
      }
      tsParseTypeMemberSemicolon() {
        if (!this.eat(12) && !this.isLineTerminator()) {
          this.expect(13);
        }
      }
      tsParseSignatureMember(kind, node) {
        this.tsFillSignature(14, node);
        this.tsParseTypeMemberSemicolon();
        return this.finishNode(node, kind);
      }
      tsIsUnambiguouslyIndexSignature() {
        this.next();
        if (tokenIsIdentifier(this.state.type)) {
          this.next();
          return this.match(14);
        }
        return false;
      }
      tsTryParseIndexSignature(node) {
        if (!(this.match(0) && this.tsLookAhead(this.tsIsUnambiguouslyIndexSignature.bind(this)))) {
          return void 0;
        }
        this.expect(0);
        const id = this.parseIdentifier();
        id.typeAnnotation = this.tsParseTypeAnnotation();
        this.resetEndLocation(id);
        this.expect(3);
        node.parameters = [id];
        const type = this.tsTryParseTypeAnnotation();
        if (type)
          node.typeAnnotation = type;
        this.tsParseTypeMemberSemicolon();
        return this.finishNode(node, "TSIndexSignature");
      }
      tsParsePropertyOrMethodSignature(node, readonly) {
        if (this.eat(17))
          node.optional = true;
        const nodeAny = node;
        if (this.match(10) || this.match(47)) {
          if (readonly) {
            this.raise(TSErrors.ReadonlyForMethodSignature, {
              at: node
            });
          }
          const method = nodeAny;
          if (method.kind && this.match(47)) {
            this.raise(TSErrors.AccesorCannotHaveTypeParameters, {
              at: this.state.curPosition()
            });
          }
          this.tsFillSignature(14, method);
          this.tsParseTypeMemberSemicolon();
          const paramsKey = "parameters";
          const returnTypeKey = "typeAnnotation";
          if (method.kind === "get") {
            if (method[paramsKey].length > 0) {
              this.raise(Errors.BadGetterArity, {
                at: this.state.curPosition()
              });
              if (this.isThisParam(method[paramsKey][0])) {
                this.raise(TSErrors.AccesorCannotDeclareThisParameter, {
                  at: this.state.curPosition()
                });
              }
            }
          } else if (method.kind === "set") {
            if (method[paramsKey].length !== 1) {
              this.raise(Errors.BadSetterArity, {
                at: this.state.curPosition()
              });
            } else {
              const firstParameter = method[paramsKey][0];
              if (this.isThisParam(firstParameter)) {
                this.raise(TSErrors.AccesorCannotDeclareThisParameter, {
                  at: this.state.curPosition()
                });
              }
              if (firstParameter.type === "Identifier" && firstParameter.optional) {
                this.raise(TSErrors.SetAccesorCannotHaveOptionalParameter, {
                  at: this.state.curPosition()
                });
              }
              if (firstParameter.type === "RestElement") {
                this.raise(TSErrors.SetAccesorCannotHaveRestParameter, {
                  at: this.state.curPosition()
                });
              }
            }
            if (method[returnTypeKey]) {
              this.raise(TSErrors.SetAccesorCannotHaveReturnType, {
                at: method[returnTypeKey]
              });
            }
          } else {
            method.kind = "method";
          }
          return this.finishNode(method, "TSMethodSignature");
        } else {
          const property = nodeAny;
          if (readonly)
            property.readonly = true;
          const type = this.tsTryParseTypeAnnotation();
          if (type)
            property.typeAnnotation = type;
          this.tsParseTypeMemberSemicolon();
          return this.finishNode(property, "TSPropertySignature");
        }
      }
      tsParseTypeMember() {
        const node = this.startNode();
        if (this.match(10) || this.match(47)) {
          return this.tsParseSignatureMember("TSCallSignatureDeclaration", node);
        }
        if (this.match(77)) {
          const id = this.startNode();
          this.next();
          if (this.match(10) || this.match(47)) {
            return this.tsParseSignatureMember("TSConstructSignatureDeclaration", node);
          } else {
            node.key = this.createIdentifier(id, "new");
            return this.tsParsePropertyOrMethodSignature(node, false);
          }
        }
        this.tsParseModifiers({
          modified: node,
          allowedModifiers: ["readonly"],
          disallowedModifiers: ["declare", "abstract", "private", "protected", "public", "static", "override"]
        });
        const idx = this.tsTryParseIndexSignature(node);
        if (idx) {
          return idx;
        }
        super.parsePropertyName(node);
        if (!node.computed && node.key.type === "Identifier" && (node.key.name === "get" || node.key.name === "set") && this.tsTokenCanFollowModifier()) {
          node.kind = node.key.name;
          super.parsePropertyName(node);
        }
        return this.tsParsePropertyOrMethodSignature(node, !!node.readonly);
      }
      tsParseTypeLiteral() {
        const node = this.startNode();
        node.members = this.tsParseObjectTypeMembers();
        return this.finishNode(node, "TSTypeLiteral");
      }
      tsParseObjectTypeMembers() {
        this.expect(5);
        const members = this.tsParseList("TypeMembers", this.tsParseTypeMember.bind(this));
        this.expect(8);
        return members;
      }
      tsIsStartOfMappedType() {
        this.next();
        if (this.eat(53)) {
          return this.isContextual(120);
        }
        if (this.isContextual(120)) {
          this.next();
        }
        if (!this.match(0)) {
          return false;
        }
        this.next();
        if (!this.tsIsIdentifier()) {
          return false;
        }
        this.next();
        return this.match(58);
      }
      tsParseMappedTypeParameter() {
        const node = this.startNode();
        node.name = this.tsParseTypeParameterName();
        node.constraint = this.tsExpectThenParseType(58);
        return this.finishNode(node, "TSTypeParameter");
      }
      tsParseMappedType() {
        const node = this.startNode();
        this.expect(5);
        if (this.match(53)) {
          node.readonly = this.state.value;
          this.next();
          this.expectContextual(120);
        } else if (this.eatContextual(120)) {
          node.readonly = true;
        }
        this.expect(0);
        node.typeParameter = this.tsParseMappedTypeParameter();
        node.nameType = this.eatContextual(93) ? this.tsParseType() : null;
        this.expect(3);
        if (this.match(53)) {
          node.optional = this.state.value;
          this.next();
          this.expect(17);
        } else if (this.eat(17)) {
          node.optional = true;
        }
        node.typeAnnotation = this.tsTryParseType();
        this.semicolon();
        this.expect(8);
        return this.finishNode(node, "TSMappedType");
      }
      tsParseTupleType() {
        const node = this.startNode();
        node.elementTypes = this.tsParseBracketedList("TupleElementTypes", this.tsParseTupleElementType.bind(this), true, false);
        let seenOptionalElement = false;
        let labeledElements = null;
        node.elementTypes.forEach((elementNode) => {
          var _labeledElements;
          const {
            type
          } = elementNode;
          if (seenOptionalElement && type !== "TSRestType" && type !== "TSOptionalType" && !(type === "TSNamedTupleMember" && elementNode.optional)) {
            this.raise(TSErrors.OptionalTypeBeforeRequired, {
              at: elementNode
            });
          }
          seenOptionalElement || (seenOptionalElement = type === "TSNamedTupleMember" && elementNode.optional || type === "TSOptionalType");
          let checkType = type;
          if (type === "TSRestType") {
            elementNode = elementNode.typeAnnotation;
            checkType = elementNode.type;
          }
          const isLabeled = checkType === "TSNamedTupleMember";
          (_labeledElements = labeledElements) != null ? _labeledElements : labeledElements = isLabeled;
          if (labeledElements !== isLabeled) {
            this.raise(TSErrors.MixedLabeledAndUnlabeledElements, {
              at: elementNode
            });
          }
        });
        return this.finishNode(node, "TSTupleType");
      }
      tsParseTupleElementType() {
        const {
          startLoc
        } = this.state;
        const rest = this.eat(21);
        let type = this.tsParseType();
        const optional = this.eat(17);
        const labeled = this.eat(14);
        if (labeled) {
          const labeledNode = this.startNodeAtNode(type);
          labeledNode.optional = optional;
          if (type.type === "TSTypeReference" && !type.typeParameters && type.typeName.type === "Identifier") {
            labeledNode.label = type.typeName;
          } else {
            this.raise(TSErrors.InvalidTupleMemberLabel, {
              at: type
            });
            labeledNode.label = type;
          }
          labeledNode.elementType = this.tsParseType();
          type = this.finishNode(labeledNode, "TSNamedTupleMember");
        } else if (optional) {
          const optionalTypeNode = this.startNodeAtNode(type);
          optionalTypeNode.typeAnnotation = type;
          type = this.finishNode(optionalTypeNode, "TSOptionalType");
        }
        if (rest) {
          const restNode = this.startNodeAt(startLoc);
          restNode.typeAnnotation = type;
          type = this.finishNode(restNode, "TSRestType");
        }
        return type;
      }
      tsParseParenthesizedType() {
        const node = this.startNode();
        this.expect(10);
        node.typeAnnotation = this.tsParseType();
        this.expect(11);
        return this.finishNode(node, "TSParenthesizedType");
      }
      tsParseFunctionOrConstructorType(type, abstract) {
        const node = this.startNode();
        if (type === "TSConstructorType") {
          node.abstract = !!abstract;
          if (abstract)
            this.next();
          this.next();
        }
        this.tsInAllowConditionalTypesContext(() => this.tsFillSignature(19, node));
        return this.finishNode(node, type);
      }
      tsParseLiteralTypeNode() {
        const node = this.startNode();
        node.literal = (() => {
          switch (this.state.type) {
            case 132:
            case 133:
            case 131:
            case 85:
            case 86:
              return super.parseExprAtom();
            default:
              throw this.unexpected();
          }
        })();
        return this.finishNode(node, "TSLiteralType");
      }
      tsParseTemplateLiteralType() {
        const node = this.startNode();
        node.literal = super.parseTemplate(false);
        return this.finishNode(node, "TSLiteralType");
      }
      parseTemplateSubstitution() {
        if (this.state.inType)
          return this.tsParseType();
        return super.parseTemplateSubstitution();
      }
      tsParseThisTypeOrThisTypePredicate() {
        const thisKeyword = this.tsParseThisTypeNode();
        if (this.isContextual(114) && !this.hasPrecedingLineBreak()) {
          return this.tsParseThisTypePredicate(thisKeyword);
        } else {
          return thisKeyword;
        }
      }
      tsParseNonArrayType() {
        switch (this.state.type) {
          case 131:
          case 132:
          case 133:
          case 85:
          case 86:
            return this.tsParseLiteralTypeNode();
          case 53:
            if (this.state.value === "-") {
              const node = this.startNode();
              const nextToken = this.lookahead();
              if (nextToken.type !== 132 && nextToken.type !== 133) {
                throw this.unexpected();
              }
              node.literal = this.parseMaybeUnary();
              return this.finishNode(node, "TSLiteralType");
            }
            break;
          case 78:
            return this.tsParseThisTypeOrThisTypePredicate();
          case 87:
            return this.tsParseTypeQuery();
          case 83:
            return this.tsParseImportType();
          case 5:
            return this.tsLookAhead(this.tsIsStartOfMappedType.bind(this)) ? this.tsParseMappedType() : this.tsParseTypeLiteral();
          case 0:
            return this.tsParseTupleType();
          case 10:
            return this.tsParseParenthesizedType();
          case 25:
          case 24:
            return this.tsParseTemplateLiteralType();
          default: {
            const {
              type
            } = this.state;
            if (tokenIsIdentifier(type) || type === 88 || type === 84) {
              const nodeType = type === 88 ? "TSVoidKeyword" : type === 84 ? "TSNullKeyword" : keywordTypeFromName(this.state.value);
              if (nodeType !== void 0 && this.lookaheadCharCode() !== 46) {
                const node = this.startNode();
                this.next();
                return this.finishNode(node, nodeType);
              }
              return this.tsParseTypeReference();
            }
          }
        }
        throw this.unexpected();
      }
      tsParseArrayTypeOrHigher() {
        let type = this.tsParseNonArrayType();
        while (!this.hasPrecedingLineBreak() && this.eat(0)) {
          if (this.match(3)) {
            const node = this.startNodeAtNode(type);
            node.elementType = type;
            this.expect(3);
            type = this.finishNode(node, "TSArrayType");
          } else {
            const node = this.startNodeAtNode(type);
            node.objectType = type;
            node.indexType = this.tsParseType();
            this.expect(3);
            type = this.finishNode(node, "TSIndexedAccessType");
          }
        }
        return type;
      }
      tsParseTypeOperator() {
        const node = this.startNode();
        const operator = this.state.value;
        this.next();
        node.operator = operator;
        node.typeAnnotation = this.tsParseTypeOperatorOrHigher();
        if (operator === "readonly") {
          this.tsCheckTypeAnnotationForReadOnly(
            node
          );
        }
        return this.finishNode(node, "TSTypeOperator");
      }
      tsCheckTypeAnnotationForReadOnly(node) {
        switch (node.typeAnnotation.type) {
          case "TSTupleType":
          case "TSArrayType":
            return;
          default:
            this.raise(TSErrors.UnexpectedReadonly, {
              at: node
            });
        }
      }
      tsParseInferType() {
        const node = this.startNode();
        this.expectContextual(113);
        const typeParameter = this.startNode();
        typeParameter.name = this.tsParseTypeParameterName();
        typeParameter.constraint = this.tsTryParse(() => this.tsParseConstraintForInferType());
        node.typeParameter = this.finishNode(typeParameter, "TSTypeParameter");
        return this.finishNode(node, "TSInferType");
      }
      tsParseConstraintForInferType() {
        if (this.eat(81)) {
          const constraint = this.tsInDisallowConditionalTypesContext(() => this.tsParseType());
          if (this.state.inDisallowConditionalTypesContext || !this.match(17)) {
            return constraint;
          }
        }
      }
      tsParseTypeOperatorOrHigher() {
        const isTypeOperator = tokenIsTSTypeOperator(this.state.type) && !this.state.containsEsc;
        return isTypeOperator ? this.tsParseTypeOperator() : this.isContextual(113) ? this.tsParseInferType() : this.tsInAllowConditionalTypesContext(() => this.tsParseArrayTypeOrHigher());
      }
      tsParseUnionOrIntersectionType(kind, parseConstituentType, operator) {
        const node = this.startNode();
        const hasLeadingOperator = this.eat(operator);
        const types2 = [];
        do {
          types2.push(parseConstituentType());
        } while (this.eat(operator));
        if (types2.length === 1 && !hasLeadingOperator) {
          return types2[0];
        }
        node.types = types2;
        return this.finishNode(node, kind);
      }
      tsParseIntersectionTypeOrHigher() {
        return this.tsParseUnionOrIntersectionType("TSIntersectionType", this.tsParseTypeOperatorOrHigher.bind(this), 45);
      }
      tsParseUnionTypeOrHigher() {
        return this.tsParseUnionOrIntersectionType("TSUnionType", this.tsParseIntersectionTypeOrHigher.bind(this), 43);
      }
      tsIsStartOfFunctionType() {
        if (this.match(47)) {
          return true;
        }
        return this.match(10) && this.tsLookAhead(this.tsIsUnambiguouslyStartOfFunctionType.bind(this));
      }
      tsSkipParameterStart() {
        if (tokenIsIdentifier(this.state.type) || this.match(78)) {
          this.next();
          return true;
        }
        if (this.match(5)) {
          const {
            errors
          } = this.state;
          const previousErrorCount = errors.length;
          try {
            this.parseObjectLike(8, true);
            return errors.length === previousErrorCount;
          } catch (_unused) {
            return false;
          }
        }
        if (this.match(0)) {
          this.next();
          const {
            errors
          } = this.state;
          const previousErrorCount = errors.length;
          try {
            super.parseBindingList(3, 93, true);
            return errors.length === previousErrorCount;
          } catch (_unused2) {
            return false;
          }
        }
        return false;
      }
      tsIsUnambiguouslyStartOfFunctionType() {
        this.next();
        if (this.match(11) || this.match(21)) {
          return true;
        }
        if (this.tsSkipParameterStart()) {
          if (this.match(14) || this.match(12) || this.match(17) || this.match(29)) {
            return true;
          }
          if (this.match(11)) {
            this.next();
            if (this.match(19)) {
              return true;
            }
          }
        }
        return false;
      }
      tsParseTypeOrTypePredicateAnnotation(returnToken) {
        return this.tsInType(() => {
          const t3 = this.startNode();
          this.expect(returnToken);
          const node = this.startNode();
          const asserts = !!this.tsTryParse(this.tsParseTypePredicateAsserts.bind(this));
          if (asserts && this.match(78)) {
            let thisTypePredicate = this.tsParseThisTypeOrThisTypePredicate();
            if (thisTypePredicate.type === "TSThisType") {
              node.parameterName = thisTypePredicate;
              node.asserts = true;
              node.typeAnnotation = null;
              thisTypePredicate = this.finishNode(node, "TSTypePredicate");
            } else {
              this.resetStartLocationFromNode(thisTypePredicate, node);
              thisTypePredicate.asserts = true;
            }
            t3.typeAnnotation = thisTypePredicate;
            return this.finishNode(t3, "TSTypeAnnotation");
          }
          const typePredicateVariable = this.tsIsIdentifier() && this.tsTryParse(this.tsParseTypePredicatePrefix.bind(this));
          if (!typePredicateVariable) {
            if (!asserts) {
              return this.tsParseTypeAnnotation(false, t3);
            }
            node.parameterName = this.parseIdentifier();
            node.asserts = asserts;
            node.typeAnnotation = null;
            t3.typeAnnotation = this.finishNode(node, "TSTypePredicate");
            return this.finishNode(t3, "TSTypeAnnotation");
          }
          const type = this.tsParseTypeAnnotation(false);
          node.parameterName = typePredicateVariable;
          node.typeAnnotation = type;
          node.asserts = asserts;
          t3.typeAnnotation = this.finishNode(node, "TSTypePredicate");
          return this.finishNode(t3, "TSTypeAnnotation");
        });
      }
      tsTryParseTypeOrTypePredicateAnnotation() {
        return this.match(14) ? this.tsParseTypeOrTypePredicateAnnotation(14) : void 0;
      }
      tsTryParseTypeAnnotation() {
        return this.match(14) ? this.tsParseTypeAnnotation() : void 0;
      }
      tsTryParseType() {
        return this.tsEatThenParseType(14);
      }
      tsParseTypePredicatePrefix() {
        const id = this.parseIdentifier();
        if (this.isContextual(114) && !this.hasPrecedingLineBreak()) {
          this.next();
          return id;
        }
      }
      tsParseTypePredicateAsserts() {
        if (this.state.type !== 107) {
          return false;
        }
        const containsEsc = this.state.containsEsc;
        this.next();
        if (!tokenIsIdentifier(this.state.type) && !this.match(78)) {
          return false;
        }
        if (containsEsc) {
          this.raise(Errors.InvalidEscapedReservedWord, {
            at: this.state.lastTokStartLoc,
            reservedWord: "asserts"
          });
        }
        return true;
      }
      tsParseTypeAnnotation(eatColon = true, t3 = this.startNode()) {
        this.tsInType(() => {
          if (eatColon)
            this.expect(14);
          t3.typeAnnotation = this.tsParseType();
        });
        return this.finishNode(t3, "TSTypeAnnotation");
      }
      tsParseType() {
        assert(this.state.inType);
        const type = this.tsParseNonConditionalType();
        if (this.state.inDisallowConditionalTypesContext || this.hasPrecedingLineBreak() || !this.eat(81)) {
          return type;
        }
        const node = this.startNodeAtNode(type);
        node.checkType = type;
        node.extendsType = this.tsInDisallowConditionalTypesContext(() => this.tsParseNonConditionalType());
        this.expect(17);
        node.trueType = this.tsInAllowConditionalTypesContext(() => this.tsParseType());
        this.expect(14);
        node.falseType = this.tsInAllowConditionalTypesContext(() => this.tsParseType());
        return this.finishNode(node, "TSConditionalType");
      }
      isAbstractConstructorSignature() {
        return this.isContextual(122) && this.lookahead().type === 77;
      }
      tsParseNonConditionalType() {
        if (this.tsIsStartOfFunctionType()) {
          return this.tsParseFunctionOrConstructorType("TSFunctionType");
        }
        if (this.match(77)) {
          return this.tsParseFunctionOrConstructorType("TSConstructorType");
        } else if (this.isAbstractConstructorSignature()) {
          return this.tsParseFunctionOrConstructorType("TSConstructorType", true);
        }
        return this.tsParseUnionTypeOrHigher();
      }
      tsParseTypeAssertion() {
        if (this.getPluginOption("typescript", "disallowAmbiguousJSXLike")) {
          this.raise(TSErrors.ReservedTypeAssertion, {
            at: this.state.startLoc
          });
        }
        const node = this.startNode();
        node.typeAnnotation = this.tsInType(() => {
          this.next();
          return this.match(75) ? this.tsParseTypeReference() : this.tsParseType();
        });
        this.expect(48);
        node.expression = this.parseMaybeUnary();
        return this.finishNode(node, "TSTypeAssertion");
      }
      tsParseHeritageClause(token) {
        const originalStartLoc = this.state.startLoc;
        const delimitedList = this.tsParseDelimitedList("HeritageClauseElement", () => {
          const node = this.startNode();
          node.expression = this.tsParseEntityName();
          if (this.match(47)) {
            node.typeParameters = this.tsParseTypeArguments();
          }
          return this.finishNode(node, "TSExpressionWithTypeArguments");
        });
        if (!delimitedList.length) {
          this.raise(TSErrors.EmptyHeritageClauseType, {
            at: originalStartLoc,
            token
          });
        }
        return delimitedList;
      }
      tsParseInterfaceDeclaration(node, properties = {}) {
        if (this.hasFollowingLineBreak())
          return null;
        this.expectContextual(127);
        if (properties.declare)
          node.declare = true;
        if (tokenIsIdentifier(this.state.type)) {
          node.id = this.parseIdentifier();
          this.checkIdentifier(node.id, BIND_TS_INTERFACE);
        } else {
          node.id = null;
          this.raise(TSErrors.MissingInterfaceName, {
            at: this.state.startLoc
          });
        }
        node.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this));
        if (this.eat(81)) {
          node.extends = this.tsParseHeritageClause("extends");
        }
        const body = this.startNode();
        body.body = this.tsInType(this.tsParseObjectTypeMembers.bind(this));
        node.body = this.finishNode(body, "TSInterfaceBody");
        return this.finishNode(node, "TSInterfaceDeclaration");
      }
      tsParseTypeAliasDeclaration(node) {
        node.id = this.parseIdentifier();
        this.checkIdentifier(node.id, BIND_TS_TYPE);
        node.typeAnnotation = this.tsInType(() => {
          node.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this));
          this.expect(29);
          if (this.isContextual(112) && this.lookahead().type !== 16) {
            const node2 = this.startNode();
            this.next();
            return this.finishNode(node2, "TSIntrinsicKeyword");
          }
          return this.tsParseType();
        });
        this.semicolon();
        return this.finishNode(node, "TSTypeAliasDeclaration");
      }
      tsInNoContext(cb) {
        const oldContext = this.state.context;
        this.state.context = [oldContext[0]];
        try {
          return cb();
        } finally {
          this.state.context = oldContext;
        }
      }
      tsInType(cb) {
        const oldInType = this.state.inType;
        this.state.inType = true;
        try {
          return cb();
        } finally {
          this.state.inType = oldInType;
        }
      }
      tsInDisallowConditionalTypesContext(cb) {
        const oldInDisallowConditionalTypesContext = this.state.inDisallowConditionalTypesContext;
        this.state.inDisallowConditionalTypesContext = true;
        try {
          return cb();
        } finally {
          this.state.inDisallowConditionalTypesContext = oldInDisallowConditionalTypesContext;
        }
      }
      tsInAllowConditionalTypesContext(cb) {
        const oldInDisallowConditionalTypesContext = this.state.inDisallowConditionalTypesContext;
        this.state.inDisallowConditionalTypesContext = false;
        try {
          return cb();
        } finally {
          this.state.inDisallowConditionalTypesContext = oldInDisallowConditionalTypesContext;
        }
      }
      tsEatThenParseType(token) {
        return !this.match(token) ? void 0 : this.tsNextThenParseType();
      }
      tsExpectThenParseType(token) {
        return this.tsDoThenParseType(() => this.expect(token));
      }
      tsNextThenParseType() {
        return this.tsDoThenParseType(() => this.next());
      }
      tsDoThenParseType(cb) {
        return this.tsInType(() => {
          cb();
          return this.tsParseType();
        });
      }
      tsParseEnumMember() {
        const node = this.startNode();
        node.id = this.match(131) ? super.parseStringLiteral(this.state.value) : this.parseIdentifier(true);
        if (this.eat(29)) {
          node.initializer = super.parseMaybeAssignAllowIn();
        }
        return this.finishNode(node, "TSEnumMember");
      }
      tsParseEnumDeclaration(node, properties = {}) {
        if (properties.const)
          node.const = true;
        if (properties.declare)
          node.declare = true;
        this.expectContextual(124);
        node.id = this.parseIdentifier();
        this.checkIdentifier(node.id, node.const ? BIND_TS_CONST_ENUM : BIND_TS_ENUM);
        this.expect(5);
        node.members = this.tsParseDelimitedList("EnumMembers", this.tsParseEnumMember.bind(this));
        this.expect(8);
        return this.finishNode(node, "TSEnumDeclaration");
      }
      tsParseModuleBlock() {
        const node = this.startNode();
        this.scope.enter(SCOPE_OTHER);
        this.expect(5);
        super.parseBlockOrModuleBlockBody(node.body = [], void 0, true, 8);
        this.scope.exit();
        return this.finishNode(node, "TSModuleBlock");
      }
      tsParseModuleOrNamespaceDeclaration(node, nested = false) {
        node.id = this.parseIdentifier();
        if (!nested) {
          this.checkIdentifier(node.id, BIND_TS_NAMESPACE);
        }
        if (this.eat(16)) {
          const inner = this.startNode();
          this.tsParseModuleOrNamespaceDeclaration(inner, true);
          node.body = inner;
        } else {
          this.scope.enter(SCOPE_TS_MODULE);
          this.prodParam.enter(PARAM);
          node.body = this.tsParseModuleBlock();
          this.prodParam.exit();
          this.scope.exit();
        }
        return this.finishNode(node, "TSModuleDeclaration");
      }
      tsParseAmbientExternalModuleDeclaration(node) {
        if (this.isContextual(110)) {
          node.global = true;
          node.id = this.parseIdentifier();
        } else if (this.match(131)) {
          node.id = super.parseStringLiteral(this.state.value);
        } else {
          this.unexpected();
        }
        if (this.match(5)) {
          this.scope.enter(SCOPE_TS_MODULE);
          this.prodParam.enter(PARAM);
          node.body = this.tsParseModuleBlock();
          this.prodParam.exit();
          this.scope.exit();
        } else {
          this.semicolon();
        }
        return this.finishNode(node, "TSModuleDeclaration");
      }
      tsParseImportEqualsDeclaration(node, isExport) {
        node.isExport = isExport || false;
        node.id = this.parseIdentifier();
        this.checkIdentifier(node.id, BIND_FLAGS_TS_IMPORT);
        this.expect(29);
        const moduleReference = this.tsParseModuleReference();
        if (node.importKind === "type" && moduleReference.type !== "TSExternalModuleReference") {
          this.raise(TSErrors.ImportAliasHasImportType, {
            at: moduleReference
          });
        }
        node.moduleReference = moduleReference;
        this.semicolon();
        return this.finishNode(node, "TSImportEqualsDeclaration");
      }
      tsIsExternalModuleReference() {
        return this.isContextual(117) && this.lookaheadCharCode() === 40;
      }
      tsParseModuleReference() {
        return this.tsIsExternalModuleReference() ? this.tsParseExternalModuleReference() : this.tsParseEntityName(false);
      }
      tsParseExternalModuleReference() {
        const node = this.startNode();
        this.expectContextual(117);
        this.expect(10);
        if (!this.match(131)) {
          throw this.unexpected();
        }
        node.expression = super.parseExprAtom();
        this.expect(11);
        return this.finishNode(node, "TSExternalModuleReference");
      }
      tsLookAhead(f) {
        const state = this.state.clone();
        const res = f();
        this.state = state;
        return res;
      }
      tsTryParseAndCatch(f) {
        const result = this.tryParse((abort) => f() || abort());
        if (result.aborted || !result.node)
          return void 0;
        if (result.error)
          this.state = result.failState;
        return result.node;
      }
      tsTryParse(f) {
        const state = this.state.clone();
        const result = f();
        if (result !== void 0 && result !== false) {
          return result;
        } else {
          this.state = state;
          return void 0;
        }
      }
      tsTryParseDeclare(nany) {
        if (this.isLineTerminator()) {
          return;
        }
        let starttype = this.state.type;
        let kind;
        if (this.isContextual(99)) {
          starttype = 74;
          kind = "let";
        }
        return this.tsInAmbientContext(() => {
          if (starttype === 68) {
            nany.declare = true;
            return super.parseFunctionStatement(nany, false, false);
          }
          if (starttype === 80) {
            nany.declare = true;
            return this.parseClass(nany, true, false);
          }
          if (starttype === 124) {
            return this.tsParseEnumDeclaration(nany, {
              declare: true
            });
          }
          if (starttype === 110) {
            return this.tsParseAmbientExternalModuleDeclaration(nany);
          }
          if (starttype === 75 || starttype === 74) {
            if (!this.match(75) || !this.isLookaheadContextual("enum")) {
              nany.declare = true;
              return this.parseVarStatement(nany, kind || this.state.value, true);
            }
            this.expect(75);
            return this.tsParseEnumDeclaration(nany, {
              const: true,
              declare: true
            });
          }
          if (starttype === 127) {
            const result = this.tsParseInterfaceDeclaration(nany, {
              declare: true
            });
            if (result)
              return result;
          }
          if (tokenIsIdentifier(starttype)) {
            return this.tsParseDeclaration(nany, this.state.value, true, null);
          }
        });
      }
      tsTryParseExportDeclaration() {
        return this.tsParseDeclaration(this.startNode(), this.state.value, true, null);
      }
      tsParseExpressionStatement(node, expr, decorators) {
        switch (expr.name) {
          case "declare": {
            const declaration = this.tsTryParseDeclare(node);
            if (declaration) {
              declaration.declare = true;
              return declaration;
            }
            break;
          }
          case "global":
            if (this.match(5)) {
              this.scope.enter(SCOPE_TS_MODULE);
              this.prodParam.enter(PARAM);
              const mod = node;
              mod.global = true;
              mod.id = expr;
              mod.body = this.tsParseModuleBlock();
              this.scope.exit();
              this.prodParam.exit();
              return this.finishNode(mod, "TSModuleDeclaration");
            }
            break;
          default:
            return this.tsParseDeclaration(node, expr.name, false, decorators);
        }
      }
      tsParseDeclaration(node, value2, next, decorators) {
        switch (value2) {
          case "abstract":
            if (this.tsCheckLineTerminator(next) && (this.match(80) || tokenIsIdentifier(this.state.type))) {
              return this.tsParseAbstractDeclaration(node, decorators);
            }
            break;
          case "module":
            if (this.tsCheckLineTerminator(next)) {
              if (this.match(131)) {
                return this.tsParseAmbientExternalModuleDeclaration(node);
              } else if (tokenIsIdentifier(this.state.type)) {
                return this.tsParseModuleOrNamespaceDeclaration(node);
              }
            }
            break;
          case "namespace":
            if (this.tsCheckLineTerminator(next) && tokenIsIdentifier(this.state.type)) {
              return this.tsParseModuleOrNamespaceDeclaration(node);
            }
            break;
          case "type":
            if (this.tsCheckLineTerminator(next) && tokenIsIdentifier(this.state.type)) {
              return this.tsParseTypeAliasDeclaration(node);
            }
            break;
        }
      }
      tsCheckLineTerminator(next) {
        if (next) {
          if (this.hasFollowingLineBreak())
            return false;
          this.next();
          return true;
        }
        return !this.isLineTerminator();
      }
      tsTryParseGenericAsyncArrowFunction(startLoc) {
        if (!this.match(47)) {
          return void 0;
        }
        const oldMaybeInArrowParameters = this.state.maybeInArrowParameters;
        this.state.maybeInArrowParameters = true;
        const res = this.tsTryParseAndCatch(() => {
          const node = this.startNodeAt(startLoc);
          node.typeParameters = this.tsParseTypeParameters();
          super.parseFunctionParams(node);
          node.returnType = this.tsTryParseTypeOrTypePredicateAnnotation();
          this.expect(19);
          return node;
        });
        this.state.maybeInArrowParameters = oldMaybeInArrowParameters;
        if (!res) {
          return void 0;
        }
        return super.parseArrowExpression(res, null, true);
      }
      tsParseTypeArgumentsInExpression() {
        if (this.reScan_lt() !== 47) {
          return void 0;
        }
        return this.tsParseTypeArguments();
      }
      tsParseTypeArguments() {
        const node = this.startNode();
        node.params = this.tsInType(() => this.tsInNoContext(() => {
          this.expect(47);
          return this.tsParseDelimitedList("TypeParametersOrArguments", this.tsParseType.bind(this));
        }));
        if (node.params.length === 0) {
          this.raise(TSErrors.EmptyTypeArguments, {
            at: node
          });
        }
        this.expect(48);
        return this.finishNode(node, "TSTypeParameterInstantiation");
      }
      tsIsDeclarationStart() {
        return tokenIsTSDeclarationStart(this.state.type);
      }
      isExportDefaultSpecifier() {
        if (this.tsIsDeclarationStart())
          return false;
        return super.isExportDefaultSpecifier();
      }
      parseAssignableListItem(allowModifiers, decorators) {
        const startLoc = this.state.startLoc;
        let accessibility;
        let readonly = false;
        let override = false;
        if (allowModifiers !== void 0) {
          const modified = {};
          this.tsParseModifiers({
            modified,
            allowedModifiers: ["public", "private", "protected", "override", "readonly"]
          });
          accessibility = modified.accessibility;
          override = modified.override;
          readonly = modified.readonly;
          if (allowModifiers === false && (accessibility || readonly || override)) {
            this.raise(TSErrors.UnexpectedParameterModifier, {
              at: startLoc
            });
          }
        }
        const left = this.parseMaybeDefault();
        this.parseAssignableListItemTypes(left);
        const elt = this.parseMaybeDefault(left.loc.start, left);
        if (accessibility || readonly || override) {
          const pp = this.startNodeAt(startLoc);
          if (decorators.length) {
            pp.decorators = decorators;
          }
          if (accessibility)
            pp.accessibility = accessibility;
          if (readonly)
            pp.readonly = readonly;
          if (override)
            pp.override = override;
          if (elt.type !== "Identifier" && elt.type !== "AssignmentPattern") {
            this.raise(TSErrors.UnsupportedParameterPropertyKind, {
              at: pp
            });
          }
          pp.parameter = elt;
          return this.finishNode(pp, "TSParameterProperty");
        }
        if (decorators.length) {
          left.decorators = decorators;
        }
        return elt;
      }
      isSimpleParameter(node) {
        return node.type === "TSParameterProperty" && super.isSimpleParameter(node.parameter) || super.isSimpleParameter(node);
      }
      parseFunctionBodyAndFinish(node, type, isMethod = false) {
        if (this.match(14)) {
          node.returnType = this.tsParseTypeOrTypePredicateAnnotation(14);
        }
        const bodilessType = type === "FunctionDeclaration" ? "TSDeclareFunction" : type === "ClassMethod" || type === "ClassPrivateMethod" ? "TSDeclareMethod" : void 0;
        if (bodilessType && !this.match(5) && this.isLineTerminator()) {
          return this.finishNode(node, bodilessType);
        }
        if (bodilessType === "TSDeclareFunction" && this.state.isAmbientContext) {
          this.raise(TSErrors.DeclareFunctionHasImplementation, {
            at: node
          });
          if (node.declare) {
            return super.parseFunctionBodyAndFinish(node, bodilessType, isMethod);
          }
        }
        return super.parseFunctionBodyAndFinish(node, type, isMethod);
      }
      registerFunctionStatementId(node) {
        if (!node.body && node.id) {
          this.checkIdentifier(node.id, BIND_TS_AMBIENT);
        } else {
          super.registerFunctionStatementId(node);
        }
      }
      tsCheckForInvalidTypeCasts(items) {
        items.forEach((node) => {
          if ((node == null ? void 0 : node.type) === "TSTypeCastExpression") {
            this.raise(TSErrors.UnexpectedTypeAnnotation, {
              at: node.typeAnnotation
            });
          }
        });
      }
      toReferencedList(exprList, isInParens) {
        this.tsCheckForInvalidTypeCasts(exprList);
        return exprList;
      }
      parseArrayLike(close, canBePattern, isTuple, refExpressionErrors) {
        const node = super.parseArrayLike(close, canBePattern, isTuple, refExpressionErrors);
        if (node.type === "ArrayExpression") {
          this.tsCheckForInvalidTypeCasts(node.elements);
        }
        return node;
      }
      parseSubscript(base, startLoc, noCalls, state) {
        if (!this.hasPrecedingLineBreak() && this.match(35)) {
          this.state.canStartJSXElement = false;
          this.next();
          const nonNullExpression = this.startNodeAt(startLoc);
          nonNullExpression.expression = base;
          return this.finishNode(nonNullExpression, "TSNonNullExpression");
        }
        let isOptionalCall = false;
        if (this.match(18) && this.lookaheadCharCode() === 60) {
          if (noCalls) {
            state.stop = true;
            return base;
          }
          state.optionalChainMember = isOptionalCall = true;
          this.next();
        }
        if (this.match(47) || this.match(51)) {
          let missingParenErrorLoc;
          const result = this.tsTryParseAndCatch(() => {
            if (!noCalls && this.atPossibleAsyncArrow(base)) {
              const asyncArrowFn = this.tsTryParseGenericAsyncArrowFunction(startLoc);
              if (asyncArrowFn) {
                return asyncArrowFn;
              }
            }
            const typeArguments = this.tsParseTypeArgumentsInExpression();
            if (!typeArguments)
              return;
            if (isOptionalCall && !this.match(10)) {
              missingParenErrorLoc = this.state.curPosition();
              return;
            }
            if (tokenIsTemplate(this.state.type)) {
              const result2 = super.parseTaggedTemplateExpression(base, startLoc, state);
              result2.typeParameters = typeArguments;
              return result2;
            }
            if (!noCalls && this.eat(10)) {
              const node2 = this.startNodeAt(startLoc);
              node2.callee = base;
              node2.arguments = this.parseCallExpressionArguments(11, false);
              this.tsCheckForInvalidTypeCasts(node2.arguments);
              node2.typeParameters = typeArguments;
              if (state.optionalChainMember) {
                node2.optional = isOptionalCall;
              }
              return this.finishCallExpression(node2, state.optionalChainMember);
            }
            const tokenType = this.state.type;
            if (tokenType === 48 || tokenType === 52 || tokenType !== 10 && tokenCanStartExpression(tokenType) && !this.hasPrecedingLineBreak()) {
              return;
            }
            const node = this.startNodeAt(startLoc);
            node.expression = base;
            node.typeParameters = typeArguments;
            return this.finishNode(node, "TSInstantiationExpression");
          });
          if (missingParenErrorLoc) {
            this.unexpected(missingParenErrorLoc, 10);
          }
          if (result) {
            if (result.type === "TSInstantiationExpression" && (this.match(16) || this.match(18) && this.lookaheadCharCode() !== 40)) {
              this.raise(TSErrors.InvalidPropertyAccessAfterInstantiationExpression, {
                at: this.state.startLoc
              });
            }
            return result;
          }
        }
        return super.parseSubscript(base, startLoc, noCalls, state);
      }
      parseNewCallee(node) {
        var _callee$extra;
        super.parseNewCallee(node);
        const {
          callee
        } = node;
        if (callee.type === "TSInstantiationExpression" && !((_callee$extra = callee.extra) != null && _callee$extra.parenthesized)) {
          node.typeParameters = callee.typeParameters;
          node.callee = callee.expression;
        }
      }
      parseExprOp(left, leftStartLoc, minPrec) {
        let isSatisfies;
        if (tokenOperatorPrecedence(58) > minPrec && !this.hasPrecedingLineBreak() && (this.isContextual(93) || (isSatisfies = this.isContextual(118)))) {
          const node = this.startNodeAt(leftStartLoc);
          node.expression = left;
          node.typeAnnotation = this.tsInType(() => {
            this.next();
            if (this.match(75)) {
              if (isSatisfies) {
                this.raise(Errors.UnexpectedKeyword, {
                  at: this.state.startLoc,
                  keyword: "const"
                });
              }
              return this.tsParseTypeReference();
            }
            return this.tsParseType();
          });
          this.finishNode(node, isSatisfies ? "TSSatisfiesExpression" : "TSAsExpression");
          this.reScan_lt_gt();
          return this.parseExprOp(
            node,
            leftStartLoc,
            minPrec
          );
        }
        return super.parseExprOp(left, leftStartLoc, minPrec);
      }
      checkReservedWord(word, startLoc, checkKeywords, isBinding) {
        if (!this.state.isAmbientContext) {
          super.checkReservedWord(word, startLoc, checkKeywords, isBinding);
        }
      }
      checkImportReflection(node) {
        super.checkImportReflection(node);
        if (node.module && node.importKind !== "value") {
          this.raise(TSErrors.ImportReflectionHasImportType, {
            at: node.specifiers[0].loc.start
          });
        }
      }
      checkDuplicateExports() {
      }
      parseImport(node) {
        node.importKind = "value";
        if (tokenIsIdentifier(this.state.type) || this.match(55) || this.match(5)) {
          let ahead = this.lookahead();
          if (this.isContextual(128) && ahead.type !== 12 && ahead.type !== 97 && ahead.type !== 29) {
            node.importKind = "type";
            this.next();
            ahead = this.lookahead();
          }
          if (tokenIsIdentifier(this.state.type) && ahead.type === 29) {
            return this.tsParseImportEqualsDeclaration(node);
          }
        }
        const importNode = super.parseImport(node);
        if (importNode.importKind === "type" && importNode.specifiers.length > 1 && importNode.specifiers[0].type === "ImportDefaultSpecifier") {
          this.raise(TSErrors.TypeImportCannotSpecifyDefaultAndNamed, {
            at: importNode
          });
        }
        return importNode;
      }
      parseExport(node, decorators) {
        if (this.match(83)) {
          this.next();
          if (this.isContextual(128) && this.lookaheadCharCode() !== 61) {
            node.importKind = "type";
            this.next();
          } else {
            node.importKind = "value";
          }
          return this.tsParseImportEqualsDeclaration(node, true);
        } else if (this.eat(29)) {
          const assign = node;
          assign.expression = super.parseExpression();
          this.semicolon();
          return this.finishNode(assign, "TSExportAssignment");
        } else if (this.eatContextual(93)) {
          const decl = node;
          this.expectContextual(126);
          decl.id = this.parseIdentifier();
          this.semicolon();
          return this.finishNode(decl, "TSNamespaceExportDeclaration");
        } else {
          if (this.isContextual(128) && this.lookahead().type === 5) {
            this.next();
            node.exportKind = "type";
          } else {
            node.exportKind = "value";
          }
          return super.parseExport(node, decorators);
        }
      }
      isAbstractClass() {
        return this.isContextual(122) && this.lookahead().type === 80;
      }
      parseExportDefaultExpression() {
        if (this.isAbstractClass()) {
          const cls = this.startNode();
          this.next();
          cls.abstract = true;
          return this.parseClass(cls, true, true);
        }
        if (this.match(127)) {
          const result = this.tsParseInterfaceDeclaration(this.startNode());
          if (result)
            return result;
        }
        return super.parseExportDefaultExpression();
      }
      parseVarStatement(node, kind, allowMissingInitializer = false) {
        const {
          isAmbientContext
        } = this.state;
        const declaration = super.parseVarStatement(node, kind, allowMissingInitializer || isAmbientContext);
        if (!isAmbientContext)
          return declaration;
        for (const {
          id,
          init
        } of declaration.declarations) {
          if (!init)
            continue;
          if (kind !== "const" || !!id.typeAnnotation) {
            this.raise(TSErrors.InitializerNotAllowedInAmbientContext, {
              at: init
            });
          } else if (init.type !== "StringLiteral" && init.type !== "BooleanLiteral" && init.type !== "NumericLiteral" && init.type !== "BigIntLiteral" && (init.type !== "TemplateLiteral" || init.expressions.length > 0) && !isPossiblyLiteralEnum(init)) {
            this.raise(TSErrors.ConstInitiailizerMustBeStringOrNumericLiteralOrLiteralEnumReference, {
              at: init
            });
          }
        }
        return declaration;
      }
      parseStatementContent(flags, decorators) {
        if (this.match(75) && this.isLookaheadContextual("enum")) {
          const node = this.startNode();
          this.expect(75);
          return this.tsParseEnumDeclaration(node, {
            const: true
          });
        }
        if (this.isContextual(124)) {
          return this.tsParseEnumDeclaration(this.startNode());
        }
        if (this.isContextual(127)) {
          const result = this.tsParseInterfaceDeclaration(this.startNode());
          if (result)
            return result;
        }
        return super.parseStatementContent(flags, decorators);
      }
      parseAccessModifier() {
        return this.tsParseModifier(["public", "protected", "private"]);
      }
      tsHasSomeModifiers(member, modifiers) {
        return modifiers.some((modifier) => {
          if (tsIsAccessModifier(modifier)) {
            return member.accessibility === modifier;
          }
          return !!member[modifier];
        });
      }
      tsIsStartOfStaticBlocks() {
        return this.isContextual(104) && this.lookaheadCharCode() === 123;
      }
      parseClassMember(classBody, member, state) {
        const modifiers = ["declare", "private", "public", "protected", "override", "abstract", "readonly", "static"];
        this.tsParseModifiers({
          modified: member,
          allowedModifiers: modifiers,
          disallowedModifiers: ["in", "out"],
          stopOnStartOfClassStaticBlock: true,
          errorTemplate: TSErrors.InvalidModifierOnTypeParameterPositions
        });
        const callParseClassMemberWithIsStatic = () => {
          if (this.tsIsStartOfStaticBlocks()) {
            this.next();
            this.next();
            if (this.tsHasSomeModifiers(member, modifiers)) {
              this.raise(TSErrors.StaticBlockCannotHaveModifier, {
                at: this.state.curPosition()
              });
            }
            super.parseClassStaticBlock(classBody, member);
          } else {
            this.parseClassMemberWithIsStatic(classBody, member, state, !!member.static);
          }
        };
        if (member.declare) {
          this.tsInAmbientContext(callParseClassMemberWithIsStatic);
        } else {
          callParseClassMemberWithIsStatic();
        }
      }
      parseClassMemberWithIsStatic(classBody, member, state, isStatic) {
        const idx = this.tsTryParseIndexSignature(member);
        if (idx) {
          classBody.body.push(idx);
          if (member.abstract) {
            this.raise(TSErrors.IndexSignatureHasAbstract, {
              at: member
            });
          }
          if (member.accessibility) {
            this.raise(TSErrors.IndexSignatureHasAccessibility, {
              at: member,
              modifier: member.accessibility
            });
          }
          if (member.declare) {
            this.raise(TSErrors.IndexSignatureHasDeclare, {
              at: member
            });
          }
          if (member.override) {
            this.raise(TSErrors.IndexSignatureHasOverride, {
              at: member
            });
          }
          return;
        }
        if (!this.state.inAbstractClass && member.abstract) {
          this.raise(TSErrors.NonAbstractClassHasAbstractMethod, {
            at: member
          });
        }
        if (member.override) {
          if (!state.hadSuperClass) {
            this.raise(TSErrors.OverrideNotInSubClass, {
              at: member
            });
          }
        }
        super.parseClassMemberWithIsStatic(classBody, member, state, isStatic);
      }
      parsePostMemberNameModifiers(methodOrProp) {
        const optional = this.eat(17);
        if (optional)
          methodOrProp.optional = true;
        if (methodOrProp.readonly && this.match(10)) {
          this.raise(TSErrors.ClassMethodHasReadonly, {
            at: methodOrProp
          });
        }
        if (methodOrProp.declare && this.match(10)) {
          this.raise(TSErrors.ClassMethodHasDeclare, {
            at: methodOrProp
          });
        }
      }
      parseExpressionStatement(node, expr, decorators) {
        const decl = expr.type === "Identifier" ? this.tsParseExpressionStatement(node, expr, decorators) : void 0;
        return decl || super.parseExpressionStatement(node, expr, decorators);
      }
      shouldParseExportDeclaration() {
        if (this.tsIsDeclarationStart())
          return true;
        return super.shouldParseExportDeclaration();
      }
      parseConditional(expr, startLoc, refExpressionErrors) {
        if (!this.state.maybeInArrowParameters || !this.match(17)) {
          return super.parseConditional(expr, startLoc, refExpressionErrors);
        }
        const result = this.tryParse(() => super.parseConditional(expr, startLoc));
        if (!result.node) {
          if (result.error) {
            super.setOptionalParametersError(refExpressionErrors, result.error);
          }
          return expr;
        }
        if (result.error)
          this.state = result.failState;
        return result.node;
      }
      parseParenItem(node, startLoc) {
        node = super.parseParenItem(node, startLoc);
        if (this.eat(17)) {
          node.optional = true;
          this.resetEndLocation(node);
        }
        if (this.match(14)) {
          const typeCastNode = this.startNodeAt(startLoc);
          typeCastNode.expression = node;
          typeCastNode.typeAnnotation = this.tsParseTypeAnnotation();
          return this.finishNode(typeCastNode, "TSTypeCastExpression");
        }
        return node;
      }
      parseExportDeclaration(node) {
        if (!this.state.isAmbientContext && this.isContextual(123)) {
          return this.tsInAmbientContext(() => this.parseExportDeclaration(node));
        }
        const startLoc = this.state.startLoc;
        const isDeclare = this.eatContextual(123);
        if (isDeclare && (this.isContextual(123) || !this.shouldParseExportDeclaration())) {
          throw this.raise(TSErrors.ExpectedAmbientAfterExportDeclare, {
            at: this.state.startLoc
          });
        }
        const isIdentifier2 = tokenIsIdentifier(this.state.type);
        const declaration = isIdentifier2 && this.tsTryParseExportDeclaration() || super.parseExportDeclaration(node);
        if (!declaration)
          return null;
        if (declaration.type === "TSInterfaceDeclaration" || declaration.type === "TSTypeAliasDeclaration" || isDeclare) {
          node.exportKind = "type";
        }
        if (isDeclare) {
          this.resetStartLocation(declaration, startLoc);
          declaration.declare = true;
        }
        return declaration;
      }
      parseClassId(node, isStatement, optionalId, bindingType) {
        if ((!isStatement || optionalId) && this.isContextual(111)) {
          return;
        }
        super.parseClassId(node, isStatement, optionalId, node.declare ? BIND_TS_AMBIENT : BIND_CLASS);
        const typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this));
        if (typeParameters)
          node.typeParameters = typeParameters;
      }
      parseClassPropertyAnnotation(node) {
        if (!node.optional) {
          if (this.eat(35)) {
            node.definite = true;
          } else if (this.eat(17)) {
            node.optional = true;
          }
        }
        const type = this.tsTryParseTypeAnnotation();
        if (type)
          node.typeAnnotation = type;
      }
      parseClassProperty(node) {
        this.parseClassPropertyAnnotation(node);
        if (this.state.isAmbientContext && !(node.readonly && !node.typeAnnotation) && this.match(29)) {
          this.raise(TSErrors.DeclareClassFieldHasInitializer, {
            at: this.state.startLoc
          });
        }
        if (node.abstract && this.match(29)) {
          const {
            key
          } = node;
          this.raise(TSErrors.AbstractPropertyHasInitializer, {
            at: this.state.startLoc,
            propertyName: key.type === "Identifier" && !node.computed ? key.name : `[${this.input.slice(key.start, key.end)}]`
          });
        }
        return super.parseClassProperty(node);
      }
      parseClassPrivateProperty(node) {
        if (node.abstract) {
          this.raise(TSErrors.PrivateElementHasAbstract, {
            at: node
          });
        }
        if (node.accessibility) {
          this.raise(TSErrors.PrivateElementHasAccessibility, {
            at: node,
            modifier: node.accessibility
          });
        }
        this.parseClassPropertyAnnotation(node);
        return super.parseClassPrivateProperty(node);
      }
      parseClassAccessorProperty(node) {
        this.parseClassPropertyAnnotation(node);
        if (node.optional) {
          this.raise(TSErrors.AccessorCannotBeOptional, {
            at: node
          });
        }
        return super.parseClassAccessorProperty(node);
      }
      pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper) {
        const typeParameters = this.tsTryParseTypeParameters();
        if (typeParameters && isConstructor) {
          this.raise(TSErrors.ConstructorHasTypeParameters, {
            at: typeParameters
          });
        }
        const {
          declare = false,
          kind
        } = method;
        if (declare && (kind === "get" || kind === "set")) {
          this.raise(TSErrors.DeclareAccessor, {
            at: method,
            kind
          });
        }
        if (typeParameters)
          method.typeParameters = typeParameters;
        super.pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper);
      }
      pushClassPrivateMethod(classBody, method, isGenerator, isAsync) {
        const typeParameters = this.tsTryParseTypeParameters();
        if (typeParameters)
          method.typeParameters = typeParameters;
        super.pushClassPrivateMethod(classBody, method, isGenerator, isAsync);
      }
      declareClassPrivateMethodInScope(node, kind) {
        if (node.type === "TSDeclareMethod")
          return;
        if (node.type === "MethodDefinition" && !node.value.body)
          return;
        super.declareClassPrivateMethodInScope(node, kind);
      }
      parseClassSuper(node) {
        super.parseClassSuper(node);
        if (node.superClass && (this.match(47) || this.match(51))) {
          node.superTypeParameters = this.tsParseTypeArgumentsInExpression();
        }
        if (this.eatContextual(111)) {
          node.implements = this.tsParseHeritageClause("implements");
        }
      }
      parseObjPropValue(prop, startLoc, isGenerator, isAsync, isPattern, isAccessor, refExpressionErrors) {
        const typeParameters = this.tsTryParseTypeParameters();
        if (typeParameters)
          prop.typeParameters = typeParameters;
        return super.parseObjPropValue(prop, startLoc, isGenerator, isAsync, isPattern, isAccessor, refExpressionErrors);
      }
      parseFunctionParams(node, allowModifiers) {
        const typeParameters = this.tsTryParseTypeParameters();
        if (typeParameters)
          node.typeParameters = typeParameters;
        super.parseFunctionParams(node, allowModifiers);
      }
      parseVarId(decl, kind) {
        super.parseVarId(decl, kind);
        if (decl.id.type === "Identifier" && !this.hasPrecedingLineBreak() && this.eat(35)) {
          decl.definite = true;
        }
        const type = this.tsTryParseTypeAnnotation();
        if (type) {
          decl.id.typeAnnotation = type;
          this.resetEndLocation(decl.id);
        }
      }
      parseAsyncArrowFromCallExpression(node, call) {
        if (this.match(14)) {
          node.returnType = this.tsParseTypeAnnotation();
        }
        return super.parseAsyncArrowFromCallExpression(node, call);
      }
      parseMaybeAssign(refExpressionErrors, afterLeftParse) {
        var _jsx, _jsx2, _typeCast, _jsx3, _typeCast2, _jsx4, _typeCast3;
        let state;
        let jsx2;
        let typeCast;
        if (this.hasPlugin("jsx") && (this.match(140) || this.match(47))) {
          state = this.state.clone();
          jsx2 = this.tryParse(() => super.parseMaybeAssign(refExpressionErrors, afterLeftParse), state);
          if (!jsx2.error)
            return jsx2.node;
          const {
            context
          } = this.state;
          const currentContext = context[context.length - 1];
          if (currentContext === types.j_oTag || currentContext === types.j_expr) {
            context.pop();
          }
        }
        if (!((_jsx = jsx2) != null && _jsx.error) && !this.match(47)) {
          return super.parseMaybeAssign(refExpressionErrors, afterLeftParse);
        }
        if (!state || state === this.state)
          state = this.state.clone();
        let typeParameters;
        const arrow = this.tryParse((abort) => {
          var _expr$extra, _typeParameters;
          typeParameters = this.tsParseTypeParameters();
          const expr = super.parseMaybeAssign(refExpressionErrors, afterLeftParse);
          if (expr.type !== "ArrowFunctionExpression" || (_expr$extra = expr.extra) != null && _expr$extra.parenthesized) {
            abort();
          }
          if (((_typeParameters = typeParameters) == null ? void 0 : _typeParameters.params.length) !== 0) {
            this.resetStartLocationFromNode(expr, typeParameters);
          }
          expr.typeParameters = typeParameters;
          return expr;
        }, state);
        if (!arrow.error && !arrow.aborted) {
          if (typeParameters)
            this.reportReservedArrowTypeParam(typeParameters);
          return arrow.node;
        }
        if (!jsx2) {
          assert(!this.hasPlugin("jsx"));
          typeCast = this.tryParse(() => super.parseMaybeAssign(refExpressionErrors, afterLeftParse), state);
          if (!typeCast.error)
            return typeCast.node;
        }
        if ((_jsx2 = jsx2) != null && _jsx2.node) {
          this.state = jsx2.failState;
          return jsx2.node;
        }
        if (arrow.node) {
          this.state = arrow.failState;
          if (typeParameters)
            this.reportReservedArrowTypeParam(typeParameters);
          return arrow.node;
        }
        if ((_typeCast = typeCast) != null && _typeCast.node) {
          this.state = typeCast.failState;
          return typeCast.node;
        }
        if ((_jsx3 = jsx2) != null && _jsx3.thrown)
          throw jsx2.error;
        if (arrow.thrown)
          throw arrow.error;
        if ((_typeCast2 = typeCast) != null && _typeCast2.thrown)
          throw typeCast.error;
        throw ((_jsx4 = jsx2) == null ? void 0 : _jsx4.error) || arrow.error || ((_typeCast3 = typeCast) == null ? void 0 : _typeCast3.error);
      }
      reportReservedArrowTypeParam(node) {
        var _node$extra;
        if (node.params.length === 1 && !((_node$extra = node.extra) != null && _node$extra.trailingComma) && this.getPluginOption("typescript", "disallowAmbiguousJSXLike")) {
          this.raise(TSErrors.ReservedArrowTypeParam, {
            at: node
          });
        }
      }
      parseMaybeUnary(refExpressionErrors, sawUnary) {
        if (!this.hasPlugin("jsx") && this.match(47)) {
          return this.tsParseTypeAssertion();
        } else {
          return super.parseMaybeUnary(refExpressionErrors, sawUnary);
        }
      }
      parseArrow(node) {
        if (this.match(14)) {
          const result = this.tryParse((abort) => {
            const returnType = this.tsParseTypeOrTypePredicateAnnotation(14);
            if (this.canInsertSemicolon() || !this.match(19))
              abort();
            return returnType;
          });
          if (result.aborted)
            return;
          if (!result.thrown) {
            if (result.error)
              this.state = result.failState;
            node.returnType = result.node;
          }
        }
        return super.parseArrow(node);
      }
      parseAssignableListItemTypes(param) {
        if (this.eat(17)) {
          if (param.type !== "Identifier" && !this.state.isAmbientContext && !this.state.inType) {
            this.raise(TSErrors.PatternIsOptional, {
              at: param
            });
          }
          param.optional = true;
        }
        const type = this.tsTryParseTypeAnnotation();
        if (type)
          param.typeAnnotation = type;
        this.resetEndLocation(param);
        return param;
      }
      isAssignable(node, isBinding) {
        switch (node.type) {
          case "TSTypeCastExpression":
            return this.isAssignable(node.expression, isBinding);
          case "TSParameterProperty":
            return true;
          default:
            return super.isAssignable(node, isBinding);
        }
      }
      toAssignable(node, isLHS = false) {
        switch (node.type) {
          case "ParenthesizedExpression":
            this.toAssignableParenthesizedExpression(node, isLHS);
            break;
          case "TSAsExpression":
          case "TSSatisfiesExpression":
          case "TSNonNullExpression":
          case "TSTypeAssertion":
            if (isLHS) {
              this.expressionScope.recordArrowParameterBindingError(TSErrors.UnexpectedTypeCastInParameter, {
                at: node
              });
            } else {
              this.raise(TSErrors.UnexpectedTypeCastInParameter, {
                at: node
              });
            }
            this.toAssignable(node.expression, isLHS);
            break;
          case "AssignmentExpression":
            if (!isLHS && node.left.type === "TSTypeCastExpression") {
              node.left = this.typeCastToParameter(node.left);
            }
          default:
            super.toAssignable(node, isLHS);
        }
      }
      toAssignableParenthesizedExpression(node, isLHS) {
        switch (node.expression.type) {
          case "TSAsExpression":
          case "TSSatisfiesExpression":
          case "TSNonNullExpression":
          case "TSTypeAssertion":
          case "ParenthesizedExpression":
            this.toAssignable(node.expression, isLHS);
            break;
          default:
            super.toAssignable(node, isLHS);
        }
      }
      checkToRestConversion(node, allowPattern) {
        switch (node.type) {
          case "TSAsExpression":
          case "TSSatisfiesExpression":
          case "TSTypeAssertion":
          case "TSNonNullExpression":
            this.checkToRestConversion(node.expression, false);
            break;
          default:
            super.checkToRestConversion(node, allowPattern);
        }
      }
      isValidLVal(type, isUnparenthesizedInAssign, binding) {
        return getOwn$1({
          TSTypeCastExpression: true,
          TSParameterProperty: "parameter",
          TSNonNullExpression: "expression",
          TSAsExpression: (binding !== BIND_NONE || !isUnparenthesizedInAssign) && ["expression", true],
          TSSatisfiesExpression: (binding !== BIND_NONE || !isUnparenthesizedInAssign) && ["expression", true],
          TSTypeAssertion: (binding !== BIND_NONE || !isUnparenthesizedInAssign) && ["expression", true]
        }, type) || super.isValidLVal(type, isUnparenthesizedInAssign, binding);
      }
      parseBindingAtom() {
        switch (this.state.type) {
          case 78:
            return this.parseIdentifier(true);
          default:
            return super.parseBindingAtom();
        }
      }
      parseMaybeDecoratorArguments(expr) {
        if (this.match(47) || this.match(51)) {
          const typeArguments = this.tsParseTypeArgumentsInExpression();
          if (this.match(10)) {
            const call = super.parseMaybeDecoratorArguments(expr);
            call.typeParameters = typeArguments;
            return call;
          }
          this.unexpected(null, 10);
        }
        return super.parseMaybeDecoratorArguments(expr);
      }
      checkCommaAfterRest(close) {
        if (this.state.isAmbientContext && this.match(12) && this.lookaheadCharCode() === close) {
          this.next();
          return false;
        } else {
          return super.checkCommaAfterRest(close);
        }
      }
      isClassMethod() {
        return this.match(47) || super.isClassMethod();
      }
      isClassProperty() {
        return this.match(35) || this.match(14) || super.isClassProperty();
      }
      parseMaybeDefault(startLoc, left) {
        const node = super.parseMaybeDefault(startLoc, left);
        if (node.type === "AssignmentPattern" && node.typeAnnotation && node.right.start < node.typeAnnotation.start) {
          this.raise(TSErrors.TypeAnnotationAfterAssign, {
            at: node.typeAnnotation
          });
        }
        return node;
      }
      getTokenFromCode(code) {
        if (this.state.inType) {
          if (code === 62) {
            return this.finishOp(48, 1);
          }
          if (code === 60) {
            return this.finishOp(47, 1);
          }
        }
        return super.getTokenFromCode(code);
      }
      reScan_lt_gt() {
        const {
          type
        } = this.state;
        if (type === 47) {
          this.state.pos -= 1;
          this.readToken_lt();
        } else if (type === 48) {
          this.state.pos -= 1;
          this.readToken_gt();
        }
      }
      reScan_lt() {
        const {
          type
        } = this.state;
        if (type === 51) {
          this.state.pos -= 2;
          this.finishOp(47, 1);
          return 47;
        }
        return type;
      }
      toAssignableList(exprList, trailingCommaLoc, isLHS) {
        for (let i = 0; i < exprList.length; i++) {
          const expr = exprList[i];
          if ((expr == null ? void 0 : expr.type) === "TSTypeCastExpression") {
            exprList[i] = this.typeCastToParameter(expr);
          }
        }
        super.toAssignableList(exprList, trailingCommaLoc, isLHS);
      }
      typeCastToParameter(node) {
        node.expression.typeAnnotation = node.typeAnnotation;
        this.resetEndLocation(node.expression, node.typeAnnotation.loc.end);
        return node.expression;
      }
      shouldParseArrow(params) {
        if (this.match(14)) {
          return params.every((expr) => this.isAssignable(expr, true));
        }
        return super.shouldParseArrow(params);
      }
      shouldParseAsyncArrow() {
        return this.match(14) || super.shouldParseAsyncArrow();
      }
      canHaveLeadingDecorator() {
        return super.canHaveLeadingDecorator() || this.isAbstractClass();
      }
      jsxParseOpeningElementAfterName(node) {
        if (this.match(47) || this.match(51)) {
          const typeArguments = this.tsTryParseAndCatch(() => this.tsParseTypeArgumentsInExpression());
          if (typeArguments)
            node.typeParameters = typeArguments;
        }
        return super.jsxParseOpeningElementAfterName(node);
      }
      getGetterSetterExpectedParamCount(method) {
        const baseCount = super.getGetterSetterExpectedParamCount(method);
        const params = this.getObjectOrClassMethodParams(method);
        const firstParam = params[0];
        const hasContextParam = firstParam && this.isThisParam(firstParam);
        return hasContextParam ? baseCount + 1 : baseCount;
      }
      parseCatchClauseParam() {
        const param = super.parseCatchClauseParam();
        const type = this.tsTryParseTypeAnnotation();
        if (type) {
          param.typeAnnotation = type;
          this.resetEndLocation(param);
        }
        return param;
      }
      tsInAmbientContext(cb) {
        const oldIsAmbientContext = this.state.isAmbientContext;
        this.state.isAmbientContext = true;
        try {
          return cb();
        } finally {
          this.state.isAmbientContext = oldIsAmbientContext;
        }
      }
      parseClass(node, isStatement, optionalId) {
        const oldInAbstractClass = this.state.inAbstractClass;
        this.state.inAbstractClass = !!node.abstract;
        try {
          return super.parseClass(node, isStatement, optionalId);
        } finally {
          this.state.inAbstractClass = oldInAbstractClass;
        }
      }
      tsParseAbstractDeclaration(node, decorators) {
        if (this.match(80)) {
          node.abstract = true;
          return this.maybeTakeDecorators(decorators, this.parseClass(node, true, false));
        } else if (this.isContextual(127)) {
          if (!this.hasFollowingLineBreak()) {
            node.abstract = true;
            this.raise(TSErrors.NonClassMethodPropertyHasAbstractModifer, {
              at: node
            });
            return this.tsParseInterfaceDeclaration(node);
          }
        } else {
          this.unexpected(null, 80);
        }
      }
      parseMethod(node, isGenerator, isAsync, isConstructor, allowDirectSuper, type, inClassScope) {
        const method = super.parseMethod(node, isGenerator, isAsync, isConstructor, allowDirectSuper, type, inClassScope);
        if (method.abstract) {
          const hasBody = this.hasPlugin("estree") ? !!method.value.body : !!method.body;
          if (hasBody) {
            const {
              key
            } = method;
            this.raise(TSErrors.AbstractMethodHasImplementation, {
              at: method,
              methodName: key.type === "Identifier" && !method.computed ? key.name : `[${this.input.slice(key.start, key.end)}]`
            });
          }
        }
        return method;
      }
      tsParseTypeParameterName() {
        const typeName = this.parseIdentifier();
        return typeName.name;
      }
      shouldParseAsAmbientContext() {
        return !!this.getPluginOption("typescript", "dts");
      }
      parse() {
        if (this.shouldParseAsAmbientContext()) {
          this.state.isAmbientContext = true;
        }
        return super.parse();
      }
      getExpression() {
        if (this.shouldParseAsAmbientContext()) {
          this.state.isAmbientContext = true;
        }
        return super.getExpression();
      }
      parseExportSpecifier(node, isString, isInTypeExport, isMaybeTypeOnly) {
        if (!isString && isMaybeTypeOnly) {
          this.parseTypeOnlyImportExportSpecifier(node, false, isInTypeExport);
          return this.finishNode(node, "ExportSpecifier");
        }
        node.exportKind = "value";
        return super.parseExportSpecifier(node, isString, isInTypeExport, isMaybeTypeOnly);
      }
      parseImportSpecifier(specifier, importedIsString, isInTypeOnlyImport, isMaybeTypeOnly, bindingType) {
        if (!importedIsString && isMaybeTypeOnly) {
          this.parseTypeOnlyImportExportSpecifier(specifier, true, isInTypeOnlyImport);
          return this.finishNode(specifier, "ImportSpecifier");
        }
        specifier.importKind = "value";
        return super.parseImportSpecifier(specifier, importedIsString, isInTypeOnlyImport, isMaybeTypeOnly, isInTypeOnlyImport ? BIND_TS_TYPE_IMPORT : BIND_FLAGS_TS_IMPORT);
      }
      parseTypeOnlyImportExportSpecifier(node, isImport, isInTypeOnlyImportExport) {
        const leftOfAsKey = isImport ? "imported" : "local";
        const rightOfAsKey = isImport ? "local" : "exported";
        let leftOfAs = node[leftOfAsKey];
        let rightOfAs;
        let hasTypeSpecifier = false;
        let canParseAsKeyword = true;
        const loc = leftOfAs.loc.start;
        if (this.isContextual(93)) {
          const firstAs = this.parseIdentifier();
          if (this.isContextual(93)) {
            const secondAs = this.parseIdentifier();
            if (tokenIsKeywordOrIdentifier(this.state.type)) {
              hasTypeSpecifier = true;
              leftOfAs = firstAs;
              rightOfAs = isImport ? this.parseIdentifier() : this.parseModuleExportName();
              canParseAsKeyword = false;
            } else {
              rightOfAs = secondAs;
              canParseAsKeyword = false;
            }
          } else if (tokenIsKeywordOrIdentifier(this.state.type)) {
            canParseAsKeyword = false;
            rightOfAs = isImport ? this.parseIdentifier() : this.parseModuleExportName();
          } else {
            hasTypeSpecifier = true;
            leftOfAs = firstAs;
          }
        } else if (tokenIsKeywordOrIdentifier(this.state.type)) {
          hasTypeSpecifier = true;
          if (isImport) {
            leftOfAs = this.parseIdentifier(true);
            if (!this.isContextual(93)) {
              this.checkReservedWord(leftOfAs.name, leftOfAs.loc.start, true, true);
            }
          } else {
            leftOfAs = this.parseModuleExportName();
          }
        }
        if (hasTypeSpecifier && isInTypeOnlyImportExport) {
          this.raise(isImport ? TSErrors.TypeModifierIsUsedInTypeImports : TSErrors.TypeModifierIsUsedInTypeExports, {
            at: loc
          });
        }
        node[leftOfAsKey] = leftOfAs;
        node[rightOfAsKey] = rightOfAs;
        const kindKey = isImport ? "importKind" : "exportKind";
        node[kindKey] = hasTypeSpecifier ? "type" : "value";
        if (canParseAsKeyword && this.eatContextual(93)) {
          node[rightOfAsKey] = isImport ? this.parseIdentifier() : this.parseModuleExportName();
        }
        if (!node[rightOfAsKey]) {
          node[rightOfAsKey] = cloneIdentifier(node[leftOfAsKey]);
        }
        if (isImport) {
          this.checkIdentifier(node[rightOfAsKey], hasTypeSpecifier ? BIND_TS_TYPE_IMPORT : BIND_FLAGS_TS_IMPORT);
        }
      }
    };
    function isPossiblyLiteralEnum(expression) {
      if (expression.type !== "MemberExpression")
        return false;
      const {
        computed,
        property
      } = expression;
      if (computed && property.type !== "StringLiteral" && (property.type !== "TemplateLiteral" || property.expressions.length > 0)) {
        return false;
      }
      return isUncomputedMemberExpressionChain(expression.object);
    }
    function isUncomputedMemberExpressionChain(expression) {
      if (expression.type === "Identifier")
        return true;
      if (expression.type !== "MemberExpression")
        return false;
      if (expression.computed)
        return false;
      return isUncomputedMemberExpressionChain(expression.object);
    }
    var PlaceholderErrors = ParseErrorEnum`placeholders`({
      ClassNameIsRequired: "A class name is required.",
      UnexpectedSpace: "Unexpected space in placeholder."
    });
    var placeholders = (superClass) => class PlaceholdersParserMixin extends superClass {
      parsePlaceholder(expectedNode) {
        if (this.match(142)) {
          const node = this.startNode();
          this.next();
          this.assertNoSpace();
          node.name = super.parseIdentifier(true);
          this.assertNoSpace();
          this.expect(142);
          return this.finishPlaceholder(node, expectedNode);
        }
      }
      finishPlaceholder(node, expectedNode) {
        const isFinished = !!(node.expectedNode && node.type === "Placeholder");
        node.expectedNode = expectedNode;
        return isFinished ? node : this.finishNode(node, "Placeholder");
      }
      getTokenFromCode(code) {
        if (code === 37 && this.input.charCodeAt(this.state.pos + 1) === 37) {
          return this.finishOp(142, 2);
        }
        return super.getTokenFromCode(code);
      }
      parseExprAtom(refExpressionErrors) {
        return this.parsePlaceholder("Expression") || super.parseExprAtom(refExpressionErrors);
      }
      parseIdentifier(liberal) {
        return this.parsePlaceholder("Identifier") || super.parseIdentifier(liberal);
      }
      checkReservedWord(word, startLoc, checkKeywords, isBinding) {
        if (word !== void 0) {
          super.checkReservedWord(word, startLoc, checkKeywords, isBinding);
        }
      }
      parseBindingAtom() {
        return this.parsePlaceholder("Pattern") || super.parseBindingAtom();
      }
      isValidLVal(type, isParenthesized, binding) {
        return type === "Placeholder" || super.isValidLVal(type, isParenthesized, binding);
      }
      toAssignable(node, isLHS) {
        if (node && node.type === "Placeholder" && node.expectedNode === "Expression") {
          node.expectedNode = "Pattern";
        } else {
          super.toAssignable(node, isLHS);
        }
      }
      chStartsBindingIdentifier(ch, pos) {
        if (super.chStartsBindingIdentifier(ch, pos)) {
          return true;
        }
        const nextToken = this.lookahead();
        if (nextToken.type === 142) {
          return true;
        }
        return false;
      }
      verifyBreakContinue(node, isBreak) {
        if (node.label && node.label.type === "Placeholder")
          return;
        super.verifyBreakContinue(node, isBreak);
      }
      parseExpressionStatement(node, expr) {
        if (expr.type !== "Placeholder" || expr.extra && expr.extra.parenthesized) {
          return super.parseExpressionStatement(node, expr);
        }
        if (this.match(14)) {
          const stmt = node;
          stmt.label = this.finishPlaceholder(expr, "Identifier");
          this.next();
          stmt.body = super.parseStatementOrFunctionDeclaration(false);
          return this.finishNode(stmt, "LabeledStatement");
        }
        this.semicolon();
        node.name = expr.name;
        return this.finishPlaceholder(node, "Statement");
      }
      parseBlock(allowDirectives, createNewLexicalScope, afterBlockParse) {
        return this.parsePlaceholder("BlockStatement") || super.parseBlock(allowDirectives, createNewLexicalScope, afterBlockParse);
      }
      parseFunctionId(requireId) {
        return this.parsePlaceholder("Identifier") || super.parseFunctionId(requireId);
      }
      parseClass(node, isStatement, optionalId) {
        const type = isStatement ? "ClassDeclaration" : "ClassExpression";
        this.next();
        const oldStrict = this.state.strict;
        const placeholder = this.parsePlaceholder("Identifier");
        if (placeholder) {
          if (this.match(81) || this.match(142) || this.match(5)) {
            node.id = placeholder;
          } else if (optionalId || !isStatement) {
            node.id = null;
            node.body = this.finishPlaceholder(placeholder, "ClassBody");
            return this.finishNode(node, type);
          } else {
            throw this.raise(PlaceholderErrors.ClassNameIsRequired, {
              at: this.state.startLoc
            });
          }
        } else {
          this.parseClassId(node, isStatement, optionalId);
        }
        super.parseClassSuper(node);
        node.body = this.parsePlaceholder("ClassBody") || super.parseClassBody(!!node.superClass, oldStrict);
        return this.finishNode(node, type);
      }
      parseExport(node, decorators) {
        const placeholder = this.parsePlaceholder("Identifier");
        if (!placeholder)
          return super.parseExport(node, decorators);
        if (!this.isContextual(97) && !this.match(12)) {
          node.specifiers = [];
          node.source = null;
          node.declaration = this.finishPlaceholder(placeholder, "Declaration");
          return this.finishNode(node, "ExportNamedDeclaration");
        }
        this.expectPlugin("exportDefaultFrom");
        const specifier = this.startNode();
        specifier.exported = placeholder;
        node.specifiers = [this.finishNode(specifier, "ExportDefaultSpecifier")];
        return super.parseExport(node, decorators);
      }
      isExportDefaultSpecifier() {
        if (this.match(65)) {
          const next = this.nextTokenStart();
          if (this.isUnparsedContextual(next, "from")) {
            if (this.input.startsWith(tokenLabelName(142), this.nextTokenStartSince(next + 4))) {
              return true;
            }
          }
        }
        return super.isExportDefaultSpecifier();
      }
      maybeParseExportDefaultSpecifier(node) {
        if (node.specifiers && node.specifiers.length > 0) {
          return true;
        }
        return super.maybeParseExportDefaultSpecifier(node);
      }
      checkExport(node) {
        const {
          specifiers
        } = node;
        if (specifiers != null && specifiers.length) {
          node.specifiers = specifiers.filter(
            (node2) => node2.exported.type === "Placeholder"
          );
        }
        super.checkExport(node);
        node.specifiers = specifiers;
      }
      parseImport(node) {
        const placeholder = this.parsePlaceholder("Identifier");
        if (!placeholder)
          return super.parseImport(node);
        node.specifiers = [];
        if (!this.isContextual(97) && !this.match(12)) {
          node.source = this.finishPlaceholder(placeholder, "StringLiteral");
          this.semicolon();
          return this.finishNode(node, "ImportDeclaration");
        }
        const specifier = this.startNodeAtNode(placeholder);
        specifier.local = placeholder;
        node.specifiers.push(this.finishNode(specifier, "ImportDefaultSpecifier"));
        if (this.eat(12)) {
          const hasStarImport = this.maybeParseStarImportSpecifier(node);
          if (!hasStarImport)
            this.parseNamedImportSpecifiers(node);
        }
        this.expectContextual(97);
        node.source = this.parseImportSource();
        this.semicolon();
        return this.finishNode(node, "ImportDeclaration");
      }
      parseImportSource() {
        return this.parsePlaceholder("StringLiteral") || super.parseImportSource();
      }
      assertNoSpace() {
        if (this.state.start > this.state.lastTokEndLoc.index) {
          this.raise(PlaceholderErrors.UnexpectedSpace, {
            at: this.state.lastTokEndLoc
          });
        }
      }
    };
    var v8intrinsic = (superClass) => class V8IntrinsicMixin extends superClass {
      parseV8Intrinsic() {
        if (this.match(54)) {
          const v8IntrinsicStartLoc = this.state.startLoc;
          const node = this.startNode();
          this.next();
          if (tokenIsIdentifier(this.state.type)) {
            const name = this.parseIdentifierName();
            const identifier3 = this.createIdentifier(node, name);
            identifier3.type = "V8IntrinsicIdentifier";
            if (this.match(10)) {
              return identifier3;
            }
          }
          this.unexpected(v8IntrinsicStartLoc);
        }
      }
      parseExprAtom(refExpressionErrors) {
        return this.parseV8Intrinsic() || super.parseExprAtom(refExpressionErrors);
      }
    };
    function hasPlugin(plugins, expectedConfig) {
      const [expectedName, expectedOptions] = typeof expectedConfig === "string" ? [expectedConfig, {}] : expectedConfig;
      const expectedKeys = Object.keys(expectedOptions);
      const expectedOptionsIsEmpty = expectedKeys.length === 0;
      return plugins.some((p) => {
        if (typeof p === "string") {
          return expectedOptionsIsEmpty && p === expectedName;
        } else {
          const [pluginName, pluginOptions] = p;
          if (pluginName !== expectedName) {
            return false;
          }
          for (const key of expectedKeys) {
            if (pluginOptions[key] !== expectedOptions[key]) {
              return false;
            }
          }
          return true;
        }
      });
    }
    function getPluginOption(plugins, name, option) {
      const plugin = plugins.find((plugin2) => {
        if (Array.isArray(plugin2)) {
          return plugin2[0] === name;
        } else {
          return plugin2 === name;
        }
      });
      if (plugin && Array.isArray(plugin) && plugin.length > 1) {
        return plugin[1][option];
      }
      return null;
    }
    var PIPELINE_PROPOSALS = ["minimal", "fsharp", "hack", "smart"];
    var TOPIC_TOKENS = ["^^", "@@", "^", "%", "#"];
    var RECORD_AND_TUPLE_SYNTAX_TYPES = ["hash", "bar"];
    function validatePlugins(plugins) {
      if (hasPlugin(plugins, "decorators")) {
        if (hasPlugin(plugins, "decorators-legacy")) {
          throw new Error("Cannot use the decorators and decorators-legacy plugin together");
        }
        const decoratorsBeforeExport = getPluginOption(plugins, "decorators", "decoratorsBeforeExport");
        if (decoratorsBeforeExport != null && typeof decoratorsBeforeExport !== "boolean") {
          throw new Error("'decoratorsBeforeExport' must be a boolean.");
        }
        const allowCallParenthesized = getPluginOption(plugins, "decorators", "allowCallParenthesized");
        if (allowCallParenthesized != null && typeof allowCallParenthesized !== "boolean") {
          throw new Error("'allowCallParenthesized' must be a boolean.");
        }
      }
      if (hasPlugin(plugins, "flow") && hasPlugin(plugins, "typescript")) {
        throw new Error("Cannot combine flow and typescript plugins.");
      }
      if (hasPlugin(plugins, "placeholders") && hasPlugin(plugins, "v8intrinsic")) {
        throw new Error("Cannot combine placeholders and v8intrinsic plugins.");
      }
      if (hasPlugin(plugins, "pipelineOperator")) {
        const proposal = getPluginOption(plugins, "pipelineOperator", "proposal");
        if (!PIPELINE_PROPOSALS.includes(proposal)) {
          const proposalList = PIPELINE_PROPOSALS.map((p) => `"${p}"`).join(", ");
          throw new Error(`"pipelineOperator" requires "proposal" option whose value must be one of: ${proposalList}.`);
        }
        const tupleSyntaxIsHash = hasPlugin(plugins, ["recordAndTuple", {
          syntaxType: "hash"
        }]);
        if (proposal === "hack") {
          if (hasPlugin(plugins, "placeholders")) {
            throw new Error("Cannot combine placeholders plugin and Hack-style pipes.");
          }
          if (hasPlugin(plugins, "v8intrinsic")) {
            throw new Error("Cannot combine v8intrinsic plugin and Hack-style pipes.");
          }
          const topicToken = getPluginOption(plugins, "pipelineOperator", "topicToken");
          if (!TOPIC_TOKENS.includes(topicToken)) {
            const tokenList = TOPIC_TOKENS.map((t3) => `"${t3}"`).join(", ");
            throw new Error(`"pipelineOperator" in "proposal": "hack" mode also requires a "topicToken" option whose value must be one of: ${tokenList}.`);
          }
          if (topicToken === "#" && tupleSyntaxIsHash) {
            throw new Error('Plugin conflict between `["pipelineOperator", { proposal: "hack", topicToken: "#" }]` and `["recordAndtuple", { syntaxType: "hash"}]`.');
          }
        } else if (proposal === "smart" && tupleSyntaxIsHash) {
          throw new Error('Plugin conflict between `["pipelineOperator", { proposal: "smart" }]` and `["recordAndtuple", { syntaxType: "hash"}]`.');
        }
      }
      if (hasPlugin(plugins, "moduleAttributes")) {
        {
          if (hasPlugin(plugins, "importAssertions")) {
            throw new Error("Cannot combine importAssertions and moduleAttributes plugins.");
          }
          const moduleAttributesVersionPluginOption = getPluginOption(plugins, "moduleAttributes", "version");
          if (moduleAttributesVersionPluginOption !== "may-2020") {
            throw new Error("The 'moduleAttributes' plugin requires a 'version' option, representing the last proposal update. Currently, the only supported value is 'may-2020'.");
          }
        }
      }
      if (hasPlugin(plugins, "recordAndTuple") && getPluginOption(plugins, "recordAndTuple", "syntaxType") != null && !RECORD_AND_TUPLE_SYNTAX_TYPES.includes(getPluginOption(plugins, "recordAndTuple", "syntaxType"))) {
        throw new Error("The 'syntaxType' option of the 'recordAndTuple' plugin must be one of: " + RECORD_AND_TUPLE_SYNTAX_TYPES.map((p) => `'${p}'`).join(", "));
      }
      if (hasPlugin(plugins, "asyncDoExpressions") && !hasPlugin(plugins, "doExpressions")) {
        const error = new Error("'asyncDoExpressions' requires 'doExpressions', please add 'doExpressions' to parser plugins.");
        error.missingPlugins = "doExpressions";
        throw error;
      }
    }
    var mixinPlugins = {
      estree,
      jsx,
      flow,
      typescript,
      v8intrinsic,
      placeholders
    };
    var mixinPluginNames = Object.keys(mixinPlugins);
    var defaultOptions2 = {
      sourceType: "script",
      sourceFilename: void 0,
      startColumn: 0,
      startLine: 1,
      allowAwaitOutsideFunction: false,
      allowReturnOutsideFunction: false,
      allowImportExportEverywhere: false,
      allowSuperOutsideMethod: false,
      allowUndeclaredExports: false,
      plugins: [],
      strictMode: null,
      ranges: false,
      tokens: false,
      createParenthesizedExpressions: false,
      errorRecovery: false,
      attachComment: true
    };
    function getOptions(opts) {
      const options = {};
      for (const key of Object.keys(defaultOptions2)) {
        options[key] = opts && opts[key] != null ? opts[key] : defaultOptions2[key];
      }
      return options;
    }
    var getOwn = (object, key) => Object.hasOwnProperty.call(object, key) && object[key];
    var unwrapParenthesizedExpression = (node) => {
      return node.type === "ParenthesizedExpression" ? unwrapParenthesizedExpression(node.expression) : node;
    };
    var LValParser = class extends NodeUtils {
      toAssignable(node, isLHS = false) {
        var _node$extra, _node$extra3;
        let parenthesized = void 0;
        if (node.type === "ParenthesizedExpression" || (_node$extra = node.extra) != null && _node$extra.parenthesized) {
          parenthesized = unwrapParenthesizedExpression(node);
          if (isLHS) {
            if (parenthesized.type === "Identifier") {
              this.expressionScope.recordArrowParameterBindingError(Errors.InvalidParenthesizedAssignment, {
                at: node
              });
            } else if (parenthesized.type !== "MemberExpression") {
              this.raise(Errors.InvalidParenthesizedAssignment, {
                at: node
              });
            }
          } else {
            this.raise(Errors.InvalidParenthesizedAssignment, {
              at: node
            });
          }
        }
        switch (node.type) {
          case "Identifier":
          case "ObjectPattern":
          case "ArrayPattern":
          case "AssignmentPattern":
          case "RestElement":
            break;
          case "ObjectExpression":
            node.type = "ObjectPattern";
            for (let i = 0, length = node.properties.length, last2 = length - 1; i < length; i++) {
              var _node$extra2;
              const prop = node.properties[i];
              const isLast = i === last2;
              this.toAssignableObjectExpressionProp(prop, isLast, isLHS);
              if (isLast && prop.type === "RestElement" && (_node$extra2 = node.extra) != null && _node$extra2.trailingCommaLoc) {
                this.raise(Errors.RestTrailingComma, {
                  at: node.extra.trailingCommaLoc
                });
              }
            }
            break;
          case "ObjectProperty": {
            const {
              key,
              value: value2
            } = node;
            if (this.isPrivateName(key)) {
              this.classScope.usePrivateName(this.getPrivateNameSV(key), key.loc.start);
            }
            this.toAssignable(value2, isLHS);
            break;
          }
          case "SpreadElement": {
            throw new Error("Internal @babel/parser error (this is a bug, please report it). SpreadElement should be converted by .toAssignable's caller.");
          }
          case "ArrayExpression":
            node.type = "ArrayPattern";
            this.toAssignableList(node.elements, (_node$extra3 = node.extra) == null ? void 0 : _node$extra3.trailingCommaLoc, isLHS);
            break;
          case "AssignmentExpression":
            if (node.operator !== "=") {
              this.raise(Errors.MissingEqInAssignment, {
                at: node.left.loc.end
              });
            }
            node.type = "AssignmentPattern";
            delete node.operator;
            this.toAssignable(node.left, isLHS);
            break;
          case "ParenthesizedExpression":
            this.toAssignable(parenthesized, isLHS);
            break;
        }
      }
      toAssignableObjectExpressionProp(prop, isLast, isLHS) {
        if (prop.type === "ObjectMethod") {
          this.raise(prop.kind === "get" || prop.kind === "set" ? Errors.PatternHasAccessor : Errors.PatternHasMethod, {
            at: prop.key
          });
        } else if (prop.type === "SpreadElement") {
          prop.type = "RestElement";
          const arg = prop.argument;
          this.checkToRestConversion(arg, false);
          this.toAssignable(arg, isLHS);
          if (!isLast) {
            this.raise(Errors.RestTrailingComma, {
              at: prop
            });
          }
        } else {
          this.toAssignable(prop, isLHS);
        }
      }
      toAssignableList(exprList, trailingCommaLoc, isLHS) {
        const end = exprList.length - 1;
        for (let i = 0; i <= end; i++) {
          const elt = exprList[i];
          if (!elt)
            continue;
          if (elt.type === "SpreadElement") {
            elt.type = "RestElement";
            const arg = elt.argument;
            this.checkToRestConversion(arg, true);
            this.toAssignable(arg, isLHS);
          } else {
            this.toAssignable(elt, isLHS);
          }
          if (elt.type === "RestElement") {
            if (i < end) {
              this.raise(Errors.RestTrailingComma, {
                at: elt
              });
            } else if (trailingCommaLoc) {
              this.raise(Errors.RestTrailingComma, {
                at: trailingCommaLoc
              });
            }
          }
        }
      }
      isAssignable(node, isBinding) {
        switch (node.type) {
          case "Identifier":
          case "ObjectPattern":
          case "ArrayPattern":
          case "AssignmentPattern":
          case "RestElement":
            return true;
          case "ObjectExpression": {
            const last2 = node.properties.length - 1;
            return node.properties.every((prop, i) => {
              return prop.type !== "ObjectMethod" && (i === last2 || prop.type !== "SpreadElement") && this.isAssignable(prop);
            });
          }
          case "ObjectProperty":
            return this.isAssignable(node.value);
          case "SpreadElement":
            return this.isAssignable(node.argument);
          case "ArrayExpression":
            return node.elements.every((element) => element === null || this.isAssignable(element));
          case "AssignmentExpression":
            return node.operator === "=";
          case "ParenthesizedExpression":
            return this.isAssignable(node.expression);
          case "MemberExpression":
          case "OptionalMemberExpression":
            return !isBinding;
          default:
            return false;
        }
      }
      toReferencedList(exprList, isParenthesizedExpr) {
        return exprList;
      }
      toReferencedListDeep(exprList, isParenthesizedExpr) {
        this.toReferencedList(exprList, isParenthesizedExpr);
        for (const expr of exprList) {
          if ((expr == null ? void 0 : expr.type) === "ArrayExpression") {
            this.toReferencedListDeep(expr.elements);
          }
        }
      }
      parseSpread(refExpressionErrors) {
        const node = this.startNode();
        this.next();
        node.argument = this.parseMaybeAssignAllowIn(refExpressionErrors, void 0);
        return this.finishNode(node, "SpreadElement");
      }
      parseRestBinding() {
        const node = this.startNode();
        this.next();
        node.argument = this.parseBindingAtom();
        return this.finishNode(node, "RestElement");
      }
      parseBindingAtom() {
        switch (this.state.type) {
          case 0: {
            const node = this.startNode();
            this.next();
            node.elements = this.parseBindingList(3, 93, true);
            return this.finishNode(node, "ArrayPattern");
          }
          case 5:
            return this.parseObjectLike(8, true);
        }
        return this.parseIdentifier();
      }
      parseBindingList(close, closeCharCode, allowEmpty, allowModifiers) {
        const elts = [];
        let first2 = true;
        while (!this.eat(close)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12);
          }
          if (allowEmpty && this.match(12)) {
            elts.push(null);
          } else if (this.eat(close)) {
            break;
          } else if (this.match(21)) {
            elts.push(this.parseAssignableListItemTypes(this.parseRestBinding()));
            if (!this.checkCommaAfterRest(closeCharCode)) {
              this.expect(close);
              break;
            }
          } else {
            const decorators = [];
            if (this.match(26) && this.hasPlugin("decorators")) {
              this.raise(Errors.UnsupportedParameterDecorator, {
                at: this.state.startLoc
              });
            }
            while (this.match(26)) {
              decorators.push(this.parseDecorator());
            }
            elts.push(this.parseAssignableListItem(allowModifiers, decorators));
          }
        }
        return elts;
      }
      parseBindingRestProperty(prop) {
        this.next();
        prop.argument = this.parseIdentifier();
        this.checkCommaAfterRest(125);
        return this.finishNode(prop, "RestElement");
      }
      parseBindingProperty() {
        const prop = this.startNode();
        const {
          type,
          startLoc
        } = this.state;
        if (type === 21) {
          return this.parseBindingRestProperty(prop);
        } else if (type === 136) {
          this.expectPlugin("destructuringPrivate", startLoc);
          this.classScope.usePrivateName(this.state.value, startLoc);
          prop.key = this.parsePrivateName();
        } else {
          this.parsePropertyName(prop);
        }
        prop.method = false;
        return this.parseObjPropValue(prop, startLoc, false, false, true, false);
      }
      parseAssignableListItem(allowModifiers, decorators) {
        const left = this.parseMaybeDefault();
        this.parseAssignableListItemTypes(left);
        const elt = this.parseMaybeDefault(left.loc.start, left);
        if (decorators.length) {
          left.decorators = decorators;
        }
        return elt;
      }
      parseAssignableListItemTypes(param) {
        return param;
      }
      parseMaybeDefault(startLoc, left) {
        var _startLoc, _left;
        (_startLoc = startLoc) != null ? _startLoc : startLoc = this.state.startLoc;
        left = (_left = left) != null ? _left : this.parseBindingAtom();
        if (!this.eat(29))
          return left;
        const node = this.startNodeAt(startLoc);
        node.left = left;
        node.right = this.parseMaybeAssignAllowIn();
        return this.finishNode(node, "AssignmentPattern");
      }
      isValidLVal(type, isUnparenthesizedInAssign, binding) {
        return getOwn(
          {
            AssignmentPattern: "left",
            RestElement: "argument",
            ObjectProperty: "value",
            ParenthesizedExpression: "expression",
            ArrayPattern: "elements",
            ObjectPattern: "properties"
          },
          type
        );
      }
      checkLVal(expression, {
        in: ancestor,
        binding = BIND_NONE,
        checkClashes = false,
        strictModeChanged = false,
        allowingSloppyLetBinding = !(binding & BIND_SCOPE_LEXICAL),
        hasParenthesizedAncestor = false
      }) {
        var _expression$extra;
        const type = expression.type;
        if (this.isObjectMethod(expression))
          return;
        if (type === "MemberExpression") {
          if (binding !== BIND_NONE) {
            this.raise(Errors.InvalidPropertyBindingPattern, {
              at: expression
            });
          }
          return;
        }
        if (expression.type === "Identifier") {
          this.checkIdentifier(expression, binding, strictModeChanged, allowingSloppyLetBinding);
          const {
            name
          } = expression;
          if (checkClashes) {
            if (checkClashes.has(name)) {
              this.raise(Errors.ParamDupe, {
                at: expression
              });
            } else {
              checkClashes.add(name);
            }
          }
          return;
        }
        const validity = this.isValidLVal(expression.type, !(hasParenthesizedAncestor || (_expression$extra = expression.extra) != null && _expression$extra.parenthesized) && ancestor.type === "AssignmentExpression", binding);
        if (validity === true)
          return;
        if (validity === false) {
          const ParseErrorClass = binding === BIND_NONE ? Errors.InvalidLhs : Errors.InvalidLhsBinding;
          this.raise(ParseErrorClass, {
            at: expression,
            ancestor: ancestor.type === "UpdateExpression" ? {
              type: "UpdateExpression",
              prefix: ancestor.prefix
            } : {
              type: ancestor.type
            }
          });
          return;
        }
        const [key, isParenthesizedExpression] = Array.isArray(validity) ? validity : [validity, type === "ParenthesizedExpression"];
        const nextAncestor = expression.type === "ArrayPattern" || expression.type === "ObjectPattern" || expression.type === "ParenthesizedExpression" ? expression : ancestor;
        for (const child of [].concat(expression[key])) {
          if (child) {
            this.checkLVal(child, {
              in: nextAncestor,
              binding,
              checkClashes,
              allowingSloppyLetBinding,
              strictModeChanged,
              hasParenthesizedAncestor: isParenthesizedExpression
            });
          }
        }
      }
      checkIdentifier(at, bindingType, strictModeChanged = false, allowLetBinding = !(bindingType & BIND_SCOPE_LEXICAL)) {
        if (this.state.strict && (strictModeChanged ? isStrictBindReservedWord(at.name, this.inModule) : isStrictBindOnlyReservedWord(at.name))) {
          if (bindingType === BIND_NONE) {
            this.raise(Errors.StrictEvalArguments, {
              at,
              referenceName: at.name
            });
          } else {
            this.raise(Errors.StrictEvalArgumentsBinding, {
              at,
              bindingName: at.name
            });
          }
        }
        if (!allowLetBinding && at.name === "let") {
          this.raise(Errors.LetInLexicalBinding, {
            at
          });
        }
        if (!(bindingType & BIND_NONE)) {
          this.declareNameFromIdentifier(at, bindingType);
        }
      }
      declareNameFromIdentifier(identifier3, binding) {
        this.scope.declareName(identifier3.name, binding, identifier3.loc.start);
      }
      checkToRestConversion(node, allowPattern) {
        switch (node.type) {
          case "ParenthesizedExpression":
            this.checkToRestConversion(node.expression, allowPattern);
            break;
          case "Identifier":
          case "MemberExpression":
            break;
          case "ArrayExpression":
          case "ObjectExpression":
            if (allowPattern)
              break;
          default:
            this.raise(Errors.InvalidRestAssignmentPattern, {
              at: node
            });
        }
      }
      checkCommaAfterRest(close) {
        if (!this.match(12)) {
          return false;
        }
        this.raise(this.lookaheadCharCode() === close ? Errors.RestTrailingComma : Errors.ElementAfterRest, {
          at: this.state.startLoc
        });
        return true;
      }
    };
    var ExpressionParser = class extends LValParser {
      checkProto(prop, isRecord, protoRef, refExpressionErrors) {
        if (prop.type === "SpreadElement" || this.isObjectMethod(prop) || prop.computed || prop.shorthand) {
          return;
        }
        const key = prop.key;
        const name = key.type === "Identifier" ? key.name : key.value;
        if (name === "__proto__") {
          if (isRecord) {
            this.raise(Errors.RecordNoProto, {
              at: key
            });
            return;
          }
          if (protoRef.used) {
            if (refExpressionErrors) {
              if (refExpressionErrors.doubleProtoLoc === null) {
                refExpressionErrors.doubleProtoLoc = key.loc.start;
              }
            } else {
              this.raise(Errors.DuplicateProto, {
                at: key
              });
            }
          }
          protoRef.used = true;
        }
      }
      shouldExitDescending(expr, potentialArrowAt) {
        return expr.type === "ArrowFunctionExpression" && expr.start === potentialArrowAt;
      }
      getExpression() {
        this.enterInitialScopes();
        this.nextToken();
        const expr = this.parseExpression();
        if (!this.match(137)) {
          this.unexpected();
        }
        this.finalizeRemainingComments();
        expr.comments = this.state.comments;
        expr.errors = this.state.errors;
        if (this.options.tokens) {
          expr.tokens = this.tokens;
        }
        return expr;
      }
      parseExpression(disallowIn, refExpressionErrors) {
        if (disallowIn) {
          return this.disallowInAnd(() => this.parseExpressionBase(refExpressionErrors));
        }
        return this.allowInAnd(() => this.parseExpressionBase(refExpressionErrors));
      }
      parseExpressionBase(refExpressionErrors) {
        const startLoc = this.state.startLoc;
        const expr = this.parseMaybeAssign(refExpressionErrors);
        if (this.match(12)) {
          const node = this.startNodeAt(startLoc);
          node.expressions = [expr];
          while (this.eat(12)) {
            node.expressions.push(this.parseMaybeAssign(refExpressionErrors));
          }
          this.toReferencedList(node.expressions);
          return this.finishNode(node, "SequenceExpression");
        }
        return expr;
      }
      parseMaybeAssignDisallowIn(refExpressionErrors, afterLeftParse) {
        return this.disallowInAnd(() => this.parseMaybeAssign(refExpressionErrors, afterLeftParse));
      }
      parseMaybeAssignAllowIn(refExpressionErrors, afterLeftParse) {
        return this.allowInAnd(() => this.parseMaybeAssign(refExpressionErrors, afterLeftParse));
      }
      setOptionalParametersError(refExpressionErrors, resultError) {
        var _resultError$loc;
        refExpressionErrors.optionalParametersLoc = (_resultError$loc = resultError == null ? void 0 : resultError.loc) != null ? _resultError$loc : this.state.startLoc;
      }
      parseMaybeAssign(refExpressionErrors, afterLeftParse) {
        const startLoc = this.state.startLoc;
        if (this.isContextual(106)) {
          if (this.prodParam.hasYield) {
            let left2 = this.parseYield();
            if (afterLeftParse) {
              left2 = afterLeftParse.call(this, left2, startLoc);
            }
            return left2;
          }
        }
        let ownExpressionErrors;
        if (refExpressionErrors) {
          ownExpressionErrors = false;
        } else {
          refExpressionErrors = new ExpressionErrors();
          ownExpressionErrors = true;
        }
        const {
          type
        } = this.state;
        if (type === 10 || tokenIsIdentifier(type)) {
          this.state.potentialArrowAt = this.state.start;
        }
        let left = this.parseMaybeConditional(refExpressionErrors);
        if (afterLeftParse) {
          left = afterLeftParse.call(this, left, startLoc);
        }
        if (tokenIsAssignment(this.state.type)) {
          const node = this.startNodeAt(startLoc);
          const operator = this.state.value;
          node.operator = operator;
          if (this.match(29)) {
            this.toAssignable(left, true);
            node.left = left;
            const startIndex = startLoc.index;
            if (refExpressionErrors.doubleProtoLoc != null && refExpressionErrors.doubleProtoLoc.index >= startIndex) {
              refExpressionErrors.doubleProtoLoc = null;
            }
            if (refExpressionErrors.shorthandAssignLoc != null && refExpressionErrors.shorthandAssignLoc.index >= startIndex) {
              refExpressionErrors.shorthandAssignLoc = null;
            }
            if (refExpressionErrors.privateKeyLoc != null && refExpressionErrors.privateKeyLoc.index >= startIndex) {
              this.checkDestructuringPrivate(refExpressionErrors);
              refExpressionErrors.privateKeyLoc = null;
            }
          } else {
            node.left = left;
          }
          this.next();
          node.right = this.parseMaybeAssign();
          this.checkLVal(left, {
            in: this.finishNode(node, "AssignmentExpression")
          });
          return node;
        } else if (ownExpressionErrors) {
          this.checkExpressionErrors(refExpressionErrors, true);
        }
        return left;
      }
      parseMaybeConditional(refExpressionErrors) {
        const startLoc = this.state.startLoc;
        const potentialArrowAt = this.state.potentialArrowAt;
        const expr = this.parseExprOps(refExpressionErrors);
        if (this.shouldExitDescending(expr, potentialArrowAt)) {
          return expr;
        }
        return this.parseConditional(expr, startLoc, refExpressionErrors);
      }
      parseConditional(expr, startLoc, refExpressionErrors) {
        if (this.eat(17)) {
          const node = this.startNodeAt(startLoc);
          node.test = expr;
          node.consequent = this.parseMaybeAssignAllowIn();
          this.expect(14);
          node.alternate = this.parseMaybeAssign();
          return this.finishNode(node, "ConditionalExpression");
        }
        return expr;
      }
      parseMaybeUnaryOrPrivate(refExpressionErrors) {
        return this.match(136) ? this.parsePrivateName() : this.parseMaybeUnary(refExpressionErrors);
      }
      parseExprOps(refExpressionErrors) {
        const startLoc = this.state.startLoc;
        const potentialArrowAt = this.state.potentialArrowAt;
        const expr = this.parseMaybeUnaryOrPrivate(refExpressionErrors);
        if (this.shouldExitDescending(expr, potentialArrowAt)) {
          return expr;
        }
        return this.parseExprOp(expr, startLoc, -1);
      }
      parseExprOp(left, leftStartLoc, minPrec) {
        if (this.isPrivateName(left)) {
          const value2 = this.getPrivateNameSV(left);
          if (minPrec >= tokenOperatorPrecedence(58) || !this.prodParam.hasIn || !this.match(58)) {
            this.raise(Errors.PrivateInExpectedIn, {
              at: left,
              identifierName: value2
            });
          }
          this.classScope.usePrivateName(value2, left.loc.start);
        }
        const op = this.state.type;
        if (tokenIsOperator(op) && (this.prodParam.hasIn || !this.match(58))) {
          let prec = tokenOperatorPrecedence(op);
          if (prec > minPrec) {
            if (op === 39) {
              this.expectPlugin("pipelineOperator");
              if (this.state.inFSharpPipelineDirectBody) {
                return left;
              }
              this.checkPipelineAtInfixOperator(left, leftStartLoc);
            }
            const node = this.startNodeAt(leftStartLoc);
            node.left = left;
            node.operator = this.state.value;
            const logical = op === 41 || op === 42;
            const coalesce = op === 40;
            if (coalesce) {
              prec = tokenOperatorPrecedence(42);
            }
            this.next();
            if (op === 39 && this.hasPlugin(["pipelineOperator", {
              proposal: "minimal"
            }])) {
              if (this.state.type === 96 && this.prodParam.hasAwait) {
                throw this.raise(Errors.UnexpectedAwaitAfterPipelineBody, {
                  at: this.state.startLoc
                });
              }
            }
            node.right = this.parseExprOpRightExpr(op, prec);
            const finishedNode = this.finishNode(node, logical || coalesce ? "LogicalExpression" : "BinaryExpression");
            const nextOp = this.state.type;
            if (coalesce && (nextOp === 41 || nextOp === 42) || logical && nextOp === 40) {
              throw this.raise(Errors.MixingCoalesceWithLogical, {
                at: this.state.startLoc
              });
            }
            return this.parseExprOp(finishedNode, leftStartLoc, minPrec);
          }
        }
        return left;
      }
      parseExprOpRightExpr(op, prec) {
        const startLoc = this.state.startLoc;
        switch (op) {
          case 39:
            switch (this.getPluginOption("pipelineOperator", "proposal")) {
              case "hack":
                return this.withTopicBindingContext(() => {
                  return this.parseHackPipeBody();
                });
              case "smart":
                return this.withTopicBindingContext(() => {
                  if (this.prodParam.hasYield && this.isContextual(106)) {
                    throw this.raise(Errors.PipeBodyIsTighter, {
                      at: this.state.startLoc
                    });
                  }
                  return this.parseSmartPipelineBodyInStyle(this.parseExprOpBaseRightExpr(op, prec), startLoc);
                });
              case "fsharp":
                return this.withSoloAwaitPermittingContext(() => {
                  return this.parseFSharpPipelineBody(prec);
                });
            }
          default:
            return this.parseExprOpBaseRightExpr(op, prec);
        }
      }
      parseExprOpBaseRightExpr(op, prec) {
        const startLoc = this.state.startLoc;
        return this.parseExprOp(this.parseMaybeUnaryOrPrivate(), startLoc, tokenIsRightAssociative(op) ? prec - 1 : prec);
      }
      parseHackPipeBody() {
        var _body$extra;
        const {
          startLoc
        } = this.state;
        const body = this.parseMaybeAssign();
        const requiredParentheses = UnparenthesizedPipeBodyDescriptions.has(
          body.type
        );
        if (requiredParentheses && !((_body$extra = body.extra) != null && _body$extra.parenthesized)) {
          this.raise(Errors.PipeUnparenthesizedBody, {
            at: startLoc,
            type: body.type
          });
        }
        if (!this.topicReferenceWasUsedInCurrentContext()) {
          this.raise(Errors.PipeTopicUnused, {
            at: startLoc
          });
        }
        return body;
      }
      checkExponentialAfterUnary(node) {
        if (this.match(57)) {
          this.raise(Errors.UnexpectedTokenUnaryExponentiation, {
            at: node.argument
          });
        }
      }
      parseMaybeUnary(refExpressionErrors, sawUnary) {
        const startLoc = this.state.startLoc;
        const isAwait = this.isContextual(96);
        if (isAwait && this.isAwaitAllowed()) {
          this.next();
          const expr2 = this.parseAwait(startLoc);
          if (!sawUnary)
            this.checkExponentialAfterUnary(expr2);
          return expr2;
        }
        const update = this.match(34);
        const node = this.startNode();
        if (tokenIsPrefix(this.state.type)) {
          node.operator = this.state.value;
          node.prefix = true;
          if (this.match(72)) {
            this.expectPlugin("throwExpressions");
          }
          const isDelete = this.match(89);
          this.next();
          node.argument = this.parseMaybeUnary(null, true);
          this.checkExpressionErrors(refExpressionErrors, true);
          if (this.state.strict && isDelete) {
            const arg = node.argument;
            if (arg.type === "Identifier") {
              this.raise(Errors.StrictDelete, {
                at: node
              });
            } else if (this.hasPropertyAsPrivateName(arg)) {
              this.raise(Errors.DeletePrivateField, {
                at: node
              });
            }
          }
          if (!update) {
            if (!sawUnary) {
              this.checkExponentialAfterUnary(node);
            }
            return this.finishNode(node, "UnaryExpression");
          }
        }
        const expr = this.parseUpdate(
          node,
          update,
          refExpressionErrors
        );
        if (isAwait) {
          const {
            type
          } = this.state;
          const startsExpr2 = this.hasPlugin("v8intrinsic") ? tokenCanStartExpression(type) : tokenCanStartExpression(type) && !this.match(54);
          if (startsExpr2 && !this.isAmbiguousAwait()) {
            this.raiseOverwrite(Errors.AwaitNotInAsyncContext, {
              at: startLoc
            });
            return this.parseAwait(startLoc);
          }
        }
        return expr;
      }
      parseUpdate(node, update, refExpressionErrors) {
        if (update) {
          const updateExpressionNode = node;
          this.checkLVal(updateExpressionNode.argument, {
            in: this.finishNode(updateExpressionNode, "UpdateExpression")
          });
          return node;
        }
        const startLoc = this.state.startLoc;
        let expr = this.parseExprSubscripts(refExpressionErrors);
        if (this.checkExpressionErrors(refExpressionErrors, false))
          return expr;
        while (tokenIsPostfix(this.state.type) && !this.canInsertSemicolon()) {
          const node2 = this.startNodeAt(startLoc);
          node2.operator = this.state.value;
          node2.prefix = false;
          node2.argument = expr;
          this.next();
          this.checkLVal(expr, {
            in: expr = this.finishNode(node2, "UpdateExpression")
          });
        }
        return expr;
      }
      parseExprSubscripts(refExpressionErrors) {
        const startLoc = this.state.startLoc;
        const potentialArrowAt = this.state.potentialArrowAt;
        const expr = this.parseExprAtom(refExpressionErrors);
        if (this.shouldExitDescending(expr, potentialArrowAt)) {
          return expr;
        }
        return this.parseSubscripts(expr, startLoc);
      }
      parseSubscripts(base, startLoc, noCalls) {
        const state = {
          optionalChainMember: false,
          maybeAsyncArrow: this.atPossibleAsyncArrow(base),
          stop: false
        };
        do {
          base = this.parseSubscript(base, startLoc, noCalls, state);
          state.maybeAsyncArrow = false;
        } while (!state.stop);
        return base;
      }
      parseSubscript(base, startLoc, noCalls, state) {
        const {
          type
        } = this.state;
        if (!noCalls && type === 15) {
          return this.parseBind(base, startLoc, noCalls, state);
        } else if (tokenIsTemplate(type)) {
          return this.parseTaggedTemplateExpression(base, startLoc, state);
        }
        let optional = false;
        if (type === 18) {
          if (noCalls && this.lookaheadCharCode() === 40) {
            state.stop = true;
            return base;
          }
          state.optionalChainMember = optional = true;
          this.next();
        }
        if (!noCalls && this.match(10)) {
          return this.parseCoverCallAndAsyncArrowHead(base, startLoc, state, optional);
        } else {
          const computed = this.eat(0);
          if (computed || optional || this.eat(16)) {
            return this.parseMember(base, startLoc, state, computed, optional);
          } else {
            state.stop = true;
            return base;
          }
        }
      }
      parseMember(base, startLoc, state, computed, optional) {
        const node = this.startNodeAt(startLoc);
        node.object = base;
        node.computed = computed;
        if (computed) {
          node.property = this.parseExpression();
          this.expect(3);
        } else if (this.match(136)) {
          if (base.type === "Super") {
            this.raise(Errors.SuperPrivateField, {
              at: startLoc
            });
          }
          this.classScope.usePrivateName(this.state.value, this.state.startLoc);
          node.property = this.parsePrivateName();
        } else {
          node.property = this.parseIdentifier(true);
        }
        if (state.optionalChainMember) {
          node.optional = optional;
          return this.finishNode(node, "OptionalMemberExpression");
        } else {
          return this.finishNode(node, "MemberExpression");
        }
      }
      parseBind(base, startLoc, noCalls, state) {
        const node = this.startNodeAt(startLoc);
        node.object = base;
        this.next();
        node.callee = this.parseNoCallExpr();
        state.stop = true;
        return this.parseSubscripts(this.finishNode(node, "BindExpression"), startLoc, noCalls);
      }
      parseCoverCallAndAsyncArrowHead(base, startLoc, state, optional) {
        const oldMaybeInArrowParameters = this.state.maybeInArrowParameters;
        let refExpressionErrors = null;
        this.state.maybeInArrowParameters = true;
        this.next();
        const node = this.startNodeAt(startLoc);
        node.callee = base;
        const {
          maybeAsyncArrow,
          optionalChainMember
        } = state;
        if (maybeAsyncArrow) {
          this.expressionScope.enter(newAsyncArrowScope());
          refExpressionErrors = new ExpressionErrors();
        }
        if (optionalChainMember) {
          node.optional = optional;
        }
        if (optional) {
          node.arguments = this.parseCallExpressionArguments(11);
        } else {
          node.arguments = this.parseCallExpressionArguments(
            11,
            base.type === "Import",
            base.type !== "Super",
            node,
            refExpressionErrors
          );
        }
        let finishedNode = this.finishCallExpression(node, optionalChainMember);
        if (maybeAsyncArrow && this.shouldParseAsyncArrow() && !optional) {
          state.stop = true;
          this.checkDestructuringPrivate(refExpressionErrors);
          this.expressionScope.validateAsPattern();
          this.expressionScope.exit();
          finishedNode = this.parseAsyncArrowFromCallExpression(this.startNodeAt(startLoc), finishedNode);
        } else {
          if (maybeAsyncArrow) {
            this.checkExpressionErrors(refExpressionErrors, true);
            this.expressionScope.exit();
          }
          this.toReferencedArguments(finishedNode);
        }
        this.state.maybeInArrowParameters = oldMaybeInArrowParameters;
        return finishedNode;
      }
      toReferencedArguments(node, isParenthesizedExpr) {
        this.toReferencedListDeep(node.arguments, isParenthesizedExpr);
      }
      parseTaggedTemplateExpression(base, startLoc, state) {
        const node = this.startNodeAt(startLoc);
        node.tag = base;
        node.quasi = this.parseTemplate(true);
        if (state.optionalChainMember) {
          this.raise(Errors.OptionalChainingNoTemplate, {
            at: startLoc
          });
        }
        return this.finishNode(node, "TaggedTemplateExpression");
      }
      atPossibleAsyncArrow(base) {
        return base.type === "Identifier" && base.name === "async" && this.state.lastTokEndLoc.index === base.end && !this.canInsertSemicolon() && base.end - base.start === 5 && base.start === this.state.potentialArrowAt;
      }
      finishCallExpression(node, optional) {
        if (node.callee.type === "Import") {
          if (node.arguments.length === 2) {
            {
              if (!this.hasPlugin("moduleAttributes")) {
                this.expectPlugin("importAssertions");
              }
            }
          }
          if (node.arguments.length === 0 || node.arguments.length > 2) {
            this.raise(Errors.ImportCallArity, {
              at: node,
              maxArgumentCount: this.hasPlugin("importAssertions") || this.hasPlugin("moduleAttributes") ? 2 : 1
            });
          } else {
            for (const arg of node.arguments) {
              if (arg.type === "SpreadElement") {
                this.raise(Errors.ImportCallSpreadArgument, {
                  at: arg
                });
              }
            }
          }
        }
        return this.finishNode(node, optional ? "OptionalCallExpression" : "CallExpression");
      }
      parseCallExpressionArguments(close, dynamicImport, allowPlaceholder, nodeForExtra, refExpressionErrors) {
        const elts = [];
        let first2 = true;
        const oldInFSharpPipelineDirectBody = this.state.inFSharpPipelineDirectBody;
        this.state.inFSharpPipelineDirectBody = false;
        while (!this.eat(close)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12);
            if (this.match(close)) {
              if (dynamicImport && !this.hasPlugin("importAssertions") && !this.hasPlugin("moduleAttributes")) {
                this.raise(Errors.ImportCallArgumentTrailingComma, {
                  at: this.state.lastTokStartLoc
                });
              }
              if (nodeForExtra) {
                this.addTrailingCommaExtraToNode(nodeForExtra);
              }
              this.next();
              break;
            }
          }
          elts.push(this.parseExprListItem(false, refExpressionErrors, allowPlaceholder));
        }
        this.state.inFSharpPipelineDirectBody = oldInFSharpPipelineDirectBody;
        return elts;
      }
      shouldParseAsyncArrow() {
        return this.match(19) && !this.canInsertSemicolon();
      }
      parseAsyncArrowFromCallExpression(node, call) {
        var _call$extra;
        this.resetPreviousNodeTrailingComments(call);
        this.expect(19);
        this.parseArrowExpression(node, call.arguments, true, (_call$extra = call.extra) == null ? void 0 : _call$extra.trailingCommaLoc);
        if (call.innerComments) {
          setInnerComments(node, call.innerComments);
        }
        if (call.callee.trailingComments) {
          setInnerComments(node, call.callee.trailingComments);
        }
        return node;
      }
      parseNoCallExpr() {
        const startLoc = this.state.startLoc;
        return this.parseSubscripts(this.parseExprAtom(), startLoc, true);
      }
      parseExprAtom(refExpressionErrors) {
        let node;
        let decorators = null;
        const {
          type
        } = this.state;
        switch (type) {
          case 79:
            return this.parseSuper();
          case 83:
            node = this.startNode();
            this.next();
            if (this.match(16)) {
              return this.parseImportMetaProperty(node);
            }
            if (!this.match(10)) {
              this.raise(Errors.UnsupportedImport, {
                at: this.state.lastTokStartLoc
              });
            }
            return this.finishNode(node, "Import");
          case 78:
            node = this.startNode();
            this.next();
            return this.finishNode(node, "ThisExpression");
          case 90: {
            return this.parseDo(this.startNode(), false);
          }
          case 56:
          case 31: {
            this.readRegexp();
            return this.parseRegExpLiteral(this.state.value);
          }
          case 132:
            return this.parseNumericLiteral(this.state.value);
          case 133:
            return this.parseBigIntLiteral(this.state.value);
          case 134:
            return this.parseDecimalLiteral(this.state.value);
          case 131:
            return this.parseStringLiteral(this.state.value);
          case 84:
            return this.parseNullLiteral();
          case 85:
            return this.parseBooleanLiteral(true);
          case 86:
            return this.parseBooleanLiteral(false);
          case 10: {
            const canBeArrow = this.state.potentialArrowAt === this.state.start;
            return this.parseParenAndDistinguishExpression(canBeArrow);
          }
          case 2:
          case 1: {
            return this.parseArrayLike(this.state.type === 2 ? 4 : 3, false, true);
          }
          case 0: {
            return this.parseArrayLike(3, true, false, refExpressionErrors);
          }
          case 6:
          case 7: {
            return this.parseObjectLike(this.state.type === 6 ? 9 : 8, false, true);
          }
          case 5: {
            return this.parseObjectLike(8, false, false, refExpressionErrors);
          }
          case 68:
            return this.parseFunctionOrFunctionSent();
          case 26:
            decorators = this.parseDecorators();
          case 80:
            return this.parseClass(this.maybeTakeDecorators(decorators, this.startNode()), false);
          case 77:
            return this.parseNewOrNewTarget();
          case 25:
          case 24:
            return this.parseTemplate(false);
          case 15: {
            node = this.startNode();
            this.next();
            node.object = null;
            const callee = node.callee = this.parseNoCallExpr();
            if (callee.type === "MemberExpression") {
              return this.finishNode(node, "BindExpression");
            } else {
              throw this.raise(Errors.UnsupportedBind, {
                at: callee
              });
            }
          }
          case 136: {
            this.raise(Errors.PrivateInExpectedIn, {
              at: this.state.startLoc,
              identifierName: this.state.value
            });
            return this.parsePrivateName();
          }
          case 33: {
            return this.parseTopicReferenceThenEqualsSign(54, "%");
          }
          case 32: {
            return this.parseTopicReferenceThenEqualsSign(44, "^");
          }
          case 37:
          case 38: {
            return this.parseTopicReference("hack");
          }
          case 44:
          case 54:
          case 27: {
            const pipeProposal = this.getPluginOption("pipelineOperator", "proposal");
            if (pipeProposal) {
              return this.parseTopicReference(pipeProposal);
            } else {
              throw this.unexpected();
            }
          }
          case 47: {
            const lookaheadCh = this.input.codePointAt(this.nextTokenStart());
            if (isIdentifierStart(lookaheadCh) || lookaheadCh === 62) {
              this.expectOnePlugin(["jsx", "flow", "typescript"]);
              break;
            } else {
              throw this.unexpected();
            }
          }
          default:
            if (tokenIsIdentifier(type)) {
              if (this.isContextual(125) && this.lookaheadCharCode() === 123 && !this.hasFollowingLineBreak()) {
                return this.parseModuleExpression();
              }
              const canBeArrow = this.state.potentialArrowAt === this.state.start;
              const containsEsc = this.state.containsEsc;
              const id = this.parseIdentifier();
              if (!containsEsc && id.name === "async" && !this.canInsertSemicolon()) {
                const {
                  type: type2
                } = this.state;
                if (type2 === 68) {
                  this.resetPreviousNodeTrailingComments(id);
                  this.next();
                  return this.parseAsyncFunctionExpression(this.startNodeAtNode(id));
                } else if (tokenIsIdentifier(type2)) {
                  if (this.lookaheadCharCode() === 61) {
                    return this.parseAsyncArrowUnaryFunction(this.startNodeAtNode(id));
                  } else {
                    return id;
                  }
                } else if (type2 === 90) {
                  this.resetPreviousNodeTrailingComments(id);
                  return this.parseDo(this.startNodeAtNode(id), true);
                }
              }
              if (canBeArrow && this.match(19) && !this.canInsertSemicolon()) {
                this.next();
                return this.parseArrowExpression(this.startNodeAtNode(id), [id], false);
              }
              return id;
            } else {
              throw this.unexpected();
            }
        }
      }
      parseTopicReferenceThenEqualsSign(topicTokenType, topicTokenValue) {
        const pipeProposal = this.getPluginOption("pipelineOperator", "proposal");
        if (pipeProposal) {
          this.state.type = topicTokenType;
          this.state.value = topicTokenValue;
          this.state.pos--;
          this.state.end--;
          this.state.endLoc = createPositionWithColumnOffset(this.state.endLoc, -1);
          return this.parseTopicReference(pipeProposal);
        } else {
          throw this.unexpected();
        }
      }
      parseTopicReference(pipeProposal) {
        const node = this.startNode();
        const startLoc = this.state.startLoc;
        const tokenType = this.state.type;
        this.next();
        return this.finishTopicReference(node, startLoc, pipeProposal, tokenType);
      }
      finishTopicReference(node, startLoc, pipeProposal, tokenType) {
        if (this.testTopicReferenceConfiguration(pipeProposal, startLoc, tokenType)) {
          const nodeType = pipeProposal === "smart" ? "PipelinePrimaryTopicReference" : "TopicReference";
          if (!this.topicReferenceIsAllowedInCurrentContext()) {
            this.raise(
              pipeProposal === "smart" ? Errors.PrimaryTopicNotAllowed : Errors.PipeTopicUnbound,
              {
                at: startLoc
              }
            );
          }
          this.registerTopicReference();
          return this.finishNode(node, nodeType);
        } else {
          throw this.raise(Errors.PipeTopicUnconfiguredToken, {
            at: startLoc,
            token: tokenLabelName(tokenType)
          });
        }
      }
      testTopicReferenceConfiguration(pipeProposal, startLoc, tokenType) {
        switch (pipeProposal) {
          case "hack": {
            return this.hasPlugin(["pipelineOperator", {
              topicToken: tokenLabelName(tokenType)
            }]);
          }
          case "smart":
            return tokenType === 27;
          default:
            throw this.raise(Errors.PipeTopicRequiresHackPipes, {
              at: startLoc
            });
        }
      }
      parseAsyncArrowUnaryFunction(node) {
        this.prodParam.enter(functionFlags(true, this.prodParam.hasYield));
        const params = [this.parseIdentifier()];
        this.prodParam.exit();
        if (this.hasPrecedingLineBreak()) {
          this.raise(Errors.LineTerminatorBeforeArrow, {
            at: this.state.curPosition()
          });
        }
        this.expect(19);
        return this.parseArrowExpression(node, params, true);
      }
      parseDo(node, isAsync) {
        this.expectPlugin("doExpressions");
        if (isAsync) {
          this.expectPlugin("asyncDoExpressions");
        }
        node.async = isAsync;
        this.next();
        const oldLabels = this.state.labels;
        this.state.labels = [];
        if (isAsync) {
          this.prodParam.enter(PARAM_AWAIT);
          node.body = this.parseBlock();
          this.prodParam.exit();
        } else {
          node.body = this.parseBlock();
        }
        this.state.labels = oldLabels;
        return this.finishNode(node, "DoExpression");
      }
      parseSuper() {
        const node = this.startNode();
        this.next();
        if (this.match(10) && !this.scope.allowDirectSuper && !this.options.allowSuperOutsideMethod) {
          this.raise(Errors.SuperNotAllowed, {
            at: node
          });
        } else if (!this.scope.allowSuper && !this.options.allowSuperOutsideMethod) {
          this.raise(Errors.UnexpectedSuper, {
            at: node
          });
        }
        if (!this.match(10) && !this.match(0) && !this.match(16)) {
          this.raise(Errors.UnsupportedSuper, {
            at: node
          });
        }
        return this.finishNode(node, "Super");
      }
      parsePrivateName() {
        const node = this.startNode();
        const id = this.startNodeAt(
          createPositionWithColumnOffset(this.state.startLoc, 1)
        );
        const name = this.state.value;
        this.next();
        node.id = this.createIdentifier(id, name);
        return this.finishNode(node, "PrivateName");
      }
      parseFunctionOrFunctionSent() {
        const node = this.startNode();
        this.next();
        if (this.prodParam.hasYield && this.match(16)) {
          const meta = this.createIdentifier(this.startNodeAtNode(node), "function");
          this.next();
          if (this.match(102)) {
            this.expectPlugin("functionSent");
          } else if (!this.hasPlugin("functionSent")) {
            this.unexpected();
          }
          return this.parseMetaProperty(node, meta, "sent");
        }
        return this.parseFunction(node);
      }
      parseMetaProperty(node, meta, propertyName) {
        node.meta = meta;
        const containsEsc = this.state.containsEsc;
        node.property = this.parseIdentifier(true);
        if (node.property.name !== propertyName || containsEsc) {
          this.raise(Errors.UnsupportedMetaProperty, {
            at: node.property,
            target: meta.name,
            onlyValidPropertyName: propertyName
          });
        }
        return this.finishNode(node, "MetaProperty");
      }
      parseImportMetaProperty(node) {
        const id = this.createIdentifier(this.startNodeAtNode(node), "import");
        this.next();
        if (this.isContextual(100)) {
          if (!this.inModule) {
            this.raise(Errors.ImportMetaOutsideModule, {
              at: id
            });
          }
          this.sawUnambiguousESM = true;
        }
        return this.parseMetaProperty(node, id, "meta");
      }
      parseLiteralAtNode(value2, type, node) {
        this.addExtra(node, "rawValue", value2);
        this.addExtra(node, "raw", this.input.slice(node.start, this.state.end));
        node.value = value2;
        this.next();
        return this.finishNode(node, type);
      }
      parseLiteral(value2, type) {
        const node = this.startNode();
        return this.parseLiteralAtNode(value2, type, node);
      }
      parseStringLiteral(value2) {
        return this.parseLiteral(value2, "StringLiteral");
      }
      parseNumericLiteral(value2) {
        return this.parseLiteral(value2, "NumericLiteral");
      }
      parseBigIntLiteral(value2) {
        return this.parseLiteral(value2, "BigIntLiteral");
      }
      parseDecimalLiteral(value2) {
        return this.parseLiteral(value2, "DecimalLiteral");
      }
      parseRegExpLiteral(value2) {
        const node = this.parseLiteral(value2.value, "RegExpLiteral");
        node.pattern = value2.pattern;
        node.flags = value2.flags;
        return node;
      }
      parseBooleanLiteral(value2) {
        const node = this.startNode();
        node.value = value2;
        this.next();
        return this.finishNode(node, "BooleanLiteral");
      }
      parseNullLiteral() {
        const node = this.startNode();
        this.next();
        return this.finishNode(node, "NullLiteral");
      }
      parseParenAndDistinguishExpression(canBeArrow) {
        const startLoc = this.state.startLoc;
        let val;
        this.next();
        this.expressionScope.enter(newArrowHeadScope());
        const oldMaybeInArrowParameters = this.state.maybeInArrowParameters;
        const oldInFSharpPipelineDirectBody = this.state.inFSharpPipelineDirectBody;
        this.state.maybeInArrowParameters = true;
        this.state.inFSharpPipelineDirectBody = false;
        const innerStartLoc = this.state.startLoc;
        const exprList = [];
        const refExpressionErrors = new ExpressionErrors();
        let first2 = true;
        let spreadStartLoc;
        let optionalCommaStartLoc;
        while (!this.match(11)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12, refExpressionErrors.optionalParametersLoc === null ? null : refExpressionErrors.optionalParametersLoc);
            if (this.match(11)) {
              optionalCommaStartLoc = this.state.startLoc;
              break;
            }
          }
          if (this.match(21)) {
            const spreadNodeStartLoc = this.state.startLoc;
            spreadStartLoc = this.state.startLoc;
            exprList.push(this.parseParenItem(this.parseRestBinding(), spreadNodeStartLoc));
            if (!this.checkCommaAfterRest(41)) {
              break;
            }
          } else {
            exprList.push(this.parseMaybeAssignAllowIn(refExpressionErrors, this.parseParenItem));
          }
        }
        const innerEndLoc = this.state.lastTokEndLoc;
        this.expect(11);
        this.state.maybeInArrowParameters = oldMaybeInArrowParameters;
        this.state.inFSharpPipelineDirectBody = oldInFSharpPipelineDirectBody;
        let arrowNode = this.startNodeAt(startLoc);
        if (canBeArrow && this.shouldParseArrow(exprList) && (arrowNode = this.parseArrow(arrowNode))) {
          this.checkDestructuringPrivate(refExpressionErrors);
          this.expressionScope.validateAsPattern();
          this.expressionScope.exit();
          this.parseArrowExpression(arrowNode, exprList, false);
          return arrowNode;
        }
        this.expressionScope.exit();
        if (!exprList.length) {
          this.unexpected(this.state.lastTokStartLoc);
        }
        if (optionalCommaStartLoc)
          this.unexpected(optionalCommaStartLoc);
        if (spreadStartLoc)
          this.unexpected(spreadStartLoc);
        this.checkExpressionErrors(refExpressionErrors, true);
        this.toReferencedListDeep(exprList, true);
        if (exprList.length > 1) {
          val = this.startNodeAt(innerStartLoc);
          val.expressions = exprList;
          this.finishNode(val, "SequenceExpression");
          this.resetEndLocation(val, innerEndLoc);
        } else {
          val = exprList[0];
        }
        return this.wrapParenthesis(
          startLoc,
          val
        );
      }
      wrapParenthesis(startLoc, expression) {
        if (!this.options.createParenthesizedExpressions) {
          this.addExtra(expression, "parenthesized", true);
          this.addExtra(expression, "parenStart", startLoc.index);
          this.takeSurroundingComments(expression, startLoc.index, this.state.lastTokEndLoc.index);
          return expression;
        }
        const parenExpression = this.startNodeAt(startLoc);
        parenExpression.expression = expression;
        return this.finishNode(parenExpression, "ParenthesizedExpression");
      }
      shouldParseArrow(params) {
        return !this.canInsertSemicolon();
      }
      parseArrow(node) {
        if (this.eat(19)) {
          return node;
        }
      }
      parseParenItem(node, startLoc) {
        return node;
      }
      parseNewOrNewTarget() {
        const node = this.startNode();
        this.next();
        if (this.match(16)) {
          const meta = this.createIdentifier(this.startNodeAtNode(node), "new");
          this.next();
          const metaProp = this.parseMetaProperty(node, meta, "target");
          if (!this.scope.inNonArrowFunction && !this.scope.inClass) {
            this.raise(Errors.UnexpectedNewTarget, {
              at: metaProp
            });
          }
          return metaProp;
        }
        return this.parseNew(node);
      }
      parseNew(node) {
        this.parseNewCallee(node);
        if (this.eat(10)) {
          const args = this.parseExprList(11);
          this.toReferencedList(args);
          node.arguments = args;
        } else {
          node.arguments = [];
        }
        return this.finishNode(node, "NewExpression");
      }
      parseNewCallee(node) {
        node.callee = this.parseNoCallExpr();
        if (node.callee.type === "Import") {
          this.raise(Errors.ImportCallNotNewExpression, {
            at: node.callee
          });
        } else if (this.isOptionalChain(node.callee)) {
          this.raise(Errors.OptionalChainingNoNew, {
            at: this.state.lastTokEndLoc
          });
        } else if (this.eat(18)) {
          this.raise(Errors.OptionalChainingNoNew, {
            at: this.state.startLoc
          });
        }
      }
      parseTemplateElement(isTagged) {
        const {
          start,
          startLoc,
          end,
          value: value2
        } = this.state;
        const elemStart = start + 1;
        const elem = this.startNodeAt(createPositionWithColumnOffset(startLoc, 1));
        if (value2 === null) {
          if (!isTagged) {
            this.raise(Errors.InvalidEscapeSequenceTemplate, {
              at: createPositionWithColumnOffset(this.state.firstInvalidTemplateEscapePos, 1)
            });
          }
        }
        const isTail = this.match(24);
        const endOffset = isTail ? -1 : -2;
        const elemEnd = end + endOffset;
        elem.value = {
          raw: this.input.slice(elemStart, elemEnd).replace(/\r\n?/g, "\n"),
          cooked: value2 === null ? null : value2.slice(1, endOffset)
        };
        elem.tail = isTail;
        this.next();
        const finishedNode = this.finishNode(elem, "TemplateElement");
        this.resetEndLocation(finishedNode, createPositionWithColumnOffset(this.state.lastTokEndLoc, endOffset));
        return finishedNode;
      }
      parseTemplate(isTagged) {
        const node = this.startNode();
        node.expressions = [];
        let curElt = this.parseTemplateElement(isTagged);
        node.quasis = [curElt];
        while (!curElt.tail) {
          node.expressions.push(this.parseTemplateSubstitution());
          this.readTemplateContinuation();
          node.quasis.push(curElt = this.parseTemplateElement(isTagged));
        }
        return this.finishNode(node, "TemplateLiteral");
      }
      parseTemplateSubstitution() {
        return this.parseExpression();
      }
      parseObjectLike(close, isPattern, isRecord, refExpressionErrors) {
        if (isRecord) {
          this.expectPlugin("recordAndTuple");
        }
        const oldInFSharpPipelineDirectBody = this.state.inFSharpPipelineDirectBody;
        this.state.inFSharpPipelineDirectBody = false;
        const propHash = /* @__PURE__ */ Object.create(null);
        let first2 = true;
        const node = this.startNode();
        node.properties = [];
        this.next();
        while (!this.match(close)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12);
            if (this.match(close)) {
              this.addTrailingCommaExtraToNode(
                node
              );
              break;
            }
          }
          let prop;
          if (isPattern) {
            prop = this.parseBindingProperty();
          } else {
            prop = this.parsePropertyDefinition(refExpressionErrors);
            this.checkProto(prop, isRecord, propHash, refExpressionErrors);
          }
          if (isRecord && !this.isObjectProperty(prop) && prop.type !== "SpreadElement") {
            this.raise(Errors.InvalidRecordProperty, {
              at: prop
            });
          }
          if (prop.shorthand) {
            this.addExtra(prop, "shorthand", true);
          }
          node.properties.push(prop);
        }
        this.next();
        this.state.inFSharpPipelineDirectBody = oldInFSharpPipelineDirectBody;
        let type = "ObjectExpression";
        if (isPattern) {
          type = "ObjectPattern";
        } else if (isRecord) {
          type = "RecordExpression";
        }
        return this.finishNode(node, type);
      }
      addTrailingCommaExtraToNode(node) {
        this.addExtra(node, "trailingComma", this.state.lastTokStart);
        this.addExtra(node, "trailingCommaLoc", this.state.lastTokStartLoc, false);
      }
      maybeAsyncOrAccessorProp(prop) {
        return !prop.computed && prop.key.type === "Identifier" && (this.isLiteralPropertyName() || this.match(0) || this.match(55));
      }
      parsePropertyDefinition(refExpressionErrors) {
        let decorators = [];
        if (this.match(26)) {
          if (this.hasPlugin("decorators")) {
            this.raise(Errors.UnsupportedPropertyDecorator, {
              at: this.state.startLoc
            });
          }
          while (this.match(26)) {
            decorators.push(this.parseDecorator());
          }
        }
        const prop = this.startNode();
        let isAsync = false;
        let isAccessor = false;
        let startLoc;
        if (this.match(21)) {
          if (decorators.length)
            this.unexpected();
          return this.parseSpread();
        }
        if (decorators.length) {
          prop.decorators = decorators;
          decorators = [];
        }
        prop.method = false;
        if (refExpressionErrors) {
          startLoc = this.state.startLoc;
        }
        let isGenerator = this.eat(55);
        this.parsePropertyNamePrefixOperator(prop);
        const containsEsc = this.state.containsEsc;
        const key = this.parsePropertyName(prop, refExpressionErrors);
        if (!isGenerator && !containsEsc && this.maybeAsyncOrAccessorProp(prop)) {
          const keyName = key.name;
          if (keyName === "async" && !this.hasPrecedingLineBreak()) {
            isAsync = true;
            this.resetPreviousNodeTrailingComments(key);
            isGenerator = this.eat(55);
            this.parsePropertyName(prop);
          }
          if (keyName === "get" || keyName === "set") {
            isAccessor = true;
            this.resetPreviousNodeTrailingComments(key);
            prop.kind = keyName;
            if (this.match(55)) {
              isGenerator = true;
              this.raise(Errors.AccessorIsGenerator, {
                at: this.state.curPosition(),
                kind: keyName
              });
              this.next();
            }
            this.parsePropertyName(prop);
          }
        }
        return this.parseObjPropValue(prop, startLoc, isGenerator, isAsync, false, isAccessor, refExpressionErrors);
      }
      getGetterSetterExpectedParamCount(method) {
        return method.kind === "get" ? 0 : 1;
      }
      getObjectOrClassMethodParams(method) {
        return method.params;
      }
      checkGetterSetterParams(method) {
        var _params;
        const paramCount = this.getGetterSetterExpectedParamCount(method);
        const params = this.getObjectOrClassMethodParams(method);
        if (params.length !== paramCount) {
          this.raise(method.kind === "get" ? Errors.BadGetterArity : Errors.BadSetterArity, {
            at: method
          });
        }
        if (method.kind === "set" && ((_params = params[params.length - 1]) == null ? void 0 : _params.type) === "RestElement") {
          this.raise(Errors.BadSetterRestParameter, {
            at: method
          });
        }
      }
      parseObjectMethod(prop, isGenerator, isAsync, isPattern, isAccessor) {
        if (isAccessor) {
          const finishedProp = this.parseMethod(
            prop,
            isGenerator,
            false,
            false,
            false,
            "ObjectMethod"
          );
          this.checkGetterSetterParams(finishedProp);
          return finishedProp;
        }
        if (isAsync || isGenerator || this.match(10)) {
          if (isPattern)
            this.unexpected();
          prop.kind = "method";
          prop.method = true;
          return this.parseMethod(prop, isGenerator, isAsync, false, false, "ObjectMethod");
        }
      }
      parseObjectProperty(prop, startLoc, isPattern, refExpressionErrors) {
        prop.shorthand = false;
        if (this.eat(14)) {
          prop.value = isPattern ? this.parseMaybeDefault(this.state.startLoc) : this.parseMaybeAssignAllowIn(refExpressionErrors);
          return this.finishNode(prop, "ObjectProperty");
        }
        if (!prop.computed && prop.key.type === "Identifier") {
          this.checkReservedWord(prop.key.name, prop.key.loc.start, true, false);
          if (isPattern) {
            prop.value = this.parseMaybeDefault(startLoc, cloneIdentifier(prop.key));
          } else if (this.match(29)) {
            const shorthandAssignLoc = this.state.startLoc;
            if (refExpressionErrors != null) {
              if (refExpressionErrors.shorthandAssignLoc === null) {
                refExpressionErrors.shorthandAssignLoc = shorthandAssignLoc;
              }
            } else {
              this.raise(Errors.InvalidCoverInitializedName, {
                at: shorthandAssignLoc
              });
            }
            prop.value = this.parseMaybeDefault(startLoc, cloneIdentifier(prop.key));
          } else {
            prop.value = cloneIdentifier(prop.key);
          }
          prop.shorthand = true;
          return this.finishNode(prop, "ObjectProperty");
        }
      }
      parseObjPropValue(prop, startLoc, isGenerator, isAsync, isPattern, isAccessor, refExpressionErrors) {
        const node = this.parseObjectMethod(prop, isGenerator, isAsync, isPattern, isAccessor) || this.parseObjectProperty(prop, startLoc, isPattern, refExpressionErrors);
        if (!node)
          this.unexpected();
        return node;
      }
      parsePropertyName(prop, refExpressionErrors) {
        if (this.eat(0)) {
          prop.computed = true;
          prop.key = this.parseMaybeAssignAllowIn();
          this.expect(3);
        } else {
          const {
            type,
            value: value2
          } = this.state;
          let key;
          if (tokenIsKeywordOrIdentifier(type)) {
            key = this.parseIdentifier(true);
          } else {
            switch (type) {
              case 132:
                key = this.parseNumericLiteral(value2);
                break;
              case 131:
                key = this.parseStringLiteral(value2);
                break;
              case 133:
                key = this.parseBigIntLiteral(value2);
                break;
              case 134:
                key = this.parseDecimalLiteral(value2);
                break;
              case 136: {
                const privateKeyLoc = this.state.startLoc;
                if (refExpressionErrors != null) {
                  if (refExpressionErrors.privateKeyLoc === null) {
                    refExpressionErrors.privateKeyLoc = privateKeyLoc;
                  }
                } else {
                  this.raise(Errors.UnexpectedPrivateField, {
                    at: privateKeyLoc
                  });
                }
                key = this.parsePrivateName();
                break;
              }
              default:
                throw this.unexpected();
            }
          }
          prop.key = key;
          if (type !== 136) {
            prop.computed = false;
          }
        }
        return prop.key;
      }
      initFunction(node, isAsync) {
        node.id = null;
        node.generator = false;
        node.async = isAsync;
      }
      parseMethod(node, isGenerator, isAsync, isConstructor, allowDirectSuper, type, inClassScope = false) {
        this.initFunction(node, isAsync);
        node.generator = isGenerator;
        const allowModifiers = isConstructor;
        this.scope.enter(SCOPE_FUNCTION | SCOPE_SUPER | (inClassScope ? SCOPE_CLASS : 0) | (allowDirectSuper ? SCOPE_DIRECT_SUPER : 0));
        this.prodParam.enter(functionFlags(isAsync, node.generator));
        this.parseFunctionParams(node, allowModifiers);
        const finishedNode = this.parseFunctionBodyAndFinish(node, type, true);
        this.prodParam.exit();
        this.scope.exit();
        return finishedNode;
      }
      parseArrayLike(close, canBePattern, isTuple, refExpressionErrors) {
        if (isTuple) {
          this.expectPlugin("recordAndTuple");
        }
        const oldInFSharpPipelineDirectBody = this.state.inFSharpPipelineDirectBody;
        this.state.inFSharpPipelineDirectBody = false;
        const node = this.startNode();
        this.next();
        node.elements = this.parseExprList(
          close,
          !isTuple,
          refExpressionErrors,
          node
        );
        this.state.inFSharpPipelineDirectBody = oldInFSharpPipelineDirectBody;
        return this.finishNode(node, isTuple ? "TupleExpression" : "ArrayExpression");
      }
      parseArrowExpression(node, params, isAsync, trailingCommaLoc) {
        this.scope.enter(SCOPE_FUNCTION | SCOPE_ARROW);
        let flags = functionFlags(isAsync, false);
        if (!this.match(5) && this.prodParam.hasIn) {
          flags |= PARAM_IN;
        }
        this.prodParam.enter(flags);
        this.initFunction(node, isAsync);
        const oldMaybeInArrowParameters = this.state.maybeInArrowParameters;
        if (params) {
          this.state.maybeInArrowParameters = true;
          this.setArrowFunctionParameters(node, params, trailingCommaLoc);
        }
        this.state.maybeInArrowParameters = false;
        this.parseFunctionBody(node, true);
        this.prodParam.exit();
        this.scope.exit();
        this.state.maybeInArrowParameters = oldMaybeInArrowParameters;
        return this.finishNode(node, "ArrowFunctionExpression");
      }
      setArrowFunctionParameters(node, params, trailingCommaLoc) {
        this.toAssignableList(params, trailingCommaLoc, false);
        node.params = params;
      }
      parseFunctionBodyAndFinish(node, type, isMethod = false) {
        this.parseFunctionBody(node, false, isMethod);
        return this.finishNode(node, type);
      }
      parseFunctionBody(node, allowExpression, isMethod = false) {
        const isExpression2 = allowExpression && !this.match(5);
        this.expressionScope.enter(newExpressionScope());
        if (isExpression2) {
          node.body = this.parseMaybeAssign();
          this.checkParams(node, false, allowExpression, false);
        } else {
          const oldStrict = this.state.strict;
          const oldLabels = this.state.labels;
          this.state.labels = [];
          this.prodParam.enter(this.prodParam.currentFlags() | PARAM_RETURN);
          node.body = this.parseBlock(
            true,
            false,
            (hasStrictModeDirective) => {
              const nonSimple = !this.isSimpleParamList(node.params);
              if (hasStrictModeDirective && nonSimple) {
                this.raise(Errors.IllegalLanguageModeDirective, {
                  at: (node.kind === "method" || node.kind === "constructor") && !!node.key ? node.key.loc.end : node
                });
              }
              const strictModeChanged = !oldStrict && this.state.strict;
              this.checkParams(node, !this.state.strict && !allowExpression && !isMethod && !nonSimple, allowExpression, strictModeChanged);
              if (this.state.strict && node.id) {
                this.checkIdentifier(node.id, BIND_OUTSIDE, strictModeChanged);
              }
            }
          );
          this.prodParam.exit();
          this.state.labels = oldLabels;
        }
        this.expressionScope.exit();
      }
      isSimpleParameter(node) {
        return node.type === "Identifier";
      }
      isSimpleParamList(params) {
        for (let i = 0, len = params.length; i < len; i++) {
          if (!this.isSimpleParameter(params[i]))
            return false;
        }
        return true;
      }
      checkParams(node, allowDuplicates, isArrowFunction, strictModeChanged = true) {
        const checkClashes = !allowDuplicates && /* @__PURE__ */ new Set();
        const formalParameters = {
          type: "FormalParameters"
        };
        for (const param of node.params) {
          this.checkLVal(param, {
            in: formalParameters,
            binding: BIND_VAR,
            checkClashes,
            strictModeChanged
          });
        }
      }
      parseExprList(close, allowEmpty, refExpressionErrors, nodeForExtra) {
        const elts = [];
        let first2 = true;
        while (!this.eat(close)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12);
            if (this.match(close)) {
              if (nodeForExtra) {
                this.addTrailingCommaExtraToNode(nodeForExtra);
              }
              this.next();
              break;
            }
          }
          elts.push(this.parseExprListItem(allowEmpty, refExpressionErrors));
        }
        return elts;
      }
      parseExprListItem(allowEmpty, refExpressionErrors, allowPlaceholder) {
        let elt;
        if (this.match(12)) {
          if (!allowEmpty) {
            this.raise(Errors.UnexpectedToken, {
              at: this.state.curPosition(),
              unexpected: ","
            });
          }
          elt = null;
        } else if (this.match(21)) {
          const spreadNodeStartLoc = this.state.startLoc;
          elt = this.parseParenItem(this.parseSpread(refExpressionErrors), spreadNodeStartLoc);
        } else if (this.match(17)) {
          this.expectPlugin("partialApplication");
          if (!allowPlaceholder) {
            this.raise(Errors.UnexpectedArgumentPlaceholder, {
              at: this.state.startLoc
            });
          }
          const node = this.startNode();
          this.next();
          elt = this.finishNode(node, "ArgumentPlaceholder");
        } else {
          elt = this.parseMaybeAssignAllowIn(refExpressionErrors, this.parseParenItem);
        }
        return elt;
      }
      parseIdentifier(liberal) {
        const node = this.startNode();
        const name = this.parseIdentifierName(liberal);
        return this.createIdentifier(node, name);
      }
      createIdentifier(node, name) {
        node.name = name;
        node.loc.identifierName = name;
        return this.finishNode(node, "Identifier");
      }
      parseIdentifierName(liberal) {
        let name;
        const {
          startLoc,
          type
        } = this.state;
        if (tokenIsKeywordOrIdentifier(type)) {
          name = this.state.value;
        } else {
          throw this.unexpected();
        }
        const tokenIsKeyword2 = tokenKeywordOrIdentifierIsKeyword(type);
        if (liberal) {
          if (tokenIsKeyword2) {
            this.replaceToken(130);
          }
        } else {
          this.checkReservedWord(name, startLoc, tokenIsKeyword2, false);
        }
        this.next();
        return name;
      }
      checkReservedWord(word, startLoc, checkKeywords, isBinding) {
        if (word.length > 10) {
          return;
        }
        if (!canBeReservedWord(word)) {
          return;
        }
        if (word === "yield") {
          if (this.prodParam.hasYield) {
            this.raise(Errors.YieldBindingIdentifier, {
              at: startLoc
            });
            return;
          }
        } else if (word === "await") {
          if (this.prodParam.hasAwait) {
            this.raise(Errors.AwaitBindingIdentifier, {
              at: startLoc
            });
            return;
          }
          if (this.scope.inStaticBlock) {
            this.raise(Errors.AwaitBindingIdentifierInStaticBlock, {
              at: startLoc
            });
            return;
          }
          this.expressionScope.recordAsyncArrowParametersError({
            at: startLoc
          });
        } else if (word === "arguments") {
          if (this.scope.inClassAndNotInNonArrowFunction) {
            this.raise(Errors.ArgumentsInClass, {
              at: startLoc
            });
            return;
          }
        }
        if (checkKeywords && isKeyword(word)) {
          this.raise(Errors.UnexpectedKeyword, {
            at: startLoc,
            keyword: word
          });
          return;
        }
        const reservedTest = !this.state.strict ? isReservedWord : isBinding ? isStrictBindReservedWord : isStrictReservedWord;
        if (reservedTest(word, this.inModule)) {
          this.raise(Errors.UnexpectedReservedWord, {
            at: startLoc,
            reservedWord: word
          });
        }
      }
      isAwaitAllowed() {
        if (this.prodParam.hasAwait)
          return true;
        if (this.options.allowAwaitOutsideFunction && !this.scope.inFunction) {
          return true;
        }
        return false;
      }
      parseAwait(startLoc) {
        const node = this.startNodeAt(startLoc);
        this.expressionScope.recordParameterInitializerError(Errors.AwaitExpressionFormalParameter, {
          at: node
        });
        if (this.eat(55)) {
          this.raise(Errors.ObsoleteAwaitStar, {
            at: node
          });
        }
        if (!this.scope.inFunction && !this.options.allowAwaitOutsideFunction) {
          if (this.isAmbiguousAwait()) {
            this.ambiguousScriptDifferentAst = true;
          } else {
            this.sawUnambiguousESM = true;
          }
        }
        if (!this.state.soloAwait) {
          node.argument = this.parseMaybeUnary(null, true);
        }
        return this.finishNode(node, "AwaitExpression");
      }
      isAmbiguousAwait() {
        if (this.hasPrecedingLineBreak())
          return true;
        const {
          type
        } = this.state;
        return type === 53 || type === 10 || type === 0 || tokenIsTemplate(type) || type === 101 && !this.state.containsEsc || type === 135 || type === 56 || this.hasPlugin("v8intrinsic") && type === 54;
      }
      parseYield() {
        const node = this.startNode();
        this.expressionScope.recordParameterInitializerError(Errors.YieldInParameter, {
          at: node
        });
        this.next();
        let delegating = false;
        let argument = null;
        if (!this.hasPrecedingLineBreak()) {
          delegating = this.eat(55);
          switch (this.state.type) {
            case 13:
            case 137:
            case 8:
            case 11:
            case 3:
            case 9:
            case 14:
            case 12:
              if (!delegating)
                break;
            default:
              argument = this.parseMaybeAssign();
          }
        }
        node.delegate = delegating;
        node.argument = argument;
        return this.finishNode(node, "YieldExpression");
      }
      checkPipelineAtInfixOperator(left, leftStartLoc) {
        if (this.hasPlugin(["pipelineOperator", {
          proposal: "smart"
        }])) {
          if (left.type === "SequenceExpression") {
            this.raise(Errors.PipelineHeadSequenceExpression, {
              at: leftStartLoc
            });
          }
        }
      }
      parseSmartPipelineBodyInStyle(childExpr, startLoc) {
        if (this.isSimpleReference(childExpr)) {
          const bodyNode = this.startNodeAt(startLoc);
          bodyNode.callee = childExpr;
          return this.finishNode(bodyNode, "PipelineBareFunction");
        } else {
          const bodyNode = this.startNodeAt(startLoc);
          this.checkSmartPipeTopicBodyEarlyErrors(startLoc);
          bodyNode.expression = childExpr;
          return this.finishNode(bodyNode, "PipelineTopicExpression");
        }
      }
      isSimpleReference(expression) {
        switch (expression.type) {
          case "MemberExpression":
            return !expression.computed && this.isSimpleReference(expression.object);
          case "Identifier":
            return true;
          default:
            return false;
        }
      }
      checkSmartPipeTopicBodyEarlyErrors(startLoc) {
        if (this.match(19)) {
          throw this.raise(Errors.PipelineBodyNoArrow, {
            at: this.state.startLoc
          });
        }
        if (!this.topicReferenceWasUsedInCurrentContext()) {
          this.raise(Errors.PipelineTopicUnused, {
            at: startLoc
          });
        }
      }
      withTopicBindingContext(callback) {
        const outerContextTopicState = this.state.topicContext;
        this.state.topicContext = {
          maxNumOfResolvableTopics: 1,
          maxTopicIndex: null
        };
        try {
          return callback();
        } finally {
          this.state.topicContext = outerContextTopicState;
        }
      }
      withSmartMixTopicForbiddingContext(callback) {
        if (this.hasPlugin(["pipelineOperator", {
          proposal: "smart"
        }])) {
          const outerContextTopicState = this.state.topicContext;
          this.state.topicContext = {
            maxNumOfResolvableTopics: 0,
            maxTopicIndex: null
          };
          try {
            return callback();
          } finally {
            this.state.topicContext = outerContextTopicState;
          }
        } else {
          return callback();
        }
      }
      withSoloAwaitPermittingContext(callback) {
        const outerContextSoloAwaitState = this.state.soloAwait;
        this.state.soloAwait = true;
        try {
          return callback();
        } finally {
          this.state.soloAwait = outerContextSoloAwaitState;
        }
      }
      allowInAnd(callback) {
        const flags = this.prodParam.currentFlags();
        const prodParamToSet = PARAM_IN & ~flags;
        if (prodParamToSet) {
          this.prodParam.enter(flags | PARAM_IN);
          try {
            return callback();
          } finally {
            this.prodParam.exit();
          }
        }
        return callback();
      }
      disallowInAnd(callback) {
        const flags = this.prodParam.currentFlags();
        const prodParamToClear = PARAM_IN & flags;
        if (prodParamToClear) {
          this.prodParam.enter(flags & ~PARAM_IN);
          try {
            return callback();
          } finally {
            this.prodParam.exit();
          }
        }
        return callback();
      }
      registerTopicReference() {
        this.state.topicContext.maxTopicIndex = 0;
      }
      topicReferenceIsAllowedInCurrentContext() {
        return this.state.topicContext.maxNumOfResolvableTopics >= 1;
      }
      topicReferenceWasUsedInCurrentContext() {
        return this.state.topicContext.maxTopicIndex != null && this.state.topicContext.maxTopicIndex >= 0;
      }
      parseFSharpPipelineBody(prec) {
        const startLoc = this.state.startLoc;
        this.state.potentialArrowAt = this.state.start;
        const oldInFSharpPipelineDirectBody = this.state.inFSharpPipelineDirectBody;
        this.state.inFSharpPipelineDirectBody = true;
        const ret = this.parseExprOp(this.parseMaybeUnaryOrPrivate(), startLoc, prec);
        this.state.inFSharpPipelineDirectBody = oldInFSharpPipelineDirectBody;
        return ret;
      }
      parseModuleExpression() {
        this.expectPlugin("moduleBlocks");
        const node = this.startNode();
        this.next();
        if (!this.match(5)) {
          this.unexpected(null, 5);
        }
        const program2 = this.startNodeAt(this.state.endLoc);
        this.next();
        const revertScopes = this.initializeScopes(true);
        this.enterInitialScopes();
        try {
          node.body = this.parseProgram(program2, 8, "module");
        } finally {
          revertScopes();
        }
        return this.finishNode(node, "ModuleExpression");
      }
      parsePropertyNamePrefixOperator(prop) {
      }
    };
    var loopLabel = {
      kind: "loop"
    };
    var switchLabel = {
      kind: "switch"
    };
    var ParseFunctionFlag = {
      Expression: 0,
      Declaration: 1,
      HangingDeclaration: 2,
      NullableId: 4,
      Async: 8
    };
    var ParseStatementFlag = {
      StatementOnly: 0,
      AllowImportExport: 1,
      AllowDeclaration: 2,
      AllowFunctionDeclaration: 4,
      AllowLabeledFunction: 8
    };
    var loneSurrogate = /[\uD800-\uDFFF]/u;
    var keywordRelationalOperator = /in(?:stanceof)?/y;
    function babel7CompatTokens(tokens, input) {
      for (let i = 0; i < tokens.length; i++) {
        const token = tokens[i];
        const {
          type
        } = token;
        if (typeof type === "number") {
          {
            if (type === 136) {
              const {
                loc,
                start,
                value: value2,
                end
              } = token;
              const hashEndPos = start + 1;
              const hashEndLoc = createPositionWithColumnOffset(loc.start, 1);
              tokens.splice(i, 1, new Token({
                type: getExportedToken(27),
                value: "#",
                start,
                end: hashEndPos,
                startLoc: loc.start,
                endLoc: hashEndLoc
              }), new Token({
                type: getExportedToken(130),
                value: value2,
                start: hashEndPos,
                end,
                startLoc: hashEndLoc,
                endLoc: loc.end
              }));
              i++;
              continue;
            }
            if (tokenIsTemplate(type)) {
              const {
                loc,
                start,
                value: value2,
                end
              } = token;
              const backquoteEnd = start + 1;
              const backquoteEndLoc = createPositionWithColumnOffset(loc.start, 1);
              let startToken;
              if (input.charCodeAt(start) === 96) {
                startToken = new Token({
                  type: getExportedToken(22),
                  value: "`",
                  start,
                  end: backquoteEnd,
                  startLoc: loc.start,
                  endLoc: backquoteEndLoc
                });
              } else {
                startToken = new Token({
                  type: getExportedToken(8),
                  value: "}",
                  start,
                  end: backquoteEnd,
                  startLoc: loc.start,
                  endLoc: backquoteEndLoc
                });
              }
              let templateValue, templateElementEnd, templateElementEndLoc, endToken;
              if (type === 24) {
                templateElementEnd = end - 1;
                templateElementEndLoc = createPositionWithColumnOffset(loc.end, -1);
                templateValue = value2 === null ? null : value2.slice(1, -1);
                endToken = new Token({
                  type: getExportedToken(22),
                  value: "`",
                  start: templateElementEnd,
                  end,
                  startLoc: templateElementEndLoc,
                  endLoc: loc.end
                });
              } else {
                templateElementEnd = end - 2;
                templateElementEndLoc = createPositionWithColumnOffset(loc.end, -2);
                templateValue = value2 === null ? null : value2.slice(1, -2);
                endToken = new Token({
                  type: getExportedToken(23),
                  value: "${",
                  start: templateElementEnd,
                  end,
                  startLoc: templateElementEndLoc,
                  endLoc: loc.end
                });
              }
              tokens.splice(i, 1, startToken, new Token({
                type: getExportedToken(20),
                value: templateValue,
                start: backquoteEnd,
                end: templateElementEnd,
                startLoc: backquoteEndLoc,
                endLoc: templateElementEndLoc
              }), endToken);
              i += 2;
              continue;
            }
          }
          token.type = getExportedToken(type);
        }
      }
      return tokens;
    }
    var StatementParser = class extends ExpressionParser {
      parseTopLevel(file, program2) {
        file.program = this.parseProgram(program2);
        file.comments = this.state.comments;
        if (this.options.tokens) {
          file.tokens = babel7CompatTokens(this.tokens, this.input);
        }
        return this.finishNode(file, "File");
      }
      parseProgram(program2, end = 137, sourceType = this.options.sourceType) {
        program2.sourceType = sourceType;
        program2.interpreter = this.parseInterpreterDirective();
        this.parseBlockBody(program2, true, true, end);
        if (this.inModule && !this.options.allowUndeclaredExports && this.scope.undefinedExports.size > 0) {
          for (const [localName, at] of Array.from(this.scope.undefinedExports)) {
            this.raise(Errors.ModuleExportUndefined, {
              at,
              localName
            });
          }
        }
        let finishedProgram;
        if (end === 137) {
          finishedProgram = this.finishNode(program2, "Program");
        } else {
          finishedProgram = this.finishNodeAt(program2, "Program", createPositionWithColumnOffset(this.state.startLoc, -1));
        }
        return finishedProgram;
      }
      stmtToDirective(stmt) {
        const directive = stmt;
        directive.type = "Directive";
        directive.value = directive.expression;
        delete directive.expression;
        const directiveLiteral = directive.value;
        const expressionValue = directiveLiteral.value;
        const raw = this.input.slice(directiveLiteral.start, directiveLiteral.end);
        const val = directiveLiteral.value = raw.slice(1, -1);
        this.addExtra(directiveLiteral, "raw", raw);
        this.addExtra(directiveLiteral, "rawValue", val);
        this.addExtra(directiveLiteral, "expressionValue", expressionValue);
        directiveLiteral.type = "DirectiveLiteral";
        return directive;
      }
      parseInterpreterDirective() {
        if (!this.match(28)) {
          return null;
        }
        const node = this.startNode();
        node.value = this.state.value;
        this.next();
        return this.finishNode(node, "InterpreterDirective");
      }
      isLet() {
        if (!this.isContextual(99)) {
          return false;
        }
        return this.hasFollowingBindingAtom();
      }
      chStartsBindingIdentifier(ch, pos) {
        if (isIdentifierStart(ch)) {
          keywordRelationalOperator.lastIndex = pos;
          if (keywordRelationalOperator.test(this.input)) {
            const endCh = this.codePointAtPos(keywordRelationalOperator.lastIndex);
            if (!isIdentifierChar(endCh) && endCh !== 92) {
              return false;
            }
          }
          return true;
        } else if (ch === 92) {
          return true;
        } else {
          return false;
        }
      }
      chStartsBindingPattern(ch) {
        return ch === 91 || ch === 123;
      }
      hasFollowingBindingAtom() {
        const next = this.nextTokenStart();
        const nextCh = this.codePointAtPos(next);
        return this.chStartsBindingPattern(nextCh) || this.chStartsBindingIdentifier(nextCh, next);
      }
      hasFollowingBindingIdentifier() {
        const next = this.nextTokenStart();
        const nextCh = this.codePointAtPos(next);
        return this.chStartsBindingIdentifier(nextCh, next);
      }
      startsUsingForOf() {
        const lookahead = this.lookahead();
        if (lookahead.type === 101 && !lookahead.containsEsc) {
          return false;
        } else {
          this.expectPlugin("explicitResourceManagement");
          return true;
        }
      }
      parseModuleItem() {
        return this.parseStatementLike(ParseStatementFlag.AllowImportExport | ParseStatementFlag.AllowDeclaration | ParseStatementFlag.AllowFunctionDeclaration | ParseStatementFlag.AllowLabeledFunction);
      }
      parseStatementListItem() {
        return this.parseStatementLike(ParseStatementFlag.AllowDeclaration | ParseStatementFlag.AllowFunctionDeclaration | ParseStatementFlag.AllowLabeledFunction);
      }
      parseStatementOrFunctionDeclaration(disallowLabeledFunction) {
        return this.parseStatementLike(ParseStatementFlag.AllowFunctionDeclaration | (disallowLabeledFunction ? 0 : ParseStatementFlag.AllowLabeledFunction));
      }
      parseStatement() {
        return this.parseStatementLike(ParseStatementFlag.StatementOnly);
      }
      parseStatementLike(flags) {
        let decorators = null;
        if (this.match(26)) {
          decorators = this.parseDecorators(true);
        }
        return this.parseStatementContent(flags, decorators);
      }
      parseStatementContent(flags, decorators) {
        const starttype = this.state.type;
        const node = this.startNode();
        const allowDeclaration = !!(flags & ParseStatementFlag.AllowDeclaration);
        const allowFunctionDeclaration = !!(flags & ParseStatementFlag.AllowFunctionDeclaration);
        const topLevel = flags & ParseStatementFlag.AllowImportExport;
        switch (starttype) {
          case 60:
            return this.parseBreakContinueStatement(node, true);
          case 63:
            return this.parseBreakContinueStatement(node, false);
          case 64:
            return this.parseDebuggerStatement(node);
          case 90:
            return this.parseDoWhileStatement(node);
          case 91:
            return this.parseForStatement(node);
          case 68:
            if (this.lookaheadCharCode() === 46)
              break;
            if (!allowDeclaration) {
              if (this.state.strict) {
                this.raise(Errors.StrictFunction, {
                  at: this.state.startLoc
                });
              } else if (!allowFunctionDeclaration) {
                this.raise(Errors.SloppyFunction, {
                  at: this.state.startLoc
                });
              }
            }
            return this.parseFunctionStatement(node, false, !allowDeclaration && allowFunctionDeclaration);
          case 80:
            if (!allowDeclaration)
              this.unexpected();
            return this.parseClass(this.maybeTakeDecorators(decorators, node), true);
          case 69:
            return this.parseIfStatement(node);
          case 70:
            return this.parseReturnStatement(node);
          case 71:
            return this.parseSwitchStatement(node);
          case 72:
            return this.parseThrowStatement(node);
          case 73:
            return this.parseTryStatement(node);
          case 105:
            if (this.hasFollowingLineBreak() || this.state.containsEsc || !this.hasFollowingBindingIdentifier()) {
              break;
            }
            this.expectPlugin("explicitResourceManagement");
            if (!this.scope.inModule && this.scope.inTopLevel) {
              this.raise(Errors.UnexpectedUsingDeclaration, {
                at: this.state.startLoc
              });
            } else if (!allowDeclaration) {
              this.raise(Errors.UnexpectedLexicalDeclaration, {
                at: this.state.startLoc
              });
            }
            return this.parseVarStatement(node, "using");
          case 99: {
            if (this.state.containsEsc) {
              break;
            }
            const next = this.nextTokenStart();
            const nextCh = this.codePointAtPos(next);
            if (nextCh !== 91) {
              if (!allowDeclaration && this.hasFollowingLineBreak())
                break;
              if (!this.chStartsBindingIdentifier(nextCh, next) && nextCh !== 123) {
                break;
              }
            }
          }
          case 75: {
            if (!allowDeclaration) {
              this.raise(Errors.UnexpectedLexicalDeclaration, {
                at: this.state.startLoc
              });
            }
          }
          case 74: {
            const kind = this.state.value;
            return this.parseVarStatement(node, kind);
          }
          case 92:
            return this.parseWhileStatement(node);
          case 76:
            return this.parseWithStatement(node);
          case 5:
            return this.parseBlock();
          case 13:
            return this.parseEmptyStatement(node);
          case 83: {
            const nextTokenCharCode = this.lookaheadCharCode();
            if (nextTokenCharCode === 40 || nextTokenCharCode === 46) {
              break;
            }
          }
          case 82: {
            if (!this.options.allowImportExportEverywhere && !topLevel) {
              this.raise(Errors.UnexpectedImportExport, {
                at: this.state.startLoc
              });
            }
            this.next();
            let result;
            if (starttype === 83) {
              result = this.parseImport(node);
              if (result.type === "ImportDeclaration" && (!result.importKind || result.importKind === "value")) {
                this.sawUnambiguousESM = true;
              }
            } else {
              result = this.parseExport(node, decorators);
              if (result.type === "ExportNamedDeclaration" && (!result.exportKind || result.exportKind === "value") || result.type === "ExportAllDeclaration" && (!result.exportKind || result.exportKind === "value") || result.type === "ExportDefaultDeclaration") {
                this.sawUnambiguousESM = true;
              }
            }
            this.assertModuleNodeAllowed(result);
            return result;
          }
          default: {
            if (this.isAsyncFunction()) {
              if (!allowDeclaration) {
                this.raise(Errors.AsyncFunctionInSingleStatementContext, {
                  at: this.state.startLoc
                });
              }
              this.next();
              return this.parseFunctionStatement(node, true, !allowDeclaration && allowFunctionDeclaration);
            }
          }
        }
        const maybeName = this.state.value;
        const expr = this.parseExpression();
        if (tokenIsIdentifier(starttype) && expr.type === "Identifier" && this.eat(14)) {
          return this.parseLabeledStatement(
            node,
            maybeName,
            expr,
            flags
          );
        } else {
          return this.parseExpressionStatement(node, expr, decorators);
        }
      }
      assertModuleNodeAllowed(node) {
        if (!this.options.allowImportExportEverywhere && !this.inModule) {
          this.raise(Errors.ImportOutsideModule, {
            at: node
          });
        }
      }
      decoratorsEnabledBeforeExport() {
        if (this.hasPlugin("decorators-legacy"))
          return true;
        return this.hasPlugin("decorators") && !!this.getPluginOption("decorators", "decoratorsBeforeExport");
      }
      maybeTakeDecorators(maybeDecorators, classNode, exportNode) {
        if (maybeDecorators) {
          classNode.decorators = maybeDecorators;
          this.resetStartLocationFromNode(classNode, maybeDecorators[0]);
          if (exportNode)
            this.resetStartLocationFromNode(exportNode, classNode);
        }
        return classNode;
      }
      canHaveLeadingDecorator() {
        return this.match(80);
      }
      parseDecorators(allowExport) {
        const decorators = [];
        do {
          decorators.push(this.parseDecorator());
        } while (this.match(26));
        if (this.match(82)) {
          if (!allowExport) {
            this.unexpected();
          }
          if (!this.decoratorsEnabledBeforeExport()) {
            this.raise(Errors.DecoratorExportClass, {
              at: this.state.startLoc
            });
          }
        } else if (!this.canHaveLeadingDecorator()) {
          throw this.raise(Errors.UnexpectedLeadingDecorator, {
            at: this.state.startLoc
          });
        }
        return decorators;
      }
      parseDecorator() {
        this.expectOnePlugin(["decorators", "decorators-legacy"]);
        const node = this.startNode();
        this.next();
        if (this.hasPlugin("decorators")) {
          const startLoc = this.state.startLoc;
          let expr;
          if (this.match(10)) {
            const startLoc2 = this.state.startLoc;
            this.next();
            expr = this.parseExpression();
            this.expect(11);
            expr = this.wrapParenthesis(startLoc2, expr);
            const paramsStartLoc = this.state.startLoc;
            node.expression = this.parseMaybeDecoratorArguments(expr);
            if (this.getPluginOption("decorators", "allowCallParenthesized") === false && node.expression !== expr) {
              this.raise(Errors.DecoratorArgumentsOutsideParentheses, {
                at: paramsStartLoc
              });
            }
          } else {
            expr = this.parseIdentifier(false);
            while (this.eat(16)) {
              const node2 = this.startNodeAt(startLoc);
              node2.object = expr;
              if (this.match(136)) {
                this.classScope.usePrivateName(this.state.value, this.state.startLoc);
                node2.property = this.parsePrivateName();
              } else {
                node2.property = this.parseIdentifier(true);
              }
              node2.computed = false;
              expr = this.finishNode(node2, "MemberExpression");
            }
            node.expression = this.parseMaybeDecoratorArguments(expr);
          }
        } else {
          node.expression = this.parseExprSubscripts();
        }
        return this.finishNode(node, "Decorator");
      }
      parseMaybeDecoratorArguments(expr) {
        if (this.eat(10)) {
          const node = this.startNodeAtNode(expr);
          node.callee = expr;
          node.arguments = this.parseCallExpressionArguments(11, false);
          this.toReferencedList(node.arguments);
          return this.finishNode(node, "CallExpression");
        }
        return expr;
      }
      parseBreakContinueStatement(node, isBreak) {
        this.next();
        if (this.isLineTerminator()) {
          node.label = null;
        } else {
          node.label = this.parseIdentifier();
          this.semicolon();
        }
        this.verifyBreakContinue(node, isBreak);
        return this.finishNode(node, isBreak ? "BreakStatement" : "ContinueStatement");
      }
      verifyBreakContinue(node, isBreak) {
        let i;
        for (i = 0; i < this.state.labels.length; ++i) {
          const lab = this.state.labels[i];
          if (node.label == null || lab.name === node.label.name) {
            if (lab.kind != null && (isBreak || lab.kind === "loop"))
              break;
            if (node.label && isBreak)
              break;
          }
        }
        if (i === this.state.labels.length) {
          const type = isBreak ? "BreakStatement" : "ContinueStatement";
          this.raise(Errors.IllegalBreakContinue, {
            at: node,
            type
          });
        }
      }
      parseDebuggerStatement(node) {
        this.next();
        this.semicolon();
        return this.finishNode(node, "DebuggerStatement");
      }
      parseHeaderExpression() {
        this.expect(10);
        const val = this.parseExpression();
        this.expect(11);
        return val;
      }
      parseDoWhileStatement(node) {
        this.next();
        this.state.labels.push(loopLabel);
        node.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement());
        this.state.labels.pop();
        this.expect(92);
        node.test = this.parseHeaderExpression();
        this.eat(13);
        return this.finishNode(node, "DoWhileStatement");
      }
      parseForStatement(node) {
        this.next();
        this.state.labels.push(loopLabel);
        let awaitAt = null;
        if (this.isAwaitAllowed() && this.eatContextual(96)) {
          awaitAt = this.state.lastTokStartLoc;
        }
        this.scope.enter(SCOPE_OTHER);
        this.expect(10);
        if (this.match(13)) {
          if (awaitAt !== null) {
            this.unexpected(awaitAt);
          }
          return this.parseFor(node, null);
        }
        const startsWithLet = this.isContextual(99);
        const startsWithUsing = this.isContextual(105) && !this.hasFollowingLineBreak();
        const isLetOrUsing = startsWithLet && this.hasFollowingBindingAtom() || startsWithUsing && this.hasFollowingBindingIdentifier() && this.startsUsingForOf();
        if (this.match(74) || this.match(75) || isLetOrUsing) {
          const initNode = this.startNode();
          const kind = this.state.value;
          this.next();
          this.parseVar(initNode, true, kind);
          const init2 = this.finishNode(initNode, "VariableDeclaration");
          const isForIn = this.match(58);
          if (isForIn && startsWithUsing) {
            this.raise(Errors.ForInUsing, {
              at: init2
            });
          }
          if ((isForIn || this.isContextual(101)) && init2.declarations.length === 1) {
            return this.parseForIn(node, init2, awaitAt);
          }
          if (awaitAt !== null) {
            this.unexpected(awaitAt);
          }
          return this.parseFor(node, init2);
        }
        const startsWithAsync = this.isContextual(95);
        const refExpressionErrors = new ExpressionErrors();
        const init = this.parseExpression(true, refExpressionErrors);
        const isForOf = this.isContextual(101);
        if (isForOf) {
          if (startsWithLet) {
            this.raise(Errors.ForOfLet, {
              at: init
            });
          }
          if (awaitAt === null && startsWithAsync && init.type === "Identifier") {
            this.raise(Errors.ForOfAsync, {
              at: init
            });
          }
        }
        if (isForOf || this.match(58)) {
          this.checkDestructuringPrivate(refExpressionErrors);
          this.toAssignable(init, true);
          const type = isForOf ? "ForOfStatement" : "ForInStatement";
          this.checkLVal(init, {
            in: {
              type
            }
          });
          return this.parseForIn(
            node,
            init,
            awaitAt
          );
        } else {
          this.checkExpressionErrors(refExpressionErrors, true);
        }
        if (awaitAt !== null) {
          this.unexpected(awaitAt);
        }
        return this.parseFor(node, init);
      }
      parseFunctionStatement(node, isAsync, isHangingDeclaration) {
        this.next();
        return this.parseFunction(node, ParseFunctionFlag.Declaration | (isHangingDeclaration ? ParseFunctionFlag.HangingDeclaration : 0) | (isAsync ? ParseFunctionFlag.Async : 0));
      }
      parseIfStatement(node) {
        this.next();
        node.test = this.parseHeaderExpression();
        node.consequent = this.parseStatementOrFunctionDeclaration(
          true
        );
        node.alternate = this.eat(66) ? this.parseStatementOrFunctionDeclaration(true) : null;
        return this.finishNode(node, "IfStatement");
      }
      parseReturnStatement(node) {
        if (!this.prodParam.hasReturn && !this.options.allowReturnOutsideFunction) {
          this.raise(Errors.IllegalReturn, {
            at: this.state.startLoc
          });
        }
        this.next();
        if (this.isLineTerminator()) {
          node.argument = null;
        } else {
          node.argument = this.parseExpression();
          this.semicolon();
        }
        return this.finishNode(node, "ReturnStatement");
      }
      parseSwitchStatement(node) {
        this.next();
        node.discriminant = this.parseHeaderExpression();
        const cases = node.cases = [];
        this.expect(5);
        this.state.labels.push(switchLabel);
        this.scope.enter(SCOPE_OTHER);
        let cur;
        for (let sawDefault; !this.match(8); ) {
          if (this.match(61) || this.match(65)) {
            const isCase = this.match(61);
            if (cur)
              this.finishNode(cur, "SwitchCase");
            cases.push(cur = this.startNode());
            cur.consequent = [];
            this.next();
            if (isCase) {
              cur.test = this.parseExpression();
            } else {
              if (sawDefault) {
                this.raise(Errors.MultipleDefaultsInSwitch, {
                  at: this.state.lastTokStartLoc
                });
              }
              sawDefault = true;
              cur.test = null;
            }
            this.expect(14);
          } else {
            if (cur) {
              cur.consequent.push(this.parseStatementListItem());
            } else {
              this.unexpected();
            }
          }
        }
        this.scope.exit();
        if (cur)
          this.finishNode(cur, "SwitchCase");
        this.next();
        this.state.labels.pop();
        return this.finishNode(node, "SwitchStatement");
      }
      parseThrowStatement(node) {
        this.next();
        if (this.hasPrecedingLineBreak()) {
          this.raise(Errors.NewlineAfterThrow, {
            at: this.state.lastTokEndLoc
          });
        }
        node.argument = this.parseExpression();
        this.semicolon();
        return this.finishNode(node, "ThrowStatement");
      }
      parseCatchClauseParam() {
        const param = this.parseBindingAtom();
        const simple = param.type === "Identifier";
        this.scope.enter(simple ? SCOPE_SIMPLE_CATCH : 0);
        this.checkLVal(param, {
          in: {
            type: "CatchClause"
          },
          binding: BIND_LEXICAL,
          allowingSloppyLetBinding: true
        });
        return param;
      }
      parseTryStatement(node) {
        this.next();
        node.block = this.parseBlock();
        node.handler = null;
        if (this.match(62)) {
          const clause = this.startNode();
          this.next();
          if (this.match(10)) {
            this.expect(10);
            clause.param = this.parseCatchClauseParam();
            this.expect(11);
          } else {
            clause.param = null;
            this.scope.enter(SCOPE_OTHER);
          }
          clause.body = this.withSmartMixTopicForbiddingContext(() => this.parseBlock(false, false));
          this.scope.exit();
          node.handler = this.finishNode(clause, "CatchClause");
        }
        node.finalizer = this.eat(67) ? this.parseBlock() : null;
        if (!node.handler && !node.finalizer) {
          this.raise(Errors.NoCatchOrFinally, {
            at: node
          });
        }
        return this.finishNode(node, "TryStatement");
      }
      parseVarStatement(node, kind, allowMissingInitializer = false) {
        this.next();
        this.parseVar(node, false, kind, allowMissingInitializer);
        this.semicolon();
        return this.finishNode(node, "VariableDeclaration");
      }
      parseWhileStatement(node) {
        this.next();
        node.test = this.parseHeaderExpression();
        this.state.labels.push(loopLabel);
        node.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement());
        this.state.labels.pop();
        return this.finishNode(node, "WhileStatement");
      }
      parseWithStatement(node) {
        if (this.state.strict) {
          this.raise(Errors.StrictWith, {
            at: this.state.startLoc
          });
        }
        this.next();
        node.object = this.parseHeaderExpression();
        node.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement());
        return this.finishNode(node, "WithStatement");
      }
      parseEmptyStatement(node) {
        this.next();
        return this.finishNode(node, "EmptyStatement");
      }
      parseLabeledStatement(node, maybeName, expr, flags) {
        for (const label of this.state.labels) {
          if (label.name === maybeName) {
            this.raise(Errors.LabelRedeclaration, {
              at: expr,
              labelName: maybeName
            });
          }
        }
        const kind = tokenIsLoop(this.state.type) ? "loop" : this.match(71) ? "switch" : null;
        for (let i = this.state.labels.length - 1; i >= 0; i--) {
          const label = this.state.labels[i];
          if (label.statementStart === node.start) {
            label.statementStart = this.state.start;
            label.kind = kind;
          } else {
            break;
          }
        }
        this.state.labels.push({
          name: maybeName,
          kind,
          statementStart: this.state.start
        });
        node.body = flags & ParseStatementFlag.AllowLabeledFunction ? this.parseStatementOrFunctionDeclaration(false) : this.parseStatement();
        this.state.labels.pop();
        node.label = expr;
        return this.finishNode(node, "LabeledStatement");
      }
      parseExpressionStatement(node, expr, decorators) {
        node.expression = expr;
        this.semicolon();
        return this.finishNode(node, "ExpressionStatement");
      }
      parseBlock(allowDirectives = false, createNewLexicalScope = true, afterBlockParse) {
        const node = this.startNode();
        if (allowDirectives) {
          this.state.strictErrors.clear();
        }
        this.expect(5);
        if (createNewLexicalScope) {
          this.scope.enter(SCOPE_OTHER);
        }
        this.parseBlockBody(node, allowDirectives, false, 8, afterBlockParse);
        if (createNewLexicalScope) {
          this.scope.exit();
        }
        return this.finishNode(node, "BlockStatement");
      }
      isValidDirective(stmt) {
        return stmt.type === "ExpressionStatement" && stmt.expression.type === "StringLiteral" && !stmt.expression.extra.parenthesized;
      }
      parseBlockBody(node, allowDirectives, topLevel, end, afterBlockParse) {
        const body = node.body = [];
        const directives = node.directives = [];
        this.parseBlockOrModuleBlockBody(body, allowDirectives ? directives : void 0, topLevel, end, afterBlockParse);
      }
      parseBlockOrModuleBlockBody(body, directives, topLevel, end, afterBlockParse) {
        const oldStrict = this.state.strict;
        let hasStrictModeDirective = false;
        let parsedNonDirective = false;
        while (!this.match(end)) {
          const stmt = topLevel ? this.parseModuleItem() : this.parseStatementListItem();
          if (directives && !parsedNonDirective) {
            if (this.isValidDirective(stmt)) {
              const directive = this.stmtToDirective(stmt);
              directives.push(directive);
              if (!hasStrictModeDirective && directive.value.value === "use strict") {
                hasStrictModeDirective = true;
                this.setStrict(true);
              }
              continue;
            }
            parsedNonDirective = true;
            this.state.strictErrors.clear();
          }
          body.push(stmt);
        }
        if (afterBlockParse) {
          afterBlockParse.call(this, hasStrictModeDirective);
        }
        if (!oldStrict) {
          this.setStrict(false);
        }
        this.next();
      }
      parseFor(node, init) {
        node.init = init;
        this.semicolon(false);
        node.test = this.match(13) ? null : this.parseExpression();
        this.semicolon(false);
        node.update = this.match(11) ? null : this.parseExpression();
        this.expect(11);
        node.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement());
        this.scope.exit();
        this.state.labels.pop();
        return this.finishNode(node, "ForStatement");
      }
      parseForIn(node, init, awaitAt) {
        const isForIn = this.match(58);
        this.next();
        if (isForIn) {
          if (awaitAt !== null)
            this.unexpected(awaitAt);
        } else {
          node.await = awaitAt !== null;
        }
        if (init.type === "VariableDeclaration" && init.declarations[0].init != null && (!isForIn || this.state.strict || init.kind !== "var" || init.declarations[0].id.type !== "Identifier")) {
          this.raise(Errors.ForInOfLoopInitializer, {
            at: init,
            type: isForIn ? "ForInStatement" : "ForOfStatement"
          });
        }
        if (init.type === "AssignmentPattern") {
          this.raise(Errors.InvalidLhs, {
            at: init,
            ancestor: {
              type: "ForStatement"
            }
          });
        }
        node.left = init;
        node.right = isForIn ? this.parseExpression() : this.parseMaybeAssignAllowIn();
        this.expect(11);
        node.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement());
        this.scope.exit();
        this.state.labels.pop();
        return this.finishNode(node, isForIn ? "ForInStatement" : "ForOfStatement");
      }
      parseVar(node, isFor, kind, allowMissingInitializer = false) {
        const declarations = node.declarations = [];
        node.kind = kind;
        for (; ; ) {
          const decl = this.startNode();
          this.parseVarId(decl, kind);
          decl.init = !this.eat(29) ? null : isFor ? this.parseMaybeAssignDisallowIn() : this.parseMaybeAssignAllowIn();
          if (decl.init === null && !allowMissingInitializer) {
            if (decl.id.type !== "Identifier" && !(isFor && (this.match(58) || this.isContextual(101)))) {
              this.raise(Errors.DeclarationMissingInitializer, {
                at: this.state.lastTokEndLoc,
                kind: "destructuring"
              });
            } else if (kind === "const" && !(this.match(58) || this.isContextual(101))) {
              this.raise(Errors.DeclarationMissingInitializer, {
                at: this.state.lastTokEndLoc,
                kind: "const"
              });
            }
          }
          declarations.push(this.finishNode(decl, "VariableDeclarator"));
          if (!this.eat(12))
            break;
        }
        return node;
      }
      parseVarId(decl, kind) {
        const id = this.parseBindingAtom();
        this.checkLVal(id, {
          in: {
            type: "VariableDeclarator"
          },
          binding: kind === "var" ? BIND_VAR : BIND_LEXICAL
        });
        decl.id = id;
      }
      parseAsyncFunctionExpression(node) {
        return this.parseFunction(node, ParseFunctionFlag.Async);
      }
      parseFunction(node, flags = ParseFunctionFlag.Expression) {
        const hangingDeclaration = flags & ParseFunctionFlag.HangingDeclaration;
        const isDeclaration = !!(flags & ParseFunctionFlag.Declaration);
        const requireId = isDeclaration && !(flags & ParseFunctionFlag.NullableId);
        const isAsync = !!(flags & ParseFunctionFlag.Async);
        this.initFunction(node, isAsync);
        if (this.match(55)) {
          if (hangingDeclaration) {
            this.raise(Errors.GeneratorInSingleStatementContext, {
              at: this.state.startLoc
            });
          }
          this.next();
          node.generator = true;
        }
        if (isDeclaration) {
          node.id = this.parseFunctionId(requireId);
        }
        const oldMaybeInArrowParameters = this.state.maybeInArrowParameters;
        this.state.maybeInArrowParameters = false;
        this.scope.enter(SCOPE_FUNCTION);
        this.prodParam.enter(functionFlags(isAsync, node.generator));
        if (!isDeclaration) {
          node.id = this.parseFunctionId();
        }
        this.parseFunctionParams(node, false);
        this.withSmartMixTopicForbiddingContext(() => {
          this.parseFunctionBodyAndFinish(node, isDeclaration ? "FunctionDeclaration" : "FunctionExpression");
        });
        this.prodParam.exit();
        this.scope.exit();
        if (isDeclaration && !hangingDeclaration) {
          this.registerFunctionStatementId(node);
        }
        this.state.maybeInArrowParameters = oldMaybeInArrowParameters;
        return node;
      }
      parseFunctionId(requireId) {
        return requireId || tokenIsIdentifier(this.state.type) ? this.parseIdentifier() : null;
      }
      parseFunctionParams(node, allowModifiers) {
        this.expect(10);
        this.expressionScope.enter(newParameterDeclarationScope());
        node.params = this.parseBindingList(11, 41, false, allowModifiers);
        this.expressionScope.exit();
      }
      registerFunctionStatementId(node) {
        if (!node.id)
          return;
        this.scope.declareName(node.id.name, this.state.strict || node.generator || node.async ? this.scope.treatFunctionsAsVar ? BIND_VAR : BIND_LEXICAL : BIND_FUNCTION, node.id.loc.start);
      }
      parseClass(node, isStatement, optionalId) {
        this.next();
        const oldStrict = this.state.strict;
        this.state.strict = true;
        this.parseClassId(node, isStatement, optionalId);
        this.parseClassSuper(node);
        node.body = this.parseClassBody(!!node.superClass, oldStrict);
        return this.finishNode(node, isStatement ? "ClassDeclaration" : "ClassExpression");
      }
      isClassProperty() {
        return this.match(29) || this.match(13) || this.match(8);
      }
      isClassMethod() {
        return this.match(10);
      }
      isNonstaticConstructor(method) {
        return !method.computed && !method.static && (method.key.name === "constructor" || method.key.value === "constructor");
      }
      parseClassBody(hadSuperClass, oldStrict) {
        this.classScope.enter();
        const state = {
          hadConstructor: false,
          hadSuperClass
        };
        let decorators = [];
        const classBody = this.startNode();
        classBody.body = [];
        this.expect(5);
        this.withSmartMixTopicForbiddingContext(() => {
          while (!this.match(8)) {
            if (this.eat(13)) {
              if (decorators.length > 0) {
                throw this.raise(Errors.DecoratorSemicolon, {
                  at: this.state.lastTokEndLoc
                });
              }
              continue;
            }
            if (this.match(26)) {
              decorators.push(this.parseDecorator());
              continue;
            }
            const member = this.startNode();
            if (decorators.length) {
              member.decorators = decorators;
              this.resetStartLocationFromNode(member, decorators[0]);
              decorators = [];
            }
            this.parseClassMember(classBody, member, state);
            if (member.kind === "constructor" && member.decorators && member.decorators.length > 0) {
              this.raise(Errors.DecoratorConstructor, {
                at: member
              });
            }
          }
        });
        this.state.strict = oldStrict;
        this.next();
        if (decorators.length) {
          throw this.raise(Errors.TrailingDecorator, {
            at: this.state.startLoc
          });
        }
        this.classScope.exit();
        return this.finishNode(classBody, "ClassBody");
      }
      parseClassMemberFromModifier(classBody, member) {
        const key = this.parseIdentifier(true);
        if (this.isClassMethod()) {
          const method = member;
          method.kind = "method";
          method.computed = false;
          method.key = key;
          method.static = false;
          this.pushClassMethod(classBody, method, false, false, false, false);
          return true;
        } else if (this.isClassProperty()) {
          const prop = member;
          prop.computed = false;
          prop.key = key;
          prop.static = false;
          classBody.body.push(this.parseClassProperty(prop));
          return true;
        }
        this.resetPreviousNodeTrailingComments(key);
        return false;
      }
      parseClassMember(classBody, member, state) {
        const isStatic = this.isContextual(104);
        if (isStatic) {
          if (this.parseClassMemberFromModifier(classBody, member)) {
            return;
          }
          if (this.eat(5)) {
            this.parseClassStaticBlock(classBody, member);
            return;
          }
        }
        this.parseClassMemberWithIsStatic(classBody, member, state, isStatic);
      }
      parseClassMemberWithIsStatic(classBody, member, state, isStatic) {
        const publicMethod = member;
        const privateMethod = member;
        const publicProp = member;
        const privateProp = member;
        const accessorProp = member;
        const method = publicMethod;
        const publicMember = publicMethod;
        member.static = isStatic;
        this.parsePropertyNamePrefixOperator(member);
        if (this.eat(55)) {
          method.kind = "method";
          const isPrivateName = this.match(136);
          this.parseClassElementName(method);
          if (isPrivateName) {
            this.pushClassPrivateMethod(classBody, privateMethod, true, false);
            return;
          }
          if (this.isNonstaticConstructor(publicMethod)) {
            this.raise(Errors.ConstructorIsGenerator, {
              at: publicMethod.key
            });
          }
          this.pushClassMethod(classBody, publicMethod, true, false, false, false);
          return;
        }
        const isContextual = tokenIsIdentifier(this.state.type) && !this.state.containsEsc;
        const isPrivate = this.match(136);
        const key = this.parseClassElementName(member);
        const maybeQuestionTokenStartLoc = this.state.startLoc;
        this.parsePostMemberNameModifiers(publicMember);
        if (this.isClassMethod()) {
          method.kind = "method";
          if (isPrivate) {
            this.pushClassPrivateMethod(classBody, privateMethod, false, false);
            return;
          }
          const isConstructor = this.isNonstaticConstructor(publicMethod);
          let allowsDirectSuper = false;
          if (isConstructor) {
            publicMethod.kind = "constructor";
            if (state.hadConstructor && !this.hasPlugin("typescript")) {
              this.raise(Errors.DuplicateConstructor, {
                at: key
              });
            }
            if (isConstructor && this.hasPlugin("typescript") && member.override) {
              this.raise(Errors.OverrideOnConstructor, {
                at: key
              });
            }
            state.hadConstructor = true;
            allowsDirectSuper = state.hadSuperClass;
          }
          this.pushClassMethod(classBody, publicMethod, false, false, isConstructor, allowsDirectSuper);
        } else if (this.isClassProperty()) {
          if (isPrivate) {
            this.pushClassPrivateProperty(classBody, privateProp);
          } else {
            this.pushClassProperty(classBody, publicProp);
          }
        } else if (isContextual && key.name === "async" && !this.isLineTerminator()) {
          this.resetPreviousNodeTrailingComments(key);
          const isGenerator = this.eat(55);
          if (publicMember.optional) {
            this.unexpected(maybeQuestionTokenStartLoc);
          }
          method.kind = "method";
          const isPrivate2 = this.match(136);
          this.parseClassElementName(method);
          this.parsePostMemberNameModifiers(publicMember);
          if (isPrivate2) {
            this.pushClassPrivateMethod(classBody, privateMethod, isGenerator, true);
          } else {
            if (this.isNonstaticConstructor(publicMethod)) {
              this.raise(Errors.ConstructorIsAsync, {
                at: publicMethod.key
              });
            }
            this.pushClassMethod(classBody, publicMethod, isGenerator, true, false, false);
          }
        } else if (isContextual && (key.name === "get" || key.name === "set") && !(this.match(55) && this.isLineTerminator())) {
          this.resetPreviousNodeTrailingComments(key);
          method.kind = key.name;
          const isPrivate2 = this.match(136);
          this.parseClassElementName(publicMethod);
          if (isPrivate2) {
            this.pushClassPrivateMethod(classBody, privateMethod, false, false);
          } else {
            if (this.isNonstaticConstructor(publicMethod)) {
              this.raise(Errors.ConstructorIsAccessor, {
                at: publicMethod.key
              });
            }
            this.pushClassMethod(classBody, publicMethod, false, false, false, false);
          }
          this.checkGetterSetterParams(publicMethod);
        } else if (isContextual && key.name === "accessor" && !this.isLineTerminator()) {
          this.expectPlugin("decoratorAutoAccessors");
          this.resetPreviousNodeTrailingComments(key);
          const isPrivate2 = this.match(136);
          this.parseClassElementName(publicProp);
          this.pushClassAccessorProperty(classBody, accessorProp, isPrivate2);
        } else if (this.isLineTerminator()) {
          if (isPrivate) {
            this.pushClassPrivateProperty(classBody, privateProp);
          } else {
            this.pushClassProperty(classBody, publicProp);
          }
        } else {
          this.unexpected();
        }
      }
      parseClassElementName(member) {
        const {
          type,
          value: value2
        } = this.state;
        if ((type === 130 || type === 131) && member.static && value2 === "prototype") {
          this.raise(Errors.StaticPrototype, {
            at: this.state.startLoc
          });
        }
        if (type === 136) {
          if (value2 === "constructor") {
            this.raise(Errors.ConstructorClassPrivateField, {
              at: this.state.startLoc
            });
          }
          const key = this.parsePrivateName();
          member.key = key;
          return key;
        }
        return this.parsePropertyName(member);
      }
      parseClassStaticBlock(classBody, member) {
        var _member$decorators;
        this.scope.enter(SCOPE_CLASS | SCOPE_STATIC_BLOCK | SCOPE_SUPER);
        const oldLabels = this.state.labels;
        this.state.labels = [];
        this.prodParam.enter(PARAM);
        const body = member.body = [];
        this.parseBlockOrModuleBlockBody(body, void 0, false, 8);
        this.prodParam.exit();
        this.scope.exit();
        this.state.labels = oldLabels;
        classBody.body.push(this.finishNode(member, "StaticBlock"));
        if ((_member$decorators = member.decorators) != null && _member$decorators.length) {
          this.raise(Errors.DecoratorStaticBlock, {
            at: member
          });
        }
      }
      pushClassProperty(classBody, prop) {
        if (!prop.computed && (prop.key.name === "constructor" || prop.key.value === "constructor")) {
          this.raise(Errors.ConstructorClassField, {
            at: prop.key
          });
        }
        classBody.body.push(this.parseClassProperty(prop));
      }
      pushClassPrivateProperty(classBody, prop) {
        const node = this.parseClassPrivateProperty(prop);
        classBody.body.push(node);
        this.classScope.declarePrivateName(this.getPrivateNameSV(node.key), CLASS_ELEMENT_OTHER, node.key.loc.start);
      }
      pushClassAccessorProperty(classBody, prop, isPrivate) {
        if (!isPrivate && !prop.computed) {
          const key = prop.key;
          if (key.name === "constructor" || key.value === "constructor") {
            this.raise(Errors.ConstructorClassField, {
              at: key
            });
          }
        }
        const node = this.parseClassAccessorProperty(prop);
        classBody.body.push(node);
        if (isPrivate) {
          this.classScope.declarePrivateName(this.getPrivateNameSV(node.key), CLASS_ELEMENT_OTHER, node.key.loc.start);
        }
      }
      pushClassMethod(classBody, method, isGenerator, isAsync, isConstructor, allowsDirectSuper) {
        classBody.body.push(this.parseMethod(method, isGenerator, isAsync, isConstructor, allowsDirectSuper, "ClassMethod", true));
      }
      pushClassPrivateMethod(classBody, method, isGenerator, isAsync) {
        const node = this.parseMethod(method, isGenerator, isAsync, false, false, "ClassPrivateMethod", true);
        classBody.body.push(node);
        const kind = node.kind === "get" ? node.static ? CLASS_ELEMENT_STATIC_GETTER : CLASS_ELEMENT_INSTANCE_GETTER : node.kind === "set" ? node.static ? CLASS_ELEMENT_STATIC_SETTER : CLASS_ELEMENT_INSTANCE_SETTER : CLASS_ELEMENT_OTHER;
        this.declareClassPrivateMethodInScope(node, kind);
      }
      declareClassPrivateMethodInScope(node, kind) {
        this.classScope.declarePrivateName(this.getPrivateNameSV(node.key), kind, node.key.loc.start);
      }
      parsePostMemberNameModifiers(methodOrProp) {
      }
      parseClassPrivateProperty(node) {
        this.parseInitializer(node);
        this.semicolon();
        return this.finishNode(node, "ClassPrivateProperty");
      }
      parseClassProperty(node) {
        this.parseInitializer(node);
        this.semicolon();
        return this.finishNode(node, "ClassProperty");
      }
      parseClassAccessorProperty(node) {
        this.parseInitializer(node);
        this.semicolon();
        return this.finishNode(node, "ClassAccessorProperty");
      }
      parseInitializer(node) {
        this.scope.enter(SCOPE_CLASS | SCOPE_SUPER);
        this.expressionScope.enter(newExpressionScope());
        this.prodParam.enter(PARAM);
        node.value = this.eat(29) ? this.parseMaybeAssignAllowIn() : null;
        this.expressionScope.exit();
        this.prodParam.exit();
        this.scope.exit();
      }
      parseClassId(node, isStatement, optionalId, bindingType = BIND_CLASS) {
        if (tokenIsIdentifier(this.state.type)) {
          node.id = this.parseIdentifier();
          if (isStatement) {
            this.declareNameFromIdentifier(node.id, bindingType);
          }
        } else {
          if (optionalId || !isStatement) {
            node.id = null;
          } else {
            throw this.raise(Errors.MissingClassName, {
              at: this.state.startLoc
            });
          }
        }
      }
      parseClassSuper(node) {
        node.superClass = this.eat(81) ? this.parseExprSubscripts() : null;
      }
      parseExport(node, decorators) {
        const hasDefault = this.maybeParseExportDefaultSpecifier(
          node
        );
        const parseAfterDefault = !hasDefault || this.eat(12);
        const hasStar = parseAfterDefault && this.eatExportStar(
          node
        );
        const hasNamespace = hasStar && this.maybeParseExportNamespaceSpecifier(
          node
        );
        const parseAfterNamespace = parseAfterDefault && (!hasNamespace || this.eat(12));
        const isFromRequired = hasDefault || hasStar;
        if (hasStar && !hasNamespace) {
          if (hasDefault)
            this.unexpected();
          if (decorators) {
            throw this.raise(Errors.UnsupportedDecoratorExport, {
              at: node
            });
          }
          this.parseExportFrom(node, true);
          return this.finishNode(node, "ExportAllDeclaration");
        }
        const hasSpecifiers = this.maybeParseExportNamedSpecifiers(
          node
        );
        if (hasDefault && parseAfterDefault && !hasStar && !hasSpecifiers || hasNamespace && parseAfterNamespace && !hasSpecifiers) {
          throw this.unexpected(null, 5);
        }
        let hasDeclaration;
        if (isFromRequired || hasSpecifiers) {
          hasDeclaration = false;
          if (decorators) {
            throw this.raise(Errors.UnsupportedDecoratorExport, {
              at: node
            });
          }
          this.parseExportFrom(node, isFromRequired);
        } else {
          hasDeclaration = this.maybeParseExportDeclaration(node);
        }
        if (isFromRequired || hasSpecifiers || hasDeclaration) {
          var _node2$declaration;
          const node2 = node;
          this.checkExport(node2, true, false, !!node2.source);
          if (((_node2$declaration = node2.declaration) == null ? void 0 : _node2$declaration.type) === "ClassDeclaration") {
            this.maybeTakeDecorators(decorators, node2.declaration, node2);
          } else if (decorators) {
            throw this.raise(Errors.UnsupportedDecoratorExport, {
              at: node
            });
          }
          return this.finishNode(node2, "ExportNamedDeclaration");
        }
        if (this.eat(65)) {
          const node2 = node;
          const decl = this.parseExportDefaultExpression();
          node2.declaration = decl;
          if (decl.type === "ClassDeclaration") {
            this.maybeTakeDecorators(decorators, decl, node2);
          } else if (decorators) {
            throw this.raise(Errors.UnsupportedDecoratorExport, {
              at: node
            });
          }
          this.checkExport(node2, true, true);
          return this.finishNode(node2, "ExportDefaultDeclaration");
        }
        throw this.unexpected(null, 5);
      }
      eatExportStar(node) {
        return this.eat(55);
      }
      maybeParseExportDefaultSpecifier(node) {
        if (this.isExportDefaultSpecifier()) {
          this.expectPlugin("exportDefaultFrom");
          const specifier = this.startNode();
          specifier.exported = this.parseIdentifier(true);
          node.specifiers = [this.finishNode(specifier, "ExportDefaultSpecifier")];
          return true;
        }
        return false;
      }
      maybeParseExportNamespaceSpecifier(node) {
        if (this.isContextual(93)) {
          if (!node.specifiers)
            node.specifiers = [];
          const specifier = this.startNodeAt(this.state.lastTokStartLoc);
          this.next();
          specifier.exported = this.parseModuleExportName();
          node.specifiers.push(this.finishNode(specifier, "ExportNamespaceSpecifier"));
          return true;
        }
        return false;
      }
      maybeParseExportNamedSpecifiers(node) {
        if (this.match(5)) {
          if (!node.specifiers)
            node.specifiers = [];
          const isTypeExport = node.exportKind === "type";
          node.specifiers.push(...this.parseExportSpecifiers(isTypeExport));
          node.source = null;
          node.declaration = null;
          if (this.hasPlugin("importAssertions")) {
            node.assertions = [];
          }
          return true;
        }
        return false;
      }
      maybeParseExportDeclaration(node) {
        if (this.shouldParseExportDeclaration()) {
          node.specifiers = [];
          node.source = null;
          if (this.hasPlugin("importAssertions")) {
            node.assertions = [];
          }
          node.declaration = this.parseExportDeclaration(node);
          return true;
        }
        return false;
      }
      isAsyncFunction() {
        if (!this.isContextual(95))
          return false;
        const next = this.nextTokenStart();
        return !lineBreak.test(this.input.slice(this.state.pos, next)) && this.isUnparsedContextual(next, "function");
      }
      parseExportDefaultExpression() {
        const expr = this.startNode();
        if (this.match(68)) {
          this.next();
          return this.parseFunction(expr, ParseFunctionFlag.Declaration | ParseFunctionFlag.NullableId);
        } else if (this.isAsyncFunction()) {
          this.next();
          this.next();
          return this.parseFunction(expr, ParseFunctionFlag.Declaration | ParseFunctionFlag.NullableId | ParseFunctionFlag.Async);
        }
        if (this.match(80)) {
          return this.parseClass(expr, true, true);
        }
        if (this.match(26)) {
          if (this.hasPlugin("decorators") && this.getPluginOption("decorators", "decoratorsBeforeExport")) {
            this.raise(Errors.DecoratorBeforeExport, {
              at: this.state.startLoc
            });
          }
          return this.parseClass(this.maybeTakeDecorators(this.parseDecorators(false), this.startNode()), true, true);
        }
        if (this.match(75) || this.match(74) || this.isLet()) {
          throw this.raise(Errors.UnsupportedDefaultExport, {
            at: this.state.startLoc
          });
        }
        const res = this.parseMaybeAssignAllowIn();
        this.semicolon();
        return res;
      }
      parseExportDeclaration(node) {
        if (this.match(80)) {
          const node2 = this.parseClass(this.startNode(), true, false);
          return node2;
        }
        return this.parseStatementListItem();
      }
      isExportDefaultSpecifier() {
        const {
          type
        } = this.state;
        if (tokenIsIdentifier(type)) {
          if (type === 95 && !this.state.containsEsc || type === 99) {
            return false;
          }
          if ((type === 128 || type === 127) && !this.state.containsEsc) {
            const {
              type: nextType
            } = this.lookahead();
            if (tokenIsIdentifier(nextType) && nextType !== 97 || nextType === 5) {
              this.expectOnePlugin(["flow", "typescript"]);
              return false;
            }
          }
        } else if (!this.match(65)) {
          return false;
        }
        const next = this.nextTokenStart();
        const hasFrom = this.isUnparsedContextual(next, "from");
        if (this.input.charCodeAt(next) === 44 || tokenIsIdentifier(this.state.type) && hasFrom) {
          return true;
        }
        if (this.match(65) && hasFrom) {
          const nextAfterFrom = this.input.charCodeAt(this.nextTokenStartSince(next + 4));
          return nextAfterFrom === 34 || nextAfterFrom === 39;
        }
        return false;
      }
      parseExportFrom(node, expect) {
        if (this.eatContextual(97)) {
          node.source = this.parseImportSource();
          this.checkExport(node);
          const assertions = this.maybeParseImportAssertions();
          if (assertions) {
            node.assertions = assertions;
            this.checkJSONModuleImport(node);
          }
        } else if (expect) {
          this.unexpected();
        }
        this.semicolon();
      }
      shouldParseExportDeclaration() {
        const {
          type
        } = this.state;
        if (type === 26) {
          this.expectOnePlugin(["decorators", "decorators-legacy"]);
          if (this.hasPlugin("decorators")) {
            if (this.getPluginOption("decorators", "decoratorsBeforeExport")) {
              throw this.raise(Errors.DecoratorBeforeExport, {
                at: this.state.startLoc
              });
            }
            return true;
          }
        }
        return type === 74 || type === 75 || type === 68 || type === 80 || this.isLet() || this.isAsyncFunction();
      }
      checkExport(node, checkNames, isDefault, isFrom) {
        if (checkNames) {
          if (isDefault) {
            this.checkDuplicateExports(node, "default");
            if (this.hasPlugin("exportDefaultFrom")) {
              var _declaration$extra;
              const declaration = node.declaration;
              if (declaration.type === "Identifier" && declaration.name === "from" && declaration.end - declaration.start === 4 && !((_declaration$extra = declaration.extra) != null && _declaration$extra.parenthesized)) {
                this.raise(Errors.ExportDefaultFromAsIdentifier, {
                  at: declaration
                });
              }
            }
          } else if (node.specifiers && node.specifiers.length) {
            for (const specifier of node.specifiers) {
              const {
                exported
              } = specifier;
              const exportName = exported.type === "Identifier" ? exported.name : exported.value;
              this.checkDuplicateExports(specifier, exportName);
              if (!isFrom && specifier.local) {
                const {
                  local
                } = specifier;
                if (local.type !== "Identifier") {
                  this.raise(Errors.ExportBindingIsString, {
                    at: specifier,
                    localName: local.value,
                    exportName
                  });
                } else {
                  this.checkReservedWord(local.name, local.loc.start, true, false);
                  this.scope.checkLocalExport(local);
                }
              }
            }
          } else if (node.declaration) {
            if (node.declaration.type === "FunctionDeclaration" || node.declaration.type === "ClassDeclaration") {
              const id = node.declaration.id;
              if (!id)
                throw new Error("Assertion failure");
              this.checkDuplicateExports(node, id.name);
            } else if (node.declaration.type === "VariableDeclaration") {
              for (const declaration of node.declaration.declarations) {
                this.checkDeclaration(declaration.id);
              }
            }
          }
        }
      }
      checkDeclaration(node) {
        if (node.type === "Identifier") {
          this.checkDuplicateExports(node, node.name);
        } else if (node.type === "ObjectPattern") {
          for (const prop of node.properties) {
            this.checkDeclaration(prop);
          }
        } else if (node.type === "ArrayPattern") {
          for (const elem of node.elements) {
            if (elem) {
              this.checkDeclaration(elem);
            }
          }
        } else if (node.type === "ObjectProperty") {
          this.checkDeclaration(node.value);
        } else if (node.type === "RestElement") {
          this.checkDeclaration(node.argument);
        } else if (node.type === "AssignmentPattern") {
          this.checkDeclaration(node.left);
        }
      }
      checkDuplicateExports(node, exportName) {
        if (this.exportedIdentifiers.has(exportName)) {
          if (exportName === "default") {
            this.raise(Errors.DuplicateDefaultExport, {
              at: node
            });
          } else {
            this.raise(Errors.DuplicateExport, {
              at: node,
              exportName
            });
          }
        }
        this.exportedIdentifiers.add(exportName);
      }
      parseExportSpecifiers(isInTypeExport) {
        const nodes = [];
        let first2 = true;
        this.expect(5);
        while (!this.eat(8)) {
          if (first2) {
            first2 = false;
          } else {
            this.expect(12);
            if (this.eat(8))
              break;
          }
          const isMaybeTypeOnly = this.isContextual(128);
          const isString = this.match(131);
          const node = this.startNode();
          node.local = this.parseModuleExportName();
          nodes.push(this.parseExportSpecifier(node, isString, isInTypeExport, isMaybeTypeOnly));
        }
        return nodes;
      }
      parseExportSpecifier(node, isString, isInTypeExport, isMaybeTypeOnly) {
        if (this.eatContextual(93)) {
          node.exported = this.parseModuleExportName();
        } else if (isString) {
          node.exported = cloneStringLiteral(node.local);
        } else if (!node.exported) {
          node.exported = cloneIdentifier(node.local);
        }
        return this.finishNode(node, "ExportSpecifier");
      }
      parseModuleExportName() {
        if (this.match(131)) {
          const result = this.parseStringLiteral(this.state.value);
          const surrogate = result.value.match(loneSurrogate);
          if (surrogate) {
            this.raise(Errors.ModuleExportNameHasLoneSurrogate, {
              at: result,
              surrogateCharCode: surrogate[0].charCodeAt(0)
            });
          }
          return result;
        }
        return this.parseIdentifier(true);
      }
      isJSONModuleImport(node) {
        if (node.assertions != null) {
          return node.assertions.some(({
            key,
            value: value2
          }) => {
            return value2.value === "json" && (key.type === "Identifier" ? key.name === "type" : key.value === "type");
          });
        }
        return false;
      }
      checkImportReflection(node) {
        if (node.module) {
          var _node$assertions;
          if (node.specifiers.length !== 1 || node.specifiers[0].type !== "ImportDefaultSpecifier") {
            this.raise(Errors.ImportReflectionNotBinding, {
              at: node.specifiers[0].loc.start
            });
          }
          if (((_node$assertions = node.assertions) == null ? void 0 : _node$assertions.length) > 0) {
            this.raise(Errors.ImportReflectionHasAssertion, {
              at: node.specifiers[0].loc.start
            });
          }
        }
      }
      checkJSONModuleImport(node) {
        if (this.isJSONModuleImport(node) && node.type !== "ExportAllDeclaration") {
          const {
            specifiers
          } = node;
          if (specifiers != null) {
            const nonDefaultNamedSpecifier = specifiers.find((specifier) => {
              let imported;
              if (specifier.type === "ExportSpecifier") {
                imported = specifier.local;
              } else if (specifier.type === "ImportSpecifier") {
                imported = specifier.imported;
              }
              if (imported !== void 0) {
                return imported.type === "Identifier" ? imported.name !== "default" : imported.value !== "default";
              }
            });
            if (nonDefaultNamedSpecifier !== void 0) {
              this.raise(Errors.ImportJSONBindingNotDefault, {
                at: nonDefaultNamedSpecifier.loc.start
              });
            }
          }
        }
      }
      parseMaybeImportReflection(node) {
        let isImportReflection = false;
        if (this.isContextual(125)) {
          const lookahead = this.lookahead();
          const nextType = lookahead.type;
          if (tokenIsIdentifier(nextType)) {
            if (nextType !== 97) {
              isImportReflection = true;
            } else {
              const nextNextTokenFirstChar = this.input.charCodeAt(this.nextTokenStartSince(lookahead.end));
              if (nextNextTokenFirstChar === 102) {
                isImportReflection = true;
              }
            }
          } else if (nextType !== 12) {
            isImportReflection = true;
          }
        }
        if (isImportReflection) {
          this.expectPlugin("importReflection");
          this.next();
          node.module = true;
        } else if (this.hasPlugin("importReflection")) {
          node.module = false;
        }
      }
      parseImport(node) {
        node.specifiers = [];
        if (!this.match(131)) {
          this.parseMaybeImportReflection(node);
          const hasDefault = this.maybeParseDefaultImportSpecifier(node);
          const parseNext = !hasDefault || this.eat(12);
          const hasStar = parseNext && this.maybeParseStarImportSpecifier(node);
          if (parseNext && !hasStar)
            this.parseNamedImportSpecifiers(node);
          this.expectContextual(97);
        }
        node.source = this.parseImportSource();
        const assertions = this.maybeParseImportAssertions();
        if (assertions) {
          node.assertions = assertions;
        } else {
          const attributes = this.maybeParseModuleAttributes();
          if (attributes) {
            node.attributes = attributes;
          }
        }
        this.checkImportReflection(node);
        this.checkJSONModuleImport(node);
        this.semicolon();
        return this.finishNode(node, "ImportDeclaration");
      }
      parseImportSource() {
        if (!this.match(131))
          this.unexpected();
        return this.parseExprAtom();
      }
      shouldParseDefaultImport(node) {
        return tokenIsIdentifier(this.state.type);
      }
      parseImportSpecifierLocal(node, specifier, type) {
        specifier.local = this.parseIdentifier();
        node.specifiers.push(this.finishImportSpecifier(specifier, type));
      }
      finishImportSpecifier(specifier, type, bindingType = BIND_LEXICAL) {
        this.checkLVal(specifier.local, {
          in: specifier,
          binding: bindingType
        });
        return this.finishNode(specifier, type);
      }
      parseAssertEntries() {
        const attrs = [];
        const attrNames = /* @__PURE__ */ new Set();
        do {
          if (this.match(8)) {
            break;
          }
          const node = this.startNode();
          const keyName = this.state.value;
          if (attrNames.has(keyName)) {
            this.raise(Errors.ModuleAttributesWithDuplicateKeys, {
              at: this.state.startLoc,
              key: keyName
            });
          }
          attrNames.add(keyName);
          if (this.match(131)) {
            node.key = this.parseStringLiteral(keyName);
          } else {
            node.key = this.parseIdentifier(true);
          }
          this.expect(14);
          if (!this.match(131)) {
            throw this.raise(Errors.ModuleAttributeInvalidValue, {
              at: this.state.startLoc
            });
          }
          node.value = this.parseStringLiteral(this.state.value);
          attrs.push(this.finishNode(node, "ImportAttribute"));
        } while (this.eat(12));
        return attrs;
      }
      maybeParseModuleAttributes() {
        if (this.match(76) && !this.hasPrecedingLineBreak()) {
          this.expectPlugin("moduleAttributes");
          this.next();
        } else {
          if (this.hasPlugin("moduleAttributes"))
            return [];
          return null;
        }
        const attrs = [];
        const attributes = /* @__PURE__ */ new Set();
        do {
          const node = this.startNode();
          node.key = this.parseIdentifier(true);
          if (node.key.name !== "type") {
            this.raise(Errors.ModuleAttributeDifferentFromType, {
              at: node.key
            });
          }
          if (attributes.has(node.key.name)) {
            this.raise(Errors.ModuleAttributesWithDuplicateKeys, {
              at: node.key,
              key: node.key.name
            });
          }
          attributes.add(node.key.name);
          this.expect(14);
          if (!this.match(131)) {
            throw this.raise(Errors.ModuleAttributeInvalidValue, {
              at: this.state.startLoc
            });
          }
          node.value = this.parseStringLiteral(this.state.value);
          this.finishNode(node, "ImportAttribute");
          attrs.push(node);
        } while (this.eat(12));
        return attrs;
      }
      maybeParseImportAssertions() {
        if (this.isContextual(94) && !this.hasPrecedingLineBreak()) {
          this.expectPlugin("importAssertions");
          this.next();
        } else {
          if (this.hasPlugin("importAssertions"))
            return [];
          return null;
        }
        this.eat(5);
        const attrs = this.parseAssertEntries();
        this.eat(8);
        return attrs;
      }
      maybeParseDefaultImportSpecifier(node) {
        if (this.shouldParseDefaultImport(node)) {
          this.parseImportSpecifierLocal(node, this.startNode(), "ImportDefaultSpecifier");
          return true;
        }
        return false;
      }
      maybeParseStarImportSpecifier(node) {
        if (this.match(55)) {
          const specifier = this.startNode();
          this.next();
          this.expectContextual(93);
          this.parseImportSpecifierLocal(node, specifier, "ImportNamespaceSpecifier");
          return true;
        }
        return false;
      }
      parseNamedImportSpecifiers(node) {
        let first2 = true;
        this.expect(5);
        while (!this.eat(8)) {
          if (first2) {
            first2 = false;
          } else {
            if (this.eat(14)) {
              throw this.raise(Errors.DestructureNamedImport, {
                at: this.state.startLoc
              });
            }
            this.expect(12);
            if (this.eat(8))
              break;
          }
          const specifier = this.startNode();
          const importedIsString = this.match(131);
          const isMaybeTypeOnly = this.isContextual(128);
          specifier.imported = this.parseModuleExportName();
          const importSpecifier2 = this.parseImportSpecifier(specifier, importedIsString, node.importKind === "type" || node.importKind === "typeof", isMaybeTypeOnly, void 0);
          node.specifiers.push(importSpecifier2);
        }
      }
      parseImportSpecifier(specifier, importedIsString, isInTypeOnlyImport, isMaybeTypeOnly, bindingType) {
        if (this.eatContextual(93)) {
          specifier.local = this.parseIdentifier();
        } else {
          const {
            imported
          } = specifier;
          if (importedIsString) {
            throw this.raise(Errors.ImportBindingIsString, {
              at: specifier,
              importName: imported.value
            });
          }
          this.checkReservedWord(imported.name, specifier.loc.start, true, true);
          if (!specifier.local) {
            specifier.local = cloneIdentifier(imported);
          }
        }
        return this.finishImportSpecifier(specifier, "ImportSpecifier", bindingType);
      }
      isThisParam(param) {
        return param.type === "Identifier" && param.name === "this";
      }
    };
    var Parser2 = class extends StatementParser {
      constructor(options, input) {
        options = getOptions(options);
        super(options, input);
        this.options = options;
        this.initializeScopes();
        this.plugins = pluginsMap(this.options.plugins);
        this.filename = options.sourceFilename;
      }
      getScopeHandler() {
        return ScopeHandler;
      }
      parse() {
        this.enterInitialScopes();
        const file = this.startNode();
        const program2 = this.startNode();
        this.nextToken();
        file.errors = null;
        this.parseTopLevel(file, program2);
        file.errors = this.state.errors;
        return file;
      }
    };
    function pluginsMap(plugins) {
      const pluginMap = /* @__PURE__ */ new Map();
      for (const plugin of plugins) {
        const [name, options] = Array.isArray(plugin) ? plugin : [plugin, {}];
        if (!pluginMap.has(name))
          pluginMap.set(name, options || {});
      }
      return pluginMap;
    }
    function parse3(input, options) {
      var _options;
      if (((_options = options) == null ? void 0 : _options.sourceType) === "unambiguous") {
        options = Object.assign({}, options);
        try {
          options.sourceType = "module";
          const parser = getParser(options, input);
          const ast = parser.parse();
          if (parser.sawUnambiguousESM) {
            return ast;
          }
          if (parser.ambiguousScriptDifferentAst) {
            try {
              options.sourceType = "script";
              return getParser(options, input).parse();
            } catch (_unused) {
            }
          } else {
            ast.program.sourceType = "script";
          }
          return ast;
        } catch (moduleError) {
          try {
            options.sourceType = "script";
            return getParser(options, input).parse();
          } catch (_unused2) {
          }
          throw moduleError;
        }
      } else {
        return getParser(options, input).parse();
      }
    }
    function parseExpression(input, options) {
      const parser = getParser(options, input);
      if (parser.options.strictMode) {
        parser.state.strict = true;
      }
      return parser.getExpression();
    }
    function generateExportedTokenTypes(internalTokenTypes) {
      const tokenTypes2 = {};
      for (const typeName of Object.keys(internalTokenTypes)) {
        tokenTypes2[typeName] = getExportedToken(internalTokenTypes[typeName]);
      }
      return tokenTypes2;
    }
    var tokTypes = generateExportedTokenTypes(tt);
    function getParser(options, input) {
      let cls = Parser2;
      if (options != null && options.plugins) {
        validatePlugins(options.plugins);
        cls = getParserClass(options.plugins);
      }
      return new cls(options, input);
    }
    var parserClassCache = {};
    function getParserClass(pluginsFromOptions) {
      const pluginList = mixinPluginNames.filter((name) => hasPlugin(pluginsFromOptions, name));
      const key = pluginList.join("/");
      let cls = parserClassCache[key];
      if (!cls) {
        cls = Parser2;
        for (const plugin of pluginList) {
          cls = mixinPlugins[plugin](cls);
        }
        parserClassCache[key] = cls;
      }
      return cls;
    }
    exports.parse = parse3;
    exports.parseExpression = parseExpression;
    exports.tokTypes = tokTypes;
  }
});

// node_modules/vue-eslint-parser-private/node_modules/eslint-visitor-keys/lib/visitor-keys.json
var require_visitor_keys = __commonJS({
  "node_modules/vue-eslint-parser-private/node_modules/eslint-visitor-keys/lib/visitor-keys.json"(exports, module2) {
    module2.exports = {
      AssignmentExpression: [
        "left",
        "right"
      ],
      AssignmentPattern: [
        "left",
        "right"
      ],
      ArrayExpression: [
        "elements"
      ],
      ArrayPattern: [
        "elements"
      ],
      ArrowFunctionExpression: [
        "params",
        "body"
      ],
      AwaitExpression: [
        "argument"
      ],
      BlockStatement: [
        "body"
      ],
      BinaryExpression: [
        "left",
        "right"
      ],
      BreakStatement: [
        "label"
      ],
      CallExpression: [
        "callee",
        "arguments"
      ],
      CatchClause: [
        "param",
        "body"
      ],
      ChainExpression: [
        "expression"
      ],
      ClassBody: [
        "body"
      ],
      ClassDeclaration: [
        "id",
        "superClass",
        "body"
      ],
      ClassExpression: [
        "id",
        "superClass",
        "body"
      ],
      ConditionalExpression: [
        "test",
        "consequent",
        "alternate"
      ],
      ContinueStatement: [
        "label"
      ],
      DebuggerStatement: [],
      DoWhileStatement: [
        "body",
        "test"
      ],
      EmptyStatement: [],
      ExportAllDeclaration: [
        "exported",
        "source"
      ],
      ExportDefaultDeclaration: [
        "declaration"
      ],
      ExportNamedDeclaration: [
        "declaration",
        "specifiers",
        "source"
      ],
      ExportSpecifier: [
        "exported",
        "local"
      ],
      ExpressionStatement: [
        "expression"
      ],
      ExperimentalRestProperty: [
        "argument"
      ],
      ExperimentalSpreadProperty: [
        "argument"
      ],
      ForStatement: [
        "init",
        "test",
        "update",
        "body"
      ],
      ForInStatement: [
        "left",
        "right",
        "body"
      ],
      ForOfStatement: [
        "left",
        "right",
        "body"
      ],
      FunctionDeclaration: [
        "id",
        "params",
        "body"
      ],
      FunctionExpression: [
        "id",
        "params",
        "body"
      ],
      Identifier: [],
      IfStatement: [
        "test",
        "consequent",
        "alternate"
      ],
      ImportDeclaration: [
        "specifiers",
        "source"
      ],
      ImportDefaultSpecifier: [
        "local"
      ],
      ImportExpression: [
        "source"
      ],
      ImportNamespaceSpecifier: [
        "local"
      ],
      ImportSpecifier: [
        "imported",
        "local"
      ],
      JSXAttribute: [
        "name",
        "value"
      ],
      JSXClosingElement: [
        "name"
      ],
      JSXElement: [
        "openingElement",
        "children",
        "closingElement"
      ],
      JSXEmptyExpression: [],
      JSXExpressionContainer: [
        "expression"
      ],
      JSXIdentifier: [],
      JSXMemberExpression: [
        "object",
        "property"
      ],
      JSXNamespacedName: [
        "namespace",
        "name"
      ],
      JSXOpeningElement: [
        "name",
        "attributes"
      ],
      JSXSpreadAttribute: [
        "argument"
      ],
      JSXText: [],
      JSXFragment: [
        "openingFragment",
        "children",
        "closingFragment"
      ],
      Literal: [],
      LabeledStatement: [
        "label",
        "body"
      ],
      LogicalExpression: [
        "left",
        "right"
      ],
      MemberExpression: [
        "object",
        "property"
      ],
      MetaProperty: [
        "meta",
        "property"
      ],
      MethodDefinition: [
        "key",
        "value"
      ],
      NewExpression: [
        "callee",
        "arguments"
      ],
      ObjectExpression: [
        "properties"
      ],
      ObjectPattern: [
        "properties"
      ],
      Program: [
        "body"
      ],
      Property: [
        "key",
        "value"
      ],
      RestElement: [
        "argument"
      ],
      ReturnStatement: [
        "argument"
      ],
      SequenceExpression: [
        "expressions"
      ],
      SpreadElement: [
        "argument"
      ],
      Super: [],
      SwitchStatement: [
        "discriminant",
        "cases"
      ],
      SwitchCase: [
        "test",
        "consequent"
      ],
      TaggedTemplateExpression: [
        "tag",
        "quasi"
      ],
      TemplateElement: [],
      TemplateLiteral: [
        "quasis",
        "expressions"
      ],
      ThisExpression: [],
      ThrowStatement: [
        "argument"
      ],
      TryStatement: [
        "block",
        "handler",
        "finalizer"
      ],
      UnaryExpression: [
        "argument"
      ],
      UpdateExpression: [
        "argument"
      ],
      VariableDeclaration: [
        "declarations"
      ],
      VariableDeclarator: [
        "id",
        "init"
      ],
      WhileStatement: [
        "test",
        "body"
      ],
      WithStatement: [
        "object",
        "body"
      ],
      YieldExpression: [
        "argument"
      ]
    };
  }
});

// node_modules/vue-eslint-parser-private/node_modules/eslint-visitor-keys/lib/index.js
var require_lib3 = __commonJS({
  "node_modules/vue-eslint-parser-private/node_modules/eslint-visitor-keys/lib/index.js"(exports, module2) {
    "use strict";
    var KEYS = require_visitor_keys();
    var NODE_TYPES = Object.freeze(Object.keys(KEYS));
    for (const type of NODE_TYPES) {
      Object.freeze(KEYS[type]);
    }
    Object.freeze(KEYS);
    var KEY_BLACKLIST = /* @__PURE__ */ new Set([
      "parent",
      "leadingComments",
      "trailingComments"
    ]);
    function filterKey(key) {
      return !KEY_BLACKLIST.has(key) && key[0] !== "_";
    }
    module2.exports = Object.freeze({
      /**
       * Visitor keys.
       * @type {{ [type: string]: string[] | undefined }}
       */
      KEYS,
      /**
       * Get visitor keys of a given node.
       * @param {Object} node The AST node to get keys.
       * @returns {string[]} Visitor keys of the node.
       */
      getKeys(node) {
        return Object.keys(node).filter(filterKey);
      },
      // Disable valid-jsdoc rule because it reports syntax error on the type of @returns.
      // eslint-disable-next-line valid-jsdoc
      /**
       * Make the union set with `KEYS` and given keys.
       * @param {Object} additionalKeys The additional keys.
       * @returns {{ [type: string]: string[] | undefined }} The union set.
       */
      unionWith(additionalKeys) {
        const retv = Object.assign({}, KEYS);
        for (const type of Object.keys(additionalKeys)) {
          if (retv.hasOwnProperty(type)) {
            const keys3 = new Set(additionalKeys[type]);
            for (const key of retv[type]) {
              keys3.add(key);
            }
            retv[type] = Object.freeze(Array.from(keys3));
          } else {
            retv[type] = Object.freeze(Array.from(additionalKeys[type]));
          }
        }
        return Object.freeze(retv);
      }
    });
  }
});

// node_modules/lodash/_baseSortedIndexBy.js
var require_baseSortedIndexBy = __commonJS({
  "node_modules/lodash/_baseSortedIndexBy.js"(exports, module2) {
    var isSymbol = require_isSymbol();
    var MAX_ARRAY_LENGTH = 4294967295;
    var MAX_ARRAY_INDEX = MAX_ARRAY_LENGTH - 1;
    var nativeFloor = Math.floor;
    var nativeMin = Math.min;
    function baseSortedIndexBy(array, value2, iteratee, retHighest) {
      var low = 0, high = array == null ? 0 : array.length;
      if (high === 0) {
        return 0;
      }
      value2 = iteratee(value2);
      var valIsNaN = value2 !== value2, valIsNull = value2 === null, valIsSymbol = isSymbol(value2), valIsUndefined = value2 === void 0;
      while (low < high) {
        var mid = nativeFloor((low + high) / 2), computed = iteratee(array[mid]), othIsDefined = computed !== void 0, othIsNull = computed === null, othIsReflexive = computed === computed, othIsSymbol = isSymbol(computed);
        if (valIsNaN) {
          var setLow = retHighest || othIsReflexive;
        } else if (valIsUndefined) {
          setLow = othIsReflexive && (retHighest || othIsDefined);
        } else if (valIsNull) {
          setLow = othIsReflexive && othIsDefined && (retHighest || !othIsNull);
        } else if (valIsSymbol) {
          setLow = othIsReflexive && othIsDefined && !othIsNull && (retHighest || !othIsSymbol);
        } else if (othIsNull || othIsSymbol) {
          setLow = false;
        } else {
          setLow = retHighest ? computed <= value2 : computed < value2;
        }
        if (setLow) {
          low = mid + 1;
        } else {
          high = mid;
        }
      }
      return nativeMin(high, MAX_ARRAY_INDEX);
    }
    module2.exports = baseSortedIndexBy;
  }
});

// node_modules/lodash/_baseSortedIndex.js
var require_baseSortedIndex = __commonJS({
  "node_modules/lodash/_baseSortedIndex.js"(exports, module2) {
    var baseSortedIndexBy = require_baseSortedIndexBy();
    var identity = require_identity2();
    var isSymbol = require_isSymbol();
    var MAX_ARRAY_LENGTH = 4294967295;
    var HALF_MAX_ARRAY_LENGTH = MAX_ARRAY_LENGTH >>> 1;
    function baseSortedIndex(array, value2, retHighest) {
      var low = 0, high = array == null ? low : array.length;
      if (typeof value2 == "number" && value2 === value2 && high <= HALF_MAX_ARRAY_LENGTH) {
        while (low < high) {
          var mid = low + high >>> 1, computed = array[mid];
          if (computed !== null && !isSymbol(computed) && (retHighest ? computed <= value2 : computed < value2)) {
            low = mid + 1;
          } else {
            high = mid;
          }
        }
        return high;
      }
      return baseSortedIndexBy(array, value2, identity, retHighest);
    }
    module2.exports = baseSortedIndex;
  }
});

// node_modules/lodash/sortedLastIndex.js
var require_sortedLastIndex = __commonJS({
  "node_modules/lodash/sortedLastIndex.js"(exports, module2) {
    var baseSortedIndex = require_baseSortedIndex();
    function sortedLastIndex(array, value2) {
      return baseSortedIndex(array, value2, true);
    }
    module2.exports = sortedLastIndex;
  }
});

// node_modules/lodash/last.js
var require_last2 = __commonJS({
  "node_modules/lodash/last.js"(exports, module2) {
    function last2(array) {
      var length = array == null ? 0 : array.length;
      return length ? array[length - 1] : void 0;
    }
    module2.exports = last2;
  }
});

// node_modules/lodash/_baseFindIndex.js
var require_baseFindIndex = __commonJS({
  "node_modules/lodash/_baseFindIndex.js"(exports, module2) {
    function baseFindIndex(array, predicate, fromIndex, fromRight) {
      var length = array.length, index = fromIndex + (fromRight ? 1 : -1);
      while (fromRight ? index-- : ++index < length) {
        if (predicate(array[index], index, array)) {
          return index;
        }
      }
      return -1;
    }
    module2.exports = baseFindIndex;
  }
});

// node_modules/lodash/_trimmedEndIndex.js
var require_trimmedEndIndex = __commonJS({
  "node_modules/lodash/_trimmedEndIndex.js"(exports, module2) {
    var reWhitespace = /\s/;
    function trimmedEndIndex(string) {
      var index = string.length;
      while (index-- && reWhitespace.test(string.charAt(index))) {
      }
      return index;
    }
    module2.exports = trimmedEndIndex;
  }
});

// node_modules/lodash/_baseTrim.js
var require_baseTrim = __commonJS({
  "node_modules/lodash/_baseTrim.js"(exports, module2) {
    var trimmedEndIndex = require_trimmedEndIndex();
    var reTrimStart = /^\s+/;
    function baseTrim(string) {
      return string ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, "") : string;
    }
    module2.exports = baseTrim;
  }
});

// node_modules/lodash/toNumber.js
var require_toNumber = __commonJS({
  "node_modules/lodash/toNumber.js"(exports, module2) {
    var baseTrim = require_baseTrim();
    var isObject = require_isObject();
    var isSymbol = require_isSymbol();
    var NAN = 0 / 0;
    var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
    var reIsBinary = /^0b[01]+$/i;
    var reIsOctal = /^0o[0-7]+$/i;
    var freeParseInt = parseInt;
    function toNumber(value2) {
      if (typeof value2 == "number") {
        return value2;
      }
      if (isSymbol(value2)) {
        return NAN;
      }
      if (isObject(value2)) {
        var other = typeof value2.valueOf == "function" ? value2.valueOf() : value2;
        value2 = isObject(other) ? other + "" : other;
      }
      if (typeof value2 != "string") {
        return value2 === 0 ? value2 : +value2;
      }
      value2 = baseTrim(value2);
      var isBinary = reIsBinary.test(value2);
      return isBinary || reIsOctal.test(value2) ? freeParseInt(value2.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value2) ? NAN : +value2;
    }
    module2.exports = toNumber;
  }
});

// node_modules/lodash/toFinite.js
var require_toFinite = __commonJS({
  "node_modules/lodash/toFinite.js"(exports, module2) {
    var toNumber = require_toNumber();
    var INFINITY = 1 / 0;
    var MAX_INTEGER = 17976931348623157e292;
    function toFinite(value2) {
      if (!value2) {
        return value2 === 0 ? value2 : 0;
      }
      value2 = toNumber(value2);
      if (value2 === INFINITY || value2 === -INFINITY) {
        var sign = value2 < 0 ? -1 : 1;
        return sign * MAX_INTEGER;
      }
      return value2 === value2 ? value2 : 0;
    }
    module2.exports = toFinite;
  }
});

// node_modules/lodash/toInteger.js
var require_toInteger = __commonJS({
  "node_modules/lodash/toInteger.js"(exports, module2) {
    var toFinite = require_toFinite();
    function toInteger(value2) {
      var result = toFinite(value2), remainder = result % 1;
      return result === result ? remainder ? result - remainder : result : 0;
    }
    module2.exports = toInteger;
  }
});

// node_modules/lodash/findLastIndex.js
var require_findLastIndex = __commonJS({
  "node_modules/lodash/findLastIndex.js"(exports, module2) {
    var baseFindIndex = require_baseFindIndex();
    var baseIteratee = require_baseIteratee();
    var toInteger = require_toInteger();
    var nativeMax = Math.max;
    var nativeMin = Math.min;
    function findLastIndex(array, predicate, fromIndex) {
      var length = array == null ? 0 : array.length;
      if (!length) {
        return -1;
      }
      var index = length - 1;
      if (fromIndex !== void 0) {
        index = toInteger(fromIndex);
        index = fromIndex < 0 ? nativeMax(length + index, 0) : nativeMin(index, length - 1);
      }
      return baseFindIndex(array, baseIteratee(predicate, 3), index, true);
    }
    module2.exports = findLastIndex;
  }
});

// node_modules/ms/index.js
var require_ms = __commonJS({
  "node_modules/ms/index.js"(exports, module2) {
    var s = 1e3;
    var m = s * 60;
    var h = m * 60;
    var d = h * 24;
    var w = d * 7;
    var y = d * 365.25;
    module2.exports = function(val, options) {
      options = options || {};
      var type = typeof val;
      if (type === "string" && val.length > 0) {
        return parse3(val);
      } else if (type === "number" && isFinite(val)) {
        return options.long ? fmtLong(val) : fmtShort(val);
      }
      throw new Error(
        "val is not a non-empty string or a valid number. val=" + JSON.stringify(val)
      );
    };
    function parse3(str) {
      str = String(str);
      if (str.length > 100) {
        return;
      }
      var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(
        str
      );
      if (!match) {
        return;
      }
      var n = parseFloat(match[1]);
      var type = (match[2] || "ms").toLowerCase();
      switch (type) {
        case "years":
        case "year":
        case "yrs":
        case "yr":
        case "y":
          return n * y;
        case "weeks":
        case "week":
        case "w":
          return n * w;
        case "days":
        case "day":
        case "d":
          return n * d;
        case "hours":
        case "hour":
        case "hrs":
        case "hr":
        case "h":
          return n * h;
        case "minutes":
        case "minute":
        case "mins":
        case "min":
        case "m":
          return n * m;
        case "seconds":
        case "second":
        case "secs":
        case "sec":
        case "s":
          return n * s;
        case "milliseconds":
        case "millisecond":
        case "msecs":
        case "msec":
        case "ms":
          return n;
        default:
          return void 0;
      }
    }
    function fmtShort(ms) {
      var msAbs = Math.abs(ms);
      if (msAbs >= d) {
        return Math.round(ms / d) + "d";
      }
      if (msAbs >= h) {
        return Math.round(ms / h) + "h";
      }
      if (msAbs >= m) {
        return Math.round(ms / m) + "m";
      }
      if (msAbs >= s) {
        return Math.round(ms / s) + "s";
      }
      return ms + "ms";
    }
    function fmtLong(ms) {
      var msAbs = Math.abs(ms);
      if (msAbs >= d) {
        return plural(ms, msAbs, d, "day");
      }
      if (msAbs >= h) {
        return plural(ms, msAbs, h, "hour");
      }
      if (msAbs >= m) {
        return plural(ms, msAbs, m, "minute");
      }
      if (msAbs >= s) {
        return plural(ms, msAbs, s, "second");
      }
      return ms + " ms";
    }
    function plural(ms, msAbs, n, name) {
      var isPlural = msAbs >= n * 1.5;
      return Math.round(ms / n) + " " + name + (isPlural ? "s" : "");
    }
  }
});

// node_modules/debug/src/common.js
var require_common2 = __commonJS({
  "node_modules/debug/src/common.js"(exports, module2) {
    function setup(env) {
      createDebug.debug = createDebug;
      createDebug.default = createDebug;
      createDebug.coerce = coerce;
      createDebug.disable = disable;
      createDebug.enable = enable;
      createDebug.enabled = enabled;
      createDebug.humanize = require_ms();
      createDebug.destroy = destroy;
      Object.keys(env).forEach((key) => {
        createDebug[key] = env[key];
      });
      createDebug.names = [];
      createDebug.skips = [];
      createDebug.formatters = {};
      function selectColor(namespace) {
        let hash = 0;
        for (let i = 0; i < namespace.length; i++) {
          hash = (hash << 5) - hash + namespace.charCodeAt(i);
          hash |= 0;
        }
        return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
      }
      createDebug.selectColor = selectColor;
      function createDebug(namespace) {
        let prevTime;
        let enableOverride = null;
        let namespacesCache;
        let enabledCache;
        function debug(...args) {
          if (!debug.enabled) {
            return;
          }
          const self2 = debug;
          const curr = Number(/* @__PURE__ */ new Date());
          const ms = curr - (prevTime || curr);
          self2.diff = ms;
          self2.prev = prevTime;
          self2.curr = curr;
          prevTime = curr;
          args[0] = createDebug.coerce(args[0]);
          if (typeof args[0] !== "string") {
            args.unshift("%O");
          }
          let index = 0;
          args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format2) => {
            if (match === "%%") {
              return "%";
            }
            index++;
            const formatter = createDebug.formatters[format2];
            if (typeof formatter === "function") {
              const val = args[index];
              match = formatter.call(self2, val);
              args.splice(index, 1);
              index--;
            }
            return match;
          });
          createDebug.formatArgs.call(self2, args);
          const logFn = self2.log || createDebug.log;
          logFn.apply(self2, args);
        }
        debug.namespace = namespace;
        debug.useColors = createDebug.useColors();
        debug.color = createDebug.selectColor(namespace);
        debug.extend = extend;
        debug.destroy = createDebug.destroy;
        Object.defineProperty(debug, "enabled", {
          enumerable: true,
          configurable: false,
          get: () => {
            if (enableOverride !== null) {
              return enableOverride;
            }
            if (namespacesCache !== createDebug.namespaces) {
              namespacesCache = createDebug.namespaces;
              enabledCache = createDebug.enabled(namespace);
            }
            return enabledCache;
          },
          set: (v) => {
            enableOverride = v;
          }
        });
        if (typeof createDebug.init === "function") {
          createDebug.init(debug);
        }
        return debug;
      }
      function extend(namespace, delimiter) {
        const newDebug = createDebug(this.namespace + (typeof delimiter === "undefined" ? ":" : delimiter) + namespace);
        newDebug.log = this.log;
        return newDebug;
      }
      function enable(namespaces) {
        createDebug.save(namespaces);
        createDebug.namespaces = namespaces;
        createDebug.names = [];
        createDebug.skips = [];
        let i;
        const split = (typeof namespaces === "string" ? namespaces : "").split(/[\s,]+/);
        const len = split.length;
        for (i = 0; i < len; i++) {
          if (!split[i]) {
            continue;
          }
          namespaces = split[i].replace(/\*/g, ".*?");
          if (namespaces[0] === "-") {
            createDebug.skips.push(new RegExp("^" + namespaces.slice(1) + "$"));
          } else {
            createDebug.names.push(new RegExp("^" + namespaces + "$"));
          }
        }
      }
      function disable() {
        const namespaces = [
          ...createDebug.names.map(toNamespace),
          ...createDebug.skips.map(toNamespace).map((namespace) => "-" + namespace)
        ].join(",");
        createDebug.enable("");
        return namespaces;
      }
      function enabled(name) {
        if (name[name.length - 1] === "*") {
          return true;
        }
        let i;
        let len;
        for (i = 0, len = createDebug.skips.length; i < len; i++) {
          if (createDebug.skips[i].test(name)) {
            return false;
          }
        }
        for (i = 0, len = createDebug.names.length; i < len; i++) {
          if (createDebug.names[i].test(name)) {
            return true;
          }
        }
        return false;
      }
      function toNamespace(regexp) {
        return regexp.toString().substring(2, regexp.toString().length - 2).replace(/\.\*\?$/, "*");
      }
      function coerce(val) {
        if (val instanceof Error) {
          return val.stack || val.message;
        }
        return val;
      }
      function destroy() {
        console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.");
      }
      createDebug.enable(createDebug.load());
      return createDebug;
    }
    module2.exports = setup;
  }
});

// node_modules/debug/src/browser.js
var require_browser = __commonJS({
  "node_modules/debug/src/browser.js"(exports, module2) {
    exports.formatArgs = formatArgs;
    exports.save = save;
    exports.load = load;
    exports.useColors = useColors;
    exports.storage = localstorage();
    exports.destroy = (() => {
      let warned = false;
      return () => {
        if (!warned) {
          warned = true;
          console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.");
        }
      };
    })();
    exports.colors = [
      "#0000CC",
      "#0000FF",
      "#0033CC",
      "#0033FF",
      "#0066CC",
      "#0066FF",
      "#0099CC",
      "#0099FF",
      "#00CC00",
      "#00CC33",
      "#00CC66",
      "#00CC99",
      "#00CCCC",
      "#00CCFF",
      "#3300CC",
      "#3300FF",
      "#3333CC",
      "#3333FF",
      "#3366CC",
      "#3366FF",
      "#3399CC",
      "#3399FF",
      "#33CC00",
      "#33CC33",
      "#33CC66",
      "#33CC99",
      "#33CCCC",
      "#33CCFF",
      "#6600CC",
      "#6600FF",
      "#6633CC",
      "#6633FF",
      "#66CC00",
      "#66CC33",
      "#9900CC",
      "#9900FF",
      "#9933CC",
      "#9933FF",
      "#99CC00",
      "#99CC33",
      "#CC0000",
      "#CC0033",
      "#CC0066",
      "#CC0099",
      "#CC00CC",
      "#CC00FF",
      "#CC3300",
      "#CC3333",
      "#CC3366",
      "#CC3399",
      "#CC33CC",
      "#CC33FF",
      "#CC6600",
      "#CC6633",
      "#CC9900",
      "#CC9933",
      "#CCCC00",
      "#CCCC33",
      "#FF0000",
      "#FF0033",
      "#FF0066",
      "#FF0099",
      "#FF00CC",
      "#FF00FF",
      "#FF3300",
      "#FF3333",
      "#FF3366",
      "#FF3399",
      "#FF33CC",
      "#FF33FF",
      "#FF6600",
      "#FF6633",
      "#FF9900",
      "#FF9933",
      "#FFCC00",
      "#FFCC33"
    ];
    function useColors() {
      if (typeof window !== "undefined" && window.process && (window.process.type === "renderer" || window.process.__nwjs)) {
        return true;
      }
      if (typeof navigator !== "undefined" && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
        return false;
      }
      return typeof document !== "undefined" && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
      typeof window !== "undefined" && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
      // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
      typeof navigator !== "undefined" && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
      typeof navigator !== "undefined" && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
    }
    function formatArgs(args) {
      args[0] = (this.useColors ? "%c" : "") + this.namespace + (this.useColors ? " %c" : " ") + args[0] + (this.useColors ? "%c " : " ") + "+" + module2.exports.humanize(this.diff);
      if (!this.useColors) {
        return;
      }
      const c = "color: " + this.color;
      args.splice(1, 0, c, "color: inherit");
      let index = 0;
      let lastC = 0;
      args[0].replace(/%[a-zA-Z%]/g, (match) => {
        if (match === "%%") {
          return;
        }
        index++;
        if (match === "%c") {
          lastC = index;
        }
      });
      args.splice(lastC, 0, c);
    }
    exports.log = console.debug || console.log || (() => {
    });
    function save(namespaces) {
      try {
        if (namespaces) {
          exports.storage.setItem("debug", namespaces);
        } else {
          exports.storage.removeItem("debug");
        }
      } catch (error) {
      }
    }
    function load() {
      let r;
      try {
        r = exports.storage.getItem("debug");
      } catch (error) {
      }
      if (!r && typeof process !== "undefined" && "env" in process) {
        r = process.env.DEBUG;
      }
      return r;
    }
    function localstorage() {
      try {
        return localStorage;
      } catch (error) {
      }
    }
    module2.exports = require_common2()(exports);
    var { formatters } = module2.exports;
    formatters.j = function(v) {
      try {
        return JSON.stringify(v);
      } catch (error) {
        return "[UnexpectedJSONParseError]: " + error.message;
      }
    };
  }
});

// node_modules/debug/src/node.js
var require_node2 = __commonJS({
  "node_modules/debug/src/node.js"(exports, module2) {
    var tty = require("tty");
    var util = require("util");
    exports.init = init;
    exports.log = log2;
    exports.formatArgs = formatArgs;
    exports.save = save;
    exports.load = load;
    exports.useColors = useColors;
    exports.destroy = util.deprecate(
      () => {
      },
      "Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`."
    );
    exports.colors = [6, 2, 3, 4, 5, 1];
    try {
      const supportsColor = require_supports_color();
      if (supportsColor && (supportsColor.stderr || supportsColor).level >= 2) {
        exports.colors = [
          20,
          21,
          26,
          27,
          32,
          33,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          56,
          57,
          62,
          63,
          68,
          69,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          92,
          93,
          98,
          99,
          112,
          113,
          128,
          129,
          134,
          135,
          148,
          149,
          160,
          161,
          162,
          163,
          164,
          165,
          166,
          167,
          168,
          169,
          170,
          171,
          172,
          173,
          178,
          179,
          184,
          185,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          214,
          215,
          220,
          221
        ];
      }
    } catch (error) {
    }
    exports.inspectOpts = Object.keys(process.env).filter((key) => {
      return /^debug_/i.test(key);
    }).reduce((obj, key) => {
      const prop = key.substring(6).toLowerCase().replace(/_([a-z])/g, (_, k) => {
        return k.toUpperCase();
      });
      let val = process.env[key];
      if (/^(yes|on|true|enabled)$/i.test(val)) {
        val = true;
      } else if (/^(no|off|false|disabled)$/i.test(val)) {
        val = false;
      } else if (val === "null") {
        val = null;
      } else {
        val = Number(val);
      }
      obj[prop] = val;
      return obj;
    }, {});
    function useColors() {
      return "colors" in exports.inspectOpts ? Boolean(exports.inspectOpts.colors) : tty.isatty(process.stderr.fd);
    }
    function formatArgs(args) {
      const { namespace: name, useColors: useColors2 } = this;
      if (useColors2) {
        const c = this.color;
        const colorCode = "\x1B[3" + (c < 8 ? c : "8;5;" + c);
        const prefix = `  ${colorCode};1m${name} \x1B[0m`;
        args[0] = prefix + args[0].split("\n").join("\n" + prefix);
        args.push(colorCode + "m+" + module2.exports.humanize(this.diff) + "\x1B[0m");
      } else {
        args[0] = getDate() + name + " " + args[0];
      }
    }
    function getDate() {
      if (exports.inspectOpts.hideDate) {
        return "";
      }
      return (/* @__PURE__ */ new Date()).toISOString() + " ";
    }
    function log2(...args) {
      return process.stderr.write(util.format(...args) + "\n");
    }
    function save(namespaces) {
      if (namespaces) {
        process.env.DEBUG = namespaces;
      } else {
        delete process.env.DEBUG;
      }
    }
    function load() {
      return process.env.DEBUG;
    }
    function init(debug) {
      debug.inspectOpts = {};
      const keys3 = Object.keys(exports.inspectOpts);
      for (let i = 0; i < keys3.length; i++) {
        debug.inspectOpts[keys3[i]] = exports.inspectOpts[keys3[i]];
      }
    }
    module2.exports = require_common2()(exports);
    var { formatters } = module2.exports;
    formatters.o = function(v) {
      this.inspectOpts.colors = this.useColors;
      return util.inspect(v, this.inspectOpts).split("\n").map((str) => str.trim()).join(" ");
    };
    formatters.O = function(v) {
      this.inspectOpts.colors = this.useColors;
      return util.inspect(v, this.inspectOpts);
    };
  }
});

// node_modules/debug/src/index.js
var require_src = __commonJS({
  "node_modules/debug/src/index.js"(exports, module2) {
    if (typeof process === "undefined" || process.type === "renderer" || process.browser === true || process.__nwjs) {
      module2.exports = require_browser();
    } else {
      module2.exports = require_node2();
    }
  }
});

// node_modules/lodash/head.js
var require_head = __commonJS({
  "node_modules/lodash/head.js"(exports, module2) {
    function head(array) {
      return array && array.length ? array[0] : void 0;
    }
    module2.exports = head;
  }
});

// node_modules/lodash/first.js
var require_first2 = __commonJS({
  "node_modules/lodash/first.js"(exports, module2) {
    module2.exports = require_head();
  }
});

// node_modules/lodash/sortedIndexBy.js
var require_sortedIndexBy = __commonJS({
  "node_modules/lodash/sortedIndexBy.js"(exports, module2) {
    var baseIteratee = require_baseIteratee();
    var baseSortedIndexBy = require_baseSortedIndexBy();
    function sortedIndexBy(array, value2, iteratee) {
      return baseSortedIndexBy(array, value2, baseIteratee(iteratee, 2));
    }
    module2.exports = sortedIndexBy;
  }
});

// node_modules/eslint-scope/node_modules/estraverse/package.json
var require_package = __commonJS({
  "node_modules/eslint-scope/node_modules/estraverse/package.json"(exports, module2) {
    module2.exports = {
      name: "estraverse",
      description: "ECMAScript JS AST traversal functions",
      homepage: "https://github.com/estools/estraverse",
      main: "estraverse.js",
      version: "4.3.0",
      engines: {
        node: ">=4.0"
      },
      maintainers: [
        {
          name: "Yusuke Suzuki",
          email: "utatane.tea@gmail.com",
          web: "http://github.com/Constellation"
        }
      ],
      repository: {
        type: "git",
        url: "http://github.com/estools/estraverse.git"
      },
      devDependencies: {
        "babel-preset-env": "^1.6.1",
        "babel-register": "^6.3.13",
        chai: "^2.1.1",
        espree: "^1.11.0",
        gulp: "^3.8.10",
        "gulp-bump": "^0.2.2",
        "gulp-filter": "^2.0.0",
        "gulp-git": "^1.0.1",
        "gulp-tag-version": "^1.3.0",
        jshint: "^2.5.6",
        mocha: "^2.1.0"
      },
      license: "BSD-2-Clause",
      scripts: {
        test: "npm run-script lint && npm run-script unit-test",
        lint: "jshint estraverse.js",
        "unit-test": "mocha --compilers js:babel-register"
      }
    };
  }
});

// node_modules/eslint-scope/node_modules/estraverse/estraverse.js
var require_estraverse = __commonJS({
  "node_modules/eslint-scope/node_modules/estraverse/estraverse.js"(exports) {
    (function clone(exports2) {
      "use strict";
      var Syntax, VisitorOption, VisitorKeys, BREAK, SKIP, REMOVE;
      function deepCopy(obj) {
        var ret = {}, key, val;
        for (key in obj) {
          if (obj.hasOwnProperty(key)) {
            val = obj[key];
            if (typeof val === "object" && val !== null) {
              ret[key] = deepCopy(val);
            } else {
              ret[key] = val;
            }
          }
        }
        return ret;
      }
      function upperBound(array, func) {
        var diff, len, i, current;
        len = array.length;
        i = 0;
        while (len) {
          diff = len >>> 1;
          current = i + diff;
          if (func(array[current])) {
            len = diff;
          } else {
            i = current + 1;
            len -= diff + 1;
          }
        }
        return i;
      }
      Syntax = {
        AssignmentExpression: "AssignmentExpression",
        AssignmentPattern: "AssignmentPattern",
        ArrayExpression: "ArrayExpression",
        ArrayPattern: "ArrayPattern",
        ArrowFunctionExpression: "ArrowFunctionExpression",
        AwaitExpression: "AwaitExpression",
        // CAUTION: It's deferred to ES7.
        BlockStatement: "BlockStatement",
        BinaryExpression: "BinaryExpression",
        BreakStatement: "BreakStatement",
        CallExpression: "CallExpression",
        CatchClause: "CatchClause",
        ClassBody: "ClassBody",
        ClassDeclaration: "ClassDeclaration",
        ClassExpression: "ClassExpression",
        ComprehensionBlock: "ComprehensionBlock",
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: "ComprehensionExpression",
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: "ConditionalExpression",
        ContinueStatement: "ContinueStatement",
        DebuggerStatement: "DebuggerStatement",
        DirectiveStatement: "DirectiveStatement",
        DoWhileStatement: "DoWhileStatement",
        EmptyStatement: "EmptyStatement",
        ExportAllDeclaration: "ExportAllDeclaration",
        ExportDefaultDeclaration: "ExportDefaultDeclaration",
        ExportNamedDeclaration: "ExportNamedDeclaration",
        ExportSpecifier: "ExportSpecifier",
        ExpressionStatement: "ExpressionStatement",
        ForStatement: "ForStatement",
        ForInStatement: "ForInStatement",
        ForOfStatement: "ForOfStatement",
        FunctionDeclaration: "FunctionDeclaration",
        FunctionExpression: "FunctionExpression",
        GeneratorExpression: "GeneratorExpression",
        // CAUTION: It's deferred to ES7.
        Identifier: "Identifier",
        IfStatement: "IfStatement",
        ImportExpression: "ImportExpression",
        ImportDeclaration: "ImportDeclaration",
        ImportDefaultSpecifier: "ImportDefaultSpecifier",
        ImportNamespaceSpecifier: "ImportNamespaceSpecifier",
        ImportSpecifier: "ImportSpecifier",
        Literal: "Literal",
        LabeledStatement: "LabeledStatement",
        LogicalExpression: "LogicalExpression",
        MemberExpression: "MemberExpression",
        MetaProperty: "MetaProperty",
        MethodDefinition: "MethodDefinition",
        ModuleSpecifier: "ModuleSpecifier",
        NewExpression: "NewExpression",
        ObjectExpression: "ObjectExpression",
        ObjectPattern: "ObjectPattern",
        Program: "Program",
        Property: "Property",
        RestElement: "RestElement",
        ReturnStatement: "ReturnStatement",
        SequenceExpression: "SequenceExpression",
        SpreadElement: "SpreadElement",
        Super: "Super",
        SwitchStatement: "SwitchStatement",
        SwitchCase: "SwitchCase",
        TaggedTemplateExpression: "TaggedTemplateExpression",
        TemplateElement: "TemplateElement",
        TemplateLiteral: "TemplateLiteral",
        ThisExpression: "ThisExpression",
        ThrowStatement: "ThrowStatement",
        TryStatement: "TryStatement",
        UnaryExpression: "UnaryExpression",
        UpdateExpression: "UpdateExpression",
        VariableDeclaration: "VariableDeclaration",
        VariableDeclarator: "VariableDeclarator",
        WhileStatement: "WhileStatement",
        WithStatement: "WithStatement",
        YieldExpression: "YieldExpression"
      };
      VisitorKeys = {
        AssignmentExpression: ["left", "right"],
        AssignmentPattern: ["left", "right"],
        ArrayExpression: ["elements"],
        ArrayPattern: ["elements"],
        ArrowFunctionExpression: ["params", "body"],
        AwaitExpression: ["argument"],
        // CAUTION: It's deferred to ES7.
        BlockStatement: ["body"],
        BinaryExpression: ["left", "right"],
        BreakStatement: ["label"],
        CallExpression: ["callee", "arguments"],
        CatchClause: ["param", "body"],
        ClassBody: ["body"],
        ClassDeclaration: ["id", "superClass", "body"],
        ClassExpression: ["id", "superClass", "body"],
        ComprehensionBlock: ["left", "right"],
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: ["test", "consequent", "alternate"],
        ContinueStatement: ["label"],
        DebuggerStatement: [],
        DirectiveStatement: [],
        DoWhileStatement: ["body", "test"],
        EmptyStatement: [],
        ExportAllDeclaration: ["source"],
        ExportDefaultDeclaration: ["declaration"],
        ExportNamedDeclaration: ["declaration", "specifiers", "source"],
        ExportSpecifier: ["exported", "local"],
        ExpressionStatement: ["expression"],
        ForStatement: ["init", "test", "update", "body"],
        ForInStatement: ["left", "right", "body"],
        ForOfStatement: ["left", "right", "body"],
        FunctionDeclaration: ["id", "params", "body"],
        FunctionExpression: ["id", "params", "body"],
        GeneratorExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        Identifier: [],
        IfStatement: ["test", "consequent", "alternate"],
        ImportExpression: ["source"],
        ImportDeclaration: ["specifiers", "source"],
        ImportDefaultSpecifier: ["local"],
        ImportNamespaceSpecifier: ["local"],
        ImportSpecifier: ["imported", "local"],
        Literal: [],
        LabeledStatement: ["label", "body"],
        LogicalExpression: ["left", "right"],
        MemberExpression: ["object", "property"],
        MetaProperty: ["meta", "property"],
        MethodDefinition: ["key", "value"],
        ModuleSpecifier: [],
        NewExpression: ["callee", "arguments"],
        ObjectExpression: ["properties"],
        ObjectPattern: ["properties"],
        Program: ["body"],
        Property: ["key", "value"],
        RestElement: ["argument"],
        ReturnStatement: ["argument"],
        SequenceExpression: ["expressions"],
        SpreadElement: ["argument"],
        Super: [],
        SwitchStatement: ["discriminant", "cases"],
        SwitchCase: ["test", "consequent"],
        TaggedTemplateExpression: ["tag", "quasi"],
        TemplateElement: [],
        TemplateLiteral: ["quasis", "expressions"],
        ThisExpression: [],
        ThrowStatement: ["argument"],
        TryStatement: ["block", "handler", "finalizer"],
        UnaryExpression: ["argument"],
        UpdateExpression: ["argument"],
        VariableDeclaration: ["declarations"],
        VariableDeclarator: ["id", "init"],
        WhileStatement: ["test", "body"],
        WithStatement: ["object", "body"],
        YieldExpression: ["argument"]
      };
      BREAK = {};
      SKIP = {};
      REMOVE = {};
      VisitorOption = {
        Break: BREAK,
        Skip: SKIP,
        Remove: REMOVE
      };
      function Reference(parent, key) {
        this.parent = parent;
        this.key = key;
      }
      Reference.prototype.replace = function replace2(node) {
        this.parent[this.key] = node;
      };
      Reference.prototype.remove = function remove() {
        if (Array.isArray(this.parent)) {
          this.parent.splice(this.key, 1);
          return true;
        } else {
          this.replace(null);
          return false;
        }
      };
      function Element2(node, path2, wrap, ref) {
        this.node = node;
        this.path = path2;
        this.wrap = wrap;
        this.ref = ref;
      }
      function Controller() {
      }
      Controller.prototype.path = function path2() {
        var i, iz, j, jz, result, element;
        function addToPath(result2, path3) {
          if (Array.isArray(path3)) {
            for (j = 0, jz = path3.length; j < jz; ++j) {
              result2.push(path3[j]);
            }
          } else {
            result2.push(path3);
          }
        }
        if (!this.__current.path) {
          return null;
        }
        result = [];
        for (i = 2, iz = this.__leavelist.length; i < iz; ++i) {
          element = this.__leavelist[i];
          addToPath(result, element.path);
        }
        addToPath(result, this.__current.path);
        return result;
      };
      Controller.prototype.type = function() {
        var node = this.current();
        return node.type || this.__current.wrap;
      };
      Controller.prototype.parents = function parents() {
        var i, iz, result;
        result = [];
        for (i = 1, iz = this.__leavelist.length; i < iz; ++i) {
          result.push(this.__leavelist[i].node);
        }
        return result;
      };
      Controller.prototype.current = function current() {
        return this.__current.node;
      };
      Controller.prototype.__execute = function __execute(callback, element) {
        var previous, result;
        result = void 0;
        previous = this.__current;
        this.__current = element;
        this.__state = null;
        if (callback) {
          result = callback.call(this, element.node, this.__leavelist[this.__leavelist.length - 1].node);
        }
        this.__current = previous;
        return result;
      };
      Controller.prototype.notify = function notify(flag) {
        this.__state = flag;
      };
      Controller.prototype.skip = function() {
        this.notify(SKIP);
      };
      Controller.prototype["break"] = function() {
        this.notify(BREAK);
      };
      Controller.prototype.remove = function() {
        this.notify(REMOVE);
      };
      Controller.prototype.__initialize = function(root2, visitor) {
        this.visitor = visitor;
        this.root = root2;
        this.__worklist = [];
        this.__leavelist = [];
        this.__current = null;
        this.__state = null;
        this.__fallback = null;
        if (visitor.fallback === "iteration") {
          this.__fallback = Object.keys;
        } else if (typeof visitor.fallback === "function") {
          this.__fallback = visitor.fallback;
        }
        this.__keys = VisitorKeys;
        if (visitor.keys) {
          this.__keys = Object.assign(Object.create(this.__keys), visitor.keys);
        }
      };
      function isNode(node) {
        if (node == null) {
          return false;
        }
        return typeof node === "object" && typeof node.type === "string";
      }
      function isProperty(nodeType, key) {
        return (nodeType === Syntax.ObjectExpression || nodeType === Syntax.ObjectPattern) && "properties" === key;
      }
      Controller.prototype.traverse = function traverse4(root2, visitor) {
        var worklist, leavelist, element, node, nodeType, ret, key, current, current2, candidates, candidate, sentinel;
        this.__initialize(root2, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        worklist.push(new Element2(root2, null, null, null));
        leavelist.push(new Element2(null, null, null, null));
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            ret = this.__execute(visitor.leave, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            continue;
          }
          if (element.node) {
            ret = this.__execute(visitor.enter, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            worklist.push(sentinel);
            leavelist.push(element);
            if (this.__state === SKIP || ret === SKIP) {
              continue;
            }
            node = element.node;
            nodeType = node.type || element.wrap;
            candidates = this.__keys[nodeType];
            if (!candidates) {
              if (this.__fallback) {
                candidates = this.__fallback(node);
              } else {
                throw new Error("Unknown node type " + nodeType + ".");
              }
            }
            current = candidates.length;
            while ((current -= 1) >= 0) {
              key = candidates[current];
              candidate = node[key];
              if (!candidate) {
                continue;
              }
              if (Array.isArray(candidate)) {
                current2 = candidate.length;
                while ((current2 -= 1) >= 0) {
                  if (!candidate[current2]) {
                    continue;
                  }
                  if (isProperty(nodeType, candidates[current])) {
                    element = new Element2(candidate[current2], [key, current2], "Property", null);
                  } else if (isNode(candidate[current2])) {
                    element = new Element2(candidate[current2], [key, current2], null, null);
                  } else {
                    continue;
                  }
                  worklist.push(element);
                }
              } else if (isNode(candidate)) {
                worklist.push(new Element2(candidate, key, null, null));
              }
            }
          }
        }
      };
      Controller.prototype.replace = function replace2(root2, visitor) {
        var worklist, leavelist, node, nodeType, target, element, current, current2, candidates, candidate, sentinel, outer, key;
        function removeElem(element2) {
          var i, key2, nextElem, parent;
          if (element2.ref.remove()) {
            key2 = element2.ref.key;
            parent = element2.ref.parent;
            i = worklist.length;
            while (i--) {
              nextElem = worklist[i];
              if (nextElem.ref && nextElem.ref.parent === parent) {
                if (nextElem.ref.key < key2) {
                  break;
                }
                --nextElem.ref.key;
              }
            }
          }
        }
        this.__initialize(root2, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        outer = {
          root: root2
        };
        element = new Element2(root2, null, null, new Reference(outer, "root"));
        worklist.push(element);
        leavelist.push(element);
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            target = this.__execute(visitor.leave, element);
            if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
              element.ref.replace(target);
            }
            if (this.__state === REMOVE || target === REMOVE) {
              removeElem(element);
            }
            if (this.__state === BREAK || target === BREAK) {
              return outer.root;
            }
            continue;
          }
          target = this.__execute(visitor.enter, element);
          if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
            element.ref.replace(target);
            element.node = target;
          }
          if (this.__state === REMOVE || target === REMOVE) {
            removeElem(element);
            element.node = null;
          }
          if (this.__state === BREAK || target === BREAK) {
            return outer.root;
          }
          node = element.node;
          if (!node) {
            continue;
          }
          worklist.push(sentinel);
          leavelist.push(element);
          if (this.__state === SKIP || target === SKIP) {
            continue;
          }
          nodeType = node.type || element.wrap;
          candidates = this.__keys[nodeType];
          if (!candidates) {
            if (this.__fallback) {
              candidates = this.__fallback(node);
            } else {
              throw new Error("Unknown node type " + nodeType + ".");
            }
          }
          current = candidates.length;
          while ((current -= 1) >= 0) {
            key = candidates[current];
            candidate = node[key];
            if (!candidate) {
              continue;
            }
            if (Array.isArray(candidate)) {
              current2 = candidate.length;
              while ((current2 -= 1) >= 0) {
                if (!candidate[current2]) {
                  continue;
                }
                if (isProperty(nodeType, candidates[current])) {
                  element = new Element2(candidate[current2], [key, current2], "Property", new Reference(candidate, current2));
                } else if (isNode(candidate[current2])) {
                  element = new Element2(candidate[current2], [key, current2], null, new Reference(candidate, current2));
                } else {
                  continue;
                }
                worklist.push(element);
              }
            } else if (isNode(candidate)) {
              worklist.push(new Element2(candidate, key, null, new Reference(node, key)));
            }
          }
        }
        return outer.root;
      };
      function traverse3(root2, visitor) {
        var controller = new Controller();
        return controller.traverse(root2, visitor);
      }
      function replace(root2, visitor) {
        var controller = new Controller();
        return controller.replace(root2, visitor);
      }
      function extendCommentRange(comment, tokens) {
        var target;
        target = upperBound(tokens, function search(token) {
          return token.range[0] > comment.range[0];
        });
        comment.extendedRange = [comment.range[0], comment.range[1]];
        if (target !== tokens.length) {
          comment.extendedRange[1] = tokens[target].range[0];
        }
        target -= 1;
        if (target >= 0) {
          comment.extendedRange[0] = tokens[target].range[1];
        }
        return comment;
      }
      function attachComments(tree, providedComments, tokens) {
        var comments = [], comment, len, i, cursor;
        if (!tree.range) {
          throw new Error("attachComments needs range information");
        }
        if (!tokens.length) {
          if (providedComments.length) {
            for (i = 0, len = providedComments.length; i < len; i += 1) {
              comment = deepCopy(providedComments[i]);
              comment.extendedRange = [0, tree.range[0]];
              comments.push(comment);
            }
            tree.leadingComments = comments;
          }
          return tree;
        }
        for (i = 0, len = providedComments.length; i < len; i += 1) {
          comments.push(extendCommentRange(deepCopy(providedComments[i]), tokens));
        }
        cursor = 0;
        traverse3(tree, {
          enter: function(node) {
            var comment2;
            while (cursor < comments.length) {
              comment2 = comments[cursor];
              if (comment2.extendedRange[1] > node.range[0]) {
                break;
              }
              if (comment2.extendedRange[1] === node.range[0]) {
                if (!node.leadingComments) {
                  node.leadingComments = [];
                }
                node.leadingComments.push(comment2);
                comments.splice(cursor, 1);
              } else {
                cursor += 1;
              }
            }
            if (cursor === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }
        });
        cursor = 0;
        traverse3(tree, {
          leave: function(node) {
            var comment2;
            while (cursor < comments.length) {
              comment2 = comments[cursor];
              if (node.range[1] < comment2.extendedRange[0]) {
                break;
              }
              if (node.range[1] === comment2.extendedRange[0]) {
                if (!node.trailingComments) {
                  node.trailingComments = [];
                }
                node.trailingComments.push(comment2);
                comments.splice(cursor, 1);
              } else {
                cursor += 1;
              }
            }
            if (cursor === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }
        });
        return tree;
      }
      exports2.version = require_package().version;
      exports2.Syntax = Syntax;
      exports2.traverse = traverse3;
      exports2.replace = replace;
      exports2.attachComments = attachComments;
      exports2.VisitorKeys = VisitorKeys;
      exports2.VisitorOption = VisitorOption;
      exports2.Controller = Controller;
      exports2.cloneEnvironment = function() {
        return clone({});
      };
      return exports2;
    })(exports);
  }
});

// node_modules/eslint-scope/lib/reference.js
var require_reference = __commonJS({
  "node_modules/eslint-scope/lib/reference.js"(exports, module2) {
    "use strict";
    var READ = 1;
    var WRITE = 2;
    var RW = READ | WRITE;
    var Reference = class _Reference {
      constructor(ident, scope, flag, writeExpr, maybeImplicitGlobal, partial, init) {
        this.identifier = ident;
        this.from = scope;
        this.tainted = false;
        this.resolved = null;
        this.flag = flag;
        if (this.isWrite()) {
          this.writeExpr = writeExpr;
          this.partial = partial;
          this.init = init;
        }
        this.__maybeImplicitGlobal = maybeImplicitGlobal;
      }
      /**
       * Whether the reference is static.
       * @method Reference#isStatic
       * @returns {boolean} static
       */
      isStatic() {
        return !this.tainted && this.resolved && this.resolved.scope.isStatic();
      }
      /**
       * Whether the reference is writeable.
       * @method Reference#isWrite
       * @returns {boolean} write
       */
      isWrite() {
        return !!(this.flag & _Reference.WRITE);
      }
      /**
       * Whether the reference is readable.
       * @method Reference#isRead
       * @returns {boolean} read
       */
      isRead() {
        return !!(this.flag & _Reference.READ);
      }
      /**
       * Whether the reference is read-only.
       * @method Reference#isReadOnly
       * @returns {boolean} read only
       */
      isReadOnly() {
        return this.flag === _Reference.READ;
      }
      /**
       * Whether the reference is write-only.
       * @method Reference#isWriteOnly
       * @returns {boolean} write only
       */
      isWriteOnly() {
        return this.flag === _Reference.WRITE;
      }
      /**
       * Whether the reference is read-write.
       * @method Reference#isReadWrite
       * @returns {boolean} read write
       */
      isReadWrite() {
        return this.flag === _Reference.RW;
      }
    };
    Reference.READ = READ;
    Reference.WRITE = WRITE;
    Reference.RW = RW;
    module2.exports = Reference;
  }
});

// node_modules/eslint-scope/lib/variable.js
var require_variable = __commonJS({
  "node_modules/eslint-scope/lib/variable.js"(exports, module2) {
    "use strict";
    var Variable = class {
      constructor(name, scope) {
        this.name = name;
        this.identifiers = [];
        this.references = [];
        this.defs = [];
        this.tainted = false;
        this.stack = true;
        this.scope = scope;
      }
    };
    Variable.CatchClause = "CatchClause";
    Variable.Parameter = "Parameter";
    Variable.FunctionName = "FunctionName";
    Variable.ClassName = "ClassName";
    Variable.Variable = "Variable";
    Variable.ImportBinding = "ImportBinding";
    Variable.ImplicitGlobalVariable = "ImplicitGlobalVariable";
    module2.exports = Variable;
  }
});

// node_modules/eslint-scope/lib/definition.js
var require_definition = __commonJS({
  "node_modules/eslint-scope/lib/definition.js"(exports, module2) {
    "use strict";
    var Variable = require_variable();
    var Definition = class {
      constructor(type, name, node, parent, index, kind) {
        this.type = type;
        this.name = name;
        this.node = node;
        this.parent = parent;
        this.index = index;
        this.kind = kind;
      }
    };
    var ParameterDefinition = class extends Definition {
      constructor(name, node, index, rest) {
        super(Variable.Parameter, name, node, null, index, null);
        this.rest = rest;
      }
    };
    module2.exports = {
      ParameterDefinition,
      Definition
    };
  }
});

// node_modules/eslint-scope/lib/scope.js
var require_scope = __commonJS({
  "node_modules/eslint-scope/lib/scope.js"(exports, module2) {
    "use strict";
    var Syntax = require_estraverse().Syntax;
    var Reference = require_reference();
    var Variable = require_variable();
    var Definition = require_definition().Definition;
    var assert = require("assert");
    function isStrictScope(scope, block, isMethodDefinition, useDirective) {
      let body;
      if (scope.upper && scope.upper.isStrict) {
        return true;
      }
      if (isMethodDefinition) {
        return true;
      }
      if (scope.type === "class" || scope.type === "module") {
        return true;
      }
      if (scope.type === "block" || scope.type === "switch") {
        return false;
      }
      if (scope.type === "function") {
        if (block.type === Syntax.ArrowFunctionExpression && block.body.type !== Syntax.BlockStatement) {
          return false;
        }
        if (block.type === Syntax.Program) {
          body = block;
        } else {
          body = block.body;
        }
        if (!body) {
          return false;
        }
      } else if (scope.type === "global") {
        body = block;
      } else {
        return false;
      }
      if (useDirective) {
        for (let i = 0, iz = body.body.length; i < iz; ++i) {
          const stmt = body.body[i];
          if (stmt.type !== Syntax.DirectiveStatement) {
            break;
          }
          if (stmt.raw === '"use strict"' || stmt.raw === "'use strict'") {
            return true;
          }
        }
      } else {
        for (let i = 0, iz = body.body.length; i < iz; ++i) {
          const stmt = body.body[i];
          if (stmt.type !== Syntax.ExpressionStatement) {
            break;
          }
          const expr = stmt.expression;
          if (expr.type !== Syntax.Literal || typeof expr.value !== "string") {
            break;
          }
          if (expr.raw !== null && expr.raw !== void 0) {
            if (expr.raw === '"use strict"' || expr.raw === "'use strict'") {
              return true;
            }
          } else {
            if (expr.value === "use strict") {
              return true;
            }
          }
        }
      }
      return false;
    }
    function registerScope(scopeManager, scope) {
      scopeManager.scopes.push(scope);
      const scopes = scopeManager.__nodeToScope.get(scope.block);
      if (scopes) {
        scopes.push(scope);
      } else {
        scopeManager.__nodeToScope.set(scope.block, [scope]);
      }
    }
    function shouldBeStatically(def) {
      return def.type === Variable.ClassName || def.type === Variable.Variable && def.parent.kind !== "var";
    }
    var Scope = class {
      constructor(scopeManager, type, upperScope, block, isMethodDefinition) {
        this.type = type;
        this.set = /* @__PURE__ */ new Map();
        this.taints = /* @__PURE__ */ new Map();
        this.dynamic = this.type === "global" || this.type === "with";
        this.block = block;
        this.through = [];
        this.variables = [];
        this.references = [];
        this.variableScope = this.type === "global" || this.type === "function" || this.type === "module" ? this : upperScope.variableScope;
        this.functionExpressionScope = false;
        this.directCallToEvalScope = false;
        this.thisFound = false;
        this.__left = [];
        this.upper = upperScope;
        this.isStrict = isStrictScope(this, block, isMethodDefinition, scopeManager.__useDirective());
        this.childScopes = [];
        if (this.upper) {
          this.upper.childScopes.push(this);
        }
        this.__declaredVariables = scopeManager.__declaredVariables;
        registerScope(scopeManager, this);
      }
      __shouldStaticallyClose(scopeManager) {
        return !this.dynamic || scopeManager.__isOptimistic();
      }
      __shouldStaticallyCloseForGlobal(ref) {
        const name = ref.identifier.name;
        if (!this.set.has(name)) {
          return false;
        }
        const variable = this.set.get(name);
        const defs = variable.defs;
        return defs.length > 0 && defs.every(shouldBeStatically);
      }
      __staticCloseRef(ref) {
        if (!this.__resolve(ref)) {
          this.__delegateToUpperScope(ref);
        }
      }
      __dynamicCloseRef(ref) {
        let current = this;
        do {
          current.through.push(ref);
          current = current.upper;
        } while (current);
      }
      __globalCloseRef(ref) {
        if (this.__shouldStaticallyCloseForGlobal(ref)) {
          this.__staticCloseRef(ref);
        } else {
          this.__dynamicCloseRef(ref);
        }
      }
      __close(scopeManager) {
        let closeRef;
        if (this.__shouldStaticallyClose(scopeManager)) {
          closeRef = this.__staticCloseRef;
        } else if (this.type !== "global") {
          closeRef = this.__dynamicCloseRef;
        } else {
          closeRef = this.__globalCloseRef;
        }
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          closeRef.call(this, ref);
        }
        this.__left = null;
        return this.upper;
      }
      // To override by function scopes.
      // References in default parameters isn't resolved to variables which are in their function body.
      __isValidResolution(ref, variable) {
        return true;
      }
      __resolve(ref) {
        const name = ref.identifier.name;
        if (!this.set.has(name)) {
          return false;
        }
        const variable = this.set.get(name);
        if (!this.__isValidResolution(ref, variable)) {
          return false;
        }
        variable.references.push(ref);
        variable.stack = variable.stack && ref.from.variableScope === this.variableScope;
        if (ref.tainted) {
          variable.tainted = true;
          this.taints.set(variable.name, true);
        }
        ref.resolved = variable;
        return true;
      }
      __delegateToUpperScope(ref) {
        if (this.upper) {
          this.upper.__left.push(ref);
        }
        this.through.push(ref);
      }
      __addDeclaredVariablesOfNode(variable, node) {
        if (node === null || node === void 0) {
          return;
        }
        let variables = this.__declaredVariables.get(node);
        if (variables === null || variables === void 0) {
          variables = [];
          this.__declaredVariables.set(node, variables);
        }
        if (variables.indexOf(variable) === -1) {
          variables.push(variable);
        }
      }
      __defineGeneric(name, set, variables, node, def) {
        let variable;
        variable = set.get(name);
        if (!variable) {
          variable = new Variable(name, this);
          set.set(name, variable);
          variables.push(variable);
        }
        if (def) {
          variable.defs.push(def);
          this.__addDeclaredVariablesOfNode(variable, def.node);
          this.__addDeclaredVariablesOfNode(variable, def.parent);
        }
        if (node) {
          variable.identifiers.push(node);
        }
      }
      __define(node, def) {
        if (node && node.type === Syntax.Identifier) {
          this.__defineGeneric(
            node.name,
            this.set,
            this.variables,
            node,
            def
          );
        }
      }
      __referencing(node, assign, writeExpr, maybeImplicitGlobal, partial, init) {
        if (!node || node.type !== Syntax.Identifier) {
          return;
        }
        if (node.name === "super") {
          return;
        }
        const ref = new Reference(node, this, assign || Reference.READ, writeExpr, maybeImplicitGlobal, !!partial, !!init);
        this.references.push(ref);
        this.__left.push(ref);
      }
      __detectEval() {
        let current = this;
        this.directCallToEvalScope = true;
        do {
          current.dynamic = true;
          current = current.upper;
        } while (current);
      }
      __detectThis() {
        this.thisFound = true;
      }
      __isClosed() {
        return this.__left === null;
      }
      /**
       * returns resolved {Reference}
       * @method Scope#resolve
       * @param {Espree.Identifier} ident - identifier to be resolved.
       * @returns {Reference} reference
       */
      resolve(ident) {
        let ref, i, iz;
        assert(this.__isClosed(), "Scope should be closed.");
        assert(ident.type === Syntax.Identifier, "Target should be identifier.");
        for (i = 0, iz = this.references.length; i < iz; ++i) {
          ref = this.references[i];
          if (ref.identifier === ident) {
            return ref;
          }
        }
        return null;
      }
      /**
       * returns this scope is static
       * @method Scope#isStatic
       * @returns {boolean} static
       */
      isStatic() {
        return !this.dynamic;
      }
      /**
       * returns this scope has materialized arguments
       * @method Scope#isArgumentsMaterialized
       * @returns {boolean} arguemnts materialized
       */
      isArgumentsMaterialized() {
        return true;
      }
      /**
       * returns this scope has materialized `this` reference
       * @method Scope#isThisMaterialized
       * @returns {boolean} this materialized
       */
      isThisMaterialized() {
        return true;
      }
      isUsedName(name) {
        if (this.set.has(name)) {
          return true;
        }
        for (let i = 0, iz = this.through.length; i < iz; ++i) {
          if (this.through[i].identifier.name === name) {
            return true;
          }
        }
        return false;
      }
    };
    var GlobalScope = class extends Scope {
      constructor(scopeManager, block) {
        super(scopeManager, "global", null, block, false);
        this.implicit = {
          set: /* @__PURE__ */ new Map(),
          variables: [],
          /**
          * List of {@link Reference}s that are left to be resolved (i.e. which
          * need to be linked to the variable they refer to).
          * @member {Reference[]} Scope#implicit#left
          */
          left: []
        };
      }
      __close(scopeManager) {
        const implicit = [];
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          if (ref.__maybeImplicitGlobal && !this.set.has(ref.identifier.name)) {
            implicit.push(ref.__maybeImplicitGlobal);
          }
        }
        for (let i = 0, iz = implicit.length; i < iz; ++i) {
          const info = implicit[i];
          this.__defineImplicit(
            info.pattern,
            new Definition(
              Variable.ImplicitGlobalVariable,
              info.pattern,
              info.node,
              null,
              null,
              null
            )
          );
        }
        this.implicit.left = this.__left;
        return super.__close(scopeManager);
      }
      __defineImplicit(node, def) {
        if (node && node.type === Syntax.Identifier) {
          this.__defineGeneric(
            node.name,
            this.implicit.set,
            this.implicit.variables,
            node,
            def
          );
        }
      }
    };
    var ModuleScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "module", upperScope, block, false);
      }
    };
    var FunctionExpressionNameScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "function-expression-name", upperScope, block, false);
        this.__define(
          block.id,
          new Definition(
            Variable.FunctionName,
            block.id,
            block,
            null,
            null,
            null
          )
        );
        this.functionExpressionScope = true;
      }
    };
    var CatchScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "catch", upperScope, block, false);
      }
    };
    var WithScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "with", upperScope, block, false);
      }
      __close(scopeManager) {
        if (this.__shouldStaticallyClose(scopeManager)) {
          return super.__close(scopeManager);
        }
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          ref.tainted = true;
          this.__delegateToUpperScope(ref);
        }
        this.__left = null;
        return this.upper;
      }
    };
    var BlockScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "block", upperScope, block, false);
      }
    };
    var SwitchScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "switch", upperScope, block, false);
      }
    };
    var FunctionScope = class extends Scope {
      constructor(scopeManager, upperScope, block, isMethodDefinition) {
        super(scopeManager, "function", upperScope, block, isMethodDefinition);
        if (this.block.type !== Syntax.ArrowFunctionExpression) {
          this.__defineArguments();
        }
      }
      isArgumentsMaterialized() {
        if (this.block.type === Syntax.ArrowFunctionExpression) {
          return false;
        }
        if (!this.isStatic()) {
          return true;
        }
        const variable = this.set.get("arguments");
        assert(variable, "Always have arguments variable.");
        return variable.tainted || variable.references.length !== 0;
      }
      isThisMaterialized() {
        if (!this.isStatic()) {
          return true;
        }
        return this.thisFound;
      }
      __defineArguments() {
        this.__defineGeneric(
          "arguments",
          this.set,
          this.variables,
          null,
          null
        );
        this.taints.set("arguments", true);
      }
      // References in default parameters isn't resolved to variables which are in their function body.
      //     const x = 1
      //     function f(a = x) { // This `x` is resolved to the `x` in the outer scope.
      //         const x = 2
      //         console.log(a)
      //     }
      __isValidResolution(ref, variable) {
        if (this.block.type === "Program") {
          return true;
        }
        const bodyStart = this.block.body.range[0];
        return !(variable.scope === this && ref.identifier.range[0] < bodyStart && // the reference is in the parameter part.
        variable.defs.every((d) => d.name.range[0] >= bodyStart));
      }
    };
    var ForScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "for", upperScope, block, false);
      }
    };
    var ClassScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "class", upperScope, block, false);
      }
    };
    module2.exports = {
      Scope,
      GlobalScope,
      ModuleScope,
      FunctionExpressionNameScope,
      CatchScope,
      WithScope,
      BlockScope,
      SwitchScope,
      FunctionScope,
      ForScope,
      ClassScope
    };
  }
});

// node_modules/eslint-scope/lib/scope-manager.js
var require_scope_manager = __commonJS({
  "node_modules/eslint-scope/lib/scope-manager.js"(exports, module2) {
    "use strict";
    var Scope = require_scope();
    var assert = require("assert");
    var GlobalScope = Scope.GlobalScope;
    var CatchScope = Scope.CatchScope;
    var WithScope = Scope.WithScope;
    var ModuleScope = Scope.ModuleScope;
    var ClassScope = Scope.ClassScope;
    var SwitchScope = Scope.SwitchScope;
    var FunctionScope = Scope.FunctionScope;
    var ForScope = Scope.ForScope;
    var FunctionExpressionNameScope = Scope.FunctionExpressionNameScope;
    var BlockScope = Scope.BlockScope;
    var ScopeManager = class {
      constructor(options) {
        this.scopes = [];
        this.globalScope = null;
        this.__nodeToScope = /* @__PURE__ */ new WeakMap();
        this.__currentScope = null;
        this.__options = options;
        this.__declaredVariables = /* @__PURE__ */ new WeakMap();
      }
      __useDirective() {
        return this.__options.directive;
      }
      __isOptimistic() {
        return this.__options.optimistic;
      }
      __ignoreEval() {
        return this.__options.ignoreEval;
      }
      __isNodejsScope() {
        return this.__options.nodejsScope;
      }
      isModule() {
        return this.__options.sourceType === "module";
      }
      isImpliedStrict() {
        return this.__options.impliedStrict;
      }
      isStrictModeSupported() {
        return this.__options.ecmaVersion >= 5;
      }
      // Returns appropriate scope for this node.
      __get(node) {
        return this.__nodeToScope.get(node);
      }
      /**
       * Get variables that are declared by the node.
       *
       * "are declared by the node" means the node is same as `Variable.defs[].node` or `Variable.defs[].parent`.
       * If the node declares nothing, this method returns an empty array.
       * CAUTION: This API is experimental. See https://github.com/estools/escope/pull/69 for more details.
       *
       * @param {Espree.Node} node - a node to get.
       * @returns {Variable[]} variables that declared by the node.
       */
      getDeclaredVariables(node) {
        return this.__declaredVariables.get(node) || [];
      }
      /**
       * acquire scope from node.
       * @method ScopeManager#acquire
       * @param {Espree.Node} node - node for the acquired scope.
       * @param {boolean=} inner - look up the most inner scope, default value is false.
       * @returns {Scope?} Scope from node
       */
      acquire(node, inner) {
        function predicate(testScope) {
          if (testScope.type === "function" && testScope.functionExpressionScope) {
            return false;
          }
          return true;
        }
        const scopes = this.__get(node);
        if (!scopes || scopes.length === 0) {
          return null;
        }
        if (scopes.length === 1) {
          return scopes[0];
        }
        if (inner) {
          for (let i = scopes.length - 1; i >= 0; --i) {
            const scope = scopes[i];
            if (predicate(scope)) {
              return scope;
            }
          }
        } else {
          for (let i = 0, iz = scopes.length; i < iz; ++i) {
            const scope = scopes[i];
            if (predicate(scope)) {
              return scope;
            }
          }
        }
        return null;
      }
      /**
       * acquire all scopes from node.
       * @method ScopeManager#acquireAll
       * @param {Espree.Node} node - node for the acquired scope.
       * @returns {Scopes?} Scope array
       */
      acquireAll(node) {
        return this.__get(node);
      }
      /**
       * release the node.
       * @method ScopeManager#release
       * @param {Espree.Node} node - releasing node.
       * @param {boolean=} inner - look up the most inner scope, default value is false.
       * @returns {Scope?} upper scope for the node.
       */
      release(node, inner) {
        const scopes = this.__get(node);
        if (scopes && scopes.length) {
          const scope = scopes[0].upper;
          if (!scope) {
            return null;
          }
          return this.acquire(scope.block, inner);
        }
        return null;
      }
      attach() {
      }
      // eslint-disable-line class-methods-use-this
      detach() {
      }
      // eslint-disable-line class-methods-use-this
      __nestScope(scope) {
        if (scope instanceof GlobalScope) {
          assert(this.__currentScope === null);
          this.globalScope = scope;
        }
        this.__currentScope = scope;
        return scope;
      }
      __nestGlobalScope(node) {
        return this.__nestScope(new GlobalScope(this, node));
      }
      __nestBlockScope(node) {
        return this.__nestScope(new BlockScope(this, this.__currentScope, node));
      }
      __nestFunctionScope(node, isMethodDefinition) {
        return this.__nestScope(new FunctionScope(this, this.__currentScope, node, isMethodDefinition));
      }
      __nestForScope(node) {
        return this.__nestScope(new ForScope(this, this.__currentScope, node));
      }
      __nestCatchScope(node) {
        return this.__nestScope(new CatchScope(this, this.__currentScope, node));
      }
      __nestWithScope(node) {
        return this.__nestScope(new WithScope(this, this.__currentScope, node));
      }
      __nestClassScope(node) {
        return this.__nestScope(new ClassScope(this, this.__currentScope, node));
      }
      __nestSwitchScope(node) {
        return this.__nestScope(new SwitchScope(this, this.__currentScope, node));
      }
      __nestModuleScope(node) {
        return this.__nestScope(new ModuleScope(this, this.__currentScope, node));
      }
      __nestFunctionExpressionNameScope(node) {
        return this.__nestScope(new FunctionExpressionNameScope(this, this.__currentScope, node));
      }
      __isES6() {
        return this.__options.ecmaVersion >= 6;
      }
    };
    module2.exports = ScopeManager;
  }
});

// node_modules/estraverse/estraverse.js
var require_estraverse2 = __commonJS({
  "node_modules/estraverse/estraverse.js"(exports) {
    (function clone(exports2) {
      "use strict";
      var Syntax, VisitorOption, VisitorKeys, BREAK, SKIP, REMOVE;
      function deepCopy(obj) {
        var ret = {}, key, val;
        for (key in obj) {
          if (obj.hasOwnProperty(key)) {
            val = obj[key];
            if (typeof val === "object" && val !== null) {
              ret[key] = deepCopy(val);
            } else {
              ret[key] = val;
            }
          }
        }
        return ret;
      }
      function upperBound(array, func) {
        var diff, len, i, current;
        len = array.length;
        i = 0;
        while (len) {
          diff = len >>> 1;
          current = i + diff;
          if (func(array[current])) {
            len = diff;
          } else {
            i = current + 1;
            len -= diff + 1;
          }
        }
        return i;
      }
      Syntax = {
        AssignmentExpression: "AssignmentExpression",
        AssignmentPattern: "AssignmentPattern",
        ArrayExpression: "ArrayExpression",
        ArrayPattern: "ArrayPattern",
        ArrowFunctionExpression: "ArrowFunctionExpression",
        AwaitExpression: "AwaitExpression",
        // CAUTION: It's deferred to ES7.
        BlockStatement: "BlockStatement",
        BinaryExpression: "BinaryExpression",
        BreakStatement: "BreakStatement",
        CallExpression: "CallExpression",
        CatchClause: "CatchClause",
        ChainExpression: "ChainExpression",
        ClassBody: "ClassBody",
        ClassDeclaration: "ClassDeclaration",
        ClassExpression: "ClassExpression",
        ComprehensionBlock: "ComprehensionBlock",
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: "ComprehensionExpression",
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: "ConditionalExpression",
        ContinueStatement: "ContinueStatement",
        DebuggerStatement: "DebuggerStatement",
        DirectiveStatement: "DirectiveStatement",
        DoWhileStatement: "DoWhileStatement",
        EmptyStatement: "EmptyStatement",
        ExportAllDeclaration: "ExportAllDeclaration",
        ExportDefaultDeclaration: "ExportDefaultDeclaration",
        ExportNamedDeclaration: "ExportNamedDeclaration",
        ExportSpecifier: "ExportSpecifier",
        ExpressionStatement: "ExpressionStatement",
        ForStatement: "ForStatement",
        ForInStatement: "ForInStatement",
        ForOfStatement: "ForOfStatement",
        FunctionDeclaration: "FunctionDeclaration",
        FunctionExpression: "FunctionExpression",
        GeneratorExpression: "GeneratorExpression",
        // CAUTION: It's deferred to ES7.
        Identifier: "Identifier",
        IfStatement: "IfStatement",
        ImportExpression: "ImportExpression",
        ImportDeclaration: "ImportDeclaration",
        ImportDefaultSpecifier: "ImportDefaultSpecifier",
        ImportNamespaceSpecifier: "ImportNamespaceSpecifier",
        ImportSpecifier: "ImportSpecifier",
        Literal: "Literal",
        LabeledStatement: "LabeledStatement",
        LogicalExpression: "LogicalExpression",
        MemberExpression: "MemberExpression",
        MetaProperty: "MetaProperty",
        MethodDefinition: "MethodDefinition",
        ModuleSpecifier: "ModuleSpecifier",
        NewExpression: "NewExpression",
        ObjectExpression: "ObjectExpression",
        ObjectPattern: "ObjectPattern",
        PrivateIdentifier: "PrivateIdentifier",
        Program: "Program",
        Property: "Property",
        PropertyDefinition: "PropertyDefinition",
        RestElement: "RestElement",
        ReturnStatement: "ReturnStatement",
        SequenceExpression: "SequenceExpression",
        SpreadElement: "SpreadElement",
        Super: "Super",
        SwitchStatement: "SwitchStatement",
        SwitchCase: "SwitchCase",
        TaggedTemplateExpression: "TaggedTemplateExpression",
        TemplateElement: "TemplateElement",
        TemplateLiteral: "TemplateLiteral",
        ThisExpression: "ThisExpression",
        ThrowStatement: "ThrowStatement",
        TryStatement: "TryStatement",
        UnaryExpression: "UnaryExpression",
        UpdateExpression: "UpdateExpression",
        VariableDeclaration: "VariableDeclaration",
        VariableDeclarator: "VariableDeclarator",
        WhileStatement: "WhileStatement",
        WithStatement: "WithStatement",
        YieldExpression: "YieldExpression"
      };
      VisitorKeys = {
        AssignmentExpression: ["left", "right"],
        AssignmentPattern: ["left", "right"],
        ArrayExpression: ["elements"],
        ArrayPattern: ["elements"],
        ArrowFunctionExpression: ["params", "body"],
        AwaitExpression: ["argument"],
        // CAUTION: It's deferred to ES7.
        BlockStatement: ["body"],
        BinaryExpression: ["left", "right"],
        BreakStatement: ["label"],
        CallExpression: ["callee", "arguments"],
        CatchClause: ["param", "body"],
        ChainExpression: ["expression"],
        ClassBody: ["body"],
        ClassDeclaration: ["id", "superClass", "body"],
        ClassExpression: ["id", "superClass", "body"],
        ComprehensionBlock: ["left", "right"],
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: ["test", "consequent", "alternate"],
        ContinueStatement: ["label"],
        DebuggerStatement: [],
        DirectiveStatement: [],
        DoWhileStatement: ["body", "test"],
        EmptyStatement: [],
        ExportAllDeclaration: ["source"],
        ExportDefaultDeclaration: ["declaration"],
        ExportNamedDeclaration: ["declaration", "specifiers", "source"],
        ExportSpecifier: ["exported", "local"],
        ExpressionStatement: ["expression"],
        ForStatement: ["init", "test", "update", "body"],
        ForInStatement: ["left", "right", "body"],
        ForOfStatement: ["left", "right", "body"],
        FunctionDeclaration: ["id", "params", "body"],
        FunctionExpression: ["id", "params", "body"],
        GeneratorExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        Identifier: [],
        IfStatement: ["test", "consequent", "alternate"],
        ImportExpression: ["source"],
        ImportDeclaration: ["specifiers", "source"],
        ImportDefaultSpecifier: ["local"],
        ImportNamespaceSpecifier: ["local"],
        ImportSpecifier: ["imported", "local"],
        Literal: [],
        LabeledStatement: ["label", "body"],
        LogicalExpression: ["left", "right"],
        MemberExpression: ["object", "property"],
        MetaProperty: ["meta", "property"],
        MethodDefinition: ["key", "value"],
        ModuleSpecifier: [],
        NewExpression: ["callee", "arguments"],
        ObjectExpression: ["properties"],
        ObjectPattern: ["properties"],
        PrivateIdentifier: [],
        Program: ["body"],
        Property: ["key", "value"],
        PropertyDefinition: ["key", "value"],
        RestElement: ["argument"],
        ReturnStatement: ["argument"],
        SequenceExpression: ["expressions"],
        SpreadElement: ["argument"],
        Super: [],
        SwitchStatement: ["discriminant", "cases"],
        SwitchCase: ["test", "consequent"],
        TaggedTemplateExpression: ["tag", "quasi"],
        TemplateElement: [],
        TemplateLiteral: ["quasis", "expressions"],
        ThisExpression: [],
        ThrowStatement: ["argument"],
        TryStatement: ["block", "handler", "finalizer"],
        UnaryExpression: ["argument"],
        UpdateExpression: ["argument"],
        VariableDeclaration: ["declarations"],
        VariableDeclarator: ["id", "init"],
        WhileStatement: ["test", "body"],
        WithStatement: ["object", "body"],
        YieldExpression: ["argument"]
      };
      BREAK = {};
      SKIP = {};
      REMOVE = {};
      VisitorOption = {
        Break: BREAK,
        Skip: SKIP,
        Remove: REMOVE
      };
      function Reference(parent, key) {
        this.parent = parent;
        this.key = key;
      }
      Reference.prototype.replace = function replace2(node) {
        this.parent[this.key] = node;
      };
      Reference.prototype.remove = function remove() {
        if (Array.isArray(this.parent)) {
          this.parent.splice(this.key, 1);
          return true;
        } else {
          this.replace(null);
          return false;
        }
      };
      function Element2(node, path2, wrap, ref) {
        this.node = node;
        this.path = path2;
        this.wrap = wrap;
        this.ref = ref;
      }
      function Controller() {
      }
      Controller.prototype.path = function path2() {
        var i, iz, j, jz, result, element;
        function addToPath(result2, path3) {
          if (Array.isArray(path3)) {
            for (j = 0, jz = path3.length; j < jz; ++j) {
              result2.push(path3[j]);
            }
          } else {
            result2.push(path3);
          }
        }
        if (!this.__current.path) {
          return null;
        }
        result = [];
        for (i = 2, iz = this.__leavelist.length; i < iz; ++i) {
          element = this.__leavelist[i];
          addToPath(result, element.path);
        }
        addToPath(result, this.__current.path);
        return result;
      };
      Controller.prototype.type = function() {
        var node = this.current();
        return node.type || this.__current.wrap;
      };
      Controller.prototype.parents = function parents() {
        var i, iz, result;
        result = [];
        for (i = 1, iz = this.__leavelist.length; i < iz; ++i) {
          result.push(this.__leavelist[i].node);
        }
        return result;
      };
      Controller.prototype.current = function current() {
        return this.__current.node;
      };
      Controller.prototype.__execute = function __execute(callback, element) {
        var previous, result;
        result = void 0;
        previous = this.__current;
        this.__current = element;
        this.__state = null;
        if (callback) {
          result = callback.call(this, element.node, this.__leavelist[this.__leavelist.length - 1].node);
        }
        this.__current = previous;
        return result;
      };
      Controller.prototype.notify = function notify(flag) {
        this.__state = flag;
      };
      Controller.prototype.skip = function() {
        this.notify(SKIP);
      };
      Controller.prototype["break"] = function() {
        this.notify(BREAK);
      };
      Controller.prototype.remove = function() {
        this.notify(REMOVE);
      };
      Controller.prototype.__initialize = function(root2, visitor) {
        this.visitor = visitor;
        this.root = root2;
        this.__worklist = [];
        this.__leavelist = [];
        this.__current = null;
        this.__state = null;
        this.__fallback = null;
        if (visitor.fallback === "iteration") {
          this.__fallback = Object.keys;
        } else if (typeof visitor.fallback === "function") {
          this.__fallback = visitor.fallback;
        }
        this.__keys = VisitorKeys;
        if (visitor.keys) {
          this.__keys = Object.assign(Object.create(this.__keys), visitor.keys);
        }
      };
      function isNode(node) {
        if (node == null) {
          return false;
        }
        return typeof node === "object" && typeof node.type === "string";
      }
      function isProperty(nodeType, key) {
        return (nodeType === Syntax.ObjectExpression || nodeType === Syntax.ObjectPattern) && "properties" === key;
      }
      function candidateExistsInLeaveList(leavelist, candidate) {
        for (var i = leavelist.length - 1; i >= 0; --i) {
          if (leavelist[i].node === candidate) {
            return true;
          }
        }
        return false;
      }
      Controller.prototype.traverse = function traverse4(root2, visitor) {
        var worklist, leavelist, element, node, nodeType, ret, key, current, current2, candidates, candidate, sentinel;
        this.__initialize(root2, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        worklist.push(new Element2(root2, null, null, null));
        leavelist.push(new Element2(null, null, null, null));
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            ret = this.__execute(visitor.leave, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            continue;
          }
          if (element.node) {
            ret = this.__execute(visitor.enter, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            worklist.push(sentinel);
            leavelist.push(element);
            if (this.__state === SKIP || ret === SKIP) {
              continue;
            }
            node = element.node;
            nodeType = node.type || element.wrap;
            candidates = this.__keys[nodeType];
            if (!candidates) {
              if (this.__fallback) {
                candidates = this.__fallback(node);
              } else {
                throw new Error("Unknown node type " + nodeType + ".");
              }
            }
            current = candidates.length;
            while ((current -= 1) >= 0) {
              key = candidates[current];
              candidate = node[key];
              if (!candidate) {
                continue;
              }
              if (Array.isArray(candidate)) {
                current2 = candidate.length;
                while ((current2 -= 1) >= 0) {
                  if (!candidate[current2]) {
                    continue;
                  }
                  if (candidateExistsInLeaveList(leavelist, candidate[current2])) {
                    continue;
                  }
                  if (isProperty(nodeType, candidates[current])) {
                    element = new Element2(candidate[current2], [key, current2], "Property", null);
                  } else if (isNode(candidate[current2])) {
                    element = new Element2(candidate[current2], [key, current2], null, null);
                  } else {
                    continue;
                  }
                  worklist.push(element);
                }
              } else if (isNode(candidate)) {
                if (candidateExistsInLeaveList(leavelist, candidate)) {
                  continue;
                }
                worklist.push(new Element2(candidate, key, null, null));
              }
            }
          }
        }
      };
      Controller.prototype.replace = function replace2(root2, visitor) {
        var worklist, leavelist, node, nodeType, target, element, current, current2, candidates, candidate, sentinel, outer, key;
        function removeElem(element2) {
          var i, key2, nextElem, parent;
          if (element2.ref.remove()) {
            key2 = element2.ref.key;
            parent = element2.ref.parent;
            i = worklist.length;
            while (i--) {
              nextElem = worklist[i];
              if (nextElem.ref && nextElem.ref.parent === parent) {
                if (nextElem.ref.key < key2) {
                  break;
                }
                --nextElem.ref.key;
              }
            }
          }
        }
        this.__initialize(root2, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        outer = {
          root: root2
        };
        element = new Element2(root2, null, null, new Reference(outer, "root"));
        worklist.push(element);
        leavelist.push(element);
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            target = this.__execute(visitor.leave, element);
            if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
              element.ref.replace(target);
            }
            if (this.__state === REMOVE || target === REMOVE) {
              removeElem(element);
            }
            if (this.__state === BREAK || target === BREAK) {
              return outer.root;
            }
            continue;
          }
          target = this.__execute(visitor.enter, element);
          if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
            element.ref.replace(target);
            element.node = target;
          }
          if (this.__state === REMOVE || target === REMOVE) {
            removeElem(element);
            element.node = null;
          }
          if (this.__state === BREAK || target === BREAK) {
            return outer.root;
          }
          node = element.node;
          if (!node) {
            continue;
          }
          worklist.push(sentinel);
          leavelist.push(element);
          if (this.__state === SKIP || target === SKIP) {
            continue;
          }
          nodeType = node.type || element.wrap;
          candidates = this.__keys[nodeType];
          if (!candidates) {
            if (this.__fallback) {
              candidates = this.__fallback(node);
            } else {
              throw new Error("Unknown node type " + nodeType + ".");
            }
          }
          current = candidates.length;
          while ((current -= 1) >= 0) {
            key = candidates[current];
            candidate = node[key];
            if (!candidate) {
              continue;
            }
            if (Array.isArray(candidate)) {
              current2 = candidate.length;
              while ((current2 -= 1) >= 0) {
                if (!candidate[current2]) {
                  continue;
                }
                if (isProperty(nodeType, candidates[current])) {
                  element = new Element2(candidate[current2], [key, current2], "Property", new Reference(candidate, current2));
                } else if (isNode(candidate[current2])) {
                  element = new Element2(candidate[current2], [key, current2], null, new Reference(candidate, current2));
                } else {
                  continue;
                }
                worklist.push(element);
              }
            } else if (isNode(candidate)) {
              worklist.push(new Element2(candidate, key, null, new Reference(node, key)));
            }
          }
        }
        return outer.root;
      };
      function traverse3(root2, visitor) {
        var controller = new Controller();
        return controller.traverse(root2, visitor);
      }
      function replace(root2, visitor) {
        var controller = new Controller();
        return controller.replace(root2, visitor);
      }
      function extendCommentRange(comment, tokens) {
        var target;
        target = upperBound(tokens, function search(token) {
          return token.range[0] > comment.range[0];
        });
        comment.extendedRange = [comment.range[0], comment.range[1]];
        if (target !== tokens.length) {
          comment.extendedRange[1] = tokens[target].range[0];
        }
        target -= 1;
        if (target >= 0) {
          comment.extendedRange[0] = tokens[target].range[1];
        }
        return comment;
      }
      function attachComments(tree, providedComments, tokens) {
        var comments = [], comment, len, i, cursor;
        if (!tree.range) {
          throw new Error("attachComments needs range information");
        }
        if (!tokens.length) {
          if (providedComments.length) {
            for (i = 0, len = providedComments.length; i < len; i += 1) {
              comment = deepCopy(providedComments[i]);
              comment.extendedRange = [0, tree.range[0]];
              comments.push(comment);
            }
            tree.leadingComments = comments;
          }
          return tree;
        }
        for (i = 0, len = providedComments.length; i < len; i += 1) {
          comments.push(extendCommentRange(deepCopy(providedComments[i]), tokens));
        }
        cursor = 0;
        traverse3(tree, {
          enter: function(node) {
            var comment2;
            while (cursor < comments.length) {
              comment2 = comments[cursor];
              if (comment2.extendedRange[1] > node.range[0]) {
                break;
              }
              if (comment2.extendedRange[1] === node.range[0]) {
                if (!node.leadingComments) {
                  node.leadingComments = [];
                }
                node.leadingComments.push(comment2);
                comments.splice(cursor, 1);
              } else {
                cursor += 1;
              }
            }
            if (cursor === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }
        });
        cursor = 0;
        traverse3(tree, {
          leave: function(node) {
            var comment2;
            while (cursor < comments.length) {
              comment2 = comments[cursor];
              if (node.range[1] < comment2.extendedRange[0]) {
                break;
              }
              if (node.range[1] === comment2.extendedRange[0]) {
                if (!node.trailingComments) {
                  node.trailingComments = [];
                }
                node.trailingComments.push(comment2);
                comments.splice(cursor, 1);
              } else {
                cursor += 1;
              }
            }
            if (cursor === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }
        });
        return tree;
      }
      exports2.Syntax = Syntax;
      exports2.traverse = traverse3;
      exports2.replace = replace;
      exports2.attachComments = attachComments;
      exports2.VisitorKeys = VisitorKeys;
      exports2.VisitorOption = VisitorOption;
      exports2.Controller = Controller;
      exports2.cloneEnvironment = function() {
        return clone({});
      };
      return exports2;
    })(exports);
  }
});

// node_modules/esrecurse/package.json
var require_package2 = __commonJS({
  "node_modules/esrecurse/package.json"(exports, module2) {
    module2.exports = {
      name: "esrecurse",
      description: "ECMAScript AST recursive visitor",
      homepage: "https://github.com/estools/esrecurse",
      main: "esrecurse.js",
      version: "4.3.0",
      engines: {
        node: ">=4.0"
      },
      maintainers: [
        {
          name: "Yusuke Suzuki",
          email: "utatane.tea@gmail.com",
          web: "https://github.com/Constellation"
        }
      ],
      repository: {
        type: "git",
        url: "https://github.com/estools/esrecurse.git"
      },
      dependencies: {
        estraverse: "^5.2.0"
      },
      devDependencies: {
        "babel-cli": "^6.24.1",
        "babel-eslint": "^7.2.3",
        "babel-preset-es2015": "^6.24.1",
        "babel-register": "^6.24.1",
        chai: "^4.0.2",
        esprima: "^4.0.0",
        gulp: "^3.9.0",
        "gulp-bump": "^2.7.0",
        "gulp-eslint": "^4.0.0",
        "gulp-filter": "^5.0.0",
        "gulp-git": "^2.4.1",
        "gulp-mocha": "^4.3.1",
        "gulp-tag-version": "^1.2.1",
        jsdoc: "^3.3.0-alpha10",
        minimist: "^1.1.0"
      },
      license: "BSD-2-Clause",
      scripts: {
        test: "gulp travis",
        "unit-test": "gulp test",
        lint: "gulp lint"
      },
      babel: {
        presets: [
          "es2015"
        ]
      }
    };
  }
});

// node_modules/esrecurse/esrecurse.js
var require_esrecurse = __commonJS({
  "node_modules/esrecurse/esrecurse.js"(exports) {
    (function() {
      "use strict";
      var estraverse = require_estraverse2();
      function isNode(node) {
        if (node == null) {
          return false;
        }
        return typeof node === "object" && typeof node.type === "string";
      }
      function isProperty(nodeType, key) {
        return (nodeType === estraverse.Syntax.ObjectExpression || nodeType === estraverse.Syntax.ObjectPattern) && key === "properties";
      }
      function Visitor(visitor, options) {
        options = options || {};
        this.__visitor = visitor || this;
        this.__childVisitorKeys = options.childVisitorKeys ? Object.assign({}, estraverse.VisitorKeys, options.childVisitorKeys) : estraverse.VisitorKeys;
        if (options.fallback === "iteration") {
          this.__fallback = Object.keys;
        } else if (typeof options.fallback === "function") {
          this.__fallback = options.fallback;
        }
      }
      Visitor.prototype.visitChildren = function(node) {
        var type, children, i, iz, j, jz, child;
        if (node == null) {
          return;
        }
        type = node.type || estraverse.Syntax.Property;
        children = this.__childVisitorKeys[type];
        if (!children) {
          if (this.__fallback) {
            children = this.__fallback(node);
          } else {
            throw new Error("Unknown node type " + type + ".");
          }
        }
        for (i = 0, iz = children.length; i < iz; ++i) {
          child = node[children[i]];
          if (child) {
            if (Array.isArray(child)) {
              for (j = 0, jz = child.length; j < jz; ++j) {
                if (child[j]) {
                  if (isNode(child[j]) || isProperty(type, children[i])) {
                    this.visit(child[j]);
                  }
                }
              }
            } else if (isNode(child)) {
              this.visit(child);
            }
          }
        }
      };
      Visitor.prototype.visit = function(node) {
        var type;
        if (node == null) {
          return;
        }
        type = node.type || estraverse.Syntax.Property;
        if (this.__visitor[type]) {
          this.__visitor[type].call(this, node);
          return;
        }
        this.visitChildren(node);
      };
      exports.version = require_package2().version;
      exports.Visitor = Visitor;
      exports.visit = function(node, visitor, options) {
        var v = new Visitor(visitor, options);
        v.visit(node);
      };
    })();
  }
});

// node_modules/eslint-scope/lib/pattern-visitor.js
var require_pattern_visitor = __commonJS({
  "node_modules/eslint-scope/lib/pattern-visitor.js"(exports, module2) {
    "use strict";
    var Syntax = require_estraverse().Syntax;
    var esrecurse = require_esrecurse();
    function getLast(xs) {
      return xs[xs.length - 1] || null;
    }
    var PatternVisitor = class extends esrecurse.Visitor {
      static isPattern(node) {
        const nodeType = node.type;
        return nodeType === Syntax.Identifier || nodeType === Syntax.ObjectPattern || nodeType === Syntax.ArrayPattern || nodeType === Syntax.SpreadElement || nodeType === Syntax.RestElement || nodeType === Syntax.AssignmentPattern;
      }
      constructor(options, rootPattern, callback) {
        super(null, options);
        this.rootPattern = rootPattern;
        this.callback = callback;
        this.assignments = [];
        this.rightHandNodes = [];
        this.restElements = [];
      }
      Identifier(pattern) {
        const lastRestElement = getLast(this.restElements);
        this.callback(pattern, {
          topLevel: pattern === this.rootPattern,
          rest: lastRestElement !== null && lastRestElement !== void 0 && lastRestElement.argument === pattern,
          assignments: this.assignments
        });
      }
      Property(property) {
        if (property.computed) {
          this.rightHandNodes.push(property.key);
        }
        this.visit(property.value);
      }
      ArrayPattern(pattern) {
        for (let i = 0, iz = pattern.elements.length; i < iz; ++i) {
          const element = pattern.elements[i];
          this.visit(element);
        }
      }
      AssignmentPattern(pattern) {
        this.assignments.push(pattern);
        this.visit(pattern.left);
        this.rightHandNodes.push(pattern.right);
        this.assignments.pop();
      }
      RestElement(pattern) {
        this.restElements.push(pattern);
        this.visit(pattern.argument);
        this.restElements.pop();
      }
      MemberExpression(node) {
        if (node.computed) {
          this.rightHandNodes.push(node.property);
        }
        this.rightHandNodes.push(node.object);
      }
      //
      // ForInStatement.left and AssignmentExpression.left are LeftHandSideExpression.
      // By spec, LeftHandSideExpression is Pattern or MemberExpression.
      //   (see also: https://github.com/estree/estree/pull/20#issuecomment-74584758)
      // But espree 2.0 parses to ArrayExpression, ObjectExpression, etc...
      //
      SpreadElement(node) {
        this.visit(node.argument);
      }
      ArrayExpression(node) {
        node.elements.forEach(this.visit, this);
      }
      AssignmentExpression(node) {
        this.assignments.push(node);
        this.visit(node.left);
        this.rightHandNodes.push(node.right);
        this.assignments.pop();
      }
      CallExpression(node) {
        node.arguments.forEach((a) => {
          this.rightHandNodes.push(a);
        });
        this.visit(node.callee);
      }
    };
    module2.exports = PatternVisitor;
  }
});

// node_modules/eslint-scope/lib/referencer.js
var require_referencer = __commonJS({
  "node_modules/eslint-scope/lib/referencer.js"(exports, module2) {
    "use strict";
    var Syntax = require_estraverse().Syntax;
    var esrecurse = require_esrecurse();
    var Reference = require_reference();
    var Variable = require_variable();
    var PatternVisitor = require_pattern_visitor();
    var definition = require_definition();
    var assert = require("assert");
    var ParameterDefinition = definition.ParameterDefinition;
    var Definition = definition.Definition;
    function traverseIdentifierInPattern(options, rootPattern, referencer, callback) {
      const visitor = new PatternVisitor(options, rootPattern, callback);
      visitor.visit(rootPattern);
      if (referencer !== null && referencer !== void 0) {
        visitor.rightHandNodes.forEach(referencer.visit, referencer);
      }
    }
    var Importer = class extends esrecurse.Visitor {
      constructor(declaration, referencer) {
        super(null, referencer.options);
        this.declaration = declaration;
        this.referencer = referencer;
      }
      visitImport(id, specifier) {
        this.referencer.visitPattern(id, (pattern) => {
          this.referencer.currentScope().__define(
            pattern,
            new Definition(
              Variable.ImportBinding,
              pattern,
              specifier,
              this.declaration,
              null,
              null
            )
          );
        });
      }
      ImportNamespaceSpecifier(node) {
        const local = node.local || node.id;
        if (local) {
          this.visitImport(local, node);
        }
      }
      ImportDefaultSpecifier(node) {
        const local = node.local || node.id;
        this.visitImport(local, node);
      }
      ImportSpecifier(node) {
        const local = node.local || node.id;
        if (node.name) {
          this.visitImport(node.name, node);
        } else {
          this.visitImport(local, node);
        }
      }
    };
    var Referencer = class extends esrecurse.Visitor {
      constructor(options, scopeManager) {
        super(null, options);
        this.options = options;
        this.scopeManager = scopeManager;
        this.parent = null;
        this.isInnerMethodDefinition = false;
      }
      currentScope() {
        return this.scopeManager.__currentScope;
      }
      close(node) {
        while (this.currentScope() && node === this.currentScope().block) {
          this.scopeManager.__currentScope = this.currentScope().__close(this.scopeManager);
        }
      }
      pushInnerMethodDefinition(isInnerMethodDefinition) {
        const previous = this.isInnerMethodDefinition;
        this.isInnerMethodDefinition = isInnerMethodDefinition;
        return previous;
      }
      popInnerMethodDefinition(isInnerMethodDefinition) {
        this.isInnerMethodDefinition = isInnerMethodDefinition;
      }
      referencingDefaultValue(pattern, assignments, maybeImplicitGlobal, init) {
        const scope = this.currentScope();
        assignments.forEach((assignment) => {
          scope.__referencing(
            pattern,
            Reference.WRITE,
            assignment.right,
            maybeImplicitGlobal,
            pattern !== assignment.left,
            init
          );
        });
      }
      visitPattern(node, options, callback) {
        let visitPatternOptions = options;
        let visitPatternCallback = callback;
        if (typeof options === "function") {
          visitPatternCallback = options;
          visitPatternOptions = { processRightHandNodes: false };
        }
        traverseIdentifierInPattern(
          this.options,
          node,
          visitPatternOptions.processRightHandNodes ? this : null,
          visitPatternCallback
        );
      }
      visitFunction(node) {
        let i, iz;
        if (node.type === Syntax.FunctionDeclaration) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.FunctionName,
              node.id,
              node,
              null,
              null,
              null
            )
          );
        }
        if (node.type === Syntax.FunctionExpression && node.id) {
          this.scopeManager.__nestFunctionExpressionNameScope(node);
        }
        this.scopeManager.__nestFunctionScope(node, this.isInnerMethodDefinition);
        const that = this;
        function visitPatternCallback(pattern, info) {
          that.currentScope().__define(
            pattern,
            new ParameterDefinition(
              pattern,
              node,
              i,
              info.rest
            )
          );
          that.referencingDefaultValue(pattern, info.assignments, null, true);
        }
        for (i = 0, iz = node.params.length; i < iz; ++i) {
          this.visitPattern(node.params[i], { processRightHandNodes: true }, visitPatternCallback);
        }
        if (node.rest) {
          this.visitPattern({
            type: "RestElement",
            argument: node.rest
          }, (pattern) => {
            this.currentScope().__define(
              pattern,
              new ParameterDefinition(
                pattern,
                node,
                node.params.length,
                true
              )
            );
          });
        }
        if (node.body) {
          if (node.body.type === Syntax.BlockStatement) {
            this.visitChildren(node.body);
          } else {
            this.visit(node.body);
          }
        }
        this.close(node);
      }
      visitClass(node) {
        if (node.type === Syntax.ClassDeclaration) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.ClassName,
              node.id,
              node,
              null,
              null,
              null
            )
          );
        }
        this.visit(node.superClass);
        this.scopeManager.__nestClassScope(node);
        if (node.id) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.ClassName,
              node.id,
              node
            )
          );
        }
        this.visit(node.body);
        this.close(node);
      }
      visitProperty(node) {
        let previous;
        if (node.computed) {
          this.visit(node.key);
        }
        const isMethodDefinition = node.type === Syntax.MethodDefinition;
        if (isMethodDefinition) {
          previous = this.pushInnerMethodDefinition(true);
        }
        this.visit(node.value);
        if (isMethodDefinition) {
          this.popInnerMethodDefinition(previous);
        }
      }
      visitForIn(node) {
        if (node.left.type === Syntax.VariableDeclaration && node.left.kind !== "var") {
          this.scopeManager.__nestForScope(node);
        }
        if (node.left.type === Syntax.VariableDeclaration) {
          this.visit(node.left);
          this.visitPattern(node.left.declarations[0].id, (pattern) => {
            this.currentScope().__referencing(pattern, Reference.WRITE, node.right, null, true, true);
          });
        } else {
          this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
            let maybeImplicitGlobal = null;
            if (!this.currentScope().isStrict) {
              maybeImplicitGlobal = {
                pattern,
                node
              };
            }
            this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
            this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, true, false);
          });
        }
        this.visit(node.right);
        this.visit(node.body);
        this.close(node);
      }
      visitVariableDeclaration(variableTargetScope, type, node, index) {
        const decl = node.declarations[index];
        const init = decl.init;
        this.visitPattern(decl.id, { processRightHandNodes: true }, (pattern, info) => {
          variableTargetScope.__define(
            pattern,
            new Definition(
              type,
              pattern,
              decl,
              node,
              index,
              node.kind
            )
          );
          this.referencingDefaultValue(pattern, info.assignments, null, true);
          if (init) {
            this.currentScope().__referencing(pattern, Reference.WRITE, init, null, !info.topLevel, true);
          }
        });
      }
      AssignmentExpression(node) {
        if (PatternVisitor.isPattern(node.left)) {
          if (node.operator === "=") {
            this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
              let maybeImplicitGlobal = null;
              if (!this.currentScope().isStrict) {
                maybeImplicitGlobal = {
                  pattern,
                  node
                };
              }
              this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
              this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, !info.topLevel, false);
            });
          } else {
            this.currentScope().__referencing(node.left, Reference.RW, node.right);
          }
        } else {
          this.visit(node.left);
        }
        this.visit(node.right);
      }
      CatchClause(node) {
        this.scopeManager.__nestCatchScope(node);
        this.visitPattern(node.param, { processRightHandNodes: true }, (pattern, info) => {
          this.currentScope().__define(
            pattern,
            new Definition(
              Variable.CatchClause,
              node.param,
              node,
              null,
              null,
              null
            )
          );
          this.referencingDefaultValue(pattern, info.assignments, null, true);
        });
        this.visit(node.body);
        this.close(node);
      }
      Program(node) {
        this.scopeManager.__nestGlobalScope(node);
        if (this.scopeManager.__isNodejsScope()) {
          this.currentScope().isStrict = false;
          this.scopeManager.__nestFunctionScope(node, false);
        }
        if (this.scopeManager.__isES6() && this.scopeManager.isModule()) {
          this.scopeManager.__nestModuleScope(node);
        }
        if (this.scopeManager.isStrictModeSupported() && this.scopeManager.isImpliedStrict()) {
          this.currentScope().isStrict = true;
        }
        this.visitChildren(node);
        this.close(node);
      }
      Identifier(node) {
        this.currentScope().__referencing(node);
      }
      UpdateExpression(node) {
        if (PatternVisitor.isPattern(node.argument)) {
          this.currentScope().__referencing(node.argument, Reference.RW, null);
        } else {
          this.visitChildren(node);
        }
      }
      MemberExpression(node) {
        this.visit(node.object);
        if (node.computed) {
          this.visit(node.property);
        }
      }
      Property(node) {
        this.visitProperty(node);
      }
      MethodDefinition(node) {
        this.visitProperty(node);
      }
      BreakStatement() {
      }
      // eslint-disable-line class-methods-use-this
      ContinueStatement() {
      }
      // eslint-disable-line class-methods-use-this
      LabeledStatement(node) {
        this.visit(node.body);
      }
      ForStatement(node) {
        if (node.init && node.init.type === Syntax.VariableDeclaration && node.init.kind !== "var") {
          this.scopeManager.__nestForScope(node);
        }
        this.visitChildren(node);
        this.close(node);
      }
      ClassExpression(node) {
        this.visitClass(node);
      }
      ClassDeclaration(node) {
        this.visitClass(node);
      }
      CallExpression(node) {
        if (!this.scopeManager.__ignoreEval() && node.callee.type === Syntax.Identifier && node.callee.name === "eval") {
          this.currentScope().variableScope.__detectEval();
        }
        this.visitChildren(node);
      }
      BlockStatement(node) {
        if (this.scopeManager.__isES6()) {
          this.scopeManager.__nestBlockScope(node);
        }
        this.visitChildren(node);
        this.close(node);
      }
      ThisExpression() {
        this.currentScope().variableScope.__detectThis();
      }
      WithStatement(node) {
        this.visit(node.object);
        this.scopeManager.__nestWithScope(node);
        this.visit(node.body);
        this.close(node);
      }
      VariableDeclaration(node) {
        const variableTargetScope = node.kind === "var" ? this.currentScope().variableScope : this.currentScope();
        for (let i = 0, iz = node.declarations.length; i < iz; ++i) {
          const decl = node.declarations[i];
          this.visitVariableDeclaration(variableTargetScope, Variable.Variable, node, i);
          if (decl.init) {
            this.visit(decl.init);
          }
        }
      }
      // sec 13.11.8
      SwitchStatement(node) {
        this.visit(node.discriminant);
        if (this.scopeManager.__isES6()) {
          this.scopeManager.__nestSwitchScope(node);
        }
        for (let i = 0, iz = node.cases.length; i < iz; ++i) {
          this.visit(node.cases[i]);
        }
        this.close(node);
      }
      FunctionDeclaration(node) {
        this.visitFunction(node);
      }
      FunctionExpression(node) {
        this.visitFunction(node);
      }
      ForOfStatement(node) {
        this.visitForIn(node);
      }
      ForInStatement(node) {
        this.visitForIn(node);
      }
      ArrowFunctionExpression(node) {
        this.visitFunction(node);
      }
      ImportDeclaration(node) {
        assert(this.scopeManager.__isES6() && this.scopeManager.isModule(), "ImportDeclaration should appear when the mode is ES6 and in the module context.");
        const importer = new Importer(node, this);
        importer.visit(node);
      }
      visitExportDeclaration(node) {
        if (node.source) {
          return;
        }
        if (node.declaration) {
          this.visit(node.declaration);
          return;
        }
        this.visitChildren(node);
      }
      // TODO: ExportDeclaration doesn't exist. for bc?
      ExportDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportAllDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportDefaultDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportNamedDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportSpecifier(node) {
        const local = node.id || node.local;
        this.visit(local);
      }
      MetaProperty() {
      }
    };
    module2.exports = Referencer;
  }
});

// node_modules/eslint-scope/package.json
var require_package3 = __commonJS({
  "node_modules/eslint-scope/package.json"(exports, module2) {
    module2.exports = {
      name: "eslint-scope",
      description: "ECMAScript scope analyzer for ESLint",
      homepage: "http://github.com/eslint/eslint-scope",
      main: "lib/index.js",
      version: "5.1.1",
      engines: {
        node: ">=8.0.0"
      },
      repository: "eslint/eslint-scope",
      bugs: {
        url: "https://github.com/eslint/eslint-scope/issues"
      },
      license: "BSD-2-Clause",
      scripts: {
        test: "node Makefile.js test",
        lint: "node Makefile.js lint",
        "generate-release": "eslint-generate-release",
        "generate-alpharelease": "eslint-generate-prerelease alpha",
        "generate-betarelease": "eslint-generate-prerelease beta",
        "generate-rcrelease": "eslint-generate-prerelease rc",
        "publish-release": "eslint-publish-release"
      },
      files: [
        "LICENSE",
        "README.md",
        "lib"
      ],
      dependencies: {
        esrecurse: "^4.3.0",
        estraverse: "^4.1.1"
      },
      devDependencies: {
        "@typescript-eslint/parser": "^1.11.0",
        chai: "^4.2.0",
        eslint: "^6.0.1",
        "eslint-config-eslint": "^5.0.1",
        "eslint-plugin-node": "^9.1.0",
        "eslint-release": "^1.0.0",
        "eslint-visitor-keys": "^1.2.0",
        espree: "^7.1.0",
        istanbul: "^0.4.5",
        mocha: "^6.1.4",
        "npm-license": "^0.3.3",
        shelljs: "^0.8.3",
        typescript: "^3.5.2"
      }
    };
  }
});

// node_modules/eslint-scope/lib/index.js
var require_lib4 = __commonJS({
  "node_modules/eslint-scope/lib/index.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var ScopeManager = require_scope_manager();
    var Referencer = require_referencer();
    var Reference = require_reference();
    var Variable = require_variable();
    var Scope = require_scope().Scope;
    var version2 = require_package3().version;
    function defaultOptions2() {
      return {
        optimistic: false,
        directive: false,
        nodejsScope: false,
        impliedStrict: false,
        sourceType: "script",
        // one of ['script', 'module']
        ecmaVersion: 5,
        childVisitorKeys: null,
        fallback: "iteration"
      };
    }
    function updateDeeply(target, override) {
      function isHashObject(value2) {
        return typeof value2 === "object" && value2 instanceof Object && !(value2 instanceof Array) && !(value2 instanceof RegExp);
      }
      for (const key in override) {
        if (Object.prototype.hasOwnProperty.call(override, key)) {
          const val = override[key];
          if (isHashObject(val)) {
            if (isHashObject(target[key])) {
              updateDeeply(target[key], val);
            } else {
              target[key] = updateDeeply({}, val);
            }
          } else {
            target[key] = val;
          }
        }
      }
      return target;
    }
    function analyze(tree, providedOptions) {
      const options = updateDeeply(defaultOptions2(), providedOptions);
      const scopeManager = new ScopeManager(options);
      const referencer = new Referencer(options, scopeManager);
      referencer.visit(tree);
      assert(scopeManager.__currentScope === null, "currentScope should be null.");
      return scopeManager;
    }
    module2.exports = {
      /** @name module:escope.version */
      version: version2,
      /** @name module:escope.Reference */
      Reference,
      /** @name module:escope.Variable */
      Variable,
      /** @name module:escope.Scope */
      Scope,
      /** @name module:escope.ScopeManager */
      ScopeManager,
      analyze
    };
  }
});

// node_modules/semver/semver.js
var require_semver = __commonJS({
  "node_modules/semver/semver.js"(exports, module2) {
    exports = module2.exports = SemVer;
    var debug;
    if (typeof process === "object" && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG)) {
      debug = function() {
        var args = Array.prototype.slice.call(arguments, 0);
        args.unshift("SEMVER");
        console.log.apply(console, args);
      };
    } else {
      debug = function() {
      };
    }
    exports.SEMVER_SPEC_VERSION = "2.0.0";
    var MAX_LENGTH = 256;
    var MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER || /* istanbul ignore next */
    9007199254740991;
    var MAX_SAFE_COMPONENT_LENGTH = 16;
    var re = exports.re = [];
    var src = exports.src = [];
    var t3 = exports.tokens = {};
    var R = 0;
    function tok(n) {
      t3[n] = R++;
    }
    tok("NUMERICIDENTIFIER");
    src[t3.NUMERICIDENTIFIER] = "0|[1-9]\\d*";
    tok("NUMERICIDENTIFIERLOOSE");
    src[t3.NUMERICIDENTIFIERLOOSE] = "[0-9]+";
    tok("NONNUMERICIDENTIFIER");
    src[t3.NONNUMERICIDENTIFIER] = "\\d*[a-zA-Z-][a-zA-Z0-9-]*";
    tok("MAINVERSION");
    src[t3.MAINVERSION] = "(" + src[t3.NUMERICIDENTIFIER] + ")\\.(" + src[t3.NUMERICIDENTIFIER] + ")\\.(" + src[t3.NUMERICIDENTIFIER] + ")";
    tok("MAINVERSIONLOOSE");
    src[t3.MAINVERSIONLOOSE] = "(" + src[t3.NUMERICIDENTIFIERLOOSE] + ")\\.(" + src[t3.NUMERICIDENTIFIERLOOSE] + ")\\.(" + src[t3.NUMERICIDENTIFIERLOOSE] + ")";
    tok("PRERELEASEIDENTIFIER");
    src[t3.PRERELEASEIDENTIFIER] = "(?:" + src[t3.NUMERICIDENTIFIER] + "|" + src[t3.NONNUMERICIDENTIFIER] + ")";
    tok("PRERELEASEIDENTIFIERLOOSE");
    src[t3.PRERELEASEIDENTIFIERLOOSE] = "(?:" + src[t3.NUMERICIDENTIFIERLOOSE] + "|" + src[t3.NONNUMERICIDENTIFIER] + ")";
    tok("PRERELEASE");
    src[t3.PRERELEASE] = "(?:-(" + src[t3.PRERELEASEIDENTIFIER] + "(?:\\." + src[t3.PRERELEASEIDENTIFIER] + ")*))";
    tok("PRERELEASELOOSE");
    src[t3.PRERELEASELOOSE] = "(?:-?(" + src[t3.PRERELEASEIDENTIFIERLOOSE] + "(?:\\." + src[t3.PRERELEASEIDENTIFIERLOOSE] + ")*))";
    tok("BUILDIDENTIFIER");
    src[t3.BUILDIDENTIFIER] = "[0-9A-Za-z-]+";
    tok("BUILD");
    src[t3.BUILD] = "(?:\\+(" + src[t3.BUILDIDENTIFIER] + "(?:\\." + src[t3.BUILDIDENTIFIER] + ")*))";
    tok("FULL");
    tok("FULLPLAIN");
    src[t3.FULLPLAIN] = "v?" + src[t3.MAINVERSION] + src[t3.PRERELEASE] + "?" + src[t3.BUILD] + "?";
    src[t3.FULL] = "^" + src[t3.FULLPLAIN] + "$";
    tok("LOOSEPLAIN");
    src[t3.LOOSEPLAIN] = "[v=\\s]*" + src[t3.MAINVERSIONLOOSE] + src[t3.PRERELEASELOOSE] + "?" + src[t3.BUILD] + "?";
    tok("LOOSE");
    src[t3.LOOSE] = "^" + src[t3.LOOSEPLAIN] + "$";
    tok("GTLT");
    src[t3.GTLT] = "((?:<|>)?=?)";
    tok("XRANGEIDENTIFIERLOOSE");
    src[t3.XRANGEIDENTIFIERLOOSE] = src[t3.NUMERICIDENTIFIERLOOSE] + "|x|X|\\*";
    tok("XRANGEIDENTIFIER");
    src[t3.XRANGEIDENTIFIER] = src[t3.NUMERICIDENTIFIER] + "|x|X|\\*";
    tok("XRANGEPLAIN");
    src[t3.XRANGEPLAIN] = "[v=\\s]*(" + src[t3.XRANGEIDENTIFIER] + ")(?:\\.(" + src[t3.XRANGEIDENTIFIER] + ")(?:\\.(" + src[t3.XRANGEIDENTIFIER] + ")(?:" + src[t3.PRERELEASE] + ")?" + src[t3.BUILD] + "?)?)?";
    tok("XRANGEPLAINLOOSE");
    src[t3.XRANGEPLAINLOOSE] = "[v=\\s]*(" + src[t3.XRANGEIDENTIFIERLOOSE] + ")(?:\\.(" + src[t3.XRANGEIDENTIFIERLOOSE] + ")(?:\\.(" + src[t3.XRANGEIDENTIFIERLOOSE] + ")(?:" + src[t3.PRERELEASELOOSE] + ")?" + src[t3.BUILD] + "?)?)?";
    tok("XRANGE");
    src[t3.XRANGE] = "^" + src[t3.GTLT] + "\\s*" + src[t3.XRANGEPLAIN] + "$";
    tok("XRANGELOOSE");
    src[t3.XRANGELOOSE] = "^" + src[t3.GTLT] + "\\s*" + src[t3.XRANGEPLAINLOOSE] + "$";
    tok("COERCE");
    src[t3.COERCE] = "(^|[^\\d])(\\d{1," + MAX_SAFE_COMPONENT_LENGTH + "})(?:\\.(\\d{1," + MAX_SAFE_COMPONENT_LENGTH + "}))?(?:\\.(\\d{1," + MAX_SAFE_COMPONENT_LENGTH + "}))?(?:$|[^\\d])";
    tok("COERCERTL");
    re[t3.COERCERTL] = new RegExp(src[t3.COERCE], "g");
    tok("LONETILDE");
    src[t3.LONETILDE] = "(?:~>?)";
    tok("TILDETRIM");
    src[t3.TILDETRIM] = "(\\s*)" + src[t3.LONETILDE] + "\\s+";
    re[t3.TILDETRIM] = new RegExp(src[t3.TILDETRIM], "g");
    var tildeTrimReplace = "$1~";
    tok("TILDE");
    src[t3.TILDE] = "^" + src[t3.LONETILDE] + src[t3.XRANGEPLAIN] + "$";
    tok("TILDELOOSE");
    src[t3.TILDELOOSE] = "^" + src[t3.LONETILDE] + src[t3.XRANGEPLAINLOOSE] + "$";
    tok("LONECARET");
    src[t3.LONECARET] = "(?:\\^)";
    tok("CARETTRIM");
    src[t3.CARETTRIM] = "(\\s*)" + src[t3.LONECARET] + "\\s+";
    re[t3.CARETTRIM] = new RegExp(src[t3.CARETTRIM], "g");
    var caretTrimReplace = "$1^";
    tok("CARET");
    src[t3.CARET] = "^" + src[t3.LONECARET] + src[t3.XRANGEPLAIN] + "$";
    tok("CARETLOOSE");
    src[t3.CARETLOOSE] = "^" + src[t3.LONECARET] + src[t3.XRANGEPLAINLOOSE] + "$";
    tok("COMPARATORLOOSE");
    src[t3.COMPARATORLOOSE] = "^" + src[t3.GTLT] + "\\s*(" + src[t3.LOOSEPLAIN] + ")$|^$";
    tok("COMPARATOR");
    src[t3.COMPARATOR] = "^" + src[t3.GTLT] + "\\s*(" + src[t3.FULLPLAIN] + ")$|^$";
    tok("COMPARATORTRIM");
    src[t3.COMPARATORTRIM] = "(\\s*)" + src[t3.GTLT] + "\\s*(" + src[t3.LOOSEPLAIN] + "|" + src[t3.XRANGEPLAIN] + ")";
    re[t3.COMPARATORTRIM] = new RegExp(src[t3.COMPARATORTRIM], "g");
    var comparatorTrimReplace = "$1$2$3";
    tok("HYPHENRANGE");
    src[t3.HYPHENRANGE] = "^\\s*(" + src[t3.XRANGEPLAIN] + ")\\s+-\\s+(" + src[t3.XRANGEPLAIN] + ")\\s*$";
    tok("HYPHENRANGELOOSE");
    src[t3.HYPHENRANGELOOSE] = "^\\s*(" + src[t3.XRANGEPLAINLOOSE] + ")\\s+-\\s+(" + src[t3.XRANGEPLAINLOOSE] + ")\\s*$";
    tok("STAR");
    src[t3.STAR] = "(<|>)?=?\\s*\\*";
    for (i = 0; i < R; i++) {
      debug(i, src[i]);
      if (!re[i]) {
        re[i] = new RegExp(src[i]);
      }
    }
    var i;
    exports.parse = parse3;
    function parse3(version2, options) {
      if (!options || typeof options !== "object") {
        options = {
          loose: !!options,
          includePrerelease: false
        };
      }
      if (version2 instanceof SemVer) {
        return version2;
      }
      if (typeof version2 !== "string") {
        return null;
      }
      if (version2.length > MAX_LENGTH) {
        return null;
      }
      var r = options.loose ? re[t3.LOOSE] : re[t3.FULL];
      if (!r.test(version2)) {
        return null;
      }
      try {
        return new SemVer(version2, options);
      } catch (er) {
        return null;
      }
    }
    exports.valid = valid;
    function valid(version2, options) {
      var v = parse3(version2, options);
      return v ? v.version : null;
    }
    exports.clean = clean;
    function clean(version2, options) {
      var s = parse3(version2.trim().replace(/^[=v]+/, ""), options);
      return s ? s.version : null;
    }
    exports.SemVer = SemVer;
    function SemVer(version2, options) {
      if (!options || typeof options !== "object") {
        options = {
          loose: !!options,
          includePrerelease: false
        };
      }
      if (version2 instanceof SemVer) {
        if (version2.loose === options.loose) {
          return version2;
        } else {
          version2 = version2.version;
        }
      } else if (typeof version2 !== "string") {
        throw new TypeError("Invalid Version: " + version2);
      }
      if (version2.length > MAX_LENGTH) {
        throw new TypeError("version is longer than " + MAX_LENGTH + " characters");
      }
      if (!(this instanceof SemVer)) {
        return new SemVer(version2, options);
      }
      debug("SemVer", version2, options);
      this.options = options;
      this.loose = !!options.loose;
      var m = version2.trim().match(options.loose ? re[t3.LOOSE] : re[t3.FULL]);
      if (!m) {
        throw new TypeError("Invalid Version: " + version2);
      }
      this.raw = version2;
      this.major = +m[1];
      this.minor = +m[2];
      this.patch = +m[3];
      if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
        throw new TypeError("Invalid major version");
      }
      if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
        throw new TypeError("Invalid minor version");
      }
      if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
        throw new TypeError("Invalid patch version");
      }
      if (!m[4]) {
        this.prerelease = [];
      } else {
        this.prerelease = m[4].split(".").map(function(id) {
          if (/^[0-9]+$/.test(id)) {
            var num = +id;
            if (num >= 0 && num < MAX_SAFE_INTEGER) {
              return num;
            }
          }
          return id;
        });
      }
      this.build = m[5] ? m[5].split(".") : [];
      this.format();
    }
    SemVer.prototype.format = function() {
      this.version = this.major + "." + this.minor + "." + this.patch;
      if (this.prerelease.length) {
        this.version += "-" + this.prerelease.join(".");
      }
      return this.version;
    };
    SemVer.prototype.toString = function() {
      return this.version;
    };
    SemVer.prototype.compare = function(other) {
      debug("SemVer.compare", this.version, this.options, other);
      if (!(other instanceof SemVer)) {
        other = new SemVer(other, this.options);
      }
      return this.compareMain(other) || this.comparePre(other);
    };
    SemVer.prototype.compareMain = function(other) {
      if (!(other instanceof SemVer)) {
        other = new SemVer(other, this.options);
      }
      return compareIdentifiers(this.major, other.major) || compareIdentifiers(this.minor, other.minor) || compareIdentifiers(this.patch, other.patch);
    };
    SemVer.prototype.comparePre = function(other) {
      if (!(other instanceof SemVer)) {
        other = new SemVer(other, this.options);
      }
      if (this.prerelease.length && !other.prerelease.length) {
        return -1;
      } else if (!this.prerelease.length && other.prerelease.length) {
        return 1;
      } else if (!this.prerelease.length && !other.prerelease.length) {
        return 0;
      }
      var i2 = 0;
      do {
        var a = this.prerelease[i2];
        var b = other.prerelease[i2];
        debug("prerelease compare", i2, a, b);
        if (a === void 0 && b === void 0) {
          return 0;
        } else if (b === void 0) {
          return 1;
        } else if (a === void 0) {
          return -1;
        } else if (a === b) {
          continue;
        } else {
          return compareIdentifiers(a, b);
        }
      } while (++i2);
    };
    SemVer.prototype.compareBuild = function(other) {
      if (!(other instanceof SemVer)) {
        other = new SemVer(other, this.options);
      }
      var i2 = 0;
      do {
        var a = this.build[i2];
        var b = other.build[i2];
        debug("prerelease compare", i2, a, b);
        if (a === void 0 && b === void 0) {
          return 0;
        } else if (b === void 0) {
          return 1;
        } else if (a === void 0) {
          return -1;
        } else if (a === b) {
          continue;
        } else {
          return compareIdentifiers(a, b);
        }
      } while (++i2);
    };
    SemVer.prototype.inc = function(release, identifier3) {
      switch (release) {
        case "premajor":
          this.prerelease.length = 0;
          this.patch = 0;
          this.minor = 0;
          this.major++;
          this.inc("pre", identifier3);
          break;
        case "preminor":
          this.prerelease.length = 0;
          this.patch = 0;
          this.minor++;
          this.inc("pre", identifier3);
          break;
        case "prepatch":
          this.prerelease.length = 0;
          this.inc("patch", identifier3);
          this.inc("pre", identifier3);
          break;
        case "prerelease":
          if (this.prerelease.length === 0) {
            this.inc("patch", identifier3);
          }
          this.inc("pre", identifier3);
          break;
        case "major":
          if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {
            this.major++;
          }
          this.minor = 0;
          this.patch = 0;
          this.prerelease = [];
          break;
        case "minor":
          if (this.patch !== 0 || this.prerelease.length === 0) {
            this.minor++;
          }
          this.patch = 0;
          this.prerelease = [];
          break;
        case "patch":
          if (this.prerelease.length === 0) {
            this.patch++;
          }
          this.prerelease = [];
          break;
        case "pre":
          if (this.prerelease.length === 0) {
            this.prerelease = [0];
          } else {
            var i2 = this.prerelease.length;
            while (--i2 >= 0) {
              if (typeof this.prerelease[i2] === "number") {
                this.prerelease[i2]++;
                i2 = -2;
              }
            }
            if (i2 === -1) {
              this.prerelease.push(0);
            }
          }
          if (identifier3) {
            if (this.prerelease[0] === identifier3) {
              if (isNaN(this.prerelease[1])) {
                this.prerelease = [identifier3, 0];
              }
            } else {
              this.prerelease = [identifier3, 0];
            }
          }
          break;
        default:
          throw new Error("invalid increment argument: " + release);
      }
      this.format();
      this.raw = this.version;
      return this;
    };
    exports.inc = inc;
    function inc(version2, release, loose, identifier3) {
      if (typeof loose === "string") {
        identifier3 = loose;
        loose = void 0;
      }
      try {
        return new SemVer(version2, loose).inc(release, identifier3).version;
      } catch (er) {
        return null;
      }
    }
    exports.diff = diff;
    function diff(version1, version2) {
      if (eq(version1, version2)) {
        return null;
      } else {
        var v1 = parse3(version1);
        var v2 = parse3(version2);
        var prefix = "";
        if (v1.prerelease.length || v2.prerelease.length) {
          prefix = "pre";
          var defaultResult = "prerelease";
        }
        for (var key in v1) {
          if (key === "major" || key === "minor" || key === "patch") {
            if (v1[key] !== v2[key]) {
              return prefix + key;
            }
          }
        }
        return defaultResult;
      }
    }
    exports.compareIdentifiers = compareIdentifiers;
    var numeric = /^[0-9]+$/;
    function compareIdentifiers(a, b) {
      var anum = numeric.test(a);
      var bnum = numeric.test(b);
      if (anum && bnum) {
        a = +a;
        b = +b;
      }
      return a === b ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a < b ? -1 : 1;
    }
    exports.rcompareIdentifiers = rcompareIdentifiers;
    function rcompareIdentifiers(a, b) {
      return compareIdentifiers(b, a);
    }
    exports.major = major;
    function major(a, loose) {
      return new SemVer(a, loose).major;
    }
    exports.minor = minor;
    function minor(a, loose) {
      return new SemVer(a, loose).minor;
    }
    exports.patch = patch;
    function patch(a, loose) {
      return new SemVer(a, loose).patch;
    }
    exports.compare = compare;
    function compare(a, b, loose) {
      return new SemVer(a, loose).compare(new SemVer(b, loose));
    }
    exports.compareLoose = compareLoose;
    function compareLoose(a, b) {
      return compare(a, b, true);
    }
    exports.compareBuild = compareBuild;
    function compareBuild(a, b, loose) {
      var versionA = new SemVer(a, loose);
      var versionB = new SemVer(b, loose);
      return versionA.compare(versionB) || versionA.compareBuild(versionB);
    }
    exports.rcompare = rcompare;
    function rcompare(a, b, loose) {
      return compare(b, a, loose);
    }
    exports.sort = sort;
    function sort(list, loose) {
      return list.sort(function(a, b) {
        return exports.compareBuild(a, b, loose);
      });
    }
    exports.rsort = rsort;
    function rsort(list, loose) {
      return list.sort(function(a, b) {
        return exports.compareBuild(b, a, loose);
      });
    }
    exports.gt = gt;
    function gt(a, b, loose) {
      return compare(a, b, loose) > 0;
    }
    exports.lt = lt;
    function lt(a, b, loose) {
      return compare(a, b, loose) < 0;
    }
    exports.eq = eq;
    function eq(a, b, loose) {
      return compare(a, b, loose) === 0;
    }
    exports.neq = neq;
    function neq(a, b, loose) {
      return compare(a, b, loose) !== 0;
    }
    exports.gte = gte;
    function gte(a, b, loose) {
      return compare(a, b, loose) >= 0;
    }
    exports.lte = lte;
    function lte(a, b, loose) {
      return compare(a, b, loose) <= 0;
    }
    exports.cmp = cmp;
    function cmp(a, op, b, loose) {
      switch (op) {
        case "===":
          if (typeof a === "object")
            a = a.version;
          if (typeof b === "object")
            b = b.version;
          return a === b;
        case "!==":
          if (typeof a === "object")
            a = a.version;
          if (typeof b === "object")
            b = b.version;
          return a !== b;
        case "":
        case "=":
        case "==":
          return eq(a, b, loose);
        case "!=":
          return neq(a, b, loose);
        case ">":
          return gt(a, b, loose);
        case ">=":
          return gte(a, b, loose);
        case "<":
          return lt(a, b, loose);
        case "<=":
          return lte(a, b, loose);
        default:
          throw new TypeError("Invalid operator: " + op);
      }
    }
    exports.Comparator = Comparator;
    function Comparator(comp, options) {
      if (!options || typeof options !== "object") {
        options = {
          loose: !!options,
          includePrerelease: false
        };
      }
      if (comp instanceof Comparator) {
        if (comp.loose === !!options.loose) {
          return comp;
        } else {
          comp = comp.value;
        }
      }
      if (!(this instanceof Comparator)) {
        return new Comparator(comp, options);
      }
      debug("comparator", comp, options);
      this.options = options;
      this.loose = !!options.loose;
      this.parse(comp);
      if (this.semver === ANY) {
        this.value = "";
      } else {
        this.value = this.operator + this.semver.version;
      }
      debug("comp", this);
    }
    var ANY = {};
    Comparator.prototype.parse = function(comp) {
      var r = this.options.loose ? re[t3.COMPARATORLOOSE] : re[t3.COMPARATOR];
      var m = comp.match(r);
      if (!m) {
        throw new TypeError("Invalid comparator: " + comp);
      }
      this.operator = m[1] !== void 0 ? m[1] : "";
      if (this.operator === "=") {
        this.operator = "";
      }
      if (!m[2]) {
        this.semver = ANY;
      } else {
        this.semver = new SemVer(m[2], this.options.loose);
      }
    };
    Comparator.prototype.toString = function() {
      return this.value;
    };
    Comparator.prototype.test = function(version2) {
      debug("Comparator.test", version2, this.options.loose);
      if (this.semver === ANY || version2 === ANY) {
        return true;
      }
      if (typeof version2 === "string") {
        try {
          version2 = new SemVer(version2, this.options);
        } catch (er) {
          return false;
        }
      }
      return cmp(version2, this.operator, this.semver, this.options);
    };
    Comparator.prototype.intersects = function(comp, options) {
      if (!(comp instanceof Comparator)) {
        throw new TypeError("a Comparator is required");
      }
      if (!options || typeof options !== "object") {
        options = {
          loose: !!options,
          includePrerelease: false
        };
      }
      var rangeTmp;
      if (this.operator === "") {
        if (this.value === "") {
          return true;
        }
        rangeTmp = new Range(comp.value, options);
        return satisfies(this.value, rangeTmp, options);
      } else if (comp.operator === "") {
        if (comp.value === "") {
          return true;
        }
        rangeTmp = new Range(this.value, options);
        return satisfies(comp.semver, rangeTmp, options);
      }
      var sameDirectionIncreasing = (this.operator === ">=" || this.operator === ">") && (comp.operator === ">=" || comp.operator === ">");
      var sameDirectionDecreasing = (this.operator === "<=" || this.operator === "<") && (comp.operator === "<=" || comp.operator === "<");
      var sameSemVer = this.semver.version === comp.semver.version;
      var differentDirectionsInclusive = (this.operator === ">=" || this.operator === "<=") && (comp.operator === ">=" || comp.operator === "<=");
      var oppositeDirectionsLessThan = cmp(this.semver, "<", comp.semver, options) && ((this.operator === ">=" || this.operator === ">") && (comp.operator === "<=" || comp.operator === "<"));
      var oppositeDirectionsGreaterThan = cmp(this.semver, ">", comp.semver, options) && ((this.operator === "<=" || this.operator === "<") && (comp.operator === ">=" || comp.operator === ">"));
      return sameDirectionIncreasing || sameDirectionDecreasing || sameSemVer && differentDirectionsInclusive || oppositeDirectionsLessThan || oppositeDirectionsGreaterThan;
    };
    exports.Range = Range;
    function Range(range, options) {
      if (!options || typeof options !== "object") {
        options = {
          loose: !!options,
          includePrerelease: false
        };
      }
      if (range instanceof Range) {
        if (range.loose === !!options.loose && range.includePrerelease === !!options.includePrerelease) {
          return range;
        } else {
          return new Range(range.raw, options);
        }
      }
      if (range instanceof Comparator) {
        return new Range(range.value, options);
      }
      if (!(this instanceof Range)) {
        return new Range(range, options);
      }
      this.options = options;
      this.loose = !!options.loose;
      this.includePrerelease = !!options.includePrerelease;
      this.raw = range;
      this.set = range.split(/\s*\|\|\s*/).map(function(range2) {
        return this.parseRange(range2.trim());
      }, this).filter(function(c) {
        return c.length;
      });
      if (!this.set.length) {
        throw new TypeError("Invalid SemVer Range: " + range);
      }
      this.format();
    }
    Range.prototype.format = function() {
      this.range = this.set.map(function(comps) {
        return comps.join(" ").trim();
      }).join("||").trim();
      return this.range;
    };
    Range.prototype.toString = function() {
      return this.range;
    };
    Range.prototype.parseRange = function(range) {
      var loose = this.options.loose;
      range = range.trim();
      var hr = loose ? re[t3.HYPHENRANGELOOSE] : re[t3.HYPHENRANGE];
      range = range.replace(hr, hyphenReplace);
      debug("hyphen replace", range);
      range = range.replace(re[t3.COMPARATORTRIM], comparatorTrimReplace);
      debug("comparator trim", range, re[t3.COMPARATORTRIM]);
      range = range.replace(re[t3.TILDETRIM], tildeTrimReplace);
      range = range.replace(re[t3.CARETTRIM], caretTrimReplace);
      range = range.split(/\s+/).join(" ");
      var compRe = loose ? re[t3.COMPARATORLOOSE] : re[t3.COMPARATOR];
      var set = range.split(" ").map(function(comp) {
        return parseComparator(comp, this.options);
      }, this).join(" ").split(/\s+/);
      if (this.options.loose) {
        set = set.filter(function(comp) {
          return !!comp.match(compRe);
        });
      }
      set = set.map(function(comp) {
        return new Comparator(comp, this.options);
      }, this);
      return set;
    };
    Range.prototype.intersects = function(range, options) {
      if (!(range instanceof Range)) {
        throw new TypeError("a Range is required");
      }
      return this.set.some(function(thisComparators) {
        return isSatisfiable(thisComparators, options) && range.set.some(function(rangeComparators) {
          return isSatisfiable(rangeComparators, options) && thisComparators.every(function(thisComparator) {
            return rangeComparators.every(function(rangeComparator) {
              return thisComparator.intersects(rangeComparator, options);
            });
          });
        });
      });
    };
    function isSatisfiable(comparators, options) {
      var result = true;
      var remainingComparators = comparators.slice();
      var testComparator = remainingComparators.pop();
      while (result && remainingComparators.length) {
        result = remainingComparators.every(function(otherComparator) {
          return testComparator.intersects(otherComparator, options);
        });
        testComparator = remainingComparators.pop();
      }
      return result;
    }
    exports.toComparators = toComparators;
    function toComparators(range, options) {
      return new Range(range, options).set.map(function(comp) {
        return comp.map(function(c) {
          return c.value;
        }).join(" ").trim().split(" ");
      });
    }
    function parseComparator(comp, options) {
      debug("comp", comp, options);
      comp = replaceCarets(comp, options);
      debug("caret", comp);
      comp = replaceTildes(comp, options);
      debug("tildes", comp);
      comp = replaceXRanges(comp, options);
      debug("xrange", comp);
      comp = replaceStars(comp, options);
      debug("stars", comp);
      return comp;
    }
    function isX(id) {
      return !id || id.toLowerCase() === "x" || id === "*";
    }
    function replaceTildes(comp, options) {
      return comp.trim().split(/\s+/).map(function(comp2) {
        return replaceTilde(comp2, options);
      }).join(" ");
    }
    function replaceTilde(comp, options) {
      var r = options.loose ? re[t3.TILDELOOSE] : re[t3.TILDE];
      return comp.replace(r, function(_, M, m, p, pr) {
        debug("tilde", comp, _, M, m, p, pr);
        var ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m)) {
          ret = ">=" + M + ".0.0 <" + (+M + 1) + ".0.0";
        } else if (isX(p)) {
          ret = ">=" + M + "." + m + ".0 <" + M + "." + (+m + 1) + ".0";
        } else if (pr) {
          debug("replaceTilde pr", pr);
          ret = ">=" + M + "." + m + "." + p + "-" + pr + " <" + M + "." + (+m + 1) + ".0";
        } else {
          ret = ">=" + M + "." + m + "." + p + " <" + M + "." + (+m + 1) + ".0";
        }
        debug("tilde return", ret);
        return ret;
      });
    }
    function replaceCarets(comp, options) {
      return comp.trim().split(/\s+/).map(function(comp2) {
        return replaceCaret(comp2, options);
      }).join(" ");
    }
    function replaceCaret(comp, options) {
      debug("caret", comp, options);
      var r = options.loose ? re[t3.CARETLOOSE] : re[t3.CARET];
      return comp.replace(r, function(_, M, m, p, pr) {
        debug("caret", comp, _, M, m, p, pr);
        var ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m)) {
          ret = ">=" + M + ".0.0 <" + (+M + 1) + ".0.0";
        } else if (isX(p)) {
          if (M === "0") {
            ret = ">=" + M + "." + m + ".0 <" + M + "." + (+m + 1) + ".0";
          } else {
            ret = ">=" + M + "." + m + ".0 <" + (+M + 1) + ".0.0";
          }
        } else if (pr) {
          debug("replaceCaret pr", pr);
          if (M === "0") {
            if (m === "0") {
              ret = ">=" + M + "." + m + "." + p + "-" + pr + " <" + M + "." + m + "." + (+p + 1);
            } else {
              ret = ">=" + M + "." + m + "." + p + "-" + pr + " <" + M + "." + (+m + 1) + ".0";
            }
          } else {
            ret = ">=" + M + "." + m + "." + p + "-" + pr + " <" + (+M + 1) + ".0.0";
          }
        } else {
          debug("no pr");
          if (M === "0") {
            if (m === "0") {
              ret = ">=" + M + "." + m + "." + p + " <" + M + "." + m + "." + (+p + 1);
            } else {
              ret = ">=" + M + "." + m + "." + p + " <" + M + "." + (+m + 1) + ".0";
            }
          } else {
            ret = ">=" + M + "." + m + "." + p + " <" + (+M + 1) + ".0.0";
          }
        }
        debug("caret return", ret);
        return ret;
      });
    }
    function replaceXRanges(comp, options) {
      debug("replaceXRanges", comp, options);
      return comp.split(/\s+/).map(function(comp2) {
        return replaceXRange(comp2, options);
      }).join(" ");
    }
    function replaceXRange(comp, options) {
      comp = comp.trim();
      var r = options.loose ? re[t3.XRANGELOOSE] : re[t3.XRANGE];
      return comp.replace(r, function(ret, gtlt, M, m, p, pr) {
        debug("xRange", comp, ret, gtlt, M, m, p, pr);
        var xM = isX(M);
        var xm = xM || isX(m);
        var xp = xm || isX(p);
        var anyX = xp;
        if (gtlt === "=" && anyX) {
          gtlt = "";
        }
        pr = options.includePrerelease ? "-0" : "";
        if (xM) {
          if (gtlt === ">" || gtlt === "<") {
            ret = "<0.0.0-0";
          } else {
            ret = "*";
          }
        } else if (gtlt && anyX) {
          if (xm) {
            m = 0;
          }
          p = 0;
          if (gtlt === ">") {
            gtlt = ">=";
            if (xm) {
              M = +M + 1;
              m = 0;
              p = 0;
            } else {
              m = +m + 1;
              p = 0;
            }
          } else if (gtlt === "<=") {
            gtlt = "<";
            if (xm) {
              M = +M + 1;
            } else {
              m = +m + 1;
            }
          }
          ret = gtlt + M + "." + m + "." + p + pr;
        } else if (xm) {
          ret = ">=" + M + ".0.0" + pr + " <" + (+M + 1) + ".0.0" + pr;
        } else if (xp) {
          ret = ">=" + M + "." + m + ".0" + pr + " <" + M + "." + (+m + 1) + ".0" + pr;
        }
        debug("xRange return", ret);
        return ret;
      });
    }
    function replaceStars(comp, options) {
      debug("replaceStars", comp, options);
      return comp.trim().replace(re[t3.STAR], "");
    }
    function hyphenReplace($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr, tb) {
      if (isX(fM)) {
        from = "";
      } else if (isX(fm)) {
        from = ">=" + fM + ".0.0";
      } else if (isX(fp)) {
        from = ">=" + fM + "." + fm + ".0";
      } else {
        from = ">=" + from;
      }
      if (isX(tM)) {
        to = "";
      } else if (isX(tm)) {
        to = "<" + (+tM + 1) + ".0.0";
      } else if (isX(tp)) {
        to = "<" + tM + "." + (+tm + 1) + ".0";
      } else if (tpr) {
        to = "<=" + tM + "." + tm + "." + tp + "-" + tpr;
      } else {
        to = "<=" + to;
      }
      return (from + " " + to).trim();
    }
    Range.prototype.test = function(version2) {
      if (!version2) {
        return false;
      }
      if (typeof version2 === "string") {
        try {
          version2 = new SemVer(version2, this.options);
        } catch (er) {
          return false;
        }
      }
      for (var i2 = 0; i2 < this.set.length; i2++) {
        if (testSet(this.set[i2], version2, this.options)) {
          return true;
        }
      }
      return false;
    };
    function testSet(set, version2, options) {
      for (var i2 = 0; i2 < set.length; i2++) {
        if (!set[i2].test(version2)) {
          return false;
        }
      }
      if (version2.prerelease.length && !options.includePrerelease) {
        for (i2 = 0; i2 < set.length; i2++) {
          debug(set[i2].semver);
          if (set[i2].semver === ANY) {
            continue;
          }
          if (set[i2].semver.prerelease.length > 0) {
            var allowed = set[i2].semver;
            if (allowed.major === version2.major && allowed.minor === version2.minor && allowed.patch === version2.patch) {
              return true;
            }
          }
        }
        return false;
      }
      return true;
    }
    exports.satisfies = satisfies;
    function satisfies(version2, range, options) {
      try {
        range = new Range(range, options);
      } catch (er) {
        return false;
      }
      return range.test(version2);
    }
    exports.maxSatisfying = maxSatisfying;
    function maxSatisfying(versions, range, options) {
      var max2 = null;
      var maxSV = null;
      try {
        var rangeObj = new Range(range, options);
      } catch (er) {
        return null;
      }
      versions.forEach(function(v) {
        if (rangeObj.test(v)) {
          if (!max2 || maxSV.compare(v) === -1) {
            max2 = v;
            maxSV = new SemVer(max2, options);
          }
        }
      });
      return max2;
    }
    exports.minSatisfying = minSatisfying;
    function minSatisfying(versions, range, options) {
      var min2 = null;
      var minSV = null;
      try {
        var rangeObj = new Range(range, options);
      } catch (er) {
        return null;
      }
      versions.forEach(function(v) {
        if (rangeObj.test(v)) {
          if (!min2 || minSV.compare(v) === 1) {
            min2 = v;
            minSV = new SemVer(min2, options);
          }
        }
      });
      return min2;
    }
    exports.minVersion = minVersion;
    function minVersion(range, loose) {
      range = new Range(range, loose);
      var minver = new SemVer("0.0.0");
      if (range.test(minver)) {
        return minver;
      }
      minver = new SemVer("0.0.0-0");
      if (range.test(minver)) {
        return minver;
      }
      minver = null;
      for (var i2 = 0; i2 < range.set.length; ++i2) {
        var comparators = range.set[i2];
        comparators.forEach(function(comparator) {
          var compver = new SemVer(comparator.semver.version);
          switch (comparator.operator) {
            case ">":
              if (compver.prerelease.length === 0) {
                compver.patch++;
              } else {
                compver.prerelease.push(0);
              }
              compver.raw = compver.format();
            case "":
            case ">=":
              if (!minver || gt(minver, compver)) {
                minver = compver;
              }
              break;
            case "<":
            case "<=":
              break;
            default:
              throw new Error("Unexpected operation: " + comparator.operator);
          }
        });
      }
      if (minver && range.test(minver)) {
        return minver;
      }
      return null;
    }
    exports.validRange = validRange;
    function validRange(range, options) {
      try {
        return new Range(range, options).range || "*";
      } catch (er) {
        return null;
      }
    }
    exports.ltr = ltr;
    function ltr(version2, range, options) {
      return outside(version2, range, "<", options);
    }
    exports.gtr = gtr;
    function gtr(version2, range, options) {
      return outside(version2, range, ">", options);
    }
    exports.outside = outside;
    function outside(version2, range, hilo, options) {
      version2 = new SemVer(version2, options);
      range = new Range(range, options);
      var gtfn, ltefn, ltfn, comp, ecomp;
      switch (hilo) {
        case ">":
          gtfn = gt;
          ltefn = lte;
          ltfn = lt;
          comp = ">";
          ecomp = ">=";
          break;
        case "<":
          gtfn = lt;
          ltefn = gte;
          ltfn = gt;
          comp = "<";
          ecomp = "<=";
          break;
        default:
          throw new TypeError('Must provide a hilo val of "<" or ">"');
      }
      if (satisfies(version2, range, options)) {
        return false;
      }
      for (var i2 = 0; i2 < range.set.length; ++i2) {
        var comparators = range.set[i2];
        var high = null;
        var low = null;
        comparators.forEach(function(comparator) {
          if (comparator.semver === ANY) {
            comparator = new Comparator(">=0.0.0");
          }
          high = high || comparator;
          low = low || comparator;
          if (gtfn(comparator.semver, high.semver, options)) {
            high = comparator;
          } else if (ltfn(comparator.semver, low.semver, options)) {
            low = comparator;
          }
        });
        if (high.operator === comp || high.operator === ecomp) {
          return false;
        }
        if ((!low.operator || low.operator === comp) && ltefn(version2, low.semver)) {
          return false;
        } else if (low.operator === ecomp && ltfn(version2, low.semver)) {
          return false;
        }
      }
      return true;
    }
    exports.prerelease = prerelease;
    function prerelease(version2, options) {
      var parsed = parse3(version2, options);
      return parsed && parsed.prerelease.length ? parsed.prerelease : null;
    }
    exports.intersects = intersects;
    function intersects(r1, r2, options) {
      r1 = new Range(r1, options);
      r2 = new Range(r2, options);
      return r1.intersects(r2);
    }
    exports.coerce = coerce;
    function coerce(version2, options) {
      if (version2 instanceof SemVer) {
        return version2;
      }
      if (typeof version2 === "number") {
        version2 = String(version2);
      }
      if (typeof version2 !== "string") {
        return null;
      }
      options = options || {};
      var match = null;
      if (!options.rtl) {
        match = version2.match(re[t3.COERCE]);
      } else {
        var next;
        while ((next = re[t3.COERCERTL].exec(version2)) && (!match || match.index + match[0].length !== version2.length)) {
          if (!match || next.index + next[0].length !== match.index + match[0].length) {
            match = next;
          }
          re[t3.COERCERTL].lastIndex = next.index + next[1].length + next[2].length;
        }
        re[t3.COERCERTL].lastIndex = -1;
      }
      if (match === null) {
        return null;
      }
      return parse3(match[2] + "." + (match[3] || "0") + "." + (match[4] || "0"), options);
    }
  }
});

// node_modules/lodash/sortedLastIndexBy.js
var require_sortedLastIndexBy = __commonJS({
  "node_modules/lodash/sortedLastIndexBy.js"(exports, module2) {
    var baseIteratee = require_baseIteratee();
    var baseSortedIndexBy = require_baseSortedIndexBy();
    function sortedLastIndexBy(array, value2, iteratee) {
      return baseSortedIndexBy(array, value2, baseIteratee(iteratee, 2), true);
    }
    module2.exports = sortedLastIndexBy;
  }
});

// node_modules/esquery/dist/esquery.min.js
var require_esquery_min = __commonJS({
  "node_modules/esquery/dist/esquery.min.js"(exports, module2) {
    !function(e, t3) {
      "object" == typeof exports && "undefined" != typeof module2 ? module2.exports = t3() : "function" == typeof define && define.amd ? define(t3) : (e = e || self).esquery = t3();
    }(exports, function() {
      "use strict";
      function e(t4) {
        return (e = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(e2) {
          return typeof e2;
        } : function(e2) {
          return e2 && "function" == typeof Symbol && e2.constructor === Symbol && e2 !== Symbol.prototype ? "symbol" : typeof e2;
        })(t4);
      }
      function t3(e2, t4) {
        return function(e3) {
          if (Array.isArray(e3))
            return e3;
        }(e2) || function(e3, t5) {
          if ("undefined" == typeof Symbol || !(Symbol.iterator in Object(e3)))
            return;
          var r2 = [], n2 = true, o2 = false, a2 = void 0;
          try {
            for (var i2, s2 = e3[Symbol.iterator](); !(n2 = (i2 = s2.next()).done) && (r2.push(i2.value), !t5 || r2.length !== t5); n2 = true)
              ;
          } catch (e4) {
            o2 = true, a2 = e4;
          } finally {
            try {
              n2 || null == s2.return || s2.return();
            } finally {
              if (o2)
                throw a2;
            }
          }
          return r2;
        }(e2, t4) || n(e2, t4) || function() {
          throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
        }();
      }
      function r(e2) {
        return function(e3) {
          if (Array.isArray(e3))
            return o(e3);
        }(e2) || function(e3) {
          if ("undefined" != typeof Symbol && Symbol.iterator in Object(e3))
            return Array.from(e3);
        }(e2) || n(e2) || function() {
          throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
        }();
      }
      function n(e2, t4) {
        if (e2) {
          if ("string" == typeof e2)
            return o(e2, t4);
          var r2 = Object.prototype.toString.call(e2).slice(8, -1);
          return "Object" === r2 && e2.constructor && (r2 = e2.constructor.name), "Map" === r2 || "Set" === r2 ? Array.from(e2) : "Arguments" === r2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r2) ? o(e2, t4) : void 0;
        }
      }
      function o(e2, t4) {
        (null == t4 || t4 > e2.length) && (t4 = e2.length);
        for (var r2 = 0, n2 = new Array(t4); r2 < t4; r2++)
          n2[r2] = e2[r2];
        return n2;
      }
      function a(e2, t4) {
        var r2;
        if ("undefined" == typeof Symbol || null == e2[Symbol.iterator]) {
          if (Array.isArray(e2) || (r2 = n(e2)) || t4 && e2 && "number" == typeof e2.length) {
            r2 && (e2 = r2);
            var o2 = 0, a2 = function() {
            };
            return { s: a2, n: function() {
              return o2 >= e2.length ? { done: true } : { done: false, value: e2[o2++] };
            }, e: function(e3) {
              throw e3;
            }, f: a2 };
          }
          throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
        }
        var i2, s2 = true, l2 = false;
        return { s: function() {
          r2 = e2[Symbol.iterator]();
        }, n: function() {
          var e3 = r2.next();
          return s2 = e3.done, e3;
        }, e: function(e3) {
          l2 = true, i2 = e3;
        }, f: function() {
          try {
            s2 || null == r2.return || r2.return();
          } finally {
            if (l2)
              throw i2;
          }
        } };
      }
      "undefined" != typeof globalThis ? globalThis : "undefined" != typeof window ? window : "undefined" != typeof global ? global : "undefined" != typeof self && self;
      function i(e2, t4) {
        return e2(t4 = { exports: {} }, t4.exports), t4.exports;
      }
      var s = i(function(e2, t4) {
        !function e3(t5) {
          var r2, n2, o2, a2, i2, s2;
          function l2(e4) {
            var t6, r3, n3 = {};
            for (t6 in e4)
              e4.hasOwnProperty(t6) && (r3 = e4[t6], n3[t6] = "object" == typeof r3 && null !== r3 ? l2(r3) : r3);
            return n3;
          }
          function u2(e4, t6) {
            this.parent = e4, this.key = t6;
          }
          function c2(e4, t6, r3, n3) {
            this.node = e4, this.path = t6, this.wrap = r3, this.ref = n3;
          }
          function f2() {
          }
          function p2(e4) {
            return null != e4 && ("object" == typeof e4 && "string" == typeof e4.type);
          }
          function h2(e4, t6) {
            return (e4 === r2.ObjectExpression || e4 === r2.ObjectPattern) && "properties" === t6;
          }
          function y2(e4, t6) {
            for (var r3 = e4.length - 1; r3 >= 0; --r3)
              if (e4[r3].node === t6)
                return true;
            return false;
          }
          function d2(e4, t6) {
            return new f2().traverse(e4, t6);
          }
          function m2(e4, t6) {
            var r3;
            return r3 = function(e5, t7) {
              var r4, n3, o3, a3;
              for (n3 = e5.length, o3 = 0; n3; )
                t7(e5[a3 = o3 + (r4 = n3 >>> 1)]) ? n3 = r4 : (o3 = a3 + 1, n3 -= r4 + 1);
              return o3;
            }(t6, function(t7) {
              return t7.range[0] > e4.range[0];
            }), e4.extendedRange = [e4.range[0], e4.range[1]], r3 !== t6.length && (e4.extendedRange[1] = t6[r3].range[0]), (r3 -= 1) >= 0 && (e4.extendedRange[0] = t6[r3].range[1]), e4;
          }
          return r2 = { AssignmentExpression: "AssignmentExpression", AssignmentPattern: "AssignmentPattern", ArrayExpression: "ArrayExpression", ArrayPattern: "ArrayPattern", ArrowFunctionExpression: "ArrowFunctionExpression", AwaitExpression: "AwaitExpression", BlockStatement: "BlockStatement", BinaryExpression: "BinaryExpression", BreakStatement: "BreakStatement", CallExpression: "CallExpression", CatchClause: "CatchClause", ChainExpression: "ChainExpression", ClassBody: "ClassBody", ClassDeclaration: "ClassDeclaration", ClassExpression: "ClassExpression", ComprehensionBlock: "ComprehensionBlock", ComprehensionExpression: "ComprehensionExpression", ConditionalExpression: "ConditionalExpression", ContinueStatement: "ContinueStatement", DebuggerStatement: "DebuggerStatement", DirectiveStatement: "DirectiveStatement", DoWhileStatement: "DoWhileStatement", EmptyStatement: "EmptyStatement", ExportAllDeclaration: "ExportAllDeclaration", ExportDefaultDeclaration: "ExportDefaultDeclaration", ExportNamedDeclaration: "ExportNamedDeclaration", ExportSpecifier: "ExportSpecifier", ExpressionStatement: "ExpressionStatement", ForStatement: "ForStatement", ForInStatement: "ForInStatement", ForOfStatement: "ForOfStatement", FunctionDeclaration: "FunctionDeclaration", FunctionExpression: "FunctionExpression", GeneratorExpression: "GeneratorExpression", Identifier: "Identifier", IfStatement: "IfStatement", ImportExpression: "ImportExpression", ImportDeclaration: "ImportDeclaration", ImportDefaultSpecifier: "ImportDefaultSpecifier", ImportNamespaceSpecifier: "ImportNamespaceSpecifier", ImportSpecifier: "ImportSpecifier", Literal: "Literal", LabeledStatement: "LabeledStatement", LogicalExpression: "LogicalExpression", MemberExpression: "MemberExpression", MetaProperty: "MetaProperty", MethodDefinition: "MethodDefinition", ModuleSpecifier: "ModuleSpecifier", NewExpression: "NewExpression", ObjectExpression: "ObjectExpression", ObjectPattern: "ObjectPattern", Program: "Program", Property: "Property", RestElement: "RestElement", ReturnStatement: "ReturnStatement", SequenceExpression: "SequenceExpression", SpreadElement: "SpreadElement", Super: "Super", SwitchStatement: "SwitchStatement", SwitchCase: "SwitchCase", TaggedTemplateExpression: "TaggedTemplateExpression", TemplateElement: "TemplateElement", TemplateLiteral: "TemplateLiteral", ThisExpression: "ThisExpression", ThrowStatement: "ThrowStatement", TryStatement: "TryStatement", UnaryExpression: "UnaryExpression", UpdateExpression: "UpdateExpression", VariableDeclaration: "VariableDeclaration", VariableDeclarator: "VariableDeclarator", WhileStatement: "WhileStatement", WithStatement: "WithStatement", YieldExpression: "YieldExpression" }, o2 = { AssignmentExpression: ["left", "right"], AssignmentPattern: ["left", "right"], ArrayExpression: ["elements"], ArrayPattern: ["elements"], ArrowFunctionExpression: ["params", "body"], AwaitExpression: ["argument"], BlockStatement: ["body"], BinaryExpression: ["left", "right"], BreakStatement: ["label"], CallExpression: ["callee", "arguments"], CatchClause: ["param", "body"], ChainExpression: ["expression"], ClassBody: ["body"], ClassDeclaration: ["id", "superClass", "body"], ClassExpression: ["id", "superClass", "body"], ComprehensionBlock: ["left", "right"], ComprehensionExpression: ["blocks", "filter", "body"], ConditionalExpression: ["test", "consequent", "alternate"], ContinueStatement: ["label"], DebuggerStatement: [], DirectiveStatement: [], DoWhileStatement: ["body", "test"], EmptyStatement: [], ExportAllDeclaration: ["source"], ExportDefaultDeclaration: ["declaration"], ExportNamedDeclaration: ["declaration", "specifiers", "source"], ExportSpecifier: ["exported", "local"], ExpressionStatement: ["expression"], ForStatement: ["init", "test", "update", "body"], ForInStatement: ["left", "right", "body"], ForOfStatement: ["left", "right", "body"], FunctionDeclaration: ["id", "params", "body"], FunctionExpression: ["id", "params", "body"], GeneratorExpression: ["blocks", "filter", "body"], Identifier: [], IfStatement: ["test", "consequent", "alternate"], ImportExpression: ["source"], ImportDeclaration: ["specifiers", "source"], ImportDefaultSpecifier: ["local"], ImportNamespaceSpecifier: ["local"], ImportSpecifier: ["imported", "local"], Literal: [], LabeledStatement: ["label", "body"], LogicalExpression: ["left", "right"], MemberExpression: ["object", "property"], MetaProperty: ["meta", "property"], MethodDefinition: ["key", "value"], ModuleSpecifier: [], NewExpression: ["callee", "arguments"], ObjectExpression: ["properties"], ObjectPattern: ["properties"], Program: ["body"], Property: ["key", "value"], RestElement: ["argument"], ReturnStatement: ["argument"], SequenceExpression: ["expressions"], SpreadElement: ["argument"], Super: [], SwitchStatement: ["discriminant", "cases"], SwitchCase: ["test", "consequent"], TaggedTemplateExpression: ["tag", "quasi"], TemplateElement: [], TemplateLiteral: ["quasis", "expressions"], ThisExpression: [], ThrowStatement: ["argument"], TryStatement: ["block", "handler", "finalizer"], UnaryExpression: ["argument"], UpdateExpression: ["argument"], VariableDeclaration: ["declarations"], VariableDeclarator: ["id", "init"], WhileStatement: ["test", "body"], WithStatement: ["object", "body"], YieldExpression: ["argument"] }, n2 = { Break: a2 = {}, Skip: i2 = {}, Remove: s2 = {} }, u2.prototype.replace = function(e4) {
            this.parent[this.key] = e4;
          }, u2.prototype.remove = function() {
            return Array.isArray(this.parent) ? (this.parent.splice(this.key, 1), true) : (this.replace(null), false);
          }, f2.prototype.path = function() {
            var e4, t6, r3, n3, o3;
            function a3(e5, t7) {
              if (Array.isArray(t7))
                for (r3 = 0, n3 = t7.length; r3 < n3; ++r3)
                  e5.push(t7[r3]);
              else
                e5.push(t7);
            }
            if (!this.__current.path)
              return null;
            for (o3 = [], e4 = 2, t6 = this.__leavelist.length; e4 < t6; ++e4)
              a3(o3, this.__leavelist[e4].path);
            return a3(o3, this.__current.path), o3;
          }, f2.prototype.type = function() {
            return this.current().type || this.__current.wrap;
          }, f2.prototype.parents = function() {
            var e4, t6, r3;
            for (r3 = [], e4 = 1, t6 = this.__leavelist.length; e4 < t6; ++e4)
              r3.push(this.__leavelist[e4].node);
            return r3;
          }, f2.prototype.current = function() {
            return this.__current.node;
          }, f2.prototype.__execute = function(e4, t6) {
            var r3, n3;
            return n3 = void 0, r3 = this.__current, this.__current = t6, this.__state = null, e4 && (n3 = e4.call(this, t6.node, this.__leavelist[this.__leavelist.length - 1].node)), this.__current = r3, n3;
          }, f2.prototype.notify = function(e4) {
            this.__state = e4;
          }, f2.prototype.skip = function() {
            this.notify(i2);
          }, f2.prototype.break = function() {
            this.notify(a2);
          }, f2.prototype.remove = function() {
            this.notify(s2);
          }, f2.prototype.__initialize = function(e4, t6) {
            this.visitor = t6, this.root = e4, this.__worklist = [], this.__leavelist = [], this.__current = null, this.__state = null, this.__fallback = null, "iteration" === t6.fallback ? this.__fallback = Object.keys : "function" == typeof t6.fallback && (this.__fallback = t6.fallback), this.__keys = o2, t6.keys && (this.__keys = Object.assign(Object.create(this.__keys), t6.keys));
          }, f2.prototype.traverse = function(e4, t6) {
            var r3, n3, o3, s3, l3, u3, f3, d3, m3, x2, v2, g2;
            for (this.__initialize(e4, t6), g2 = {}, r3 = this.__worklist, n3 = this.__leavelist, r3.push(new c2(e4, null, null, null)), n3.push(new c2(null, null, null, null)); r3.length; )
              if ((o3 = r3.pop()) !== g2) {
                if (o3.node) {
                  if (u3 = this.__execute(t6.enter, o3), this.__state === a2 || u3 === a2)
                    return;
                  if (r3.push(g2), n3.push(o3), this.__state === i2 || u3 === i2)
                    continue;
                  if (l3 = (s3 = o3.node).type || o3.wrap, !(x2 = this.__keys[l3])) {
                    if (!this.__fallback)
                      throw new Error("Unknown node type " + l3 + ".");
                    x2 = this.__fallback(s3);
                  }
                  for (d3 = x2.length; (d3 -= 1) >= 0; )
                    if (v2 = s3[f3 = x2[d3]]) {
                      if (Array.isArray(v2)) {
                        for (m3 = v2.length; (m3 -= 1) >= 0; )
                          if (v2[m3] && !y2(n3, v2[m3])) {
                            if (h2(l3, x2[d3]))
                              o3 = new c2(v2[m3], [f3, m3], "Property", null);
                            else {
                              if (!p2(v2[m3]))
                                continue;
                              o3 = new c2(v2[m3], [f3, m3], null, null);
                            }
                            r3.push(o3);
                          }
                      } else if (p2(v2)) {
                        if (y2(n3, v2))
                          continue;
                        r3.push(new c2(v2, f3, null, null));
                      }
                    }
                }
              } else if (o3 = n3.pop(), u3 = this.__execute(t6.leave, o3), this.__state === a2 || u3 === a2)
                return;
          }, f2.prototype.replace = function(e4, t6) {
            var r3, n3, o3, l3, f3, y3, d3, m3, x2, v2, g2, b, A;
            function E(e5) {
              var t7, n4, o4, a3;
              if (e5.ref.remove()) {
                for (n4 = e5.ref.key, a3 = e5.ref.parent, t7 = r3.length; t7--; )
                  if ((o4 = r3[t7]).ref && o4.ref.parent === a3) {
                    if (o4.ref.key < n4)
                      break;
                    --o4.ref.key;
                  }
              }
            }
            for (this.__initialize(e4, t6), g2 = {}, r3 = this.__worklist, n3 = this.__leavelist, y3 = new c2(e4, null, null, new u2(b = { root: e4 }, "root")), r3.push(y3), n3.push(y3); r3.length; )
              if ((y3 = r3.pop()) !== g2) {
                if (void 0 !== (f3 = this.__execute(t6.enter, y3)) && f3 !== a2 && f3 !== i2 && f3 !== s2 && (y3.ref.replace(f3), y3.node = f3), this.__state !== s2 && f3 !== s2 || (E(y3), y3.node = null), this.__state === a2 || f3 === a2)
                  return b.root;
                if ((o3 = y3.node) && (r3.push(g2), n3.push(y3), this.__state !== i2 && f3 !== i2)) {
                  if (l3 = o3.type || y3.wrap, !(x2 = this.__keys[l3])) {
                    if (!this.__fallback)
                      throw new Error("Unknown node type " + l3 + ".");
                    x2 = this.__fallback(o3);
                  }
                  for (d3 = x2.length; (d3 -= 1) >= 0; )
                    if (v2 = o3[A = x2[d3]])
                      if (Array.isArray(v2)) {
                        for (m3 = v2.length; (m3 -= 1) >= 0; )
                          if (v2[m3]) {
                            if (h2(l3, x2[d3]))
                              y3 = new c2(v2[m3], [A, m3], "Property", new u2(v2, m3));
                            else {
                              if (!p2(v2[m3]))
                                continue;
                              y3 = new c2(v2[m3], [A, m3], null, new u2(v2, m3));
                            }
                            r3.push(y3);
                          }
                      } else
                        p2(v2) && r3.push(new c2(v2, A, null, new u2(o3, A)));
                }
              } else if (y3 = n3.pop(), void 0 !== (f3 = this.__execute(t6.leave, y3)) && f3 !== a2 && f3 !== i2 && f3 !== s2 && y3.ref.replace(f3), this.__state !== s2 && f3 !== s2 || E(y3), this.__state === a2 || f3 === a2)
                return b.root;
            return b.root;
          }, t5.Syntax = r2, t5.traverse = d2, t5.replace = function(e4, t6) {
            return new f2().replace(e4, t6);
          }, t5.attachComments = function(e4, t6, r3) {
            var o3, a3, i3, s3, u3 = [];
            if (!e4.range)
              throw new Error("attachComments needs range information");
            if (!r3.length) {
              if (t6.length) {
                for (i3 = 0, a3 = t6.length; i3 < a3; i3 += 1)
                  (o3 = l2(t6[i3])).extendedRange = [0, e4.range[0]], u3.push(o3);
                e4.leadingComments = u3;
              }
              return e4;
            }
            for (i3 = 0, a3 = t6.length; i3 < a3; i3 += 1)
              u3.push(m2(l2(t6[i3]), r3));
            return s3 = 0, d2(e4, { enter: function(e5) {
              for (var t7; s3 < u3.length && !((t7 = u3[s3]).extendedRange[1] > e5.range[0]); )
                t7.extendedRange[1] === e5.range[0] ? (e5.leadingComments || (e5.leadingComments = []), e5.leadingComments.push(t7), u3.splice(s3, 1)) : s3 += 1;
              return s3 === u3.length ? n2.Break : u3[s3].extendedRange[0] > e5.range[1] ? n2.Skip : void 0;
            } }), s3 = 0, d2(e4, { leave: function(e5) {
              for (var t7; s3 < u3.length && (t7 = u3[s3], !(e5.range[1] < t7.extendedRange[0])); )
                e5.range[1] === t7.extendedRange[0] ? (e5.trailingComments || (e5.trailingComments = []), e5.trailingComments.push(t7), u3.splice(s3, 1)) : s3 += 1;
              return s3 === u3.length ? n2.Break : u3[s3].extendedRange[0] > e5.range[1] ? n2.Skip : void 0;
            } }), e4;
          }, t5.VisitorKeys = o2, t5.VisitorOption = n2, t5.Controller = f2, t5.cloneEnvironment = function() {
            return e3({});
          }, t5;
        }(t4);
      }), l = i(function(e2) {
        e2.exports && (e2.exports = function() {
          function e3(t4, r2, n2, o2) {
            this.message = t4, this.expected = r2, this.found = n2, this.location = o2, this.name = "SyntaxError", "function" == typeof Error.captureStackTrace && Error.captureStackTrace(this, e3);
          }
          return function(e4, t4) {
            function r2() {
              this.constructor = e4;
            }
            r2.prototype = t4.prototype, e4.prototype = new r2();
          }(e3, Error), e3.buildMessage = function(e4, t4) {
            var r2 = { literal: function(e5) {
              return '"' + o2(e5.text) + '"';
            }, class: function(e5) {
              var t5, r3 = "";
              for (t5 = 0; t5 < e5.parts.length; t5++)
                r3 += e5.parts[t5] instanceof Array ? a2(e5.parts[t5][0]) + "-" + a2(e5.parts[t5][1]) : a2(e5.parts[t5]);
              return "[" + (e5.inverted ? "^" : "") + r3 + "]";
            }, any: function(e5) {
              return "any character";
            }, end: function(e5) {
              return "end of input";
            }, other: function(e5) {
              return e5.description;
            } };
            function n2(e5) {
              return e5.charCodeAt(0).toString(16).toUpperCase();
            }
            function o2(e5) {
              return e5.replace(/\\/g, "\\\\").replace(/"/g, '\\"').replace(/\0/g, "\\0").replace(/\t/g, "\\t").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/[\x00-\x0F]/g, function(e6) {
                return "\\x0" + n2(e6);
              }).replace(/[\x10-\x1F\x7F-\x9F]/g, function(e6) {
                return "\\x" + n2(e6);
              });
            }
            function a2(e5) {
              return e5.replace(/\\/g, "\\\\").replace(/\]/g, "\\]").replace(/\^/g, "\\^").replace(/-/g, "\\-").replace(/\0/g, "\\0").replace(/\t/g, "\\t").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/[\x00-\x0F]/g, function(e6) {
                return "\\x0" + n2(e6);
              }).replace(/[\x10-\x1F\x7F-\x9F]/g, function(e6) {
                return "\\x" + n2(e6);
              });
            }
            return "Expected " + function(e5) {
              var t5, n3, o3, a3 = new Array(e5.length);
              for (t5 = 0; t5 < e5.length; t5++)
                a3[t5] = (o3 = e5[t5], r2[o3.type](o3));
              if (a3.sort(), a3.length > 0) {
                for (t5 = 1, n3 = 1; t5 < a3.length; t5++)
                  a3[t5 - 1] !== a3[t5] && (a3[n3] = a3[t5], n3++);
                a3.length = n3;
              }
              switch (a3.length) {
                case 1:
                  return a3[0];
                case 2:
                  return a3[0] + " or " + a3[1];
                default:
                  return a3.slice(0, -1).join(", ") + ", or " + a3[a3.length - 1];
              }
            }(e4) + " but " + function(e5) {
              return e5 ? '"' + o2(e5) + '"' : "end of input";
            }(t4) + " found.";
          }, { SyntaxError: e3, parse: function(t4, r2) {
            r2 = void 0 !== r2 ? r2 : {};
            var n2, o2, a2, i2, s2 = {}, l2 = { start: be }, u2 = be, c2 = de(" ", false), f2 = /^[^ [\],():#!=><~+.]/, p2 = me([" ", "[", "]", ",", "(", ")", ":", "#", "!", "=", ">", "<", "~", "+", "."], true, false), h2 = de(">", false), y2 = de("~", false), d2 = de("+", false), m2 = de(",", false), x2 = de("!", false), v2 = de("*", false), g2 = de("#", false), b = de("[", false), A = de("]", false), E = /^[><!]/, S = me([">", "<", "!"], false, false), _ = de("=", false), w = function(e4) {
              return (e4 || "") + "=";
            }, C = /^[><]/, P = me([">", "<"], false, false), k = de(".", false), D = function(e4, t5, r3) {
              return { type: "attribute", name: e4, operator: t5, value: r3 };
            }, j = de('"', false), I = /^[^\\"]/, T = me(["\\", '"'], true, false), F = de("\\", false), L = { type: "any" }, O = function(e4, t5) {
              return e4 + t5;
            }, R = function(e4) {
              return { type: "literal", value: (t5 = e4.join(""), t5.replace(/\\(.)/g, function(e5, t6) {
                switch (t6) {
                  case "b":
                    return "\b";
                  case "f":
                    return "\f";
                  case "n":
                    return "\n";
                  case "r":
                    return "\r";
                  case "t":
                    return "	";
                  case "v":
                    return "\v";
                  default:
                    return t6;
                }
              })) };
              var t5;
            }, B = de("'", false), M = /^[^\\']/, U = me(["\\", "'"], true, false), q = /^[0-9]/, V = me([["0", "9"]], false, false), N = de("type(", false), W = /^[^ )]/, K = me([" ", ")"], true, false), G = de(")", false), z = /^[imsu]/, H = me(["i", "m", "s", "u"], false, false), Y = de("/", false), $2 = /^[^\/]/, J = me(["/"], true, false), Q = de(":not(", false), X = de(":matches(", false), Z = de(":has(", false), ee = de(":first-child", false), te = de(":last-child", false), re = de(":nth-child(", false), ne = de(":nth-last-child(", false), oe = de(":", false), ae = de("statement", true), ie = de("expression", true), se = de("declaration", true), le = de("function", true), ue = de("pattern", true), ce = 0, fe = [{ line: 1, column: 1 }], pe = 0, he = [], ye = {};
            if ("startRule" in r2) {
              if (!(r2.startRule in l2))
                throw new Error(`Can't start parsing from rule "` + r2.startRule + '".');
              u2 = l2[r2.startRule];
            }
            function de(e4, t5) {
              return { type: "literal", text: e4, ignoreCase: t5 };
            }
            function me(e4, t5, r3) {
              return { type: "class", parts: e4, inverted: t5, ignoreCase: r3 };
            }
            function xe(e4) {
              var r3, n3 = fe[e4];
              if (n3)
                return n3;
              for (r3 = e4 - 1; !fe[r3]; )
                r3--;
              for (n3 = { line: (n3 = fe[r3]).line, column: n3.column }; r3 < e4; )
                10 === t4.charCodeAt(r3) ? (n3.line++, n3.column = 1) : n3.column++, r3++;
              return fe[e4] = n3, n3;
            }
            function ve(e4, t5) {
              var r3 = xe(e4), n3 = xe(t5);
              return { start: { offset: e4, line: r3.line, column: r3.column }, end: { offset: t5, line: n3.line, column: n3.column } };
            }
            function ge(e4) {
              ce < pe || (ce > pe && (pe = ce, he = []), he.push(e4));
            }
            function be() {
              var e4, t5, r3, n3, o3 = 30 * ce + 0, a3 = ye[o3];
              return a3 ? (ce = a3.nextPos, a3.result) : (e4 = ce, (t5 = Ae()) !== s2 && (r3 = _e()) !== s2 && Ae() !== s2 ? e4 = t5 = 1 === (n3 = r3).length ? n3[0] : { type: "matches", selectors: n3 } : (ce = e4, e4 = s2), e4 === s2 && (e4 = ce, (t5 = Ae()) !== s2 && (t5 = void 0), e4 = t5), ye[o3] = { nextPos: ce, result: e4 }, e4);
            }
            function Ae() {
              var e4, r3, n3 = 30 * ce + 1, o3 = ye[n3];
              if (o3)
                return ce = o3.nextPos, o3.result;
              for (e4 = [], 32 === t4.charCodeAt(ce) ? (r3 = " ", ce++) : (r3 = s2, ge(c2)); r3 !== s2; )
                e4.push(r3), 32 === t4.charCodeAt(ce) ? (r3 = " ", ce++) : (r3 = s2, ge(c2));
              return ye[n3] = { nextPos: ce, result: e4 }, e4;
            }
            function Ee() {
              var e4, r3, n3, o3 = 30 * ce + 2, a3 = ye[o3];
              if (a3)
                return ce = a3.nextPos, a3.result;
              if (r3 = [], f2.test(t4.charAt(ce)) ? (n3 = t4.charAt(ce), ce++) : (n3 = s2, ge(p2)), n3 !== s2)
                for (; n3 !== s2; )
                  r3.push(n3), f2.test(t4.charAt(ce)) ? (n3 = t4.charAt(ce), ce++) : (n3 = s2, ge(p2));
              else
                r3 = s2;
              return r3 !== s2 && (r3 = r3.join("")), e4 = r3, ye[o3] = { nextPos: ce, result: e4 }, e4;
            }
            function Se() {
              var e4, r3, n3, o3 = 30 * ce + 3, a3 = ye[o3];
              return a3 ? (ce = a3.nextPos, a3.result) : (e4 = ce, (r3 = Ae()) !== s2 ? (62 === t4.charCodeAt(ce) ? (n3 = ">", ce++) : (n3 = s2, ge(h2)), n3 !== s2 && Ae() !== s2 ? e4 = r3 = "child" : (ce = e4, e4 = s2)) : (ce = e4, e4 = s2), e4 === s2 && (e4 = ce, (r3 = Ae()) !== s2 ? (126 === t4.charCodeAt(ce) ? (n3 = "~", ce++) : (n3 = s2, ge(y2)), n3 !== s2 && Ae() !== s2 ? e4 = r3 = "sibling" : (ce = e4, e4 = s2)) : (ce = e4, e4 = s2), e4 === s2 && (e4 = ce, (r3 = Ae()) !== s2 ? (43 === t4.charCodeAt(ce) ? (n3 = "+", ce++) : (n3 = s2, ge(d2)), n3 !== s2 && Ae() !== s2 ? e4 = r3 = "adjacent" : (ce = e4, e4 = s2)) : (ce = e4, e4 = s2), e4 === s2 && (e4 = ce, 32 === t4.charCodeAt(ce) ? (r3 = " ", ce++) : (r3 = s2, ge(c2)), r3 !== s2 && (n3 = Ae()) !== s2 ? e4 = r3 = "descendant" : (ce = e4, e4 = s2)))), ye[o3] = { nextPos: ce, result: e4 }, e4);
            }
            function _e() {
              var e4, r3, n3, o3, a3, i3, l3, u3, c3 = 30 * ce + 4, f3 = ye[c3];
              if (f3)
                return ce = f3.nextPos, f3.result;
              if (e4 = ce, (r3 = we()) !== s2) {
                for (n3 = [], o3 = ce, (a3 = Ae()) !== s2 ? (44 === t4.charCodeAt(ce) ? (i3 = ",", ce++) : (i3 = s2, ge(m2)), i3 !== s2 && (l3 = Ae()) !== s2 && (u3 = we()) !== s2 ? o3 = a3 = [a3, i3, l3, u3] : (ce = o3, o3 = s2)) : (ce = o3, o3 = s2); o3 !== s2; )
                  n3.push(o3), o3 = ce, (a3 = Ae()) !== s2 ? (44 === t4.charCodeAt(ce) ? (i3 = ",", ce++) : (i3 = s2, ge(m2)), i3 !== s2 && (l3 = Ae()) !== s2 && (u3 = we()) !== s2 ? o3 = a3 = [a3, i3, l3, u3] : (ce = o3, o3 = s2)) : (ce = o3, o3 = s2);
                n3 !== s2 ? e4 = r3 = [r3].concat(n3.map(function(e5) {
                  return e5[3];
                })) : (ce = e4, e4 = s2);
              } else
                ce = e4, e4 = s2;
              return ye[c3] = { nextPos: ce, result: e4 }, e4;
            }
            function we() {
              var e4, t5, r3, n3, o3, a3, i3, l3 = 30 * ce + 5, u3 = ye[l3];
              if (u3)
                return ce = u3.nextPos, u3.result;
              if (e4 = ce, (t5 = Ce()) !== s2) {
                for (r3 = [], n3 = ce, (o3 = Se()) !== s2 && (a3 = Ce()) !== s2 ? n3 = o3 = [o3, a3] : (ce = n3, n3 = s2); n3 !== s2; )
                  r3.push(n3), n3 = ce, (o3 = Se()) !== s2 && (a3 = Ce()) !== s2 ? n3 = o3 = [o3, a3] : (ce = n3, n3 = s2);
                r3 !== s2 ? (i3 = t5, e4 = t5 = r3.reduce(function(e5, t6) {
                  return { type: t6[0], left: e5, right: t6[1] };
                }, i3)) : (ce = e4, e4 = s2);
              } else
                ce = e4, e4 = s2;
              return ye[l3] = { nextPos: ce, result: e4 }, e4;
            }
            function Ce() {
              var e4, r3, n3, o3, a3, i3, l3, u3 = 30 * ce + 6, c3 = ye[u3];
              if (c3)
                return ce = c3.nextPos, c3.result;
              if (e4 = ce, 33 === t4.charCodeAt(ce) ? (r3 = "!", ce++) : (r3 = s2, ge(x2)), r3 === s2 && (r3 = null), r3 !== s2) {
                if (n3 = [], (o3 = Pe()) !== s2)
                  for (; o3 !== s2; )
                    n3.push(o3), o3 = Pe();
                else
                  n3 = s2;
                n3 !== s2 ? (a3 = r3, l3 = 1 === (i3 = n3).length ? i3[0] : { type: "compound", selectors: i3 }, a3 && (l3.subject = true), e4 = r3 = l3) : (ce = e4, e4 = s2);
              } else
                ce = e4, e4 = s2;
              return ye[u3] = { nextPos: ce, result: e4 }, e4;
            }
            function Pe() {
              var e4, r3 = 30 * ce + 7, n3 = ye[r3];
              return n3 ? (ce = n3.nextPos, n3.result) : ((e4 = function() {
                var e5, r4, n4 = 30 * ce + 8, o3 = ye[n4];
                return o3 ? (ce = o3.nextPos, o3.result) : (42 === t4.charCodeAt(ce) ? (r4 = "*", ce++) : (r4 = s2, ge(v2)), r4 !== s2 && (r4 = { type: "wildcard", value: r4 }), e5 = r4, ye[n4] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3 = 30 * ce + 9, a3 = ye[o3];
                return a3 ? (ce = a3.nextPos, a3.result) : (e5 = ce, 35 === t4.charCodeAt(ce) ? (r4 = "#", ce++) : (r4 = s2, ge(g2)), r4 === s2 && (r4 = null), r4 !== s2 && (n4 = Ee()) !== s2 ? e5 = r4 = { type: "identifier", value: n4 } : (ce = e5, e5 = s2), ye[o3] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3 = 30 * ce + 10, i3 = ye[a3];
                return i3 ? (ce = i3.nextPos, i3.result) : (e5 = ce, 91 === t4.charCodeAt(ce) ? (r4 = "[", ce++) : (r4 = s2, ge(b)), r4 !== s2 && Ae() !== s2 && (n4 = function() {
                  var e6, r5, n5, o4, a4 = 30 * ce + 14, i4 = ye[a4];
                  return i4 ? (ce = i4.nextPos, i4.result) : (e6 = ce, (r5 = ke()) !== s2 && Ae() !== s2 && (n5 = function() {
                    var e7, r6, n6, o5 = 30 * ce + 12, a5 = ye[o5];
                    return a5 ? (ce = a5.nextPos, a5.result) : (e7 = ce, 33 === t4.charCodeAt(ce) ? (r6 = "!", ce++) : (r6 = s2, ge(x2)), r6 === s2 && (r6 = null), r6 !== s2 ? (61 === t4.charCodeAt(ce) ? (n6 = "=", ce++) : (n6 = s2, ge(_)), n6 !== s2 ? (r6 = w(r6), e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2), ye[o5] = { nextPos: ce, result: e7 }, e7);
                  }()) !== s2 && Ae() !== s2 ? ((o4 = function() {
                    var e7, r6, n6, o5, a5, i5 = 30 * ce + 18, l3 = ye[i5];
                    if (l3)
                      return ce = l3.nextPos, l3.result;
                    if (e7 = ce, "type(" === t4.substr(ce, 5) ? (r6 = "type(", ce += 5) : (r6 = s2, ge(N)), r6 !== s2)
                      if (Ae() !== s2) {
                        if (n6 = [], W.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(K)), o5 !== s2)
                          for (; o5 !== s2; )
                            n6.push(o5), W.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(K));
                        else
                          n6 = s2;
                        n6 !== s2 && (o5 = Ae()) !== s2 ? (41 === t4.charCodeAt(ce) ? (a5 = ")", ce++) : (a5 = s2, ge(G)), a5 !== s2 ? (r6 = { type: "type", value: n6.join("") }, e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2);
                      } else
                        ce = e7, e7 = s2;
                    else
                      ce = e7, e7 = s2;
                    return ye[i5] = { nextPos: ce, result: e7 }, e7;
                  }()) === s2 && (o4 = function() {
                    var e7, r6, n6, o5, a5, i5, l3 = 30 * ce + 20, u3 = ye[l3];
                    if (u3)
                      return ce = u3.nextPos, u3.result;
                    if (e7 = ce, 47 === t4.charCodeAt(ce) ? (r6 = "/", ce++) : (r6 = s2, ge(Y)), r6 !== s2) {
                      if (n6 = [], $2.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(J)), o5 !== s2)
                        for (; o5 !== s2; )
                          n6.push(o5), $2.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(J));
                      else
                        n6 = s2;
                      n6 !== s2 ? (47 === t4.charCodeAt(ce) ? (o5 = "/", ce++) : (o5 = s2, ge(Y)), o5 !== s2 ? ((a5 = function() {
                        var e8, r7, n7 = 30 * ce + 19, o6 = ye[n7];
                        if (o6)
                          return ce = o6.nextPos, o6.result;
                        if (e8 = [], z.test(t4.charAt(ce)) ? (r7 = t4.charAt(ce), ce++) : (r7 = s2, ge(H)), r7 !== s2)
                          for (; r7 !== s2; )
                            e8.push(r7), z.test(t4.charAt(ce)) ? (r7 = t4.charAt(ce), ce++) : (r7 = s2, ge(H));
                        else
                          e8 = s2;
                        return ye[n7] = { nextPos: ce, result: e8 }, e8;
                      }()) === s2 && (a5 = null), a5 !== s2 ? (i5 = a5, r6 = { type: "regexp", value: new RegExp(n6.join(""), i5 ? i5.join("") : "") }, e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2);
                    } else
                      ce = e7, e7 = s2;
                    return ye[l3] = { nextPos: ce, result: e7 }, e7;
                  }()), o4 !== s2 ? (r5 = D(r5, n5, o4), e6 = r5) : (ce = e6, e6 = s2)) : (ce = e6, e6 = s2), e6 === s2 && (e6 = ce, (r5 = ke()) !== s2 && Ae() !== s2 && (n5 = function() {
                    var e7, r6, n6, o5 = 30 * ce + 11, a5 = ye[o5];
                    return a5 ? (ce = a5.nextPos, a5.result) : (e7 = ce, E.test(t4.charAt(ce)) ? (r6 = t4.charAt(ce), ce++) : (r6 = s2, ge(S)), r6 === s2 && (r6 = null), r6 !== s2 ? (61 === t4.charCodeAt(ce) ? (n6 = "=", ce++) : (n6 = s2, ge(_)), n6 !== s2 ? (r6 = w(r6), e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2), e7 === s2 && (C.test(t4.charAt(ce)) ? (e7 = t4.charAt(ce), ce++) : (e7 = s2, ge(P))), ye[o5] = { nextPos: ce, result: e7 }, e7);
                  }()) !== s2 && Ae() !== s2 ? ((o4 = function() {
                    var e7, r6, n6, o5, a5, i5, l3 = 30 * ce + 15, u3 = ye[l3];
                    if (u3)
                      return ce = u3.nextPos, u3.result;
                    if (e7 = ce, 34 === t4.charCodeAt(ce) ? (r6 = '"', ce++) : (r6 = s2, ge(j)), r6 !== s2) {
                      for (n6 = [], I.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(T)), o5 === s2 && (o5 = ce, 92 === t4.charCodeAt(ce) ? (a5 = "\\", ce++) : (a5 = s2, ge(F)), a5 !== s2 ? (t4.length > ce ? (i5 = t4.charAt(ce), ce++) : (i5 = s2, ge(L)), i5 !== s2 ? (a5 = O(a5, i5), o5 = a5) : (ce = o5, o5 = s2)) : (ce = o5, o5 = s2)); o5 !== s2; )
                        n6.push(o5), I.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(T)), o5 === s2 && (o5 = ce, 92 === t4.charCodeAt(ce) ? (a5 = "\\", ce++) : (a5 = s2, ge(F)), a5 !== s2 ? (t4.length > ce ? (i5 = t4.charAt(ce), ce++) : (i5 = s2, ge(L)), i5 !== s2 ? (a5 = O(a5, i5), o5 = a5) : (ce = o5, o5 = s2)) : (ce = o5, o5 = s2));
                      n6 !== s2 ? (34 === t4.charCodeAt(ce) ? (o5 = '"', ce++) : (o5 = s2, ge(j)), o5 !== s2 ? (r6 = R(n6), e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2);
                    } else
                      ce = e7, e7 = s2;
                    if (e7 === s2)
                      if (e7 = ce, 39 === t4.charCodeAt(ce) ? (r6 = "'", ce++) : (r6 = s2, ge(B)), r6 !== s2) {
                        for (n6 = [], M.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(U)), o5 === s2 && (o5 = ce, 92 === t4.charCodeAt(ce) ? (a5 = "\\", ce++) : (a5 = s2, ge(F)), a5 !== s2 ? (t4.length > ce ? (i5 = t4.charAt(ce), ce++) : (i5 = s2, ge(L)), i5 !== s2 ? (a5 = O(a5, i5), o5 = a5) : (ce = o5, o5 = s2)) : (ce = o5, o5 = s2)); o5 !== s2; )
                          n6.push(o5), M.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(U)), o5 === s2 && (o5 = ce, 92 === t4.charCodeAt(ce) ? (a5 = "\\", ce++) : (a5 = s2, ge(F)), a5 !== s2 ? (t4.length > ce ? (i5 = t4.charAt(ce), ce++) : (i5 = s2, ge(L)), i5 !== s2 ? (a5 = O(a5, i5), o5 = a5) : (ce = o5, o5 = s2)) : (ce = o5, o5 = s2));
                        n6 !== s2 ? (39 === t4.charCodeAt(ce) ? (o5 = "'", ce++) : (o5 = s2, ge(B)), o5 !== s2 ? (r6 = R(n6), e7 = r6) : (ce = e7, e7 = s2)) : (ce = e7, e7 = s2);
                      } else
                        ce = e7, e7 = s2;
                    return ye[l3] = { nextPos: ce, result: e7 }, e7;
                  }()) === s2 && (o4 = function() {
                    var e7, r6, n6, o5, a5, i5, l3, u3 = 30 * ce + 16, c3 = ye[u3];
                    if (c3)
                      return ce = c3.nextPos, c3.result;
                    for (e7 = ce, r6 = ce, n6 = [], q.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(V)); o5 !== s2; )
                      n6.push(o5), q.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(V));
                    if (n6 !== s2 ? (46 === t4.charCodeAt(ce) ? (o5 = ".", ce++) : (o5 = s2, ge(k)), o5 !== s2 ? r6 = n6 = [n6, o5] : (ce = r6, r6 = s2)) : (ce = r6, r6 = s2), r6 === s2 && (r6 = null), r6 !== s2) {
                      if (n6 = [], q.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(V)), o5 !== s2)
                        for (; o5 !== s2; )
                          n6.push(o5), q.test(t4.charAt(ce)) ? (o5 = t4.charAt(ce), ce++) : (o5 = s2, ge(V));
                      else
                        n6 = s2;
                      n6 !== s2 ? (i5 = n6, l3 = (a5 = r6) ? [].concat.apply([], a5).join("") : "", r6 = { type: "literal", value: parseFloat(l3 + i5.join("")) }, e7 = r6) : (ce = e7, e7 = s2);
                    } else
                      ce = e7, e7 = s2;
                    return ye[u3] = { nextPos: ce, result: e7 }, e7;
                  }()) === s2 && (o4 = function() {
                    var e7, t5, r6 = 30 * ce + 17, n6 = ye[r6];
                    return n6 ? (ce = n6.nextPos, n6.result) : ((t5 = Ee()) !== s2 && (t5 = { type: "literal", value: t5 }), e7 = t5, ye[r6] = { nextPos: ce, result: e7 }, e7);
                  }()), o4 !== s2 ? (r5 = D(r5, n5, o4), e6 = r5) : (ce = e6, e6 = s2)) : (ce = e6, e6 = s2), e6 === s2 && (e6 = ce, (r5 = ke()) !== s2 && (r5 = { type: "attribute", name: r5 }), e6 = r5)), ye[a4] = { nextPos: ce, result: e6 }, e6);
                }()) !== s2 && Ae() !== s2 ? (93 === t4.charCodeAt(ce) ? (o3 = "]", ce++) : (o3 = s2, ge(A)), o3 !== s2 ? e5 = r4 = n4 : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2), ye[a3] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3, i3, l3, u3, c3 = 30 * ce + 21, f3 = ye[c3];
                if (f3)
                  return ce = f3.nextPos, f3.result;
                if (e5 = ce, 46 === t4.charCodeAt(ce) ? (r4 = ".", ce++) : (r4 = s2, ge(k)), r4 !== s2)
                  if ((n4 = Ee()) !== s2) {
                    for (o3 = [], a3 = ce, 46 === t4.charCodeAt(ce) ? (i3 = ".", ce++) : (i3 = s2, ge(k)), i3 !== s2 && (l3 = Ee()) !== s2 ? a3 = i3 = [i3, l3] : (ce = a3, a3 = s2); a3 !== s2; )
                      o3.push(a3), a3 = ce, 46 === t4.charCodeAt(ce) ? (i3 = ".", ce++) : (i3 = s2, ge(k)), i3 !== s2 && (l3 = Ee()) !== s2 ? a3 = i3 = [i3, l3] : (ce = a3, a3 = s2);
                    o3 !== s2 ? (u3 = n4, r4 = { type: "field", name: o3.reduce(function(e6, t5) {
                      return e6 + t5[0] + t5[1];
                    }, u3) }, e5 = r4) : (ce = e5, e5 = s2);
                  } else
                    ce = e5, e5 = s2;
                else
                  ce = e5, e5 = s2;
                return ye[c3] = { nextPos: ce, result: e5 }, e5;
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3 = 30 * ce + 22, i3 = ye[a3];
                return i3 ? (ce = i3.nextPos, i3.result) : (e5 = ce, ":not(" === t4.substr(ce, 5) ? (r4 = ":not(", ce += 5) : (r4 = s2, ge(Q)), r4 !== s2 && Ae() !== s2 && (n4 = _e()) !== s2 && Ae() !== s2 ? (41 === t4.charCodeAt(ce) ? (o3 = ")", ce++) : (o3 = s2, ge(G)), o3 !== s2 ? e5 = r4 = { type: "not", selectors: n4 } : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2), ye[a3] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3 = 30 * ce + 23, i3 = ye[a3];
                return i3 ? (ce = i3.nextPos, i3.result) : (e5 = ce, ":matches(" === t4.substr(ce, 9) ? (r4 = ":matches(", ce += 9) : (r4 = s2, ge(X)), r4 !== s2 && Ae() !== s2 && (n4 = _e()) !== s2 && Ae() !== s2 ? (41 === t4.charCodeAt(ce) ? (o3 = ")", ce++) : (o3 = s2, ge(G)), o3 !== s2 ? e5 = r4 = { type: "matches", selectors: n4 } : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2), ye[a3] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3 = 30 * ce + 24, i3 = ye[a3];
                return i3 ? (ce = i3.nextPos, i3.result) : (e5 = ce, ":has(" === t4.substr(ce, 5) ? (r4 = ":has(", ce += 5) : (r4 = s2, ge(Z)), r4 !== s2 && Ae() !== s2 && (n4 = _e()) !== s2 && Ae() !== s2 ? (41 === t4.charCodeAt(ce) ? (o3 = ")", ce++) : (o3 = s2, ge(G)), o3 !== s2 ? e5 = r4 = { type: "has", selectors: n4 } : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2), ye[a3] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4 = 30 * ce + 25, o3 = ye[n4];
                return o3 ? (ce = o3.nextPos, o3.result) : (":first-child" === t4.substr(ce, 12) ? (r4 = ":first-child", ce += 12) : (r4 = s2, ge(ee)), r4 !== s2 && (r4 = De(1)), e5 = r4, ye[n4] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4 = 30 * ce + 26, o3 = ye[n4];
                return o3 ? (ce = o3.nextPos, o3.result) : (":last-child" === t4.substr(ce, 11) ? (r4 = ":last-child", ce += 11) : (r4 = s2, ge(te)), r4 !== s2 && (r4 = je(1)), e5 = r4, ye[n4] = { nextPos: ce, result: e5 }, e5);
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3, i3 = 30 * ce + 27, l3 = ye[i3];
                if (l3)
                  return ce = l3.nextPos, l3.result;
                if (e5 = ce, ":nth-child(" === t4.substr(ce, 11) ? (r4 = ":nth-child(", ce += 11) : (r4 = s2, ge(re)), r4 !== s2)
                  if (Ae() !== s2) {
                    if (n4 = [], q.test(t4.charAt(ce)) ? (o3 = t4.charAt(ce), ce++) : (o3 = s2, ge(V)), o3 !== s2)
                      for (; o3 !== s2; )
                        n4.push(o3), q.test(t4.charAt(ce)) ? (o3 = t4.charAt(ce), ce++) : (o3 = s2, ge(V));
                    else
                      n4 = s2;
                    n4 !== s2 && (o3 = Ae()) !== s2 ? (41 === t4.charCodeAt(ce) ? (a3 = ")", ce++) : (a3 = s2, ge(G)), a3 !== s2 ? (r4 = De(parseInt(n4.join(""), 10)), e5 = r4) : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2);
                  } else
                    ce = e5, e5 = s2;
                else
                  ce = e5, e5 = s2;
                return ye[i3] = { nextPos: ce, result: e5 }, e5;
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3, a3, i3 = 30 * ce + 28, l3 = ye[i3];
                if (l3)
                  return ce = l3.nextPos, l3.result;
                if (e5 = ce, ":nth-last-child(" === t4.substr(ce, 16) ? (r4 = ":nth-last-child(", ce += 16) : (r4 = s2, ge(ne)), r4 !== s2)
                  if (Ae() !== s2) {
                    if (n4 = [], q.test(t4.charAt(ce)) ? (o3 = t4.charAt(ce), ce++) : (o3 = s2, ge(V)), o3 !== s2)
                      for (; o3 !== s2; )
                        n4.push(o3), q.test(t4.charAt(ce)) ? (o3 = t4.charAt(ce), ce++) : (o3 = s2, ge(V));
                    else
                      n4 = s2;
                    n4 !== s2 && (o3 = Ae()) !== s2 ? (41 === t4.charCodeAt(ce) ? (a3 = ")", ce++) : (a3 = s2, ge(G)), a3 !== s2 ? (r4 = je(parseInt(n4.join(""), 10)), e5 = r4) : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2);
                  } else
                    ce = e5, e5 = s2;
                else
                  ce = e5, e5 = s2;
                return ye[i3] = { nextPos: ce, result: e5 }, e5;
              }()) === s2 && (e4 = function() {
                var e5, r4, n4, o3 = 30 * ce + 29, a3 = ye[o3];
                return a3 ? (ce = a3.nextPos, a3.result) : (e5 = ce, 58 === t4.charCodeAt(ce) ? (r4 = ":", ce++) : (r4 = s2, ge(oe)), r4 !== s2 ? ("statement" === t4.substr(ce, 9).toLowerCase() ? (n4 = t4.substr(ce, 9), ce += 9) : (n4 = s2, ge(ae)), n4 === s2 && ("expression" === t4.substr(ce, 10).toLowerCase() ? (n4 = t4.substr(ce, 10), ce += 10) : (n4 = s2, ge(ie)), n4 === s2 && ("declaration" === t4.substr(ce, 11).toLowerCase() ? (n4 = t4.substr(ce, 11), ce += 11) : (n4 = s2, ge(se)), n4 === s2 && ("function" === t4.substr(ce, 8).toLowerCase() ? (n4 = t4.substr(ce, 8), ce += 8) : (n4 = s2, ge(le)), n4 === s2 && ("pattern" === t4.substr(ce, 7).toLowerCase() ? (n4 = t4.substr(ce, 7), ce += 7) : (n4 = s2, ge(ue)))))), n4 !== s2 ? e5 = r4 = { type: "class", name: n4 } : (ce = e5, e5 = s2)) : (ce = e5, e5 = s2), ye[o3] = { nextPos: ce, result: e5 }, e5);
              }()), ye[r3] = { nextPos: ce, result: e4 }, e4);
            }
            function ke() {
              var e4, r3, n3, o3, a3, i3, l3, u3, c3 = 30 * ce + 13, f3 = ye[c3];
              if (f3)
                return ce = f3.nextPos, f3.result;
              if (e4 = ce, (r3 = Ee()) !== s2) {
                for (n3 = [], o3 = ce, 46 === t4.charCodeAt(ce) ? (a3 = ".", ce++) : (a3 = s2, ge(k)), a3 !== s2 && (i3 = Ee()) !== s2 ? o3 = a3 = [a3, i3] : (ce = o3, o3 = s2); o3 !== s2; )
                  n3.push(o3), o3 = ce, 46 === t4.charCodeAt(ce) ? (a3 = ".", ce++) : (a3 = s2, ge(k)), a3 !== s2 && (i3 = Ee()) !== s2 ? o3 = a3 = [a3, i3] : (ce = o3, o3 = s2);
                n3 !== s2 ? (l3 = r3, u3 = n3, e4 = r3 = [].concat.apply([l3], u3).join("")) : (ce = e4, e4 = s2);
              } else
                ce = e4, e4 = s2;
              return ye[c3] = { nextPos: ce, result: e4 }, e4;
            }
            function De(e4) {
              return { type: "nth-child", index: { type: "literal", value: e4 } };
            }
            function je(e4) {
              return { type: "nth-last-child", index: { type: "literal", value: e4 } };
            }
            if ((n2 = u2()) !== s2 && ce === t4.length)
              return n2;
            throw n2 !== s2 && ce < t4.length && ge({ type: "end" }), o2 = he, a2 = pe < t4.length ? t4.charAt(pe) : null, i2 = pe < t4.length ? ve(pe, pe + 1) : ve(pe, pe), new e3(e3.buildMessage(o2, a2), o2, a2, i2);
          } };
        }());
      });
      function u(t4, r2, n2, o2) {
        if (!r2)
          return true;
        if (!t4)
          return false;
        switch (n2 || (n2 = []), r2.type) {
          case "wildcard":
            return true;
          case "identifier":
            return r2.value.toLowerCase() === t4.type.toLowerCase();
          case "field":
            var i2 = r2.name.split("."), l2 = n2[i2.length - 1];
            return function e2(t5, r3, n3) {
              if (0 === n3.length)
                return t5 === r3;
              if (null == r3)
                return false;
              var o3 = r3[n3[0]], i3 = n3.slice(1);
              if (Array.isArray(o3)) {
                var s2, l3 = a(o3);
                try {
                  for (l3.s(); !(s2 = l3.n()).done; ) {
                    if (e2(t5, s2.value, i3))
                      return true;
                  }
                } catch (e3) {
                  l3.e(e3);
                } finally {
                  l3.f();
                }
                return false;
              }
              return e2(t5, o3, i3);
            }(t4, l2, i2);
          case "matches":
            var c2, f2 = a(r2.selectors);
            try {
              for (f2.s(); !(c2 = f2.n()).done; ) {
                var d2 = c2.value;
                if (u(t4, d2, n2, o2))
                  return true;
              }
            } catch (e2) {
              f2.e(e2);
            } finally {
              f2.f();
            }
            return false;
          case "compound":
            var m2, x2 = a(r2.selectors);
            try {
              for (x2.s(); !(m2 = x2.n()).done; ) {
                var v2 = m2.value;
                if (!u(t4, v2, n2, o2))
                  return false;
              }
            } catch (e2) {
              x2.e(e2);
            } finally {
              x2.f();
            }
            return true;
          case "not":
            var g2, b = a(r2.selectors);
            try {
              for (b.s(); !(g2 = b.n()).done; ) {
                var A = g2.value;
                if (u(t4, A, n2, o2))
                  return false;
              }
            } catch (e2) {
              b.e(e2);
            } finally {
              b.f();
            }
            return true;
          case "has":
            var E = function() {
              var e2, n3 = [], i3 = a(r2.selectors);
              try {
                var l3 = function() {
                  var r3 = e2.value, a2 = [];
                  s.traverse(t4, { enter: function(e3, t5) {
                    null != t5 && a2.unshift(t5), u(e3, r3, a2, o2) && n3.push(e3);
                  }, leave: function() {
                    a2.shift();
                  }, keys: o2 && o2.visitorKeys, fallback: o2 && o2.fallback || "iteration" });
                };
                for (i3.s(); !(e2 = i3.n()).done; )
                  l3();
              } catch (e3) {
                i3.e(e3);
              } finally {
                i3.f();
              }
              return { v: 0 !== n3.length };
            }();
            if ("object" === e(E))
              return E.v;
          case "child":
            return !!u(t4, r2.right, n2, o2) && u(n2[0], r2.left, n2.slice(1), o2);
          case "descendant":
            if (u(t4, r2.right, n2, o2)) {
              for (var S = 0, _ = n2.length; S < _; ++S)
                if (u(n2[S], r2.left, n2.slice(S + 1), o2))
                  return true;
            }
            return false;
          case "attribute":
            var w = function(e2, t5) {
              var r3, n3 = a(t5.split("."));
              try {
                for (n3.s(); !(r3 = n3.n()).done; ) {
                  var o3 = r3.value;
                  if (null == e2)
                    return e2;
                  e2 = e2[o3];
                }
              } catch (e3) {
                n3.e(e3);
              } finally {
                n3.f();
              }
              return e2;
            }(t4, r2.name);
            switch (r2.operator) {
              case void 0:
                return null != w;
              case "=":
                switch (r2.value.type) {
                  case "regexp":
                    return "string" == typeof w && r2.value.value.test(w);
                  case "literal":
                    return "".concat(r2.value.value) === "".concat(w);
                  case "type":
                    return r2.value.value === e(w);
                }
                throw new Error("Unknown selector value type: ".concat(r2.value.type));
              case "!=":
                switch (r2.value.type) {
                  case "regexp":
                    return !r2.value.value.test(w);
                  case "literal":
                    return "".concat(r2.value.value) !== "".concat(w);
                  case "type":
                    return r2.value.value !== e(w);
                }
                throw new Error("Unknown selector value type: ".concat(r2.value.type));
              case "<=":
                return w <= r2.value.value;
              case "<":
                return w < r2.value.value;
              case ">":
                return w > r2.value.value;
              case ">=":
                return w >= r2.value.value;
            }
            throw new Error("Unknown operator: ".concat(r2.operator));
          case "sibling":
            return u(t4, r2.right, n2, o2) && p(t4, r2.left, n2, "LEFT_SIDE", o2) || r2.left.subject && u(t4, r2.left, n2, o2) && p(t4, r2.right, n2, "RIGHT_SIDE", o2);
          case "adjacent":
            return u(t4, r2.right, n2, o2) && h(t4, r2.left, n2, "LEFT_SIDE", o2) || r2.right.subject && u(t4, r2.left, n2, o2) && h(t4, r2.right, n2, "RIGHT_SIDE", o2);
          case "nth-child":
            return u(t4, r2.right, n2, o2) && y(t4, n2, function() {
              return r2.index.value - 1;
            }, o2);
          case "nth-last-child":
            return u(t4, r2.right, n2, o2) && y(t4, n2, function(e2) {
              return e2 - r2.index.value;
            }, o2);
          case "class":
            switch (r2.name.toLowerCase()) {
              case "statement":
                if ("Statement" === t4.type.slice(-9))
                  return true;
              case "declaration":
                return "Declaration" === t4.type.slice(-11);
              case "pattern":
                if ("Pattern" === t4.type.slice(-7))
                  return true;
              case "expression":
                return "Expression" === t4.type.slice(-10) || "Literal" === t4.type.slice(-7) || "Identifier" === t4.type && (0 === n2.length || "MetaProperty" !== n2[0].type) || "MetaProperty" === t4.type;
              case "function":
                return "FunctionDeclaration" === t4.type || "FunctionExpression" === t4.type || "ArrowFunctionExpression" === t4.type;
            }
            throw new Error("Unknown class name: ".concat(r2.name));
        }
        throw new Error("Unknown selector type: ".concat(r2.type));
      }
      function c(e2, t4) {
        var r2 = e2.type;
        return t4 && t4.visitorKeys && t4.visitorKeys[r2] ? t4.visitorKeys[r2] : s.VisitorKeys[r2] ? s.VisitorKeys[r2] : t4 && "function" == typeof t4.fallback ? t4.fallback(e2) : Object.keys(e2).filter(function(e3) {
          return "type" !== e3;
        });
      }
      function f(t4) {
        return null !== t4 && "object" === e(t4) && "string" == typeof t4.type;
      }
      function p(e2, r2, n2, o2, i2) {
        var s2 = t3(n2, 1)[0];
        if (!s2)
          return false;
        var l2, p2 = a(c(s2, i2));
        try {
          for (p2.s(); !(l2 = p2.n()).done; ) {
            var h2 = s2[l2.value];
            if (Array.isArray(h2)) {
              var y2 = h2.indexOf(e2);
              if (y2 < 0)
                continue;
              var d2 = void 0, m2 = void 0;
              "LEFT_SIDE" === o2 ? (d2 = 0, m2 = y2) : (d2 = y2 + 1, m2 = h2.length);
              for (var x2 = d2; x2 < m2; ++x2)
                if (f(h2[x2]) && u(h2[x2], r2, n2, i2))
                  return true;
            }
          }
        } catch (e3) {
          p2.e(e3);
        } finally {
          p2.f();
        }
        return false;
      }
      function h(e2, r2, n2, o2, i2) {
        var s2 = t3(n2, 1)[0];
        if (!s2)
          return false;
        var l2, p2 = a(c(s2, i2));
        try {
          for (p2.s(); !(l2 = p2.n()).done; ) {
            var h2 = s2[l2.value];
            if (Array.isArray(h2)) {
              var y2 = h2.indexOf(e2);
              if (y2 < 0)
                continue;
              if ("LEFT_SIDE" === o2 && y2 > 0 && f(h2[y2 - 1]) && u(h2[y2 - 1], r2, n2, i2))
                return true;
              if ("RIGHT_SIDE" === o2 && y2 < h2.length - 1 && f(h2[y2 + 1]) && u(h2[y2 + 1], r2, n2, i2))
                return true;
            }
          }
        } catch (e3) {
          p2.e(e3);
        } finally {
          p2.f();
        }
        return false;
      }
      function y(e2, r2, n2, o2) {
        var i2 = t3(r2, 1)[0];
        if (!i2)
          return false;
        var s2, l2 = a(c(i2, o2));
        try {
          for (l2.s(); !(s2 = l2.n()).done; ) {
            var u2 = i2[s2.value];
            if (Array.isArray(u2)) {
              var f2 = u2.indexOf(e2);
              if (f2 >= 0 && f2 === n2(u2.length))
                return true;
            }
          }
        } catch (e3) {
          l2.e(e3);
        } finally {
          l2.f();
        }
        return false;
      }
      function d(n2, o2) {
        if (null == n2 || "object" != e(n2))
          return [];
        null == o2 && (o2 = n2);
        for (var a2 = n2.subject ? [o2] : [], i2 = 0, s2 = function(e2) {
          for (var t4 = [], r2 = Object.keys(e2), n3 = 0; n3 < r2.length; n3++)
            t4.push([r2[n3], e2[r2[n3]]]);
          return t4;
        }(n2); i2 < s2.length; i2++) {
          var l2 = t3(s2[i2], 2), u2 = l2[0], c2 = l2[1];
          a2.push.apply(a2, r(d(c2, "left" === u2 ? c2 : o2)));
        }
        return a2;
      }
      function m(e2, t4, r2, n2) {
        if (t4) {
          var o2 = [], a2 = d(t4);
          s.traverse(e2, { enter: function(e3, i2) {
            if (null != i2 && o2.unshift(i2), u(e3, t4, o2, n2))
              if (a2.length)
                for (var s2 = 0, l2 = a2.length; s2 < l2; ++s2) {
                  u(e3, a2[s2], o2, n2) && r2(e3, i2, o2);
                  for (var c2 = 0, f2 = o2.length; c2 < f2; ++c2) {
                    var p2 = o2.slice(c2 + 1);
                    u(o2[c2], a2[s2], p2, n2) && r2(o2[c2], i2, p2);
                  }
                }
              else
                r2(e3, i2, o2);
          }, leave: function() {
            o2.shift();
          }, keys: n2 && n2.visitorKeys, fallback: n2 && n2.fallback || "iteration" });
        }
      }
      function x(e2, t4, r2) {
        var n2 = [];
        return m(e2, t4, function(e3) {
          n2.push(e3);
        }, r2), n2;
      }
      function v(e2) {
        return l.parse(e2);
      }
      function g(e2, t4, r2) {
        return x(e2, v(t4), r2);
      }
      return g.parse = v, g.match = x, g.traverse = m, g.matches = u, g.query = g, g;
    });
  }
});

// node_modules/lodash/_isFlattenable.js
var require_isFlattenable = __commonJS({
  "node_modules/lodash/_isFlattenable.js"(exports, module2) {
    var Symbol2 = require_Symbol();
    var isArguments = require_isArguments();
    var isArray2 = require_isArray();
    var spreadableSymbol = Symbol2 ? Symbol2.isConcatSpreadable : void 0;
    function isFlattenable(value2) {
      return isArray2(value2) || isArguments(value2) || !!(spreadableSymbol && value2 && value2[spreadableSymbol]);
    }
    module2.exports = isFlattenable;
  }
});

// node_modules/lodash/_baseFlatten.js
var require_baseFlatten = __commonJS({
  "node_modules/lodash/_baseFlatten.js"(exports, module2) {
    var arrayPush = require_arrayPush();
    var isFlattenable = require_isFlattenable();
    function baseFlatten(array, depth, predicate, isStrict, result) {
      var index = -1, length = array.length;
      predicate || (predicate = isFlattenable);
      result || (result = []);
      while (++index < length) {
        var value2 = array[index];
        if (depth > 0 && predicate(value2)) {
          if (depth > 1) {
            baseFlatten(value2, depth - 1, predicate, isStrict, result);
          } else {
            arrayPush(result, value2);
          }
        } else if (!isStrict) {
          result[result.length] = value2;
        }
      }
      return result;
    }
    module2.exports = baseFlatten;
  }
});

// node_modules/lodash/_baseIsNaN.js
var require_baseIsNaN = __commonJS({
  "node_modules/lodash/_baseIsNaN.js"(exports, module2) {
    function baseIsNaN(value2) {
      return value2 !== value2;
    }
    module2.exports = baseIsNaN;
  }
});

// node_modules/lodash/_strictIndexOf.js
var require_strictIndexOf = __commonJS({
  "node_modules/lodash/_strictIndexOf.js"(exports, module2) {
    function strictIndexOf(array, value2, fromIndex) {
      var index = fromIndex - 1, length = array.length;
      while (++index < length) {
        if (array[index] === value2) {
          return index;
        }
      }
      return -1;
    }
    module2.exports = strictIndexOf;
  }
});

// node_modules/lodash/_baseIndexOf.js
var require_baseIndexOf = __commonJS({
  "node_modules/lodash/_baseIndexOf.js"(exports, module2) {
    var baseFindIndex = require_baseFindIndex();
    var baseIsNaN = require_baseIsNaN();
    var strictIndexOf = require_strictIndexOf();
    function baseIndexOf(array, value2, fromIndex) {
      return value2 === value2 ? strictIndexOf(array, value2, fromIndex) : baseFindIndex(array, baseIsNaN, fromIndex);
    }
    module2.exports = baseIndexOf;
  }
});

// node_modules/lodash/_arrayIncludes.js
var require_arrayIncludes = __commonJS({
  "node_modules/lodash/_arrayIncludes.js"(exports, module2) {
    var baseIndexOf = require_baseIndexOf();
    function arrayIncludes(array, value2) {
      var length = array == null ? 0 : array.length;
      return !!length && baseIndexOf(array, value2, 0) > -1;
    }
    module2.exports = arrayIncludes;
  }
});

// node_modules/lodash/_arrayIncludesWith.js
var require_arrayIncludesWith = __commonJS({
  "node_modules/lodash/_arrayIncludesWith.js"(exports, module2) {
    function arrayIncludesWith(array, value2, comparator) {
      var index = -1, length = array == null ? 0 : array.length;
      while (++index < length) {
        if (comparator(value2, array[index])) {
          return true;
        }
      }
      return false;
    }
    module2.exports = arrayIncludesWith;
  }
});

// node_modules/lodash/noop.js
var require_noop2 = __commonJS({
  "node_modules/lodash/noop.js"(exports, module2) {
    function noop() {
    }
    module2.exports = noop;
  }
});

// node_modules/lodash/_createSet.js
var require_createSet = __commonJS({
  "node_modules/lodash/_createSet.js"(exports, module2) {
    var Set2 = require_Set();
    var noop = require_noop2();
    var setToArray = require_setToArray();
    var INFINITY = 1 / 0;
    var createSet = !(Set2 && 1 / setToArray(new Set2([, -0]))[1] == INFINITY) ? noop : function(values2) {
      return new Set2(values2);
    };
    module2.exports = createSet;
  }
});

// node_modules/lodash/_baseUniq.js
var require_baseUniq = __commonJS({
  "node_modules/lodash/_baseUniq.js"(exports, module2) {
    var SetCache = require_SetCache();
    var arrayIncludes = require_arrayIncludes();
    var arrayIncludesWith = require_arrayIncludesWith();
    var cacheHas = require_cacheHas();
    var createSet = require_createSet();
    var setToArray = require_setToArray();
    var LARGE_ARRAY_SIZE = 200;
    function baseUniq(array, iteratee, comparator) {
      var index = -1, includes = arrayIncludes, length = array.length, isCommon = true, result = [], seen = result;
      if (comparator) {
        isCommon = false;
        includes = arrayIncludesWith;
      } else if (length >= LARGE_ARRAY_SIZE) {
        var set = iteratee ? null : createSet(array);
        if (set) {
          return setToArray(set);
        }
        isCommon = false;
        includes = cacheHas;
        seen = new SetCache();
      } else {
        seen = iteratee ? [] : result;
      }
      outer:
        while (++index < length) {
          var value2 = array[index], computed = iteratee ? iteratee(value2) : value2;
          value2 = comparator || value2 !== 0 ? value2 : 0;
          if (isCommon && computed === computed) {
            var seenIndex = seen.length;
            while (seenIndex--) {
              if (seen[seenIndex] === computed) {
                continue outer;
              }
            }
            if (iteratee) {
              seen.push(computed);
            }
            result.push(value2);
          } else if (!includes(seen, computed, comparator)) {
            if (seen !== result) {
              seen.push(computed);
            }
            result.push(value2);
          }
        }
      return result;
    }
    module2.exports = baseUniq;
  }
});

// node_modules/lodash/isArrayLikeObject.js
var require_isArrayLikeObject = __commonJS({
  "node_modules/lodash/isArrayLikeObject.js"(exports, module2) {
    var isArrayLike = require_isArrayLike2();
    var isObjectLike = require_isObjectLike();
    function isArrayLikeObject(value2) {
      return isObjectLike(value2) && isArrayLike(value2);
    }
    module2.exports = isArrayLikeObject;
  }
});

// node_modules/lodash/union.js
var require_union = __commonJS({
  "node_modules/lodash/union.js"(exports, module2) {
    var baseFlatten = require_baseFlatten();
    var baseRest = require_baseRest();
    var baseUniq = require_baseUniq();
    var isArrayLikeObject = require_isArrayLikeObject();
    var union = baseRest(function(arrays) {
      return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true));
    });
    module2.exports = union;
  }
});

// node_modules/lodash/_baseIntersection.js
var require_baseIntersection = __commonJS({
  "node_modules/lodash/_baseIntersection.js"(exports, module2) {
    var SetCache = require_SetCache();
    var arrayIncludes = require_arrayIncludes();
    var arrayIncludesWith = require_arrayIncludesWith();
    var arrayMap = require_arrayMap();
    var baseUnary = require_baseUnary();
    var cacheHas = require_cacheHas();
    var nativeMin = Math.min;
    function baseIntersection(arrays, iteratee, comparator) {
      var includes = comparator ? arrayIncludesWith : arrayIncludes, length = arrays[0].length, othLength = arrays.length, othIndex = othLength, caches = Array(othLength), maxLength = Infinity, result = [];
      while (othIndex--) {
        var array = arrays[othIndex];
        if (othIndex && iteratee) {
          array = arrayMap(array, baseUnary(iteratee));
        }
        maxLength = nativeMin(array.length, maxLength);
        caches[othIndex] = !comparator && (iteratee || length >= 120 && array.length >= 120) ? new SetCache(othIndex && array) : void 0;
      }
      array = arrays[0];
      var index = -1, seen = caches[0];
      outer:
        while (++index < length && result.length < maxLength) {
          var value2 = array[index], computed = iteratee ? iteratee(value2) : value2;
          value2 = comparator || value2 !== 0 ? value2 : 0;
          if (!(seen ? cacheHas(seen, computed) : includes(result, computed, comparator))) {
            othIndex = othLength;
            while (--othIndex) {
              var cache = caches[othIndex];
              if (!(cache ? cacheHas(cache, computed) : includes(arrays[othIndex], computed, comparator))) {
                continue outer;
              }
            }
            if (seen) {
              seen.push(computed);
            }
            result.push(value2);
          }
        }
      return result;
    }
    module2.exports = baseIntersection;
  }
});

// node_modules/lodash/_castArrayLikeObject.js
var require_castArrayLikeObject = __commonJS({
  "node_modules/lodash/_castArrayLikeObject.js"(exports, module2) {
    var isArrayLikeObject = require_isArrayLikeObject();
    function castArrayLikeObject(value2) {
      return isArrayLikeObject(value2) ? value2 : [];
    }
    module2.exports = castArrayLikeObject;
  }
});

// node_modules/lodash/intersection.js
var require_intersection = __commonJS({
  "node_modules/lodash/intersection.js"(exports, module2) {
    var arrayMap = require_arrayMap();
    var baseIntersection = require_baseIntersection();
    var baseRest = require_baseRest();
    var castArrayLikeObject = require_castArrayLikeObject();
    var intersection = baseRest(function(arrays) {
      var mapped = arrayMap(arrays, castArrayLikeObject);
      return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped) : [];
    });
    module2.exports = intersection;
  }
});

// node_modules/eslint/conf/default-cli-options.js
var require_default_cli_options = __commonJS({
  "node_modules/eslint/conf/default-cli-options.js"(exports, module2) {
    "use strict";
    module2.exports = {
      configFile: null,
      baseConfig: false,
      rulePaths: [],
      useEslintrc: true,
      envs: [],
      globals: [],
      extensions: null,
      ignore: true,
      ignorePath: void 0,
      cache: false,
      /*
       * in order to honor the cacheFile option if specified
       * this option should not have a default value otherwise
       * it will always be used
       */
      cacheLocation: "",
      cacheFile: ".eslintcache",
      cacheStrategy: "metadata",
      fix: false,
      allowInlineConfig: true,
      reportUnusedDisableDirectives: void 0,
      globInputPaths: true
    };
  }
});

// node_modules/eslint/package.json
var require_package4 = __commonJS({
  "node_modules/eslint/package.json"(exports, module2) {
    module2.exports = {
      name: "eslint",
      version: "8.31.0",
      author: "Nicholas C. Zakas <nicholas+npm@nczconsulting.com>",
      description: "An AST-based pattern checker for JavaScript.",
      bin: {
        eslint: "./bin/eslint.js"
      },
      main: "./lib/api.js",
      exports: {
        "./package.json": "./package.json",
        ".": "./lib/api.js",
        "./use-at-your-own-risk": "./lib/unsupported-api.js"
      },
      scripts: {
        "build:docs:update-links": "node tools/fetch-docs-links.js",
        "build:site": "node Makefile.js gensite",
        "build:webpack": "node Makefile.js webpack",
        "build:readme": "node tools/update-readme.js",
        lint: "node Makefile.js lint",
        "lint:docs:js": "node Makefile.js lintDocsJS",
        "lint:fix": "node Makefile.js lint -- fix",
        "lint:fix:docs:js": "node Makefile.js lintDocsJS -- fix",
        "release:generate:alpha": "node Makefile.js generatePrerelease -- alpha",
        "release:generate:beta": "node Makefile.js generatePrerelease -- beta",
        "release:generate:latest": "node Makefile.js generateRelease",
        "release:generate:rc": "node Makefile.js generatePrerelease -- rc",
        "release:publish": "node Makefile.js publishRelease",
        test: "node Makefile.js test",
        "test:cli": "mocha",
        "test:fuzz": "node Makefile.js fuzz",
        "test:performance": "node Makefile.js perf"
      },
      gitHooks: {
        "pre-commit": "lint-staged"
      },
      "lint-staged": {
        "*.js": "eslint --fix",
        "*.md": "markdownlint --fix",
        "docs/src/rules/*.md": [
          "node tools/fetch-docs-links.js",
          "git add docs/src/_data/further_reading_links.json"
        ],
        "docs/**/*.svg": "npx svgo -r --multipass"
      },
      files: [
        "LICENSE",
        "README.md",
        "bin",
        "conf",
        "lib",
        "messages"
      ],
      repository: "eslint/eslint",
      funding: "https://opencollective.com/eslint",
      homepage: "https://eslint.org",
      bugs: "https://github.com/eslint/eslint/issues/",
      dependencies: {
        "@eslint/eslintrc": "^1.4.1",
        "@humanwhocodes/config-array": "^0.11.8",
        "@humanwhocodes/module-importer": "^1.0.1",
        "@nodelib/fs.walk": "^1.2.8",
        ajv: "^6.10.0",
        chalk: "^4.0.0",
        "cross-spawn": "^7.0.2",
        debug: "^4.3.2",
        doctrine: "^3.0.0",
        "escape-string-regexp": "^4.0.0",
        "eslint-scope": "^7.1.1",
        "eslint-utils": "^3.0.0",
        "eslint-visitor-keys": "^3.3.0",
        espree: "^9.4.0",
        esquery: "^1.4.0",
        esutils: "^2.0.2",
        "fast-deep-equal": "^3.1.3",
        "file-entry-cache": "^6.0.1",
        "find-up": "^5.0.0",
        "glob-parent": "^6.0.2",
        globals: "^13.19.0",
        "grapheme-splitter": "^1.0.4",
        ignore: "^5.2.0",
        "import-fresh": "^3.0.0",
        imurmurhash: "^0.1.4",
        "is-glob": "^4.0.0",
        "is-path-inside": "^3.0.3",
        "js-sdsl": "^4.1.4",
        "js-yaml": "^4.1.0",
        "json-stable-stringify-without-jsonify": "^1.0.1",
        levn: "^0.4.1",
        "lodash.merge": "^4.6.2",
        minimatch: "^3.1.2",
        "natural-compare": "^1.4.0",
        optionator: "^0.9.1",
        regexpp: "^3.2.0",
        "strip-ansi": "^6.0.1",
        "strip-json-comments": "^3.1.0",
        "text-table": "^0.2.0"
      },
      devDependencies: {
        "@babel/core": "^7.4.3",
        "@babel/preset-env": "^7.4.3",
        "babel-loader": "^8.0.5",
        c8: "^7.12.0",
        chai: "^4.0.1",
        cheerio: "^0.22.0",
        "common-tags": "^1.8.0",
        "core-js": "^3.1.3",
        ejs: "^3.0.2",
        eslint: "file:.",
        "eslint-config-eslint": "file:packages/eslint-config-eslint",
        "eslint-plugin-eslint-comments": "^3.2.0",
        "eslint-plugin-eslint-plugin": "^4.4.0",
        "eslint-plugin-internal-rules": "file:tools/internal-rules",
        "eslint-plugin-jsdoc": "^38.1.6",
        "eslint-plugin-n": "^15.2.4",
        "eslint-plugin-unicorn": "^42.0.0",
        "eslint-release": "^3.2.0",
        eslump: "^3.0.0",
        esprima: "^4.0.1",
        "fast-glob": "^3.2.11",
        "fs-teardown": "^0.1.3",
        glob: "^7.1.6",
        got: "^11.8.3",
        "gray-matter": "^4.0.3",
        karma: "^6.1.1",
        "karma-chrome-launcher": "^3.1.0",
        "karma-mocha": "^2.0.1",
        "karma-mocha-reporter": "^2.2.5",
        "karma-webpack": "^5.0.0",
        "lint-staged": "^11.0.0",
        "load-perf": "^0.2.0",
        markdownlint: "^0.25.1",
        "markdownlint-cli": "^0.31.1",
        marked: "^4.0.8",
        memfs: "^3.0.1",
        metascraper: "^5.25.7",
        "metascraper-description": "^5.25.7",
        "metascraper-image": "^5.29.3",
        "metascraper-logo": "^5.25.7",
        "metascraper-logo-favicon": "^5.25.7",
        "metascraper-title": "^5.25.7",
        mocha: "^8.3.2",
        "mocha-junit-reporter": "^2.0.0",
        "node-polyfill-webpack-plugin": "^1.0.3",
        "npm-license": "^0.3.3",
        pirates: "^4.0.5",
        progress: "^2.0.3",
        proxyquire: "^2.0.1",
        puppeteer: "^13.7.0",
        recast: "^0.20.4",
        "regenerator-runtime": "^0.13.2",
        semver: "^7.3.5",
        shelljs: "^0.8.2",
        sinon: "^11.0.0",
        temp: "^0.9.0",
        webpack: "^5.23.0",
        "webpack-cli": "^4.5.0",
        yorkie: "^2.0.0"
      },
      keywords: [
        "ast",
        "lint",
        "javascript",
        "ecmascript",
        "espree"
      ],
      license: "MIT",
      engines: {
        node: "^12.22.0 || ^14.17.0 || >=16.0.0"
      }
    };
  }
});

// node_modules/import-fresh/node_modules/resolve-from/index.js
var require_resolve_from = __commonJS({
  "node_modules/import-fresh/node_modules/resolve-from/index.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var Module = require("module");
    var fs2 = require("fs");
    var resolveFrom = (fromDir, moduleId, silent) => {
      if (typeof fromDir !== "string") {
        throw new TypeError(`Expected \`fromDir\` to be of type \`string\`, got \`${typeof fromDir}\``);
      }
      if (typeof moduleId !== "string") {
        throw new TypeError(`Expected \`moduleId\` to be of type \`string\`, got \`${typeof moduleId}\``);
      }
      try {
        fromDir = fs2.realpathSync(fromDir);
      } catch (err) {
        if (err.code === "ENOENT") {
          fromDir = path2.resolve(fromDir);
        } else if (silent) {
          return null;
        } else {
          throw err;
        }
      }
      const fromFile = path2.join(fromDir, "noop.js");
      const resolveFileName = () => Module._resolveFilename(moduleId, {
        id: fromFile,
        filename: fromFile,
        paths: Module._nodeModulePaths(fromDir)
      });
      if (silent) {
        try {
          return resolveFileName();
        } catch (err) {
          return null;
        }
      }
      return resolveFileName();
    };
    module2.exports = (fromDir, moduleId) => resolveFrom(fromDir, moduleId);
    module2.exports.silent = (fromDir, moduleId) => resolveFrom(fromDir, moduleId, true);
  }
});

// node_modules/callsites/index.js
var require_callsites = __commonJS({
  "node_modules/callsites/index.js"(exports, module2) {
    "use strict";
    var callsites = () => {
      const _prepareStackTrace = Error.prepareStackTrace;
      Error.prepareStackTrace = (_, stack2) => stack2;
      const stack = new Error().stack.slice(1);
      Error.prepareStackTrace = _prepareStackTrace;
      return stack;
    };
    module2.exports = callsites;
    module2.exports.default = callsites;
  }
});

// node_modules/parent-module/index.js
var require_parent_module = __commonJS({
  "node_modules/parent-module/index.js"(exports, module2) {
    "use strict";
    var callsites = require_callsites();
    module2.exports = (filepath) => {
      const stacks = callsites();
      if (!filepath) {
        return stacks[2].getFileName();
      }
      let seenVal = false;
      stacks.shift();
      for (const stack of stacks) {
        const parentFilepath = stack.getFileName();
        if (typeof parentFilepath !== "string") {
          continue;
        }
        if (parentFilepath === filepath) {
          seenVal = true;
          continue;
        }
        if (parentFilepath === "module.js") {
          continue;
        }
        if (seenVal && parentFilepath !== filepath) {
          return parentFilepath;
        }
      }
    };
  }
});

// node_modules/import-fresh/index.js
var require_import_fresh = __commonJS({
  "node_modules/import-fresh/index.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var resolveFrom = require_resolve_from();
    var parentModule = require_parent_module();
    module2.exports = (moduleId) => {
      if (typeof moduleId !== "string") {
        throw new TypeError("Expected a string");
      }
      const parentPath = parentModule(__filename);
      const cwd = parentPath ? path2.dirname(parentPath) : __dirname;
      const filePath = resolveFrom(cwd, moduleId);
      const oldModule = require.cache[filePath];
      if (oldModule && oldModule.parent) {
        let i = oldModule.parent.children.length;
        while (i--) {
          if (oldModule.parent.children[i].id === filePath) {
            oldModule.parent.children.splice(i, 1);
          }
        }
      }
      delete require.cache[filePath];
      const parent = require.cache[parentPath];
      return parent === void 0 ? require(filePath) : parent.require(filePath);
    };
  }
});

// node_modules/strip-json-comments/index.js
var require_strip_json_comments = __commonJS({
  "node_modules/strip-json-comments/index.js"(exports, module2) {
    "use strict";
    var singleComment = Symbol("singleComment");
    var multiComment = Symbol("multiComment");
    var stripWithoutWhitespace = () => "";
    var stripWithWhitespace = (string, start, end) => string.slice(start, end).replace(/\S/g, " ");
    var isEscaped = (jsonString, quotePosition) => {
      let index = quotePosition - 1;
      let backslashCount = 0;
      while (jsonString[index] === "\\") {
        index -= 1;
        backslashCount += 1;
      }
      return Boolean(backslashCount % 2);
    };
    module2.exports = (jsonString, options = {}) => {
      if (typeof jsonString !== "string") {
        throw new TypeError(`Expected argument \`jsonString\` to be a \`string\`, got \`${typeof jsonString}\``);
      }
      const strip = options.whitespace === false ? stripWithoutWhitespace : stripWithWhitespace;
      let insideString = false;
      let insideComment = false;
      let offset = 0;
      let result = "";
      for (let i = 0; i < jsonString.length; i++) {
        const currentCharacter = jsonString[i];
        const nextCharacter = jsonString[i + 1];
        if (!insideComment && currentCharacter === '"') {
          const escaped = isEscaped(jsonString, i);
          if (!escaped) {
            insideString = !insideString;
          }
        }
        if (insideString) {
          continue;
        }
        if (!insideComment && currentCharacter + nextCharacter === "//") {
          result += jsonString.slice(offset, i);
          offset = i;
          insideComment = singleComment;
          i++;
        } else if (insideComment === singleComment && currentCharacter + nextCharacter === "\r\n") {
          i++;
          insideComment = false;
          result += strip(jsonString, offset, i);
          offset = i;
          continue;
        } else if (insideComment === singleComment && currentCharacter === "\n") {
          insideComment = false;
          result += strip(jsonString, offset, i);
          offset = i;
        } else if (!insideComment && currentCharacter + nextCharacter === "/*") {
          result += jsonString.slice(offset, i);
          offset = i;
          insideComment = multiComment;
          i++;
          continue;
        } else if (insideComment === multiComment && currentCharacter + nextCharacter === "*/") {
          i++;
          insideComment = false;
          result += strip(jsonString, offset, i + 1);
          offset = i + 1;
          continue;
        }
      }
      return result + (insideComment ? strip(jsonString.slice(offset)) : jsonString.slice(offset));
    };
  }
});

// node_modules/ignore/index.js
var require_ignore = __commonJS({
  "node_modules/ignore/index.js"(exports, module2) {
    function makeArray(subject) {
      return Array.isArray(subject) ? subject : [subject];
    }
    var EMPTY = "";
    var SPACE = " ";
    var ESCAPE = "\\";
    var REGEX_TEST_BLANK_LINE = /^\s+$/;
    var REGEX_INVALID_TRAILING_BACKSLASH = /(?:[^\\]|^)\\$/;
    var REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION = /^\\!/;
    var REGEX_REPLACE_LEADING_EXCAPED_HASH = /^\\#/;
    var REGEX_SPLITALL_CRLF = /\r?\n/g;
    var REGEX_TEST_INVALID_PATH = /^\.*\/|^\.+$/;
    var SLASH = "/";
    var TMP_KEY_IGNORE = "node-ignore";
    if (typeof Symbol !== "undefined") {
      TMP_KEY_IGNORE = Symbol.for("node-ignore");
    }
    var KEY_IGNORE = TMP_KEY_IGNORE;
    var define2 = (object, key, value2) => Object.defineProperty(object, key, { value: value2 });
    var REGEX_REGEXP_RANGE = /([0-z])-([0-z])/g;
    var RETURN_FALSE = () => false;
    var sanitizeRange = (range) => range.replace(
      REGEX_REGEXP_RANGE,
      (match, from, to) => from.charCodeAt(0) <= to.charCodeAt(0) ? match : EMPTY
    );
    var cleanRangeBackSlash = (slashes) => {
      const { length } = slashes;
      return slashes.slice(0, length - length % 2);
    };
    var REPLACERS = [
      // > Trailing spaces are ignored unless they are quoted with backslash ("\")
      [
        // (a\ ) -> (a )
        // (a  ) -> (a)
        // (a \ ) -> (a  )
        /\\?\s+$/,
        (match) => match.indexOf("\\") === 0 ? SPACE : EMPTY
      ],
      // replace (\ ) with ' '
      [
        /\\\s/g,
        () => SPACE
      ],
      // Escape metacharacters
      // which is written down by users but means special for regular expressions.
      // > There are 12 characters with special meanings:
      // > - the backslash \,
      // > - the caret ^,
      // > - the dollar sign $,
      // > - the period or dot .,
      // > - the vertical bar or pipe symbol |,
      // > - the question mark ?,
      // > - the asterisk or star *,
      // > - the plus sign +,
      // > - the opening parenthesis (,
      // > - the closing parenthesis ),
      // > - and the opening square bracket [,
      // > - the opening curly brace {,
      // > These special characters are often called "metacharacters".
      [
        /[\\$.|*+(){^]/g,
        (match) => `\\${match}`
      ],
      [
        // > a question mark (?) matches a single character
        /(?!\\)\?/g,
        () => "[^/]"
      ],
      // leading slash
      [
        // > A leading slash matches the beginning of the pathname.
        // > For example, "/*.c" matches "cat-file.c" but not "mozilla-sha1/sha1.c".
        // A leading slash matches the beginning of the pathname
        /^\//,
        () => "^"
      ],
      // replace special metacharacter slash after the leading slash
      [
        /\//g,
        () => "\\/"
      ],
      [
        // > A leading "**" followed by a slash means match in all directories.
        // > For example, "**/foo" matches file or directory "foo" anywhere,
        // > the same as pattern "foo".
        // > "**/foo/bar" matches file or directory "bar" anywhere that is directly
        // >   under directory "foo".
        // Notice that the '*'s have been replaced as '\\*'
        /^\^*\\\*\\\*\\\//,
        // '**/foo' <-> 'foo'
        () => "^(?:.*\\/)?"
      ],
      // starting
      [
        // there will be no leading '/'
        //   (which has been replaced by section "leading slash")
        // If starts with '**', adding a '^' to the regular expression also works
        /^(?=[^^])/,
        function startingReplacer() {
          return !/\/(?!$)/.test(this) ? "(?:^|\\/)" : "^";
        }
      ],
      // two globstars
      [
        // Use lookahead assertions so that we could match more than one `'/**'`
        /\\\/\\\*\\\*(?=\\\/|$)/g,
        // Zero, one or several directories
        // should not use '*', or it will be replaced by the next replacer
        // Check if it is not the last `'/**'`
        (_, index, str) => index + 6 < str.length ? "(?:\\/[^\\/]+)*" : "\\/.+"
      ],
      // normal intermediate wildcards
      [
        // Never replace escaped '*'
        // ignore rule '\*' will match the path '*'
        // 'abc.*/' -> go
        // 'abc.*'  -> skip this rule,
        //    coz trailing single wildcard will be handed by [trailing wildcard]
        /(^|[^\\]+)(\\\*)+(?=.+)/g,
        // '*.js' matches '.js'
        // '*.js' doesn't match 'abc'
        (_, p1, p2) => {
          const unescaped = p2.replace(/\\\*/g, "[^\\/]*");
          return p1 + unescaped;
        }
      ],
      [
        // unescape, revert step 3 except for back slash
        // For example, if a user escape a '\\*',
        // after step 3, the result will be '\\\\\\*'
        /\\\\\\(?=[$.|*+(){^])/g,
        () => ESCAPE
      ],
      [
        // '\\\\' -> '\\'
        /\\\\/g,
        () => ESCAPE
      ],
      [
        // > The range notation, e.g. [a-zA-Z],
        // > can be used to match one of the characters in a range.
        // `\` is escaped by step 3
        /(\\)?\[([^\]/]*?)(\\*)($|\])/g,
        (match, leadEscape, range, endEscape, close) => leadEscape === ESCAPE ? `\\[${range}${cleanRangeBackSlash(endEscape)}${close}` : close === "]" ? endEscape.length % 2 === 0 ? `[${sanitizeRange(range)}${endEscape}]` : "[]" : "[]"
      ],
      // ending
      [
        // 'js' will not match 'js.'
        // 'ab' will not match 'abc'
        /(?:[^*])$/,
        // WTF!
        // https://git-scm.com/docs/gitignore
        // changes in [2.22.1](https://git-scm.com/docs/gitignore/2.22.1)
        // which re-fixes #24, #38
        // > If there is a separator at the end of the pattern then the pattern
        // > will only match directories, otherwise the pattern can match both
        // > files and directories.
        // 'js*' will not match 'a.js'
        // 'js/' will not match 'a.js'
        // 'js' will match 'a.js' and 'a.js/'
        (match) => /\/$/.test(match) ? `${match}$` : `${match}(?=$|\\/$)`
      ],
      // trailing wildcard
      [
        /(\^|\\\/)?\\\*$/,
        (_, p1) => {
          const prefix = p1 ? `${p1}[^/]+` : "[^/]*";
          return `${prefix}(?=$|\\/$)`;
        }
      ]
    ];
    var regexCache = /* @__PURE__ */ Object.create(null);
    var makeRegex = (pattern, ignoreCase) => {
      let source = regexCache[pattern];
      if (!source) {
        source = REPLACERS.reduce(
          (prev, current) => prev.replace(current[0], current[1].bind(pattern)),
          pattern
        );
        regexCache[pattern] = source;
      }
      return ignoreCase ? new RegExp(source, "i") : new RegExp(source);
    };
    var isString = (subject) => typeof subject === "string";
    var checkPattern = (pattern) => pattern && isString(pattern) && !REGEX_TEST_BLANK_LINE.test(pattern) && !REGEX_INVALID_TRAILING_BACKSLASH.test(pattern) && pattern.indexOf("#") !== 0;
    var splitPattern = (pattern) => pattern.split(REGEX_SPLITALL_CRLF);
    var IgnoreRule = class {
      constructor(origin, pattern, negative, regex) {
        this.origin = origin;
        this.pattern = pattern;
        this.negative = negative;
        this.regex = regex;
      }
    };
    var createRule = (pattern, ignoreCase) => {
      const origin = pattern;
      let negative = false;
      if (pattern.indexOf("!") === 0) {
        negative = true;
        pattern = pattern.substr(1);
      }
      pattern = pattern.replace(REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION, "!").replace(REGEX_REPLACE_LEADING_EXCAPED_HASH, "#");
      const regex = makeRegex(pattern, ignoreCase);
      return new IgnoreRule(
        origin,
        pattern,
        negative,
        regex
      );
    };
    var throwError = (message, Ctor) => {
      throw new Ctor(message);
    };
    var checkPath = (path2, originalPath, doThrow) => {
      if (!isString(path2)) {
        return doThrow(
          `path must be a string, but got \`${originalPath}\``,
          TypeError
        );
      }
      if (!path2) {
        return doThrow(`path must not be empty`, TypeError);
      }
      if (checkPath.isNotRelative(path2)) {
        const r = "`path.relative()`d";
        return doThrow(
          `path should be a ${r} string, but got "${originalPath}"`,
          RangeError
        );
      }
      return true;
    };
    var isNotRelative = (path2) => REGEX_TEST_INVALID_PATH.test(path2);
    checkPath.isNotRelative = isNotRelative;
    checkPath.convert = (p) => p;
    var Ignore = class {
      constructor({
        ignorecase = true,
        ignoreCase = ignorecase,
        allowRelativePaths = false
      } = {}) {
        define2(this, KEY_IGNORE, true);
        this._rules = [];
        this._ignoreCase = ignoreCase;
        this._allowRelativePaths = allowRelativePaths;
        this._initCache();
      }
      _initCache() {
        this._ignoreCache = /* @__PURE__ */ Object.create(null);
        this._testCache = /* @__PURE__ */ Object.create(null);
      }
      _addPattern(pattern) {
        if (pattern && pattern[KEY_IGNORE]) {
          this._rules = this._rules.concat(pattern._rules);
          this._added = true;
          return;
        }
        if (checkPattern(pattern)) {
          const rule = createRule(pattern, this._ignoreCase);
          this._added = true;
          this._rules.push(rule);
        }
      }
      // @param {Array<string> | string | Ignore} pattern
      add(pattern) {
        this._added = false;
        makeArray(
          isString(pattern) ? splitPattern(pattern) : pattern
        ).forEach(this._addPattern, this);
        if (this._added) {
          this._initCache();
        }
        return this;
      }
      // legacy
      addPattern(pattern) {
        return this.add(pattern);
      }
      //          |           ignored : unignored
      // negative |   0:0   |   0:1   |   1:0   |   1:1
      // -------- | ------- | ------- | ------- | --------
      //     0    |  TEST   |  TEST   |  SKIP   |    X
      //     1    |  TESTIF |  SKIP   |  TEST   |    X
      // - SKIP: always skip
      // - TEST: always test
      // - TESTIF: only test if checkUnignored
      // - X: that never happen
      // @param {boolean} whether should check if the path is unignored,
      //   setting `checkUnignored` to `false` could reduce additional
      //   path matching.
      // @returns {TestResult} true if a file is ignored
      _testOne(path2, checkUnignored) {
        let ignored = false;
        let unignored = false;
        this._rules.forEach((rule) => {
          const { negative } = rule;
          if (unignored === negative && ignored !== unignored || negative && !ignored && !unignored && !checkUnignored) {
            return;
          }
          const matched = rule.regex.test(path2);
          if (matched) {
            ignored = !negative;
            unignored = negative;
          }
        });
        return {
          ignored,
          unignored
        };
      }
      // @returns {TestResult}
      _test(originalPath, cache, checkUnignored, slices) {
        const path2 = originalPath && checkPath.convert(originalPath);
        checkPath(
          path2,
          originalPath,
          this._allowRelativePaths ? RETURN_FALSE : throwError
        );
        return this._t(path2, cache, checkUnignored, slices);
      }
      _t(path2, cache, checkUnignored, slices) {
        if (path2 in cache) {
          return cache[path2];
        }
        if (!slices) {
          slices = path2.split(SLASH);
        }
        slices.pop();
        if (!slices.length) {
          return cache[path2] = this._testOne(path2, checkUnignored);
        }
        const parent = this._t(
          slices.join(SLASH) + SLASH,
          cache,
          checkUnignored,
          slices
        );
        return cache[path2] = parent.ignored ? parent : this._testOne(path2, checkUnignored);
      }
      ignores(path2) {
        return this._test(path2, this._ignoreCache, false).ignored;
      }
      createFilter() {
        return (path2) => !this.ignores(path2);
      }
      filter(paths) {
        return makeArray(paths).filter(this.createFilter());
      }
      // @returns {TestResult}
      test(path2) {
        return this._test(path2, this._testCache, true);
      }
    };
    var factory = (options) => new Ignore(options);
    var isPathValid = (path2) => checkPath(path2 && checkPath.convert(path2), path2, RETURN_FALSE);
    factory.isPathValid = isPathValid;
    factory.default = factory;
    module2.exports = factory;
    if (
      // Detect `process` so that it can run in browsers.
      typeof process !== "undefined" && (process.env && process.env.IGNORE_TEST_WIN32 || process.platform === "win32")
    ) {
      const makePosix = (str) => /^\\\\\?\\/.test(str) || /["<>|\u0000-\u001F]+/u.test(str) ? str : str.replace(/\\/g, "/");
      checkPath.convert = makePosix;
      const REGIX_IS_WINDOWS_PATH_ABSOLUTE = /^[a-z]:\//i;
      checkPath.isNotRelative = (path2) => REGIX_IS_WINDOWS_PATH_ABSOLUTE.test(path2) || isNotRelative(path2);
    }
  }
});

// node_modules/uri-js/dist/es5/uri.all.js
var require_uri_all = __commonJS({
  "node_modules/uri-js/dist/es5/uri.all.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports) : typeof define === "function" && define.amd ? define(["exports"], factory) : factory(global2.URI = global2.URI || {});
    })(exports, function(exports2) {
      "use strict";
      function merge4() {
        for (var _len = arguments.length, sets = Array(_len), _key = 0; _key < _len; _key++) {
          sets[_key] = arguments[_key];
        }
        if (sets.length > 1) {
          sets[0] = sets[0].slice(0, -1);
          var xl = sets.length - 1;
          for (var x = 1; x < xl; ++x) {
            sets[x] = sets[x].slice(1, -1);
          }
          sets[xl] = sets[xl].slice(1);
          return sets.join("");
        } else {
          return sets[0];
        }
      }
      function subexp(str) {
        return "(?:" + str + ")";
      }
      function typeOf(o) {
        return o === void 0 ? "undefined" : o === null ? "null" : Object.prototype.toString.call(o).split(" ").pop().split("]").shift().toLowerCase();
      }
      function toUpperCase(str) {
        return str.toUpperCase();
      }
      function toArray(obj) {
        return obj !== void 0 && obj !== null ? obj instanceof Array ? obj : typeof obj.length !== "number" || obj.split || obj.setInterval || obj.call ? [obj] : Array.prototype.slice.call(obj) : [];
      }
      function assign(target, source) {
        var obj = target;
        if (source) {
          for (var key in source) {
            obj[key] = source[key];
          }
        }
        return obj;
      }
      function buildExps(isIRI2) {
        var ALPHA$$ = "[A-Za-z]", CR$ = "[\\x0D]", DIGIT$$ = "[0-9]", DQUOTE$$ = "[\\x22]", HEXDIG$$2 = merge4(DIGIT$$, "[A-Fa-f]"), LF$$ = "[\\x0A]", SP$$ = "[\\x20]", PCT_ENCODED$2 = subexp(subexp("%[EFef]" + HEXDIG$$2 + "%" + HEXDIG$$2 + HEXDIG$$2 + "%" + HEXDIG$$2 + HEXDIG$$2) + "|" + subexp("%[89A-Fa-f]" + HEXDIG$$2 + "%" + HEXDIG$$2 + HEXDIG$$2) + "|" + subexp("%" + HEXDIG$$2 + HEXDIG$$2)), GEN_DELIMS$$ = "[\\:\\/\\?\\#\\[\\]\\@]", SUB_DELIMS$$ = "[\\!\\$\\&\\'\\(\\)\\*\\+\\,\\;\\=]", RESERVED$$ = merge4(GEN_DELIMS$$, SUB_DELIMS$$), UCSCHAR$$ = isIRI2 ? "[\\xA0-\\u200D\\u2010-\\u2029\\u202F-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFEF]" : "[]", IPRIVATE$$ = isIRI2 ? "[\\uE000-\\uF8FF]" : "[]", UNRESERVED$$2 = merge4(ALPHA$$, DIGIT$$, "[\\-\\.\\_\\~]", UCSCHAR$$), SCHEME$ = subexp(ALPHA$$ + merge4(ALPHA$$, DIGIT$$, "[\\+\\-\\.]") + "*"), USERINFO$ = subexp(subexp(PCT_ENCODED$2 + "|" + merge4(UNRESERVED$$2, SUB_DELIMS$$, "[\\:]")) + "*"), DEC_OCTET$ = subexp(subexp("25[0-5]") + "|" + subexp("2[0-4]" + DIGIT$$) + "|" + subexp("1" + DIGIT$$ + DIGIT$$) + "|" + subexp("[1-9]" + DIGIT$$) + "|" + DIGIT$$), DEC_OCTET_RELAXED$ = subexp(subexp("25[0-5]") + "|" + subexp("2[0-4]" + DIGIT$$) + "|" + subexp("1" + DIGIT$$ + DIGIT$$) + "|" + subexp("0?[1-9]" + DIGIT$$) + "|0?0?" + DIGIT$$), IPV4ADDRESS$ = subexp(DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$ + "\\." + DEC_OCTET_RELAXED$), H16$ = subexp(HEXDIG$$2 + "{1,4}"), LS32$ = subexp(subexp(H16$ + "\\:" + H16$) + "|" + IPV4ADDRESS$), IPV6ADDRESS1$ = subexp(subexp(H16$ + "\\:") + "{6}" + LS32$), IPV6ADDRESS2$ = subexp("\\:\\:" + subexp(H16$ + "\\:") + "{5}" + LS32$), IPV6ADDRESS3$ = subexp(subexp(H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{4}" + LS32$), IPV6ADDRESS4$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,1}" + H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{3}" + LS32$), IPV6ADDRESS5$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,2}" + H16$) + "?\\:\\:" + subexp(H16$ + "\\:") + "{2}" + LS32$), IPV6ADDRESS6$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,3}" + H16$) + "?\\:\\:" + H16$ + "\\:" + LS32$), IPV6ADDRESS7$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,4}" + H16$) + "?\\:\\:" + LS32$), IPV6ADDRESS8$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,5}" + H16$) + "?\\:\\:" + H16$), IPV6ADDRESS9$ = subexp(subexp(subexp(H16$ + "\\:") + "{0,6}" + H16$) + "?\\:\\:"), IPV6ADDRESS$ = subexp([IPV6ADDRESS1$, IPV6ADDRESS2$, IPV6ADDRESS3$, IPV6ADDRESS4$, IPV6ADDRESS5$, IPV6ADDRESS6$, IPV6ADDRESS7$, IPV6ADDRESS8$, IPV6ADDRESS9$].join("|")), ZONEID$ = subexp(subexp(UNRESERVED$$2 + "|" + PCT_ENCODED$2) + "+"), IPV6ADDRZ$ = subexp(IPV6ADDRESS$ + "\\%25" + ZONEID$), IPV6ADDRZ_RELAXED$ = subexp(IPV6ADDRESS$ + subexp("\\%25|\\%(?!" + HEXDIG$$2 + "{2})") + ZONEID$), IPVFUTURE$ = subexp("[vV]" + HEXDIG$$2 + "+\\." + merge4(UNRESERVED$$2, SUB_DELIMS$$, "[\\:]") + "+"), IP_LITERAL$ = subexp("\\[" + subexp(IPV6ADDRZ_RELAXED$ + "|" + IPV6ADDRESS$ + "|" + IPVFUTURE$) + "\\]"), REG_NAME$ = subexp(subexp(PCT_ENCODED$2 + "|" + merge4(UNRESERVED$$2, SUB_DELIMS$$)) + "*"), HOST$ = subexp(IP_LITERAL$ + "|" + IPV4ADDRESS$ + "(?!" + REG_NAME$ + ")|" + REG_NAME$), PORT$ = subexp(DIGIT$$ + "*"), AUTHORITY$ = subexp(subexp(USERINFO$ + "@") + "?" + HOST$ + subexp("\\:" + PORT$) + "?"), PCHAR$ = subexp(PCT_ENCODED$2 + "|" + merge4(UNRESERVED$$2, SUB_DELIMS$$, "[\\:\\@]")), SEGMENT$ = subexp(PCHAR$ + "*"), SEGMENT_NZ$ = subexp(PCHAR$ + "+"), SEGMENT_NZ_NC$ = subexp(subexp(PCT_ENCODED$2 + "|" + merge4(UNRESERVED$$2, SUB_DELIMS$$, "[\\@]")) + "+"), PATH_ABEMPTY$ = subexp(subexp("\\/" + SEGMENT$) + "*"), PATH_ABSOLUTE$ = subexp("\\/" + subexp(SEGMENT_NZ$ + PATH_ABEMPTY$) + "?"), PATH_NOSCHEME$ = subexp(SEGMENT_NZ_NC$ + PATH_ABEMPTY$), PATH_ROOTLESS$ = subexp(SEGMENT_NZ$ + PATH_ABEMPTY$), PATH_EMPTY$ = "(?!" + PCHAR$ + ")", PATH$ = subexp(PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$), QUERY$ = subexp(subexp(PCHAR$ + "|" + merge4("[\\/\\?]", IPRIVATE$$)) + "*"), FRAGMENT$ = subexp(subexp(PCHAR$ + "|[\\/\\?]") + "*"), HIER_PART$ = subexp(subexp("\\/\\/" + AUTHORITY$ + PATH_ABEMPTY$) + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$), URI$ = subexp(SCHEME$ + "\\:" + HIER_PART$ + subexp("\\?" + QUERY$) + "?" + subexp("\\#" + FRAGMENT$) + "?"), RELATIVE_PART$ = subexp(subexp("\\/\\/" + AUTHORITY$ + PATH_ABEMPTY$) + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_EMPTY$), RELATIVE$ = subexp(RELATIVE_PART$ + subexp("\\?" + QUERY$) + "?" + subexp("\\#" + FRAGMENT$) + "?"), URI_REFERENCE$ = subexp(URI$ + "|" + RELATIVE$), ABSOLUTE_URI$ = subexp(SCHEME$ + "\\:" + HIER_PART$ + subexp("\\?" + QUERY$) + "?"), GENERIC_REF$ = "^(" + SCHEME$ + ")\\:" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", RELATIVE_REF$ = "^(){0}" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_NOSCHEME$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", ABSOLUTE_REF$ = "^(" + SCHEME$ + ")\\:" + subexp(subexp("\\/\\/(" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?)") + "?(" + PATH_ABEMPTY$ + "|" + PATH_ABSOLUTE$ + "|" + PATH_ROOTLESS$ + "|" + PATH_EMPTY$ + ")") + subexp("\\?(" + QUERY$ + ")") + "?$", SAMEDOC_REF$ = "^" + subexp("\\#(" + FRAGMENT$ + ")") + "?$", AUTHORITY_REF$ = "^" + subexp("(" + USERINFO$ + ")@") + "?(" + HOST$ + ")" + subexp("\\:(" + PORT$ + ")") + "?$";
        return {
          NOT_SCHEME: new RegExp(merge4("[^]", ALPHA$$, DIGIT$$, "[\\+\\-\\.]"), "g"),
          NOT_USERINFO: new RegExp(merge4("[^\\%\\:]", UNRESERVED$$2, SUB_DELIMS$$), "g"),
          NOT_HOST: new RegExp(merge4("[^\\%\\[\\]\\:]", UNRESERVED$$2, SUB_DELIMS$$), "g"),
          NOT_PATH: new RegExp(merge4("[^\\%\\/\\:\\@]", UNRESERVED$$2, SUB_DELIMS$$), "g"),
          NOT_PATH_NOSCHEME: new RegExp(merge4("[^\\%\\/\\@]", UNRESERVED$$2, SUB_DELIMS$$), "g"),
          NOT_QUERY: new RegExp(merge4("[^\\%]", UNRESERVED$$2, SUB_DELIMS$$, "[\\:\\@\\/\\?]", IPRIVATE$$), "g"),
          NOT_FRAGMENT: new RegExp(merge4("[^\\%]", UNRESERVED$$2, SUB_DELIMS$$, "[\\:\\@\\/\\?]"), "g"),
          ESCAPE: new RegExp(merge4("[^]", UNRESERVED$$2, SUB_DELIMS$$), "g"),
          UNRESERVED: new RegExp(UNRESERVED$$2, "g"),
          OTHER_CHARS: new RegExp(merge4("[^\\%]", UNRESERVED$$2, RESERVED$$), "g"),
          PCT_ENCODED: new RegExp(PCT_ENCODED$2, "g"),
          IPV4ADDRESS: new RegExp("^(" + IPV4ADDRESS$ + ")$"),
          IPV6ADDRESS: new RegExp("^\\[?(" + IPV6ADDRESS$ + ")" + subexp(subexp("\\%25|\\%(?!" + HEXDIG$$2 + "{2})") + "(" + ZONEID$ + ")") + "?\\]?$")
          //RFC 6874, with relaxed parsing rules
        };
      }
      var URI_PROTOCOL = buildExps(false);
      var IRI_PROTOCOL = buildExps(true);
      var slicedToArray = function() {
        function sliceIterator(arr, i) {
          var _arr = [];
          var _n = true;
          var _d = false;
          var _e = void 0;
          try {
            for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
              _arr.push(_s.value);
              if (i && _arr.length === i)
                break;
            }
          } catch (err) {
            _d = true;
            _e = err;
          } finally {
            try {
              if (!_n && _i["return"])
                _i["return"]();
            } finally {
              if (_d)
                throw _e;
            }
          }
          return _arr;
        }
        return function(arr, i) {
          if (Array.isArray(arr)) {
            return arr;
          } else if (Symbol.iterator in Object(arr)) {
            return sliceIterator(arr, i);
          } else {
            throw new TypeError("Invalid attempt to destructure non-iterable instance");
          }
        };
      }();
      var toConsumableArray = function(arr) {
        if (Array.isArray(arr)) {
          for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++)
            arr2[i] = arr[i];
          return arr2;
        } else {
          return Array.from(arr);
        }
      };
      var maxInt = 2147483647;
      var base = 36;
      var tMin = 1;
      var tMax = 26;
      var skew = 38;
      var damp = 700;
      var initialBias = 72;
      var initialN = 128;
      var delimiter = "-";
      var regexPunycode = /^xn--/;
      var regexNonASCII = /[^\0-\x7E]/;
      var regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g;
      var errors = {
        "overflow": "Overflow: input needs wider integers to process",
        "not-basic": "Illegal input >= 0x80 (not a basic code point)",
        "invalid-input": "Invalid input"
      };
      var baseMinusTMin = base - tMin;
      var floor = Math.floor;
      var stringFromCharCode = String.fromCharCode;
      function error$1(type) {
        throw new RangeError(errors[type]);
      }
      function map(array, fn) {
        var result = [];
        var length = array.length;
        while (length--) {
          result[length] = fn(array[length]);
        }
        return result;
      }
      function mapDomain(string, fn) {
        var parts = string.split("@");
        var result = "";
        if (parts.length > 1) {
          result = parts[0] + "@";
          string = parts[1];
        }
        string = string.replace(regexSeparators, ".");
        var labels = string.split(".");
        var encoded = map(labels, fn).join(".");
        return result + encoded;
      }
      function ucs2decode(string) {
        var output = [];
        var counter = 0;
        var length = string.length;
        while (counter < length) {
          var value2 = string.charCodeAt(counter++);
          if (value2 >= 55296 && value2 <= 56319 && counter < length) {
            var extra = string.charCodeAt(counter++);
            if ((extra & 64512) == 56320) {
              output.push(((value2 & 1023) << 10) + (extra & 1023) + 65536);
            } else {
              output.push(value2);
              counter--;
            }
          } else {
            output.push(value2);
          }
        }
        return output;
      }
      var ucs2encode = function ucs2encode2(array) {
        return String.fromCodePoint.apply(String, toConsumableArray(array));
      };
      var basicToDigit = function basicToDigit2(codePoint) {
        if (codePoint - 48 < 10) {
          return codePoint - 22;
        }
        if (codePoint - 65 < 26) {
          return codePoint - 65;
        }
        if (codePoint - 97 < 26) {
          return codePoint - 97;
        }
        return base;
      };
      var digitToBasic = function digitToBasic2(digit, flag) {
        return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
      };
      var adapt = function adapt2(delta, numPoints, firstTime) {
        var k = 0;
        delta = firstTime ? floor(delta / damp) : delta >> 1;
        delta += floor(delta / numPoints);
        for (
          ;
          /* no initialization */
          delta > baseMinusTMin * tMax >> 1;
          k += base
        ) {
          delta = floor(delta / baseMinusTMin);
        }
        return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
      };
      var decode = function decode2(input) {
        var output = [];
        var inputLength = input.length;
        var i = 0;
        var n = initialN;
        var bias = initialBias;
        var basic = input.lastIndexOf(delimiter);
        if (basic < 0) {
          basic = 0;
        }
        for (var j = 0; j < basic; ++j) {
          if (input.charCodeAt(j) >= 128) {
            error$1("not-basic");
          }
          output.push(input.charCodeAt(j));
        }
        for (var index = basic > 0 ? basic + 1 : 0; index < inputLength; ) {
          var oldi = i;
          for (
            var w = 1, k = base;
            ;
            /* no condition */
            k += base
          ) {
            if (index >= inputLength) {
              error$1("invalid-input");
            }
            var digit = basicToDigit(input.charCodeAt(index++));
            if (digit >= base || digit > floor((maxInt - i) / w)) {
              error$1("overflow");
            }
            i += digit * w;
            var t3 = k <= bias ? tMin : k >= bias + tMax ? tMax : k - bias;
            if (digit < t3) {
              break;
            }
            var baseMinusT = base - t3;
            if (w > floor(maxInt / baseMinusT)) {
              error$1("overflow");
            }
            w *= baseMinusT;
          }
          var out = output.length + 1;
          bias = adapt(i - oldi, out, oldi == 0);
          if (floor(i / out) > maxInt - n) {
            error$1("overflow");
          }
          n += floor(i / out);
          i %= out;
          output.splice(i++, 0, n);
        }
        return String.fromCodePoint.apply(String, output);
      };
      var encode = function encode2(input) {
        var output = [];
        input = ucs2decode(input);
        var inputLength = input.length;
        var n = initialN;
        var delta = 0;
        var bias = initialBias;
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = void 0;
        try {
          for (var _iterator = input[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var _currentValue2 = _step.value;
            if (_currentValue2 < 128) {
              output.push(stringFromCharCode(_currentValue2));
            }
          }
        } catch (err) {
          _didIteratorError = true;
          _iteratorError = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }
          } finally {
            if (_didIteratorError) {
              throw _iteratorError;
            }
          }
        }
        var basicLength = output.length;
        var handledCPCount = basicLength;
        if (basicLength) {
          output.push(delimiter);
        }
        while (handledCPCount < inputLength) {
          var m = maxInt;
          var _iteratorNormalCompletion2 = true;
          var _didIteratorError2 = false;
          var _iteratorError2 = void 0;
          try {
            for (var _iterator2 = input[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
              var currentValue = _step2.value;
              if (currentValue >= n && currentValue < m) {
                m = currentValue;
              }
            }
          } catch (err) {
            _didIteratorError2 = true;
            _iteratorError2 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion2 && _iterator2.return) {
                _iterator2.return();
              }
            } finally {
              if (_didIteratorError2) {
                throw _iteratorError2;
              }
            }
          }
          var handledCPCountPlusOne = handledCPCount + 1;
          if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
            error$1("overflow");
          }
          delta += (m - n) * handledCPCountPlusOne;
          n = m;
          var _iteratorNormalCompletion3 = true;
          var _didIteratorError3 = false;
          var _iteratorError3 = void 0;
          try {
            for (var _iterator3 = input[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
              var _currentValue = _step3.value;
              if (_currentValue < n && ++delta > maxInt) {
                error$1("overflow");
              }
              if (_currentValue == n) {
                var q = delta;
                for (
                  var k = base;
                  ;
                  /* no condition */
                  k += base
                ) {
                  var t3 = k <= bias ? tMin : k >= bias + tMax ? tMax : k - bias;
                  if (q < t3) {
                    break;
                  }
                  var qMinusT = q - t3;
                  var baseMinusT = base - t3;
                  output.push(stringFromCharCode(digitToBasic(t3 + qMinusT % baseMinusT, 0)));
                  q = floor(qMinusT / baseMinusT);
                }
                output.push(stringFromCharCode(digitToBasic(q, 0)));
                bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
                delta = 0;
                ++handledCPCount;
              }
            }
          } catch (err) {
            _didIteratorError3 = true;
            _iteratorError3 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion3 && _iterator3.return) {
                _iterator3.return();
              }
            } finally {
              if (_didIteratorError3) {
                throw _iteratorError3;
              }
            }
          }
          ++delta;
          ++n;
        }
        return output.join("");
      };
      var toUnicode = function toUnicode2(input) {
        return mapDomain(input, function(string) {
          return regexPunycode.test(string) ? decode(string.slice(4).toLowerCase()) : string;
        });
      };
      var toASCII = function toASCII2(input) {
        return mapDomain(input, function(string) {
          return regexNonASCII.test(string) ? "xn--" + encode(string) : string;
        });
      };
      var punycode = {
        /**
         * A string representing the current Punycode.js version number.
         * @memberOf punycode
         * @type String
         */
        "version": "2.1.0",
        /**
         * An object of methods to convert from JavaScript's internal character
         * representation (UCS-2) to Unicode code points, and back.
         * @see <https://mathiasbynens.be/notes/javascript-encoding>
         * @memberOf punycode
         * @type Object
         */
        "ucs2": {
          "decode": ucs2decode,
          "encode": ucs2encode
        },
        "decode": decode,
        "encode": encode,
        "toASCII": toASCII,
        "toUnicode": toUnicode
      };
      var SCHEMES = {};
      function pctEncChar(chr) {
        var c = chr.charCodeAt(0);
        var e = void 0;
        if (c < 16)
          e = "%0" + c.toString(16).toUpperCase();
        else if (c < 128)
          e = "%" + c.toString(16).toUpperCase();
        else if (c < 2048)
          e = "%" + (c >> 6 | 192).toString(16).toUpperCase() + "%" + (c & 63 | 128).toString(16).toUpperCase();
        else
          e = "%" + (c >> 12 | 224).toString(16).toUpperCase() + "%" + (c >> 6 & 63 | 128).toString(16).toUpperCase() + "%" + (c & 63 | 128).toString(16).toUpperCase();
        return e;
      }
      function pctDecChars(str) {
        var newStr = "";
        var i = 0;
        var il = str.length;
        while (i < il) {
          var c = parseInt(str.substr(i + 1, 2), 16);
          if (c < 128) {
            newStr += String.fromCharCode(c);
            i += 3;
          } else if (c >= 194 && c < 224) {
            if (il - i >= 6) {
              var c2 = parseInt(str.substr(i + 4, 2), 16);
              newStr += String.fromCharCode((c & 31) << 6 | c2 & 63);
            } else {
              newStr += str.substr(i, 6);
            }
            i += 6;
          } else if (c >= 224) {
            if (il - i >= 9) {
              var _c = parseInt(str.substr(i + 4, 2), 16);
              var c3 = parseInt(str.substr(i + 7, 2), 16);
              newStr += String.fromCharCode((c & 15) << 12 | (_c & 63) << 6 | c3 & 63);
            } else {
              newStr += str.substr(i, 9);
            }
            i += 9;
          } else {
            newStr += str.substr(i, 3);
            i += 3;
          }
        }
        return newStr;
      }
      function _normalizeComponentEncoding(components, protocol) {
        function decodeUnreserved2(str) {
          var decStr = pctDecChars(str);
          return !decStr.match(protocol.UNRESERVED) ? str : decStr;
        }
        if (components.scheme)
          components.scheme = String(components.scheme).replace(protocol.PCT_ENCODED, decodeUnreserved2).toLowerCase().replace(protocol.NOT_SCHEME, "");
        if (components.userinfo !== void 0)
          components.userinfo = String(components.userinfo).replace(protocol.PCT_ENCODED, decodeUnreserved2).replace(protocol.NOT_USERINFO, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
        if (components.host !== void 0)
          components.host = String(components.host).replace(protocol.PCT_ENCODED, decodeUnreserved2).toLowerCase().replace(protocol.NOT_HOST, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
        if (components.path !== void 0)
          components.path = String(components.path).replace(protocol.PCT_ENCODED, decodeUnreserved2).replace(components.scheme ? protocol.NOT_PATH : protocol.NOT_PATH_NOSCHEME, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
        if (components.query !== void 0)
          components.query = String(components.query).replace(protocol.PCT_ENCODED, decodeUnreserved2).replace(protocol.NOT_QUERY, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
        if (components.fragment !== void 0)
          components.fragment = String(components.fragment).replace(protocol.PCT_ENCODED, decodeUnreserved2).replace(protocol.NOT_FRAGMENT, pctEncChar).replace(protocol.PCT_ENCODED, toUpperCase);
        return components;
      }
      function _stripLeadingZeros(str) {
        return str.replace(/^0*(.*)/, "$1") || "0";
      }
      function _normalizeIPv4(host, protocol) {
        var matches = host.match(protocol.IPV4ADDRESS) || [];
        var _matches = slicedToArray(matches, 2), address = _matches[1];
        if (address) {
          return address.split(".").map(_stripLeadingZeros).join(".");
        } else {
          return host;
        }
      }
      function _normalizeIPv6(host, protocol) {
        var matches = host.match(protocol.IPV6ADDRESS) || [];
        var _matches2 = slicedToArray(matches, 3), address = _matches2[1], zone = _matches2[2];
        if (address) {
          var _address$toLowerCase$ = address.toLowerCase().split("::").reverse(), _address$toLowerCase$2 = slicedToArray(_address$toLowerCase$, 2), last2 = _address$toLowerCase$2[0], first2 = _address$toLowerCase$2[1];
          var firstFields = first2 ? first2.split(":").map(_stripLeadingZeros) : [];
          var lastFields = last2.split(":").map(_stripLeadingZeros);
          var isLastFieldIPv4Address = protocol.IPV4ADDRESS.test(lastFields[lastFields.length - 1]);
          var fieldCount = isLastFieldIPv4Address ? 7 : 8;
          var lastFieldsStart = lastFields.length - fieldCount;
          var fields = Array(fieldCount);
          for (var x = 0; x < fieldCount; ++x) {
            fields[x] = firstFields[x] || lastFields[lastFieldsStart + x] || "";
          }
          if (isLastFieldIPv4Address) {
            fields[fieldCount - 1] = _normalizeIPv4(fields[fieldCount - 1], protocol);
          }
          var allZeroFields = fields.reduce(function(acc, field, index) {
            if (!field || field === "0") {
              var lastLongest = acc[acc.length - 1];
              if (lastLongest && lastLongest.index + lastLongest.length === index) {
                lastLongest.length++;
              } else {
                acc.push({ index, length: 1 });
              }
            }
            return acc;
          }, []);
          var longestZeroFields = allZeroFields.sort(function(a, b) {
            return b.length - a.length;
          })[0];
          var newHost = void 0;
          if (longestZeroFields && longestZeroFields.length > 1) {
            var newFirst = fields.slice(0, longestZeroFields.index);
            var newLast = fields.slice(longestZeroFields.index + longestZeroFields.length);
            newHost = newFirst.join(":") + "::" + newLast.join(":");
          } else {
            newHost = fields.join(":");
          }
          if (zone) {
            newHost += "%" + zone;
          }
          return newHost;
        } else {
          return host;
        }
      }
      var URI_PARSE = /^(?:([^:\/?#]+):)?(?:\/\/((?:([^\/?#@]*)@)?(\[[^\/?#\]]+\]|[^\/?#:]*)(?:\:(\d*))?))?([^?#]*)(?:\?([^#]*))?(?:#((?:.|\n|\r)*))?/i;
      var NO_MATCH_IS_UNDEFINED = "".match(/(){0}/)[1] === void 0;
      function parse3(uriString) {
        var options = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
        var components = {};
        var protocol = options.iri !== false ? IRI_PROTOCOL : URI_PROTOCOL;
        if (options.reference === "suffix")
          uriString = (options.scheme ? options.scheme + ":" : "") + "//" + uriString;
        var matches = uriString.match(URI_PARSE);
        if (matches) {
          if (NO_MATCH_IS_UNDEFINED) {
            components.scheme = matches[1];
            components.userinfo = matches[3];
            components.host = matches[4];
            components.port = parseInt(matches[5], 10);
            components.path = matches[6] || "";
            components.query = matches[7];
            components.fragment = matches[8];
            if (isNaN(components.port)) {
              components.port = matches[5];
            }
          } else {
            components.scheme = matches[1] || void 0;
            components.userinfo = uriString.indexOf("@") !== -1 ? matches[3] : void 0;
            components.host = uriString.indexOf("//") !== -1 ? matches[4] : void 0;
            components.port = parseInt(matches[5], 10);
            components.path = matches[6] || "";
            components.query = uriString.indexOf("?") !== -1 ? matches[7] : void 0;
            components.fragment = uriString.indexOf("#") !== -1 ? matches[8] : void 0;
            if (isNaN(components.port)) {
              components.port = uriString.match(/\/\/(?:.|\n)*\:(?:\/|\?|\#|$)/) ? matches[4] : void 0;
            }
          }
          if (components.host) {
            components.host = _normalizeIPv6(_normalizeIPv4(components.host, protocol), protocol);
          }
          if (components.scheme === void 0 && components.userinfo === void 0 && components.host === void 0 && components.port === void 0 && !components.path && components.query === void 0) {
            components.reference = "same-document";
          } else if (components.scheme === void 0) {
            components.reference = "relative";
          } else if (components.fragment === void 0) {
            components.reference = "absolute";
          } else {
            components.reference = "uri";
          }
          if (options.reference && options.reference !== "suffix" && options.reference !== components.reference) {
            components.error = components.error || "URI is not a " + options.reference + " reference.";
          }
          var schemeHandler = SCHEMES[(options.scheme || components.scheme || "").toLowerCase()];
          if (!options.unicodeSupport && (!schemeHandler || !schemeHandler.unicodeSupport)) {
            if (components.host && (options.domainHost || schemeHandler && schemeHandler.domainHost)) {
              try {
                components.host = punycode.toASCII(components.host.replace(protocol.PCT_ENCODED, pctDecChars).toLowerCase());
              } catch (e) {
                components.error = components.error || "Host's domain name can not be converted to ASCII via punycode: " + e;
              }
            }
            _normalizeComponentEncoding(components, URI_PROTOCOL);
          } else {
            _normalizeComponentEncoding(components, protocol);
          }
          if (schemeHandler && schemeHandler.parse) {
            schemeHandler.parse(components, options);
          }
        } else {
          components.error = components.error || "URI can not be parsed.";
        }
        return components;
      }
      function _recomposeAuthority(components, options) {
        var protocol = options.iri !== false ? IRI_PROTOCOL : URI_PROTOCOL;
        var uriTokens = [];
        if (components.userinfo !== void 0) {
          uriTokens.push(components.userinfo);
          uriTokens.push("@");
        }
        if (components.host !== void 0) {
          uriTokens.push(_normalizeIPv6(_normalizeIPv4(String(components.host), protocol), protocol).replace(protocol.IPV6ADDRESS, function(_, $1, $2) {
            return "[" + $1 + ($2 ? "%25" + $2 : "") + "]";
          }));
        }
        if (typeof components.port === "number" || typeof components.port === "string") {
          uriTokens.push(":");
          uriTokens.push(String(components.port));
        }
        return uriTokens.length ? uriTokens.join("") : void 0;
      }
      var RDS1 = /^\.\.?\//;
      var RDS2 = /^\/\.(\/|$)/;
      var RDS3 = /^\/\.\.(\/|$)/;
      var RDS5 = /^\/?(?:.|\n)*?(?=\/|$)/;
      function removeDotSegments(input) {
        var output = [];
        while (input.length) {
          if (input.match(RDS1)) {
            input = input.replace(RDS1, "");
          } else if (input.match(RDS2)) {
            input = input.replace(RDS2, "/");
          } else if (input.match(RDS3)) {
            input = input.replace(RDS3, "/");
            output.pop();
          } else if (input === "." || input === "..") {
            input = "";
          } else {
            var im = input.match(RDS5);
            if (im) {
              var s = im[0];
              input = input.slice(s.length);
              output.push(s);
            } else {
              throw new Error("Unexpected dot segment condition");
            }
          }
        }
        return output.join("");
      }
      function serialize(components) {
        var options = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
        var protocol = options.iri ? IRI_PROTOCOL : URI_PROTOCOL;
        var uriTokens = [];
        var schemeHandler = SCHEMES[(options.scheme || components.scheme || "").toLowerCase()];
        if (schemeHandler && schemeHandler.serialize)
          schemeHandler.serialize(components, options);
        if (components.host) {
          if (protocol.IPV6ADDRESS.test(components.host)) {
          } else if (options.domainHost || schemeHandler && schemeHandler.domainHost) {
            try {
              components.host = !options.iri ? punycode.toASCII(components.host.replace(protocol.PCT_ENCODED, pctDecChars).toLowerCase()) : punycode.toUnicode(components.host);
            } catch (e) {
              components.error = components.error || "Host's domain name can not be converted to " + (!options.iri ? "ASCII" : "Unicode") + " via punycode: " + e;
            }
          }
        }
        _normalizeComponentEncoding(components, protocol);
        if (options.reference !== "suffix" && components.scheme) {
          uriTokens.push(components.scheme);
          uriTokens.push(":");
        }
        var authority = _recomposeAuthority(components, options);
        if (authority !== void 0) {
          if (options.reference !== "suffix") {
            uriTokens.push("//");
          }
          uriTokens.push(authority);
          if (components.path && components.path.charAt(0) !== "/") {
            uriTokens.push("/");
          }
        }
        if (components.path !== void 0) {
          var s = components.path;
          if (!options.absolutePath && (!schemeHandler || !schemeHandler.absolutePath)) {
            s = removeDotSegments(s);
          }
          if (authority === void 0) {
            s = s.replace(/^\/\//, "/%2F");
          }
          uriTokens.push(s);
        }
        if (components.query !== void 0) {
          uriTokens.push("?");
          uriTokens.push(components.query);
        }
        if (components.fragment !== void 0) {
          uriTokens.push("#");
          uriTokens.push(components.fragment);
        }
        return uriTokens.join("");
      }
      function resolveComponents(base2, relative) {
        var options = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
        var skipNormalization = arguments[3];
        var target = {};
        if (!skipNormalization) {
          base2 = parse3(serialize(base2, options), options);
          relative = parse3(serialize(relative, options), options);
        }
        options = options || {};
        if (!options.tolerant && relative.scheme) {
          target.scheme = relative.scheme;
          target.userinfo = relative.userinfo;
          target.host = relative.host;
          target.port = relative.port;
          target.path = removeDotSegments(relative.path || "");
          target.query = relative.query;
        } else {
          if (relative.userinfo !== void 0 || relative.host !== void 0 || relative.port !== void 0) {
            target.userinfo = relative.userinfo;
            target.host = relative.host;
            target.port = relative.port;
            target.path = removeDotSegments(relative.path || "");
            target.query = relative.query;
          } else {
            if (!relative.path) {
              target.path = base2.path;
              if (relative.query !== void 0) {
                target.query = relative.query;
              } else {
                target.query = base2.query;
              }
            } else {
              if (relative.path.charAt(0) === "/") {
                target.path = removeDotSegments(relative.path);
              } else {
                if ((base2.userinfo !== void 0 || base2.host !== void 0 || base2.port !== void 0) && !base2.path) {
                  target.path = "/" + relative.path;
                } else if (!base2.path) {
                  target.path = relative.path;
                } else {
                  target.path = base2.path.slice(0, base2.path.lastIndexOf("/") + 1) + relative.path;
                }
                target.path = removeDotSegments(target.path);
              }
              target.query = relative.query;
            }
            target.userinfo = base2.userinfo;
            target.host = base2.host;
            target.port = base2.port;
          }
          target.scheme = base2.scheme;
        }
        target.fragment = relative.fragment;
        return target;
      }
      function resolve(baseURI, relativeURI, options) {
        var schemelessOptions = assign({ scheme: "null" }, options);
        return serialize(resolveComponents(parse3(baseURI, schemelessOptions), parse3(relativeURI, schemelessOptions), schemelessOptions, true), schemelessOptions);
      }
      function normalize(uri, options) {
        if (typeof uri === "string") {
          uri = serialize(parse3(uri, options), options);
        } else if (typeOf(uri) === "object") {
          uri = parse3(serialize(uri, options), options);
        }
        return uri;
      }
      function equal(uriA, uriB, options) {
        if (typeof uriA === "string") {
          uriA = serialize(parse3(uriA, options), options);
        } else if (typeOf(uriA) === "object") {
          uriA = serialize(uriA, options);
        }
        if (typeof uriB === "string") {
          uriB = serialize(parse3(uriB, options), options);
        } else if (typeOf(uriB) === "object") {
          uriB = serialize(uriB, options);
        }
        return uriA === uriB;
      }
      function escapeComponent(str, options) {
        return str && str.toString().replace(!options || !options.iri ? URI_PROTOCOL.ESCAPE : IRI_PROTOCOL.ESCAPE, pctEncChar);
      }
      function unescapeComponent(str, options) {
        return str && str.toString().replace(!options || !options.iri ? URI_PROTOCOL.PCT_ENCODED : IRI_PROTOCOL.PCT_ENCODED, pctDecChars);
      }
      var handler = {
        scheme: "http",
        domainHost: true,
        parse: function parse4(components, options) {
          if (!components.host) {
            components.error = components.error || "HTTP URIs must have a host.";
          }
          return components;
        },
        serialize: function serialize2(components, options) {
          var secure = String(components.scheme).toLowerCase() === "https";
          if (components.port === (secure ? 443 : 80) || components.port === "") {
            components.port = void 0;
          }
          if (!components.path) {
            components.path = "/";
          }
          return components;
        }
      };
      var handler$1 = {
        scheme: "https",
        domainHost: handler.domainHost,
        parse: handler.parse,
        serialize: handler.serialize
      };
      function isSecure(wsComponents) {
        return typeof wsComponents.secure === "boolean" ? wsComponents.secure : String(wsComponents.scheme).toLowerCase() === "wss";
      }
      var handler$2 = {
        scheme: "ws",
        domainHost: true,
        parse: function parse4(components, options) {
          var wsComponents = components;
          wsComponents.secure = isSecure(wsComponents);
          wsComponents.resourceName = (wsComponents.path || "/") + (wsComponents.query ? "?" + wsComponents.query : "");
          wsComponents.path = void 0;
          wsComponents.query = void 0;
          return wsComponents;
        },
        serialize: function serialize2(wsComponents, options) {
          if (wsComponents.port === (isSecure(wsComponents) ? 443 : 80) || wsComponents.port === "") {
            wsComponents.port = void 0;
          }
          if (typeof wsComponents.secure === "boolean") {
            wsComponents.scheme = wsComponents.secure ? "wss" : "ws";
            wsComponents.secure = void 0;
          }
          if (wsComponents.resourceName) {
            var _wsComponents$resourc = wsComponents.resourceName.split("?"), _wsComponents$resourc2 = slicedToArray(_wsComponents$resourc, 2), path2 = _wsComponents$resourc2[0], query = _wsComponents$resourc2[1];
            wsComponents.path = path2 && path2 !== "/" ? path2 : void 0;
            wsComponents.query = query;
            wsComponents.resourceName = void 0;
          }
          wsComponents.fragment = void 0;
          return wsComponents;
        }
      };
      var handler$3 = {
        scheme: "wss",
        domainHost: handler$2.domainHost,
        parse: handler$2.parse,
        serialize: handler$2.serialize
      };
      var O = {};
      var isIRI = true;
      var UNRESERVED$$ = "[A-Za-z0-9\\-\\.\\_\\~" + (isIRI ? "\\xA0-\\u200D\\u2010-\\u2029\\u202F-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFEF" : "") + "]";
      var HEXDIG$$ = "[0-9A-Fa-f]";
      var PCT_ENCODED$ = subexp(subexp("%[EFef]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%[89A-Fa-f]" + HEXDIG$$ + "%" + HEXDIG$$ + HEXDIG$$) + "|" + subexp("%" + HEXDIG$$ + HEXDIG$$));
      var ATEXT$$ = "[A-Za-z0-9\\!\\$\\%\\'\\*\\+\\-\\^\\_\\`\\{\\|\\}\\~]";
      var QTEXT$$ = "[\\!\\$\\%\\'\\(\\)\\*\\+\\,\\-\\.0-9\\<\\>A-Z\\x5E-\\x7E]";
      var VCHAR$$ = merge4(QTEXT$$, '[\\"\\\\]');
      var SOME_DELIMS$$ = "[\\!\\$\\'\\(\\)\\*\\+\\,\\;\\:\\@]";
      var UNRESERVED = new RegExp(UNRESERVED$$, "g");
      var PCT_ENCODED = new RegExp(PCT_ENCODED$, "g");
      var NOT_LOCAL_PART = new RegExp(merge4("[^]", ATEXT$$, "[\\.]", '[\\"]', VCHAR$$), "g");
      var NOT_HFNAME = new RegExp(merge4("[^]", UNRESERVED$$, SOME_DELIMS$$), "g");
      var NOT_HFVALUE = NOT_HFNAME;
      function decodeUnreserved(str) {
        var decStr = pctDecChars(str);
        return !decStr.match(UNRESERVED) ? str : decStr;
      }
      var handler$4 = {
        scheme: "mailto",
        parse: function parse$$1(components, options) {
          var mailtoComponents = components;
          var to = mailtoComponents.to = mailtoComponents.path ? mailtoComponents.path.split(",") : [];
          mailtoComponents.path = void 0;
          if (mailtoComponents.query) {
            var unknownHeaders = false;
            var headers = {};
            var hfields = mailtoComponents.query.split("&");
            for (var x = 0, xl = hfields.length; x < xl; ++x) {
              var hfield = hfields[x].split("=");
              switch (hfield[0]) {
                case "to":
                  var toAddrs = hfield[1].split(",");
                  for (var _x = 0, _xl = toAddrs.length; _x < _xl; ++_x) {
                    to.push(toAddrs[_x]);
                  }
                  break;
                case "subject":
                  mailtoComponents.subject = unescapeComponent(hfield[1], options);
                  break;
                case "body":
                  mailtoComponents.body = unescapeComponent(hfield[1], options);
                  break;
                default:
                  unknownHeaders = true;
                  headers[unescapeComponent(hfield[0], options)] = unescapeComponent(hfield[1], options);
                  break;
              }
            }
            if (unknownHeaders)
              mailtoComponents.headers = headers;
          }
          mailtoComponents.query = void 0;
          for (var _x2 = 0, _xl2 = to.length; _x2 < _xl2; ++_x2) {
            var addr = to[_x2].split("@");
            addr[0] = unescapeComponent(addr[0]);
            if (!options.unicodeSupport) {
              try {
                addr[1] = punycode.toASCII(unescapeComponent(addr[1], options).toLowerCase());
              } catch (e) {
                mailtoComponents.error = mailtoComponents.error || "Email address's domain name can not be converted to ASCII via punycode: " + e;
              }
            } else {
              addr[1] = unescapeComponent(addr[1], options).toLowerCase();
            }
            to[_x2] = addr.join("@");
          }
          return mailtoComponents;
        },
        serialize: function serialize$$1(mailtoComponents, options) {
          var components = mailtoComponents;
          var to = toArray(mailtoComponents.to);
          if (to) {
            for (var x = 0, xl = to.length; x < xl; ++x) {
              var toAddr = String(to[x]);
              var atIdx = toAddr.lastIndexOf("@");
              var localPart = toAddr.slice(0, atIdx).replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_LOCAL_PART, pctEncChar);
              var domain = toAddr.slice(atIdx + 1);
              try {
                domain = !options.iri ? punycode.toASCII(unescapeComponent(domain, options).toLowerCase()) : punycode.toUnicode(domain);
              } catch (e) {
                components.error = components.error || "Email address's domain name can not be converted to " + (!options.iri ? "ASCII" : "Unicode") + " via punycode: " + e;
              }
              to[x] = localPart + "@" + domain;
            }
            components.path = to.join(",");
          }
          var headers = mailtoComponents.headers = mailtoComponents.headers || {};
          if (mailtoComponents.subject)
            headers["subject"] = mailtoComponents.subject;
          if (mailtoComponents.body)
            headers["body"] = mailtoComponents.body;
          var fields = [];
          for (var name in headers) {
            if (headers[name] !== O[name]) {
              fields.push(name.replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_HFNAME, pctEncChar) + "=" + headers[name].replace(PCT_ENCODED, decodeUnreserved).replace(PCT_ENCODED, toUpperCase).replace(NOT_HFVALUE, pctEncChar));
            }
          }
          if (fields.length) {
            components.query = fields.join("&");
          }
          return components;
        }
      };
      var URN_PARSE = /^([^\:]+)\:(.*)/;
      var handler$5 = {
        scheme: "urn",
        parse: function parse$$1(components, options) {
          var matches = components.path && components.path.match(URN_PARSE);
          var urnComponents = components;
          if (matches) {
            var scheme = options.scheme || urnComponents.scheme || "urn";
            var nid = matches[1].toLowerCase();
            var nss = matches[2];
            var urnScheme = scheme + ":" + (options.nid || nid);
            var schemeHandler = SCHEMES[urnScheme];
            urnComponents.nid = nid;
            urnComponents.nss = nss;
            urnComponents.path = void 0;
            if (schemeHandler) {
              urnComponents = schemeHandler.parse(urnComponents, options);
            }
          } else {
            urnComponents.error = urnComponents.error || "URN can not be parsed.";
          }
          return urnComponents;
        },
        serialize: function serialize$$1(urnComponents, options) {
          var scheme = options.scheme || urnComponents.scheme || "urn";
          var nid = urnComponents.nid;
          var urnScheme = scheme + ":" + (options.nid || nid);
          var schemeHandler = SCHEMES[urnScheme];
          if (schemeHandler) {
            urnComponents = schemeHandler.serialize(urnComponents, options);
          }
          var uriComponents = urnComponents;
          var nss = urnComponents.nss;
          uriComponents.path = (nid || options.nid) + ":" + nss;
          return uriComponents;
        }
      };
      var UUID = /^[0-9A-Fa-f]{8}(?:\-[0-9A-Fa-f]{4}){3}\-[0-9A-Fa-f]{12}$/;
      var handler$6 = {
        scheme: "urn:uuid",
        parse: function parse4(urnComponents, options) {
          var uuidComponents = urnComponents;
          uuidComponents.uuid = uuidComponents.nss;
          uuidComponents.nss = void 0;
          if (!options.tolerant && (!uuidComponents.uuid || !uuidComponents.uuid.match(UUID))) {
            uuidComponents.error = uuidComponents.error || "UUID is not valid.";
          }
          return uuidComponents;
        },
        serialize: function serialize2(uuidComponents, options) {
          var urnComponents = uuidComponents;
          urnComponents.nss = (uuidComponents.uuid || "").toLowerCase();
          return urnComponents;
        }
      };
      SCHEMES[handler.scheme] = handler;
      SCHEMES[handler$1.scheme] = handler$1;
      SCHEMES[handler$2.scheme] = handler$2;
      SCHEMES[handler$3.scheme] = handler$3;
      SCHEMES[handler$4.scheme] = handler$4;
      SCHEMES[handler$5.scheme] = handler$5;
      SCHEMES[handler$6.scheme] = handler$6;
      exports2.SCHEMES = SCHEMES;
      exports2.pctEncChar = pctEncChar;
      exports2.pctDecChars = pctDecChars;
      exports2.parse = parse3;
      exports2.removeDotSegments = removeDotSegments;
      exports2.serialize = serialize;
      exports2.resolveComponents = resolveComponents;
      exports2.resolve = resolve;
      exports2.normalize = normalize;
      exports2.equal = equal;
      exports2.escapeComponent = escapeComponent;
      exports2.unescapeComponent = unescapeComponent;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/fast-deep-equal/index.js
var require_fast_deep_equal = __commonJS({
  "node_modules/fast-deep-equal/index.js"(exports, module2) {
    "use strict";
    module2.exports = function equal(a, b) {
      if (a === b)
        return true;
      if (a && b && typeof a == "object" && typeof b == "object") {
        if (a.constructor !== b.constructor)
          return false;
        var length, i, keys3;
        if (Array.isArray(a)) {
          length = a.length;
          if (length != b.length)
            return false;
          for (i = length; i-- !== 0; )
            if (!equal(a[i], b[i]))
              return false;
          return true;
        }
        if (a.constructor === RegExp)
          return a.source === b.source && a.flags === b.flags;
        if (a.valueOf !== Object.prototype.valueOf)
          return a.valueOf() === b.valueOf();
        if (a.toString !== Object.prototype.toString)
          return a.toString() === b.toString();
        keys3 = Object.keys(a);
        length = keys3.length;
        if (length !== Object.keys(b).length)
          return false;
        for (i = length; i-- !== 0; )
          if (!Object.prototype.hasOwnProperty.call(b, keys3[i]))
            return false;
        for (i = length; i-- !== 0; ) {
          var key = keys3[i];
          if (!equal(a[key], b[key]))
            return false;
        }
        return true;
      }
      return a !== a && b !== b;
    };
  }
});

// node_modules/ajv/lib/compile/ucs2length.js
var require_ucs2length = __commonJS({
  "node_modules/ajv/lib/compile/ucs2length.js"(exports, module2) {
    "use strict";
    module2.exports = function ucs2length(str) {
      var length = 0, len = str.length, pos = 0, value2;
      while (pos < len) {
        length++;
        value2 = str.charCodeAt(pos++);
        if (value2 >= 55296 && value2 <= 56319 && pos < len) {
          value2 = str.charCodeAt(pos);
          if ((value2 & 64512) == 56320)
            pos++;
        }
      }
      return length;
    };
  }
});

// node_modules/ajv/lib/compile/util.js
var require_util2 = __commonJS({
  "node_modules/ajv/lib/compile/util.js"(exports, module2) {
    "use strict";
    module2.exports = {
      copy,
      checkDataType,
      checkDataTypes,
      coerceToTypes,
      toHash,
      getProperty,
      escapeQuotes,
      equal: require_fast_deep_equal(),
      ucs2length: require_ucs2length(),
      varOccurences,
      varReplace,
      schemaHasRules,
      schemaHasRulesExcept,
      schemaUnknownRules,
      toQuotedString,
      getPathExpr,
      getPath,
      getData,
      unescapeFragment,
      unescapeJsonPointer,
      escapeFragment,
      escapeJsonPointer
    };
    function copy(o, to) {
      to = to || {};
      for (var key in o)
        to[key] = o[key];
      return to;
    }
    function checkDataType(dataType, data, strictNumbers, negate) {
      var EQUAL = negate ? " !== " : " === ", AND = negate ? " || " : " && ", OK = negate ? "!" : "", NOT = negate ? "" : "!";
      switch (dataType) {
        case "null":
          return data + EQUAL + "null";
        case "array":
          return OK + "Array.isArray(" + data + ")";
        case "object":
          return "(" + OK + data + AND + "typeof " + data + EQUAL + '"object"' + AND + NOT + "Array.isArray(" + data + "))";
        case "integer":
          return "(typeof " + data + EQUAL + '"number"' + AND + NOT + "(" + data + " % 1)" + AND + data + EQUAL + data + (strictNumbers ? AND + OK + "isFinite(" + data + ")" : "") + ")";
        case "number":
          return "(typeof " + data + EQUAL + '"' + dataType + '"' + (strictNumbers ? AND + OK + "isFinite(" + data + ")" : "") + ")";
        default:
          return "typeof " + data + EQUAL + '"' + dataType + '"';
      }
    }
    function checkDataTypes(dataTypes, data, strictNumbers) {
      switch (dataTypes.length) {
        case 1:
          return checkDataType(dataTypes[0], data, strictNumbers, true);
        default:
          var code = "";
          var types = toHash(dataTypes);
          if (types.array && types.object) {
            code = types.null ? "(" : "(!" + data + " || ";
            code += "typeof " + data + ' !== "object")';
            delete types.null;
            delete types.array;
            delete types.object;
          }
          if (types.number)
            delete types.integer;
          for (var t3 in types)
            code += (code ? " && " : "") + checkDataType(t3, data, strictNumbers, true);
          return code;
      }
    }
    var COERCE_TO_TYPES = toHash(["string", "number", "integer", "boolean", "null"]);
    function coerceToTypes(optionCoerceTypes, dataTypes) {
      if (Array.isArray(dataTypes)) {
        var types = [];
        for (var i = 0; i < dataTypes.length; i++) {
          var t3 = dataTypes[i];
          if (COERCE_TO_TYPES[t3])
            types[types.length] = t3;
          else if (optionCoerceTypes === "array" && t3 === "array")
            types[types.length] = t3;
        }
        if (types.length)
          return types;
      } else if (COERCE_TO_TYPES[dataTypes]) {
        return [dataTypes];
      } else if (optionCoerceTypes === "array" && dataTypes === "array") {
        return ["array"];
      }
    }
    function toHash(arr) {
      var hash = {};
      for (var i = 0; i < arr.length; i++)
        hash[arr[i]] = true;
      return hash;
    }
    var IDENTIFIER = /^[a-z$_][a-z$_0-9]*$/i;
    var SINGLE_QUOTE = /'|\\/g;
    function getProperty(key) {
      return typeof key == "number" ? "[" + key + "]" : IDENTIFIER.test(key) ? "." + key : "['" + escapeQuotes(key) + "']";
    }
    function escapeQuotes(str) {
      return str.replace(SINGLE_QUOTE, "\\$&").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\f/g, "\\f").replace(/\t/g, "\\t");
    }
    function varOccurences(str, dataVar) {
      dataVar += "[^0-9]";
      var matches = str.match(new RegExp(dataVar, "g"));
      return matches ? matches.length : 0;
    }
    function varReplace(str, dataVar, expr) {
      dataVar += "([^0-9])";
      expr = expr.replace(/\$/g, "$$$$");
      return str.replace(new RegExp(dataVar, "g"), expr + "$1");
    }
    function schemaHasRules(schema, rules) {
      if (typeof schema == "boolean")
        return !schema;
      for (var key in schema)
        if (rules[key])
          return true;
    }
    function schemaHasRulesExcept(schema, rules, exceptKeyword) {
      if (typeof schema == "boolean")
        return !schema && exceptKeyword != "not";
      for (var key in schema)
        if (key != exceptKeyword && rules[key])
          return true;
    }
    function schemaUnknownRules(schema, rules) {
      if (typeof schema == "boolean")
        return;
      for (var key in schema)
        if (!rules[key])
          return key;
    }
    function toQuotedString(str) {
      return "'" + escapeQuotes(str) + "'";
    }
    function getPathExpr(currentPath, expr, jsonPointers, isNumber) {
      var path2 = jsonPointers ? "'/' + " + expr + (isNumber ? "" : ".replace(/~/g, '~0').replace(/\\//g, '~1')") : isNumber ? "'[' + " + expr + " + ']'" : "'[\\'' + " + expr + " + '\\']'";
      return joinPaths(currentPath, path2);
    }
    function getPath(currentPath, prop, jsonPointers) {
      var path2 = jsonPointers ? toQuotedString("/" + escapeJsonPointer(prop)) : toQuotedString(getProperty(prop));
      return joinPaths(currentPath, path2);
    }
    var JSON_POINTER = /^\/(?:[^~]|~0|~1)*$/;
    var RELATIVE_JSON_POINTER = /^([0-9]+)(#|\/(?:[^~]|~0|~1)*)?$/;
    function getData($data, lvl, paths) {
      var up, jsonPointer, data, matches;
      if ($data === "")
        return "rootData";
      if ($data[0] == "/") {
        if (!JSON_POINTER.test($data))
          throw new Error("Invalid JSON-pointer: " + $data);
        jsonPointer = $data;
        data = "rootData";
      } else {
        matches = $data.match(RELATIVE_JSON_POINTER);
        if (!matches)
          throw new Error("Invalid JSON-pointer: " + $data);
        up = +matches[1];
        jsonPointer = matches[2];
        if (jsonPointer == "#") {
          if (up >= lvl)
            throw new Error("Cannot access property/index " + up + " levels up, current level is " + lvl);
          return paths[lvl - up];
        }
        if (up > lvl)
          throw new Error("Cannot access data " + up + " levels up, current level is " + lvl);
        data = "data" + (lvl - up || "");
        if (!jsonPointer)
          return data;
      }
      var expr = data;
      var segments = jsonPointer.split("/");
      for (var i = 0; i < segments.length; i++) {
        var segment = segments[i];
        if (segment) {
          data += getProperty(unescapeJsonPointer(segment));
          expr += " && " + data;
        }
      }
      return expr;
    }
    function joinPaths(a, b) {
      if (a == '""')
        return b;
      return (a + " + " + b).replace(/([^\\])' \+ '/g, "$1");
    }
    function unescapeFragment(str) {
      return unescapeJsonPointer(decodeURIComponent(str));
    }
    function escapeFragment(str) {
      return encodeURIComponent(escapeJsonPointer(str));
    }
    function escapeJsonPointer(str) {
      return str.replace(/~/g, "~0").replace(/\//g, "~1");
    }
    function unescapeJsonPointer(str) {
      return str.replace(/~1/g, "/").replace(/~0/g, "~");
    }
  }
});

// node_modules/ajv/lib/compile/schema_obj.js
var require_schema_obj = __commonJS({
  "node_modules/ajv/lib/compile/schema_obj.js"(exports, module2) {
    "use strict";
    var util = require_util2();
    module2.exports = SchemaObject;
    function SchemaObject(obj) {
      util.copy(obj, this);
    }
  }
});

// node_modules/json-schema-traverse/index.js
var require_json_schema_traverse = __commonJS({
  "node_modules/json-schema-traverse/index.js"(exports, module2) {
    "use strict";
    var traverse3 = module2.exports = function(schema, opts, cb) {
      if (typeof opts == "function") {
        cb = opts;
        opts = {};
      }
      cb = opts.cb || cb;
      var pre = typeof cb == "function" ? cb : cb.pre || function() {
      };
      var post = cb.post || function() {
      };
      _traverse(opts, pre, post, schema, "", schema);
    };
    traverse3.keywords = {
      additionalItems: true,
      items: true,
      contains: true,
      additionalProperties: true,
      propertyNames: true,
      not: true
    };
    traverse3.arrayKeywords = {
      items: true,
      allOf: true,
      anyOf: true,
      oneOf: true
    };
    traverse3.propsKeywords = {
      definitions: true,
      properties: true,
      patternProperties: true,
      dependencies: true
    };
    traverse3.skipKeywords = {
      default: true,
      enum: true,
      const: true,
      required: true,
      maximum: true,
      minimum: true,
      exclusiveMaximum: true,
      exclusiveMinimum: true,
      multipleOf: true,
      maxLength: true,
      minLength: true,
      pattern: true,
      format: true,
      maxItems: true,
      minItems: true,
      uniqueItems: true,
      maxProperties: true,
      minProperties: true
    };
    function _traverse(opts, pre, post, schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex) {
      if (schema && typeof schema == "object" && !Array.isArray(schema)) {
        pre(schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex);
        for (var key in schema) {
          var sch = schema[key];
          if (Array.isArray(sch)) {
            if (key in traverse3.arrayKeywords) {
              for (var i = 0; i < sch.length; i++)
                _traverse(opts, pre, post, sch[i], jsonPtr + "/" + key + "/" + i, rootSchema, jsonPtr, key, schema, i);
            }
          } else if (key in traverse3.propsKeywords) {
            if (sch && typeof sch == "object") {
              for (var prop in sch)
                _traverse(opts, pre, post, sch[prop], jsonPtr + "/" + key + "/" + escapeJsonPtr(prop), rootSchema, jsonPtr, key, schema, prop);
            }
          } else if (key in traverse3.keywords || opts.allKeys && !(key in traverse3.skipKeywords)) {
            _traverse(opts, pre, post, sch, jsonPtr + "/" + key, rootSchema, jsonPtr, key, schema);
          }
        }
        post(schema, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex);
      }
    }
    function escapeJsonPtr(str) {
      return str.replace(/~/g, "~0").replace(/\//g, "~1");
    }
  }
});

// node_modules/ajv/lib/compile/resolve.js
var require_resolve = __commonJS({
  "node_modules/ajv/lib/compile/resolve.js"(exports, module2) {
    "use strict";
    var URI = require_uri_all();
    var equal = require_fast_deep_equal();
    var util = require_util2();
    var SchemaObject = require_schema_obj();
    var traverse3 = require_json_schema_traverse();
    module2.exports = resolve;
    resolve.normalizeId = normalizeId;
    resolve.fullPath = getFullPath;
    resolve.url = resolveUrl;
    resolve.ids = resolveIds;
    resolve.inlineRef = inlineRef;
    resolve.schema = resolveSchema;
    function resolve(compile, root2, ref) {
      var refVal = this._refs[ref];
      if (typeof refVal == "string") {
        if (this._refs[refVal])
          refVal = this._refs[refVal];
        else
          return resolve.call(this, compile, root2, refVal);
      }
      refVal = refVal || this._schemas[ref];
      if (refVal instanceof SchemaObject) {
        return inlineRef(refVal.schema, this._opts.inlineRefs) ? refVal.schema : refVal.validate || this._compile(refVal);
      }
      var res = resolveSchema.call(this, root2, ref);
      var schema, v, baseId;
      if (res) {
        schema = res.schema;
        root2 = res.root;
        baseId = res.baseId;
      }
      if (schema instanceof SchemaObject) {
        v = schema.validate || compile.call(this, schema.schema, root2, void 0, baseId);
      } else if (schema !== void 0) {
        v = inlineRef(schema, this._opts.inlineRefs) ? schema : compile.call(this, schema, root2, void 0, baseId);
      }
      return v;
    }
    function resolveSchema(root2, ref) {
      var p = URI.parse(ref), refPath = _getFullPath(p), baseId = getFullPath(this._getId(root2.schema));
      if (Object.keys(root2.schema).length === 0 || refPath !== baseId) {
        var id = normalizeId(refPath);
        var refVal = this._refs[id];
        if (typeof refVal == "string") {
          return resolveRecursive.call(this, root2, refVal, p);
        } else if (refVal instanceof SchemaObject) {
          if (!refVal.validate)
            this._compile(refVal);
          root2 = refVal;
        } else {
          refVal = this._schemas[id];
          if (refVal instanceof SchemaObject) {
            if (!refVal.validate)
              this._compile(refVal);
            if (id == normalizeId(ref))
              return { schema: refVal, root: root2, baseId };
            root2 = refVal;
          } else {
            return;
          }
        }
        if (!root2.schema)
          return;
        baseId = getFullPath(this._getId(root2.schema));
      }
      return getJsonPointer.call(this, p, baseId, root2.schema, root2);
    }
    function resolveRecursive(root2, ref, parsedRef) {
      var res = resolveSchema.call(this, root2, ref);
      if (res) {
        var schema = res.schema;
        var baseId = res.baseId;
        root2 = res.root;
        var id = this._getId(schema);
        if (id)
          baseId = resolveUrl(baseId, id);
        return getJsonPointer.call(this, parsedRef, baseId, schema, root2);
      }
    }
    var PREVENT_SCOPE_CHANGE = util.toHash(["properties", "patternProperties", "enum", "dependencies", "definitions"]);
    function getJsonPointer(parsedRef, baseId, schema, root2) {
      parsedRef.fragment = parsedRef.fragment || "";
      if (parsedRef.fragment.slice(0, 1) != "/")
        return;
      var parts = parsedRef.fragment.split("/");
      for (var i = 1; i < parts.length; i++) {
        var part = parts[i];
        if (part) {
          part = util.unescapeFragment(part);
          schema = schema[part];
          if (schema === void 0)
            break;
          var id;
          if (!PREVENT_SCOPE_CHANGE[part]) {
            id = this._getId(schema);
            if (id)
              baseId = resolveUrl(baseId, id);
            if (schema.$ref) {
              var $ref = resolveUrl(baseId, schema.$ref);
              var res = resolveSchema.call(this, root2, $ref);
              if (res) {
                schema = res.schema;
                root2 = res.root;
                baseId = res.baseId;
              }
            }
          }
        }
      }
      if (schema !== void 0 && schema !== root2.schema)
        return { schema, root: root2, baseId };
    }
    var SIMPLE_INLINED = util.toHash([
      "type",
      "format",
      "pattern",
      "maxLength",
      "minLength",
      "maxProperties",
      "minProperties",
      "maxItems",
      "minItems",
      "maximum",
      "minimum",
      "uniqueItems",
      "multipleOf",
      "required",
      "enum"
    ]);
    function inlineRef(schema, limit) {
      if (limit === false)
        return false;
      if (limit === void 0 || limit === true)
        return checkNoRef(schema);
      else if (limit)
        return countKeys(schema) <= limit;
    }
    function checkNoRef(schema) {
      var item;
      if (Array.isArray(schema)) {
        for (var i = 0; i < schema.length; i++) {
          item = schema[i];
          if (typeof item == "object" && !checkNoRef(item))
            return false;
        }
      } else {
        for (var key in schema) {
          if (key == "$ref")
            return false;
          item = schema[key];
          if (typeof item == "object" && !checkNoRef(item))
            return false;
        }
      }
      return true;
    }
    function countKeys(schema) {
      var count = 0, item;
      if (Array.isArray(schema)) {
        for (var i = 0; i < schema.length; i++) {
          item = schema[i];
          if (typeof item == "object")
            count += countKeys(item);
          if (count == Infinity)
            return Infinity;
        }
      } else {
        for (var key in schema) {
          if (key == "$ref")
            return Infinity;
          if (SIMPLE_INLINED[key]) {
            count++;
          } else {
            item = schema[key];
            if (typeof item == "object")
              count += countKeys(item) + 1;
            if (count == Infinity)
              return Infinity;
          }
        }
      }
      return count;
    }
    function getFullPath(id, normalize) {
      if (normalize !== false)
        id = normalizeId(id);
      var p = URI.parse(id);
      return _getFullPath(p);
    }
    function _getFullPath(p) {
      return URI.serialize(p).split("#")[0] + "#";
    }
    var TRAILING_SLASH_HASH = /#\/?$/;
    function normalizeId(id) {
      return id ? id.replace(TRAILING_SLASH_HASH, "") : "";
    }
    function resolveUrl(baseId, id) {
      id = normalizeId(id);
      return URI.resolve(baseId, id);
    }
    function resolveIds(schema) {
      var schemaId = normalizeId(this._getId(schema));
      var baseIds = { "": schemaId };
      var fullPaths = { "": getFullPath(schemaId, false) };
      var localRefs = {};
      var self2 = this;
      traverse3(schema, { allKeys: true }, function(sch, jsonPtr, rootSchema, parentJsonPtr, parentKeyword, parentSchema, keyIndex) {
        if (jsonPtr === "")
          return;
        var id = self2._getId(sch);
        var baseId = baseIds[parentJsonPtr];
        var fullPath = fullPaths[parentJsonPtr] + "/" + parentKeyword;
        if (keyIndex !== void 0)
          fullPath += "/" + (typeof keyIndex == "number" ? keyIndex : util.escapeFragment(keyIndex));
        if (typeof id == "string") {
          id = baseId = normalizeId(baseId ? URI.resolve(baseId, id) : id);
          var refVal = self2._refs[id];
          if (typeof refVal == "string")
            refVal = self2._refs[refVal];
          if (refVal && refVal.schema) {
            if (!equal(sch, refVal.schema))
              throw new Error('id "' + id + '" resolves to more than one schema');
          } else if (id != normalizeId(fullPath)) {
            if (id[0] == "#") {
              if (localRefs[id] && !equal(sch, localRefs[id]))
                throw new Error('id "' + id + '" resolves to more than one schema');
              localRefs[id] = sch;
            } else {
              self2._refs[id] = fullPath;
            }
          }
        }
        baseIds[jsonPtr] = baseId;
        fullPaths[jsonPtr] = fullPath;
      });
      return localRefs;
    }
  }
});

// node_modules/ajv/lib/compile/error_classes.js
var require_error_classes = __commonJS({
  "node_modules/ajv/lib/compile/error_classes.js"(exports, module2) {
    "use strict";
    var resolve = require_resolve();
    module2.exports = {
      Validation: errorSubclass(ValidationError),
      MissingRef: errorSubclass(MissingRefError)
    };
    function ValidationError(errors) {
      this.message = "validation failed";
      this.errors = errors;
      this.ajv = this.validation = true;
    }
    MissingRefError.message = function(baseId, ref) {
      return "can't resolve reference " + ref + " from id " + baseId;
    };
    function MissingRefError(baseId, ref, message) {
      this.message = message || MissingRefError.message(baseId, ref);
      this.missingRef = resolve.url(baseId, ref);
      this.missingSchema = resolve.normalizeId(resolve.fullPath(this.missingRef));
    }
    function errorSubclass(Subclass) {
      Subclass.prototype = Object.create(Error.prototype);
      Subclass.prototype.constructor = Subclass;
      return Subclass;
    }
  }
});

// node_modules/fast-json-stable-stringify/index.js
var require_fast_json_stable_stringify = __commonJS({
  "node_modules/fast-json-stable-stringify/index.js"(exports, module2) {
    "use strict";
    module2.exports = function(data, opts) {
      if (!opts)
        opts = {};
      if (typeof opts === "function")
        opts = { cmp: opts };
      var cycles = typeof opts.cycles === "boolean" ? opts.cycles : false;
      var cmp = opts.cmp && function(f) {
        return function(node) {
          return function(a, b) {
            var aobj = { key: a, value: node[a] };
            var bobj = { key: b, value: node[b] };
            return f(aobj, bobj);
          };
        };
      }(opts.cmp);
      var seen = [];
      return function stringify(node) {
        if (node && node.toJSON && typeof node.toJSON === "function") {
          node = node.toJSON();
        }
        if (node === void 0)
          return;
        if (typeof node == "number")
          return isFinite(node) ? "" + node : "null";
        if (typeof node !== "object")
          return JSON.stringify(node);
        var i, out;
        if (Array.isArray(node)) {
          out = "[";
          for (i = 0; i < node.length; i++) {
            if (i)
              out += ",";
            out += stringify(node[i]) || "null";
          }
          return out + "]";
        }
        if (node === null)
          return "null";
        if (seen.indexOf(node) !== -1) {
          if (cycles)
            return JSON.stringify("__cycle__");
          throw new TypeError("Converting circular structure to JSON");
        }
        var seenIndex = seen.push(node) - 1;
        var keys3 = Object.keys(node).sort(cmp && cmp(node));
        out = "";
        for (i = 0; i < keys3.length; i++) {
          var key = keys3[i];
          var value2 = stringify(node[key]);
          if (!value2)
            continue;
          if (out)
            out += ",";
          out += JSON.stringify(key) + ":" + value2;
        }
        seen.splice(seenIndex, 1);
        return "{" + out + "}";
      }(data);
    };
  }
});

// node_modules/ajv/lib/dotjs/validate.js
var require_validate = __commonJS({
  "node_modules/ajv/lib/dotjs/validate.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_validate(it2, $keyword, $ruleType) {
      var out = "";
      var $async = it2.schema.$async === true, $refKeywords = it2.util.schemaHasRulesExcept(it2.schema, it2.RULES.all, "$ref"), $id = it2.self._getId(it2.schema);
      if (it2.opts.strictKeywords) {
        var $unknownKwd = it2.util.schemaUnknownRules(it2.schema, it2.RULES.keywords);
        if ($unknownKwd) {
          var $keywordsMsg = "unknown keyword: " + $unknownKwd;
          if (it2.opts.strictKeywords === "log")
            it2.logger.warn($keywordsMsg);
          else
            throw new Error($keywordsMsg);
        }
      }
      if (it2.isTop) {
        out += " var validate = ";
        if ($async) {
          it2.async = true;
          out += "async ";
        }
        out += "function(data, dataPath, parentData, parentDataProperty, rootData) { 'use strict'; ";
        if ($id && (it2.opts.sourceCode || it2.opts.processCode)) {
          out += " " + ("/*# sourceURL=" + $id + " */") + " ";
        }
      }
      if (typeof it2.schema == "boolean" || !($refKeywords || it2.schema.$ref)) {
        var $keyword = "false schema";
        var $lvl = it2.level;
        var $dataLvl = it2.dataLevel;
        var $schema = it2.schema[$keyword];
        var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
        var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
        var $breakOnError = !it2.opts.allErrors;
        var $errorKeyword;
        var $data = "data" + ($dataLvl || "");
        var $valid = "valid" + $lvl;
        if (it2.schema === false) {
          if (it2.isTop) {
            $breakOnError = true;
          } else {
            out += " var " + $valid + " = false; ";
          }
          var $$outStack = $$outStack || [];
          $$outStack.push(out);
          out = "";
          if (it2.createErrors !== false) {
            out += " { keyword: '" + ($errorKeyword || "false schema") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
            if (it2.opts.messages !== false) {
              out += " , message: 'boolean schema is false' ";
            }
            if (it2.opts.verbose) {
              out += " , schema: false , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
            }
            out += " } ";
          } else {
            out += " {} ";
          }
          var __err = out;
          out = $$outStack.pop();
          if (!it2.compositeRule && $breakOnError) {
            if (it2.async) {
              out += " throw new ValidationError([" + __err + "]); ";
            } else {
              out += " validate.errors = [" + __err + "]; return false; ";
            }
          } else {
            out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
          }
        } else {
          if (it2.isTop) {
            if ($async) {
              out += " return data; ";
            } else {
              out += " validate.errors = null; return true; ";
            }
          } else {
            out += " var " + $valid + " = true; ";
          }
        }
        if (it2.isTop) {
          out += " }; return validate; ";
        }
        return out;
      }
      if (it2.isTop) {
        var $top = it2.isTop, $lvl = it2.level = 0, $dataLvl = it2.dataLevel = 0, $data = "data";
        it2.rootId = it2.resolve.fullPath(it2.self._getId(it2.root.schema));
        it2.baseId = it2.baseId || it2.rootId;
        delete it2.isTop;
        it2.dataPathArr = [""];
        if (it2.schema.default !== void 0 && it2.opts.useDefaults && it2.opts.strictDefaults) {
          var $defaultMsg = "default is ignored in the schema root";
          if (it2.opts.strictDefaults === "log")
            it2.logger.warn($defaultMsg);
          else
            throw new Error($defaultMsg);
        }
        out += " var vErrors = null; ";
        out += " var errors = 0;     ";
        out += " if (rootData === undefined) rootData = data; ";
      } else {
        var $lvl = it2.level, $dataLvl = it2.dataLevel, $data = "data" + ($dataLvl || "");
        if ($id)
          it2.baseId = it2.resolve.url(it2.baseId, $id);
        if ($async && !it2.async)
          throw new Error("async schema in sync schema");
        out += " var errs_" + $lvl + " = errors;";
      }
      var $valid = "valid" + $lvl, $breakOnError = !it2.opts.allErrors, $closingBraces1 = "", $closingBraces2 = "";
      var $errorKeyword;
      var $typeSchema = it2.schema.type, $typeIsArray = Array.isArray($typeSchema);
      if ($typeSchema && it2.opts.nullable && it2.schema.nullable === true) {
        if ($typeIsArray) {
          if ($typeSchema.indexOf("null") == -1)
            $typeSchema = $typeSchema.concat("null");
        } else if ($typeSchema != "null") {
          $typeSchema = [$typeSchema, "null"];
          $typeIsArray = true;
        }
      }
      if ($typeIsArray && $typeSchema.length == 1) {
        $typeSchema = $typeSchema[0];
        $typeIsArray = false;
      }
      if (it2.schema.$ref && $refKeywords) {
        if (it2.opts.extendRefs == "fail") {
          throw new Error('$ref: validation keywords used in schema at path "' + it2.errSchemaPath + '" (see option extendRefs)');
        } else if (it2.opts.extendRefs !== true) {
          $refKeywords = false;
          it2.logger.warn('$ref: keywords ignored in schema at path "' + it2.errSchemaPath + '"');
        }
      }
      if (it2.schema.$comment && it2.opts.$comment) {
        out += " " + it2.RULES.all.$comment.code(it2, "$comment");
      }
      if ($typeSchema) {
        if (it2.opts.coerceTypes) {
          var $coerceToTypes = it2.util.coerceToTypes(it2.opts.coerceTypes, $typeSchema);
        }
        var $rulesGroup = it2.RULES.types[$typeSchema];
        if ($coerceToTypes || $typeIsArray || $rulesGroup === true || $rulesGroup && !$shouldUseGroup($rulesGroup)) {
          var $schemaPath = it2.schemaPath + ".type", $errSchemaPath = it2.errSchemaPath + "/type";
          var $schemaPath = it2.schemaPath + ".type", $errSchemaPath = it2.errSchemaPath + "/type", $method = $typeIsArray ? "checkDataTypes" : "checkDataType";
          out += " if (" + it2.util[$method]($typeSchema, $data, it2.opts.strictNumbers, true) + ") { ";
          if ($coerceToTypes) {
            var $dataType = "dataType" + $lvl, $coerced = "coerced" + $lvl;
            out += " var " + $dataType + " = typeof " + $data + "; var " + $coerced + " = undefined; ";
            if (it2.opts.coerceTypes == "array") {
              out += " if (" + $dataType + " == 'object' && Array.isArray(" + $data + ") && " + $data + ".length == 1) { " + $data + " = " + $data + "[0]; " + $dataType + " = typeof " + $data + "; if (" + it2.util.checkDataType(it2.schema.type, $data, it2.opts.strictNumbers) + ") " + $coerced + " = " + $data + "; } ";
            }
            out += " if (" + $coerced + " !== undefined) ; ";
            var arr1 = $coerceToTypes;
            if (arr1) {
              var $type, $i = -1, l1 = arr1.length - 1;
              while ($i < l1) {
                $type = arr1[$i += 1];
                if ($type == "string") {
                  out += " else if (" + $dataType + " == 'number' || " + $dataType + " == 'boolean') " + $coerced + " = '' + " + $data + "; else if (" + $data + " === null) " + $coerced + " = ''; ";
                } else if ($type == "number" || $type == "integer") {
                  out += " else if (" + $dataType + " == 'boolean' || " + $data + " === null || (" + $dataType + " == 'string' && " + $data + " && " + $data + " == +" + $data + " ";
                  if ($type == "integer") {
                    out += " && !(" + $data + " % 1)";
                  }
                  out += ")) " + $coerced + " = +" + $data + "; ";
                } else if ($type == "boolean") {
                  out += " else if (" + $data + " === 'false' || " + $data + " === 0 || " + $data + " === null) " + $coerced + " = false; else if (" + $data + " === 'true' || " + $data + " === 1) " + $coerced + " = true; ";
                } else if ($type == "null") {
                  out += " else if (" + $data + " === '' || " + $data + " === 0 || " + $data + " === false) " + $coerced + " = null; ";
                } else if (it2.opts.coerceTypes == "array" && $type == "array") {
                  out += " else if (" + $dataType + " == 'string' || " + $dataType + " == 'number' || " + $dataType + " == 'boolean' || " + $data + " == null) " + $coerced + " = [" + $data + "]; ";
                }
              }
            }
            out += " else {   ";
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: '" + ($errorKeyword || "type") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { type: '";
              if ($typeIsArray) {
                out += "" + $typeSchema.join(",");
              } else {
                out += "" + $typeSchema;
              }
              out += "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: 'should be ";
                if ($typeIsArray) {
                  out += "" + $typeSchema.join(",");
                } else {
                  out += "" + $typeSchema;
                }
                out += "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
            out += " } if (" + $coerced + " !== undefined) {  ";
            var $parentData = $dataLvl ? "data" + ($dataLvl - 1 || "") : "parentData", $parentDataProperty = $dataLvl ? it2.dataPathArr[$dataLvl] : "parentDataProperty";
            out += " " + $data + " = " + $coerced + "; ";
            if (!$dataLvl) {
              out += "if (" + $parentData + " !== undefined)";
            }
            out += " " + $parentData + "[" + $parentDataProperty + "] = " + $coerced + "; } ";
          } else {
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: '" + ($errorKeyword || "type") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { type: '";
              if ($typeIsArray) {
                out += "" + $typeSchema.join(",");
              } else {
                out += "" + $typeSchema;
              }
              out += "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: 'should be ";
                if ($typeIsArray) {
                  out += "" + $typeSchema.join(",");
                } else {
                  out += "" + $typeSchema;
                }
                out += "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
          }
          out += " } ";
        }
      }
      if (it2.schema.$ref && !$refKeywords) {
        out += " " + it2.RULES.all.$ref.code(it2, "$ref") + " ";
        if ($breakOnError) {
          out += " } if (errors === ";
          if ($top) {
            out += "0";
          } else {
            out += "errs_" + $lvl;
          }
          out += ") { ";
          $closingBraces2 += "}";
        }
      } else {
        var arr2 = it2.RULES;
        if (arr2) {
          var $rulesGroup, i2 = -1, l2 = arr2.length - 1;
          while (i2 < l2) {
            $rulesGroup = arr2[i2 += 1];
            if ($shouldUseGroup($rulesGroup)) {
              if ($rulesGroup.type) {
                out += " if (" + it2.util.checkDataType($rulesGroup.type, $data, it2.opts.strictNumbers) + ") { ";
              }
              if (it2.opts.useDefaults) {
                if ($rulesGroup.type == "object" && it2.schema.properties) {
                  var $schema = it2.schema.properties, $schemaKeys = Object.keys($schema);
                  var arr3 = $schemaKeys;
                  if (arr3) {
                    var $propertyKey, i3 = -1, l3 = arr3.length - 1;
                    while (i3 < l3) {
                      $propertyKey = arr3[i3 += 1];
                      var $sch = $schema[$propertyKey];
                      if ($sch.default !== void 0) {
                        var $passData = $data + it2.util.getProperty($propertyKey);
                        if (it2.compositeRule) {
                          if (it2.opts.strictDefaults) {
                            var $defaultMsg = "default is ignored for: " + $passData;
                            if (it2.opts.strictDefaults === "log")
                              it2.logger.warn($defaultMsg);
                            else
                              throw new Error($defaultMsg);
                          }
                        } else {
                          out += " if (" + $passData + " === undefined ";
                          if (it2.opts.useDefaults == "empty") {
                            out += " || " + $passData + " === null || " + $passData + " === '' ";
                          }
                          out += " ) " + $passData + " = ";
                          if (it2.opts.useDefaults == "shared") {
                            out += " " + it2.useDefault($sch.default) + " ";
                          } else {
                            out += " " + JSON.stringify($sch.default) + " ";
                          }
                          out += "; ";
                        }
                      }
                    }
                  }
                } else if ($rulesGroup.type == "array" && Array.isArray(it2.schema.items)) {
                  var arr4 = it2.schema.items;
                  if (arr4) {
                    var $sch, $i = -1, l4 = arr4.length - 1;
                    while ($i < l4) {
                      $sch = arr4[$i += 1];
                      if ($sch.default !== void 0) {
                        var $passData = $data + "[" + $i + "]";
                        if (it2.compositeRule) {
                          if (it2.opts.strictDefaults) {
                            var $defaultMsg = "default is ignored for: " + $passData;
                            if (it2.opts.strictDefaults === "log")
                              it2.logger.warn($defaultMsg);
                            else
                              throw new Error($defaultMsg);
                          }
                        } else {
                          out += " if (" + $passData + " === undefined ";
                          if (it2.opts.useDefaults == "empty") {
                            out += " || " + $passData + " === null || " + $passData + " === '' ";
                          }
                          out += " ) " + $passData + " = ";
                          if (it2.opts.useDefaults == "shared") {
                            out += " " + it2.useDefault($sch.default) + " ";
                          } else {
                            out += " " + JSON.stringify($sch.default) + " ";
                          }
                          out += "; ";
                        }
                      }
                    }
                  }
                }
              }
              var arr5 = $rulesGroup.rules;
              if (arr5) {
                var $rule, i5 = -1, l5 = arr5.length - 1;
                while (i5 < l5) {
                  $rule = arr5[i5 += 1];
                  if ($shouldUseRule($rule)) {
                    var $code = $rule.code(it2, $rule.keyword, $rulesGroup.type);
                    if ($code) {
                      out += " " + $code + " ";
                      if ($breakOnError) {
                        $closingBraces1 += "}";
                      }
                    }
                  }
                }
              }
              if ($breakOnError) {
                out += " " + $closingBraces1 + " ";
                $closingBraces1 = "";
              }
              if ($rulesGroup.type) {
                out += " } ";
                if ($typeSchema && $typeSchema === $rulesGroup.type && !$coerceToTypes) {
                  out += " else { ";
                  var $schemaPath = it2.schemaPath + ".type", $errSchemaPath = it2.errSchemaPath + "/type";
                  var $$outStack = $$outStack || [];
                  $$outStack.push(out);
                  out = "";
                  if (it2.createErrors !== false) {
                    out += " { keyword: '" + ($errorKeyword || "type") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { type: '";
                    if ($typeIsArray) {
                      out += "" + $typeSchema.join(",");
                    } else {
                      out += "" + $typeSchema;
                    }
                    out += "' } ";
                    if (it2.opts.messages !== false) {
                      out += " , message: 'should be ";
                      if ($typeIsArray) {
                        out += "" + $typeSchema.join(",");
                      } else {
                        out += "" + $typeSchema;
                      }
                      out += "' ";
                    }
                    if (it2.opts.verbose) {
                      out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                    }
                    out += " } ";
                  } else {
                    out += " {} ";
                  }
                  var __err = out;
                  out = $$outStack.pop();
                  if (!it2.compositeRule && $breakOnError) {
                    if (it2.async) {
                      out += " throw new ValidationError([" + __err + "]); ";
                    } else {
                      out += " validate.errors = [" + __err + "]; return false; ";
                    }
                  } else {
                    out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
                  }
                  out += " } ";
                }
              }
              if ($breakOnError) {
                out += " if (errors === ";
                if ($top) {
                  out += "0";
                } else {
                  out += "errs_" + $lvl;
                }
                out += ") { ";
                $closingBraces2 += "}";
              }
            }
          }
        }
      }
      if ($breakOnError) {
        out += " " + $closingBraces2 + " ";
      }
      if ($top) {
        if ($async) {
          out += " if (errors === 0) return data;           ";
          out += " else throw new ValidationError(vErrors); ";
        } else {
          out += " validate.errors = vErrors; ";
          out += " return errors === 0;       ";
        }
        out += " }; return validate;";
      } else {
        out += " var " + $valid + " = errors === errs_" + $lvl + ";";
      }
      function $shouldUseGroup($rulesGroup2) {
        var rules = $rulesGroup2.rules;
        for (var i = 0; i < rules.length; i++)
          if ($shouldUseRule(rules[i]))
            return true;
      }
      function $shouldUseRule($rule2) {
        return it2.schema[$rule2.keyword] !== void 0 || $rule2.implements && $ruleImplementsSomeKeyword($rule2);
      }
      function $ruleImplementsSomeKeyword($rule2) {
        var impl = $rule2.implements;
        for (var i = 0; i < impl.length; i++)
          if (it2.schema[impl[i]] !== void 0)
            return true;
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/compile/index.js
var require_compile = __commonJS({
  "node_modules/ajv/lib/compile/index.js"(exports, module2) {
    "use strict";
    var resolve = require_resolve();
    var util = require_util2();
    var errorClasses = require_error_classes();
    var stableStringify = require_fast_json_stable_stringify();
    var validateGenerator = require_validate();
    var ucs2length = util.ucs2length;
    var equal = require_fast_deep_equal();
    var ValidationError = errorClasses.Validation;
    module2.exports = compile;
    function compile(schema, root2, localRefs, baseId) {
      var self2 = this, opts = this._opts, refVal = [void 0], refs = {}, patterns = [], patternsHash = {}, defaults = [], defaultsHash = {}, customRules = [];
      root2 = root2 || { schema, refVal, refs };
      var c = checkCompiling.call(this, schema, root2, baseId);
      var compilation = this._compilations[c.index];
      if (c.compiling)
        return compilation.callValidate = callValidate;
      var formats = this._formats;
      var RULES = this.RULES;
      try {
        var v = localCompile(schema, root2, localRefs, baseId);
        compilation.validate = v;
        var cv = compilation.callValidate;
        if (cv) {
          cv.schema = v.schema;
          cv.errors = null;
          cv.refs = v.refs;
          cv.refVal = v.refVal;
          cv.root = v.root;
          cv.$async = v.$async;
          if (opts.sourceCode)
            cv.source = v.source;
        }
        return v;
      } finally {
        endCompiling.call(this, schema, root2, baseId);
      }
      function callValidate() {
        var validate = compilation.validate;
        var result = validate.apply(this, arguments);
        callValidate.errors = validate.errors;
        return result;
      }
      function localCompile(_schema, _root, localRefs2, baseId2) {
        var isRoot = !_root || _root && _root.schema == _schema;
        if (_root.schema != root2.schema)
          return compile.call(self2, _schema, _root, localRefs2, baseId2);
        var $async = _schema.$async === true;
        var sourceCode = validateGenerator({
          isTop: true,
          schema: _schema,
          isRoot,
          baseId: baseId2,
          root: _root,
          schemaPath: "",
          errSchemaPath: "#",
          errorPath: '""',
          MissingRefError: errorClasses.MissingRef,
          RULES,
          validate: validateGenerator,
          util,
          resolve,
          resolveRef,
          usePattern,
          useDefault,
          useCustomRule,
          opts,
          formats,
          logger: self2.logger,
          self: self2
        });
        sourceCode = vars(refVal, refValCode) + vars(patterns, patternCode) + vars(defaults, defaultCode) + vars(customRules, customRuleCode) + sourceCode;
        if (opts.processCode)
          sourceCode = opts.processCode(sourceCode, _schema);
        var validate;
        try {
          var makeValidate = new Function(
            "self",
            "RULES",
            "formats",
            "root",
            "refVal",
            "defaults",
            "customRules",
            "equal",
            "ucs2length",
            "ValidationError",
            sourceCode
          );
          validate = makeValidate(
            self2,
            RULES,
            formats,
            root2,
            refVal,
            defaults,
            customRules,
            equal,
            ucs2length,
            ValidationError
          );
          refVal[0] = validate;
        } catch (e) {
          self2.logger.error("Error compiling schema, function code:", sourceCode);
          throw e;
        }
        validate.schema = _schema;
        validate.errors = null;
        validate.refs = refs;
        validate.refVal = refVal;
        validate.root = isRoot ? validate : _root;
        if ($async)
          validate.$async = true;
        if (opts.sourceCode === true) {
          validate.source = {
            code: sourceCode,
            patterns,
            defaults
          };
        }
        return validate;
      }
      function resolveRef(baseId2, ref, isRoot) {
        ref = resolve.url(baseId2, ref);
        var refIndex = refs[ref];
        var _refVal, refCode;
        if (refIndex !== void 0) {
          _refVal = refVal[refIndex];
          refCode = "refVal[" + refIndex + "]";
          return resolvedRef(_refVal, refCode);
        }
        if (!isRoot && root2.refs) {
          var rootRefId = root2.refs[ref];
          if (rootRefId !== void 0) {
            _refVal = root2.refVal[rootRefId];
            refCode = addLocalRef(ref, _refVal);
            return resolvedRef(_refVal, refCode);
          }
        }
        refCode = addLocalRef(ref);
        var v2 = resolve.call(self2, localCompile, root2, ref);
        if (v2 === void 0) {
          var localSchema = localRefs && localRefs[ref];
          if (localSchema) {
            v2 = resolve.inlineRef(localSchema, opts.inlineRefs) ? localSchema : compile.call(self2, localSchema, root2, localRefs, baseId2);
          }
        }
        if (v2 === void 0) {
          removeLocalRef(ref);
        } else {
          replaceLocalRef(ref, v2);
          return resolvedRef(v2, refCode);
        }
      }
      function addLocalRef(ref, v2) {
        var refId = refVal.length;
        refVal[refId] = v2;
        refs[ref] = refId;
        return "refVal" + refId;
      }
      function removeLocalRef(ref) {
        delete refs[ref];
      }
      function replaceLocalRef(ref, v2) {
        var refId = refs[ref];
        refVal[refId] = v2;
      }
      function resolvedRef(refVal2, code) {
        return typeof refVal2 == "object" || typeof refVal2 == "boolean" ? { code, schema: refVal2, inline: true } : { code, $async: refVal2 && !!refVal2.$async };
      }
      function usePattern(regexStr) {
        var index = patternsHash[regexStr];
        if (index === void 0) {
          index = patternsHash[regexStr] = patterns.length;
          patterns[index] = regexStr;
        }
        return "pattern" + index;
      }
      function useDefault(value2) {
        switch (typeof value2) {
          case "boolean":
          case "number":
            return "" + value2;
          case "string":
            return util.toQuotedString(value2);
          case "object":
            if (value2 === null)
              return "null";
            var valueStr = stableStringify(value2);
            var index = defaultsHash[valueStr];
            if (index === void 0) {
              index = defaultsHash[valueStr] = defaults.length;
              defaults[index] = value2;
            }
            return "default" + index;
        }
      }
      function useCustomRule(rule, schema2, parentSchema, it2) {
        if (self2._opts.validateSchema !== false) {
          var deps = rule.definition.dependencies;
          if (deps && !deps.every(function(keyword) {
            return Object.prototype.hasOwnProperty.call(parentSchema, keyword);
          }))
            throw new Error("parent schema must have all required keywords: " + deps.join(","));
          var validateSchema = rule.definition.validateSchema;
          if (validateSchema) {
            var valid = validateSchema(schema2);
            if (!valid) {
              var message = "keyword schema is invalid: " + self2.errorsText(validateSchema.errors);
              if (self2._opts.validateSchema == "log")
                self2.logger.error(message);
              else
                throw new Error(message);
            }
          }
        }
        var compile2 = rule.definition.compile, inline = rule.definition.inline, macro = rule.definition.macro;
        var validate;
        if (compile2) {
          validate = compile2.call(self2, schema2, parentSchema, it2);
        } else if (macro) {
          validate = macro.call(self2, schema2, parentSchema, it2);
          if (opts.validateSchema !== false)
            self2.validateSchema(validate, true);
        } else if (inline) {
          validate = inline.call(self2, it2, rule.keyword, schema2, parentSchema);
        } else {
          validate = rule.definition.validate;
          if (!validate)
            return;
        }
        if (validate === void 0)
          throw new Error('custom keyword "' + rule.keyword + '"failed to compile');
        var index = customRules.length;
        customRules[index] = validate;
        return {
          code: "customRule" + index,
          validate
        };
      }
    }
    function checkCompiling(schema, root2, baseId) {
      var index = compIndex.call(this, schema, root2, baseId);
      if (index >= 0)
        return { index, compiling: true };
      index = this._compilations.length;
      this._compilations[index] = {
        schema,
        root: root2,
        baseId
      };
      return { index, compiling: false };
    }
    function endCompiling(schema, root2, baseId) {
      var i = compIndex.call(this, schema, root2, baseId);
      if (i >= 0)
        this._compilations.splice(i, 1);
    }
    function compIndex(schema, root2, baseId) {
      for (var i = 0; i < this._compilations.length; i++) {
        var c = this._compilations[i];
        if (c.schema == schema && c.root == root2 && c.baseId == baseId)
          return i;
      }
      return -1;
    }
    function patternCode(i, patterns) {
      return "var pattern" + i + " = new RegExp(" + util.toQuotedString(patterns[i]) + ");";
    }
    function defaultCode(i) {
      return "var default" + i + " = defaults[" + i + "];";
    }
    function refValCode(i, refVal) {
      return refVal[i] === void 0 ? "" : "var refVal" + i + " = refVal[" + i + "];";
    }
    function customRuleCode(i) {
      return "var customRule" + i + " = customRules[" + i + "];";
    }
    function vars(arr, statement) {
      if (!arr.length)
        return "";
      var code = "";
      for (var i = 0; i < arr.length; i++)
        code += statement(i, arr);
      return code;
    }
  }
});

// node_modules/ajv/lib/cache.js
var require_cache = __commonJS({
  "node_modules/ajv/lib/cache.js"(exports, module2) {
    "use strict";
    var Cache = module2.exports = function Cache2() {
      this._cache = {};
    };
    Cache.prototype.put = function Cache_put(key, value2) {
      this._cache[key] = value2;
    };
    Cache.prototype.get = function Cache_get(key) {
      return this._cache[key];
    };
    Cache.prototype.del = function Cache_del(key) {
      delete this._cache[key];
    };
    Cache.prototype.clear = function Cache_clear() {
      this._cache = {};
    };
  }
});

// node_modules/ajv/lib/compile/formats.js
var require_formats = __commonJS({
  "node_modules/ajv/lib/compile/formats.js"(exports, module2) {
    "use strict";
    var util = require_util2();
    var DATE = /^(\d\d\d\d)-(\d\d)-(\d\d)$/;
    var DAYS = [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    var TIME = /^(\d\d):(\d\d):(\d\d)(\.\d+)?(z|[+-]\d\d(?::?\d\d)?)?$/i;
    var HOSTNAME = /^(?=.{1,253}\.?$)[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[-0-9a-z]{0,61}[0-9a-z])?)*\.?$/i;
    var URI = /^(?:[a-z][a-z0-9+\-.]*:)(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)(?:\?(?:[a-z0-9\-._~!$&'()*+,;=:@/?]|%[0-9a-f]{2})*)?(?:#(?:[a-z0-9\-._~!$&'()*+,;=:@/?]|%[0-9a-f]{2})*)?$/i;
    var URIREF = /^(?:[a-z][a-z0-9+\-.]*:)?(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'"()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?(?:\?(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?(?:#(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?$/i;
    var URITEMPLATE = /^(?:(?:[^\x00-\x20"'<>%\\^`{|}]|%[0-9a-f]{2})|\{[+#./;?&=,!@|]?(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?(?:,(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?)*\})*$/i;
    var URL2 = /^(?:(?:http[s\u017F]?|ftp):\/\/)(?:(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+(?::(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?@)?(?:(?!10(?:\.[0-9]{1,3}){3})(?!127(?:\.[0-9]{1,3}){3})(?!169\.254(?:\.[0-9]{1,3}){2})(?!192\.168(?:\.[0-9]{1,3}){2})(?!172\.(?:1[6-9]|2[0-9]|3[01])(?:\.[0-9]{1,3}){2})(?:[1-9][0-9]?|1[0-9][0-9]|2[01][0-9]|22[0-3])(?:\.(?:1?[0-9]{1,2}|2[0-4][0-9]|25[0-5])){2}(?:\.(?:[1-9][0-9]?|1[0-9][0-9]|2[0-4][0-9]|25[0-4]))|(?:(?:(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+-)*(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)(?:\.(?:(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+-)*(?:[0-9a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)*(?:\.(?:(?:[a-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]){2,})))(?::[0-9]{2,5})?(?:\/(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?$/i;
    var UUID = /^(?:urn:uuid:)?[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}$/i;
    var JSON_POINTER = /^(?:\/(?:[^~/]|~0|~1)*)*$/;
    var JSON_POINTER_URI_FRAGMENT = /^#(?:\/(?:[a-z0-9_\-.!$&'()*+,;:=@]|%[0-9a-f]{2}|~0|~1)*)*$/i;
    var RELATIVE_JSON_POINTER = /^(?:0|[1-9][0-9]*)(?:#|(?:\/(?:[^~/]|~0|~1)*)*)$/;
    module2.exports = formats;
    function formats(mode) {
      mode = mode == "full" ? "full" : "fast";
      return util.copy(formats[mode]);
    }
    formats.fast = {
      // date: http://tools.ietf.org/html/rfc3339#section-5.6
      date: /^\d\d\d\d-[0-1]\d-[0-3]\d$/,
      // date-time: http://tools.ietf.org/html/rfc3339#section-5.6
      time: /^(?:[0-2]\d:[0-5]\d:[0-5]\d|23:59:60)(?:\.\d+)?(?:z|[+-]\d\d(?::?\d\d)?)?$/i,
      "date-time": /^\d\d\d\d-[0-1]\d-[0-3]\d[t\s](?:[0-2]\d:[0-5]\d:[0-5]\d|23:59:60)(?:\.\d+)?(?:z|[+-]\d\d(?::?\d\d)?)$/i,
      // uri: https://github.com/mafintosh/is-my-json-valid/blob/master/formats.js
      uri: /^(?:[a-z][a-z0-9+\-.]*:)(?:\/?\/)?[^\s]*$/i,
      "uri-reference": /^(?:(?:[a-z][a-z0-9+\-.]*:)?\/?\/)?(?:[^\\\s#][^\s#]*)?(?:#[^\\\s]*)?$/i,
      "uri-template": URITEMPLATE,
      url: URL2,
      // email (sources from jsen validator):
      // http://stackoverflow.com/questions/201323/using-a-regular-expression-to-validate-an-email-address#answer-8829363
      // http://www.w3.org/TR/html5/forms.html#valid-e-mail-address (search for 'willful violation')
      email: /^[a-z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?)*$/i,
      hostname: HOSTNAME,
      // optimized https://www.safaribooksonline.com/library/view/regular-expressions-cookbook/9780596802837/ch07s16.html
      ipv4: /^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,
      // optimized http://stackoverflow.com/questions/53497/regular-expression-that-matches-valid-ipv6-addresses
      ipv6: /^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,
      regex,
      // uuid: http://tools.ietf.org/html/rfc4122
      uuid: UUID,
      // JSON-pointer: https://tools.ietf.org/html/rfc6901
      // uri fragment: https://tools.ietf.org/html/rfc3986#appendix-A
      "json-pointer": JSON_POINTER,
      "json-pointer-uri-fragment": JSON_POINTER_URI_FRAGMENT,
      // relative JSON-pointer: http://tools.ietf.org/html/draft-luff-relative-json-pointer-00
      "relative-json-pointer": RELATIVE_JSON_POINTER
    };
    formats.full = {
      date,
      time,
      "date-time": date_time,
      uri,
      "uri-reference": URIREF,
      "uri-template": URITEMPLATE,
      url: URL2,
      email: /^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$/i,
      hostname: HOSTNAME,
      ipv4: /^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,
      ipv6: /^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,
      regex,
      uuid: UUID,
      "json-pointer": JSON_POINTER,
      "json-pointer-uri-fragment": JSON_POINTER_URI_FRAGMENT,
      "relative-json-pointer": RELATIVE_JSON_POINTER
    };
    function isLeapYear(year) {
      return year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0);
    }
    function date(str) {
      var matches = str.match(DATE);
      if (!matches)
        return false;
      var year = +matches[1];
      var month = +matches[2];
      var day = +matches[3];
      return month >= 1 && month <= 12 && day >= 1 && day <= (month == 2 && isLeapYear(year) ? 29 : DAYS[month]);
    }
    function time(str, full) {
      var matches = str.match(TIME);
      if (!matches)
        return false;
      var hour = matches[1];
      var minute = matches[2];
      var second = matches[3];
      var timeZone = matches[5];
      return (hour <= 23 && minute <= 59 && second <= 59 || hour == 23 && minute == 59 && second == 60) && (!full || timeZone);
    }
    var DATE_TIME_SEPARATOR = /t|\s/i;
    function date_time(str) {
      var dateTime = str.split(DATE_TIME_SEPARATOR);
      return dateTime.length == 2 && date(dateTime[0]) && time(dateTime[1], true);
    }
    var NOT_URI_FRAGMENT = /\/|:/;
    function uri(str) {
      return NOT_URI_FRAGMENT.test(str) && URI.test(str);
    }
    var Z_ANCHOR = /[^\\]\\Z/;
    function regex(str) {
      if (Z_ANCHOR.test(str))
        return false;
      try {
        new RegExp(str);
        return true;
      } catch (e) {
        return false;
      }
    }
  }
});

// node_modules/ajv/lib/dotjs/ref.js
var require_ref = __commonJS({
  "node_modules/ajv/lib/dotjs/ref.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_ref(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $async, $refCode;
      if ($schema == "#" || $schema == "#/") {
        if (it2.isRoot) {
          $async = it2.async;
          $refCode = "validate";
        } else {
          $async = it2.root.schema.$async === true;
          $refCode = "root.refVal[0]";
        }
      } else {
        var $refVal = it2.resolveRef(it2.baseId, $schema, it2.isRoot);
        if ($refVal === void 0) {
          var $message = it2.MissingRefError.message(it2.baseId, $schema);
          if (it2.opts.missingRefs == "fail") {
            it2.logger.error($message);
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: '$ref' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { ref: '" + it2.util.escapeQuotes($schema) + "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: 'can\\'t resolve reference " + it2.util.escapeQuotes($schema) + "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: " + it2.util.toQuotedString($schema) + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
            if ($breakOnError) {
              out += " if (false) { ";
            }
          } else if (it2.opts.missingRefs == "ignore") {
            it2.logger.warn($message);
            if ($breakOnError) {
              out += " if (true) { ";
            }
          } else {
            throw new it2.MissingRefError(it2.baseId, $schema, $message);
          }
        } else if ($refVal.inline) {
          var $it = it2.util.copy(it2);
          $it.level++;
          var $nextValid = "valid" + $it.level;
          $it.schema = $refVal.schema;
          $it.schemaPath = "";
          $it.errSchemaPath = $schema;
          var $code = it2.validate($it).replace(/validate\.schema/g, $refVal.code);
          out += " " + $code + " ";
          if ($breakOnError) {
            out += " if (" + $nextValid + ") { ";
          }
        } else {
          $async = $refVal.$async === true || it2.async && $refVal.$async !== false;
          $refCode = $refVal.code;
        }
      }
      if ($refCode) {
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        if (it2.opts.passContext) {
          out += " " + $refCode + ".call(this, ";
        } else {
          out += " " + $refCode + "( ";
        }
        out += " " + $data + ", (dataPath || '')";
        if (it2.errorPath != '""') {
          out += " + " + it2.errorPath;
        }
        var $parentData = $dataLvl ? "data" + ($dataLvl - 1 || "") : "parentData", $parentDataProperty = $dataLvl ? it2.dataPathArr[$dataLvl] : "parentDataProperty";
        out += " , " + $parentData + " , " + $parentDataProperty + ", rootData)  ";
        var __callValidate = out;
        out = $$outStack.pop();
        if ($async) {
          if (!it2.async)
            throw new Error("async schema referenced by sync schema");
          if ($breakOnError) {
            out += " var " + $valid + "; ";
          }
          out += " try { await " + __callValidate + "; ";
          if ($breakOnError) {
            out += " " + $valid + " = true; ";
          }
          out += " } catch (e) { if (!(e instanceof ValidationError)) throw e; if (vErrors === null) vErrors = e.errors; else vErrors = vErrors.concat(e.errors); errors = vErrors.length; ";
          if ($breakOnError) {
            out += " " + $valid + " = false; ";
          }
          out += " } ";
          if ($breakOnError) {
            out += " if (" + $valid + ") { ";
          }
        } else {
          out += " if (!" + __callValidate + ") { if (vErrors === null) vErrors = " + $refCode + ".errors; else vErrors = vErrors.concat(" + $refCode + ".errors); errors = vErrors.length; } ";
          if ($breakOnError) {
            out += " else { ";
          }
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/allOf.js
var require_allOf = __commonJS({
  "node_modules/ajv/lib/dotjs/allOf.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_allOf(it2, $keyword, $ruleType) {
      var out = " ";
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $currentBaseId = $it.baseId, $allSchemasEmpty = true;
      var arr1 = $schema;
      if (arr1) {
        var $sch, $i = -1, l1 = arr1.length - 1;
        while ($i < l1) {
          $sch = arr1[$i += 1];
          if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
            $allSchemasEmpty = false;
            $it.schema = $sch;
            $it.schemaPath = $schemaPath + "[" + $i + "]";
            $it.errSchemaPath = $errSchemaPath + "/" + $i;
            out += "  " + it2.validate($it) + " ";
            $it.baseId = $currentBaseId;
            if ($breakOnError) {
              out += " if (" + $nextValid + ") { ";
              $closingBraces += "}";
            }
          }
        }
      }
      if ($breakOnError) {
        if ($allSchemasEmpty) {
          out += " if (true) { ";
        } else {
          out += " " + $closingBraces.slice(0, -1) + " ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/anyOf.js
var require_anyOf = __commonJS({
  "node_modules/ajv/lib/dotjs/anyOf.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_anyOf(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $noEmptySchema = $schema.every(function($sch2) {
        return it2.opts.strictKeywords ? typeof $sch2 == "object" && Object.keys($sch2).length > 0 || $sch2 === false : it2.util.schemaHasRules($sch2, it2.RULES.all);
      });
      if ($noEmptySchema) {
        var $currentBaseId = $it.baseId;
        out += " var " + $errs + " = errors; var " + $valid + " = false;  ";
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        var arr1 = $schema;
        if (arr1) {
          var $sch, $i = -1, l1 = arr1.length - 1;
          while ($i < l1) {
            $sch = arr1[$i += 1];
            $it.schema = $sch;
            $it.schemaPath = $schemaPath + "[" + $i + "]";
            $it.errSchemaPath = $errSchemaPath + "/" + $i;
            out += "  " + it2.validate($it) + " ";
            $it.baseId = $currentBaseId;
            out += " " + $valid + " = " + $valid + " || " + $nextValid + "; if (!" + $valid + ") { ";
            $closingBraces += "}";
          }
        }
        it2.compositeRule = $it.compositeRule = $wasComposite;
        out += " " + $closingBraces + " if (!" + $valid + ") {   var err =   ";
        if (it2.createErrors !== false) {
          out += " { keyword: 'anyOf' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
          if (it2.opts.messages !== false) {
            out += " , message: 'should match some schema in anyOf' ";
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError(vErrors); ";
          } else {
            out += " validate.errors = vErrors; return false; ";
          }
        }
        out += " } else {  errors = " + $errs + "; if (vErrors !== null) { if (" + $errs + ") vErrors.length = " + $errs + "; else vErrors = null; } ";
        if (it2.opts.allErrors) {
          out += " } ";
        }
      } else {
        if ($breakOnError) {
          out += " if (true) { ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/comment.js
var require_comment = __commonJS({
  "node_modules/ajv/lib/dotjs/comment.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_comment(it2, $keyword, $ruleType) {
      var out = " ";
      var $schema = it2.schema[$keyword];
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $comment = it2.util.toQuotedString($schema);
      if (it2.opts.$comment === true) {
        out += " console.log(" + $comment + ");";
      } else if (typeof it2.opts.$comment == "function") {
        out += " self._opts.$comment(" + $comment + ", " + it2.util.toQuotedString($errSchemaPath) + ", validate.root.schema);";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/const.js
var require_const = __commonJS({
  "node_modules/ajv/lib/dotjs/const.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_const(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (!$isData) {
        out += " var schema" + $lvl + " = validate.schema" + $schemaPath + ";";
      }
      out += "var " + $valid + " = equal(" + $data + ", schema" + $lvl + "); if (!" + $valid + ") {   ";
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'const' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { allowedValue: schema" + $lvl + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should be equal to constant' ";
        }
        if (it2.opts.verbose) {
          out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += " }";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/contains.js
var require_contains = __commonJS({
  "node_modules/ajv/lib/dotjs/contains.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_contains(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $idx = "i" + $lvl, $dataNxt = $it.dataLevel = it2.dataLevel + 1, $nextData = "data" + $dataNxt, $currentBaseId = it2.baseId, $nonEmptySchema = it2.opts.strictKeywords ? typeof $schema == "object" && Object.keys($schema).length > 0 || $schema === false : it2.util.schemaHasRules($schema, it2.RULES.all);
      out += "var " + $errs + " = errors;var " + $valid + ";";
      if ($nonEmptySchema) {
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        $it.schema = $schema;
        $it.schemaPath = $schemaPath;
        $it.errSchemaPath = $errSchemaPath;
        out += " var " + $nextValid + " = false; for (var " + $idx + " = 0; " + $idx + " < " + $data + ".length; " + $idx + "++) { ";
        $it.errorPath = it2.util.getPathExpr(it2.errorPath, $idx, it2.opts.jsonPointers, true);
        var $passData = $data + "[" + $idx + "]";
        $it.dataPathArr[$dataNxt] = $idx;
        var $code = it2.validate($it);
        $it.baseId = $currentBaseId;
        if (it2.util.varOccurences($code, $nextData) < 2) {
          out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
        } else {
          out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
        }
        out += " if (" + $nextValid + ") break; }  ";
        it2.compositeRule = $it.compositeRule = $wasComposite;
        out += " " + $closingBraces + " if (!" + $nextValid + ") {";
      } else {
        out += " if (" + $data + ".length == 0) {";
      }
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'contains' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should contain a valid item' ";
        }
        if (it2.opts.verbose) {
          out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += " } else { ";
      if ($nonEmptySchema) {
        out += "  errors = " + $errs + "; if (vErrors !== null) { if (" + $errs + ") vErrors.length = " + $errs + "; else vErrors = null; } ";
      }
      if (it2.opts.allErrors) {
        out += " } ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/dependencies.js
var require_dependencies = __commonJS({
  "node_modules/ajv/lib/dotjs/dependencies.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_dependencies(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $schemaDeps = {}, $propertyDeps = {}, $ownProperties = it2.opts.ownProperties;
      for ($property in $schema) {
        if ($property == "__proto__")
          continue;
        var $sch = $schema[$property];
        var $deps = Array.isArray($sch) ? $propertyDeps : $schemaDeps;
        $deps[$property] = $sch;
      }
      out += "var " + $errs + " = errors;";
      var $currentErrorPath = it2.errorPath;
      out += "var missing" + $lvl + ";";
      for (var $property in $propertyDeps) {
        $deps = $propertyDeps[$property];
        if ($deps.length) {
          out += " if ( " + $data + it2.util.getProperty($property) + " !== undefined ";
          if ($ownProperties) {
            out += " && Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($property) + "') ";
          }
          if ($breakOnError) {
            out += " && ( ";
            var arr1 = $deps;
            if (arr1) {
              var $propertyKey, $i = -1, l1 = arr1.length - 1;
              while ($i < l1) {
                $propertyKey = arr1[$i += 1];
                if ($i) {
                  out += " || ";
                }
                var $prop = it2.util.getProperty($propertyKey), $useData = $data + $prop;
                out += " ( ( " + $useData + " === undefined ";
                if ($ownProperties) {
                  out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                }
                out += ") && (missing" + $lvl + " = " + it2.util.toQuotedString(it2.opts.jsonPointers ? $propertyKey : $prop) + ") ) ";
              }
            }
            out += ")) {  ";
            var $propertyPath = "missing" + $lvl, $missingProperty = "' + " + $propertyPath + " + '";
            if (it2.opts._errorDataPathProperty) {
              it2.errorPath = it2.opts.jsonPointers ? it2.util.getPathExpr($currentErrorPath, $propertyPath, true) : $currentErrorPath + " + " + $propertyPath;
            }
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: 'dependencies' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { property: '" + it2.util.escapeQuotes($property) + "', missingProperty: '" + $missingProperty + "', depsCount: " + $deps.length + ", deps: '" + it2.util.escapeQuotes($deps.length == 1 ? $deps[0] : $deps.join(", ")) + "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: 'should have ";
                if ($deps.length == 1) {
                  out += "property " + it2.util.escapeQuotes($deps[0]);
                } else {
                  out += "properties " + it2.util.escapeQuotes($deps.join(", "));
                }
                out += " when property " + it2.util.escapeQuotes($property) + " is present' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
          } else {
            out += " ) { ";
            var arr2 = $deps;
            if (arr2) {
              var $propertyKey, i2 = -1, l2 = arr2.length - 1;
              while (i2 < l2) {
                $propertyKey = arr2[i2 += 1];
                var $prop = it2.util.getProperty($propertyKey), $missingProperty = it2.util.escapeQuotes($propertyKey), $useData = $data + $prop;
                if (it2.opts._errorDataPathProperty) {
                  it2.errorPath = it2.util.getPath($currentErrorPath, $propertyKey, it2.opts.jsonPointers);
                }
                out += " if ( " + $useData + " === undefined ";
                if ($ownProperties) {
                  out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                }
                out += ") {  var err =   ";
                if (it2.createErrors !== false) {
                  out += " { keyword: 'dependencies' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { property: '" + it2.util.escapeQuotes($property) + "', missingProperty: '" + $missingProperty + "', depsCount: " + $deps.length + ", deps: '" + it2.util.escapeQuotes($deps.length == 1 ? $deps[0] : $deps.join(", ")) + "' } ";
                  if (it2.opts.messages !== false) {
                    out += " , message: 'should have ";
                    if ($deps.length == 1) {
                      out += "property " + it2.util.escapeQuotes($deps[0]);
                    } else {
                      out += "properties " + it2.util.escapeQuotes($deps.join(", "));
                    }
                    out += " when property " + it2.util.escapeQuotes($property) + " is present' ";
                  }
                  if (it2.opts.verbose) {
                    out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                  }
                  out += " } ";
                } else {
                  out += " {} ";
                }
                out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } ";
              }
            }
          }
          out += " }   ";
          if ($breakOnError) {
            $closingBraces += "}";
            out += " else { ";
          }
        }
      }
      it2.errorPath = $currentErrorPath;
      var $currentBaseId = $it.baseId;
      for (var $property in $schemaDeps) {
        var $sch = $schemaDeps[$property];
        if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
          out += " " + $nextValid + " = true; if ( " + $data + it2.util.getProperty($property) + " !== undefined ";
          if ($ownProperties) {
            out += " && Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($property) + "') ";
          }
          out += ") { ";
          $it.schema = $sch;
          $it.schemaPath = $schemaPath + it2.util.getProperty($property);
          $it.errSchemaPath = $errSchemaPath + "/" + it2.util.escapeFragment($property);
          out += "  " + it2.validate($it) + " ";
          $it.baseId = $currentBaseId;
          out += " }  ";
          if ($breakOnError) {
            out += " if (" + $nextValid + ") { ";
            $closingBraces += "}";
          }
        }
      }
      if ($breakOnError) {
        out += "   " + $closingBraces + " if (" + $errs + " == errors) {";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/enum.js
var require_enum = __commonJS({
  "node_modules/ajv/lib/dotjs/enum.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_enum(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $i = "i" + $lvl, $vSchema = "schema" + $lvl;
      if (!$isData) {
        out += " var " + $vSchema + " = validate.schema" + $schemaPath + ";";
      }
      out += "var " + $valid + ";";
      if ($isData) {
        out += " if (schema" + $lvl + " === undefined) " + $valid + " = true; else if (!Array.isArray(schema" + $lvl + ")) " + $valid + " = false; else {";
      }
      out += "" + $valid + " = false;for (var " + $i + "=0; " + $i + "<" + $vSchema + ".length; " + $i + "++) if (equal(" + $data + ", " + $vSchema + "[" + $i + "])) { " + $valid + " = true; break; }";
      if ($isData) {
        out += "  }  ";
      }
      out += " if (!" + $valid + ") {   ";
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'enum' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { allowedValues: schema" + $lvl + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should be equal to one of the allowed values' ";
        }
        if (it2.opts.verbose) {
          out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += " }";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/format.js
var require_format = __commonJS({
  "node_modules/ajv/lib/dotjs/format.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_format(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      if (it2.opts.format === false) {
        if ($breakOnError) {
          out += " if (true) { ";
        }
        return out;
      }
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $unknownFormats = it2.opts.unknownFormats, $allowUnknown = Array.isArray($unknownFormats);
      if ($isData) {
        var $format = "format" + $lvl, $isObject = "isObject" + $lvl, $formatType = "formatType" + $lvl;
        out += " var " + $format + " = formats[" + $schemaValue + "]; var " + $isObject + " = typeof " + $format + " == 'object' && !(" + $format + " instanceof RegExp) && " + $format + ".validate; var " + $formatType + " = " + $isObject + " && " + $format + ".type || 'string'; if (" + $isObject + ") { ";
        if (it2.async) {
          out += " var async" + $lvl + " = " + $format + ".async; ";
        }
        out += " " + $format + " = " + $format + ".validate; } if (  ";
        if ($isData) {
          out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'string') || ";
        }
        out += " (";
        if ($unknownFormats != "ignore") {
          out += " (" + $schemaValue + " && !" + $format + " ";
          if ($allowUnknown) {
            out += " && self._opts.unknownFormats.indexOf(" + $schemaValue + ") == -1 ";
          }
          out += ") || ";
        }
        out += " (" + $format + " && " + $formatType + " == '" + $ruleType + "' && !(typeof " + $format + " == 'function' ? ";
        if (it2.async) {
          out += " (async" + $lvl + " ? await " + $format + "(" + $data + ") : " + $format + "(" + $data + ")) ";
        } else {
          out += " " + $format + "(" + $data + ") ";
        }
        out += " : " + $format + ".test(" + $data + "))))) {";
      } else {
        var $format = it2.formats[$schema];
        if (!$format) {
          if ($unknownFormats == "ignore") {
            it2.logger.warn('unknown format "' + $schema + '" ignored in schema at path "' + it2.errSchemaPath + '"');
            if ($breakOnError) {
              out += " if (true) { ";
            }
            return out;
          } else if ($allowUnknown && $unknownFormats.indexOf($schema) >= 0) {
            if ($breakOnError) {
              out += " if (true) { ";
            }
            return out;
          } else {
            throw new Error('unknown format "' + $schema + '" is used in schema at path "' + it2.errSchemaPath + '"');
          }
        }
        var $isObject = typeof $format == "object" && !($format instanceof RegExp) && $format.validate;
        var $formatType = $isObject && $format.type || "string";
        if ($isObject) {
          var $async = $format.async === true;
          $format = $format.validate;
        }
        if ($formatType != $ruleType) {
          if ($breakOnError) {
            out += " if (true) { ";
          }
          return out;
        }
        if ($async) {
          if (!it2.async)
            throw new Error("async format in sync schema");
          var $formatRef = "formats" + it2.util.getProperty($schema) + ".validate";
          out += " if (!(await " + $formatRef + "(" + $data + "))) { ";
        } else {
          out += " if (! ";
          var $formatRef = "formats" + it2.util.getProperty($schema);
          if ($isObject)
            $formatRef += ".validate";
          if (typeof $format == "function") {
            out += " " + $formatRef + "(" + $data + ") ";
          } else {
            out += " " + $formatRef + ".test(" + $data + ") ";
          }
          out += ") { ";
        }
      }
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'format' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { format:  ";
        if ($isData) {
          out += "" + $schemaValue;
        } else {
          out += "" + it2.util.toQuotedString($schema);
        }
        out += "  } ";
        if (it2.opts.messages !== false) {
          out += ` , message: 'should match format "`;
          if ($isData) {
            out += "' + " + $schemaValue + " + '";
          } else {
            out += "" + it2.util.escapeQuotes($schema);
          }
          out += `"' `;
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + it2.util.toQuotedString($schema);
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += " } ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/if.js
var require_if = __commonJS({
  "node_modules/ajv/lib/dotjs/if.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_if(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $thenSch = it2.schema["then"], $elseSch = it2.schema["else"], $thenPresent = $thenSch !== void 0 && (it2.opts.strictKeywords ? typeof $thenSch == "object" && Object.keys($thenSch).length > 0 || $thenSch === false : it2.util.schemaHasRules($thenSch, it2.RULES.all)), $elsePresent = $elseSch !== void 0 && (it2.opts.strictKeywords ? typeof $elseSch == "object" && Object.keys($elseSch).length > 0 || $elseSch === false : it2.util.schemaHasRules($elseSch, it2.RULES.all)), $currentBaseId = $it.baseId;
      if ($thenPresent || $elsePresent) {
        var $ifClause;
        $it.createErrors = false;
        $it.schema = $schema;
        $it.schemaPath = $schemaPath;
        $it.errSchemaPath = $errSchemaPath;
        out += " var " + $errs + " = errors; var " + $valid + " = true;  ";
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        out += "  " + it2.validate($it) + " ";
        $it.baseId = $currentBaseId;
        $it.createErrors = true;
        out += "  errors = " + $errs + "; if (vErrors !== null) { if (" + $errs + ") vErrors.length = " + $errs + "; else vErrors = null; }  ";
        it2.compositeRule = $it.compositeRule = $wasComposite;
        if ($thenPresent) {
          out += " if (" + $nextValid + ") {  ";
          $it.schema = it2.schema["then"];
          $it.schemaPath = it2.schemaPath + ".then";
          $it.errSchemaPath = it2.errSchemaPath + "/then";
          out += "  " + it2.validate($it) + " ";
          $it.baseId = $currentBaseId;
          out += " " + $valid + " = " + $nextValid + "; ";
          if ($thenPresent && $elsePresent) {
            $ifClause = "ifClause" + $lvl;
            out += " var " + $ifClause + " = 'then'; ";
          } else {
            $ifClause = "'then'";
          }
          out += " } ";
          if ($elsePresent) {
            out += " else { ";
          }
        } else {
          out += " if (!" + $nextValid + ") { ";
        }
        if ($elsePresent) {
          $it.schema = it2.schema["else"];
          $it.schemaPath = it2.schemaPath + ".else";
          $it.errSchemaPath = it2.errSchemaPath + "/else";
          out += "  " + it2.validate($it) + " ";
          $it.baseId = $currentBaseId;
          out += " " + $valid + " = " + $nextValid + "; ";
          if ($thenPresent && $elsePresent) {
            $ifClause = "ifClause" + $lvl;
            out += " var " + $ifClause + " = 'else'; ";
          } else {
            $ifClause = "'else'";
          }
          out += " } ";
        }
        out += " if (!" + $valid + ") {   var err =   ";
        if (it2.createErrors !== false) {
          out += " { keyword: 'if' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { failingKeyword: " + $ifClause + " } ";
          if (it2.opts.messages !== false) {
            out += ` , message: 'should match "' + ` + $ifClause + ` + '" schema' `;
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError(vErrors); ";
          } else {
            out += " validate.errors = vErrors; return false; ";
          }
        }
        out += " }   ";
        if ($breakOnError) {
          out += " else { ";
        }
      } else {
        if ($breakOnError) {
          out += " if (true) { ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/items.js
var require_items = __commonJS({
  "node_modules/ajv/lib/dotjs/items.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_items(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $idx = "i" + $lvl, $dataNxt = $it.dataLevel = it2.dataLevel + 1, $nextData = "data" + $dataNxt, $currentBaseId = it2.baseId;
      out += "var " + $errs + " = errors;var " + $valid + ";";
      if (Array.isArray($schema)) {
        var $additionalItems = it2.schema.additionalItems;
        if ($additionalItems === false) {
          out += " " + $valid + " = " + $data + ".length <= " + $schema.length + "; ";
          var $currErrSchemaPath = $errSchemaPath;
          $errSchemaPath = it2.errSchemaPath + "/additionalItems";
          out += "  if (!" + $valid + ") {   ";
          var $$outStack = $$outStack || [];
          $$outStack.push(out);
          out = "";
          if (it2.createErrors !== false) {
            out += " { keyword: 'additionalItems' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { limit: " + $schema.length + " } ";
            if (it2.opts.messages !== false) {
              out += " , message: 'should NOT have more than " + $schema.length + " items' ";
            }
            if (it2.opts.verbose) {
              out += " , schema: false , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
            }
            out += " } ";
          } else {
            out += " {} ";
          }
          var __err = out;
          out = $$outStack.pop();
          if (!it2.compositeRule && $breakOnError) {
            if (it2.async) {
              out += " throw new ValidationError([" + __err + "]); ";
            } else {
              out += " validate.errors = [" + __err + "]; return false; ";
            }
          } else {
            out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
          }
          out += " } ";
          $errSchemaPath = $currErrSchemaPath;
          if ($breakOnError) {
            $closingBraces += "}";
            out += " else { ";
          }
        }
        var arr1 = $schema;
        if (arr1) {
          var $sch, $i = -1, l1 = arr1.length - 1;
          while ($i < l1) {
            $sch = arr1[$i += 1];
            if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
              out += " " + $nextValid + " = true; if (" + $data + ".length > " + $i + ") { ";
              var $passData = $data + "[" + $i + "]";
              $it.schema = $sch;
              $it.schemaPath = $schemaPath + "[" + $i + "]";
              $it.errSchemaPath = $errSchemaPath + "/" + $i;
              $it.errorPath = it2.util.getPathExpr(it2.errorPath, $i, it2.opts.jsonPointers, true);
              $it.dataPathArr[$dataNxt] = $i;
              var $code = it2.validate($it);
              $it.baseId = $currentBaseId;
              if (it2.util.varOccurences($code, $nextData) < 2) {
                out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
              } else {
                out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
              }
              out += " }  ";
              if ($breakOnError) {
                out += " if (" + $nextValid + ") { ";
                $closingBraces += "}";
              }
            }
          }
        }
        if (typeof $additionalItems == "object" && (it2.opts.strictKeywords ? typeof $additionalItems == "object" && Object.keys($additionalItems).length > 0 || $additionalItems === false : it2.util.schemaHasRules($additionalItems, it2.RULES.all))) {
          $it.schema = $additionalItems;
          $it.schemaPath = it2.schemaPath + ".additionalItems";
          $it.errSchemaPath = it2.errSchemaPath + "/additionalItems";
          out += " " + $nextValid + " = true; if (" + $data + ".length > " + $schema.length + ") {  for (var " + $idx + " = " + $schema.length + "; " + $idx + " < " + $data + ".length; " + $idx + "++) { ";
          $it.errorPath = it2.util.getPathExpr(it2.errorPath, $idx, it2.opts.jsonPointers, true);
          var $passData = $data + "[" + $idx + "]";
          $it.dataPathArr[$dataNxt] = $idx;
          var $code = it2.validate($it);
          $it.baseId = $currentBaseId;
          if (it2.util.varOccurences($code, $nextData) < 2) {
            out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
          } else {
            out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
          }
          if ($breakOnError) {
            out += " if (!" + $nextValid + ") break; ";
          }
          out += " } }  ";
          if ($breakOnError) {
            out += " if (" + $nextValid + ") { ";
            $closingBraces += "}";
          }
        }
      } else if (it2.opts.strictKeywords ? typeof $schema == "object" && Object.keys($schema).length > 0 || $schema === false : it2.util.schemaHasRules($schema, it2.RULES.all)) {
        $it.schema = $schema;
        $it.schemaPath = $schemaPath;
        $it.errSchemaPath = $errSchemaPath;
        out += "  for (var " + $idx + " = 0; " + $idx + " < " + $data + ".length; " + $idx + "++) { ";
        $it.errorPath = it2.util.getPathExpr(it2.errorPath, $idx, it2.opts.jsonPointers, true);
        var $passData = $data + "[" + $idx + "]";
        $it.dataPathArr[$dataNxt] = $idx;
        var $code = it2.validate($it);
        $it.baseId = $currentBaseId;
        if (it2.util.varOccurences($code, $nextData) < 2) {
          out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
        } else {
          out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
        }
        if ($breakOnError) {
          out += " if (!" + $nextValid + ") break; ";
        }
        out += " }";
      }
      if ($breakOnError) {
        out += " " + $closingBraces + " if (" + $errs + " == errors) {";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/_limit.js
var require_limit = __commonJS({
  "node_modules/ajv/lib/dotjs/_limit.js"(exports, module2) {
    "use strict";
    module2.exports = function generate__limit(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $errorKeyword;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $isMax = $keyword == "maximum", $exclusiveKeyword = $isMax ? "exclusiveMaximum" : "exclusiveMinimum", $schemaExcl = it2.schema[$exclusiveKeyword], $isDataExcl = it2.opts.$data && $schemaExcl && $schemaExcl.$data, $op = $isMax ? "<" : ">", $notOp = $isMax ? ">" : "<", $errorKeyword = void 0;
      if (!($isData || typeof $schema == "number" || $schema === void 0)) {
        throw new Error($keyword + " must be number");
      }
      if (!($isDataExcl || $schemaExcl === void 0 || typeof $schemaExcl == "number" || typeof $schemaExcl == "boolean")) {
        throw new Error($exclusiveKeyword + " must be number or boolean");
      }
      if ($isDataExcl) {
        var $schemaValueExcl = it2.util.getData($schemaExcl.$data, $dataLvl, it2.dataPathArr), $exclusive = "exclusive" + $lvl, $exclType = "exclType" + $lvl, $exclIsNumber = "exclIsNumber" + $lvl, $opExpr = "op" + $lvl, $opStr = "' + " + $opExpr + " + '";
        out += " var schemaExcl" + $lvl + " = " + $schemaValueExcl + "; ";
        $schemaValueExcl = "schemaExcl" + $lvl;
        out += " var " + $exclusive + "; var " + $exclType + " = typeof " + $schemaValueExcl + "; if (" + $exclType + " != 'boolean' && " + $exclType + " != 'undefined' && " + $exclType + " != 'number') { ";
        var $errorKeyword = $exclusiveKeyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        if (it2.createErrors !== false) {
          out += " { keyword: '" + ($errorKeyword || "_exclusiveLimit") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
          if (it2.opts.messages !== false) {
            out += " , message: '" + $exclusiveKeyword + " should be boolean' ";
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError([" + __err + "]); ";
          } else {
            out += " validate.errors = [" + __err + "]; return false; ";
          }
        } else {
          out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        }
        out += " } else if ( ";
        if ($isData) {
          out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
        }
        out += " " + $exclType + " == 'number' ? ( (" + $exclusive + " = " + $schemaValue + " === undefined || " + $schemaValueExcl + " " + $op + "= " + $schemaValue + ") ? " + $data + " " + $notOp + "= " + $schemaValueExcl + " : " + $data + " " + $notOp + " " + $schemaValue + " ) : ( (" + $exclusive + " = " + $schemaValueExcl + " === true) ? " + $data + " " + $notOp + "= " + $schemaValue + " : " + $data + " " + $notOp + " " + $schemaValue + " ) || " + $data + " !== " + $data + ") { var op" + $lvl + " = " + $exclusive + " ? '" + $op + "' : '" + $op + "='; ";
        if ($schema === void 0) {
          $errorKeyword = $exclusiveKeyword;
          $errSchemaPath = it2.errSchemaPath + "/" + $exclusiveKeyword;
          $schemaValue = $schemaValueExcl;
          $isData = $isDataExcl;
        }
      } else {
        var $exclIsNumber = typeof $schemaExcl == "number", $opStr = $op;
        if ($exclIsNumber && $isData) {
          var $opExpr = "'" + $opStr + "'";
          out += " if ( ";
          if ($isData) {
            out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
          }
          out += " ( " + $schemaValue + " === undefined || " + $schemaExcl + " " + $op + "= " + $schemaValue + " ? " + $data + " " + $notOp + "= " + $schemaExcl + " : " + $data + " " + $notOp + " " + $schemaValue + " ) || " + $data + " !== " + $data + ") { ";
        } else {
          if ($exclIsNumber && $schema === void 0) {
            $exclusive = true;
            $errorKeyword = $exclusiveKeyword;
            $errSchemaPath = it2.errSchemaPath + "/" + $exclusiveKeyword;
            $schemaValue = $schemaExcl;
            $notOp += "=";
          } else {
            if ($exclIsNumber)
              $schemaValue = Math[$isMax ? "min" : "max"]($schemaExcl, $schema);
            if ($schemaExcl === ($exclIsNumber ? $schemaValue : true)) {
              $exclusive = true;
              $errorKeyword = $exclusiveKeyword;
              $errSchemaPath = it2.errSchemaPath + "/" + $exclusiveKeyword;
              $notOp += "=";
            } else {
              $exclusive = false;
              $opStr += "=";
            }
          }
          var $opExpr = "'" + $opStr + "'";
          out += " if ( ";
          if ($isData) {
            out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
          }
          out += " " + $data + " " + $notOp + " " + $schemaValue + " || " + $data + " !== " + $data + ") { ";
        }
      }
      $errorKeyword = $errorKeyword || $keyword;
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: '" + ($errorKeyword || "_limit") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { comparison: " + $opExpr + ", limit: " + $schemaValue + ", exclusive: " + $exclusive + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should be " + $opStr + " ";
          if ($isData) {
            out += "' + " + $schemaValue;
          } else {
            out += "" + $schemaValue + "'";
          }
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + $schema;
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += " } ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/_limitItems.js
var require_limitItems = __commonJS({
  "node_modules/ajv/lib/dotjs/_limitItems.js"(exports, module2) {
    "use strict";
    module2.exports = function generate__limitItems(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $errorKeyword;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (!($isData || typeof $schema == "number")) {
        throw new Error($keyword + " must be number");
      }
      var $op = $keyword == "maxItems" ? ">" : "<";
      out += "if ( ";
      if ($isData) {
        out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
      }
      out += " " + $data + ".length " + $op + " " + $schemaValue + ") { ";
      var $errorKeyword = $keyword;
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: '" + ($errorKeyword || "_limitItems") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { limit: " + $schemaValue + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should NOT have ";
          if ($keyword == "maxItems") {
            out += "more";
          } else {
            out += "fewer";
          }
          out += " than ";
          if ($isData) {
            out += "' + " + $schemaValue + " + '";
          } else {
            out += "" + $schema;
          }
          out += " items' ";
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + $schema;
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += "} ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/_limitLength.js
var require_limitLength = __commonJS({
  "node_modules/ajv/lib/dotjs/_limitLength.js"(exports, module2) {
    "use strict";
    module2.exports = function generate__limitLength(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $errorKeyword;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (!($isData || typeof $schema == "number")) {
        throw new Error($keyword + " must be number");
      }
      var $op = $keyword == "maxLength" ? ">" : "<";
      out += "if ( ";
      if ($isData) {
        out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
      }
      if (it2.opts.unicode === false) {
        out += " " + $data + ".length ";
      } else {
        out += " ucs2length(" + $data + ") ";
      }
      out += " " + $op + " " + $schemaValue + ") { ";
      var $errorKeyword = $keyword;
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: '" + ($errorKeyword || "_limitLength") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { limit: " + $schemaValue + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should NOT be ";
          if ($keyword == "maxLength") {
            out += "longer";
          } else {
            out += "shorter";
          }
          out += " than ";
          if ($isData) {
            out += "' + " + $schemaValue + " + '";
          } else {
            out += "" + $schema;
          }
          out += " characters' ";
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + $schema;
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += "} ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/_limitProperties.js
var require_limitProperties = __commonJS({
  "node_modules/ajv/lib/dotjs/_limitProperties.js"(exports, module2) {
    "use strict";
    module2.exports = function generate__limitProperties(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $errorKeyword;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (!($isData || typeof $schema == "number")) {
        throw new Error($keyword + " must be number");
      }
      var $op = $keyword == "maxProperties" ? ">" : "<";
      out += "if ( ";
      if ($isData) {
        out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'number') || ";
      }
      out += " Object.keys(" + $data + ").length " + $op + " " + $schemaValue + ") { ";
      var $errorKeyword = $keyword;
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: '" + ($errorKeyword || "_limitProperties") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { limit: " + $schemaValue + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should NOT have ";
          if ($keyword == "maxProperties") {
            out += "more";
          } else {
            out += "fewer";
          }
          out += " than ";
          if ($isData) {
            out += "' + " + $schemaValue + " + '";
          } else {
            out += "" + $schema;
          }
          out += " properties' ";
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + $schema;
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += "} ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/multipleOf.js
var require_multipleOf = __commonJS({
  "node_modules/ajv/lib/dotjs/multipleOf.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_multipleOf(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (!($isData || typeof $schema == "number")) {
        throw new Error($keyword + " must be number");
      }
      out += "var division" + $lvl + ";if (";
      if ($isData) {
        out += " " + $schemaValue + " !== undefined && ( typeof " + $schemaValue + " != 'number' || ";
      }
      out += " (division" + $lvl + " = " + $data + " / " + $schemaValue + ", ";
      if (it2.opts.multipleOfPrecision) {
        out += " Math.abs(Math.round(division" + $lvl + ") - division" + $lvl + ") > 1e-" + it2.opts.multipleOfPrecision + " ";
      } else {
        out += " division" + $lvl + " !== parseInt(division" + $lvl + ") ";
      }
      out += " ) ";
      if ($isData) {
        out += "  )  ";
      }
      out += " ) {   ";
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'multipleOf' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { multipleOf: " + $schemaValue + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should be multiple of ";
          if ($isData) {
            out += "' + " + $schemaValue;
          } else {
            out += "" + $schemaValue + "'";
          }
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + $schema;
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += "} ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/not.js
var require_not2 = __commonJS({
  "node_modules/ajv/lib/dotjs/not.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_not(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      $it.level++;
      var $nextValid = "valid" + $it.level;
      if (it2.opts.strictKeywords ? typeof $schema == "object" && Object.keys($schema).length > 0 || $schema === false : it2.util.schemaHasRules($schema, it2.RULES.all)) {
        $it.schema = $schema;
        $it.schemaPath = $schemaPath;
        $it.errSchemaPath = $errSchemaPath;
        out += " var " + $errs + " = errors;  ";
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        $it.createErrors = false;
        var $allErrorsOption;
        if ($it.opts.allErrors) {
          $allErrorsOption = $it.opts.allErrors;
          $it.opts.allErrors = false;
        }
        out += " " + it2.validate($it) + " ";
        $it.createErrors = true;
        if ($allErrorsOption)
          $it.opts.allErrors = $allErrorsOption;
        it2.compositeRule = $it.compositeRule = $wasComposite;
        out += " if (" + $nextValid + ") {   ";
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        if (it2.createErrors !== false) {
          out += " { keyword: 'not' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
          if (it2.opts.messages !== false) {
            out += " , message: 'should NOT be valid' ";
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError([" + __err + "]); ";
          } else {
            out += " validate.errors = [" + __err + "]; return false; ";
          }
        } else {
          out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        }
        out += " } else {  errors = " + $errs + "; if (vErrors !== null) { if (" + $errs + ") vErrors.length = " + $errs + "; else vErrors = null; } ";
        if (it2.opts.allErrors) {
          out += " } ";
        }
      } else {
        out += "  var err =   ";
        if (it2.createErrors !== false) {
          out += " { keyword: 'not' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: {} ";
          if (it2.opts.messages !== false) {
            out += " , message: 'should NOT be valid' ";
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        if ($breakOnError) {
          out += " if (false) { ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/oneOf.js
var require_oneOf = __commonJS({
  "node_modules/ajv/lib/dotjs/oneOf.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_oneOf(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $currentBaseId = $it.baseId, $prevValid = "prevValid" + $lvl, $passingSchemas = "passingSchemas" + $lvl;
      out += "var " + $errs + " = errors , " + $prevValid + " = false , " + $valid + " = false , " + $passingSchemas + " = null; ";
      var $wasComposite = it2.compositeRule;
      it2.compositeRule = $it.compositeRule = true;
      var arr1 = $schema;
      if (arr1) {
        var $sch, $i = -1, l1 = arr1.length - 1;
        while ($i < l1) {
          $sch = arr1[$i += 1];
          if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
            $it.schema = $sch;
            $it.schemaPath = $schemaPath + "[" + $i + "]";
            $it.errSchemaPath = $errSchemaPath + "/" + $i;
            out += "  " + it2.validate($it) + " ";
            $it.baseId = $currentBaseId;
          } else {
            out += " var " + $nextValid + " = true; ";
          }
          if ($i) {
            out += " if (" + $nextValid + " && " + $prevValid + ") { " + $valid + " = false; " + $passingSchemas + " = [" + $passingSchemas + ", " + $i + "]; } else { ";
            $closingBraces += "}";
          }
          out += " if (" + $nextValid + ") { " + $valid + " = " + $prevValid + " = true; " + $passingSchemas + " = " + $i + "; }";
        }
      }
      it2.compositeRule = $it.compositeRule = $wasComposite;
      out += "" + $closingBraces + "if (!" + $valid + ") {   var err =   ";
      if (it2.createErrors !== false) {
        out += " { keyword: 'oneOf' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { passingSchemas: " + $passingSchemas + " } ";
        if (it2.opts.messages !== false) {
          out += " , message: 'should match exactly one schema in oneOf' ";
        }
        if (it2.opts.verbose) {
          out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError(vErrors); ";
        } else {
          out += " validate.errors = vErrors; return false; ";
        }
      }
      out += "} else {  errors = " + $errs + "; if (vErrors !== null) { if (" + $errs + ") vErrors.length = " + $errs + "; else vErrors = null; }";
      if (it2.opts.allErrors) {
        out += " } ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/pattern.js
var require_pattern = __commonJS({
  "node_modules/ajv/lib/dotjs/pattern.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_pattern(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $regexp = $isData ? "(new RegExp(" + $schemaValue + "))" : it2.usePattern($schema);
      out += "if ( ";
      if ($isData) {
        out += " (" + $schemaValue + " !== undefined && typeof " + $schemaValue + " != 'string') || ";
      }
      out += " !" + $regexp + ".test(" + $data + ") ) {   ";
      var $$outStack = $$outStack || [];
      $$outStack.push(out);
      out = "";
      if (it2.createErrors !== false) {
        out += " { keyword: 'pattern' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { pattern:  ";
        if ($isData) {
          out += "" + $schemaValue;
        } else {
          out += "" + it2.util.toQuotedString($schema);
        }
        out += "  } ";
        if (it2.opts.messages !== false) {
          out += ` , message: 'should match pattern "`;
          if ($isData) {
            out += "' + " + $schemaValue + " + '";
          } else {
            out += "" + it2.util.escapeQuotes($schema);
          }
          out += `"' `;
        }
        if (it2.opts.verbose) {
          out += " , schema:  ";
          if ($isData) {
            out += "validate.schema" + $schemaPath;
          } else {
            out += "" + it2.util.toQuotedString($schema);
          }
          out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
        }
        out += " } ";
      } else {
        out += " {} ";
      }
      var __err = out;
      out = $$outStack.pop();
      if (!it2.compositeRule && $breakOnError) {
        if (it2.async) {
          out += " throw new ValidationError([" + __err + "]); ";
        } else {
          out += " validate.errors = [" + __err + "]; return false; ";
        }
      } else {
        out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
      }
      out += "} ";
      if ($breakOnError) {
        out += " else { ";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/properties.js
var require_properties = __commonJS({
  "node_modules/ajv/lib/dotjs/properties.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_properties(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      var $key = "key" + $lvl, $idx = "idx" + $lvl, $dataNxt = $it.dataLevel = it2.dataLevel + 1, $nextData = "data" + $dataNxt, $dataProperties = "dataProperties" + $lvl;
      var $schemaKeys = Object.keys($schema || {}).filter(notProto), $pProperties = it2.schema.patternProperties || {}, $pPropertyKeys = Object.keys($pProperties).filter(notProto), $aProperties = it2.schema.additionalProperties, $someProperties = $schemaKeys.length || $pPropertyKeys.length, $noAdditional = $aProperties === false, $additionalIsSchema = typeof $aProperties == "object" && Object.keys($aProperties).length, $removeAdditional = it2.opts.removeAdditional, $checkAdditional = $noAdditional || $additionalIsSchema || $removeAdditional, $ownProperties = it2.opts.ownProperties, $currentBaseId = it2.baseId;
      var $required = it2.schema.required;
      if ($required && !(it2.opts.$data && $required.$data) && $required.length < it2.opts.loopRequired) {
        var $requiredHash = it2.util.toHash($required);
      }
      function notProto(p) {
        return p !== "__proto__";
      }
      out += "var " + $errs + " = errors;var " + $nextValid + " = true;";
      if ($ownProperties) {
        out += " var " + $dataProperties + " = undefined;";
      }
      if ($checkAdditional) {
        if ($ownProperties) {
          out += " " + $dataProperties + " = " + $dataProperties + " || Object.keys(" + $data + "); for (var " + $idx + "=0; " + $idx + "<" + $dataProperties + ".length; " + $idx + "++) { var " + $key + " = " + $dataProperties + "[" + $idx + "]; ";
        } else {
          out += " for (var " + $key + " in " + $data + ") { ";
        }
        if ($someProperties) {
          out += " var isAdditional" + $lvl + " = !(false ";
          if ($schemaKeys.length) {
            if ($schemaKeys.length > 8) {
              out += " || validate.schema" + $schemaPath + ".hasOwnProperty(" + $key + ") ";
            } else {
              var arr1 = $schemaKeys;
              if (arr1) {
                var $propertyKey, i1 = -1, l1 = arr1.length - 1;
                while (i1 < l1) {
                  $propertyKey = arr1[i1 += 1];
                  out += " || " + $key + " == " + it2.util.toQuotedString($propertyKey) + " ";
                }
              }
            }
          }
          if ($pPropertyKeys.length) {
            var arr2 = $pPropertyKeys;
            if (arr2) {
              var $pProperty, $i = -1, l2 = arr2.length - 1;
              while ($i < l2) {
                $pProperty = arr2[$i += 1];
                out += " || " + it2.usePattern($pProperty) + ".test(" + $key + ") ";
              }
            }
          }
          out += " ); if (isAdditional" + $lvl + ") { ";
        }
        if ($removeAdditional == "all") {
          out += " delete " + $data + "[" + $key + "]; ";
        } else {
          var $currentErrorPath = it2.errorPath;
          var $additionalProperty = "' + " + $key + " + '";
          if (it2.opts._errorDataPathProperty) {
            it2.errorPath = it2.util.getPathExpr(it2.errorPath, $key, it2.opts.jsonPointers);
          }
          if ($noAdditional) {
            if ($removeAdditional) {
              out += " delete " + $data + "[" + $key + "]; ";
            } else {
              out += " " + $nextValid + " = false; ";
              var $currErrSchemaPath = $errSchemaPath;
              $errSchemaPath = it2.errSchemaPath + "/additionalProperties";
              var $$outStack = $$outStack || [];
              $$outStack.push(out);
              out = "";
              if (it2.createErrors !== false) {
                out += " { keyword: 'additionalProperties' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { additionalProperty: '" + $additionalProperty + "' } ";
                if (it2.opts.messages !== false) {
                  out += " , message: '";
                  if (it2.opts._errorDataPathProperty) {
                    out += "is an invalid additional property";
                  } else {
                    out += "should NOT have additional properties";
                  }
                  out += "' ";
                }
                if (it2.opts.verbose) {
                  out += " , schema: false , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                }
                out += " } ";
              } else {
                out += " {} ";
              }
              var __err = out;
              out = $$outStack.pop();
              if (!it2.compositeRule && $breakOnError) {
                if (it2.async) {
                  out += " throw new ValidationError([" + __err + "]); ";
                } else {
                  out += " validate.errors = [" + __err + "]; return false; ";
                }
              } else {
                out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
              }
              $errSchemaPath = $currErrSchemaPath;
              if ($breakOnError) {
                out += " break; ";
              }
            }
          } else if ($additionalIsSchema) {
            if ($removeAdditional == "failing") {
              out += " var " + $errs + " = errors;  ";
              var $wasComposite = it2.compositeRule;
              it2.compositeRule = $it.compositeRule = true;
              $it.schema = $aProperties;
              $it.schemaPath = it2.schemaPath + ".additionalProperties";
              $it.errSchemaPath = it2.errSchemaPath + "/additionalProperties";
              $it.errorPath = it2.opts._errorDataPathProperty ? it2.errorPath : it2.util.getPathExpr(it2.errorPath, $key, it2.opts.jsonPointers);
              var $passData = $data + "[" + $key + "]";
              $it.dataPathArr[$dataNxt] = $key;
              var $code = it2.validate($it);
              $it.baseId = $currentBaseId;
              if (it2.util.varOccurences($code, $nextData) < 2) {
                out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
              } else {
                out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
              }
              out += " if (!" + $nextValid + ") { errors = " + $errs + "; if (validate.errors !== null) { if (errors) validate.errors.length = errors; else validate.errors = null; } delete " + $data + "[" + $key + "]; }  ";
              it2.compositeRule = $it.compositeRule = $wasComposite;
            } else {
              $it.schema = $aProperties;
              $it.schemaPath = it2.schemaPath + ".additionalProperties";
              $it.errSchemaPath = it2.errSchemaPath + "/additionalProperties";
              $it.errorPath = it2.opts._errorDataPathProperty ? it2.errorPath : it2.util.getPathExpr(it2.errorPath, $key, it2.opts.jsonPointers);
              var $passData = $data + "[" + $key + "]";
              $it.dataPathArr[$dataNxt] = $key;
              var $code = it2.validate($it);
              $it.baseId = $currentBaseId;
              if (it2.util.varOccurences($code, $nextData) < 2) {
                out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
              } else {
                out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
              }
              if ($breakOnError) {
                out += " if (!" + $nextValid + ") break; ";
              }
            }
          }
          it2.errorPath = $currentErrorPath;
        }
        if ($someProperties) {
          out += " } ";
        }
        out += " }  ";
        if ($breakOnError) {
          out += " if (" + $nextValid + ") { ";
          $closingBraces += "}";
        }
      }
      var $useDefaults = it2.opts.useDefaults && !it2.compositeRule;
      if ($schemaKeys.length) {
        var arr3 = $schemaKeys;
        if (arr3) {
          var $propertyKey, i3 = -1, l3 = arr3.length - 1;
          while (i3 < l3) {
            $propertyKey = arr3[i3 += 1];
            var $sch = $schema[$propertyKey];
            if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
              var $prop = it2.util.getProperty($propertyKey), $passData = $data + $prop, $hasDefault = $useDefaults && $sch.default !== void 0;
              $it.schema = $sch;
              $it.schemaPath = $schemaPath + $prop;
              $it.errSchemaPath = $errSchemaPath + "/" + it2.util.escapeFragment($propertyKey);
              $it.errorPath = it2.util.getPath(it2.errorPath, $propertyKey, it2.opts.jsonPointers);
              $it.dataPathArr[$dataNxt] = it2.util.toQuotedString($propertyKey);
              var $code = it2.validate($it);
              $it.baseId = $currentBaseId;
              if (it2.util.varOccurences($code, $nextData) < 2) {
                $code = it2.util.varReplace($code, $nextData, $passData);
                var $useData = $passData;
              } else {
                var $useData = $nextData;
                out += " var " + $nextData + " = " + $passData + "; ";
              }
              if ($hasDefault) {
                out += " " + $code + " ";
              } else {
                if ($requiredHash && $requiredHash[$propertyKey]) {
                  out += " if ( " + $useData + " === undefined ";
                  if ($ownProperties) {
                    out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                  }
                  out += ") { " + $nextValid + " = false; ";
                  var $currentErrorPath = it2.errorPath, $currErrSchemaPath = $errSchemaPath, $missingProperty = it2.util.escapeQuotes($propertyKey);
                  if (it2.opts._errorDataPathProperty) {
                    it2.errorPath = it2.util.getPath($currentErrorPath, $propertyKey, it2.opts.jsonPointers);
                  }
                  $errSchemaPath = it2.errSchemaPath + "/required";
                  var $$outStack = $$outStack || [];
                  $$outStack.push(out);
                  out = "";
                  if (it2.createErrors !== false) {
                    out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
                    if (it2.opts.messages !== false) {
                      out += " , message: '";
                      if (it2.opts._errorDataPathProperty) {
                        out += "is a required property";
                      } else {
                        out += "should have required property \\'" + $missingProperty + "\\'";
                      }
                      out += "' ";
                    }
                    if (it2.opts.verbose) {
                      out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                    }
                    out += " } ";
                  } else {
                    out += " {} ";
                  }
                  var __err = out;
                  out = $$outStack.pop();
                  if (!it2.compositeRule && $breakOnError) {
                    if (it2.async) {
                      out += " throw new ValidationError([" + __err + "]); ";
                    } else {
                      out += " validate.errors = [" + __err + "]; return false; ";
                    }
                  } else {
                    out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
                  }
                  $errSchemaPath = $currErrSchemaPath;
                  it2.errorPath = $currentErrorPath;
                  out += " } else { ";
                } else {
                  if ($breakOnError) {
                    out += " if ( " + $useData + " === undefined ";
                    if ($ownProperties) {
                      out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                    }
                    out += ") { " + $nextValid + " = true; } else { ";
                  } else {
                    out += " if (" + $useData + " !== undefined ";
                    if ($ownProperties) {
                      out += " &&   Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                    }
                    out += " ) { ";
                  }
                }
                out += " " + $code + " } ";
              }
            }
            if ($breakOnError) {
              out += " if (" + $nextValid + ") { ";
              $closingBraces += "}";
            }
          }
        }
      }
      if ($pPropertyKeys.length) {
        var arr4 = $pPropertyKeys;
        if (arr4) {
          var $pProperty, i4 = -1, l4 = arr4.length - 1;
          while (i4 < l4) {
            $pProperty = arr4[i4 += 1];
            var $sch = $pProperties[$pProperty];
            if (it2.opts.strictKeywords ? typeof $sch == "object" && Object.keys($sch).length > 0 || $sch === false : it2.util.schemaHasRules($sch, it2.RULES.all)) {
              $it.schema = $sch;
              $it.schemaPath = it2.schemaPath + ".patternProperties" + it2.util.getProperty($pProperty);
              $it.errSchemaPath = it2.errSchemaPath + "/patternProperties/" + it2.util.escapeFragment($pProperty);
              if ($ownProperties) {
                out += " " + $dataProperties + " = " + $dataProperties + " || Object.keys(" + $data + "); for (var " + $idx + "=0; " + $idx + "<" + $dataProperties + ".length; " + $idx + "++) { var " + $key + " = " + $dataProperties + "[" + $idx + "]; ";
              } else {
                out += " for (var " + $key + " in " + $data + ") { ";
              }
              out += " if (" + it2.usePattern($pProperty) + ".test(" + $key + ")) { ";
              $it.errorPath = it2.util.getPathExpr(it2.errorPath, $key, it2.opts.jsonPointers);
              var $passData = $data + "[" + $key + "]";
              $it.dataPathArr[$dataNxt] = $key;
              var $code = it2.validate($it);
              $it.baseId = $currentBaseId;
              if (it2.util.varOccurences($code, $nextData) < 2) {
                out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
              } else {
                out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
              }
              if ($breakOnError) {
                out += " if (!" + $nextValid + ") break; ";
              }
              out += " } ";
              if ($breakOnError) {
                out += " else " + $nextValid + " = true; ";
              }
              out += " }  ";
              if ($breakOnError) {
                out += " if (" + $nextValid + ") { ";
                $closingBraces += "}";
              }
            }
          }
        }
      }
      if ($breakOnError) {
        out += " " + $closingBraces + " if (" + $errs + " == errors) {";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/propertyNames.js
var require_propertyNames = __commonJS({
  "node_modules/ajv/lib/dotjs/propertyNames.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_propertyNames(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $errs = "errs__" + $lvl;
      var $it = it2.util.copy(it2);
      var $closingBraces = "";
      $it.level++;
      var $nextValid = "valid" + $it.level;
      out += "var " + $errs + " = errors;";
      if (it2.opts.strictKeywords ? typeof $schema == "object" && Object.keys($schema).length > 0 || $schema === false : it2.util.schemaHasRules($schema, it2.RULES.all)) {
        $it.schema = $schema;
        $it.schemaPath = $schemaPath;
        $it.errSchemaPath = $errSchemaPath;
        var $key = "key" + $lvl, $idx = "idx" + $lvl, $i = "i" + $lvl, $invalidName = "' + " + $key + " + '", $dataNxt = $it.dataLevel = it2.dataLevel + 1, $nextData = "data" + $dataNxt, $dataProperties = "dataProperties" + $lvl, $ownProperties = it2.opts.ownProperties, $currentBaseId = it2.baseId;
        if ($ownProperties) {
          out += " var " + $dataProperties + " = undefined; ";
        }
        if ($ownProperties) {
          out += " " + $dataProperties + " = " + $dataProperties + " || Object.keys(" + $data + "); for (var " + $idx + "=0; " + $idx + "<" + $dataProperties + ".length; " + $idx + "++) { var " + $key + " = " + $dataProperties + "[" + $idx + "]; ";
        } else {
          out += " for (var " + $key + " in " + $data + ") { ";
        }
        out += " var startErrs" + $lvl + " = errors; ";
        var $passData = $key;
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        var $code = it2.validate($it);
        $it.baseId = $currentBaseId;
        if (it2.util.varOccurences($code, $nextData) < 2) {
          out += " " + it2.util.varReplace($code, $nextData, $passData) + " ";
        } else {
          out += " var " + $nextData + " = " + $passData + "; " + $code + " ";
        }
        it2.compositeRule = $it.compositeRule = $wasComposite;
        out += " if (!" + $nextValid + ") { for (var " + $i + "=startErrs" + $lvl + "; " + $i + "<errors; " + $i + "++) { vErrors[" + $i + "].propertyName = " + $key + "; }   var err =   ";
        if (it2.createErrors !== false) {
          out += " { keyword: 'propertyNames' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { propertyName: '" + $invalidName + "' } ";
          if (it2.opts.messages !== false) {
            out += " , message: 'property name \\'" + $invalidName + "\\' is invalid' ";
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError(vErrors); ";
          } else {
            out += " validate.errors = vErrors; return false; ";
          }
        }
        if ($breakOnError) {
          out += " break; ";
        }
        out += " } }";
      }
      if ($breakOnError) {
        out += " " + $closingBraces + " if (" + $errs + " == errors) {";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/required.js
var require_required = __commonJS({
  "node_modules/ajv/lib/dotjs/required.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_required(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $vSchema = "schema" + $lvl;
      if (!$isData) {
        if ($schema.length < it2.opts.loopRequired && it2.schema.properties && Object.keys(it2.schema.properties).length) {
          var $required = [];
          var arr1 = $schema;
          if (arr1) {
            var $property, i1 = -1, l1 = arr1.length - 1;
            while (i1 < l1) {
              $property = arr1[i1 += 1];
              var $propertySch = it2.schema.properties[$property];
              if (!($propertySch && (it2.opts.strictKeywords ? typeof $propertySch == "object" && Object.keys($propertySch).length > 0 || $propertySch === false : it2.util.schemaHasRules($propertySch, it2.RULES.all)))) {
                $required[$required.length] = $property;
              }
            }
          }
        } else {
          var $required = $schema;
        }
      }
      if ($isData || $required.length) {
        var $currentErrorPath = it2.errorPath, $loopRequired = $isData || $required.length >= it2.opts.loopRequired, $ownProperties = it2.opts.ownProperties;
        if ($breakOnError) {
          out += " var missing" + $lvl + "; ";
          if ($loopRequired) {
            if (!$isData) {
              out += " var " + $vSchema + " = validate.schema" + $schemaPath + "; ";
            }
            var $i = "i" + $lvl, $propertyPath = "schema" + $lvl + "[" + $i + "]", $missingProperty = "' + " + $propertyPath + " + '";
            if (it2.opts._errorDataPathProperty) {
              it2.errorPath = it2.util.getPathExpr($currentErrorPath, $propertyPath, it2.opts.jsonPointers);
            }
            out += " var " + $valid + " = true; ";
            if ($isData) {
              out += " if (schema" + $lvl + " === undefined) " + $valid + " = true; else if (!Array.isArray(schema" + $lvl + ")) " + $valid + " = false; else {";
            }
            out += " for (var " + $i + " = 0; " + $i + " < " + $vSchema + ".length; " + $i + "++) { " + $valid + " = " + $data + "[" + $vSchema + "[" + $i + "]] !== undefined ";
            if ($ownProperties) {
              out += " &&   Object.prototype.hasOwnProperty.call(" + $data + ", " + $vSchema + "[" + $i + "]) ";
            }
            out += "; if (!" + $valid + ") break; } ";
            if ($isData) {
              out += "  }  ";
            }
            out += "  if (!" + $valid + ") {   ";
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: '";
                if (it2.opts._errorDataPathProperty) {
                  out += "is a required property";
                } else {
                  out += "should have required property \\'" + $missingProperty + "\\'";
                }
                out += "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
            out += " } else { ";
          } else {
            out += " if ( ";
            var arr2 = $required;
            if (arr2) {
              var $propertyKey, $i = -1, l2 = arr2.length - 1;
              while ($i < l2) {
                $propertyKey = arr2[$i += 1];
                if ($i) {
                  out += " || ";
                }
                var $prop = it2.util.getProperty($propertyKey), $useData = $data + $prop;
                out += " ( ( " + $useData + " === undefined ";
                if ($ownProperties) {
                  out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                }
                out += ") && (missing" + $lvl + " = " + it2.util.toQuotedString(it2.opts.jsonPointers ? $propertyKey : $prop) + ") ) ";
              }
            }
            out += ") {  ";
            var $propertyPath = "missing" + $lvl, $missingProperty = "' + " + $propertyPath + " + '";
            if (it2.opts._errorDataPathProperty) {
              it2.errorPath = it2.opts.jsonPointers ? it2.util.getPathExpr($currentErrorPath, $propertyPath, true) : $currentErrorPath + " + " + $propertyPath;
            }
            var $$outStack = $$outStack || [];
            $$outStack.push(out);
            out = "";
            if (it2.createErrors !== false) {
              out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: '";
                if (it2.opts._errorDataPathProperty) {
                  out += "is a required property";
                } else {
                  out += "should have required property \\'" + $missingProperty + "\\'";
                }
                out += "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            var __err = out;
            out = $$outStack.pop();
            if (!it2.compositeRule && $breakOnError) {
              if (it2.async) {
                out += " throw new ValidationError([" + __err + "]); ";
              } else {
                out += " validate.errors = [" + __err + "]; return false; ";
              }
            } else {
              out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
            }
            out += " } else { ";
          }
        } else {
          if ($loopRequired) {
            if (!$isData) {
              out += " var " + $vSchema + " = validate.schema" + $schemaPath + "; ";
            }
            var $i = "i" + $lvl, $propertyPath = "schema" + $lvl + "[" + $i + "]", $missingProperty = "' + " + $propertyPath + " + '";
            if (it2.opts._errorDataPathProperty) {
              it2.errorPath = it2.util.getPathExpr($currentErrorPath, $propertyPath, it2.opts.jsonPointers);
            }
            if ($isData) {
              out += " if (" + $vSchema + " && !Array.isArray(" + $vSchema + ")) {  var err =   ";
              if (it2.createErrors !== false) {
                out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
                if (it2.opts.messages !== false) {
                  out += " , message: '";
                  if (it2.opts._errorDataPathProperty) {
                    out += "is a required property";
                  } else {
                    out += "should have required property \\'" + $missingProperty + "\\'";
                  }
                  out += "' ";
                }
                if (it2.opts.verbose) {
                  out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                }
                out += " } ";
              } else {
                out += " {} ";
              }
              out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } else if (" + $vSchema + " !== undefined) { ";
            }
            out += " for (var " + $i + " = 0; " + $i + " < " + $vSchema + ".length; " + $i + "++) { if (" + $data + "[" + $vSchema + "[" + $i + "]] === undefined ";
            if ($ownProperties) {
              out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", " + $vSchema + "[" + $i + "]) ";
            }
            out += ") {  var err =   ";
            if (it2.createErrors !== false) {
              out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
              if (it2.opts.messages !== false) {
                out += " , message: '";
                if (it2.opts._errorDataPathProperty) {
                  out += "is a required property";
                } else {
                  out += "should have required property \\'" + $missingProperty + "\\'";
                }
                out += "' ";
              }
              if (it2.opts.verbose) {
                out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
              }
              out += " } ";
            } else {
              out += " {} ";
            }
            out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } } ";
            if ($isData) {
              out += "  }  ";
            }
          } else {
            var arr3 = $required;
            if (arr3) {
              var $propertyKey, i3 = -1, l3 = arr3.length - 1;
              while (i3 < l3) {
                $propertyKey = arr3[i3 += 1];
                var $prop = it2.util.getProperty($propertyKey), $missingProperty = it2.util.escapeQuotes($propertyKey), $useData = $data + $prop;
                if (it2.opts._errorDataPathProperty) {
                  it2.errorPath = it2.util.getPath($currentErrorPath, $propertyKey, it2.opts.jsonPointers);
                }
                out += " if ( " + $useData + " === undefined ";
                if ($ownProperties) {
                  out += " || ! Object.prototype.hasOwnProperty.call(" + $data + ", '" + it2.util.escapeQuotes($propertyKey) + "') ";
                }
                out += ") {  var err =   ";
                if (it2.createErrors !== false) {
                  out += " { keyword: 'required' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { missingProperty: '" + $missingProperty + "' } ";
                  if (it2.opts.messages !== false) {
                    out += " , message: '";
                    if (it2.opts._errorDataPathProperty) {
                      out += "is a required property";
                    } else {
                      out += "should have required property \\'" + $missingProperty + "\\'";
                    }
                    out += "' ";
                  }
                  if (it2.opts.verbose) {
                    out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
                  }
                  out += " } ";
                } else {
                  out += " {} ";
                }
                out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } ";
              }
            }
          }
        }
        it2.errorPath = $currentErrorPath;
      } else if ($breakOnError) {
        out += " if (true) {";
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/uniqueItems.js
var require_uniqueItems = __commonJS({
  "node_modules/ajv/lib/dotjs/uniqueItems.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_uniqueItems(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      if (($schema || $isData) && it2.opts.uniqueItems !== false) {
        if ($isData) {
          out += " var " + $valid + "; if (" + $schemaValue + " === false || " + $schemaValue + " === undefined) " + $valid + " = true; else if (typeof " + $schemaValue + " != 'boolean') " + $valid + " = false; else { ";
        }
        out += " var i = " + $data + ".length , " + $valid + " = true , j; if (i > 1) { ";
        var $itemType = it2.schema.items && it2.schema.items.type, $typeIsArray = Array.isArray($itemType);
        if (!$itemType || $itemType == "object" || $itemType == "array" || $typeIsArray && ($itemType.indexOf("object") >= 0 || $itemType.indexOf("array") >= 0)) {
          out += " outer: for (;i--;) { for (j = i; j--;) { if (equal(" + $data + "[i], " + $data + "[j])) { " + $valid + " = false; break outer; } } } ";
        } else {
          out += " var itemIndices = {}, item; for (;i--;) { var item = " + $data + "[i]; ";
          var $method = "checkDataType" + ($typeIsArray ? "s" : "");
          out += " if (" + it2.util[$method]($itemType, "item", it2.opts.strictNumbers, true) + ") continue; ";
          if ($typeIsArray) {
            out += ` if (typeof item == 'string') item = '"' + item; `;
          }
          out += " if (typeof itemIndices[item] == 'number') { " + $valid + " = false; j = itemIndices[item]; break; } itemIndices[item] = i; } ";
        }
        out += " } ";
        if ($isData) {
          out += "  }  ";
        }
        out += " if (!" + $valid + ") {   ";
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        if (it2.createErrors !== false) {
          out += " { keyword: 'uniqueItems' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { i: i, j: j } ";
          if (it2.opts.messages !== false) {
            out += " , message: 'should NOT have duplicate items (items ## ' + j + ' and ' + i + ' are identical)' ";
          }
          if (it2.opts.verbose) {
            out += " , schema:  ";
            if ($isData) {
              out += "validate.schema" + $schemaPath;
            } else {
              out += "" + $schema;
            }
            out += "         , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError([" + __err + "]); ";
          } else {
            out += " validate.errors = [" + __err + "]; return false; ";
          }
        } else {
          out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        }
        out += " } ";
        if ($breakOnError) {
          out += " else { ";
        }
      } else {
        if ($breakOnError) {
          out += " if (true) { ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/dotjs/index.js
var require_dotjs = __commonJS({
  "node_modules/ajv/lib/dotjs/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      "$ref": require_ref(),
      allOf: require_allOf(),
      anyOf: require_anyOf(),
      "$comment": require_comment(),
      const: require_const(),
      contains: require_contains(),
      dependencies: require_dependencies(),
      "enum": require_enum(),
      format: require_format(),
      "if": require_if(),
      items: require_items(),
      maximum: require_limit(),
      minimum: require_limit(),
      maxItems: require_limitItems(),
      minItems: require_limitItems(),
      maxLength: require_limitLength(),
      minLength: require_limitLength(),
      maxProperties: require_limitProperties(),
      minProperties: require_limitProperties(),
      multipleOf: require_multipleOf(),
      not: require_not2(),
      oneOf: require_oneOf(),
      pattern: require_pattern(),
      properties: require_properties(),
      propertyNames: require_propertyNames(),
      required: require_required(),
      uniqueItems: require_uniqueItems(),
      validate: require_validate()
    };
  }
});

// node_modules/ajv/lib/compile/rules.js
var require_rules = __commonJS({
  "node_modules/ajv/lib/compile/rules.js"(exports, module2) {
    "use strict";
    var ruleModules = require_dotjs();
    var toHash = require_util2().toHash;
    module2.exports = function rules() {
      var RULES = [
        {
          type: "number",
          rules: [
            { "maximum": ["exclusiveMaximum"] },
            { "minimum": ["exclusiveMinimum"] },
            "multipleOf",
            "format"
          ]
        },
        {
          type: "string",
          rules: ["maxLength", "minLength", "pattern", "format"]
        },
        {
          type: "array",
          rules: ["maxItems", "minItems", "items", "contains", "uniqueItems"]
        },
        {
          type: "object",
          rules: [
            "maxProperties",
            "minProperties",
            "required",
            "dependencies",
            "propertyNames",
            { "properties": ["additionalProperties", "patternProperties"] }
          ]
        },
        { rules: ["$ref", "const", "enum", "not", "anyOf", "oneOf", "allOf", "if"] }
      ];
      var ALL = ["type", "$comment"];
      var KEYWORDS = [
        "$schema",
        "$id",
        "id",
        "$data",
        "$async",
        "title",
        "description",
        "default",
        "definitions",
        "examples",
        "readOnly",
        "writeOnly",
        "contentMediaType",
        "contentEncoding",
        "additionalItems",
        "then",
        "else"
      ];
      var TYPES = ["number", "integer", "string", "array", "object", "boolean", "null"];
      RULES.all = toHash(ALL);
      RULES.types = toHash(TYPES);
      RULES.forEach(function(group) {
        group.rules = group.rules.map(function(keyword) {
          var implKeywords;
          if (typeof keyword == "object") {
            var key = Object.keys(keyword)[0];
            implKeywords = keyword[key];
            keyword = key;
            implKeywords.forEach(function(k) {
              ALL.push(k);
              RULES.all[k] = true;
            });
          }
          ALL.push(keyword);
          var rule = RULES.all[keyword] = {
            keyword,
            code: ruleModules[keyword],
            implements: implKeywords
          };
          return rule;
        });
        RULES.all.$comment = {
          keyword: "$comment",
          code: ruleModules.$comment
        };
        if (group.type)
          RULES.types[group.type] = group;
      });
      RULES.keywords = toHash(ALL.concat(KEYWORDS));
      RULES.custom = {};
      return RULES;
    };
  }
});

// node_modules/ajv/lib/data.js
var require_data = __commonJS({
  "node_modules/ajv/lib/data.js"(exports, module2) {
    "use strict";
    var KEYWORDS = [
      "multipleOf",
      "maximum",
      "exclusiveMaximum",
      "minimum",
      "exclusiveMinimum",
      "maxLength",
      "minLength",
      "pattern",
      "additionalItems",
      "maxItems",
      "minItems",
      "uniqueItems",
      "maxProperties",
      "minProperties",
      "required",
      "additionalProperties",
      "enum",
      "format",
      "const"
    ];
    module2.exports = function(metaSchema, keywordsJsonPointers) {
      for (var i = 0; i < keywordsJsonPointers.length; i++) {
        metaSchema = JSON.parse(JSON.stringify(metaSchema));
        var segments = keywordsJsonPointers[i].split("/");
        var keywords = metaSchema;
        var j;
        for (j = 1; j < segments.length; j++)
          keywords = keywords[segments[j]];
        for (j = 0; j < KEYWORDS.length; j++) {
          var key = KEYWORDS[j];
          var schema = keywords[key];
          if (schema) {
            keywords[key] = {
              anyOf: [
                schema,
                { $ref: "https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#" }
              ]
            };
          }
        }
      }
      return metaSchema;
    };
  }
});

// node_modules/ajv/lib/compile/async.js
var require_async2 = __commonJS({
  "node_modules/ajv/lib/compile/async.js"(exports, module2) {
    "use strict";
    var MissingRefError = require_error_classes().MissingRef;
    module2.exports = compileAsync;
    function compileAsync(schema, meta, callback) {
      var self2 = this;
      if (typeof this._opts.loadSchema != "function")
        throw new Error("options.loadSchema should be a function");
      if (typeof meta == "function") {
        callback = meta;
        meta = void 0;
      }
      var p = loadMetaSchemaOf(schema).then(function() {
        var schemaObj = self2._addSchema(schema, void 0, meta);
        return schemaObj.validate || _compileAsync(schemaObj);
      });
      if (callback) {
        p.then(
          function(v) {
            callback(null, v);
          },
          callback
        );
      }
      return p;
      function loadMetaSchemaOf(sch) {
        var $schema = sch.$schema;
        return $schema && !self2.getSchema($schema) ? compileAsync.call(self2, { $ref: $schema }, true) : Promise.resolve();
      }
      function _compileAsync(schemaObj) {
        try {
          return self2._compile(schemaObj);
        } catch (e) {
          if (e instanceof MissingRefError)
            return loadMissingSchema(e);
          throw e;
        }
        function loadMissingSchema(e) {
          var ref = e.missingSchema;
          if (added(ref))
            throw new Error("Schema " + ref + " is loaded but " + e.missingRef + " cannot be resolved");
          var schemaPromise = self2._loadingSchemas[ref];
          if (!schemaPromise) {
            schemaPromise = self2._loadingSchemas[ref] = self2._opts.loadSchema(ref);
            schemaPromise.then(removePromise, removePromise);
          }
          return schemaPromise.then(function(sch) {
            if (!added(ref)) {
              return loadMetaSchemaOf(sch).then(function() {
                if (!added(ref))
                  self2.addSchema(sch, ref, void 0, meta);
              });
            }
          }).then(function() {
            return _compileAsync(schemaObj);
          });
          function removePromise() {
            delete self2._loadingSchemas[ref];
          }
          function added(ref2) {
            return self2._refs[ref2] || self2._schemas[ref2];
          }
        }
      }
    }
  }
});

// node_modules/ajv/lib/dotjs/custom.js
var require_custom = __commonJS({
  "node_modules/ajv/lib/dotjs/custom.js"(exports, module2) {
    "use strict";
    module2.exports = function generate_custom(it2, $keyword, $ruleType) {
      var out = " ";
      var $lvl = it2.level;
      var $dataLvl = it2.dataLevel;
      var $schema = it2.schema[$keyword];
      var $schemaPath = it2.schemaPath + it2.util.getProperty($keyword);
      var $errSchemaPath = it2.errSchemaPath + "/" + $keyword;
      var $breakOnError = !it2.opts.allErrors;
      var $errorKeyword;
      var $data = "data" + ($dataLvl || "");
      var $valid = "valid" + $lvl;
      var $errs = "errs__" + $lvl;
      var $isData = it2.opts.$data && $schema && $schema.$data, $schemaValue;
      if ($isData) {
        out += " var schema" + $lvl + " = " + it2.util.getData($schema.$data, $dataLvl, it2.dataPathArr) + "; ";
        $schemaValue = "schema" + $lvl;
      } else {
        $schemaValue = $schema;
      }
      var $rule = this, $definition = "definition" + $lvl, $rDef = $rule.definition, $closingBraces = "";
      var $compile, $inline, $macro, $ruleValidate, $validateCode;
      if ($isData && $rDef.$data) {
        $validateCode = "keywordValidate" + $lvl;
        var $validateSchema = $rDef.validateSchema;
        out += " var " + $definition + " = RULES.custom['" + $keyword + "'].definition; var " + $validateCode + " = " + $definition + ".validate;";
      } else {
        $ruleValidate = it2.useCustomRule($rule, $schema, it2.schema, it2);
        if (!$ruleValidate)
          return;
        $schemaValue = "validate.schema" + $schemaPath;
        $validateCode = $ruleValidate.code;
        $compile = $rDef.compile;
        $inline = $rDef.inline;
        $macro = $rDef.macro;
      }
      var $ruleErrs = $validateCode + ".errors", $i = "i" + $lvl, $ruleErr = "ruleErr" + $lvl, $asyncKeyword = $rDef.async;
      if ($asyncKeyword && !it2.async)
        throw new Error("async keyword in sync schema");
      if (!($inline || $macro)) {
        out += "" + $ruleErrs + " = null;";
      }
      out += "var " + $errs + " = errors;var " + $valid + ";";
      if ($isData && $rDef.$data) {
        $closingBraces += "}";
        out += " if (" + $schemaValue + " === undefined) { " + $valid + " = true; } else { ";
        if ($validateSchema) {
          $closingBraces += "}";
          out += " " + $valid + " = " + $definition + ".validateSchema(" + $schemaValue + "); if (" + $valid + ") { ";
        }
      }
      if ($inline) {
        if ($rDef.statements) {
          out += " " + $ruleValidate.validate + " ";
        } else {
          out += " " + $valid + " = " + $ruleValidate.validate + "; ";
        }
      } else if ($macro) {
        var $it = it2.util.copy(it2);
        var $closingBraces = "";
        $it.level++;
        var $nextValid = "valid" + $it.level;
        $it.schema = $ruleValidate.validate;
        $it.schemaPath = "";
        var $wasComposite = it2.compositeRule;
        it2.compositeRule = $it.compositeRule = true;
        var $code = it2.validate($it).replace(/validate\.schema/g, $validateCode);
        it2.compositeRule = $it.compositeRule = $wasComposite;
        out += " " + $code;
      } else {
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        out += "  " + $validateCode + ".call( ";
        if (it2.opts.passContext) {
          out += "this";
        } else {
          out += "self";
        }
        if ($compile || $rDef.schema === false) {
          out += " , " + $data + " ";
        } else {
          out += " , " + $schemaValue + " , " + $data + " , validate.schema" + it2.schemaPath + " ";
        }
        out += " , (dataPath || '')";
        if (it2.errorPath != '""') {
          out += " + " + it2.errorPath;
        }
        var $parentData = $dataLvl ? "data" + ($dataLvl - 1 || "") : "parentData", $parentDataProperty = $dataLvl ? it2.dataPathArr[$dataLvl] : "parentDataProperty";
        out += " , " + $parentData + " , " + $parentDataProperty + " , rootData )  ";
        var def_callRuleValidate = out;
        out = $$outStack.pop();
        if ($rDef.errors === false) {
          out += " " + $valid + " = ";
          if ($asyncKeyword) {
            out += "await ";
          }
          out += "" + def_callRuleValidate + "; ";
        } else {
          if ($asyncKeyword) {
            $ruleErrs = "customErrors" + $lvl;
            out += " var " + $ruleErrs + " = null; try { " + $valid + " = await " + def_callRuleValidate + "; } catch (e) { " + $valid + " = false; if (e instanceof ValidationError) " + $ruleErrs + " = e.errors; else throw e; } ";
          } else {
            out += " " + $ruleErrs + " = null; " + $valid + " = " + def_callRuleValidate + "; ";
          }
        }
      }
      if ($rDef.modifying) {
        out += " if (" + $parentData + ") " + $data + " = " + $parentData + "[" + $parentDataProperty + "];";
      }
      out += "" + $closingBraces;
      if ($rDef.valid) {
        if ($breakOnError) {
          out += " if (true) { ";
        }
      } else {
        out += " if ( ";
        if ($rDef.valid === void 0) {
          out += " !";
          if ($macro) {
            out += "" + $nextValid;
          } else {
            out += "" + $valid;
          }
        } else {
          out += " " + !$rDef.valid + " ";
        }
        out += ") { ";
        $errorKeyword = $rule.keyword;
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        var $$outStack = $$outStack || [];
        $$outStack.push(out);
        out = "";
        if (it2.createErrors !== false) {
          out += " { keyword: '" + ($errorKeyword || "custom") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { keyword: '" + $rule.keyword + "' } ";
          if (it2.opts.messages !== false) {
            out += ` , message: 'should pass "` + $rule.keyword + `" keyword validation' `;
          }
          if (it2.opts.verbose) {
            out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
          }
          out += " } ";
        } else {
          out += " {} ";
        }
        var __err = out;
        out = $$outStack.pop();
        if (!it2.compositeRule && $breakOnError) {
          if (it2.async) {
            out += " throw new ValidationError([" + __err + "]); ";
          } else {
            out += " validate.errors = [" + __err + "]; return false; ";
          }
        } else {
          out += " var err = " + __err + ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
        }
        var def_customError = out;
        out = $$outStack.pop();
        if ($inline) {
          if ($rDef.errors) {
            if ($rDef.errors != "full") {
              out += "  for (var " + $i + "=" + $errs + "; " + $i + "<errors; " + $i + "++) { var " + $ruleErr + " = vErrors[" + $i + "]; if (" + $ruleErr + ".dataPath === undefined) " + $ruleErr + ".dataPath = (dataPath || '') + " + it2.errorPath + "; if (" + $ruleErr + ".schemaPath === undefined) { " + $ruleErr + '.schemaPath = "' + $errSchemaPath + '"; } ';
              if (it2.opts.verbose) {
                out += " " + $ruleErr + ".schema = " + $schemaValue + "; " + $ruleErr + ".data = " + $data + "; ";
              }
              out += " } ";
            }
          } else {
            if ($rDef.errors === false) {
              out += " " + def_customError + " ";
            } else {
              out += " if (" + $errs + " == errors) { " + def_customError + " } else {  for (var " + $i + "=" + $errs + "; " + $i + "<errors; " + $i + "++) { var " + $ruleErr + " = vErrors[" + $i + "]; if (" + $ruleErr + ".dataPath === undefined) " + $ruleErr + ".dataPath = (dataPath || '') + " + it2.errorPath + "; if (" + $ruleErr + ".schemaPath === undefined) { " + $ruleErr + '.schemaPath = "' + $errSchemaPath + '"; } ';
              if (it2.opts.verbose) {
                out += " " + $ruleErr + ".schema = " + $schemaValue + "; " + $ruleErr + ".data = " + $data + "; ";
              }
              out += " } } ";
            }
          }
        } else if ($macro) {
          out += "   var err =   ";
          if (it2.createErrors !== false) {
            out += " { keyword: '" + ($errorKeyword || "custom") + "' , dataPath: (dataPath || '') + " + it2.errorPath + " , schemaPath: " + it2.util.toQuotedString($errSchemaPath) + " , params: { keyword: '" + $rule.keyword + "' } ";
            if (it2.opts.messages !== false) {
              out += ` , message: 'should pass "` + $rule.keyword + `" keyword validation' `;
            }
            if (it2.opts.verbose) {
              out += " , schema: validate.schema" + $schemaPath + " , parentSchema: validate.schema" + it2.schemaPath + " , data: " + $data + " ";
            }
            out += " } ";
          } else {
            out += " {} ";
          }
          out += ";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";
          if (!it2.compositeRule && $breakOnError) {
            if (it2.async) {
              out += " throw new ValidationError(vErrors); ";
            } else {
              out += " validate.errors = vErrors; return false; ";
            }
          }
        } else {
          if ($rDef.errors === false) {
            out += " " + def_customError + " ";
          } else {
            out += " if (Array.isArray(" + $ruleErrs + ")) { if (vErrors === null) vErrors = " + $ruleErrs + "; else vErrors = vErrors.concat(" + $ruleErrs + "); errors = vErrors.length;  for (var " + $i + "=" + $errs + "; " + $i + "<errors; " + $i + "++) { var " + $ruleErr + " = vErrors[" + $i + "]; if (" + $ruleErr + ".dataPath === undefined) " + $ruleErr + ".dataPath = (dataPath || '') + " + it2.errorPath + ";  " + $ruleErr + '.schemaPath = "' + $errSchemaPath + '";  ';
            if (it2.opts.verbose) {
              out += " " + $ruleErr + ".schema = " + $schemaValue + "; " + $ruleErr + ".data = " + $data + "; ";
            }
            out += " } } else { " + def_customError + " } ";
          }
        }
        out += " } ";
        if ($breakOnError) {
          out += " else { ";
        }
      }
      return out;
    };
  }
});

// node_modules/ajv/lib/refs/json-schema-draft-07.json
var require_json_schema_draft_07 = __commonJS({
  "node_modules/ajv/lib/refs/json-schema-draft-07.json"(exports, module2) {
    module2.exports = {
      $schema: "http://json-schema.org/draft-07/schema#",
      $id: "http://json-schema.org/draft-07/schema#",
      title: "Core schema meta-schema",
      definitions: {
        schemaArray: {
          type: "array",
          minItems: 1,
          items: { $ref: "#" }
        },
        nonNegativeInteger: {
          type: "integer",
          minimum: 0
        },
        nonNegativeIntegerDefault0: {
          allOf: [
            { $ref: "#/definitions/nonNegativeInteger" },
            { default: 0 }
          ]
        },
        simpleTypes: {
          enum: [
            "array",
            "boolean",
            "integer",
            "null",
            "number",
            "object",
            "string"
          ]
        },
        stringArray: {
          type: "array",
          items: { type: "string" },
          uniqueItems: true,
          default: []
        }
      },
      type: ["object", "boolean"],
      properties: {
        $id: {
          type: "string",
          format: "uri-reference"
        },
        $schema: {
          type: "string",
          format: "uri"
        },
        $ref: {
          type: "string",
          format: "uri-reference"
        },
        $comment: {
          type: "string"
        },
        title: {
          type: "string"
        },
        description: {
          type: "string"
        },
        default: true,
        readOnly: {
          type: "boolean",
          default: false
        },
        examples: {
          type: "array",
          items: true
        },
        multipleOf: {
          type: "number",
          exclusiveMinimum: 0
        },
        maximum: {
          type: "number"
        },
        exclusiveMaximum: {
          type: "number"
        },
        minimum: {
          type: "number"
        },
        exclusiveMinimum: {
          type: "number"
        },
        maxLength: { $ref: "#/definitions/nonNegativeInteger" },
        minLength: { $ref: "#/definitions/nonNegativeIntegerDefault0" },
        pattern: {
          type: "string",
          format: "regex"
        },
        additionalItems: { $ref: "#" },
        items: {
          anyOf: [
            { $ref: "#" },
            { $ref: "#/definitions/schemaArray" }
          ],
          default: true
        },
        maxItems: { $ref: "#/definitions/nonNegativeInteger" },
        minItems: { $ref: "#/definitions/nonNegativeIntegerDefault0" },
        uniqueItems: {
          type: "boolean",
          default: false
        },
        contains: { $ref: "#" },
        maxProperties: { $ref: "#/definitions/nonNegativeInteger" },
        minProperties: { $ref: "#/definitions/nonNegativeIntegerDefault0" },
        required: { $ref: "#/definitions/stringArray" },
        additionalProperties: { $ref: "#" },
        definitions: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        properties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        patternProperties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          propertyNames: { format: "regex" },
          default: {}
        },
        dependencies: {
          type: "object",
          additionalProperties: {
            anyOf: [
              { $ref: "#" },
              { $ref: "#/definitions/stringArray" }
            ]
          }
        },
        propertyNames: { $ref: "#" },
        const: true,
        enum: {
          type: "array",
          items: true,
          minItems: 1,
          uniqueItems: true
        },
        type: {
          anyOf: [
            { $ref: "#/definitions/simpleTypes" },
            {
              type: "array",
              items: { $ref: "#/definitions/simpleTypes" },
              minItems: 1,
              uniqueItems: true
            }
          ]
        },
        format: { type: "string" },
        contentMediaType: { type: "string" },
        contentEncoding: { type: "string" },
        if: { $ref: "#" },
        then: { $ref: "#" },
        else: { $ref: "#" },
        allOf: { $ref: "#/definitions/schemaArray" },
        anyOf: { $ref: "#/definitions/schemaArray" },
        oneOf: { $ref: "#/definitions/schemaArray" },
        not: { $ref: "#" }
      },
      default: true
    };
  }
});

// node_modules/ajv/lib/definition_schema.js
var require_definition_schema = __commonJS({
  "node_modules/ajv/lib/definition_schema.js"(exports, module2) {
    "use strict";
    var metaSchema = require_json_schema_draft_07();
    module2.exports = {
      $id: "https://github.com/ajv-validator/ajv/blob/master/lib/definition_schema.js",
      definitions: {
        simpleTypes: metaSchema.definitions.simpleTypes
      },
      type: "object",
      dependencies: {
        schema: ["validate"],
        $data: ["validate"],
        statements: ["inline"],
        valid: { not: { required: ["macro"] } }
      },
      properties: {
        type: metaSchema.properties.type,
        schema: { type: "boolean" },
        statements: { type: "boolean" },
        dependencies: {
          type: "array",
          items: { type: "string" }
        },
        metaSchema: { type: "object" },
        modifying: { type: "boolean" },
        valid: { type: "boolean" },
        $data: { type: "boolean" },
        async: { type: "boolean" },
        errors: {
          anyOf: [
            { type: "boolean" },
            { const: "full" }
          ]
        }
      }
    };
  }
});

// node_modules/ajv/lib/keyword.js
var require_keyword = __commonJS({
  "node_modules/ajv/lib/keyword.js"(exports, module2) {
    "use strict";
    var IDENTIFIER = /^[a-z_$][a-z0-9_$-]*$/i;
    var customRuleCode = require_custom();
    var definitionSchema = require_definition_schema();
    module2.exports = {
      add: addKeyword,
      get: getKeyword,
      remove: removeKeyword,
      validate: validateKeyword
    };
    function addKeyword(keyword, definition) {
      var RULES = this.RULES;
      if (RULES.keywords[keyword])
        throw new Error("Keyword " + keyword + " is already defined");
      if (!IDENTIFIER.test(keyword))
        throw new Error("Keyword " + keyword + " is not a valid identifier");
      if (definition) {
        this.validateKeyword(definition, true);
        var dataType = definition.type;
        if (Array.isArray(dataType)) {
          for (var i = 0; i < dataType.length; i++)
            _addRule(keyword, dataType[i], definition);
        } else {
          _addRule(keyword, dataType, definition);
        }
        var metaSchema = definition.metaSchema;
        if (metaSchema) {
          if (definition.$data && this._opts.$data) {
            metaSchema = {
              anyOf: [
                metaSchema,
                { "$ref": "https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#" }
              ]
            };
          }
          definition.validateSchema = this.compile(metaSchema, true);
        }
      }
      RULES.keywords[keyword] = RULES.all[keyword] = true;
      function _addRule(keyword2, dataType2, definition2) {
        var ruleGroup;
        for (var i2 = 0; i2 < RULES.length; i2++) {
          var rg = RULES[i2];
          if (rg.type == dataType2) {
            ruleGroup = rg;
            break;
          }
        }
        if (!ruleGroup) {
          ruleGroup = { type: dataType2, rules: [] };
          RULES.push(ruleGroup);
        }
        var rule = {
          keyword: keyword2,
          definition: definition2,
          custom: true,
          code: customRuleCode,
          implements: definition2.implements
        };
        ruleGroup.rules.push(rule);
        RULES.custom[keyword2] = rule;
      }
      return this;
    }
    function getKeyword(keyword) {
      var rule = this.RULES.custom[keyword];
      return rule ? rule.definition : this.RULES.keywords[keyword] || false;
    }
    function removeKeyword(keyword) {
      var RULES = this.RULES;
      delete RULES.keywords[keyword];
      delete RULES.all[keyword];
      delete RULES.custom[keyword];
      for (var i = 0; i < RULES.length; i++) {
        var rules = RULES[i].rules;
        for (var j = 0; j < rules.length; j++) {
          if (rules[j].keyword == keyword) {
            rules.splice(j, 1);
            break;
          }
        }
      }
      return this;
    }
    function validateKeyword(definition, throwError) {
      validateKeyword.errors = null;
      var v = this._validateKeyword = this._validateKeyword || this.compile(definitionSchema, true);
      if (v(definition))
        return true;
      validateKeyword.errors = v.errors;
      if (throwError)
        throw new Error("custom keyword definition is invalid: " + this.errorsText(v.errors));
      else
        return false;
    }
  }
});

// node_modules/ajv/lib/refs/data.json
var require_data2 = __commonJS({
  "node_modules/ajv/lib/refs/data.json"(exports, module2) {
    module2.exports = {
      $schema: "http://json-schema.org/draft-07/schema#",
      $id: "https://raw.githubusercontent.com/ajv-validator/ajv/master/lib/refs/data.json#",
      description: "Meta-schema for $data reference (JSON Schema extension proposal)",
      type: "object",
      required: ["$data"],
      properties: {
        $data: {
          type: "string",
          anyOf: [
            { format: "relative-json-pointer" },
            { format: "json-pointer" }
          ]
        }
      },
      additionalProperties: false
    };
  }
});

// node_modules/ajv/lib/ajv.js
var require_ajv = __commonJS({
  "node_modules/ajv/lib/ajv.js"(exports, module2) {
    "use strict";
    var compileSchema = require_compile();
    var resolve = require_resolve();
    var Cache = require_cache();
    var SchemaObject = require_schema_obj();
    var stableStringify = require_fast_json_stable_stringify();
    var formats = require_formats();
    var rules = require_rules();
    var $dataMetaSchema = require_data();
    var util = require_util2();
    module2.exports = Ajv;
    Ajv.prototype.validate = validate;
    Ajv.prototype.compile = compile;
    Ajv.prototype.addSchema = addSchema;
    Ajv.prototype.addMetaSchema = addMetaSchema;
    Ajv.prototype.validateSchema = validateSchema;
    Ajv.prototype.getSchema = getSchema;
    Ajv.prototype.removeSchema = removeSchema;
    Ajv.prototype.addFormat = addFormat;
    Ajv.prototype.errorsText = errorsText;
    Ajv.prototype._addSchema = _addSchema;
    Ajv.prototype._compile = _compile;
    Ajv.prototype.compileAsync = require_async2();
    var customKeyword = require_keyword();
    Ajv.prototype.addKeyword = customKeyword.add;
    Ajv.prototype.getKeyword = customKeyword.get;
    Ajv.prototype.removeKeyword = customKeyword.remove;
    Ajv.prototype.validateKeyword = customKeyword.validate;
    var errorClasses = require_error_classes();
    Ajv.ValidationError = errorClasses.Validation;
    Ajv.MissingRefError = errorClasses.MissingRef;
    Ajv.$dataMetaSchema = $dataMetaSchema;
    var META_SCHEMA_ID = "http://json-schema.org/draft-07/schema";
    var META_IGNORE_OPTIONS = ["removeAdditional", "useDefaults", "coerceTypes", "strictDefaults"];
    var META_SUPPORT_DATA = ["/properties"];
    function Ajv(opts) {
      if (!(this instanceof Ajv))
        return new Ajv(opts);
      opts = this._opts = util.copy(opts) || {};
      setLogger(this);
      this._schemas = {};
      this._refs = {};
      this._fragments = {};
      this._formats = formats(opts.format);
      this._cache = opts.cache || new Cache();
      this._loadingSchemas = {};
      this._compilations = [];
      this.RULES = rules();
      this._getId = chooseGetId(opts);
      opts.loopRequired = opts.loopRequired || Infinity;
      if (opts.errorDataPath == "property")
        opts._errorDataPathProperty = true;
      if (opts.serialize === void 0)
        opts.serialize = stableStringify;
      this._metaOpts = getMetaSchemaOptions(this);
      if (opts.formats)
        addInitialFormats(this);
      if (opts.keywords)
        addInitialKeywords(this);
      addDefaultMetaSchema(this);
      if (typeof opts.meta == "object")
        this.addMetaSchema(opts.meta);
      if (opts.nullable)
        this.addKeyword("nullable", { metaSchema: { type: "boolean" } });
      addInitialSchemas(this);
    }
    function validate(schemaKeyRef, data) {
      var v;
      if (typeof schemaKeyRef == "string") {
        v = this.getSchema(schemaKeyRef);
        if (!v)
          throw new Error('no schema with key or ref "' + schemaKeyRef + '"');
      } else {
        var schemaObj = this._addSchema(schemaKeyRef);
        v = schemaObj.validate || this._compile(schemaObj);
      }
      var valid = v(data);
      if (v.$async !== true)
        this.errors = v.errors;
      return valid;
    }
    function compile(schema, _meta) {
      var schemaObj = this._addSchema(schema, void 0, _meta);
      return schemaObj.validate || this._compile(schemaObj);
    }
    function addSchema(schema, key, _skipValidation, _meta) {
      if (Array.isArray(schema)) {
        for (var i = 0; i < schema.length; i++)
          this.addSchema(schema[i], void 0, _skipValidation, _meta);
        return this;
      }
      var id = this._getId(schema);
      if (id !== void 0 && typeof id != "string")
        throw new Error("schema id must be string");
      key = resolve.normalizeId(key || id);
      checkUnique(this, key);
      this._schemas[key] = this._addSchema(schema, _skipValidation, _meta, true);
      return this;
    }
    function addMetaSchema(schema, key, skipValidation) {
      this.addSchema(schema, key, skipValidation, true);
      return this;
    }
    function validateSchema(schema, throwOrLogError) {
      var $schema = schema.$schema;
      if ($schema !== void 0 && typeof $schema != "string")
        throw new Error("$schema must be a string");
      $schema = $schema || this._opts.defaultMeta || defaultMeta(this);
      if (!$schema) {
        this.logger.warn("meta-schema not available");
        this.errors = null;
        return true;
      }
      var valid = this.validate($schema, schema);
      if (!valid && throwOrLogError) {
        var message = "schema is invalid: " + this.errorsText();
        if (this._opts.validateSchema == "log")
          this.logger.error(message);
        else
          throw new Error(message);
      }
      return valid;
    }
    function defaultMeta(self2) {
      var meta = self2._opts.meta;
      self2._opts.defaultMeta = typeof meta == "object" ? self2._getId(meta) || meta : self2.getSchema(META_SCHEMA_ID) ? META_SCHEMA_ID : void 0;
      return self2._opts.defaultMeta;
    }
    function getSchema(keyRef) {
      var schemaObj = _getSchemaObj(this, keyRef);
      switch (typeof schemaObj) {
        case "object":
          return schemaObj.validate || this._compile(schemaObj);
        case "string":
          return this.getSchema(schemaObj);
        case "undefined":
          return _getSchemaFragment(this, keyRef);
      }
    }
    function _getSchemaFragment(self2, ref) {
      var res = resolve.schema.call(self2, { schema: {} }, ref);
      if (res) {
        var schema = res.schema, root2 = res.root, baseId = res.baseId;
        var v = compileSchema.call(self2, schema, root2, void 0, baseId);
        self2._fragments[ref] = new SchemaObject({
          ref,
          fragment: true,
          schema,
          root: root2,
          baseId,
          validate: v
        });
        return v;
      }
    }
    function _getSchemaObj(self2, keyRef) {
      keyRef = resolve.normalizeId(keyRef);
      return self2._schemas[keyRef] || self2._refs[keyRef] || self2._fragments[keyRef];
    }
    function removeSchema(schemaKeyRef) {
      if (schemaKeyRef instanceof RegExp) {
        _removeAllSchemas(this, this._schemas, schemaKeyRef);
        _removeAllSchemas(this, this._refs, schemaKeyRef);
        return this;
      }
      switch (typeof schemaKeyRef) {
        case "undefined":
          _removeAllSchemas(this, this._schemas);
          _removeAllSchemas(this, this._refs);
          this._cache.clear();
          return this;
        case "string":
          var schemaObj = _getSchemaObj(this, schemaKeyRef);
          if (schemaObj)
            this._cache.del(schemaObj.cacheKey);
          delete this._schemas[schemaKeyRef];
          delete this._refs[schemaKeyRef];
          return this;
        case "object":
          var serialize = this._opts.serialize;
          var cacheKey = serialize ? serialize(schemaKeyRef) : schemaKeyRef;
          this._cache.del(cacheKey);
          var id = this._getId(schemaKeyRef);
          if (id) {
            id = resolve.normalizeId(id);
            delete this._schemas[id];
            delete this._refs[id];
          }
      }
      return this;
    }
    function _removeAllSchemas(self2, schemas, regex) {
      for (var keyRef in schemas) {
        var schemaObj = schemas[keyRef];
        if (!schemaObj.meta && (!regex || regex.test(keyRef))) {
          self2._cache.del(schemaObj.cacheKey);
          delete schemas[keyRef];
        }
      }
    }
    function _addSchema(schema, skipValidation, meta, shouldAddSchema) {
      if (typeof schema != "object" && typeof schema != "boolean")
        throw new Error("schema should be object or boolean");
      var serialize = this._opts.serialize;
      var cacheKey = serialize ? serialize(schema) : schema;
      var cached = this._cache.get(cacheKey);
      if (cached)
        return cached;
      shouldAddSchema = shouldAddSchema || this._opts.addUsedSchema !== false;
      var id = resolve.normalizeId(this._getId(schema));
      if (id && shouldAddSchema)
        checkUnique(this, id);
      var willValidate = this._opts.validateSchema !== false && !skipValidation;
      var recursiveMeta;
      if (willValidate && !(recursiveMeta = id && id == resolve.normalizeId(schema.$schema)))
        this.validateSchema(schema, true);
      var localRefs = resolve.ids.call(this, schema);
      var schemaObj = new SchemaObject({
        id,
        schema,
        localRefs,
        cacheKey,
        meta
      });
      if (id[0] != "#" && shouldAddSchema)
        this._refs[id] = schemaObj;
      this._cache.put(cacheKey, schemaObj);
      if (willValidate && recursiveMeta)
        this.validateSchema(schema, true);
      return schemaObj;
    }
    function _compile(schemaObj, root2) {
      if (schemaObj.compiling) {
        schemaObj.validate = callValidate;
        callValidate.schema = schemaObj.schema;
        callValidate.errors = null;
        callValidate.root = root2 ? root2 : callValidate;
        if (schemaObj.schema.$async === true)
          callValidate.$async = true;
        return callValidate;
      }
      schemaObj.compiling = true;
      var currentOpts;
      if (schemaObj.meta) {
        currentOpts = this._opts;
        this._opts = this._metaOpts;
      }
      var v;
      try {
        v = compileSchema.call(this, schemaObj.schema, root2, schemaObj.localRefs);
      } catch (e) {
        delete schemaObj.validate;
        throw e;
      } finally {
        schemaObj.compiling = false;
        if (schemaObj.meta)
          this._opts = currentOpts;
      }
      schemaObj.validate = v;
      schemaObj.refs = v.refs;
      schemaObj.refVal = v.refVal;
      schemaObj.root = v.root;
      return v;
      function callValidate() {
        var _validate = schemaObj.validate;
        var result = _validate.apply(this, arguments);
        callValidate.errors = _validate.errors;
        return result;
      }
    }
    function chooseGetId(opts) {
      switch (opts.schemaId) {
        case "auto":
          return _get$IdOrId;
        case "id":
          return _getId;
        default:
          return _get$Id;
      }
    }
    function _getId(schema) {
      if (schema.$id)
        this.logger.warn("schema $id ignored", schema.$id);
      return schema.id;
    }
    function _get$Id(schema) {
      if (schema.id)
        this.logger.warn("schema id ignored", schema.id);
      return schema.$id;
    }
    function _get$IdOrId(schema) {
      if (schema.$id && schema.id && schema.$id != schema.id)
        throw new Error("schema $id is different from id");
      return schema.$id || schema.id;
    }
    function errorsText(errors, options) {
      errors = errors || this.errors;
      if (!errors)
        return "No errors";
      options = options || {};
      var separator = options.separator === void 0 ? ", " : options.separator;
      var dataVar = options.dataVar === void 0 ? "data" : options.dataVar;
      var text = "";
      for (var i = 0; i < errors.length; i++) {
        var e = errors[i];
        if (e)
          text += dataVar + e.dataPath + " " + e.message + separator;
      }
      return text.slice(0, -separator.length);
    }
    function addFormat(name, format2) {
      if (typeof format2 == "string")
        format2 = new RegExp(format2);
      this._formats[name] = format2;
      return this;
    }
    function addDefaultMetaSchema(self2) {
      var $dataSchema;
      if (self2._opts.$data) {
        $dataSchema = require_data2();
        self2.addMetaSchema($dataSchema, $dataSchema.$id, true);
      }
      if (self2._opts.meta === false)
        return;
      var metaSchema = require_json_schema_draft_07();
      if (self2._opts.$data)
        metaSchema = $dataMetaSchema(metaSchema, META_SUPPORT_DATA);
      self2.addMetaSchema(metaSchema, META_SCHEMA_ID, true);
      self2._refs["http://json-schema.org/schema"] = META_SCHEMA_ID;
    }
    function addInitialSchemas(self2) {
      var optsSchemas = self2._opts.schemas;
      if (!optsSchemas)
        return;
      if (Array.isArray(optsSchemas))
        self2.addSchema(optsSchemas);
      else
        for (var key in optsSchemas)
          self2.addSchema(optsSchemas[key], key);
    }
    function addInitialFormats(self2) {
      for (var name in self2._opts.formats) {
        var format2 = self2._opts.formats[name];
        self2.addFormat(name, format2);
      }
    }
    function addInitialKeywords(self2) {
      for (var name in self2._opts.keywords) {
        var keyword = self2._opts.keywords[name];
        self2.addKeyword(name, keyword);
      }
    }
    function checkUnique(self2, id) {
      if (self2._schemas[id] || self2._refs[id])
        throw new Error('schema with key or id "' + id + '" already exists');
    }
    function getMetaSchemaOptions(self2) {
      var metaOpts = util.copy(self2._opts);
      for (var i = 0; i < META_IGNORE_OPTIONS.length; i++)
        delete metaOpts[META_IGNORE_OPTIONS[i]];
      return metaOpts;
    }
    function setLogger(self2) {
      var logger = self2._opts.logger;
      if (logger === false) {
        self2.logger = { log: noop, warn: noop, error: noop };
      } else {
        if (logger === void 0)
          logger = console;
        if (!(typeof logger == "object" && logger.log && logger.warn && logger.error))
          throw new Error("logger must implement log, warn and error methods");
        self2.logger = logger;
      }
    }
    function noop() {
    }
  }
});

// node_modules/@eslint/eslintrc/node_modules/globals/globals.json
var require_globals = __commonJS({
  "node_modules/@eslint/eslintrc/node_modules/globals/globals.json"(exports, module2) {
    module2.exports = {
      builtin: {
        AggregateError: false,
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        FinalizationRegistry: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakRef: false,
        WeakSet: false
      },
      es5: {
        Array: false,
        Boolean: false,
        constructor: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        propertyIsEnumerable: false,
        RangeError: false,
        ReferenceError: false,
        RegExp: false,
        String: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false
      },
      es2015: {
        Array: false,
        ArrayBuffer: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2017: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2020: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2021: {
        AggregateError: false,
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        FinalizationRegistry: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakRef: false,
        WeakSet: false
      },
      browser: {
        AbortController: false,
        AbortSignal: false,
        addEventListener: false,
        alert: false,
        AnalyserNode: false,
        Animation: false,
        AnimationEffectReadOnly: false,
        AnimationEffectTiming: false,
        AnimationEffectTimingReadOnly: false,
        AnimationEvent: false,
        AnimationPlaybackEvent: false,
        AnimationTimeline: false,
        applicationCache: false,
        ApplicationCache: false,
        ApplicationCacheErrorEvent: false,
        atob: false,
        Attr: false,
        Audio: false,
        AudioBuffer: false,
        AudioBufferSourceNode: false,
        AudioContext: false,
        AudioDestinationNode: false,
        AudioListener: false,
        AudioNode: false,
        AudioParam: false,
        AudioProcessingEvent: false,
        AudioScheduledSourceNode: false,
        AudioWorkletGlobalScope: false,
        AudioWorkletNode: false,
        AudioWorkletProcessor: false,
        BarProp: false,
        BaseAudioContext: false,
        BatteryManager: false,
        BeforeUnloadEvent: false,
        BiquadFilterNode: false,
        Blob: false,
        BlobEvent: false,
        blur: false,
        BroadcastChannel: false,
        btoa: false,
        BudgetService: false,
        ByteLengthQueuingStrategy: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        cancelAnimationFrame: false,
        cancelIdleCallback: false,
        CanvasCaptureMediaStreamTrack: false,
        CanvasGradient: false,
        CanvasPattern: false,
        CanvasRenderingContext2D: false,
        ChannelMergerNode: false,
        ChannelSplitterNode: false,
        CharacterData: false,
        clearInterval: false,
        clearTimeout: false,
        clientInformation: false,
        ClipboardEvent: false,
        ClipboardItem: false,
        close: false,
        closed: false,
        CloseEvent: false,
        Comment: false,
        CompositionEvent: false,
        confirm: false,
        console: false,
        ConstantSourceNode: false,
        ConvolverNode: false,
        CountQueuingStrategy: false,
        createImageBitmap: false,
        Credential: false,
        CredentialsContainer: false,
        crypto: false,
        Crypto: false,
        CryptoKey: false,
        CSS: false,
        CSSConditionRule: false,
        CSSFontFaceRule: false,
        CSSGroupingRule: false,
        CSSImportRule: false,
        CSSKeyframeRule: false,
        CSSKeyframesRule: false,
        CSSMatrixComponent: false,
        CSSMediaRule: false,
        CSSNamespaceRule: false,
        CSSPageRule: false,
        CSSPerspective: false,
        CSSRotate: false,
        CSSRule: false,
        CSSRuleList: false,
        CSSScale: false,
        CSSSkew: false,
        CSSSkewX: false,
        CSSSkewY: false,
        CSSStyleDeclaration: false,
        CSSStyleRule: false,
        CSSStyleSheet: false,
        CSSSupportsRule: false,
        CSSTransformValue: false,
        CSSTranslate: false,
        CustomElementRegistry: false,
        customElements: false,
        CustomEvent: false,
        DataTransfer: false,
        DataTransferItem: false,
        DataTransferItemList: false,
        defaultstatus: false,
        defaultStatus: false,
        DelayNode: false,
        DeviceMotionEvent: false,
        DeviceOrientationEvent: false,
        devicePixelRatio: false,
        dispatchEvent: false,
        document: false,
        Document: false,
        DocumentFragment: false,
        DocumentType: false,
        DOMError: false,
        DOMException: false,
        DOMImplementation: false,
        DOMMatrix: false,
        DOMMatrixReadOnly: false,
        DOMParser: false,
        DOMPoint: false,
        DOMPointReadOnly: false,
        DOMQuad: false,
        DOMRect: false,
        DOMRectList: false,
        DOMRectReadOnly: false,
        DOMStringList: false,
        DOMStringMap: false,
        DOMTokenList: false,
        DragEvent: false,
        DynamicsCompressorNode: false,
        Element: false,
        ErrorEvent: false,
        event: false,
        Event: false,
        EventSource: false,
        EventTarget: false,
        external: false,
        fetch: false,
        File: false,
        FileList: false,
        FileReader: false,
        find: false,
        focus: false,
        FocusEvent: false,
        FontFace: false,
        FontFaceSetLoadEvent: false,
        FormData: false,
        FormDataEvent: false,
        frameElement: false,
        frames: false,
        GainNode: false,
        Gamepad: false,
        GamepadButton: false,
        GamepadEvent: false,
        getComputedStyle: false,
        getSelection: false,
        HashChangeEvent: false,
        Headers: false,
        history: false,
        History: false,
        HTMLAllCollection: false,
        HTMLAnchorElement: false,
        HTMLAreaElement: false,
        HTMLAudioElement: false,
        HTMLBaseElement: false,
        HTMLBodyElement: false,
        HTMLBRElement: false,
        HTMLButtonElement: false,
        HTMLCanvasElement: false,
        HTMLCollection: false,
        HTMLContentElement: false,
        HTMLDataElement: false,
        HTMLDataListElement: false,
        HTMLDetailsElement: false,
        HTMLDialogElement: false,
        HTMLDirectoryElement: false,
        HTMLDivElement: false,
        HTMLDListElement: false,
        HTMLDocument: false,
        HTMLElement: false,
        HTMLEmbedElement: false,
        HTMLFieldSetElement: false,
        HTMLFontElement: false,
        HTMLFormControlsCollection: false,
        HTMLFormElement: false,
        HTMLFrameElement: false,
        HTMLFrameSetElement: false,
        HTMLHeadElement: false,
        HTMLHeadingElement: false,
        HTMLHRElement: false,
        HTMLHtmlElement: false,
        HTMLIFrameElement: false,
        HTMLImageElement: false,
        HTMLInputElement: false,
        HTMLLabelElement: false,
        HTMLLegendElement: false,
        HTMLLIElement: false,
        HTMLLinkElement: false,
        HTMLMapElement: false,
        HTMLMarqueeElement: false,
        HTMLMediaElement: false,
        HTMLMenuElement: false,
        HTMLMetaElement: false,
        HTMLMeterElement: false,
        HTMLModElement: false,
        HTMLObjectElement: false,
        HTMLOListElement: false,
        HTMLOptGroupElement: false,
        HTMLOptionElement: false,
        HTMLOptionsCollection: false,
        HTMLOutputElement: false,
        HTMLParagraphElement: false,
        HTMLParamElement: false,
        HTMLPictureElement: false,
        HTMLPreElement: false,
        HTMLProgressElement: false,
        HTMLQuoteElement: false,
        HTMLScriptElement: false,
        HTMLSelectElement: false,
        HTMLShadowElement: false,
        HTMLSlotElement: false,
        HTMLSourceElement: false,
        HTMLSpanElement: false,
        HTMLStyleElement: false,
        HTMLTableCaptionElement: false,
        HTMLTableCellElement: false,
        HTMLTableColElement: false,
        HTMLTableElement: false,
        HTMLTableRowElement: false,
        HTMLTableSectionElement: false,
        HTMLTemplateElement: false,
        HTMLTextAreaElement: false,
        HTMLTimeElement: false,
        HTMLTitleElement: false,
        HTMLTrackElement: false,
        HTMLUListElement: false,
        HTMLUnknownElement: false,
        HTMLVideoElement: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        IdleDeadline: false,
        IIRFilterNode: false,
        Image: false,
        ImageBitmap: false,
        ImageBitmapRenderingContext: false,
        ImageCapture: false,
        ImageData: false,
        indexedDB: false,
        innerHeight: false,
        innerWidth: false,
        InputEvent: false,
        IntersectionObserver: false,
        IntersectionObserverEntry: false,
        Intl: false,
        isSecureContext: false,
        KeyboardEvent: false,
        KeyframeEffect: false,
        KeyframeEffectReadOnly: false,
        length: false,
        localStorage: false,
        location: true,
        Location: false,
        locationbar: false,
        matchMedia: false,
        MediaDeviceInfo: false,
        MediaDevices: false,
        MediaElementAudioSourceNode: false,
        MediaEncryptedEvent: false,
        MediaError: false,
        MediaKeyMessageEvent: false,
        MediaKeySession: false,
        MediaKeyStatusMap: false,
        MediaKeySystemAccess: false,
        MediaList: false,
        MediaMetadata: false,
        MediaQueryList: false,
        MediaQueryListEvent: false,
        MediaRecorder: false,
        MediaSettingsRange: false,
        MediaSource: false,
        MediaStream: false,
        MediaStreamAudioDestinationNode: false,
        MediaStreamAudioSourceNode: false,
        MediaStreamEvent: false,
        MediaStreamTrack: false,
        MediaStreamTrackEvent: false,
        menubar: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        MIDIAccess: false,
        MIDIConnectionEvent: false,
        MIDIInput: false,
        MIDIInputMap: false,
        MIDIMessageEvent: false,
        MIDIOutput: false,
        MIDIOutputMap: false,
        MIDIPort: false,
        MimeType: false,
        MimeTypeArray: false,
        MouseEvent: false,
        moveBy: false,
        moveTo: false,
        MutationEvent: false,
        MutationObserver: false,
        MutationRecord: false,
        name: false,
        NamedNodeMap: false,
        NavigationPreloadManager: false,
        navigator: false,
        Navigator: false,
        NavigatorUAData: false,
        NetworkInformation: false,
        Node: false,
        NodeFilter: false,
        NodeIterator: false,
        NodeList: false,
        Notification: false,
        OfflineAudioCompletionEvent: false,
        OfflineAudioContext: false,
        offscreenBuffering: false,
        OffscreenCanvas: true,
        OffscreenCanvasRenderingContext2D: false,
        onabort: true,
        onafterprint: true,
        onanimationend: true,
        onanimationiteration: true,
        onanimationstart: true,
        onappinstalled: true,
        onauxclick: true,
        onbeforeinstallprompt: true,
        onbeforeprint: true,
        onbeforeunload: true,
        onblur: true,
        oncancel: true,
        oncanplay: true,
        oncanplaythrough: true,
        onchange: true,
        onclick: true,
        onclose: true,
        oncontextmenu: true,
        oncuechange: true,
        ondblclick: true,
        ondevicemotion: true,
        ondeviceorientation: true,
        ondeviceorientationabsolute: true,
        ondrag: true,
        ondragend: true,
        ondragenter: true,
        ondragleave: true,
        ondragover: true,
        ondragstart: true,
        ondrop: true,
        ondurationchange: true,
        onemptied: true,
        onended: true,
        onerror: true,
        onfocus: true,
        ongotpointercapture: true,
        onhashchange: true,
        oninput: true,
        oninvalid: true,
        onkeydown: true,
        onkeypress: true,
        onkeyup: true,
        onlanguagechange: true,
        onload: true,
        onloadeddata: true,
        onloadedmetadata: true,
        onloadstart: true,
        onlostpointercapture: true,
        onmessage: true,
        onmessageerror: true,
        onmousedown: true,
        onmouseenter: true,
        onmouseleave: true,
        onmousemove: true,
        onmouseout: true,
        onmouseover: true,
        onmouseup: true,
        onmousewheel: true,
        onoffline: true,
        ononline: true,
        onpagehide: true,
        onpageshow: true,
        onpause: true,
        onplay: true,
        onplaying: true,
        onpointercancel: true,
        onpointerdown: true,
        onpointerenter: true,
        onpointerleave: true,
        onpointermove: true,
        onpointerout: true,
        onpointerover: true,
        onpointerup: true,
        onpopstate: true,
        onprogress: true,
        onratechange: true,
        onrejectionhandled: true,
        onreset: true,
        onresize: true,
        onscroll: true,
        onsearch: true,
        onseeked: true,
        onseeking: true,
        onselect: true,
        onstalled: true,
        onstorage: true,
        onsubmit: true,
        onsuspend: true,
        ontimeupdate: true,
        ontoggle: true,
        ontransitionend: true,
        onunhandledrejection: true,
        onunload: true,
        onvolumechange: true,
        onwaiting: true,
        onwheel: true,
        open: false,
        openDatabase: false,
        opener: false,
        Option: false,
        origin: false,
        OscillatorNode: false,
        outerHeight: false,
        outerWidth: false,
        OverconstrainedError: false,
        PageTransitionEvent: false,
        pageXOffset: false,
        pageYOffset: false,
        PannerNode: false,
        parent: false,
        Path2D: false,
        PaymentAddress: false,
        PaymentRequest: false,
        PaymentRequestUpdateEvent: false,
        PaymentResponse: false,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceLongTaskTiming: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceNavigationTiming: false,
        PerformanceObserver: false,
        PerformanceObserverEntryList: false,
        PerformancePaintTiming: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        PeriodicWave: false,
        Permissions: false,
        PermissionStatus: false,
        personalbar: false,
        PhotoCapabilities: false,
        Plugin: false,
        PluginArray: false,
        PointerEvent: false,
        PopStateEvent: false,
        postMessage: false,
        Presentation: false,
        PresentationAvailability: false,
        PresentationConnection: false,
        PresentationConnectionAvailableEvent: false,
        PresentationConnectionCloseEvent: false,
        PresentationConnectionList: false,
        PresentationReceiver: false,
        PresentationRequest: false,
        print: false,
        ProcessingInstruction: false,
        ProgressEvent: false,
        PromiseRejectionEvent: false,
        prompt: false,
        PushManager: false,
        PushSubscription: false,
        PushSubscriptionOptions: false,
        queueMicrotask: false,
        RadioNodeList: false,
        Range: false,
        ReadableStream: false,
        registerProcessor: false,
        RemotePlayback: false,
        removeEventListener: false,
        reportError: false,
        Request: false,
        requestAnimationFrame: false,
        requestIdleCallback: false,
        resizeBy: false,
        ResizeObserver: false,
        ResizeObserverEntry: false,
        resizeTo: false,
        Response: false,
        RTCCertificate: false,
        RTCDataChannel: false,
        RTCDataChannelEvent: false,
        RTCDtlsTransport: false,
        RTCIceCandidate: false,
        RTCIceGatherer: false,
        RTCIceTransport: false,
        RTCPeerConnection: false,
        RTCPeerConnectionIceEvent: false,
        RTCRtpContributingSource: false,
        RTCRtpReceiver: false,
        RTCRtpSender: false,
        RTCSctpTransport: false,
        RTCSessionDescription: false,
        RTCStatsReport: false,
        RTCTrackEvent: false,
        screen: false,
        Screen: false,
        screenLeft: false,
        ScreenOrientation: false,
        screenTop: false,
        screenX: false,
        screenY: false,
        ScriptProcessorNode: false,
        scroll: false,
        scrollbars: false,
        scrollBy: false,
        scrollTo: false,
        scrollX: false,
        scrollY: false,
        SecurityPolicyViolationEvent: false,
        Selection: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerRegistration: false,
        sessionStorage: false,
        setInterval: false,
        setTimeout: false,
        ShadowRoot: false,
        SharedWorker: false,
        SourceBuffer: false,
        SourceBufferList: false,
        speechSynthesis: false,
        SpeechSynthesisEvent: false,
        SpeechSynthesisUtterance: false,
        StaticRange: false,
        status: false,
        statusbar: false,
        StereoPannerNode: false,
        stop: false,
        Storage: false,
        StorageEvent: false,
        StorageManager: false,
        structuredClone: false,
        styleMedia: false,
        StyleSheet: false,
        StyleSheetList: false,
        SubmitEvent: false,
        SubtleCrypto: false,
        SVGAElement: false,
        SVGAngle: false,
        SVGAnimatedAngle: false,
        SVGAnimatedBoolean: false,
        SVGAnimatedEnumeration: false,
        SVGAnimatedInteger: false,
        SVGAnimatedLength: false,
        SVGAnimatedLengthList: false,
        SVGAnimatedNumber: false,
        SVGAnimatedNumberList: false,
        SVGAnimatedPreserveAspectRatio: false,
        SVGAnimatedRect: false,
        SVGAnimatedString: false,
        SVGAnimatedTransformList: false,
        SVGAnimateElement: false,
        SVGAnimateMotionElement: false,
        SVGAnimateTransformElement: false,
        SVGAnimationElement: false,
        SVGCircleElement: false,
        SVGClipPathElement: false,
        SVGComponentTransferFunctionElement: false,
        SVGDefsElement: false,
        SVGDescElement: false,
        SVGDiscardElement: false,
        SVGElement: false,
        SVGEllipseElement: false,
        SVGFEBlendElement: false,
        SVGFEColorMatrixElement: false,
        SVGFEComponentTransferElement: false,
        SVGFECompositeElement: false,
        SVGFEConvolveMatrixElement: false,
        SVGFEDiffuseLightingElement: false,
        SVGFEDisplacementMapElement: false,
        SVGFEDistantLightElement: false,
        SVGFEDropShadowElement: false,
        SVGFEFloodElement: false,
        SVGFEFuncAElement: false,
        SVGFEFuncBElement: false,
        SVGFEFuncGElement: false,
        SVGFEFuncRElement: false,
        SVGFEGaussianBlurElement: false,
        SVGFEImageElement: false,
        SVGFEMergeElement: false,
        SVGFEMergeNodeElement: false,
        SVGFEMorphologyElement: false,
        SVGFEOffsetElement: false,
        SVGFEPointLightElement: false,
        SVGFESpecularLightingElement: false,
        SVGFESpotLightElement: false,
        SVGFETileElement: false,
        SVGFETurbulenceElement: false,
        SVGFilterElement: false,
        SVGForeignObjectElement: false,
        SVGGElement: false,
        SVGGeometryElement: false,
        SVGGradientElement: false,
        SVGGraphicsElement: false,
        SVGImageElement: false,
        SVGLength: false,
        SVGLengthList: false,
        SVGLinearGradientElement: false,
        SVGLineElement: false,
        SVGMarkerElement: false,
        SVGMaskElement: false,
        SVGMatrix: false,
        SVGMetadataElement: false,
        SVGMPathElement: false,
        SVGNumber: false,
        SVGNumberList: false,
        SVGPathElement: false,
        SVGPatternElement: false,
        SVGPoint: false,
        SVGPointList: false,
        SVGPolygonElement: false,
        SVGPolylineElement: false,
        SVGPreserveAspectRatio: false,
        SVGRadialGradientElement: false,
        SVGRect: false,
        SVGRectElement: false,
        SVGScriptElement: false,
        SVGSetElement: false,
        SVGStopElement: false,
        SVGStringList: false,
        SVGStyleElement: false,
        SVGSVGElement: false,
        SVGSwitchElement: false,
        SVGSymbolElement: false,
        SVGTextContentElement: false,
        SVGTextElement: false,
        SVGTextPathElement: false,
        SVGTextPositioningElement: false,
        SVGTitleElement: false,
        SVGTransform: false,
        SVGTransformList: false,
        SVGTSpanElement: false,
        SVGUnitTypes: false,
        SVGUseElement: false,
        SVGViewElement: false,
        TaskAttributionTiming: false,
        Text: false,
        TextDecoder: false,
        TextEncoder: false,
        TextEvent: false,
        TextMetrics: false,
        TextTrack: false,
        TextTrackCue: false,
        TextTrackCueList: false,
        TextTrackList: false,
        TimeRanges: false,
        toolbar: false,
        top: false,
        Touch: false,
        TouchEvent: false,
        TouchList: false,
        TrackEvent: false,
        TransformStream: false,
        TransitionEvent: false,
        TreeWalker: false,
        UIEvent: false,
        URL: false,
        URLSearchParams: false,
        ValidityState: false,
        visualViewport: false,
        VisualViewport: false,
        VTTCue: false,
        WaveShaperNode: false,
        WebAssembly: false,
        WebGL2RenderingContext: false,
        WebGLActiveInfo: false,
        WebGLBuffer: false,
        WebGLContextEvent: false,
        WebGLFramebuffer: false,
        WebGLProgram: false,
        WebGLQuery: false,
        WebGLRenderbuffer: false,
        WebGLRenderingContext: false,
        WebGLSampler: false,
        WebGLShader: false,
        WebGLShaderPrecisionFormat: false,
        WebGLSync: false,
        WebGLTexture: false,
        WebGLTransformFeedback: false,
        WebGLUniformLocation: false,
        WebGLVertexArrayObject: false,
        WebSocket: false,
        WheelEvent: false,
        window: false,
        Window: false,
        Worker: false,
        WritableStream: false,
        XMLDocument: false,
        XMLHttpRequest: false,
        XMLHttpRequestEventTarget: false,
        XMLHttpRequestUpload: false,
        XMLSerializer: false,
        XPathEvaluator: false,
        XPathExpression: false,
        XPathResult: false,
        XSLTProcessor: false
      },
      worker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        clearInterval: false,
        clearTimeout: false,
        close: true,
        console: false,
        CustomEvent: false,
        ErrorEvent: false,
        Event: false,
        fetch: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: true,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onlanguagechange: true,
        onmessage: true,
        onoffline: true,
        ononline: true,
        onrejectionhandled: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        removeEventListener: false,
        reportError: false,
        Request: false,
        Response: false,
        self: true,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      node: {
        __dirname: false,
        __filename: false,
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        Buffer: false,
        clearImmediate: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        exports: true,
        fetch: false,
        global: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        module: false,
        performance: false,
        process: false,
        queueMicrotask: false,
        require: false,
        setImmediate: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      nodeBuiltin: {
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        Buffer: false,
        clearImmediate: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        fetch: false,
        global: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        performance: false,
        process: false,
        queueMicrotask: false,
        setImmediate: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      commonjs: {
        exports: true,
        global: false,
        module: false,
        require: false
      },
      amd: {
        define: false,
        require: false
      },
      mocha: {
        after: false,
        afterEach: false,
        before: false,
        beforeEach: false,
        context: false,
        describe: false,
        it: false,
        mocha: false,
        run: false,
        setup: false,
        specify: false,
        suite: false,
        suiteSetup: false,
        suiteTeardown: false,
        teardown: false,
        test: false,
        xcontext: false,
        xdescribe: false,
        xit: false,
        xspecify: false
      },
      jasmine: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        expectAsync: false,
        fail: false,
        fdescribe: false,
        fit: false,
        it: false,
        jasmine: false,
        pending: false,
        runs: false,
        spyOn: false,
        spyOnAllFunctions: false,
        spyOnProperty: false,
        waits: false,
        waitsFor: false,
        xdescribe: false,
        xit: false
      },
      jest: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        fdescribe: false,
        fit: false,
        it: false,
        jest: false,
        pit: false,
        require: false,
        test: false,
        xdescribe: false,
        xit: false,
        xtest: false
      },
      qunit: {
        asyncTest: false,
        deepEqual: false,
        equal: false,
        expect: false,
        module: false,
        notDeepEqual: false,
        notEqual: false,
        notOk: false,
        notPropEqual: false,
        notStrictEqual: false,
        ok: false,
        propEqual: false,
        QUnit: false,
        raises: false,
        start: false,
        stop: false,
        strictEqual: false,
        test: false,
        throws: false
      },
      phantomjs: {
        console: true,
        exports: true,
        phantom: true,
        require: true,
        WebPage: true
      },
      couch: {
        emit: false,
        exports: false,
        getRow: false,
        log: false,
        module: false,
        provides: false,
        require: false,
        respond: false,
        send: false,
        start: false,
        sum: false
      },
      rhino: {
        defineClass: false,
        deserialize: false,
        gc: false,
        help: false,
        importClass: false,
        importPackage: false,
        java: false,
        load: false,
        loadClass: false,
        Packages: false,
        print: false,
        quit: false,
        readFile: false,
        readUrl: false,
        runCommand: false,
        seal: false,
        serialize: false,
        spawn: false,
        sync: false,
        toint32: false,
        version: false
      },
      nashorn: {
        __DIR__: false,
        __FILE__: false,
        __LINE__: false,
        com: false,
        edu: false,
        exit: false,
        java: false,
        Java: false,
        javafx: false,
        JavaImporter: false,
        javax: false,
        JSAdapter: false,
        load: false,
        loadWithNewGlobal: false,
        org: false,
        Packages: false,
        print: false,
        quit: false
      },
      wsh: {
        ActiveXObject: false,
        CollectGarbage: false,
        Debug: false,
        Enumerator: false,
        GetObject: false,
        RuntimeObject: false,
        ScriptEngine: false,
        ScriptEngineBuildVersion: false,
        ScriptEngineMajorVersion: false,
        ScriptEngineMinorVersion: false,
        VBArray: false,
        WScript: false,
        WSH: false
      },
      jquery: {
        $: false,
        jQuery: false
      },
      yui: {
        YAHOO: false,
        YAHOO_config: false,
        YUI: false,
        YUI_config: false
      },
      shelljs: {
        cat: false,
        cd: false,
        chmod: false,
        config: false,
        cp: false,
        dirs: false,
        echo: false,
        env: false,
        error: false,
        exec: false,
        exit: false,
        find: false,
        grep: false,
        ln: false,
        ls: false,
        mkdir: false,
        mv: false,
        popd: false,
        pushd: false,
        pwd: false,
        rm: false,
        sed: false,
        set: false,
        target: false,
        tempdir: false,
        test: false,
        touch: false,
        which: false
      },
      prototypejs: {
        $: false,
        $$: false,
        $A: false,
        $break: false,
        $continue: false,
        $F: false,
        $H: false,
        $R: false,
        $w: false,
        Abstract: false,
        Ajax: false,
        Autocompleter: false,
        Builder: false,
        Class: false,
        Control: false,
        Draggable: false,
        Draggables: false,
        Droppables: false,
        Effect: false,
        Element: false,
        Enumerable: false,
        Event: false,
        Field: false,
        Form: false,
        Hash: false,
        Insertion: false,
        ObjectRange: false,
        PeriodicalExecuter: false,
        Position: false,
        Prototype: false,
        Scriptaculous: false,
        Selector: false,
        Sortable: false,
        SortableObserver: false,
        Sound: false,
        Template: false,
        Toggle: false,
        Try: false
      },
      meteor: {
        $: false,
        Accounts: false,
        AccountsClient: false,
        AccountsCommon: false,
        AccountsServer: false,
        App: false,
        Assets: false,
        Blaze: false,
        check: false,
        Cordova: false,
        DDP: false,
        DDPRateLimiter: false,
        DDPServer: false,
        Deps: false,
        EJSON: false,
        Email: false,
        HTTP: false,
        Log: false,
        Match: false,
        Meteor: false,
        Mongo: false,
        MongoInternals: false,
        Npm: false,
        Package: false,
        Plugin: false,
        process: false,
        Random: false,
        ReactiveDict: false,
        ReactiveVar: false,
        Router: false,
        ServiceConfiguration: false,
        Session: false,
        share: false,
        Spacebars: false,
        Template: false,
        Tinytest: false,
        Tracker: false,
        UI: false,
        Utils: false,
        WebApp: false,
        WebAppInternals: false
      },
      mongo: {
        _isWindows: false,
        _rand: false,
        BulkWriteResult: false,
        cat: false,
        cd: false,
        connect: false,
        db: false,
        getHostName: false,
        getMemInfo: false,
        hostname: false,
        ISODate: false,
        listFiles: false,
        load: false,
        ls: false,
        md5sumFile: false,
        mkdir: false,
        Mongo: false,
        NumberInt: false,
        NumberLong: false,
        ObjectId: false,
        PlanCache: false,
        print: false,
        printjson: false,
        pwd: false,
        quit: false,
        removeFile: false,
        rs: false,
        sh: false,
        UUID: false,
        version: false,
        WriteResult: false
      },
      applescript: {
        $: false,
        Application: false,
        Automation: false,
        console: false,
        delay: false,
        Library: false,
        ObjC: false,
        ObjectSpecifier: false,
        Path: false,
        Progress: false,
        Ref: false
      },
      serviceworker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        clearInterval: false,
        clearTimeout: false,
        Client: false,
        clients: false,
        Clients: false,
        close: true,
        console: false,
        CustomEvent: false,
        ErrorEvent: false,
        Event: false,
        ExtendableEvent: false,
        ExtendableMessageEvent: false,
        fetch: false,
        FetchEvent: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: false,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onfetch: true,
        oninstall: true,
        onlanguagechange: true,
        onmessage: true,
        onmessageerror: true,
        onnotificationclick: true,
        onnotificationclose: true,
        onoffline: true,
        ononline: true,
        onpush: true,
        onpushsubscriptionchange: true,
        onrejectionhandled: true,
        onsync: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        registration: false,
        removeEventListener: false,
        Request: false,
        Response: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerGlobalScope: false,
        ServiceWorkerMessageEvent: false,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        skipWaiting: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        WindowClient: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      atomtest: {
        advanceClock: false,
        atom: false,
        fakeClearInterval: false,
        fakeClearTimeout: false,
        fakeSetInterval: false,
        fakeSetTimeout: false,
        resetTimeouts: false,
        waitsForPromise: false
      },
      embertest: {
        andThen: false,
        click: false,
        currentPath: false,
        currentRouteName: false,
        currentURL: false,
        fillIn: false,
        find: false,
        findAll: false,
        findWithAssert: false,
        keyEvent: false,
        pauseTest: false,
        resumeTest: false,
        triggerEvent: false,
        visit: false,
        wait: false
      },
      protractor: {
        $: false,
        $$: false,
        browser: false,
        by: false,
        By: false,
        DartObject: false,
        element: false,
        protractor: false
      },
      "shared-node-browser": {
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        fetch: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        performance: false,
        queueMicrotask: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      webextensions: {
        browser: false,
        chrome: false,
        opr: false
      },
      greasemonkey: {
        cloneInto: false,
        createObjectIn: false,
        exportFunction: false,
        GM: false,
        GM_addElement: false,
        GM_addStyle: false,
        GM_addValueChangeListener: false,
        GM_deleteValue: false,
        GM_download: false,
        GM_getResourceText: false,
        GM_getResourceURL: false,
        GM_getTab: false,
        GM_getTabs: false,
        GM_getValue: false,
        GM_info: false,
        GM_listValues: false,
        GM_log: false,
        GM_notification: false,
        GM_openInTab: false,
        GM_registerMenuCommand: false,
        GM_removeValueChangeListener: false,
        GM_saveTab: false,
        GM_setClipboard: false,
        GM_setValue: false,
        GM_unregisterMenuCommand: false,
        GM_xmlhttpRequest: false,
        unsafeWindow: false
      },
      devtools: {
        $: false,
        $_: false,
        $$: false,
        $0: false,
        $1: false,
        $2: false,
        $3: false,
        $4: false,
        $x: false,
        chrome: false,
        clear: false,
        copy: false,
        debug: false,
        dir: false,
        dirxml: false,
        getEventListeners: false,
        inspect: false,
        keys: false,
        monitor: false,
        monitorEvents: false,
        profile: false,
        profileEnd: false,
        queryObjects: false,
        table: false,
        undebug: false,
        unmonitor: false,
        unmonitorEvents: false,
        values: false
      }
    };
  }
});

// node_modules/@eslint/eslintrc/node_modules/globals/index.js
var require_globals2 = __commonJS({
  "node_modules/@eslint/eslintrc/node_modules/globals/index.js"(exports, module2) {
    "use strict";
    module2.exports = require_globals();
  }
});

// node_modules/@eslint/eslintrc/dist/eslintrc.cjs
var require_eslintrc = __commonJS({
  "node_modules/@eslint/eslintrc/dist/eslintrc.cjs"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var debugOrig = require_src();
    var fs2 = require("fs");
    var importFresh = require_import_fresh();
    var Module = require("module");
    var path2 = require("path");
    var stripComments = require_strip_json_comments();
    var assert = require("assert");
    var ignore = require_ignore();
    var util = require("util");
    var minimatch = require_minimatch();
    var Ajv = require_ajv();
    var globals = require_globals2();
    var os = require("os");
    function _interopDefaultLegacy(e) {
      return e && typeof e === "object" && "default" in e ? e : { "default": e };
    }
    var debugOrig__default = /* @__PURE__ */ _interopDefaultLegacy(debugOrig);
    var fs__default = /* @__PURE__ */ _interopDefaultLegacy(fs2);
    var importFresh__default = /* @__PURE__ */ _interopDefaultLegacy(importFresh);
    var Module__default = /* @__PURE__ */ _interopDefaultLegacy(Module);
    var path__default = /* @__PURE__ */ _interopDefaultLegacy(path2);
    var stripComments__default = /* @__PURE__ */ _interopDefaultLegacy(stripComments);
    var assert__default = /* @__PURE__ */ _interopDefaultLegacy(assert);
    var ignore__default = /* @__PURE__ */ _interopDefaultLegacy(ignore);
    var util__default = /* @__PURE__ */ _interopDefaultLegacy(util);
    var minimatch__default = /* @__PURE__ */ _interopDefaultLegacy(minimatch);
    var Ajv__default = /* @__PURE__ */ _interopDefaultLegacy(Ajv);
    var globals__default = /* @__PURE__ */ _interopDefaultLegacy(globals);
    var os__default = /* @__PURE__ */ _interopDefaultLegacy(os);
    var debug$3 = debugOrig__default["default"]("eslintrc:ignore-pattern");
    function getCommonAncestorPath(sourcePaths) {
      let result = sourcePaths[0];
      for (let i = 1; i < sourcePaths.length; ++i) {
        const a = result;
        const b = sourcePaths[i];
        result = a.length < b.length ? a : b;
        for (let j = 0, lastSepPos = 0; j < a.length && j < b.length; ++j) {
          if (a[j] !== b[j]) {
            result = a.slice(0, lastSepPos);
            break;
          }
          if (a[j] === path__default["default"].sep) {
            lastSepPos = j;
          }
        }
      }
      let resolvedResult = result || path__default["default"].sep;
      if (resolvedResult && resolvedResult.endsWith(":") && process.platform === "win32") {
        resolvedResult += path__default["default"].sep;
      }
      return resolvedResult;
    }
    function relative(from, to) {
      const relPath = path__default["default"].relative(from, to);
      if (path__default["default"].sep === "/") {
        return relPath;
      }
      return relPath.split(path__default["default"].sep).join("/");
    }
    function dirSuffix(filePath) {
      const isDir = filePath.endsWith(path__default["default"].sep) || process.platform === "win32" && filePath.endsWith("/");
      return isDir ? "/" : "";
    }
    var DefaultPatterns = Object.freeze(["/**/node_modules/*"]);
    var DotPatterns = Object.freeze([".*", "!.eslintrc.*", "!../"]);
    var IgnorePattern = class _IgnorePattern {
      /**
       * The default patterns.
       * @type {string[]}
       */
      static get DefaultPatterns() {
        return DefaultPatterns;
      }
      /**
       * Create the default predicate function.
       * @param {string} cwd The current working directory.
       * @returns {((filePath:string, dot:boolean) => boolean) & {basePath:string; patterns:string[]}}
       * The preficate function.
       * The first argument is an absolute path that is checked.
       * The second argument is the flag to not ignore dotfiles.
       * If the predicate function returned `true`, it means the path should be ignored.
       */
      static createDefaultIgnore(cwd) {
        return this.createIgnore([new _IgnorePattern(DefaultPatterns, cwd)]);
      }
      /**
       * Create the predicate function from multiple `IgnorePattern` objects.
       * @param {IgnorePattern[]} ignorePatterns The list of ignore patterns.
       * @returns {((filePath:string, dot?:boolean) => boolean) & {basePath:string; patterns:string[]}}
       * The preficate function.
       * The first argument is an absolute path that is checked.
       * The second argument is the flag to not ignore dotfiles.
       * If the predicate function returned `true`, it means the path should be ignored.
       */
      static createIgnore(ignorePatterns) {
        debug$3("Create with: %o", ignorePatterns);
        const basePath = getCommonAncestorPath(ignorePatterns.map((p) => p.basePath));
        const patterns = [].concat(
          ...ignorePatterns.map((p) => p.getPatternsRelativeTo(basePath))
        );
        const ig = ignore__default["default"]({ allowRelativePaths: true }).add([...DotPatterns, ...patterns]);
        const dotIg = ignore__default["default"]({ allowRelativePaths: true }).add(patterns);
        debug$3("  processed: %o", { basePath, patterns });
        return Object.assign(
          (filePath, dot = false) => {
            assert__default["default"](path__default["default"].isAbsolute(filePath), "'filePath' should be an absolute path.");
            const relPathRaw = relative(basePath, filePath);
            const relPath = relPathRaw && relPathRaw + dirSuffix(filePath);
            const adoptedIg = dot ? dotIg : ig;
            const result = relPath !== "" && adoptedIg.ignores(relPath);
            debug$3("Check", { filePath, dot, relativePath: relPath, result });
            return result;
          },
          { basePath, patterns }
        );
      }
      /**
       * Initialize a new `IgnorePattern` instance.
       * @param {string[]} patterns The glob patterns that ignore to lint.
       * @param {string} basePath The base path of `patterns`.
       */
      constructor(patterns, basePath) {
        assert__default["default"](path__default["default"].isAbsolute(basePath), "'basePath' should be an absolute path.");
        this.patterns = patterns;
        this.basePath = basePath;
        this.loose = false;
      }
      /**
       * Get `patterns` as modified for a given base path. It modifies the
       * absolute paths in the patterns as prepending the difference of two base
       * paths.
       * @param {string} newBasePath The base path.
       * @returns {string[]} Modifired patterns.
       */
      getPatternsRelativeTo(newBasePath) {
        assert__default["default"](path__default["default"].isAbsolute(newBasePath), "'newBasePath' should be an absolute path.");
        const { basePath, loose, patterns } = this;
        if (newBasePath === basePath) {
          return patterns;
        }
        const prefix = `/${relative(newBasePath, basePath)}`;
        return patterns.map((pattern) => {
          const negative = pattern.startsWith("!");
          const head = negative ? "!" : "";
          const body = negative ? pattern.slice(1) : pattern;
          if (body.startsWith("/") || body.startsWith("../")) {
            return `${head}${prefix}${body}`;
          }
          return loose ? pattern : `${head}${prefix}/**/${body}`;
        });
      }
    };
    function startsWith(xs, ys) {
      return xs.length >= ys.length && ys.every((y, i) => y === xs[i]);
    }
    var ExtractedConfig = class {
      constructor() {
        this.configNameOfNoInlineConfig = "";
        this.env = {};
        this.globals = {};
        this.ignores = void 0;
        this.noInlineConfig = void 0;
        this.parser = null;
        this.parserOptions = {};
        this.plugins = {};
        this.processor = null;
        this.reportUnusedDisableDirectives = void 0;
        this.rules = {};
        this.settings = {};
      }
      /**
       * Convert this config to the compatible object as a config file content.
       * @returns {ConfigData} The converted object.
       */
      toCompatibleObjectAsConfigFileContent() {
        const {
          /* eslint-disable no-unused-vars */
          configNameOfNoInlineConfig: _ignore1,
          processor: _ignore2,
          /* eslint-enable no-unused-vars */
          ignores,
          ...config
        } = this;
        config.parser = config.parser && config.parser.filePath;
        config.plugins = Object.keys(config.plugins).filter(Boolean).reverse();
        config.ignorePatterns = ignores ? ignores.patterns : [];
        if (startsWith(config.ignorePatterns, IgnorePattern.DefaultPatterns)) {
          config.ignorePatterns = config.ignorePatterns.slice(IgnorePattern.DefaultPatterns.length);
        }
        return config;
      }
    };
    var internalSlotsMap$2 = new class extends WeakMap {
      get(key) {
        let value2 = super.get(key);
        if (!value2) {
          value2 = {
            cache: /* @__PURE__ */ new Map(),
            envMap: null,
            processorMap: null,
            ruleMap: null
          };
          super.set(key, value2);
        }
        return value2;
      }
    }();
    function getMatchedIndices(elements, filePath) {
      const indices = [];
      for (let i = elements.length - 1; i >= 0; --i) {
        const element = elements[i];
        if (!element.criteria || filePath && element.criteria.test(filePath)) {
          indices.push(i);
        }
      }
      return indices;
    }
    function isNonNullObject(x) {
      return typeof x === "object" && x !== null;
    }
    function mergeWithoutOverwrite(target, source) {
      if (!isNonNullObject(source)) {
        return;
      }
      for (const key of Object.keys(source)) {
        if (key === "__proto__") {
          continue;
        }
        if (isNonNullObject(target[key])) {
          mergeWithoutOverwrite(target[key], source[key]);
        } else if (target[key] === void 0) {
          if (isNonNullObject(source[key])) {
            target[key] = Array.isArray(source[key]) ? [] : {};
            mergeWithoutOverwrite(target[key], source[key]);
          } else if (source[key] !== void 0) {
            target[key] = source[key];
          }
        }
      }
    }
    var PluginConflictError = class extends Error {
      /**
       * Initialize this error object.
       * @param {string} pluginId The plugin ID.
       * @param {{filePath:string, importerName:string}[]} plugins The resolved plugins.
       */
      constructor(pluginId, plugins) {
        super(`Plugin "${pluginId}" was conflicted between ${plugins.map((p) => `"${p.importerName}"`).join(" and ")}.`);
        this.messageTemplate = "plugin-conflict";
        this.messageData = { pluginId, plugins };
      }
    };
    function mergePlugins(target, source) {
      if (!isNonNullObject(source)) {
        return;
      }
      for (const key of Object.keys(source)) {
        if (key === "__proto__") {
          continue;
        }
        const targetValue = target[key];
        const sourceValue = source[key];
        if (targetValue === void 0) {
          if (sourceValue.error) {
            throw sourceValue.error;
          }
          target[key] = sourceValue;
        } else if (sourceValue.filePath !== targetValue.filePath) {
          throw new PluginConflictError(key, [
            {
              filePath: targetValue.filePath,
              importerName: targetValue.importerName
            },
            {
              filePath: sourceValue.filePath,
              importerName: sourceValue.importerName
            }
          ]);
        }
      }
    }
    function mergeRuleConfigs(target, source) {
      if (!isNonNullObject(source)) {
        return;
      }
      for (const key of Object.keys(source)) {
        if (key === "__proto__") {
          continue;
        }
        const targetDef = target[key];
        const sourceDef = source[key];
        if (targetDef === void 0) {
          if (Array.isArray(sourceDef)) {
            target[key] = [...sourceDef];
          } else {
            target[key] = [sourceDef];
          }
        } else if (targetDef.length === 1 && Array.isArray(sourceDef) && sourceDef.length >= 2) {
          targetDef.push(...sourceDef.slice(1));
        }
      }
    }
    function createConfig(instance, indices) {
      const config = new ExtractedConfig();
      const ignorePatterns = [];
      for (const index of indices) {
        const element = instance[index];
        if (!config.parser && element.parser) {
          if (element.parser.error) {
            throw element.parser.error;
          }
          config.parser = element.parser;
        }
        if (!config.processor && element.processor) {
          config.processor = element.processor;
        }
        if (config.noInlineConfig === void 0 && element.noInlineConfig !== void 0) {
          config.noInlineConfig = element.noInlineConfig;
          config.configNameOfNoInlineConfig = element.name;
        }
        if (config.reportUnusedDisableDirectives === void 0 && element.reportUnusedDisableDirectives !== void 0) {
          config.reportUnusedDisableDirectives = element.reportUnusedDisableDirectives;
        }
        if (element.ignorePattern) {
          ignorePatterns.push(element.ignorePattern);
        }
        mergeWithoutOverwrite(config.env, element.env);
        mergeWithoutOverwrite(config.globals, element.globals);
        mergeWithoutOverwrite(config.parserOptions, element.parserOptions);
        mergeWithoutOverwrite(config.settings, element.settings);
        mergePlugins(config.plugins, element.plugins);
        mergeRuleConfigs(config.rules, element.rules);
      }
      if (ignorePatterns.length > 0) {
        config.ignores = IgnorePattern.createIgnore(ignorePatterns.reverse());
      }
      return config;
    }
    function collect(pluginId, defs, map, normalize) {
      if (defs) {
        const prefix = pluginId && `${pluginId}/`;
        for (const [key, value2] of Object.entries(defs)) {
          map.set(
            `${prefix}${key}`,
            normalize ? normalize(value2) : value2
          );
        }
      }
    }
    function normalizePluginRule(rule) {
      return typeof rule === "function" ? { create: rule } : rule;
    }
    function deleteMutationMethods(map) {
      Object.defineProperties(map, {
        clear: { configurable: true, value: void 0 },
        delete: { configurable: true, value: void 0 },
        set: { configurable: true, value: void 0 }
      });
    }
    function initPluginMemberMaps(elements, slots) {
      const processed = /* @__PURE__ */ new Set();
      slots.envMap = /* @__PURE__ */ new Map();
      slots.processorMap = /* @__PURE__ */ new Map();
      slots.ruleMap = /* @__PURE__ */ new Map();
      for (const element of elements) {
        if (!element.plugins) {
          continue;
        }
        for (const [pluginId, value2] of Object.entries(element.plugins)) {
          const plugin = value2.definition;
          if (!plugin || processed.has(pluginId)) {
            continue;
          }
          processed.add(pluginId);
          collect(pluginId, plugin.environments, slots.envMap);
          collect(pluginId, plugin.processors, slots.processorMap);
          collect(pluginId, plugin.rules, slots.ruleMap, normalizePluginRule);
        }
      }
      deleteMutationMethods(slots.envMap);
      deleteMutationMethods(slots.processorMap);
      deleteMutationMethods(slots.ruleMap);
    }
    function ensurePluginMemberMaps(instance) {
      const slots = internalSlotsMap$2.get(instance);
      if (!slots.ruleMap) {
        initPluginMemberMaps(instance, slots);
      }
      return slots;
    }
    var ConfigArray = class extends Array {
      /**
       * Get the plugin environments.
       * The returned map cannot be mutated.
       * @type {ReadonlyMap<string, Environment>} The plugin environments.
       */
      get pluginEnvironments() {
        return ensurePluginMemberMaps(this).envMap;
      }
      /**
       * Get the plugin processors.
       * The returned map cannot be mutated.
       * @type {ReadonlyMap<string, Processor>} The plugin processors.
       */
      get pluginProcessors() {
        return ensurePluginMemberMaps(this).processorMap;
      }
      /**
       * Get the plugin rules.
       * The returned map cannot be mutated.
       * @returns {ReadonlyMap<string, Rule>} The plugin rules.
       */
      get pluginRules() {
        return ensurePluginMemberMaps(this).ruleMap;
      }
      /**
       * Check if this config has `root` flag.
       * @returns {boolean} `true` if this config array is root.
       */
      isRoot() {
        for (let i = this.length - 1; i >= 0; --i) {
          const root2 = this[i].root;
          if (typeof root2 === "boolean") {
            return root2;
          }
        }
        return false;
      }
      /**
       * Extract the config data which is related to a given file.
       * @param {string} filePath The absolute path to the target file.
       * @returns {ExtractedConfig} The extracted config data.
       */
      extractConfig(filePath) {
        const { cache } = internalSlotsMap$2.get(this);
        const indices = getMatchedIndices(this, filePath);
        const cacheKey = indices.join(",");
        if (!cache.has(cacheKey)) {
          cache.set(cacheKey, createConfig(this, indices));
        }
        return cache.get(cacheKey);
      }
      /**
       * Check if a given path is an additional lint target.
       * @param {string} filePath The absolute path to the target file.
       * @returns {boolean} `true` if the file is an additional lint target.
       */
      isAdditionalTargetPath(filePath) {
        for (const { criteria, type } of this) {
          if (type === "config" && criteria && !criteria.endsWithWildcard && criteria.test(filePath)) {
            return true;
          }
        }
        return false;
      }
    };
    function getUsedExtractedConfigs(instance) {
      const { cache } = internalSlotsMap$2.get(instance);
      return Array.from(cache.values());
    }
    var ConfigDependency = class {
      /**
       * Initialize this instance.
       * @param {Object} data The dependency data.
       * @param {T} [data.definition] The dependency if the loading succeeded.
       * @param {Error} [data.error] The error object if the loading failed.
       * @param {string} [data.filePath] The actual path to the dependency if the loading succeeded.
       * @param {string} data.id The ID of this dependency.
       * @param {string} data.importerName The name of the config file which loads this dependency.
       * @param {string} data.importerPath The path to the config file which loads this dependency.
       */
      constructor({
        definition = null,
        error = null,
        filePath = null,
        id,
        importerName,
        importerPath
      }) {
        this.definition = definition;
        this.error = error;
        this.filePath = filePath;
        this.id = id;
        this.importerName = importerName;
        this.importerPath = importerPath;
      }
      // eslint-disable-next-line jsdoc/require-description
      /**
       * @returns {Object} a JSON compatible object.
       */
      toJSON() {
        const obj = this[util__default["default"].inspect.custom]();
        if (obj.error instanceof Error) {
          obj.error = { ...obj.error, message: obj.error.message };
        }
        return obj;
      }
      // eslint-disable-next-line jsdoc/require-description
      /**
       * @returns {Object} an object to display by `console.log()`.
       */
      [util__default["default"].inspect.custom]() {
        const {
          definition: _ignore,
          // eslint-disable-line no-unused-vars
          ...obj
        } = this;
        return obj;
      }
    };
    var { Minimatch } = minimatch__default["default"];
    var minimatchOpts = { dot: true, matchBase: true };
    function normalizePatterns(patterns) {
      if (Array.isArray(patterns)) {
        return patterns.filter(Boolean);
      }
      if (typeof patterns === "string" && patterns) {
        return [patterns];
      }
      return [];
    }
    function toMatcher(patterns) {
      if (patterns.length === 0) {
        return null;
      }
      return patterns.map((pattern) => {
        if (/^\.[/\\]/u.test(pattern)) {
          return new Minimatch(
            pattern.slice(2),
            // `./*.js` should not match with `subdir/foo.js`
            { ...minimatchOpts, matchBase: false }
          );
        }
        return new Minimatch(pattern, minimatchOpts);
      });
    }
    function patternToJson({ includes, excludes }) {
      return {
        includes: includes && includes.map((m) => m.pattern),
        excludes: excludes && excludes.map((m) => m.pattern)
      };
    }
    var OverrideTester = class _OverrideTester {
      /**
       * Create a tester with given criteria.
       * If there are no criteria, returns `null`.
       * @param {string|string[]} files The glob patterns for included files.
       * @param {string|string[]} excludedFiles The glob patterns for excluded files.
       * @param {string} basePath The path to the base directory to test paths.
       * @returns {OverrideTester|null} The created instance or `null`.
       */
      static create(files, excludedFiles, basePath) {
        const includePatterns = normalizePatterns(files);
        const excludePatterns = normalizePatterns(excludedFiles);
        let endsWithWildcard = false;
        if (includePatterns.length === 0) {
          return null;
        }
        for (const pattern of includePatterns) {
          if (path__default["default"].isAbsolute(pattern) || pattern.includes("..")) {
            throw new Error(`Invalid override pattern (expected relative path not containing '..'): ${pattern}`);
          }
          if (pattern.endsWith("*")) {
            endsWithWildcard = true;
          }
        }
        for (const pattern of excludePatterns) {
          if (path__default["default"].isAbsolute(pattern) || pattern.includes("..")) {
            throw new Error(`Invalid override pattern (expected relative path not containing '..'): ${pattern}`);
          }
        }
        const includes = toMatcher(includePatterns);
        const excludes = toMatcher(excludePatterns);
        return new _OverrideTester(
          [{ includes, excludes }],
          basePath,
          endsWithWildcard
        );
      }
      /**
       * Combine two testers by logical and.
       * If either of the testers was `null`, returns the other tester.
       * The `basePath` property of the two must be the same value.
       * @param {OverrideTester|null} a A tester.
       * @param {OverrideTester|null} b Another tester.
       * @returns {OverrideTester|null} Combined tester.
       */
      static and(a, b) {
        if (!b) {
          return a && new _OverrideTester(
            a.patterns,
            a.basePath,
            a.endsWithWildcard
          );
        }
        if (!a) {
          return new _OverrideTester(
            b.patterns,
            b.basePath,
            b.endsWithWildcard
          );
        }
        assert__default["default"].strictEqual(a.basePath, b.basePath);
        return new _OverrideTester(
          a.patterns.concat(b.patterns),
          a.basePath,
          a.endsWithWildcard || b.endsWithWildcard
        );
      }
      /**
       * Initialize this instance.
       * @param {Pattern[]} patterns The matchers.
       * @param {string} basePath The base path.
       * @param {boolean} endsWithWildcard If `true` then a pattern ends with `*`.
       */
      constructor(patterns, basePath, endsWithWildcard = false) {
        this.patterns = patterns;
        this.basePath = basePath;
        this.endsWithWildcard = endsWithWildcard;
      }
      /**
       * Test if a given path is matched or not.
       * @param {string} filePath The absolute path to the target file.
       * @returns {boolean} `true` if the path was matched.
       */
      test(filePath) {
        if (typeof filePath !== "string" || !path__default["default"].isAbsolute(filePath)) {
          throw new Error(`'filePath' should be an absolute path, but got ${filePath}.`);
        }
        const relativePath = path__default["default"].relative(this.basePath, filePath);
        return this.patterns.every(({ includes, excludes }) => (!includes || includes.some((m) => m.match(relativePath))) && (!excludes || !excludes.some((m) => m.match(relativePath))));
      }
      // eslint-disable-next-line jsdoc/require-description
      /**
       * @returns {Object} a JSON compatible object.
       */
      toJSON() {
        if (this.patterns.length === 1) {
          return {
            ...patternToJson(this.patterns[0]),
            basePath: this.basePath
          };
        }
        return {
          AND: this.patterns.map(patternToJson),
          basePath: this.basePath
        };
      }
      // eslint-disable-next-line jsdoc/require-description
      /**
       * @returns {Object} an object to display by `console.log()`.
       */
      [util__default["default"].inspect.custom]() {
        return this.toJSON();
      }
    };
    var RULE_SEVERITY_STRINGS = ["off", "warn", "error"];
    var RULE_SEVERITY = RULE_SEVERITY_STRINGS.reduce((map, value2, index) => {
      map[value2] = index;
      return map;
    }, {});
    var VALID_SEVERITIES = [0, 1, 2, "off", "warn", "error"];
    function getRuleSeverity(ruleConfig) {
      const severityValue = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
      if (severityValue === 0 || severityValue === 1 || severityValue === 2) {
        return severityValue;
      }
      if (typeof severityValue === "string") {
        return RULE_SEVERITY[severityValue.toLowerCase()] || 0;
      }
      return 0;
    }
    function normalizeToStrings(config) {
      if (config.rules) {
        Object.keys(config.rules).forEach((ruleId) => {
          const ruleConfig = config.rules[ruleId];
          if (typeof ruleConfig === "number") {
            config.rules[ruleId] = RULE_SEVERITY_STRINGS[ruleConfig] || RULE_SEVERITY_STRINGS[0];
          } else if (Array.isArray(ruleConfig) && typeof ruleConfig[0] === "number") {
            ruleConfig[0] = RULE_SEVERITY_STRINGS[ruleConfig[0]] || RULE_SEVERITY_STRINGS[0];
          }
        });
      }
    }
    function isErrorSeverity(ruleConfig) {
      return getRuleSeverity(ruleConfig) === 2;
    }
    function isValidSeverity(ruleConfig) {
      let severity = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
      if (typeof severity === "string") {
        severity = severity.toLowerCase();
      }
      return VALID_SEVERITIES.indexOf(severity) !== -1;
    }
    function isEverySeverityValid(config) {
      return Object.keys(config).every((ruleId) => isValidSeverity(config[ruleId]));
    }
    function normalizeConfigGlobal(configuredValue) {
      switch (configuredValue) {
        case "off":
          return "off";
        case true:
        case "true":
        case "writeable":
        case "writable":
          return "writable";
        case null:
        case false:
        case "false":
        case "readable":
        case "readonly":
          return "readonly";
        default:
          throw new Error(`'${configuredValue}' is not a valid configuration for a global (use 'readonly', 'writable', or 'off')`);
      }
    }
    var ConfigOps = {
      __proto__: null,
      getRuleSeverity,
      normalizeToStrings,
      isErrorSeverity,
      isValidSeverity,
      isEverySeverityValid,
      normalizeConfigGlobal
    };
    var deprecationWarningMessages = {
      ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect.",
      ESLINT_PERSONAL_CONFIG_LOAD: "'~/.eslintrc.*' config files have been deprecated. Please use a config file per project or the '--config' option.",
      ESLINT_PERSONAL_CONFIG_SUPPRESS: "'~/.eslintrc.*' config files have been deprecated. Please remove it or add 'root:true' to the config files in your projects in order to avoid loading '~/.eslintrc.*' accidentally."
    };
    var sourceFileErrorCache = /* @__PURE__ */ new Set();
    function emitDeprecationWarning(source, errorCode) {
      const cacheKey = JSON.stringify({ source, errorCode });
      if (sourceFileErrorCache.has(cacheKey)) {
        return;
      }
      sourceFileErrorCache.add(cacheKey);
      const rel = path__default["default"].relative(process.cwd(), source);
      const message = deprecationWarningMessages[errorCode];
      process.emitWarning(
        `${message} (found in "${rel}")`,
        "DeprecationWarning",
        errorCode
      );
    }
    var metaSchema = {
      id: "http://json-schema.org/draft-04/schema#",
      $schema: "http://json-schema.org/draft-04/schema#",
      description: "Core schema meta-schema",
      definitions: {
        schemaArray: {
          type: "array",
          minItems: 1,
          items: { $ref: "#" }
        },
        positiveInteger: {
          type: "integer",
          minimum: 0
        },
        positiveIntegerDefault0: {
          allOf: [{ $ref: "#/definitions/positiveInteger" }, { default: 0 }]
        },
        simpleTypes: {
          enum: ["array", "boolean", "integer", "null", "number", "object", "string"]
        },
        stringArray: {
          type: "array",
          items: { type: "string" },
          minItems: 1,
          uniqueItems: true
        }
      },
      type: "object",
      properties: {
        id: {
          type: "string"
        },
        $schema: {
          type: "string"
        },
        title: {
          type: "string"
        },
        description: {
          type: "string"
        },
        default: {},
        multipleOf: {
          type: "number",
          minimum: 0,
          exclusiveMinimum: true
        },
        maximum: {
          type: "number"
        },
        exclusiveMaximum: {
          type: "boolean",
          default: false
        },
        minimum: {
          type: "number"
        },
        exclusiveMinimum: {
          type: "boolean",
          default: false
        },
        maxLength: { $ref: "#/definitions/positiveInteger" },
        minLength: { $ref: "#/definitions/positiveIntegerDefault0" },
        pattern: {
          type: "string",
          format: "regex"
        },
        additionalItems: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        items: {
          anyOf: [
            { $ref: "#" },
            { $ref: "#/definitions/schemaArray" }
          ],
          default: {}
        },
        maxItems: { $ref: "#/definitions/positiveInteger" },
        minItems: { $ref: "#/definitions/positiveIntegerDefault0" },
        uniqueItems: {
          type: "boolean",
          default: false
        },
        maxProperties: { $ref: "#/definitions/positiveInteger" },
        minProperties: { $ref: "#/definitions/positiveIntegerDefault0" },
        required: { $ref: "#/definitions/stringArray" },
        additionalProperties: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        definitions: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        properties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        patternProperties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        dependencies: {
          type: "object",
          additionalProperties: {
            anyOf: [
              { $ref: "#" },
              { $ref: "#/definitions/stringArray" }
            ]
          }
        },
        enum: {
          type: "array",
          minItems: 1,
          uniqueItems: true
        },
        type: {
          anyOf: [
            { $ref: "#/definitions/simpleTypes" },
            {
              type: "array",
              items: { $ref: "#/definitions/simpleTypes" },
              minItems: 1,
              uniqueItems: true
            }
          ]
        },
        format: { type: "string" },
        allOf: { $ref: "#/definitions/schemaArray" },
        anyOf: { $ref: "#/definitions/schemaArray" },
        oneOf: { $ref: "#/definitions/schemaArray" },
        not: { $ref: "#" }
      },
      dependencies: {
        exclusiveMaximum: ["maximum"],
        exclusiveMinimum: ["minimum"]
      },
      default: {}
    };
    var ajvOrig = (additionalOptions = {}) => {
      const ajv2 = new Ajv__default["default"]({
        meta: false,
        useDefaults: true,
        validateSchema: false,
        missingRefs: "ignore",
        verbose: true,
        schemaId: "auto",
        ...additionalOptions
      });
      ajv2.addMetaSchema(metaSchema);
      ajv2._opts.defaultMeta = metaSchema.id;
      return ajv2;
    };
    var baseConfigProperties = {
      $schema: { type: "string" },
      env: { type: "object" },
      extends: { $ref: "#/definitions/stringOrStrings" },
      globals: { type: "object" },
      overrides: {
        type: "array",
        items: { $ref: "#/definitions/overrideConfig" },
        additionalItems: false
      },
      parser: { type: ["string", "null"] },
      parserOptions: { type: "object" },
      plugins: { type: "array" },
      processor: { type: "string" },
      rules: { type: "object" },
      settings: { type: "object" },
      noInlineConfig: { type: "boolean" },
      reportUnusedDisableDirectives: { type: "boolean" },
      ecmaFeatures: { type: "object" }
      // deprecated; logs a warning when used
    };
    var configSchema = {
      definitions: {
        stringOrStrings: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false
            }
          ]
        },
        stringOrStringsRequired: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false,
              minItems: 1
            }
          ]
        },
        // Config at top-level.
        objectConfig: {
          type: "object",
          properties: {
            root: { type: "boolean" },
            ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
            ...baseConfigProperties
          },
          additionalProperties: false
        },
        // Config in `overrides`.
        overrideConfig: {
          type: "object",
          properties: {
            excludedFiles: { $ref: "#/definitions/stringOrStrings" },
            files: { $ref: "#/definitions/stringOrStringsRequired" },
            ...baseConfigProperties
          },
          required: ["files"],
          additionalProperties: false
        }
      },
      $ref: "#/definitions/objectConfig"
    };
    function getDiff(current, prev) {
      const retv = {};
      for (const [key, value2] of Object.entries(current)) {
        if (!Object.hasOwnProperty.call(prev, key)) {
          retv[key] = value2;
        }
      }
      return retv;
    }
    var newGlobals2015 = getDiff(globals__default["default"].es2015, globals__default["default"].es5);
    var newGlobals2017 = {
      Atomics: false,
      SharedArrayBuffer: false
    };
    var newGlobals2020 = {
      BigInt: false,
      BigInt64Array: false,
      BigUint64Array: false,
      globalThis: false
    };
    var newGlobals2021 = {
      AggregateError: false,
      FinalizationRegistry: false,
      WeakRef: false
    };
    var environments = new Map(Object.entries({
      // Language
      builtin: {
        globals: globals__default["default"].es5
      },
      es6: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 6
        }
      },
      es2015: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 6
        }
      },
      es2016: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 7
        }
      },
      es2017: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 8
        }
      },
      es2018: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 9
        }
      },
      es2019: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 10
        }
      },
      es2020: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020 },
        parserOptions: {
          ecmaVersion: 11
        }
      },
      es2021: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
        parserOptions: {
          ecmaVersion: 12
        }
      },
      es2022: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
        parserOptions: {
          ecmaVersion: 13
        }
      },
      // Platforms
      browser: {
        globals: globals__default["default"].browser
      },
      node: {
        globals: globals__default["default"].node,
        parserOptions: {
          ecmaFeatures: {
            globalReturn: true
          }
        }
      },
      "shared-node-browser": {
        globals: globals__default["default"]["shared-node-browser"]
      },
      worker: {
        globals: globals__default["default"].worker
      },
      serviceworker: {
        globals: globals__default["default"].serviceworker
      },
      // Frameworks
      commonjs: {
        globals: globals__default["default"].commonjs,
        parserOptions: {
          ecmaFeatures: {
            globalReturn: true
          }
        }
      },
      amd: {
        globals: globals__default["default"].amd
      },
      mocha: {
        globals: globals__default["default"].mocha
      },
      jasmine: {
        globals: globals__default["default"].jasmine
      },
      jest: {
        globals: globals__default["default"].jest
      },
      phantomjs: {
        globals: globals__default["default"].phantomjs
      },
      jquery: {
        globals: globals__default["default"].jquery
      },
      qunit: {
        globals: globals__default["default"].qunit
      },
      prototypejs: {
        globals: globals__default["default"].prototypejs
      },
      shelljs: {
        globals: globals__default["default"].shelljs
      },
      meteor: {
        globals: globals__default["default"].meteor
      },
      mongo: {
        globals: globals__default["default"].mongo
      },
      protractor: {
        globals: globals__default["default"].protractor
      },
      applescript: {
        globals: globals__default["default"].applescript
      },
      nashorn: {
        globals: globals__default["default"].nashorn
      },
      atomtest: {
        globals: globals__default["default"].atomtest
      },
      embertest: {
        globals: globals__default["default"].embertest
      },
      webextensions: {
        globals: globals__default["default"].webextensions
      },
      greasemonkey: {
        globals: globals__default["default"].greasemonkey
      }
    }));
    var ajv = ajvOrig();
    var ruleValidators = /* @__PURE__ */ new WeakMap();
    var noop = Function.prototype;
    var validateSchema;
    var severityMap = {
      error: 2,
      warn: 1,
      off: 0
    };
    var validated = /* @__PURE__ */ new WeakSet();
    var ConfigValidator = class {
      constructor({ builtInRules = /* @__PURE__ */ new Map() } = {}) {
        this.builtInRules = builtInRules;
      }
      /**
       * Gets a complete options schema for a rule.
       * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
       * @returns {Object} JSON Schema for the rule's options.
       */
      getRuleOptionsSchema(rule) {
        if (!rule) {
          return null;
        }
        const schema = rule.schema || rule.meta && rule.meta.schema;
        if (Array.isArray(schema)) {
          if (schema.length) {
            return {
              type: "array",
              items: schema,
              minItems: 0,
              maxItems: schema.length
            };
          }
          return {
            type: "array",
            minItems: 0,
            maxItems: 0
          };
        }
        return schema || null;
      }
      /**
       * Validates a rule's severity and returns the severity value. Throws an error if the severity is invalid.
       * @param {options} options The given options for the rule.
       * @returns {number|string} The rule's severity value
       */
      validateRuleSeverity(options) {
        const severity = Array.isArray(options) ? options[0] : options;
        const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
        if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
          return normSeverity;
        }
        throw new Error(`	Severity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util__default["default"].inspect(severity).replace(/'/gu, '"').replace(/\n/gu, "")}').
`);
      }
      /**
       * Validates the non-severity options passed to a rule, based on its schema.
       * @param {{create: Function}} rule The rule to validate
       * @param {Array} localOptions The options for the rule, excluding severity
       * @returns {void}
       */
      validateRuleSchema(rule, localOptions) {
        if (!ruleValidators.has(rule)) {
          const schema = this.getRuleOptionsSchema(rule);
          if (schema) {
            ruleValidators.set(rule, ajv.compile(schema));
          }
        }
        const validateRule = ruleValidators.get(rule);
        if (validateRule) {
          validateRule(localOptions);
          if (validateRule.errors) {
            throw new Error(validateRule.errors.map(
              (error) => `	Value ${JSON.stringify(error.data)} ${error.message}.
`
            ).join(""));
          }
        }
      }
      /**
       * Validates a rule's options against its schema.
       * @param {{create: Function}|null} rule The rule that the config is being validated for
       * @param {string} ruleId The rule's unique name.
       * @param {Array|number} options The given options for the rule.
       * @param {string|null} source The name of the configuration source to report in any errors. If null or undefined,
       * no source is prepended to the message.
       * @returns {void}
       */
      validateRuleOptions(rule, ruleId, options, source = null) {
        try {
          const severity = this.validateRuleSeverity(options);
          if (severity !== 0) {
            this.validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
          }
        } catch (err) {
          const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:
${err.message}`;
          if (typeof source === "string") {
            throw new Error(`${source}:
	${enhancedMessage}`);
          } else {
            throw new Error(enhancedMessage);
          }
        }
      }
      /**
       * Validates an environment object
       * @param {Object} environment The environment config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded environments.
       * @returns {void}
       */
      validateEnvironment(environment, source, getAdditionalEnv = noop) {
        if (!environment) {
          return;
        }
        Object.keys(environment).forEach((id) => {
          const env = getAdditionalEnv(id) || environments.get(id) || null;
          if (!env) {
            const message = `${source}:
	Environment key "${id}" is unknown
`;
            throw new Error(message);
          }
        });
      }
      /**
       * Validates a rules config object
       * @param {Object} rulesConfig The rules config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(ruleId:string): Object} getAdditionalRule A map from strings to loaded rules
       * @returns {void}
       */
      validateRules(rulesConfig, source, getAdditionalRule = noop) {
        if (!rulesConfig) {
          return;
        }
        Object.keys(rulesConfig).forEach((id) => {
          const rule = getAdditionalRule(id) || this.builtInRules.get(id) || null;
          this.validateRuleOptions(rule, id, rulesConfig[id], source);
        });
      }
      /**
       * Validates a `globals` section of a config file
       * @param {Object} globalsConfig The `globals` section
       * @param {string|null} source The name of the configuration source to report in the event of an error.
       * @returns {void}
       */
      validateGlobals(globalsConfig, source = null) {
        if (!globalsConfig) {
          return;
        }
        Object.entries(globalsConfig).forEach(([configuredGlobal, configuredValue]) => {
          try {
            normalizeConfigGlobal(configuredValue);
          } catch (err) {
            throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:
${err.message}`);
          }
        });
      }
      /**
       * Validate `processor` configuration.
       * @param {string|undefined} processorName The processor name.
       * @param {string} source The name of config file.
       * @param {function(id:string): Processor} getProcessor The getter of defined processors.
       * @returns {void}
       */
      validateProcessor(processorName, source, getProcessor) {
        if (processorName && !getProcessor(processorName)) {
          throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
        }
      }
      /**
       * Formats an array of schema validation errors.
       * @param {Array} errors An array of error messages to format.
       * @returns {string} Formatted error message
       */
      formatErrors(errors) {
        return errors.map((error) => {
          if (error.keyword === "additionalProperties") {
            const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
            return `Unexpected top-level property "${formattedPropertyPath}"`;
          }
          if (error.keyword === "type") {
            const formattedField = error.dataPath.slice(1);
            const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
            const formattedValue = JSON.stringify(error.data);
            return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
          }
          const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
          return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
        }).map((message) => `	- ${message}.
`).join("");
      }
      /**
       * Validates the top level properties of the config object.
       * @param {Object} config The config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @returns {void}
       */
      validateConfigSchema(config, source = null) {
        validateSchema = validateSchema || ajv.compile(configSchema);
        if (!validateSchema(config)) {
          throw new Error(`ESLint configuration in ${source} is invalid:
${this.formatErrors(validateSchema.errors)}`);
        }
        if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
          emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
        }
      }
      /**
       * Validates an entire config object.
       * @param {Object} config The config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(ruleId:string): Object} [getAdditionalRule] A map from strings to loaded rules.
       * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded envs.
       * @returns {void}
       */
      validate(config, source, getAdditionalRule, getAdditionalEnv) {
        this.validateConfigSchema(config, source);
        this.validateRules(config.rules, source, getAdditionalRule);
        this.validateEnvironment(config.env, source, getAdditionalEnv);
        this.validateGlobals(config.globals, source);
        for (const override of config.overrides || []) {
          this.validateRules(override.rules, source, getAdditionalRule);
          this.validateEnvironment(override.env, source, getAdditionalEnv);
          this.validateGlobals(config.globals, source);
        }
      }
      /**
       * Validate config array object.
       * @param {ConfigArray} configArray The config array to validate.
       * @returns {void}
       */
      validateConfigArray(configArray) {
        const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
        const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
        const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
        for (const element of configArray) {
          if (validated.has(element)) {
            continue;
          }
          validated.add(element);
          this.validateEnvironment(element.env, element.name, getPluginEnv);
          this.validateGlobals(element.globals, element.name);
          this.validateProcessor(element.processor, element.name, getPluginProcessor);
          this.validateRules(element.rules, element.name, getPluginRule);
        }
      }
    };
    var NAMESPACE_REGEX = /^@.*\//iu;
    function normalizePackageName(name, prefix) {
      let normalizedName = name;
      if (normalizedName.includes("\\")) {
        normalizedName = normalizedName.replace(/\\/gu, "/");
      }
      if (normalizedName.charAt(0) === "@") {
        const scopedPackageShortcutRegex = new RegExp(`^(@[^/]+)(?:/(?:${prefix})?)?$`, "u"), scopedPackageNameRegex = new RegExp(`^${prefix}(-|$)`, "u");
        if (scopedPackageShortcutRegex.test(normalizedName)) {
          normalizedName = normalizedName.replace(scopedPackageShortcutRegex, `$1/${prefix}`);
        } else if (!scopedPackageNameRegex.test(normalizedName.split("/")[1])) {
          normalizedName = normalizedName.replace(/^@([^/]+)\/(.*)$/u, `@$1/${prefix}-$2`);
        }
      } else if (!normalizedName.startsWith(`${prefix}-`)) {
        normalizedName = `${prefix}-${normalizedName}`;
      }
      return normalizedName;
    }
    function getShorthandName(fullname, prefix) {
      if (fullname[0] === "@") {
        let matchResult = new RegExp(`^(@[^/]+)/${prefix}$`, "u").exec(fullname);
        if (matchResult) {
          return matchResult[1];
        }
        matchResult = new RegExp(`^(@[^/]+)/${prefix}-(.+)$`, "u").exec(fullname);
        if (matchResult) {
          return `${matchResult[1]}/${matchResult[2]}`;
        }
      } else if (fullname.startsWith(`${prefix}-`)) {
        return fullname.slice(prefix.length + 1);
      }
      return fullname;
    }
    function getNamespaceFromTerm(term) {
      const match = term.match(NAMESPACE_REGEX);
      return match ? match[0] : "";
    }
    var naming = {
      __proto__: null,
      normalizePackageName,
      getShorthandName,
      getNamespaceFromTerm
    };
    var createRequire = Module__default["default"].createRequire;
    function resolve(moduleName, relativeToPath) {
      try {
        return createRequire(relativeToPath).resolve(moduleName);
      } catch (error) {
        if (typeof error === "object" && error !== null && error.code === "MODULE_NOT_FOUND" && !error.requireStack && error.message.includes(moduleName)) {
          error.message += `
Require stack:
- ${relativeToPath}`;
        }
        throw error;
      }
    }
    var ModuleResolver = {
      __proto__: null,
      resolve
    };
    var require$1 = Module.createRequire(require("url").pathToFileURL(__filename).toString());
    var debug$2 = debugOrig__default["default"]("eslintrc:config-array-factory");
    var configFilenames = [
      ".eslintrc.js",
      ".eslintrc.cjs",
      ".eslintrc.yaml",
      ".eslintrc.yml",
      ".eslintrc.json",
      ".eslintrc",
      "package.json"
    ];
    var internalSlotsMap$1 = /* @__PURE__ */ new WeakMap();
    var normalizedPlugins = /* @__PURE__ */ new WeakMap();
    function isFilePath(nameOrPath) {
      return /^\.{1,2}[/\\]/u.test(nameOrPath) || path__default["default"].isAbsolute(nameOrPath);
    }
    function readFile(filePath) {
      return fs__default["default"].readFileSync(filePath, "utf8").replace(/^\ufeff/u, "");
    }
    function loadYAMLConfigFile(filePath) {
      debug$2(`Loading YAML config file: ${filePath}`);
      const yaml = require$1("js-yaml");
      try {
        return yaml.load(readFile(filePath)) || {};
      } catch (e) {
        debug$2(`Error reading YAML file: ${filePath}`);
        e.message = `Cannot read config file: ${filePath}
Error: ${e.message}`;
        throw e;
      }
    }
    function loadJSONConfigFile(filePath) {
      debug$2(`Loading JSON config file: ${filePath}`);
      try {
        return JSON.parse(stripComments__default["default"](readFile(filePath)));
      } catch (e) {
        debug$2(`Error reading JSON file: ${filePath}`);
        e.message = `Cannot read config file: ${filePath}
Error: ${e.message}`;
        e.messageTemplate = "failed-to-read-json";
        e.messageData = {
          path: filePath,
          message: e.message
        };
        throw e;
      }
    }
    function loadLegacyConfigFile(filePath) {
      debug$2(`Loading legacy config file: ${filePath}`);
      const yaml = require$1("js-yaml");
      try {
        return yaml.load(stripComments__default["default"](readFile(filePath))) || /* istanbul ignore next */
        {};
      } catch (e) {
        debug$2("Error reading YAML file: %s\n%o", filePath, e);
        e.message = `Cannot read config file: ${filePath}
Error: ${e.message}`;
        throw e;
      }
    }
    function loadJSConfigFile(filePath) {
      debug$2(`Loading JS config file: ${filePath}`);
      try {
        return importFresh__default["default"](filePath);
      } catch (e) {
        debug$2(`Error reading JavaScript file: ${filePath}`);
        e.message = `Cannot read config file: ${filePath}
Error: ${e.message}`;
        throw e;
      }
    }
    function loadPackageJSONConfigFile(filePath) {
      debug$2(`Loading package.json config file: ${filePath}`);
      try {
        const packageData = loadJSONConfigFile(filePath);
        if (!Object.hasOwnProperty.call(packageData, "eslintConfig")) {
          throw Object.assign(
            new Error("package.json file doesn't have 'eslintConfig' field."),
            { code: "ESLINT_CONFIG_FIELD_NOT_FOUND" }
          );
        }
        return packageData.eslintConfig;
      } catch (e) {
        debug$2(`Error reading package.json file: ${filePath}`);
        e.message = `Cannot read config file: ${filePath}
Error: ${e.message}`;
        throw e;
      }
    }
    function loadESLintIgnoreFile(filePath) {
      debug$2(`Loading .eslintignore file: ${filePath}`);
      try {
        return readFile(filePath).split(/\r?\n/gu).filter((line) => line.trim() !== "" && !line.startsWith("#"));
      } catch (e) {
        debug$2(`Error reading .eslintignore file: ${filePath}`);
        e.message = `Cannot read .eslintignore file: ${filePath}
Error: ${e.message}`;
        throw e;
      }
    }
    function configInvalidError(configName, importerName, messageTemplate) {
      return Object.assign(
        new Error(`Failed to load config "${configName}" to extend from.`),
        {
          messageTemplate,
          messageData: { configName, importerName }
        }
      );
    }
    function loadConfigFile(filePath) {
      switch (path__default["default"].extname(filePath)) {
        case ".js":
        case ".cjs":
          return loadJSConfigFile(filePath);
        case ".json":
          if (path__default["default"].basename(filePath) === "package.json") {
            return loadPackageJSONConfigFile(filePath);
          }
          return loadJSONConfigFile(filePath);
        case ".yaml":
        case ".yml":
          return loadYAMLConfigFile(filePath);
        default:
          return loadLegacyConfigFile(filePath);
      }
    }
    function writeDebugLogForLoading(request, relativeTo, filePath) {
      if (debug$2.enabled) {
        let nameAndVersion = null;
        try {
          const packageJsonPath = resolve(
            `${request}/package.json`,
            relativeTo
          );
          const { version: version2 = "unknown" } = require$1(packageJsonPath);
          nameAndVersion = `${request}@${version2}`;
        } catch (error) {
          debug$2("package.json was not found:", error.message);
          nameAndVersion = request;
        }
        debug$2("Loaded: %s (%s)", nameAndVersion, filePath);
      }
    }
    function createContext({ cwd, resolvePluginsRelativeTo }, providedType, providedName, providedFilePath, providedMatchBasePath) {
      const filePath = providedFilePath ? path__default["default"].resolve(cwd, providedFilePath) : "";
      const matchBasePath = providedMatchBasePath && path__default["default"].resolve(cwd, providedMatchBasePath) || filePath && path__default["default"].dirname(filePath) || cwd;
      const name = providedName || filePath && path__default["default"].relative(cwd, filePath) || "";
      const pluginBasePath = resolvePluginsRelativeTo || filePath && path__default["default"].dirname(filePath) || cwd;
      const type = providedType || "config";
      return { filePath, matchBasePath, name, pluginBasePath, type };
    }
    function normalizePlugin(plugin) {
      let normalizedPlugin = normalizedPlugins.get(plugin);
      if (normalizedPlugin) {
        return normalizedPlugin;
      }
      normalizedPlugin = {
        configs: plugin.configs || {},
        environments: plugin.environments || {},
        processors: plugin.processors || {},
        rules: plugin.rules || {}
      };
      normalizedPlugins.set(plugin, normalizedPlugin);
      return normalizedPlugin;
    }
    var ConfigArrayFactory = class {
      /**
       * Initialize this instance.
       * @param {ConfigArrayFactoryOptions} [options] The map for additional plugins.
       */
      constructor({
        additionalPluginPool = /* @__PURE__ */ new Map(),
        cwd = process.cwd(),
        resolvePluginsRelativeTo,
        builtInRules,
        resolver = ModuleResolver,
        eslintAllPath,
        getEslintAllConfig,
        eslintRecommendedPath,
        getEslintRecommendedConfig
      } = {}) {
        internalSlotsMap$1.set(this, {
          additionalPluginPool,
          cwd,
          resolvePluginsRelativeTo: resolvePluginsRelativeTo && path__default["default"].resolve(cwd, resolvePluginsRelativeTo),
          builtInRules,
          resolver,
          eslintAllPath,
          getEslintAllConfig,
          eslintRecommendedPath,
          getEslintRecommendedConfig
        });
      }
      /**
       * Create `ConfigArray` instance from a config data.
       * @param {ConfigData|null} configData The config data to create.
       * @param {Object} [options] The options.
       * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
       * @param {string} [options.filePath] The path to this config data.
       * @param {string} [options.name] The config name.
       * @returns {ConfigArray} Loaded config.
       */
      create(configData, { basePath, filePath, name } = {}) {
        if (!configData) {
          return new ConfigArray();
        }
        const slots = internalSlotsMap$1.get(this);
        const ctx = createContext(slots, "config", name, filePath, basePath);
        const elements = this._normalizeConfigData(configData, ctx);
        return new ConfigArray(...elements);
      }
      /**
       * Load a config file.
       * @param {string} filePath The path to a config file.
       * @param {Object} [options] The options.
       * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
       * @param {string} [options.name] The config name.
       * @returns {ConfigArray} Loaded config.
       */
      loadFile(filePath, { basePath, name } = {}) {
        const slots = internalSlotsMap$1.get(this);
        const ctx = createContext(slots, "config", name, filePath, basePath);
        return new ConfigArray(...this._loadConfigData(ctx));
      }
      /**
       * Load the config file on a given directory if exists.
       * @param {string} directoryPath The path to a directory.
       * @param {Object} [options] The options.
       * @param {string} [options.basePath] The base path to resolve relative paths in `overrides[].files`, `overrides[].excludedFiles`, and `ignorePatterns`.
       * @param {string} [options.name] The config name.
       * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
       */
      loadInDirectory(directoryPath, { basePath, name } = {}) {
        const slots = internalSlotsMap$1.get(this);
        for (const filename of configFilenames) {
          const ctx = createContext(
            slots,
            "config",
            name,
            path__default["default"].join(directoryPath, filename),
            basePath
          );
          if (fs__default["default"].existsSync(ctx.filePath) && fs__default["default"].statSync(ctx.filePath).isFile()) {
            let configData;
            try {
              configData = loadConfigFile(ctx.filePath);
            } catch (error) {
              if (!error || error.code !== "ESLINT_CONFIG_FIELD_NOT_FOUND") {
                throw error;
              }
            }
            if (configData) {
              debug$2(`Config file found: ${ctx.filePath}`);
              return new ConfigArray(
                ...this._normalizeConfigData(configData, ctx)
              );
            }
          }
        }
        debug$2(`Config file not found on ${directoryPath}`);
        return new ConfigArray();
      }
      /**
       * Check if a config file on a given directory exists or not.
       * @param {string} directoryPath The path to a directory.
       * @returns {string | null} The path to the found config file. If not found then null.
       */
      static getPathToConfigFileInDirectory(directoryPath) {
        for (const filename of configFilenames) {
          const filePath = path__default["default"].join(directoryPath, filename);
          if (fs__default["default"].existsSync(filePath)) {
            if (filename === "package.json") {
              try {
                loadPackageJSONConfigFile(filePath);
                return filePath;
              } catch {
              }
            } else {
              return filePath;
            }
          }
        }
        return null;
      }
      /**
       * Load `.eslintignore` file.
       * @param {string} filePath The path to a `.eslintignore` file to load.
       * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
       */
      loadESLintIgnore(filePath) {
        const slots = internalSlotsMap$1.get(this);
        const ctx = createContext(
          slots,
          "ignore",
          void 0,
          filePath,
          slots.cwd
        );
        const ignorePatterns = loadESLintIgnoreFile(ctx.filePath);
        return new ConfigArray(
          ...this._normalizeESLintIgnoreData(ignorePatterns, ctx)
        );
      }
      /**
       * Load `.eslintignore` file in the current working directory.
       * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
       */
      loadDefaultESLintIgnore() {
        const slots = internalSlotsMap$1.get(this);
        const eslintIgnorePath = path__default["default"].resolve(slots.cwd, ".eslintignore");
        const packageJsonPath = path__default["default"].resolve(slots.cwd, "package.json");
        if (fs__default["default"].existsSync(eslintIgnorePath)) {
          return this.loadESLintIgnore(eslintIgnorePath);
        }
        if (fs__default["default"].existsSync(packageJsonPath)) {
          const data = loadJSONConfigFile(packageJsonPath);
          if (Object.hasOwnProperty.call(data, "eslintIgnore")) {
            if (!Array.isArray(data.eslintIgnore)) {
              throw new Error("Package.json eslintIgnore property requires an array of paths");
            }
            const ctx = createContext(
              slots,
              "ignore",
              "eslintIgnore in package.json",
              packageJsonPath,
              slots.cwd
            );
            return new ConfigArray(
              ...this._normalizeESLintIgnoreData(data.eslintIgnore, ctx)
            );
          }
        }
        return new ConfigArray();
      }
      /**
       * Load a given config file.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} Loaded config.
       * @private
       */
      _loadConfigData(ctx) {
        return this._normalizeConfigData(loadConfigFile(ctx.filePath), ctx);
      }
      /**
       * Normalize a given `.eslintignore` data to config array elements.
       * @param {string[]} ignorePatterns The patterns to ignore files.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      *_normalizeESLintIgnoreData(ignorePatterns, ctx) {
        const elements = this._normalizeObjectConfigData(
          { ignorePatterns },
          ctx
        );
        for (const element of elements) {
          if (element.ignorePattern) {
            element.ignorePattern.loose = true;
          }
          yield element;
        }
      }
      /**
       * Normalize a given config to an array.
       * @param {ConfigData} configData The config data to normalize.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      _normalizeConfigData(configData, ctx) {
        const validator = new ConfigValidator();
        validator.validateConfigSchema(configData, ctx.name || ctx.filePath);
        return this._normalizeObjectConfigData(configData, ctx);
      }
      /**
       * Normalize a given config to an array.
       * @param {ConfigData|OverrideConfigData} configData The config data to normalize.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      *_normalizeObjectConfigData(configData, ctx) {
        const { files, excludedFiles, ...configBody } = configData;
        const criteria = OverrideTester.create(
          files,
          excludedFiles,
          ctx.matchBasePath
        );
        const elements = this._normalizeObjectConfigDataBody(configBody, ctx);
        for (const element of elements) {
          element.criteria = OverrideTester.and(criteria, element.criteria);
          if (element.criteria) {
            element.root = void 0;
          }
          yield element;
        }
      }
      /**
       * Normalize a given config to an array.
       * @param {ConfigData} configData The config data to normalize.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      *_normalizeObjectConfigDataBody({
        env,
        extends: extend,
        globals: globals2,
        ignorePatterns,
        noInlineConfig,
        parser: parserName,
        parserOptions,
        plugins: pluginList,
        processor,
        reportUnusedDisableDirectives,
        root: root2,
        rules,
        settings,
        overrides: overrideList = []
      }, ctx) {
        const extendList = Array.isArray(extend) ? extend : [extend];
        const ignorePattern = ignorePatterns && new IgnorePattern(
          Array.isArray(ignorePatterns) ? ignorePatterns : [ignorePatterns],
          ctx.matchBasePath
        );
        for (const extendName of extendList.filter(Boolean)) {
          yield* this._loadExtends(extendName, ctx);
        }
        const parser = parserName && this._loadParser(parserName, ctx);
        const plugins = pluginList && this._loadPlugins(pluginList, ctx);
        if (plugins) {
          yield* this._takeFileExtensionProcessors(plugins, ctx);
        }
        yield {
          // Debug information.
          type: ctx.type,
          name: ctx.name,
          filePath: ctx.filePath,
          // Config data.
          criteria: null,
          env,
          globals: globals2,
          ignorePattern,
          noInlineConfig,
          parser,
          parserOptions,
          plugins,
          processor,
          reportUnusedDisableDirectives,
          root: root2,
          rules,
          settings
        };
        for (let i = 0; i < overrideList.length; ++i) {
          yield* this._normalizeObjectConfigData(
            overrideList[i],
            { ...ctx, name: `${ctx.name}#overrides[${i}]` }
          );
        }
      }
      /**
       * Load configs of an element in `extends`.
       * @param {string} extendName The name of a base config.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      _loadExtends(extendName, ctx) {
        debug$2("Loading {extends:%j} relative to %s", extendName, ctx.filePath);
        try {
          if (extendName.startsWith("eslint:")) {
            return this._loadExtendedBuiltInConfig(extendName, ctx);
          }
          if (extendName.startsWith("plugin:")) {
            return this._loadExtendedPluginConfig(extendName, ctx);
          }
          return this._loadExtendedShareableConfig(extendName, ctx);
        } catch (error) {
          error.message += `
Referenced from: ${ctx.filePath || ctx.name}`;
          throw error;
        }
      }
      /**
       * Load configs of an element in `extends`.
       * @param {string} extendName The name of a base config.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      _loadExtendedBuiltInConfig(extendName, ctx) {
        const {
          eslintAllPath,
          getEslintAllConfig,
          eslintRecommendedPath,
          getEslintRecommendedConfig
        } = internalSlotsMap$1.get(this);
        if (extendName === "eslint:recommended") {
          const name = `${ctx.name} \xBB ${extendName}`;
          if (getEslintRecommendedConfig) {
            if (typeof getEslintRecommendedConfig !== "function") {
              throw new Error(`getEslintRecommendedConfig must be a function instead of '${getEslintRecommendedConfig}'`);
            }
            return this._normalizeConfigData(getEslintRecommendedConfig(), { ...ctx, name, filePath: "" });
          }
          return this._loadConfigData({
            ...ctx,
            name,
            filePath: eslintRecommendedPath
          });
        }
        if (extendName === "eslint:all") {
          const name = `${ctx.name} \xBB ${extendName}`;
          if (getEslintAllConfig) {
            if (typeof getEslintAllConfig !== "function") {
              throw new Error(`getEslintAllConfig must be a function instead of '${getEslintAllConfig}'`);
            }
            return this._normalizeConfigData(getEslintAllConfig(), { ...ctx, name, filePath: "" });
          }
          return this._loadConfigData({
            ...ctx,
            name,
            filePath: eslintAllPath
          });
        }
        throw configInvalidError(extendName, ctx.name, "extend-config-missing");
      }
      /**
       * Load configs of an element in `extends`.
       * @param {string} extendName The name of a base config.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      _loadExtendedPluginConfig(extendName, ctx) {
        const slashIndex = extendName.lastIndexOf("/");
        if (slashIndex === -1) {
          throw configInvalidError(extendName, ctx.filePath, "plugin-invalid");
        }
        const pluginName = extendName.slice("plugin:".length, slashIndex);
        const configName = extendName.slice(slashIndex + 1);
        if (isFilePath(pluginName)) {
          throw new Error("'extends' cannot use a file path for plugins.");
        }
        const plugin = this._loadPlugin(pluginName, ctx);
        const configData = plugin.definition && plugin.definition.configs[configName];
        if (configData) {
          return this._normalizeConfigData(configData, {
            ...ctx,
            filePath: plugin.filePath || ctx.filePath,
            name: `${ctx.name} \xBB plugin:${plugin.id}/${configName}`
          });
        }
        throw plugin.error || configInvalidError(extendName, ctx.filePath, "extend-config-missing");
      }
      /**
       * Load configs of an element in `extends`.
       * @param {string} extendName The name of a base config.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
       * @private
       */
      _loadExtendedShareableConfig(extendName, ctx) {
        const { cwd, resolver } = internalSlotsMap$1.get(this);
        const relativeTo = ctx.filePath || path__default["default"].join(cwd, "__placeholder__.js");
        let request;
        if (isFilePath(extendName)) {
          request = extendName;
        } else if (extendName.startsWith(".")) {
          request = `./${extendName}`;
        } else {
          request = normalizePackageName(
            extendName,
            "eslint-config"
          );
        }
        let filePath;
        try {
          filePath = resolver.resolve(request, relativeTo);
        } catch (error) {
          if (error && error.code === "MODULE_NOT_FOUND") {
            throw configInvalidError(extendName, ctx.filePath, "extend-config-missing");
          }
          throw error;
        }
        writeDebugLogForLoading(request, relativeTo, filePath);
        return this._loadConfigData({
          ...ctx,
          filePath,
          name: `${ctx.name} \xBB ${request}`
        });
      }
      /**
       * Load given plugins.
       * @param {string[]} names The plugin names to load.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {Record<string,DependentPlugin>} The loaded parser.
       * @private
       */
      _loadPlugins(names, ctx) {
        return names.reduce((map, name) => {
          if (isFilePath(name)) {
            throw new Error("Plugins array cannot includes file paths.");
          }
          const plugin = this._loadPlugin(name, ctx);
          map[plugin.id] = plugin;
          return map;
        }, {});
      }
      /**
       * Load a given parser.
       * @param {string} nameOrPath The package name or the path to a parser file.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {DependentParser} The loaded parser.
       */
      _loadParser(nameOrPath, ctx) {
        debug$2("Loading parser %j from %s", nameOrPath, ctx.filePath);
        const { cwd, resolver } = internalSlotsMap$1.get(this);
        const relativeTo = ctx.filePath || path__default["default"].join(cwd, "__placeholder__.js");
        try {
          const filePath = resolver.resolve(nameOrPath, relativeTo);
          writeDebugLogForLoading(nameOrPath, relativeTo, filePath);
          return new ConfigDependency({
            definition: require$1(filePath),
            filePath,
            id: nameOrPath,
            importerName: ctx.name,
            importerPath: ctx.filePath
          });
        } catch (error) {
          if (nameOrPath === "espree") {
            debug$2("Fallback espree.");
            return new ConfigDependency({
              definition: require$1("espree"),
              filePath: require$1.resolve("espree"),
              id: nameOrPath,
              importerName: ctx.name,
              importerPath: ctx.filePath
            });
          }
          debug$2("Failed to load parser '%s' declared in '%s'.", nameOrPath, ctx.name);
          error.message = `Failed to load parser '${nameOrPath}' declared in '${ctx.name}': ${error.message}`;
          return new ConfigDependency({
            error,
            id: nameOrPath,
            importerName: ctx.name,
            importerPath: ctx.filePath
          });
        }
      }
      /**
       * Load a given plugin.
       * @param {string} name The plugin name to load.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {DependentPlugin} The loaded plugin.
       * @private
       */
      _loadPlugin(name, ctx) {
        debug$2("Loading plugin %j from %s", name, ctx.filePath);
        const { additionalPluginPool, resolver } = internalSlotsMap$1.get(this);
        const request = normalizePackageName(name, "eslint-plugin");
        const id = getShorthandName(request, "eslint-plugin");
        const relativeTo = path__default["default"].join(ctx.pluginBasePath, "__placeholder__.js");
        if (name.match(/\s+/u)) {
          const error2 = Object.assign(
            new Error(`Whitespace found in plugin name '${name}'`),
            {
              messageTemplate: "whitespace-found",
              messageData: { pluginName: request }
            }
          );
          return new ConfigDependency({
            error: error2,
            id,
            importerName: ctx.name,
            importerPath: ctx.filePath
          });
        }
        const plugin = additionalPluginPool.get(request) || additionalPluginPool.get(id);
        if (plugin) {
          return new ConfigDependency({
            definition: normalizePlugin(plugin),
            filePath: "",
            // It's unknown where the plugin came from.
            id,
            importerName: ctx.name,
            importerPath: ctx.filePath
          });
        }
        let filePath;
        let error;
        try {
          filePath = resolver.resolve(request, relativeTo);
        } catch (resolveError) {
          error = resolveError;
          if (error && error.code === "MODULE_NOT_FOUND") {
            error.messageTemplate = "plugin-missing";
            error.messageData = {
              pluginName: request,
              resolvePluginsRelativeTo: ctx.pluginBasePath,
              importerName: ctx.name
            };
          }
        }
        if (filePath) {
          try {
            writeDebugLogForLoading(request, relativeTo, filePath);
            const startTime = Date.now();
            const pluginDefinition = require$1(filePath);
            debug$2(`Plugin ${filePath} loaded in: ${Date.now() - startTime}ms`);
            return new ConfigDependency({
              definition: normalizePlugin(pluginDefinition),
              filePath,
              id,
              importerName: ctx.name,
              importerPath: ctx.filePath
            });
          } catch (loadError) {
            error = loadError;
          }
        }
        debug$2("Failed to load plugin '%s' declared in '%s'.", name, ctx.name);
        error.message = `Failed to load plugin '${name}' declared in '${ctx.name}': ${error.message}`;
        return new ConfigDependency({
          error,
          id,
          importerName: ctx.name,
          importerPath: ctx.filePath
        });
      }
      /**
       * Take file expression processors as config array elements.
       * @param {Record<string,DependentPlugin>} plugins The plugin definitions.
       * @param {ConfigArrayFactoryLoadingContext} ctx The loading context.
       * @returns {IterableIterator<ConfigArrayElement>} The config array elements of file expression processors.
       * @private
       */
      *_takeFileExtensionProcessors(plugins, ctx) {
        for (const pluginId of Object.keys(plugins)) {
          const processors = plugins[pluginId] && plugins[pluginId].definition && plugins[pluginId].definition.processors;
          if (!processors) {
            continue;
          }
          for (const processorId of Object.keys(processors)) {
            if (processorId.startsWith(".")) {
              yield* this._normalizeObjectConfigData(
                {
                  files: [`*${processorId}`],
                  processor: `${pluginId}/${processorId}`
                },
                {
                  ...ctx,
                  type: "implicit-processor",
                  name: `${ctx.name}#processors["${pluginId}/${processorId}"]`
                }
              );
            }
          }
        }
      }
    };
    var debug$1 = debugOrig__default["default"]("eslintrc:cascading-config-array-factory");
    var internalSlotsMap = /* @__PURE__ */ new WeakMap();
    function createBaseConfigArray({
      configArrayFactory,
      baseConfigData,
      rulePaths,
      cwd,
      loadRules
    }) {
      const baseConfigArray = configArrayFactory.create(
        baseConfigData,
        { name: "BaseConfig" }
      );
      baseConfigArray.unshift(configArrayFactory.create(
        { ignorePatterns: IgnorePattern.DefaultPatterns },
        { name: "DefaultIgnorePattern" }
      )[0]);
      if (rulePaths && rulePaths.length > 0) {
        baseConfigArray.push({
          type: "config",
          name: "--rulesdir",
          filePath: "",
          plugins: {
            "": new ConfigDependency({
              definition: {
                rules: rulePaths.reduce(
                  (map, rulesPath) => Object.assign(
                    map,
                    loadRules(rulesPath, cwd)
                  ),
                  {}
                )
              },
              filePath: "",
              id: "",
              importerName: "--rulesdir",
              importerPath: ""
            })
          }
        });
      }
      return baseConfigArray;
    }
    function createCLIConfigArray({
      cliConfigData,
      configArrayFactory,
      cwd,
      ignorePath,
      specificConfigPath
    }) {
      const cliConfigArray = configArrayFactory.create(
        cliConfigData,
        { name: "CLIOptions" }
      );
      cliConfigArray.unshift(
        ...ignorePath ? configArrayFactory.loadESLintIgnore(ignorePath) : configArrayFactory.loadDefaultESLintIgnore()
      );
      if (specificConfigPath) {
        cliConfigArray.unshift(
          ...configArrayFactory.loadFile(
            specificConfigPath,
            { name: "--config", basePath: cwd }
          )
        );
      }
      return cliConfigArray;
    }
    var ConfigurationNotFoundError = class extends Error {
      // eslint-disable-next-line jsdoc/require-description
      /**
       * @param {string} directoryPath The directory path.
       */
      constructor(directoryPath) {
        super(`No ESLint configuration found in ${directoryPath}.`);
        this.messageTemplate = "no-config-found";
        this.messageData = { directoryPath };
      }
    };
    var CascadingConfigArrayFactory = class {
      /**
       * Initialize this enumerator.
       * @param {CascadingConfigArrayFactoryOptions} options The options.
       */
      constructor({
        additionalPluginPool = /* @__PURE__ */ new Map(),
        baseConfig: baseConfigData = null,
        cliConfig: cliConfigData = null,
        cwd = process.cwd(),
        ignorePath,
        resolvePluginsRelativeTo,
        rulePaths = [],
        specificConfigPath = null,
        useEslintrc = true,
        builtInRules = /* @__PURE__ */ new Map(),
        loadRules,
        resolver,
        eslintRecommendedPath,
        getEslintRecommendedConfig,
        eslintAllPath,
        getEslintAllConfig
      } = {}) {
        const configArrayFactory = new ConfigArrayFactory({
          additionalPluginPool,
          cwd,
          resolvePluginsRelativeTo,
          builtInRules,
          resolver,
          eslintRecommendedPath,
          getEslintRecommendedConfig,
          eslintAllPath,
          getEslintAllConfig
        });
        internalSlotsMap.set(this, {
          baseConfigArray: createBaseConfigArray({
            baseConfigData,
            configArrayFactory,
            cwd,
            rulePaths,
            loadRules
          }),
          baseConfigData,
          cliConfigArray: createCLIConfigArray({
            cliConfigData,
            configArrayFactory,
            cwd,
            ignorePath,
            specificConfigPath
          }),
          cliConfigData,
          configArrayFactory,
          configCache: /* @__PURE__ */ new Map(),
          cwd,
          finalizeCache: /* @__PURE__ */ new WeakMap(),
          ignorePath,
          rulePaths,
          specificConfigPath,
          useEslintrc,
          builtInRules,
          loadRules
        });
      }
      /**
       * The path to the current working directory.
       * This is used by tests.
       * @type {string}
       */
      get cwd() {
        const { cwd } = internalSlotsMap.get(this);
        return cwd;
      }
      /**
       * Get the config array of a given file.
       * If `filePath` was not given, it returns the config which contains only
       * `baseConfigData` and `cliConfigData`.
       * @param {string} [filePath] The file path to a file.
       * @param {Object} [options] The options.
       * @param {boolean} [options.ignoreNotFoundError] If `true` then it doesn't throw `ConfigurationNotFoundError`.
       * @returns {ConfigArray} The config array of the file.
       */
      getConfigArrayForFile(filePath, { ignoreNotFoundError = false } = {}) {
        const {
          baseConfigArray,
          cliConfigArray,
          cwd
        } = internalSlotsMap.get(this);
        if (!filePath) {
          return new ConfigArray(...baseConfigArray, ...cliConfigArray);
        }
        const directoryPath = path__default["default"].dirname(path__default["default"].resolve(cwd, filePath));
        debug$1(`Load config files for ${directoryPath}.`);
        return this._finalizeConfigArray(
          this._loadConfigInAncestors(directoryPath),
          directoryPath,
          ignoreNotFoundError
        );
      }
      /**
       * Set the config data to override all configs.
       * Require to call `clearCache()` method after this method is called.
       * @param {ConfigData} configData The config data to override all configs.
       * @returns {void}
       */
      setOverrideConfig(configData) {
        const slots = internalSlotsMap.get(this);
        slots.cliConfigData = configData;
      }
      /**
       * Clear config cache.
       * @returns {void}
       */
      clearCache() {
        const slots = internalSlotsMap.get(this);
        slots.baseConfigArray = createBaseConfigArray(slots);
        slots.cliConfigArray = createCLIConfigArray(slots);
        slots.configCache.clear();
      }
      /**
       * Load and normalize config files from the ancestor directories.
       * @param {string} directoryPath The path to a leaf directory.
       * @param {boolean} configsExistInSubdirs `true` if configurations exist in subdirectories.
       * @returns {ConfigArray} The loaded config.
       * @private
       */
      _loadConfigInAncestors(directoryPath, configsExistInSubdirs = false) {
        const {
          baseConfigArray,
          configArrayFactory,
          configCache,
          cwd,
          useEslintrc
        } = internalSlotsMap.get(this);
        if (!useEslintrc) {
          return baseConfigArray;
        }
        let configArray = configCache.get(directoryPath);
        if (configArray) {
          debug$1(`Cache hit: ${directoryPath}.`);
          return configArray;
        }
        debug$1(`No cache found: ${directoryPath}.`);
        const homePath = os__default["default"].homedir();
        if (directoryPath === homePath && cwd !== homePath) {
          debug$1("Stop traversing because of considered root.");
          if (configsExistInSubdirs) {
            const filePath = ConfigArrayFactory.getPathToConfigFileInDirectory(directoryPath);
            if (filePath) {
              emitDeprecationWarning(
                filePath,
                "ESLINT_PERSONAL_CONFIG_SUPPRESS"
              );
            }
          }
          return this._cacheConfig(directoryPath, baseConfigArray);
        }
        try {
          configArray = configArrayFactory.loadInDirectory(directoryPath);
        } catch (error) {
          if (error.code === "EACCES") {
            debug$1("Stop traversing because of 'EACCES' error.");
            return this._cacheConfig(directoryPath, baseConfigArray);
          }
          throw error;
        }
        if (configArray.length > 0 && configArray.isRoot()) {
          debug$1("Stop traversing because of 'root:true'.");
          configArray.unshift(...baseConfigArray);
          return this._cacheConfig(directoryPath, configArray);
        }
        const parentPath = path__default["default"].dirname(directoryPath);
        const parentConfigArray = parentPath && parentPath !== directoryPath ? this._loadConfigInAncestors(
          parentPath,
          configsExistInSubdirs || configArray.length > 0
        ) : baseConfigArray;
        if (configArray.length > 0) {
          configArray.unshift(...parentConfigArray);
        } else {
          configArray = parentConfigArray;
        }
        return this._cacheConfig(directoryPath, configArray);
      }
      /**
       * Freeze and cache a given config.
       * @param {string} directoryPath The path to a directory as a cache key.
       * @param {ConfigArray} configArray The config array as a cache value.
       * @returns {ConfigArray} The `configArray` (frozen).
       */
      _cacheConfig(directoryPath, configArray) {
        const { configCache } = internalSlotsMap.get(this);
        Object.freeze(configArray);
        configCache.set(directoryPath, configArray);
        return configArray;
      }
      /**
       * Finalize a given config array.
       * Concatenate `--config` and other CLI options.
       * @param {ConfigArray} configArray The parent config array.
       * @param {string} directoryPath The path to the leaf directory to find config files.
       * @param {boolean} ignoreNotFoundError If `true` then it doesn't throw `ConfigurationNotFoundError`.
       * @returns {ConfigArray} The loaded config.
       * @private
       */
      _finalizeConfigArray(configArray, directoryPath, ignoreNotFoundError) {
        const {
          cliConfigArray,
          configArrayFactory,
          finalizeCache,
          useEslintrc,
          builtInRules
        } = internalSlotsMap.get(this);
        let finalConfigArray = finalizeCache.get(configArray);
        if (!finalConfigArray) {
          finalConfigArray = configArray;
          if (useEslintrc && configArray.every((c) => !c.filePath) && cliConfigArray.every((c) => !c.filePath)) {
            const homePath = os__default["default"].homedir();
            debug$1("Loading the config file of the home directory:", homePath);
            const personalConfigArray = configArrayFactory.loadInDirectory(
              homePath,
              { name: "PersonalConfig" }
            );
            if (personalConfigArray.length > 0 && !directoryPath.startsWith(homePath)) {
              const lastElement = personalConfigArray[personalConfigArray.length - 1];
              emitDeprecationWarning(
                lastElement.filePath,
                "ESLINT_PERSONAL_CONFIG_LOAD"
              );
            }
            finalConfigArray = finalConfigArray.concat(personalConfigArray);
          }
          if (cliConfigArray.length > 0) {
            finalConfigArray = finalConfigArray.concat(cliConfigArray);
          }
          const validator = new ConfigValidator({
            builtInRules
          });
          validator.validateConfigArray(finalConfigArray);
          Object.freeze(finalConfigArray);
          finalizeCache.set(configArray, finalConfigArray);
          debug$1(
            "Configuration was determined: %o on %s",
            finalConfigArray,
            directoryPath
          );
        }
        if (!ignoreNotFoundError && useEslintrc && finalConfigArray.length <= 1) {
          throw new ConfigurationNotFoundError(directoryPath);
        }
        return finalConfigArray;
      }
    };
    var debug = debugOrig__default["default"]("eslintrc:flat-compat");
    var cafactory = Symbol("cafactory");
    function translateESLintRC(eslintrcConfig, {
      resolveConfigRelativeTo,
      resolvePluginsRelativeTo,
      pluginEnvironments,
      pluginProcessors
    }) {
      const flatConfig = {};
      const configs = [];
      const languageOptions = {};
      const linterOptions = {};
      const keysToCopy = ["settings", "rules", "processor"];
      const languageOptionsKeysToCopy = ["globals", "parser", "parserOptions"];
      const linterOptionsKeysToCopy = ["noInlineConfig", "reportUnusedDisableDirectives"];
      if (eslintrcConfig.settings) {
        if (eslintrcConfig.settings["eslint:all"] === true) {
          return ["eslint:all"];
        }
        if (eslintrcConfig.settings["eslint:recommended"] === true) {
          return ["eslint:recommended"];
        }
      }
      for (const key of keysToCopy) {
        if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
          flatConfig[key] = eslintrcConfig[key];
        }
      }
      for (const key of languageOptionsKeysToCopy) {
        if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
          flatConfig.languageOptions = languageOptions;
          if (key === "parser") {
            debug(`Resolving parser '${languageOptions[key]}' relative to ${resolveConfigRelativeTo}`);
            if (eslintrcConfig[key].error) {
              throw eslintrcConfig[key].error;
            }
            languageOptions[key] = eslintrcConfig[key].definition;
            continue;
          }
          if (eslintrcConfig[key] && typeof eslintrcConfig[key] === "object") {
            languageOptions[key] = {
              ...eslintrcConfig[key]
            };
          } else {
            languageOptions[key] = eslintrcConfig[key];
          }
        }
      }
      for (const key of linterOptionsKeysToCopy) {
        if (key in eslintrcConfig && typeof eslintrcConfig[key] !== "undefined") {
          flatConfig.linterOptions = linterOptions;
          linterOptions[key] = eslintrcConfig[key];
        }
      }
      if (languageOptions.parserOptions) {
        if ("ecmaVersion" in languageOptions.parserOptions) {
          languageOptions.ecmaVersion = languageOptions.parserOptions.ecmaVersion;
          delete languageOptions.parserOptions.ecmaVersion;
        }
        if ("sourceType" in languageOptions.parserOptions) {
          languageOptions.sourceType = languageOptions.parserOptions.sourceType;
          delete languageOptions.parserOptions.sourceType;
        }
        if (Object.keys(languageOptions.parserOptions).length === 0) {
          delete languageOptions.parserOptions;
        }
      }
      if (eslintrcConfig.criteria) {
        flatConfig.files = [(absoluteFilePath) => eslintrcConfig.criteria.test(absoluteFilePath)];
      }
      if (eslintrcConfig.plugins && typeof eslintrcConfig.plugins === "object") {
        debug(`Translating plugins: ${eslintrcConfig.plugins}`);
        flatConfig.plugins = {};
        for (const pluginName of Object.keys(eslintrcConfig.plugins)) {
          debug(`Translating plugin: ${pluginName}`);
          debug(`Resolving plugin '${pluginName} relative to ${resolvePluginsRelativeTo}`);
          const { definition: plugin, error } = eslintrcConfig.plugins[pluginName];
          if (error) {
            throw error;
          }
          flatConfig.plugins[pluginName] = plugin;
          if (plugin.processors) {
            for (const processorName of Object.keys(plugin.processors)) {
              if (processorName.startsWith(".")) {
                debug(`Assigning processor: ${pluginName}/${processorName}`);
                configs.unshift({
                  files: [`**/*${processorName}`],
                  processor: pluginProcessors.get(`${pluginName}/${processorName}`)
                });
              }
            }
          }
        }
      }
      if (eslintrcConfig.env && typeof eslintrcConfig.env === "object") {
        for (const envName of Object.keys(eslintrcConfig.env)) {
          if (eslintrcConfig.env[envName]) {
            debug(`Translating environment: ${envName}`);
            if (environments.has(envName)) {
              configs.unshift(...translateESLintRC(environments.get(envName), {
                resolveConfigRelativeTo,
                resolvePluginsRelativeTo
              }));
            } else if (pluginEnvironments.has(envName)) {
              configs.push(...translateESLintRC(pluginEnvironments.get(envName), {
                resolveConfigRelativeTo,
                resolvePluginsRelativeTo
              }));
            }
          }
        }
      }
      if (Object.keys(flatConfig).length > 0) {
        configs.push(flatConfig);
      }
      return configs;
    }
    var FlatCompat = class {
      constructor({
        baseDirectory = process.cwd(),
        resolvePluginsRelativeTo = baseDirectory
      } = {}) {
        this.baseDirectory = baseDirectory;
        this.resolvePluginsRelativeTo = resolvePluginsRelativeTo;
        this[cafactory] = new ConfigArrayFactory({
          cwd: baseDirectory,
          resolvePluginsRelativeTo,
          getEslintAllConfig: () => ({ settings: { "eslint:all": true } }),
          getEslintRecommendedConfig: () => ({ settings: { "eslint:recommended": true } })
        });
      }
      /**
       * Translates an ESLintRC-style config into a flag-config-style config.
       * @param {Object} eslintrcConfig The ESLintRC-style config object.
       * @returns {Object} A flag-config-style config object.
       */
      config(eslintrcConfig) {
        const eslintrcArray = this[cafactory].create(eslintrcConfig, {
          basePath: this.baseDirectory
        });
        const flatArray = [];
        let hasIgnorePatterns = false;
        eslintrcArray.forEach((configData) => {
          if (configData.type === "config") {
            hasIgnorePatterns = hasIgnorePatterns || configData.ignorePattern;
            flatArray.push(...translateESLintRC(configData, {
              resolveConfigRelativeTo: path__default["default"].join(this.baseDirectory, "__placeholder.js"),
              resolvePluginsRelativeTo: path__default["default"].join(this.resolvePluginsRelativeTo, "__placeholder.js"),
              pluginEnvironments: eslintrcArray.pluginEnvironments,
              pluginProcessors: eslintrcArray.pluginProcessors
            }));
          }
        });
        if (hasIgnorePatterns) {
          flatArray.unshift({
            ignores: [(filePath) => {
              const finalConfig = eslintrcArray.extractConfig(filePath);
              return Boolean(finalConfig.ignores) && finalConfig.ignores(filePath);
            }]
          });
        }
        return flatArray;
      }
      /**
       * Translates the `env` section of an ESLintRC-style config.
       * @param {Object} envConfig The `env` section of an ESLintRC config.
       * @returns {Object[]} An array of flag-config objects representing the environments.
       */
      env(envConfig) {
        return this.config({
          env: envConfig
        });
      }
      /**
       * Translates the `extends` section of an ESLintRC-style config.
       * @param {...string} configsToExtend The names of the configs to load.
       * @returns {Object[]} An array of flag-config objects representing the config.
       */
      extends(...configsToExtend) {
        return this.config({
          extends: configsToExtend
        });
      }
      /**
       * Translates the `plugins` section of an ESLintRC-style config.
       * @param {...string} plugins The names of the plugins to load.
       * @returns {Object[]} An array of flag-config objects representing the plugins.
       */
      plugins(...plugins) {
        return this.config({
          plugins
        });
      }
    };
    var Legacy = {
      ConfigArray,
      createConfigArrayFactoryContext: createContext,
      CascadingConfigArrayFactory,
      ConfigArrayFactory,
      ConfigDependency,
      ExtractedConfig,
      IgnorePattern,
      OverrideTester,
      getUsedExtractedConfigs,
      environments,
      // shared
      ConfigOps,
      ConfigValidator,
      ModuleResolver,
      naming
    };
    exports.FlatCompat = FlatCompat;
    exports.Legacy = Legacy;
  }
});

// node_modules/is-extglob/index.js
var require_is_extglob = __commonJS({
  "node_modules/is-extglob/index.js"(exports, module2) {
    module2.exports = function isExtglob(str) {
      if (typeof str !== "string" || str === "") {
        return false;
      }
      var match;
      while (match = /(\\).|([@?!+*]\(.*\))/g.exec(str)) {
        if (match[2])
          return true;
        str = str.slice(match.index + match[0].length);
      }
      return false;
    };
  }
});

// node_modules/is-glob/index.js
var require_is_glob = __commonJS({
  "node_modules/is-glob/index.js"(exports, module2) {
    var isExtglob = require_is_extglob();
    var chars = { "{": "}", "(": ")", "[": "]" };
    var strictCheck = function(str) {
      if (str[0] === "!") {
        return true;
      }
      var index = 0;
      var pipeIndex = -2;
      var closeSquareIndex = -2;
      var closeCurlyIndex = -2;
      var closeParenIndex = -2;
      var backSlashIndex = -2;
      while (index < str.length) {
        if (str[index] === "*") {
          return true;
        }
        if (str[index + 1] === "?" && /[\].+)]/.test(str[index])) {
          return true;
        }
        if (closeSquareIndex !== -1 && str[index] === "[" && str[index + 1] !== "]") {
          if (closeSquareIndex < index) {
            closeSquareIndex = str.indexOf("]", index);
          }
          if (closeSquareIndex > index) {
            if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
              return true;
            }
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
              return true;
            }
          }
        }
        if (closeCurlyIndex !== -1 && str[index] === "{" && str[index + 1] !== "}") {
          closeCurlyIndex = str.indexOf("}", index);
          if (closeCurlyIndex > index) {
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeCurlyIndex) {
              return true;
            }
          }
        }
        if (closeParenIndex !== -1 && str[index] === "(" && str[index + 1] === "?" && /[:!=]/.test(str[index + 2]) && str[index + 3] !== ")") {
          closeParenIndex = str.indexOf(")", index);
          if (closeParenIndex > index) {
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
              return true;
            }
          }
        }
        if (pipeIndex !== -1 && str[index] === "(" && str[index + 1] !== "|") {
          if (pipeIndex < index) {
            pipeIndex = str.indexOf("|", index);
          }
          if (pipeIndex !== -1 && str[pipeIndex + 1] !== ")") {
            closeParenIndex = str.indexOf(")", pipeIndex);
            if (closeParenIndex > pipeIndex) {
              backSlashIndex = str.indexOf("\\", pipeIndex);
              if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                return true;
              }
            }
          }
        }
        if (str[index] === "\\") {
          var open = str[index + 1];
          index += 2;
          var close = chars[open];
          if (close) {
            var n = str.indexOf(close, index);
            if (n !== -1) {
              index = n + 1;
            }
          }
          if (str[index] === "!") {
            return true;
          }
        } else {
          index++;
        }
      }
      return false;
    };
    var relaxedCheck = function(str) {
      if (str[0] === "!") {
        return true;
      }
      var index = 0;
      while (index < str.length) {
        if (/[*?{}()[\]]/.test(str[index])) {
          return true;
        }
        if (str[index] === "\\") {
          var open = str[index + 1];
          index += 2;
          var close = chars[open];
          if (close) {
            var n = str.indexOf(close, index);
            if (n !== -1) {
              index = n + 1;
            }
          }
          if (str[index] === "!") {
            return true;
          }
        } else {
          index++;
        }
      }
      return false;
    };
    module2.exports = function isGlob(str, options) {
      if (typeof str !== "string" || str === "") {
        return false;
      }
      if (isExtglob(str)) {
        return true;
      }
      var check = strictCheck;
      if (options && options.strict === false) {
        check = relaxedCheck;
      }
      return check(str);
    };
  }
});

// node_modules/glob-parent/index.js
var require_glob_parent = __commonJS({
  "node_modules/glob-parent/index.js"(exports, module2) {
    "use strict";
    var isGlob = require_is_glob();
    var pathPosixDirname = require("path").posix.dirname;
    var isWin32 = require("os").platform() === "win32";
    var slash = "/";
    var backslash = /\\/g;
    var escaped = /\\([!*?|[\](){}])/g;
    module2.exports = function globParent(str, opts) {
      var options = Object.assign({ flipBackslashes: true }, opts);
      if (options.flipBackslashes && isWin32 && str.indexOf(slash) < 0) {
        str = str.replace(backslash, slash);
      }
      if (isEnclosure(str)) {
        str += slash;
      }
      str += "a";
      do {
        str = pathPosixDirname(str);
      } while (isGlobby(str));
      return str.replace(escaped, "$1");
    };
    function isEnclosure(str) {
      var lastChar = str.slice(-1);
      var enclosureStart;
      switch (lastChar) {
        case "}":
          enclosureStart = "{";
          break;
        case "]":
          enclosureStart = "[";
          break;
        default:
          return false;
      }
      var foundIndex = str.indexOf(enclosureStart);
      if (foundIndex < 0) {
        return false;
      }
      return str.slice(foundIndex + 1, -1).includes(slash);
    }
    function isGlobby(str) {
      if (/\([^()]+$/.test(str)) {
        return true;
      }
      if (str[0] === "{" || str[0] === "[") {
        return true;
      }
      if (/[^\\][{[]/.test(str)) {
        return true;
      }
      return isGlob(str);
    }
  }
});

// node_modules/eslint/node_modules/escape-string-regexp/index.js
var require_escape_string_regexp2 = __commonJS({
  "node_modules/eslint/node_modules/escape-string-regexp/index.js"(exports, module2) {
    "use strict";
    module2.exports = (string) => {
      if (typeof string !== "string") {
        throw new TypeError("Expected a string");
      }
      return string.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
    };
  }
});

// node_modules/eslint/conf/eslint-recommended.js
var require_eslint_recommended = __commonJS({
  "node_modules/eslint/conf/eslint-recommended.js"(exports, module2) {
    "use strict";
    module2.exports = {
      rules: {
        "constructor-super": "error",
        "for-direction": "error",
        "getter-return": "error",
        "no-async-promise-executor": "error",
        "no-case-declarations": "error",
        "no-class-assign": "error",
        "no-compare-neg-zero": "error",
        "no-cond-assign": "error",
        "no-const-assign": "error",
        "no-constant-condition": "error",
        "no-control-regex": "error",
        "no-debugger": "error",
        "no-delete-var": "error",
        "no-dupe-args": "error",
        "no-dupe-class-members": "error",
        "no-dupe-else-if": "error",
        "no-dupe-keys": "error",
        "no-duplicate-case": "error",
        "no-empty": "error",
        "no-empty-character-class": "error",
        "no-empty-pattern": "error",
        "no-ex-assign": "error",
        "no-extra-boolean-cast": "error",
        "no-extra-semi": "error",
        "no-fallthrough": "error",
        "no-func-assign": "error",
        "no-global-assign": "error",
        "no-import-assign": "error",
        "no-inner-declarations": "error",
        "no-invalid-regexp": "error",
        "no-irregular-whitespace": "error",
        "no-loss-of-precision": "error",
        "no-misleading-character-class": "error",
        "no-mixed-spaces-and-tabs": "error",
        "no-new-symbol": "error",
        "no-nonoctal-decimal-escape": "error",
        "no-obj-calls": "error",
        "no-octal": "error",
        "no-prototype-builtins": "error",
        "no-redeclare": "error",
        "no-regex-spaces": "error",
        "no-self-assign": "error",
        "no-setter-return": "error",
        "no-shadow-restricted-names": "error",
        "no-sparse-arrays": "error",
        "no-this-before-super": "error",
        "no-undef": "error",
        "no-unexpected-multiline": "error",
        "no-unreachable": "error",
        "no-unsafe-finally": "error",
        "no-unsafe-negation": "error",
        "no-unsafe-optional-chaining": "error",
        "no-unused-labels": "error",
        "no-unused-vars": "error",
        "no-useless-backreference": "error",
        "no-useless-catch": "error",
        "no-useless-escape": "error",
        "no-with": "error",
        "require-yield": "error",
        "use-isnan": "error",
        "valid-typeof": "error"
      }
    };
  }
});

// node_modules/eslint/lib/rules/utils/lazy-loading-rule-map.js
var require_lazy_loading_rule_map = __commonJS({
  "node_modules/eslint/lib/rules/utils/lazy-loading-rule-map.js"(exports, module2) {
    "use strict";
    var debug = require_src()("eslint:rules");
    var LazyLoadingRuleMap = class _LazyLoadingRuleMap extends Map {
      /**
       * Initialize this map.
       * @param {Array<[string, function(): Rule]>} loaders The rule loaders.
       */
      constructor(loaders) {
        let remaining = loaders.length;
        super(
          debug.enabled ? loaders.map(([ruleId, load]) => {
            let cache = null;
            return [
              ruleId,
              () => {
                if (!cache) {
                  debug("Loading rule %o (remaining=%d)", ruleId, --remaining);
                  cache = load();
                }
                return cache;
              }
            ];
          }) : loaders
        );
        Object.defineProperty(_LazyLoadingRuleMap.prototype, "set", {
          configurable: true,
          value: void 0
        });
      }
      /**
       * Get a rule.
       * Each rule will be loaded on the first access.
       * @param {string} ruleId The rule ID to get.
       * @returns {Rule|undefined} The rule.
       */
      get(ruleId) {
        const load = super.get(ruleId);
        return load && load();
      }
      /**
       * Iterate rules.
       * @returns {IterableIterator<Rule>} Rules.
       */
      *values() {
        for (const load of super.values()) {
          yield load();
        }
      }
      /**
       * Iterate rules.
       * @returns {IterableIterator<[string, Rule]>} Rules.
       */
      *entries() {
        for (const [ruleId, load] of super.entries()) {
          yield [ruleId, load()];
        }
      }
      /**
       * Call a function with each rule.
       * @param {Function} callbackFn The callback function.
       * @param {any} [thisArg] The object to pass to `this` of the callback function.
       * @returns {void}
       */
      forEach(callbackFn, thisArg) {
        for (const [ruleId, load] of super.entries()) {
          callbackFn.call(thisArg, load(), ruleId, this);
        }
      }
    };
    Object.defineProperties(LazyLoadingRuleMap.prototype, {
      clear: { configurable: true, value: void 0 },
      delete: { configurable: true, value: void 0 },
      [Symbol.iterator]: {
        configurable: true,
        writable: true,
        value: LazyLoadingRuleMap.prototype.entries
      }
    });
    module2.exports = { LazyLoadingRuleMap };
  }
});

// node_modules/esutils/lib/ast.js
var require_ast = __commonJS({
  "node_modules/esutils/lib/ast.js"(exports, module2) {
    (function() {
      "use strict";
      function isExpression2(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "ArrayExpression":
          case "AssignmentExpression":
          case "BinaryExpression":
          case "CallExpression":
          case "ConditionalExpression":
          case "FunctionExpression":
          case "Identifier":
          case "Literal":
          case "LogicalExpression":
          case "MemberExpression":
          case "NewExpression":
          case "ObjectExpression":
          case "SequenceExpression":
          case "ThisExpression":
          case "UnaryExpression":
          case "UpdateExpression":
            return true;
        }
        return false;
      }
      function isIterationStatement(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "DoWhileStatement":
          case "ForInStatement":
          case "ForStatement":
          case "WhileStatement":
            return true;
        }
        return false;
      }
      function isStatement(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "BlockStatement":
          case "BreakStatement":
          case "ContinueStatement":
          case "DebuggerStatement":
          case "DoWhileStatement":
          case "EmptyStatement":
          case "ExpressionStatement":
          case "ForInStatement":
          case "ForStatement":
          case "IfStatement":
          case "LabeledStatement":
          case "ReturnStatement":
          case "SwitchStatement":
          case "ThrowStatement":
          case "TryStatement":
          case "VariableDeclaration":
          case "WhileStatement":
          case "WithStatement":
            return true;
        }
        return false;
      }
      function isSourceElement(node) {
        return isStatement(node) || node != null && node.type === "FunctionDeclaration";
      }
      function trailingStatement(node) {
        switch (node.type) {
          case "IfStatement":
            if (node.alternate != null) {
              return node.alternate;
            }
            return node.consequent;
          case "LabeledStatement":
          case "ForStatement":
          case "ForInStatement":
          case "WhileStatement":
          case "WithStatement":
            return node.body;
        }
        return null;
      }
      function isProblematicIfStatement(node) {
        var current;
        if (node.type !== "IfStatement") {
          return false;
        }
        if (node.alternate == null) {
          return false;
        }
        current = node.consequent;
        do {
          if (current.type === "IfStatement") {
            if (current.alternate == null) {
              return true;
            }
          }
          current = trailingStatement(current);
        } while (current);
        return false;
      }
      module2.exports = {
        isExpression: isExpression2,
        isStatement,
        isIterationStatement,
        isSourceElement,
        isProblematicIfStatement,
        trailingStatement
      };
    })();
  }
});

// node_modules/esutils/lib/code.js
var require_code = __commonJS({
  "node_modules/esutils/lib/code.js"(exports, module2) {
    (function() {
      "use strict";
      var ES6Regex, ES5Regex, NON_ASCII_WHITESPACES, IDENTIFIER_START, IDENTIFIER_PART, ch;
      ES5Regex = {
        // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/,
        // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/
      };
      ES6Regex = {
        // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
        // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
      };
      function isDecimalDigit(ch2) {
        return 48 <= ch2 && ch2 <= 57;
      }
      function isHexDigit(ch2) {
        return 48 <= ch2 && ch2 <= 57 || // 0..9
        97 <= ch2 && ch2 <= 102 || // a..f
        65 <= ch2 && ch2 <= 70;
      }
      function isOctalDigit(ch2) {
        return ch2 >= 48 && ch2 <= 55;
      }
      NON_ASCII_WHITESPACES = [
        5760,
        8192,
        8193,
        8194,
        8195,
        8196,
        8197,
        8198,
        8199,
        8200,
        8201,
        8202,
        8239,
        8287,
        12288,
        65279
      ];
      function isWhiteSpace(ch2) {
        return ch2 === 32 || ch2 === 9 || ch2 === 11 || ch2 === 12 || ch2 === 160 || ch2 >= 5760 && NON_ASCII_WHITESPACES.indexOf(ch2) >= 0;
      }
      function isLineTerminator(ch2) {
        return ch2 === 10 || ch2 === 13 || ch2 === 8232 || ch2 === 8233;
      }
      function fromCodePoint(cp) {
        if (cp <= 65535) {
          return String.fromCharCode(cp);
        }
        var cu1 = String.fromCharCode(Math.floor((cp - 65536) / 1024) + 55296);
        var cu2 = String.fromCharCode((cp - 65536) % 1024 + 56320);
        return cu1 + cu2;
      }
      IDENTIFIER_START = new Array(128);
      for (ch = 0; ch < 128; ++ch) {
        IDENTIFIER_START[ch] = ch >= 97 && ch <= 122 || // a..z
        ch >= 65 && ch <= 90 || // A..Z
        ch === 36 || ch === 95;
      }
      IDENTIFIER_PART = new Array(128);
      for (ch = 0; ch < 128; ++ch) {
        IDENTIFIER_PART[ch] = ch >= 97 && ch <= 122 || // a..z
        ch >= 65 && ch <= 90 || // A..Z
        ch >= 48 && ch <= 57 || // 0..9
        ch === 36 || ch === 95;
      }
      function isIdentifierStartES5(ch2) {
        return ch2 < 128 ? IDENTIFIER_START[ch2] : ES5Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
      }
      function isIdentifierPartES5(ch2) {
        return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES5Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
      }
      function isIdentifierStartES6(ch2) {
        return ch2 < 128 ? IDENTIFIER_START[ch2] : ES6Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
      }
      function isIdentifierPartES6(ch2) {
        return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES6Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
      }
      module2.exports = {
        isDecimalDigit,
        isHexDigit,
        isOctalDigit,
        isWhiteSpace,
        isLineTerminator,
        isIdentifierStartES5,
        isIdentifierPartES5,
        isIdentifierStartES6,
        isIdentifierPartES6
      };
    })();
  }
});

// node_modules/esutils/lib/keyword.js
var require_keyword2 = __commonJS({
  "node_modules/esutils/lib/keyword.js"(exports, module2) {
    (function() {
      "use strict";
      var code = require_code();
      function isStrictModeReservedWordES6(id) {
        switch (id) {
          case "implements":
          case "interface":
          case "package":
          case "private":
          case "protected":
          case "public":
          case "static":
          case "let":
            return true;
          default:
            return false;
        }
      }
      function isKeywordES5(id, strict) {
        if (!strict && id === "yield") {
          return false;
        }
        return isKeywordES6(id, strict);
      }
      function isKeywordES6(id, strict) {
        if (strict && isStrictModeReservedWordES6(id)) {
          return true;
        }
        switch (id.length) {
          case 2:
            return id === "if" || id === "in" || id === "do";
          case 3:
            return id === "var" || id === "for" || id === "new" || id === "try";
          case 4:
            return id === "this" || id === "else" || id === "case" || id === "void" || id === "with" || id === "enum";
          case 5:
            return id === "while" || id === "break" || id === "catch" || id === "throw" || id === "const" || id === "yield" || id === "class" || id === "super";
          case 6:
            return id === "return" || id === "typeof" || id === "delete" || id === "switch" || id === "export" || id === "import";
          case 7:
            return id === "default" || id === "finally" || id === "extends";
          case 8:
            return id === "function" || id === "continue" || id === "debugger";
          case 10:
            return id === "instanceof";
          default:
            return false;
        }
      }
      function isReservedWordES5(id, strict) {
        return id === "null" || id === "true" || id === "false" || isKeywordES5(id, strict);
      }
      function isReservedWordES6(id, strict) {
        return id === "null" || id === "true" || id === "false" || isKeywordES6(id, strict);
      }
      function isRestrictedWord(id) {
        return id === "eval" || id === "arguments";
      }
      function isIdentifierNameES5(id) {
        var i, iz, ch;
        if (id.length === 0) {
          return false;
        }
        ch = id.charCodeAt(0);
        if (!code.isIdentifierStartES5(ch)) {
          return false;
        }
        for (i = 1, iz = id.length; i < iz; ++i) {
          ch = id.charCodeAt(i);
          if (!code.isIdentifierPartES5(ch)) {
            return false;
          }
        }
        return true;
      }
      function decodeUtf16(lead, trail) {
        return (lead - 55296) * 1024 + (trail - 56320) + 65536;
      }
      function isIdentifierNameES6(id) {
        var i, iz, ch, lowCh, check;
        if (id.length === 0) {
          return false;
        }
        check = code.isIdentifierStartES6;
        for (i = 0, iz = id.length; i < iz; ++i) {
          ch = id.charCodeAt(i);
          if (55296 <= ch && ch <= 56319) {
            ++i;
            if (i >= iz) {
              return false;
            }
            lowCh = id.charCodeAt(i);
            if (!(56320 <= lowCh && lowCh <= 57343)) {
              return false;
            }
            ch = decodeUtf16(ch, lowCh);
          }
          if (!check(ch)) {
            return false;
          }
          check = code.isIdentifierPartES6;
        }
        return true;
      }
      function isIdentifierES5(id, strict) {
        return isIdentifierNameES5(id) && !isReservedWordES5(id, strict);
      }
      function isIdentifierES6(id, strict) {
        return isIdentifierNameES6(id) && !isReservedWordES6(id, strict);
      }
      module2.exports = {
        isKeywordES5,
        isKeywordES6,
        isReservedWordES5,
        isReservedWordES6,
        isRestrictedWord,
        isIdentifierNameES5,
        isIdentifierNameES6,
        isIdentifierES5,
        isIdentifierES6
      };
    })();
  }
});

// node_modules/esutils/lib/utils.js
var require_utils2 = __commonJS({
  "node_modules/esutils/lib/utils.js"(exports) {
    (function() {
      "use strict";
      exports.ast = require_ast();
      exports.code = require_code();
      exports.keyword = require_keyword2();
    })();
  }
});

// node_modules/eslint/lib/shared/ast-utils.js
var require_ast_utils = __commonJS({
  "node_modules/eslint/lib/shared/ast-utils.js"(exports, module2) {
    "use strict";
    var breakableTypePattern = /^(?:(?:Do)?While|For(?:In|Of)?|Switch)Statement$/u;
    var lineBreakPattern = /\r\n|[\r\n\u2028\u2029]/u;
    var shebangPattern = /^#!([^\r\n]+)/u;
    function createGlobalLinebreakMatcher() {
      return new RegExp(lineBreakPattern.source, "gu");
    }
    module2.exports = {
      breakableTypePattern,
      lineBreakPattern,
      createGlobalLinebreakMatcher,
      shebangPattern
    };
  }
});

// node_modules/eslint/lib/rules/utils/ast-utils.js
var require_ast_utils2 = __commonJS({
  "node_modules/eslint/lib/rules/utils/ast-utils.js"(exports, module2) {
    "use strict";
    var esutils = require_utils2();
    var espree = require("espree");
    var escapeRegExp = require_escape_string_regexp2();
    var {
      breakableTypePattern,
      createGlobalLinebreakMatcher,
      lineBreakPattern,
      shebangPattern
    } = require_ast_utils();
    var anyFunctionPattern = /^(?:Function(?:Declaration|Expression)|ArrowFunctionExpression)$/u;
    var anyLoopPattern = /^(?:DoWhile|For|ForIn|ForOf|While)Statement$/u;
    var arrayOrTypedArrayPattern = /Array$/u;
    var arrayMethodPattern = /^(?:every|filter|find|findIndex|forEach|map|some)$/u;
    var bindOrCallOrApplyPattern = /^(?:bind|call|apply)$/u;
    var thisTagPattern = /^[\s*]*@this/mu;
    var COMMENTS_IGNORE_PATTERN = /^\s*(?:eslint|jshint\s+|jslint\s+|istanbul\s+|globals?\s+|exported\s+|jscs)/u;
    var ESLINT_DIRECTIVE_PATTERN = /^(?:eslint[- ]|(?:globals?|exported) )/u;
    var LINEBREAKS = /* @__PURE__ */ new Set(["\r\n", "\r", "\n", "\u2028", "\u2029"]);
    var STATEMENT_LIST_PARENTS = /* @__PURE__ */ new Set(["Program", "BlockStatement", "StaticBlock", "SwitchCase"]);
    var DECIMAL_INTEGER_PATTERN = /^(?:0|0[0-7]*[89]\d*|[1-9](?:_?\d)*)$/u;
    var OCTAL_OR_NON_OCTAL_DECIMAL_ESCAPE_PATTERN = /^(?:[^\\]|\\.)*\\(?:[1-9]|0[0-9])/su;
    var LOGICAL_ASSIGNMENT_OPERATORS = /* @__PURE__ */ new Set(["&&=", "||=", "??="]);
    function isModifyingReference(reference, index, references) {
      const identifier3 = reference.identifier;
      const modifyingDifferentIdentifier = index === 0 || references[index - 1].identifier !== identifier3;
      return identifier3 && reference.init === false && reference.isWrite() && modifyingDifferentIdentifier;
    }
    function startsWithUpperCase(s) {
      return s[0] !== s[0].toLocaleLowerCase();
    }
    function isES5Constructor(node) {
      return node.id && startsWithUpperCase(node.id.name);
    }
    function getUpperFunction(node) {
      for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
        if (anyFunctionPattern.test(currentNode.type)) {
          return currentNode;
        }
      }
      return null;
    }
    function isFunction(node) {
      return Boolean(node && anyFunctionPattern.test(node.type));
    }
    function isLoop(node) {
      return Boolean(node && anyLoopPattern.test(node.type));
    }
    function isInLoop(node) {
      for (let currentNode = node; currentNode && !isFunction(currentNode); currentNode = currentNode.parent) {
        if (isLoop(currentNode)) {
          return true;
        }
      }
      return false;
    }
    function isNullLiteral(node) {
      return node.type === "Literal" && node.value === null && !node.regex && !node.bigint;
    }
    function isNullOrUndefined(node) {
      return isNullLiteral(node) || node.type === "Identifier" && node.name === "undefined" || node.type === "UnaryExpression" && node.operator === "void";
    }
    function isCallee(node) {
      return node.parent.type === "CallExpression" && node.parent.callee === node;
    }
    function getStaticStringValue(node) {
      switch (node.type) {
        case "Literal":
          if (node.value === null) {
            if (isNullLiteral(node)) {
              return String(node.value);
            }
            if (node.regex) {
              return `/${node.regex.pattern}/${node.regex.flags}`;
            }
            if (node.bigint) {
              return node.bigint;
            }
          } else {
            return String(node.value);
          }
          break;
        case "TemplateLiteral":
          if (node.expressions.length === 0 && node.quasis.length === 1) {
            return node.quasis[0].value.cooked;
          }
          break;
      }
      return null;
    }
    function getStaticPropertyName(node) {
      let prop;
      switch (node && node.type) {
        case "ChainExpression":
          return getStaticPropertyName(node.expression);
        case "Property":
        case "PropertyDefinition":
        case "MethodDefinition":
          prop = node.key;
          break;
        case "MemberExpression":
          prop = node.property;
          break;
      }
      if (prop) {
        if (prop.type === "Identifier" && !node.computed) {
          return prop.name;
        }
        return getStaticStringValue(prop);
      }
      return null;
    }
    function skipChainExpression(node) {
      return node && node.type === "ChainExpression" ? node.expression : node;
    }
    function checkText(actual, expected) {
      return typeof expected === "string" ? actual === expected : expected.test(actual);
    }
    function isSpecificId(node, name) {
      return node.type === "Identifier" && checkText(node.name, name);
    }
    function isSpecificMemberAccess(node, objectName, propertyName) {
      const checkNode = skipChainExpression(node);
      if (checkNode.type !== "MemberExpression") {
        return false;
      }
      if (objectName && !isSpecificId(checkNode.object, objectName)) {
        return false;
      }
      if (propertyName) {
        const actualPropertyName = getStaticPropertyName(checkNode);
        if (typeof actualPropertyName !== "string" || !checkText(actualPropertyName, propertyName)) {
          return false;
        }
      }
      return true;
    }
    function equalLiteralValue(left, right) {
      if (left.regex || right.regex) {
        return Boolean(
          left.regex && right.regex && left.regex.pattern === right.regex.pattern && left.regex.flags === right.regex.flags
        );
      }
      if (left.bigint || right.bigint) {
        return left.bigint === right.bigint;
      }
      return left.value === right.value;
    }
    function isSameReference(left, right, disableStaticComputedKey = false) {
      if (left.type !== right.type) {
        if (left.type === "ChainExpression") {
          return isSameReference(left.expression, right, disableStaticComputedKey);
        }
        if (right.type === "ChainExpression") {
          return isSameReference(left, right.expression, disableStaticComputedKey);
        }
        return false;
      }
      switch (left.type) {
        case "Super":
        case "ThisExpression":
          return true;
        case "Identifier":
        case "PrivateIdentifier":
          return left.name === right.name;
        case "Literal":
          return equalLiteralValue(left, right);
        case "ChainExpression":
          return isSameReference(left.expression, right.expression, disableStaticComputedKey);
        case "MemberExpression": {
          if (!disableStaticComputedKey) {
            const nameA = getStaticPropertyName(left);
            if (nameA !== null) {
              return isSameReference(left.object, right.object, disableStaticComputedKey) && nameA === getStaticPropertyName(right);
            }
          }
          return left.computed === right.computed && isSameReference(left.object, right.object, disableStaticComputedKey) && isSameReference(left.property, right.property, disableStaticComputedKey);
        }
        default:
          return false;
      }
    }
    function isReflectApply(node) {
      return isSpecificMemberAccess(node, "Reflect", "apply");
    }
    function isArrayFromMethod(node) {
      return isSpecificMemberAccess(node, arrayOrTypedArrayPattern, "from");
    }
    function isMethodWhichHasThisArg(node) {
      return isSpecificMemberAccess(node, null, arrayMethodPattern);
    }
    function negate(f) {
      return (token) => !f(token);
    }
    function hasJSDocThisTag(node, sourceCode) {
      const jsdocComment = sourceCode.getJSDocComment(node);
      if (jsdocComment && thisTagPattern.test(jsdocComment.value)) {
        return true;
      }
      return sourceCode.getCommentsBefore(node).some((comment) => thisTagPattern.test(comment.value));
    }
    function isParenthesised(sourceCode, node) {
      const previousToken = sourceCode.getTokenBefore(node), nextToken = sourceCode.getTokenAfter(node);
      return Boolean(previousToken && nextToken) && previousToken.value === "(" && previousToken.range[1] <= node.range[0] && nextToken.value === ")" && nextToken.range[0] >= node.range[1];
    }
    function isEqToken(token) {
      return token.value === "=" && token.type === "Punctuator";
    }
    function isArrowToken(token) {
      return token.value === "=>" && token.type === "Punctuator";
    }
    function isCommaToken(token) {
      return token.value === "," && token.type === "Punctuator";
    }
    function isDotToken(token) {
      return token.value === "." && token.type === "Punctuator";
    }
    function isQuestionDotToken(token) {
      return token.value === "?." && token.type === "Punctuator";
    }
    function isSemicolonToken(token) {
      return token.value === ";" && token.type === "Punctuator";
    }
    function isColonToken(token) {
      return token.value === ":" && token.type === "Punctuator";
    }
    function isOpeningParenToken(token) {
      return token.value === "(" && token.type === "Punctuator";
    }
    function isClosingParenToken(token) {
      return token.value === ")" && token.type === "Punctuator";
    }
    function isOpeningBracketToken(token) {
      return token.value === "[" && token.type === "Punctuator";
    }
    function isClosingBracketToken(token) {
      return token.value === "]" && token.type === "Punctuator";
    }
    function isOpeningBraceToken(token) {
      return token.value === "{" && token.type === "Punctuator";
    }
    function isClosingBraceToken(token) {
      return token.value === "}" && token.type === "Punctuator";
    }
    function isCommentToken(token) {
      return token.type === "Line" || token.type === "Block" || token.type === "Shebang";
    }
    function isKeywordToken(token) {
      return token.type === "Keyword";
    }
    function getOpeningParenOfParams(node, sourceCode) {
      if (node.type === "ArrowFunctionExpression" && node.params.length === 1) {
        const argToken = sourceCode.getFirstToken(node.params[0]);
        const maybeParenToken = sourceCode.getTokenBefore(argToken);
        return isOpeningParenToken(maybeParenToken) ? maybeParenToken : argToken;
      }
      return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken) : sourceCode.getFirstToken(node, isOpeningParenToken);
    }
    function equalTokens(left, right, sourceCode) {
      const tokensL = sourceCode.getTokens(left);
      const tokensR = sourceCode.getTokens(right);
      if (tokensL.length !== tokensR.length) {
        return false;
      }
      for (let i = 0; i < tokensL.length; ++i) {
        if (tokensL[i].type !== tokensR[i].type || tokensL[i].value !== tokensR[i].value) {
          return false;
        }
      }
      return true;
    }
    function isLogicalExpression(node) {
      return node.type === "LogicalExpression" && (node.operator === "&&" || node.operator === "||");
    }
    function isCoalesceExpression(node) {
      return node.type === "LogicalExpression" && node.operator === "??";
    }
    function isMixedLogicalAndCoalesceExpressions(left, right) {
      return isLogicalExpression(left) && isCoalesceExpression(right) || isCoalesceExpression(left) && isLogicalExpression(right);
    }
    function isLogicalAssignmentOperator(operator) {
      return LOGICAL_ASSIGNMENT_OPERATORS.has(operator);
    }
    function getSwitchCaseColonToken(node, sourceCode) {
      if (node.test) {
        return sourceCode.getTokenAfter(node.test, isColonToken);
      }
      return sourceCode.getFirstToken(node, 1);
    }
    function getModuleExportName(node) {
      if (node.type === "Identifier") {
        return node.name;
      }
      return node.value;
    }
    function getBooleanValue(node) {
      if (node.value === null) {
        if (node.raw === "null") {
          return false;
        }
        if (typeof node.regex === "object") {
          return true;
        }
        return null;
      }
      return !!node.value;
    }
    function isLogicalIdentity(node, operator) {
      switch (node.type) {
        case "Literal":
          return operator === "||" && getBooleanValue(node) === true || operator === "&&" && getBooleanValue(node) === false;
        case "UnaryExpression":
          return operator === "&&" && node.operator === "void";
        case "LogicalExpression":
          return operator === node.operator && (isLogicalIdentity(node.left, operator) || isLogicalIdentity(node.right, operator));
        case "AssignmentExpression":
          return ["||=", "&&="].includes(node.operator) && operator === node.operator.slice(0, -1) && isLogicalIdentity(node.right, operator);
      }
      return false;
    }
    function isReferenceToGlobalVariable(scope, node) {
      const reference = scope.references.find((ref) => ref.identifier === node);
      return Boolean(
        reference && reference.resolved && reference.resolved.scope.type === "global" && reference.resolved.defs.length === 0
      );
    }
    function isConstant(scope, node, inBooleanPosition) {
      if (!node) {
        return true;
      }
      switch (node.type) {
        case "Literal":
        case "ArrowFunctionExpression":
        case "FunctionExpression":
          return true;
        case "ClassExpression":
        case "ObjectExpression":
          return true;
        case "TemplateLiteral":
          return inBooleanPosition && node.quasis.some((quasi) => quasi.value.cooked.length) || node.expressions.every((exp) => isConstant(scope, exp, false));
        case "ArrayExpression": {
          if (!inBooleanPosition) {
            return node.elements.every((element) => isConstant(scope, element, false));
          }
          return true;
        }
        case "UnaryExpression":
          if (node.operator === "void" || node.operator === "typeof" && inBooleanPosition) {
            return true;
          }
          if (node.operator === "!") {
            return isConstant(scope, node.argument, true);
          }
          return isConstant(scope, node.argument, false);
        case "BinaryExpression":
          return isConstant(scope, node.left, false) && isConstant(scope, node.right, false) && node.operator !== "in";
        case "LogicalExpression": {
          const isLeftConstant = isConstant(scope, node.left, inBooleanPosition);
          const isRightConstant = isConstant(scope, node.right, inBooleanPosition);
          const isLeftShortCircuit = isLeftConstant && isLogicalIdentity(node.left, node.operator);
          const isRightShortCircuit = inBooleanPosition && isRightConstant && isLogicalIdentity(node.right, node.operator);
          return isLeftConstant && isRightConstant || isLeftShortCircuit || isRightShortCircuit;
        }
        case "NewExpression":
          return inBooleanPosition;
        case "AssignmentExpression":
          if (node.operator === "=") {
            return isConstant(scope, node.right, inBooleanPosition);
          }
          if (["||=", "&&="].includes(node.operator) && inBooleanPosition) {
            return isLogicalIdentity(node.right, node.operator.slice(0, -1));
          }
          return false;
        case "SequenceExpression":
          return isConstant(scope, node.expressions[node.expressions.length - 1], inBooleanPosition);
        case "SpreadElement":
          return isConstant(scope, node.argument, inBooleanPosition);
        case "CallExpression":
          if (node.callee.type === "Identifier" && node.callee.name === "Boolean") {
            if (node.arguments.length === 0 || isConstant(scope, node.arguments[0], true)) {
              return isReferenceToGlobalVariable(scope, node.callee);
            }
          }
          return false;
        case "Identifier":
          return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
      }
      return false;
    }
    module2.exports = {
      COMMENTS_IGNORE_PATTERN,
      LINEBREAKS,
      LINEBREAK_MATCHER: lineBreakPattern,
      SHEBANG_MATCHER: shebangPattern,
      STATEMENT_LIST_PARENTS,
      /**
       * Determines whether two adjacent tokens are on the same line.
       * @param {Object} left The left token object.
       * @param {Object} right The right token object.
       * @returns {boolean} Whether or not the tokens are on the same line.
       * @public
       */
      isTokenOnSameLine(left, right) {
        return left.loc.end.line === right.loc.start.line;
      },
      isNullOrUndefined,
      isCallee,
      isES5Constructor,
      getUpperFunction,
      isFunction,
      isLoop,
      isInLoop,
      isArrayFromMethod,
      isParenthesised,
      createGlobalLinebreakMatcher,
      equalTokens,
      isArrowToken,
      isClosingBraceToken,
      isClosingBracketToken,
      isClosingParenToken,
      isColonToken,
      isCommaToken,
      isCommentToken,
      isDotToken,
      isQuestionDotToken,
      isKeywordToken,
      isNotClosingBraceToken: negate(isClosingBraceToken),
      isNotClosingBracketToken: negate(isClosingBracketToken),
      isNotClosingParenToken: negate(isClosingParenToken),
      isNotColonToken: negate(isColonToken),
      isNotCommaToken: negate(isCommaToken),
      isNotDotToken: negate(isDotToken),
      isNotQuestionDotToken: negate(isQuestionDotToken),
      isNotOpeningBraceToken: negate(isOpeningBraceToken),
      isNotOpeningBracketToken: negate(isOpeningBracketToken),
      isNotOpeningParenToken: negate(isOpeningParenToken),
      isNotSemicolonToken: negate(isSemicolonToken),
      isOpeningBraceToken,
      isOpeningBracketToken,
      isOpeningParenToken,
      isSemicolonToken,
      isEqToken,
      /**
       * Checks whether or not a given node is a string literal.
       * @param {ASTNode} node A node to check.
       * @returns {boolean} `true` if the node is a string literal.
       */
      isStringLiteral(node) {
        return node.type === "Literal" && typeof node.value === "string" || node.type === "TemplateLiteral";
      },
      /**
       * Checks whether a given node is a breakable statement or not.
       * The node is breakable if the node is one of the following type:
       *
       * - DoWhileStatement
       * - ForInStatement
       * - ForOfStatement
       * - ForStatement
       * - SwitchStatement
       * - WhileStatement
       * @param {ASTNode} node A node to check.
       * @returns {boolean} `true` if the node is breakable.
       */
      isBreakableStatement(node) {
        return breakableTypePattern.test(node.type);
      },
      /**
       * Gets references which are non initializer and writable.
       * @param {Reference[]} references An array of references.
       * @returns {Reference[]} An array of only references which are non initializer and writable.
       * @public
       */
      getModifyingReferences(references) {
        return references.filter(isModifyingReference);
      },
      /**
       * Validate that a string passed in is surrounded by the specified character
       * @param {string} val The text to check.
       * @param {string} character The character to see if it's surrounded by.
       * @returns {boolean} True if the text is surrounded by the character, false if not.
       * @private
       */
      isSurroundedBy(val, character) {
        return val[0] === character && val[val.length - 1] === character;
      },
      /**
       * Returns whether the provided node is an ESLint directive comment or not
       * @param {Line|Block} node The comment token to be checked
       * @returns {boolean} `true` if the node is an ESLint directive comment
       */
      isDirectiveComment(node) {
        const comment = node.value.trim();
        return node.type === "Line" && comment.startsWith("eslint-") || node.type === "Block" && ESLINT_DIRECTIVE_PATTERN.test(comment);
      },
      /**
       * Gets the trailing statement of a given node.
       *
       *     if (code)
       *         consequent;
       *
       * When taking this `IfStatement`, returns `consequent;` statement.
       * @param {ASTNode} A node to get.
       * @returns {ASTNode|null} The trailing statement's node.
       */
      getTrailingStatement: esutils.ast.trailingStatement,
      /**
       * Finds the variable by a given name in a given scope and its upper scopes.
       * @param {eslint-scope.Scope} initScope A scope to start find.
       * @param {string} name A variable name to find.
       * @returns {eslint-scope.Variable|null} A found variable or `null`.
       */
      getVariableByName(initScope, name) {
        let scope = initScope;
        while (scope) {
          const variable = scope.set.get(name);
          if (variable) {
            return variable;
          }
          scope = scope.upper;
        }
        return null;
      },
      /**
       * Checks whether or not a given function node is the default `this` binding.
       *
       * First, this checks the node:
       *
       * - The given node is not in `PropertyDefinition#value` position.
       * - The given node is not `StaticBlock`.
       * - The function name does not start with uppercase. It's a convention to capitalize the names
       *   of constructor functions. This check is not performed if `capIsConstructor` is set to `false`.
       * - The function does not have a JSDoc comment that has a @this tag.
       *
       * Next, this checks the location of the node.
       * If the location is below, this judges `this` is valid.
       *
       * - The location is not on an object literal.
       * - The location is not assigned to a variable which starts with an uppercase letter. Applies to anonymous
       *   functions only, as the name of the variable is considered to be the name of the function in this case.
       *   This check is not performed if `capIsConstructor` is set to `false`.
       * - The location is not on an ES2015 class.
       * - Its `bind`/`call`/`apply` method is not called directly.
       * - The function is not a callback of array methods (such as `.forEach()`) if `thisArg` is given.
       * @param {ASTNode} node A function node to check. It also can be an implicit function, like `StaticBlock`
       * or any expression that is `PropertyDefinition#value` node.
       * @param {SourceCode} sourceCode A SourceCode instance to get comments.
       * @param {boolean} [capIsConstructor = true] `false` disables the assumption that functions which name starts
       * with an uppercase or are assigned to a variable which name starts with an uppercase are constructors.
       * @returns {boolean} The function node is the default `this` binding.
       */
      isDefaultThisBinding(node, sourceCode, { capIsConstructor = true } = {}) {
        if (node.parent.type === "PropertyDefinition" && node.parent.value === node) {
          return false;
        }
        if (node.type === "StaticBlock") {
          return false;
        }
        if (capIsConstructor && isES5Constructor(node) || hasJSDocThisTag(node, sourceCode)) {
          return false;
        }
        const isAnonymous = node.id === null;
        let currentNode = node;
        while (currentNode) {
          const parent = currentNode.parent;
          switch (parent.type) {
            case "LogicalExpression":
            case "ConditionalExpression":
            case "ChainExpression":
              currentNode = parent;
              break;
            case "ReturnStatement": {
              const func = getUpperFunction(parent);
              if (func === null || !isCallee(func)) {
                return true;
              }
              currentNode = func.parent;
              break;
            }
            case "ArrowFunctionExpression":
              if (currentNode !== parent.body || !isCallee(parent)) {
                return true;
              }
              currentNode = parent.parent;
              break;
            case "Property":
            case "PropertyDefinition":
            case "MethodDefinition":
              return parent.value !== currentNode;
            case "AssignmentExpression":
            case "AssignmentPattern":
              if (parent.left.type === "MemberExpression") {
                return false;
              }
              if (capIsConstructor && isAnonymous && parent.left.type === "Identifier" && startsWithUpperCase(parent.left.name)) {
                return false;
              }
              return true;
            case "VariableDeclarator":
              return !(capIsConstructor && isAnonymous && parent.init === currentNode && parent.id.type === "Identifier" && startsWithUpperCase(parent.id.name));
            case "MemberExpression":
              if (parent.object === currentNode && isSpecificMemberAccess(parent, null, bindOrCallOrApplyPattern)) {
                const maybeCalleeNode = parent.parent.type === "ChainExpression" ? parent.parent : parent;
                return !(isCallee(maybeCalleeNode) && maybeCalleeNode.parent.arguments.length >= 1 && !isNullOrUndefined(maybeCalleeNode.parent.arguments[0]));
              }
              return true;
            case "CallExpression":
              if (isReflectApply(parent.callee)) {
                return parent.arguments.length !== 3 || parent.arguments[0] !== currentNode || isNullOrUndefined(parent.arguments[1]);
              }
              if (isArrayFromMethod(parent.callee)) {
                return parent.arguments.length !== 3 || parent.arguments[1] !== currentNode || isNullOrUndefined(parent.arguments[2]);
              }
              if (isMethodWhichHasThisArg(parent.callee)) {
                return parent.arguments.length !== 2 || parent.arguments[0] !== currentNode || isNullOrUndefined(parent.arguments[1]);
              }
              return true;
            default:
              return true;
          }
        }
        return true;
      },
      /**
       * Get the precedence level based on the node type
       * @param {ASTNode} node node to evaluate
       * @returns {int} precedence level
       * @private
       */
      getPrecedence(node) {
        switch (node.type) {
          case "SequenceExpression":
            return 0;
          case "AssignmentExpression":
          case "ArrowFunctionExpression":
          case "YieldExpression":
            return 1;
          case "ConditionalExpression":
            return 3;
          case "LogicalExpression":
            switch (node.operator) {
              case "||":
              case "??":
                return 4;
              case "&&":
                return 5;
            }
          case "BinaryExpression":
            switch (node.operator) {
              case "|":
                return 6;
              case "^":
                return 7;
              case "&":
                return 8;
              case "==":
              case "!=":
              case "===":
              case "!==":
                return 9;
              case "<":
              case "<=":
              case ">":
              case ">=":
              case "in":
              case "instanceof":
                return 10;
              case "<<":
              case ">>":
              case ">>>":
                return 11;
              case "+":
              case "-":
                return 12;
              case "*":
              case "/":
              case "%":
                return 13;
              case "**":
                return 15;
            }
          case "UnaryExpression":
          case "AwaitExpression":
            return 16;
          case "UpdateExpression":
            return 17;
          case "CallExpression":
          case "ChainExpression":
          case "ImportExpression":
            return 18;
          case "NewExpression":
            return 19;
          default:
            return 20;
        }
      },
      /**
       * Checks whether the given node is an empty block node or not.
       * @param {ASTNode|null} node The node to check.
       * @returns {boolean} `true` if the node is an empty block.
       */
      isEmptyBlock(node) {
        return Boolean(node && node.type === "BlockStatement" && node.body.length === 0);
      },
      /**
       * Checks whether the given node is an empty function node or not.
       * @param {ASTNode|null} node The node to check.
       * @returns {boolean} `true` if the node is an empty function.
       */
      isEmptyFunction(node) {
        return isFunction(node) && module2.exports.isEmptyBlock(node.body);
      },
      /**
       * Get directives from directive prologue of a Program or Function node.
       * @param {ASTNode} node The node to check.
       * @returns {ASTNode[]} The directives found in the directive prologue.
       */
      getDirectivePrologue(node) {
        const directives = [];
        if (node.type === "Program" || node.type === "FunctionDeclaration" || node.type === "FunctionExpression" || /*
         * Do not check arrow functions with implicit return.
         * `() => "use strict";` returns the string `"use strict"`.
         */
        node.type === "ArrowFunctionExpression" && node.body.type === "BlockStatement") {
          const statements = node.type === "Program" ? node.body : node.body.body;
          for (const statement of statements) {
            if (statement.type === "ExpressionStatement" && statement.expression.type === "Literal") {
              directives.push(statement);
            } else {
              break;
            }
          }
        }
        return directives;
      },
      /**
       * Determines whether this node is a decimal integer literal. If a node is a decimal integer literal, a dot added
       * after the node will be parsed as a decimal point, rather than a property-access dot.
       * @param {ASTNode} node The node to check.
       * @returns {boolean} `true` if this node is a decimal integer.
       * @example
       *
       * 0         // true
       * 5         // true
       * 50        // true
       * 5_000     // true
       * 1_234_56  // true
       * 08        // true
       * 0192      // true
       * 5.        // false
       * .5        // false
       * 5.0       // false
       * 5.00_00   // false
       * 05        // false
       * 0x5       // false
       * 0b101     // false
       * 0b11_01   // false
       * 0o5       // false
       * 5e0       // false
       * 5e1_000   // false
       * 5n        // false
       * 1_000n    // false
       * "5"       // false
       *
       */
      isDecimalInteger(node) {
        return node.type === "Literal" && typeof node.value === "number" && DECIMAL_INTEGER_PATTERN.test(node.raw);
      },
      /**
       * Determines whether this token is a decimal integer numeric token.
       * This is similar to isDecimalInteger(), but for tokens.
       * @param {Token} token The token to check.
       * @returns {boolean} `true` if this token is a decimal integer.
       */
      isDecimalIntegerNumericToken(token) {
        return token.type === "Numeric" && DECIMAL_INTEGER_PATTERN.test(token.value);
      },
      /**
       * Gets the name and kind of the given function node.
       *
       * - `function foo() {}`  .................... `function 'foo'`
       * - `(function foo() {})`  .................. `function 'foo'`
       * - `(function() {})`  ...................... `function`
       * - `function* foo() {}`  ................... `generator function 'foo'`
       * - `(function* foo() {})`  ................. `generator function 'foo'`
       * - `(function*() {})`  ..................... `generator function`
       * - `() => {}`  ............................. `arrow function`
       * - `async () => {}`  ....................... `async arrow function`
       * - `({ foo: function foo() {} })`  ......... `method 'foo'`
       * - `({ foo: function() {} })`  ............. `method 'foo'`
       * - `({ ['foo']: function() {} })`  ......... `method 'foo'`
       * - `({ [foo]: function() {} })`  ........... `method`
       * - `({ foo() {} })`  ....................... `method 'foo'`
       * - `({ foo: function* foo() {} })`  ........ `generator method 'foo'`
       * - `({ foo: function*() {} })`  ............ `generator method 'foo'`
       * - `({ ['foo']: function*() {} })`  ........ `generator method 'foo'`
       * - `({ [foo]: function*() {} })`  .......... `generator method`
       * - `({ *foo() {} })`  ...................... `generator method 'foo'`
       * - `({ foo: async function foo() {} })`  ... `async method 'foo'`
       * - `({ foo: async function() {} })`  ....... `async method 'foo'`
       * - `({ ['foo']: async function() {} })`  ... `async method 'foo'`
       * - `({ [foo]: async function() {} })`  ..... `async method`
       * - `({ async foo() {} })`  ................. `async method 'foo'`
       * - `({ get foo() {} })`  ................... `getter 'foo'`
       * - `({ set foo(a) {} })`  .................. `setter 'foo'`
       * - `class A { constructor() {} }`  ......... `constructor`
       * - `class A { foo() {} }`  ................. `method 'foo'`
       * - `class A { *foo() {} }`  ................ `generator method 'foo'`
       * - `class A { async foo() {} }`  ........... `async method 'foo'`
       * - `class A { ['foo']() {} }`  ............. `method 'foo'`
       * - `class A { *['foo']() {} }`  ............ `generator method 'foo'`
       * - `class A { async ['foo']() {} }`  ....... `async method 'foo'`
       * - `class A { [foo]() {} }`  ............... `method`
       * - `class A { *[foo]() {} }`  .............. `generator method`
       * - `class A { async [foo]() {} }`  ......... `async method`
       * - `class A { get foo() {} }`  ............. `getter 'foo'`
       * - `class A { set foo(a) {} }`  ............ `setter 'foo'`
       * - `class A { static foo() {} }`  .......... `static method 'foo'`
       * - `class A { static *foo() {} }`  ......... `static generator method 'foo'`
       * - `class A { static async foo() {} }`  .... `static async method 'foo'`
       * - `class A { static get foo() {} }`  ...... `static getter 'foo'`
       * - `class A { static set foo(a) {} }`  ..... `static setter 'foo'`
       * - `class A { foo = () => {}; }`  .......... `method 'foo'`
       * - `class A { foo = function() {}; }`  ..... `method 'foo'`
       * - `class A { foo = function bar() {}; }`  . `method 'foo'`
       * - `class A { static foo = () => {}; }`  ... `static method 'foo'`
       * - `class A { '#foo' = () => {}; }`  ....... `method '#foo'`
       * - `class A { #foo = () => {}; }`  ......... `private method #foo`
       * - `class A { static #foo = () => {}; }`  .. `static private method #foo`
       * - `class A { '#foo'() {} }`  .............. `method '#foo'`
       * - `class A { #foo() {} }`  ................ `private method #foo`
       * - `class A { static #foo() {} }`  ......... `static private method #foo`
       * @param {ASTNode} node The function node to get.
       * @returns {string} The name and kind of the function node.
       */
      getFunctionNameWithKind(node) {
        const parent = node.parent;
        const tokens = [];
        if (parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
          if (parent.static) {
            tokens.push("static");
          }
          if (!parent.computed && parent.key.type === "PrivateIdentifier") {
            tokens.push("private");
          }
        }
        if (node.async) {
          tokens.push("async");
        }
        if (node.generator) {
          tokens.push("generator");
        }
        if (parent.type === "Property" || parent.type === "MethodDefinition") {
          if (parent.kind === "constructor") {
            return "constructor";
          }
          if (parent.kind === "get") {
            tokens.push("getter");
          } else if (parent.kind === "set") {
            tokens.push("setter");
          } else {
            tokens.push("method");
          }
        } else if (parent.type === "PropertyDefinition") {
          tokens.push("method");
        } else {
          if (node.type === "ArrowFunctionExpression") {
            tokens.push("arrow");
          }
          tokens.push("function");
        }
        if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
          if (!parent.computed && parent.key.type === "PrivateIdentifier") {
            tokens.push(`#${parent.key.name}`);
          } else {
            const name = getStaticPropertyName(parent);
            if (name !== null) {
              tokens.push(`'${name}'`);
            } else if (node.id) {
              tokens.push(`'${node.id.name}'`);
            }
          }
        } else if (node.id) {
          tokens.push(`'${node.id.name}'`);
        }
        return tokens.join(" ");
      },
      /**
       * Gets the location of the given function node for reporting.
       *
       * - `function foo() {}`
       *    ^^^^^^^^^^^^
       * - `(function foo() {})`
       *     ^^^^^^^^^^^^
       * - `(function() {})`
       *     ^^^^^^^^
       * - `function* foo() {}`
       *    ^^^^^^^^^^^^^
       * - `(function* foo() {})`
       *     ^^^^^^^^^^^^^
       * - `(function*() {})`
       *     ^^^^^^^^^
       * - `() => {}`
       *       ^^
       * - `async () => {}`
       *             ^^
       * - `({ foo: function foo() {} })`
       *       ^^^^^^^^^^^^^^^^^
       * - `({ foo: function() {} })`
       *       ^^^^^^^^^^^^^
       * - `({ ['foo']: function() {} })`
       *       ^^^^^^^^^^^^^^^^^
       * - `({ [foo]: function() {} })`
       *       ^^^^^^^^^^^^^^^
       * - `({ foo() {} })`
       *       ^^^
       * - `({ foo: function* foo() {} })`
       *       ^^^^^^^^^^^^^^^^^^
       * - `({ foo: function*() {} })`
       *       ^^^^^^^^^^^^^^
       * - `({ ['foo']: function*() {} })`
       *       ^^^^^^^^^^^^^^^^^^
       * - `({ [foo]: function*() {} })`
       *       ^^^^^^^^^^^^^^^^
       * - `({ *foo() {} })`
       *       ^^^^
       * - `({ foo: async function foo() {} })`
       *       ^^^^^^^^^^^^^^^^^^^^^^^
       * - `({ foo: async function() {} })`
       *       ^^^^^^^^^^^^^^^^^^^
       * - `({ ['foo']: async function() {} })`
       *       ^^^^^^^^^^^^^^^^^^^^^^^
       * - `({ [foo]: async function() {} })`
       *       ^^^^^^^^^^^^^^^^^^^^^
       * - `({ async foo() {} })`
       *       ^^^^^^^^^
       * - `({ get foo() {} })`
       *       ^^^^^^^
       * - `({ set foo(a) {} })`
       *       ^^^^^^^
       * - `class A { constructor() {} }`
       *              ^^^^^^^^^^^
       * - `class A { foo() {} }`
       *              ^^^
       * - `class A { *foo() {} }`
       *              ^^^^
       * - `class A { async foo() {} }`
       *              ^^^^^^^^^
       * - `class A { ['foo']() {} }`
       *              ^^^^^^^
       * - `class A { *['foo']() {} }`
       *              ^^^^^^^^
       * - `class A { async ['foo']() {} }`
       *              ^^^^^^^^^^^^^
       * - `class A { [foo]() {} }`
       *              ^^^^^
       * - `class A { *[foo]() {} }`
       *              ^^^^^^
       * - `class A { async [foo]() {} }`
       *              ^^^^^^^^^^^
       * - `class A { get foo() {} }`
       *              ^^^^^^^
       * - `class A { set foo(a) {} }`
       *              ^^^^^^^
       * - `class A { static foo() {} }`
       *              ^^^^^^^^^^
       * - `class A { static *foo() {} }`
       *              ^^^^^^^^^^^
       * - `class A { static async foo() {} }`
       *              ^^^^^^^^^^^^^^^^
       * - `class A { static get foo() {} }`
       *              ^^^^^^^^^^^^^^
       * - `class A { static set foo(a) {} }`
       *              ^^^^^^^^^^^^^^
       * - `class A { foo = function() {} }`
       *              ^^^^^^^^^^^^^^
       * - `class A { static foo = function() {} }`
       *              ^^^^^^^^^^^^^^^^^^^^^
       * - `class A { foo = (a, b) => {} }`
       *              ^^^^^^
       * @param {ASTNode} node The function node to get.
       * @param {SourceCode} sourceCode The source code object to get tokens.
       * @returns {string} The location of the function node for reporting.
       */
      getFunctionHeadLoc(node, sourceCode) {
        const parent = node.parent;
        let start = null;
        let end = null;
        if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
          start = parent.loc.start;
          end = getOpeningParenOfParams(node, sourceCode).loc.start;
        } else if (node.type === "ArrowFunctionExpression") {
          const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken);
          start = arrowToken.loc.start;
          end = arrowToken.loc.end;
        } else {
          start = node.loc.start;
          end = getOpeningParenOfParams(node, sourceCode).loc.start;
        }
        return {
          start: Object.assign({}, start),
          end: Object.assign({}, end)
        };
      },
      /**
       * Gets next location when the result is not out of bound, otherwise returns null.
       *
       * Assumptions:
       *
       * - The given location represents a valid location in the given source code.
       * - Columns are 0-based.
       * - Lines are 1-based.
       * - Column immediately after the last character in a line (not incl. linebreaks) is considered to be a valid location.
       * - If the source code ends with a linebreak, `sourceCode.lines` array will have an extra element (empty string) at the end.
       *   The start (column 0) of that extra line is considered to be a valid location.
       *
       * Examples of successive locations (line, column):
       *
       * code: foo
       * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> null
       *
       * code: foo<LF>
       * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> (2, 0) -> null
       *
       * code: foo<CR><LF>
       * locations: (1, 0) -> (1, 1) -> (1, 2) -> (1, 3) -> (2, 0) -> null
       *
       * code: a<LF>b
       * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> null
       *
       * code: a<LF>b<LF>
       * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> (3, 0) -> null
       *
       * code: a<CR><LF>b<CR><LF>
       * locations: (1, 0) -> (1, 1) -> (2, 0) -> (2, 1) -> (3, 0) -> null
       *
       * code: a<LF><LF>
       * locations: (1, 0) -> (1, 1) -> (2, 0) -> (3, 0) -> null
       *
       * code: <LF>
       * locations: (1, 0) -> (2, 0) -> null
       *
       * code:
       * locations: (1, 0) -> null
       * @param {SourceCode} sourceCode The sourceCode
       * @param {{line: number, column: number}} location The location
       * @returns {{line: number, column: number} | null} Next location
       */
      getNextLocation(sourceCode, { line, column }) {
        if (column < sourceCode.lines[line - 1].length) {
          return {
            line,
            column: column + 1
          };
        }
        if (line < sourceCode.lines.length) {
          return {
            line: line + 1,
            column: 0
          };
        }
        return null;
      },
      /**
       * Gets the parenthesized text of a node. This is similar to sourceCode.getText(node), but it also includes any parentheses
       * surrounding the node.
       * @param {SourceCode} sourceCode The source code object
       * @param {ASTNode} node An expression node
       * @returns {string} The text representing the node, with all surrounding parentheses included
       */
      getParenthesisedText(sourceCode, node) {
        let leftToken = sourceCode.getFirstToken(node);
        let rightToken = sourceCode.getLastToken(node);
        while (sourceCode.getTokenBefore(leftToken) && sourceCode.getTokenBefore(leftToken).type === "Punctuator" && sourceCode.getTokenBefore(leftToken).value === "(" && sourceCode.getTokenAfter(rightToken) && sourceCode.getTokenAfter(rightToken).type === "Punctuator" && sourceCode.getTokenAfter(rightToken).value === ")") {
          leftToken = sourceCode.getTokenBefore(leftToken);
          rightToken = sourceCode.getTokenAfter(rightToken);
        }
        return sourceCode.getText().slice(leftToken.range[0], rightToken.range[1]);
      },
      /**
       * Determine if a node has a possibility to be an Error object
       * @param {ASTNode} node ASTNode to check
       * @returns {boolean} True if there is a chance it contains an Error obj
       */
      couldBeError(node) {
        switch (node.type) {
          case "Identifier":
          case "CallExpression":
          case "NewExpression":
          case "MemberExpression":
          case "TaggedTemplateExpression":
          case "YieldExpression":
          case "AwaitExpression":
          case "ChainExpression":
            return true;
          case "AssignmentExpression":
            if (["=", "&&="].includes(node.operator)) {
              return module2.exports.couldBeError(node.right);
            }
            if (["||=", "??="].includes(node.operator)) {
              return module2.exports.couldBeError(node.left) || module2.exports.couldBeError(node.right);
            }
            return false;
          case "SequenceExpression": {
            const exprs = node.expressions;
            return exprs.length !== 0 && module2.exports.couldBeError(exprs[exprs.length - 1]);
          }
          case "LogicalExpression":
            if (node.operator === "&&") {
              return module2.exports.couldBeError(node.right);
            }
            return module2.exports.couldBeError(node.left) || module2.exports.couldBeError(node.right);
          case "ConditionalExpression":
            return module2.exports.couldBeError(node.consequent) || module2.exports.couldBeError(node.alternate);
          default:
            return false;
        }
      },
      /**
       * Check if a given node is a numeric literal or not.
       * @param {ASTNode} node The node to check.
       * @returns {boolean} `true` if the node is a number or bigint literal.
       */
      isNumericLiteral(node) {
        return node.type === "Literal" && (typeof node.value === "number" || Boolean(node.bigint));
      },
      /**
       * Determines whether two tokens can safely be placed next to each other without merging into a single token
       * @param {Token|string} leftValue The left token. If this is a string, it will be tokenized and the last token will be used.
       * @param {Token|string} rightValue The right token. If this is a string, it will be tokenized and the first token will be used.
       * @returns {boolean} If the tokens cannot be safely placed next to each other, returns `false`. If the tokens can be placed
       * next to each other, behavior is undefined (although it should return `true` in most cases).
       */
      canTokensBeAdjacent(leftValue, rightValue) {
        const espreeOptions = {
          ecmaVersion: espree.latestEcmaVersion,
          comment: true,
          range: true
        };
        let leftToken;
        if (typeof leftValue === "string") {
          let tokens;
          try {
            tokens = espree.tokenize(leftValue, espreeOptions);
          } catch {
            return false;
          }
          const comments = tokens.comments;
          leftToken = tokens[tokens.length - 1];
          if (comments.length) {
            const lastComment = comments[comments.length - 1];
            if (!leftToken || lastComment.range[0] > leftToken.range[0]) {
              leftToken = lastComment;
            }
          }
        } else {
          leftToken = leftValue;
        }
        if (leftToken.type === "Shebang" || leftToken.type === "Hashbang") {
          return false;
        }
        let rightToken;
        if (typeof rightValue === "string") {
          let tokens;
          try {
            tokens = espree.tokenize(rightValue, espreeOptions);
          } catch {
            return false;
          }
          const comments = tokens.comments;
          rightToken = tokens[0];
          if (comments.length) {
            const firstComment = comments[0];
            if (!rightToken || firstComment.range[0] < rightToken.range[0]) {
              rightToken = firstComment;
            }
          }
        } else {
          rightToken = rightValue;
        }
        if (leftToken.type === "Punctuator" || rightToken.type === "Punctuator") {
          if (leftToken.type === "Punctuator" && rightToken.type === "Punctuator") {
            const PLUS_TOKENS = /* @__PURE__ */ new Set(["+", "++"]);
            const MINUS_TOKENS = /* @__PURE__ */ new Set(["-", "--"]);
            return !(PLUS_TOKENS.has(leftToken.value) && PLUS_TOKENS.has(rightToken.value) || MINUS_TOKENS.has(leftToken.value) && MINUS_TOKENS.has(rightToken.value));
          }
          if (leftToken.type === "Punctuator" && leftToken.value === "/") {
            return !["Block", "Line", "RegularExpression"].includes(rightToken.type);
          }
          return true;
        }
        if (leftToken.type === "String" || rightToken.type === "String" || leftToken.type === "Template" || rightToken.type === "Template") {
          return true;
        }
        if (leftToken.type !== "Numeric" && rightToken.type === "Numeric" && rightToken.value.startsWith(".")) {
          return true;
        }
        if (leftToken.type === "Block" || rightToken.type === "Block" || rightToken.type === "Line") {
          return true;
        }
        if (rightToken.type === "PrivateIdentifier") {
          return true;
        }
        return false;
      },
      /**
       * Get the `loc` object of a given name in a `/*globals` directive comment.
       * @param {SourceCode} sourceCode The source code to convert index to loc.
       * @param {Comment} comment The `/*globals` directive comment which include the name.
       * @param {string} name The name to find.
       * @returns {SourceLocation} The `loc` object.
       */
      getNameLocationInGlobalDirectiveComment(sourceCode, comment, name) {
        const namePattern = new RegExp(`[\\s,]${escapeRegExp(name)}(?:$|[\\s,:])`, "gu");
        namePattern.lastIndex = comment.value.indexOf("global") + 6;
        const match = namePattern.exec(comment.value);
        const start = sourceCode.getLocFromIndex(
          comment.range[0] + "/*".length + (match ? match.index + 1 : 0)
        );
        const end = {
          line: start.line,
          column: start.column + (match ? name.length : 1)
        };
        return { start, end };
      },
      /**
       * Determines whether the given raw string contains an octal escape sequence
       * or a non-octal decimal escape sequence ("\8", "\9").
       *
       * "\1", "\2" ... "\7", "\8", "\9"
       * "\00", "\01" ... "\07", "\08", "\09"
       *
       * "\0", when not followed by a digit, is not an octal escape sequence.
       * @param {string} rawString A string in its raw representation.
       * @returns {boolean} `true` if the string contains at least one octal escape sequence
       * or at least one non-octal decimal escape sequence.
       */
      hasOctalOrNonOctalDecimalEscapeSequence(rawString) {
        return OCTAL_OR_NON_OCTAL_DECIMAL_ESCAPE_PATTERN.test(rawString);
      },
      isReferenceToGlobalVariable,
      isLogicalExpression,
      isCoalesceExpression,
      isMixedLogicalAndCoalesceExpressions,
      isNullLiteral,
      getStaticStringValue,
      getStaticPropertyName,
      skipChainExpression,
      isSpecificId,
      isSpecificMemberAccess,
      equalLiteralValue,
      isSameReference,
      isLogicalAssignmentOperator,
      getSwitchCaseColonToken,
      getModuleExportName,
      isConstant
    };
  }
});

// node_modules/eslint/lib/rules/accessor-pairs.js
var require_accessor_pairs = __commonJS({
  "node_modules/eslint/lib/rules/accessor-pairs.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function areEqualTokenLists(left, right) {
      if (left.length !== right.length) {
        return false;
      }
      for (let i = 0; i < left.length; i++) {
        const leftToken = left[i], rightToken = right[i];
        if (leftToken.type !== rightToken.type || leftToken.value !== rightToken.value) {
          return false;
        }
      }
      return true;
    }
    function areEqualKeys(left, right) {
      if (typeof left === "string" && typeof right === "string") {
        return left === right;
      }
      if (Array.isArray(left) && Array.isArray(right)) {
        return areEqualTokenLists(left, right);
      }
      return false;
    }
    function isAccessorKind(node) {
      return node.kind === "get" || node.kind === "set";
    }
    function isArgumentOfMethodCall(node, index, object, property) {
      const parent = node.parent;
      return parent.type === "CallExpression" && astUtils.isSpecificMemberAccess(parent.callee, object, property) && parent.arguments[index] === node;
    }
    function isPropertyDescriptor(node) {
      if (isArgumentOfMethodCall(node, 2, "Object", "defineProperty") || isArgumentOfMethodCall(node, 2, "Reflect", "defineProperty")) {
        return true;
      }
      const grandparent = node.parent.parent;
      return grandparent.type === "ObjectExpression" && (isArgumentOfMethodCall(grandparent, 1, "Object", "create") || isArgumentOfMethodCall(grandparent, 1, "Object", "defineProperties"));
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce getter and setter pairs in objects and classes",
          recommended: false,
          url: "https://eslint.org/docs/rules/accessor-pairs"
        },
        schema: [{
          type: "object",
          properties: {
            getWithoutSet: {
              type: "boolean",
              default: false
            },
            setWithoutGet: {
              type: "boolean",
              default: true
            },
            enforceForClassMembers: {
              type: "boolean",
              default: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          missingGetterInPropertyDescriptor: "Getter is not present in property descriptor.",
          missingSetterInPropertyDescriptor: "Setter is not present in property descriptor.",
          missingGetterInObjectLiteral: "Getter is not present for {{ name }}.",
          missingSetterInObjectLiteral: "Setter is not present for {{ name }}.",
          missingGetterInClass: "Getter is not present for class {{ name }}.",
          missingSetterInClass: "Setter is not present for class {{ name }}."
        }
      },
      create(context) {
        const config = context.options[0] || {};
        const checkGetWithoutSet = config.getWithoutSet === true;
        const checkSetWithoutGet = config.setWithoutGet !== false;
        const enforceForClassMembers = config.enforceForClassMembers !== false;
        const sourceCode = context.getSourceCode();
        function report(node, messageKind) {
          if (node.type === "Property") {
            context.report({
              node,
              messageId: `${messageKind}InObjectLiteral`,
              loc: astUtils.getFunctionHeadLoc(node.value, sourceCode),
              data: { name: astUtils.getFunctionNameWithKind(node.value) }
            });
          } else if (node.type === "MethodDefinition") {
            context.report({
              node,
              messageId: `${messageKind}InClass`,
              loc: astUtils.getFunctionHeadLoc(node.value, sourceCode),
              data: { name: astUtils.getFunctionNameWithKind(node.value) }
            });
          } else {
            context.report({
              node,
              messageId: `${messageKind}InPropertyDescriptor`
            });
          }
        }
        function reportList(nodes, messageKind) {
          for (const node of nodes) {
            report(node, messageKind);
          }
        }
        function createAccessorData(node) {
          const name = astUtils.getStaticPropertyName(node);
          const key = name !== null ? name : sourceCode.getTokens(node.key);
          return {
            key,
            getters: node.kind === "get" ? [node] : [],
            setters: node.kind === "set" ? [node] : []
          };
        }
        function mergeAccessorData(accessors, accessorData) {
          const equalKeyElement = accessors.find((a) => areEqualKeys(a.key, accessorData.key));
          if (equalKeyElement) {
            equalKeyElement.getters.push(...accessorData.getters);
            equalKeyElement.setters.push(...accessorData.setters);
          } else {
            accessors.push(accessorData);
          }
          return accessors;
        }
        function checkList(nodes) {
          const accessors = nodes.filter(isAccessorKind).map(createAccessorData).reduce(mergeAccessorData, []);
          for (const { getters, setters } of accessors) {
            if (checkSetWithoutGet && setters.length && !getters.length) {
              reportList(setters, "missingGetter");
            }
            if (checkGetWithoutSet && getters.length && !setters.length) {
              reportList(getters, "missingSetter");
            }
          }
        }
        function checkObjectLiteral(node) {
          checkList(node.properties.filter((p) => p.type === "Property"));
        }
        function checkPropertyDescriptor(node) {
          const namesToCheck = new Set(node.properties.filter((p) => p.type === "Property" && p.kind === "init" && !p.computed).map(({ key }) => key.name));
          const hasGetter = namesToCheck.has("get");
          const hasSetter = namesToCheck.has("set");
          if (checkSetWithoutGet && hasSetter && !hasGetter) {
            report(node, "missingGetter");
          }
          if (checkGetWithoutSet && hasGetter && !hasSetter) {
            report(node, "missingSetter");
          }
        }
        function checkObjectExpression(node) {
          checkObjectLiteral(node);
          if (isPropertyDescriptor(node)) {
            checkPropertyDescriptor(node);
          }
        }
        function checkClassBody(node) {
          const methodDefinitions = node.body.filter((m) => m.type === "MethodDefinition");
          checkList(methodDefinitions.filter((m) => m.static));
          checkList(methodDefinitions.filter((m) => !m.static));
        }
        const listeners = {};
        if (checkSetWithoutGet || checkGetWithoutSet) {
          listeners.ObjectExpression = checkObjectExpression;
          if (enforceForClassMembers) {
            listeners.ClassBody = checkClassBody;
          }
        }
        return listeners;
      }
    };
  }
});

// node_modules/eslint/lib/rules/array-bracket-newline.js
var require_array_bracket_newline = __commonJS({
  "node_modules/eslint/lib/rules/array-bracket-newline.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce linebreaks after opening and before closing array brackets",
          recommended: false,
          url: "https://eslint.org/docs/rules/array-bracket-newline"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never", "consistent"]
              },
              {
                type: "object",
                properties: {
                  multiline: {
                    type: "boolean"
                  },
                  minItems: {
                    type: ["integer", "null"],
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          unexpectedOpeningLinebreak: "There should be no linebreak after '['.",
          unexpectedClosingLinebreak: "There should be no linebreak before ']'.",
          missingOpeningLinebreak: "A linebreak is required after '['.",
          missingClosingLinebreak: "A linebreak is required before ']'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function normalizeOptionValue(option) {
          let consistent = false;
          let multiline = false;
          let minItems = 0;
          if (option) {
            if (option === "consistent") {
              consistent = true;
              minItems = Number.POSITIVE_INFINITY;
            } else if (option === "always" || option.minItems === 0) {
              minItems = 0;
            } else if (option === "never") {
              minItems = Number.POSITIVE_INFINITY;
            } else {
              multiline = Boolean(option.multiline);
              minItems = option.minItems || Number.POSITIVE_INFINITY;
            }
          } else {
            consistent = false;
            multiline = true;
            minItems = Number.POSITIVE_INFINITY;
          }
          return { consistent, multiline, minItems };
        }
        function normalizeOptions(options) {
          const value2 = normalizeOptionValue(options);
          return { ArrayExpression: value2, ArrayPattern: value2 };
        }
        function reportNoBeginningLinebreak(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "unexpectedOpeningLinebreak",
            fix(fixer) {
              const nextToken = sourceCode.getTokenAfter(token, { includeComments: true });
              if (astUtils.isCommentToken(nextToken)) {
                return null;
              }
              return fixer.removeRange([token.range[1], nextToken.range[0]]);
            }
          });
        }
        function reportNoEndingLinebreak(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "unexpectedClosingLinebreak",
            fix(fixer) {
              const previousToken = sourceCode.getTokenBefore(token, { includeComments: true });
              if (astUtils.isCommentToken(previousToken)) {
                return null;
              }
              return fixer.removeRange([previousToken.range[1], token.range[0]]);
            }
          });
        }
        function reportRequiredBeginningLinebreak(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingOpeningLinebreak",
            fix(fixer) {
              return fixer.insertTextAfter(token, "\n");
            }
          });
        }
        function reportRequiredEndingLinebreak(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingClosingLinebreak",
            fix(fixer) {
              return fixer.insertTextBefore(token, "\n");
            }
          });
        }
        function check(node) {
          const elements = node.elements;
          const normalizedOptions = normalizeOptions(context.options[0]);
          const options = normalizedOptions[node.type];
          const openBracket = sourceCode.getFirstToken(node);
          const closeBracket = sourceCode.getLastToken(node);
          const firstIncComment = sourceCode.getTokenAfter(openBracket, { includeComments: true });
          const lastIncComment = sourceCode.getTokenBefore(closeBracket, { includeComments: true });
          const first2 = sourceCode.getTokenAfter(openBracket);
          const last2 = sourceCode.getTokenBefore(closeBracket);
          const needsLinebreaks = elements.length >= options.minItems || options.multiline && elements.length > 0 && firstIncComment.loc.start.line !== lastIncComment.loc.end.line || elements.length === 0 && firstIncComment.type === "Block" && firstIncComment.loc.start.line !== lastIncComment.loc.end.line && firstIncComment === lastIncComment || options.consistent && openBracket.loc.end.line !== first2.loc.start.line;
          if (needsLinebreaks) {
            if (astUtils.isTokenOnSameLine(openBracket, first2)) {
              reportRequiredBeginningLinebreak(node, openBracket);
            }
            if (astUtils.isTokenOnSameLine(last2, closeBracket)) {
              reportRequiredEndingLinebreak(node, closeBracket);
            }
          } else {
            if (!astUtils.isTokenOnSameLine(openBracket, first2)) {
              reportNoBeginningLinebreak(node, openBracket);
            }
            if (!astUtils.isTokenOnSameLine(last2, closeBracket)) {
              reportNoEndingLinebreak(node, closeBracket);
            }
          }
        }
        return {
          ArrayPattern: check,
          ArrayExpression: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/array-bracket-spacing.js
var require_array_bracket_spacing = __commonJS({
  "node_modules/eslint/lib/rules/array-bracket-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing inside array brackets",
          recommended: false,
          url: "https://eslint.org/docs/rules/array-bracket-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              singleValue: {
                type: "boolean"
              },
              objectsInArrays: {
                type: "boolean"
              },
              arraysInArrays: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedSpaceAfter: "There should be no space after '{{tokenValue}}'.",
          unexpectedSpaceBefore: "There should be no space before '{{tokenValue}}'.",
          missingSpaceAfter: "A space is required after '{{tokenValue}}'.",
          missingSpaceBefore: "A space is required before '{{tokenValue}}'."
        }
      },
      create(context) {
        const spaced = context.options[0] === "always", sourceCode = context.getSourceCode();
        function isOptionSet(option) {
          return context.options[1] ? context.options[1][option] === !spaced : false;
        }
        const options = {
          spaced,
          singleElementException: isOptionSet("singleValue"),
          objectsInArraysException: isOptionSet("objectsInArrays"),
          arraysInArraysException: isOptionSet("arraysInArrays")
        };
        function reportNoBeginningSpace(node, token) {
          const nextToken = sourceCode.getTokenAfter(token);
          context.report({
            node,
            loc: { start: token.loc.end, end: nextToken.loc.start },
            messageId: "unexpectedSpaceAfter",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.removeRange([token.range[1], nextToken.range[0]]);
            }
          });
        }
        function reportNoEndingSpace(node, token) {
          const previousToken = sourceCode.getTokenBefore(token);
          context.report({
            node,
            loc: { start: previousToken.loc.end, end: token.loc.start },
            messageId: "unexpectedSpaceBefore",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.removeRange([previousToken.range[1], token.range[0]]);
            }
          });
        }
        function reportRequiredBeginningSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingSpaceAfter",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.insertTextAfter(token, " ");
            }
          });
        }
        function reportRequiredEndingSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingSpaceBefore",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.insertTextBefore(token, " ");
            }
          });
        }
        function isObjectType(node) {
          return node && (node.type === "ObjectExpression" || node.type === "ObjectPattern");
        }
        function isArrayType(node) {
          return node && (node.type === "ArrayExpression" || node.type === "ArrayPattern");
        }
        function validateArraySpacing(node) {
          if (options.spaced && node.elements.length === 0) {
            return;
          }
          const first2 = sourceCode.getFirstToken(node), second = sourceCode.getFirstToken(node, 1), last2 = node.typeAnnotation ? sourceCode.getTokenBefore(node.typeAnnotation) : sourceCode.getLastToken(node), penultimate = sourceCode.getTokenBefore(last2), firstElement = node.elements[0], lastElement = node.elements[node.elements.length - 1];
          const openingBracketMustBeSpaced = options.objectsInArraysException && isObjectType(firstElement) || options.arraysInArraysException && isArrayType(firstElement) || options.singleElementException && node.elements.length === 1 ? !options.spaced : options.spaced;
          const closingBracketMustBeSpaced = options.objectsInArraysException && isObjectType(lastElement) || options.arraysInArraysException && isArrayType(lastElement) || options.singleElementException && node.elements.length === 1 ? !options.spaced : options.spaced;
          if (astUtils.isTokenOnSameLine(first2, second)) {
            if (openingBracketMustBeSpaced && !sourceCode.isSpaceBetweenTokens(first2, second)) {
              reportRequiredBeginningSpace(node, first2);
            }
            if (!openingBracketMustBeSpaced && sourceCode.isSpaceBetweenTokens(first2, second)) {
              reportNoBeginningSpace(node, first2);
            }
          }
          if (first2 !== penultimate && astUtils.isTokenOnSameLine(penultimate, last2)) {
            if (closingBracketMustBeSpaced && !sourceCode.isSpaceBetweenTokens(penultimate, last2)) {
              reportRequiredEndingSpace(node, last2);
            }
            if (!closingBracketMustBeSpaced && sourceCode.isSpaceBetweenTokens(penultimate, last2)) {
              reportNoEndingSpace(node, last2);
            }
          }
        }
        return {
          ArrayPattern: validateArraySpacing,
          ArrayExpression: validateArraySpacing
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/array-callback-return.js
var require_array_callback_return = __commonJS({
  "node_modules/eslint/lib/rules/array-callback-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var TARGET_NODE_TYPE = /^(?:Arrow)?FunctionExpression$/u;
    var TARGET_METHODS = /^(?:every|filter|find(?:Last)?(?:Index)?|flatMap|forEach|map|reduce(?:Right)?|some|sort)$/u;
    function isReachable(segment) {
      return segment.reachable;
    }
    function isTargetMethod(node) {
      return astUtils.isSpecificMemberAccess(node, null, TARGET_METHODS);
    }
    function fullMethodName(arrayMethodName) {
      if (["from", "of", "isArray"].includes(arrayMethodName)) {
        return "Array.".concat(arrayMethodName);
      }
      return "Array.prototype.".concat(arrayMethodName);
    }
    function getArrayMethodName(node) {
      let currentNode = node;
      while (currentNode) {
        const parent = currentNode.parent;
        switch (parent.type) {
          case "LogicalExpression":
          case "ConditionalExpression":
          case "ChainExpression":
            currentNode = parent;
            break;
          case "ReturnStatement": {
            const func = astUtils.getUpperFunction(parent);
            if (func === null || !astUtils.isCallee(func)) {
              return null;
            }
            currentNode = func.parent;
            break;
          }
          case "CallExpression":
            if (astUtils.isArrayFromMethod(parent.callee)) {
              if (parent.arguments.length >= 2 && parent.arguments[1] === currentNode) {
                return "from";
              }
            }
            if (isTargetMethod(parent.callee)) {
              if (parent.arguments.length >= 1 && parent.arguments[0] === currentNode) {
                return astUtils.getStaticPropertyName(parent.callee);
              }
            }
            return null;
          default:
            return null;
        }
      }
      return null;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Enforce `return` statements in callbacks of array methods",
          recommended: false,
          url: "https://eslint.org/docs/rules/array-callback-return"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowImplicit: {
                type: "boolean",
                default: false
              },
              checkForEach: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expectedAtEnd: "{{arrayMethodName}}() expects a value to be returned at the end of {{name}}.",
          expectedInside: "{{arrayMethodName}}() expects a return value from {{name}}.",
          expectedReturnValue: "{{arrayMethodName}}() expects a return value from {{name}}.",
          expectedNoReturnValue: "{{arrayMethodName}}() expects no useless return value from {{name}}."
        }
      },
      create(context) {
        const options = context.options[0] || { allowImplicit: false, checkForEach: false };
        const sourceCode = context.getSourceCode();
        let funcInfo = {
          arrayMethodName: null,
          upper: null,
          codePath: null,
          hasReturn: false,
          shouldCheck: false,
          node: null
        };
        function checkLastSegment(node) {
          if (!funcInfo.shouldCheck) {
            return;
          }
          let messageId = null;
          if (funcInfo.arrayMethodName === "forEach") {
            if (options.checkForEach && node.type === "ArrowFunctionExpression" && node.expression) {
              messageId = "expectedNoReturnValue";
            }
          } else {
            if (node.body.type === "BlockStatement" && funcInfo.codePath.currentSegments.some(isReachable)) {
              messageId = funcInfo.hasReturn ? "expectedAtEnd" : "expectedInside";
            }
          }
          if (messageId) {
            const name = astUtils.getFunctionNameWithKind(node);
            context.report({
              node,
              loc: astUtils.getFunctionHeadLoc(node, sourceCode),
              messageId,
              data: { name, arrayMethodName: fullMethodName(funcInfo.arrayMethodName) }
            });
          }
        }
        return {
          // Stacks this function's information.
          onCodePathStart(codePath, node) {
            let methodName = null;
            if (TARGET_NODE_TYPE.test(node.type)) {
              methodName = getArrayMethodName(node);
            }
            funcInfo = {
              arrayMethodName: methodName,
              upper: funcInfo,
              codePath,
              hasReturn: false,
              shouldCheck: methodName && !node.async && !node.generator,
              node
            };
          },
          // Pops this function's information.
          onCodePathEnd() {
            funcInfo = funcInfo.upper;
          },
          // Checks the return statement is valid.
          ReturnStatement(node) {
            if (!funcInfo.shouldCheck) {
              return;
            }
            funcInfo.hasReturn = true;
            let messageId = null;
            if (funcInfo.arrayMethodName === "forEach") {
              if (options.checkForEach && node.argument) {
                messageId = "expectedNoReturnValue";
              }
            } else {
              if (!options.allowImplicit && !node.argument) {
                messageId = "expectedReturnValue";
              }
            }
            if (messageId) {
              context.report({
                node,
                messageId,
                data: {
                  name: astUtils.getFunctionNameWithKind(funcInfo.node),
                  arrayMethodName: fullMethodName(funcInfo.arrayMethodName)
                }
              });
            }
          },
          // Reports a given function if the last path is reachable.
          "FunctionExpression:exit": checkLastSegment,
          "ArrowFunctionExpression:exit": checkLastSegment
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/array-element-newline.js
var require_array_element_newline = __commonJS({
  "node_modules/eslint/lib/rules/array-element-newline.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce line breaks after each array element",
          recommended: false,
          url: "https://eslint.org/docs/rules/array-element-newline"
        },
        fixable: "whitespace",
        schema: {
          definitions: {
            basicConfig: {
              oneOf: [
                {
                  enum: ["always", "never", "consistent"]
                },
                {
                  type: "object",
                  properties: {
                    multiline: {
                      type: "boolean"
                    },
                    minItems: {
                      type: ["integer", "null"],
                      minimum: 0
                    }
                  },
                  additionalProperties: false
                }
              ]
            }
          },
          items: [
            {
              oneOf: [
                {
                  $ref: "#/definitions/basicConfig"
                },
                {
                  type: "object",
                  properties: {
                    ArrayExpression: {
                      $ref: "#/definitions/basicConfig"
                    },
                    ArrayPattern: {
                      $ref: "#/definitions/basicConfig"
                    }
                  },
                  additionalProperties: false,
                  minProperties: 1
                }
              ]
            }
          ]
        },
        messages: {
          unexpectedLineBreak: "There should be no linebreak here.",
          missingLineBreak: "There should be a linebreak after this element."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function normalizeOptionValue(providedOption) {
          let consistent = false;
          let multiline = false;
          let minItems;
          const option = providedOption || "always";
          if (!option || option === "always" || option.minItems === 0) {
            minItems = 0;
          } else if (option === "never") {
            minItems = Number.POSITIVE_INFINITY;
          } else if (option === "consistent") {
            consistent = true;
            minItems = Number.POSITIVE_INFINITY;
          } else {
            multiline = Boolean(option.multiline);
            minItems = option.minItems || Number.POSITIVE_INFINITY;
          }
          return { consistent, multiline, minItems };
        }
        function normalizeOptions(options) {
          if (options && (options.ArrayExpression || options.ArrayPattern)) {
            let expressionOptions, patternOptions;
            if (options.ArrayExpression) {
              expressionOptions = normalizeOptionValue(options.ArrayExpression);
            }
            if (options.ArrayPattern) {
              patternOptions = normalizeOptionValue(options.ArrayPattern);
            }
            return { ArrayExpression: expressionOptions, ArrayPattern: patternOptions };
          }
          const value2 = normalizeOptionValue(options);
          return { ArrayExpression: value2, ArrayPattern: value2 };
        }
        function reportNoLineBreak(token) {
          const tokenBefore = sourceCode.getTokenBefore(token, { includeComments: true });
          context.report({
            loc: {
              start: tokenBefore.loc.end,
              end: token.loc.start
            },
            messageId: "unexpectedLineBreak",
            fix(fixer) {
              if (astUtils.isCommentToken(tokenBefore)) {
                return null;
              }
              if (!astUtils.isTokenOnSameLine(tokenBefore, token)) {
                return fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], " ");
              }
              const twoTokensBefore = sourceCode.getTokenBefore(tokenBefore, { includeComments: true });
              if (astUtils.isCommentToken(twoTokensBefore)) {
                return null;
              }
              return fixer.replaceTextRange([twoTokensBefore.range[1], tokenBefore.range[0]], "");
            }
          });
        }
        function reportRequiredLineBreak(token) {
          const tokenBefore = sourceCode.getTokenBefore(token, { includeComments: true });
          context.report({
            loc: {
              start: tokenBefore.loc.end,
              end: token.loc.start
            },
            messageId: "missingLineBreak",
            fix(fixer) {
              return fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], "\n");
            }
          });
        }
        function check(node) {
          const elements = node.elements;
          const normalizedOptions = normalizeOptions(context.options[0]);
          const options = normalizedOptions[node.type];
          if (!options) {
            return;
          }
          let elementBreak = false;
          if (options.multiline) {
            elementBreak = elements.filter((element) => element !== null).some((element) => element.loc.start.line !== element.loc.end.line);
          }
          const linebreaksCount = node.elements.map((element, i) => {
            const previousElement = elements[i - 1];
            if (i === 0 || element === null || previousElement === null) {
              return false;
            }
            const commaToken = sourceCode.getFirstTokenBetween(previousElement, element, astUtils.isCommaToken);
            const lastTokenOfPreviousElement = sourceCode.getTokenBefore(commaToken);
            const firstTokenOfCurrentElement = sourceCode.getTokenAfter(commaToken);
            return !astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement);
          }).filter((isBreak) => isBreak === true).length;
          const needsLinebreaks = elements.length >= options.minItems || options.multiline && elementBreak || options.consistent && linebreaksCount > 0 && linebreaksCount < node.elements.length;
          elements.forEach((element, i) => {
            const previousElement = elements[i - 1];
            if (i === 0 || element === null || previousElement === null) {
              return;
            }
            const commaToken = sourceCode.getFirstTokenBetween(previousElement, element, astUtils.isCommaToken);
            const lastTokenOfPreviousElement = sourceCode.getTokenBefore(commaToken);
            const firstTokenOfCurrentElement = sourceCode.getTokenAfter(commaToken);
            if (needsLinebreaks) {
              if (astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement)) {
                reportRequiredLineBreak(firstTokenOfCurrentElement);
              }
            } else {
              if (!astUtils.isTokenOnSameLine(lastTokenOfPreviousElement, firstTokenOfCurrentElement)) {
                reportNoLineBreak(firstTokenOfCurrentElement);
              }
            }
          });
        }
        return {
          ArrayPattern: check,
          ArrayExpression: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/arrow-body-style.js
var require_arrow_body_style = __commonJS({
  "node_modules/eslint/lib/rules/arrow-body-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require braces around arrow function bodies",
          recommended: false,
          url: "https://eslint.org/docs/rules/arrow-body-style"
        },
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always", "never"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["as-needed"]
                },
                {
                  type: "object",
                  properties: {
                    requireReturnForObjectLiteral: { type: "boolean" }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        fixable: "code",
        messages: {
          unexpectedOtherBlock: "Unexpected block statement surrounding arrow body.",
          unexpectedEmptyBlock: "Unexpected block statement surrounding arrow body; put a value of `undefined` immediately after the `=>`.",
          unexpectedObjectBlock: "Unexpected block statement surrounding arrow body; parenthesize the returned value and move it immediately after the `=>`.",
          unexpectedSingleBlock: "Unexpected block statement surrounding arrow body; move the returned value immediately after the `=>`.",
          expectedBlock: "Expected block statement surrounding arrow body."
        }
      },
      create(context) {
        const options = context.options;
        const always = options[0] === "always";
        const asNeeded = !options[0] || options[0] === "as-needed";
        const never = options[0] === "never";
        const requireReturnForObjectLiteral = options[1] && options[1].requireReturnForObjectLiteral;
        const sourceCode = context.getSourceCode();
        let funcInfo = null;
        function hasASIProblem(token) {
          return token && token.type === "Punctuator" && /^[([/`+-]/u.test(token.value);
        }
        function findClosingParen(node) {
          let nodeToCheck = node;
          while (!astUtils.isParenthesised(sourceCode, nodeToCheck)) {
            nodeToCheck = nodeToCheck.parent;
          }
          return sourceCode.getTokenAfter(nodeToCheck);
        }
        function isInsideForLoopInitializer(node) {
          if (node && node.parent) {
            if (node.parent.type === "ForStatement" && node.parent.init === node) {
              return true;
            }
            return isInsideForLoopInitializer(node.parent);
          }
          return false;
        }
        function validate(node) {
          const arrowBody = node.body;
          if (arrowBody.type === "BlockStatement") {
            const blockBody = arrowBody.body;
            if (blockBody.length !== 1 && !never) {
              return;
            }
            if (asNeeded && requireReturnForObjectLiteral && blockBody[0].type === "ReturnStatement" && blockBody[0].argument && blockBody[0].argument.type === "ObjectExpression") {
              return;
            }
            if (never || asNeeded && blockBody[0].type === "ReturnStatement") {
              let messageId;
              if (blockBody.length === 0) {
                messageId = "unexpectedEmptyBlock";
              } else if (blockBody.length > 1) {
                messageId = "unexpectedOtherBlock";
              } else if (blockBody[0].argument === null) {
                messageId = "unexpectedSingleBlock";
              } else if (astUtils.isOpeningBraceToken(sourceCode.getFirstToken(blockBody[0], { skip: 1 }))) {
                messageId = "unexpectedObjectBlock";
              } else {
                messageId = "unexpectedSingleBlock";
              }
              context.report({
                node,
                loc: arrowBody.loc,
                messageId,
                fix(fixer) {
                  const fixes = [];
                  if (blockBody.length !== 1 || blockBody[0].type !== "ReturnStatement" || !blockBody[0].argument || hasASIProblem(sourceCode.getTokenAfter(arrowBody))) {
                    return fixes;
                  }
                  const openingBrace = sourceCode.getFirstToken(arrowBody);
                  const closingBrace = sourceCode.getLastToken(arrowBody);
                  const firstValueToken = sourceCode.getFirstToken(blockBody[0], 1);
                  const lastValueToken = sourceCode.getLastToken(blockBody[0]);
                  const commentsExist = sourceCode.commentsExistBetween(openingBrace, firstValueToken) || sourceCode.commentsExistBetween(lastValueToken, closingBrace);
                  if (commentsExist) {
                    fixes.push(
                      fixer.remove(openingBrace),
                      fixer.remove(closingBrace),
                      fixer.remove(sourceCode.getTokenAfter(openingBrace))
                      // return keyword
                    );
                  } else {
                    fixes.push(
                      fixer.removeRange([openingBrace.range[0], firstValueToken.range[0]]),
                      fixer.removeRange([lastValueToken.range[1], closingBrace.range[1]])
                    );
                  }
                  if (astUtils.isOpeningBraceToken(firstValueToken) || blockBody[0].argument.type === "SequenceExpression" || funcInfo.hasInOperator && isInsideForLoopInitializer(node)) {
                    if (!astUtils.isParenthesised(sourceCode, blockBody[0].argument)) {
                      fixes.push(
                        fixer.insertTextBefore(firstValueToken, "("),
                        fixer.insertTextAfter(lastValueToken, ")")
                      );
                    }
                  }
                  if (astUtils.isSemicolonToken(lastValueToken)) {
                    fixes.push(fixer.remove(lastValueToken));
                  }
                  return fixes;
                }
              });
            }
          } else {
            if (always || asNeeded && requireReturnForObjectLiteral && arrowBody.type === "ObjectExpression") {
              context.report({
                node,
                loc: arrowBody.loc,
                messageId: "expectedBlock",
                fix(fixer) {
                  const fixes = [];
                  const arrowToken = sourceCode.getTokenBefore(arrowBody, astUtils.isArrowToken);
                  const [firstTokenAfterArrow, secondTokenAfterArrow] = sourceCode.getTokensAfter(arrowToken, { count: 2 });
                  const lastToken = sourceCode.getLastToken(node);
                  let parenthesisedObjectLiteral = null;
                  if (astUtils.isOpeningParenToken(firstTokenAfterArrow) && astUtils.isOpeningBraceToken(secondTokenAfterArrow)) {
                    const braceNode = sourceCode.getNodeByRangeIndex(secondTokenAfterArrow.range[0]);
                    if (braceNode.type === "ObjectExpression") {
                      parenthesisedObjectLiteral = braceNode;
                    }
                  }
                  if (parenthesisedObjectLiteral) {
                    const openingParenToken = firstTokenAfterArrow;
                    const openingBraceToken = secondTokenAfterArrow;
                    if (astUtils.isTokenOnSameLine(openingParenToken, openingBraceToken)) {
                      fixes.push(fixer.replaceText(openingParenToken, "{return "));
                    } else {
                      fixes.push(
                        fixer.replaceText(openingParenToken, "{"),
                        fixer.insertTextBefore(openingBraceToken, "return ")
                      );
                    }
                    fixes.push(fixer.remove(findClosingParen(parenthesisedObjectLiteral)));
                    fixes.push(fixer.insertTextAfter(lastToken, "}"));
                  } else {
                    fixes.push(fixer.insertTextBefore(firstTokenAfterArrow, "{return "));
                    fixes.push(fixer.insertTextAfter(lastToken, "}"));
                  }
                  return fixes;
                }
              });
            }
          }
        }
        return {
          "BinaryExpression[operator='in']"() {
            let info = funcInfo;
            while (info) {
              info.hasInOperator = true;
              info = info.upper;
            }
          },
          ArrowFunctionExpression() {
            funcInfo = {
              upper: funcInfo,
              hasInOperator: false
            };
          },
          "ArrowFunctionExpression:exit"(node) {
            validate(node);
            funcInfo = funcInfo.upper;
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/arrow-parens.js
var require_arrow_parens = __commonJS({
  "node_modules/eslint/lib/rules/arrow-parens.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function hasBlockBody(node) {
      return node.body.type === "BlockStatement";
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require parentheses around arrow function arguments",
          recommended: false,
          url: "https://eslint.org/docs/rules/arrow-parens"
        },
        fixable: "code",
        schema: [
          {
            enum: ["always", "as-needed"]
          },
          {
            type: "object",
            properties: {
              requireForBlockBody: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedParens: "Unexpected parentheses around single function argument.",
          expectedParens: "Expected parentheses around arrow function argument.",
          unexpectedParensInline: "Unexpected parentheses around single function argument having a body with no curly braces.",
          expectedParensBlock: "Expected parentheses around arrow function argument having a body with curly braces."
        }
      },
      create(context) {
        const asNeeded = context.options[0] === "as-needed";
        const requireForBlockBody = asNeeded && context.options[1] && context.options[1].requireForBlockBody === true;
        const sourceCode = context.getSourceCode();
        function findOpeningParenOfParams(node) {
          const tokenBeforeParams = sourceCode.getTokenBefore(node.params[0]);
          if (tokenBeforeParams && astUtils.isOpeningParenToken(tokenBeforeParams) && node.range[0] <= tokenBeforeParams.range[0]) {
            return tokenBeforeParams;
          }
          return null;
        }
        function getClosingParenOfParams(node) {
          return sourceCode.getTokenAfter(node.params[0], astUtils.isClosingParenToken);
        }
        function hasCommentsInParensOfParams(node, openingParen) {
          return sourceCode.commentsExistBetween(openingParen, getClosingParenOfParams(node));
        }
        function hasUnexpectedTokensBeforeOpeningParen(node, openingParen) {
          const expectedCount = node.async ? 1 : 0;
          return sourceCode.getFirstToken(node, { skip: expectedCount }) !== openingParen;
        }
        return {
          "ArrowFunctionExpression[params.length=1]"(node) {
            const shouldHaveParens = !asNeeded || requireForBlockBody && hasBlockBody(node);
            const openingParen = findOpeningParenOfParams(node);
            const hasParens = openingParen !== null;
            const [param] = node.params;
            if (shouldHaveParens && !hasParens) {
              context.report({
                node,
                messageId: requireForBlockBody ? "expectedParensBlock" : "expectedParens",
                loc: param.loc,
                *fix(fixer) {
                  yield fixer.insertTextBefore(param, "(");
                  yield fixer.insertTextAfter(param, ")");
                }
              });
            }
            if (!shouldHaveParens && hasParens && param.type === "Identifier" && !param.typeAnnotation && !node.returnType && !hasCommentsInParensOfParams(node, openingParen) && !hasUnexpectedTokensBeforeOpeningParen(node, openingParen)) {
              context.report({
                node,
                messageId: requireForBlockBody ? "unexpectedParensInline" : "unexpectedParens",
                loc: param.loc,
                *fix(fixer) {
                  const tokenBeforeOpeningParen = sourceCode.getTokenBefore(openingParen);
                  const closingParen = getClosingParenOfParams(node);
                  if (tokenBeforeOpeningParen && tokenBeforeOpeningParen.range[1] === openingParen.range[0] && !astUtils.canTokensBeAdjacent(tokenBeforeOpeningParen, sourceCode.getFirstToken(param))) {
                    yield fixer.insertTextBefore(openingParen, " ");
                  }
                  yield fixer.removeRange([openingParen.range[0], param.range[0]]);
                  yield fixer.removeRange([param.range[1], closingParen.range[1]]);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/arrow-spacing.js
var require_arrow_spacing = __commonJS({
  "node_modules/eslint/lib/rules/arrow-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before and after the arrow in arrow functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/arrow-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              before: {
                type: "boolean",
                default: true
              },
              after: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expectedBefore: "Missing space before =>.",
          unexpectedBefore: "Unexpected space before =>.",
          expectedAfter: "Missing space after =>.",
          unexpectedAfter: "Unexpected space after =>."
        }
      },
      create(context) {
        const rule = Object.assign({}, context.options[0]);
        rule.before = rule.before !== false;
        rule.after = rule.after !== false;
        const sourceCode = context.getSourceCode();
        function getTokens(node) {
          const arrow = sourceCode.getTokenBefore(node.body, astUtils.isArrowToken);
          return {
            before: sourceCode.getTokenBefore(arrow),
            arrow,
            after: sourceCode.getTokenAfter(arrow)
          };
        }
        function countSpaces(tokens) {
          const before = tokens.arrow.range[0] - tokens.before.range[1];
          const after = tokens.after.range[0] - tokens.arrow.range[1];
          return { before, after };
        }
        function spaces(node) {
          const tokens = getTokens(node);
          const countSpace = countSpaces(tokens);
          if (rule.before) {
            if (countSpace.before === 0) {
              context.report({
                node: tokens.before,
                messageId: "expectedBefore",
                fix(fixer) {
                  return fixer.insertTextBefore(tokens.arrow, " ");
                }
              });
            }
          } else {
            if (countSpace.before > 0) {
              context.report({
                node: tokens.before,
                messageId: "unexpectedBefore",
                fix(fixer) {
                  return fixer.removeRange([tokens.before.range[1], tokens.arrow.range[0]]);
                }
              });
            }
          }
          if (rule.after) {
            if (countSpace.after === 0) {
              context.report({
                node: tokens.after,
                messageId: "expectedAfter",
                fix(fixer) {
                  return fixer.insertTextAfter(tokens.arrow, " ");
                }
              });
            }
          } else {
            if (countSpace.after > 0) {
              context.report({
                node: tokens.after,
                messageId: "unexpectedAfter",
                fix(fixer) {
                  return fixer.removeRange([tokens.arrow.range[1], tokens.after.range[0]]);
                }
              });
            }
          }
        }
        return {
          ArrowFunctionExpression: spaces
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/block-scoped-var.js
var require_block_scoped_var = __commonJS({
  "node_modules/eslint/lib/rules/block-scoped-var.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce the use of variables within the scope they are defined",
          recommended: false,
          url: "https://eslint.org/docs/rules/block-scoped-var"
        },
        schema: [],
        messages: {
          outOfScope: "'{{name}}' used outside of binding context."
        }
      },
      create(context) {
        let stack = [];
        function enterScope(node) {
          stack.push(node.range);
        }
        function exitScope() {
          stack.pop();
        }
        function report(reference) {
          const identifier3 = reference.identifier;
          context.report({ node: identifier3, messageId: "outOfScope", data: { name: identifier3.name } });
        }
        function checkForVariables(node) {
          if (node.kind !== "var") {
            return;
          }
          const scopeRange = stack[stack.length - 1];
          function isOutsideOfScope(reference) {
            const idRange = reference.identifier.range;
            return idRange[0] < scopeRange[0] || idRange[1] > scopeRange[1];
          }
          const variables = context.getDeclaredVariables(node);
          for (let i = 0; i < variables.length; ++i) {
            variables[i].references.filter(isOutsideOfScope).forEach(report);
          }
        }
        return {
          Program(node) {
            stack = [node.range];
          },
          // Manages scopes.
          BlockStatement: enterScope,
          "BlockStatement:exit": exitScope,
          ForStatement: enterScope,
          "ForStatement:exit": exitScope,
          ForInStatement: enterScope,
          "ForInStatement:exit": exitScope,
          ForOfStatement: enterScope,
          "ForOfStatement:exit": exitScope,
          SwitchStatement: enterScope,
          "SwitchStatement:exit": exitScope,
          CatchClause: enterScope,
          "CatchClause:exit": exitScope,
          StaticBlock: enterScope,
          "StaticBlock:exit": exitScope,
          // Finds and reports references which are outside of valid scope.
          VariableDeclaration: checkForVariables
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/block-spacing.js
var require_block_spacing = __commonJS({
  "node_modules/eslint/lib/rules/block-spacing.js"(exports, module2) {
    "use strict";
    var util = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow or enforce spaces inside of blocks after opening block and before closing block",
          recommended: false,
          url: "https://eslint.org/docs/rules/block-spacing"
        },
        fixable: "whitespace",
        schema: [
          { enum: ["always", "never"] }
        ],
        messages: {
          missing: "Requires a space {{location}} '{{token}}'.",
          extra: "Unexpected space(s) {{location}} '{{token}}'."
        }
      },
      create(context) {
        const always = context.options[0] !== "never", messageId = always ? "missing" : "extra", sourceCode = context.getSourceCode();
        function getOpenBrace(node) {
          if (node.type === "SwitchStatement") {
            if (node.cases.length > 0) {
              return sourceCode.getTokenBefore(node.cases[0]);
            }
            return sourceCode.getLastToken(node, 1);
          }
          if (node.type === "StaticBlock") {
            return sourceCode.getFirstToken(node, { skip: 1 });
          }
          return sourceCode.getFirstToken(node);
        }
        function isValid(left, right) {
          return !util.isTokenOnSameLine(left, right) || sourceCode.isSpaceBetweenTokens(left, right) === always;
        }
        function checkSpacingInsideBraces(node) {
          const openBrace = getOpenBrace(node);
          const closeBrace = sourceCode.getLastToken(node);
          const firstToken = sourceCode.getTokenAfter(openBrace, { includeComments: true });
          const lastToken = sourceCode.getTokenBefore(closeBrace, { includeComments: true });
          if (openBrace.type !== "Punctuator" || openBrace.value !== "{" || closeBrace.type !== "Punctuator" || closeBrace.value !== "}" || firstToken === closeBrace) {
            return;
          }
          if (!always && firstToken.type === "Line") {
            return;
          }
          if (!isValid(openBrace, firstToken)) {
            let loc = openBrace.loc;
            if (messageId === "extra") {
              loc = {
                start: openBrace.loc.end,
                end: firstToken.loc.start
              };
            }
            context.report({
              node,
              loc,
              messageId,
              data: {
                location: "after",
                token: openBrace.value
              },
              fix(fixer) {
                if (always) {
                  return fixer.insertTextBefore(firstToken, " ");
                }
                return fixer.removeRange([openBrace.range[1], firstToken.range[0]]);
              }
            });
          }
          if (!isValid(lastToken, closeBrace)) {
            let loc = closeBrace.loc;
            if (messageId === "extra") {
              loc = {
                start: lastToken.loc.end,
                end: closeBrace.loc.start
              };
            }
            context.report({
              node,
              loc,
              messageId,
              data: {
                location: "before",
                token: closeBrace.value
              },
              fix(fixer) {
                if (always) {
                  return fixer.insertTextAfter(lastToken, " ");
                }
                return fixer.removeRange([lastToken.range[1], closeBrace.range[0]]);
              }
            });
          }
        }
        return {
          BlockStatement: checkSpacingInsideBraces,
          StaticBlock: checkSpacingInsideBraces,
          SwitchStatement: checkSpacingInsideBraces
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/brace-style.js
var require_brace_style = __commonJS({
  "node_modules/eslint/lib/rules/brace-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent brace style for blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/brace-style"
        },
        schema: [
          {
            enum: ["1tbs", "stroustrup", "allman"]
          },
          {
            type: "object",
            properties: {
              allowSingleLine: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "whitespace",
        messages: {
          nextLineOpen: "Opening curly brace does not appear on the same line as controlling statement.",
          sameLineOpen: "Opening curly brace appears on the same line as controlling statement.",
          blockSameLine: "Statement inside of curly braces should be on next line.",
          nextLineClose: "Closing curly brace does not appear on the same line as the subsequent block.",
          singleLineClose: "Closing curly brace should be on the same line as opening curly brace or on the line after the previous block.",
          sameLineClose: "Closing curly brace appears on the same line as the subsequent block."
        }
      },
      create(context) {
        const style = context.options[0] || "1tbs", params = context.options[1] || {}, sourceCode = context.getSourceCode();
        function removeNewlineBetween(firstToken, secondToken) {
          const textRange = [firstToken.range[1], secondToken.range[0]];
          const textBetween = sourceCode.text.slice(textRange[0], textRange[1]);
          if (textBetween.trim()) {
            return null;
          }
          return (fixer) => fixer.replaceTextRange(textRange, " ");
        }
        function validateCurlyPair(openingCurly, closingCurly) {
          const tokenBeforeOpeningCurly = sourceCode.getTokenBefore(openingCurly);
          const tokenAfterOpeningCurly = sourceCode.getTokenAfter(openingCurly);
          const tokenBeforeClosingCurly = sourceCode.getTokenBefore(closingCurly);
          const singleLineException = params.allowSingleLine && astUtils.isTokenOnSameLine(openingCurly, closingCurly);
          if (style !== "allman" && !astUtils.isTokenOnSameLine(tokenBeforeOpeningCurly, openingCurly)) {
            context.report({
              node: openingCurly,
              messageId: "nextLineOpen",
              fix: removeNewlineBetween(tokenBeforeOpeningCurly, openingCurly)
            });
          }
          if (style === "allman" && astUtils.isTokenOnSameLine(tokenBeforeOpeningCurly, openingCurly) && !singleLineException) {
            context.report({
              node: openingCurly,
              messageId: "sameLineOpen",
              fix: (fixer) => fixer.insertTextBefore(openingCurly, "\n")
            });
          }
          if (astUtils.isTokenOnSameLine(openingCurly, tokenAfterOpeningCurly) && tokenAfterOpeningCurly !== closingCurly && !singleLineException) {
            context.report({
              node: openingCurly,
              messageId: "blockSameLine",
              fix: (fixer) => fixer.insertTextAfter(openingCurly, "\n")
            });
          }
          if (tokenBeforeClosingCurly !== openingCurly && !singleLineException && astUtils.isTokenOnSameLine(tokenBeforeClosingCurly, closingCurly)) {
            context.report({
              node: closingCurly,
              messageId: "singleLineClose",
              fix: (fixer) => fixer.insertTextBefore(closingCurly, "\n")
            });
          }
        }
        function validateCurlyBeforeKeyword(curlyToken) {
          const keywordToken = sourceCode.getTokenAfter(curlyToken);
          if (style === "1tbs" && !astUtils.isTokenOnSameLine(curlyToken, keywordToken)) {
            context.report({
              node: curlyToken,
              messageId: "nextLineClose",
              fix: removeNewlineBetween(curlyToken, keywordToken)
            });
          }
          if (style !== "1tbs" && astUtils.isTokenOnSameLine(curlyToken, keywordToken)) {
            context.report({
              node: curlyToken,
              messageId: "sameLineClose",
              fix: (fixer) => fixer.insertTextAfter(curlyToken, "\n")
            });
          }
        }
        return {
          BlockStatement(node) {
            if (!astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
              validateCurlyPair(sourceCode.getFirstToken(node), sourceCode.getLastToken(node));
            }
          },
          StaticBlock(node) {
            validateCurlyPair(
              sourceCode.getFirstToken(node, { skip: 1 }),
              // skip the `static` token
              sourceCode.getLastToken(node)
            );
          },
          ClassBody(node) {
            validateCurlyPair(sourceCode.getFirstToken(node), sourceCode.getLastToken(node));
          },
          SwitchStatement(node) {
            const closingCurly = sourceCode.getLastToken(node);
            const openingCurly = sourceCode.getTokenBefore(node.cases.length ? node.cases[0] : closingCurly);
            validateCurlyPair(openingCurly, closingCurly);
          },
          IfStatement(node) {
            if (node.consequent.type === "BlockStatement" && node.alternate) {
              validateCurlyBeforeKeyword(sourceCode.getLastToken(node.consequent));
            }
          },
          TryStatement(node) {
            validateCurlyBeforeKeyword(sourceCode.getLastToken(node.block));
            if (node.handler && node.finalizer) {
              validateCurlyBeforeKeyword(sourceCode.getLastToken(node.handler.body));
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/callback-return.js
var require_callback_return = __commonJS({
  "node_modules/eslint/lib/rules/callback-return.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Require `return` statements after callbacks",
          recommended: false,
          url: "https://eslint.org/docs/rules/callback-return"
        },
        schema: [{
          type: "array",
          items: { type: "string" }
        }],
        messages: {
          missingReturn: "Expected return with your callback function."
        }
      },
      create(context) {
        const callbacks = context.options[0] || ["callback", "cb", "next"], sourceCode = context.getSourceCode();
        function findClosestParentOfType(node, types) {
          if (!node.parent) {
            return null;
          }
          if (!types.includes(node.parent.type)) {
            return findClosestParentOfType(node.parent, types);
          }
          return node.parent;
        }
        function containsOnlyIdentifiers(node) {
          if (node.type === "Identifier") {
            return true;
          }
          if (node.type === "MemberExpression") {
            if (node.object.type === "Identifier") {
              return true;
            }
            if (node.object.type === "MemberExpression") {
              return containsOnlyIdentifiers(node.object);
            }
          }
          return false;
        }
        function isCallback(node) {
          return containsOnlyIdentifiers(node.callee) && callbacks.includes(sourceCode.getText(node.callee));
        }
        function isCallbackExpression(node, parentNode) {
          if (!parentNode || parentNode.type !== "ExpressionStatement") {
            return false;
          }
          if (parentNode.expression === node) {
            return true;
          }
          if (parentNode.expression.type === "BinaryExpression" || parentNode.expression.type === "LogicalExpression") {
            if (parentNode.expression.right === node) {
              return true;
            }
          }
          return false;
        }
        return {
          CallExpression(node) {
            if (!isCallback(node)) {
              return;
            }
            const closestBlock = findClosestParentOfType(node, ["BlockStatement", "ReturnStatement", "ArrowFunctionExpression"]) || {};
            if (closestBlock.type === "ReturnStatement") {
              return;
            }
            if (closestBlock.type === "ArrowFunctionExpression") {
              return;
            }
            if (closestBlock.type === "BlockStatement") {
              const lastItem = closestBlock.body[closestBlock.body.length - 1];
              if (isCallbackExpression(node, lastItem)) {
                const parentType = closestBlock.parent.type;
                if (parentType === "FunctionExpression" || parentType === "FunctionDeclaration" || parentType === "ArrowFunctionExpression") {
                  return;
                }
              }
              if (lastItem.type === "ReturnStatement") {
                if (isCallbackExpression(node, closestBlock.body[closestBlock.body.length - 2])) {
                  return;
                }
              }
            }
            if (findClosestParentOfType(node, ["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"])) {
              context.report({ node, messageId: "missingReturn" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/camelcase.js
var require_camelcase = __commonJS({
  "node_modules/eslint/lib/rules/camelcase.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce camelcase naming convention",
          recommended: false,
          url: "https://eslint.org/docs/rules/camelcase"
        },
        schema: [
          {
            type: "object",
            properties: {
              ignoreDestructuring: {
                type: "boolean",
                default: false
              },
              ignoreImports: {
                type: "boolean",
                default: false
              },
              ignoreGlobals: {
                type: "boolean",
                default: false
              },
              properties: {
                enum: ["always", "never"]
              },
              allow: {
                type: "array",
                items: [
                  {
                    type: "string"
                  }
                ],
                minItems: 0,
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          notCamelCase: "Identifier '{{name}}' is not in camel case.",
          notCamelCasePrivate: "#{{name}} is not in camel case."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const properties = options.properties === "never" ? "never" : "always";
        const ignoreDestructuring = options.ignoreDestructuring;
        const ignoreImports = options.ignoreImports;
        const ignoreGlobals = options.ignoreGlobals;
        const allow = options.allow || [];
        const reported = /* @__PURE__ */ new Set();
        function isUnderscored(name) {
          const nameBody = name.replace(/^_+|_+$/gu, "");
          return nameBody.includes("_") && nameBody !== nameBody.toUpperCase();
        }
        function isAllowed(name) {
          return allow.some(
            (entry) => name === entry || name.match(new RegExp(entry, "u"))
          );
        }
        function isGoodName(name) {
          return !isUnderscored(name) || isAllowed(name);
        }
        function isAssignmentTarget(node) {
          const parent = node.parent;
          switch (parent.type) {
            case "AssignmentExpression":
            case "AssignmentPattern":
              return parent.left === node;
            case "Property":
              return parent.parent.type === "ObjectPattern" && parent.value === node;
            case "ArrayPattern":
            case "RestElement":
              return true;
            default:
              return false;
          }
        }
        function equalsToOriginalName(node) {
          const localName = node.name;
          const valueNode = node.parent.type === "AssignmentPattern" ? node.parent : node;
          const parent = valueNode.parent;
          switch (parent.type) {
            case "Property":
              return (parent.parent.type === "ObjectPattern" || parent.parent.type === "ObjectExpression") && parent.value === valueNode && !parent.computed && parent.key.type === "Identifier" && parent.key.name === localName;
            case "ImportSpecifier":
              return parent.local === node && astUtils.getModuleExportName(parent.imported) === localName;
            default:
              return false;
          }
        }
        function report(node) {
          if (reported.has(node.range[0])) {
            return;
          }
          reported.add(node.range[0]);
          context.report({
            node,
            messageId: node.type === "PrivateIdentifier" ? "notCamelCasePrivate" : "notCamelCase",
            data: { name: node.name }
          });
        }
        function reportReferenceId(node) {
          if (node.parent.type === "CallExpression" || node.parent.type === "NewExpression") {
            return;
          }
          if (node.parent.type === "AssignmentPattern" && node.parent.right === node) {
            return;
          }
          if (ignoreDestructuring && equalsToOriginalName(node)) {
            return;
          }
          report(node);
        }
        return {
          // Report camelcase of global variable references ------------------
          Program() {
            const scope = context.getScope();
            if (!ignoreGlobals) {
              for (const variable of scope.variables) {
                if (variable.identifiers.length > 0 || isGoodName(variable.name)) {
                  continue;
                }
                for (const reference of variable.references) {
                  reportReferenceId(reference.identifier);
                }
              }
            }
            for (const reference of scope.through) {
              const id = reference.identifier;
              if (isGoodName(id.name)) {
                continue;
              }
              reportReferenceId(id);
            }
          },
          // Report camelcase of declared variables --------------------------
          [[
            "VariableDeclaration",
            "FunctionDeclaration",
            "FunctionExpression",
            "ArrowFunctionExpression",
            "ClassDeclaration",
            "ClassExpression",
            "CatchClause"
          ]](node) {
            for (const variable of context.getDeclaredVariables(node)) {
              if (isGoodName(variable.name)) {
                continue;
              }
              const id = variable.identifiers[0];
              if (!(ignoreDestructuring && equalsToOriginalName(id))) {
                report(id);
              }
              for (const reference of variable.references) {
                if (reference.init) {
                  continue;
                }
                reportReferenceId(reference.identifier);
              }
            }
          },
          // Report camelcase in properties ----------------------------------
          [[
            "ObjectExpression > Property[computed!=true] > Identifier.key",
            "MethodDefinition[computed!=true] > Identifier.key",
            "PropertyDefinition[computed!=true] > Identifier.key",
            "MethodDefinition > PrivateIdentifier.key",
            "PropertyDefinition > PrivateIdentifier.key"
          ]](node) {
            if (properties === "never" || isGoodName(node.name)) {
              return;
            }
            report(node);
          },
          "MemberExpression[computed!=true] > Identifier.property"(node) {
            if (properties === "never" || !isAssignmentTarget(node.parent) || // ← ignore read-only references.
            isGoodName(node.name)) {
              return;
            }
            report(node);
          },
          // Report camelcase in import --------------------------------------
          ImportDeclaration(node) {
            for (const variable of context.getDeclaredVariables(node)) {
              if (isGoodName(variable.name)) {
                continue;
              }
              const id = variable.identifiers[0];
              if (!(ignoreImports && equalsToOriginalName(id))) {
                report(id);
              }
              for (const reference of variable.references) {
                reportReferenceId(reference.identifier);
              }
            }
          },
          // Report camelcase in re-export -----------------------------------
          [[
            "ExportAllDeclaration > Identifier.exported",
            "ExportSpecifier > Identifier.exported"
          ]](node) {
            if (isGoodName(node.name)) {
              return;
            }
            report(node);
          },
          // Report camelcase in labels --------------------------------------
          [[
            "LabeledStatement > Identifier.label",
            /*
             * For backward compatibility, report references as well.
             * It looks unnecessary because declarations are reported.
             */
            "BreakStatement > Identifier.label",
            "ContinueStatement > Identifier.label"
          ]](node) {
            if (isGoodName(node.name)) {
              return;
            }
            report(node);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/utils/patterns/letters.js
var require_letters = __commonJS({
  "node_modules/eslint/lib/rules/utils/patterns/letters.js"(exports, module2) {
    "use strict";
    module2.exports = /[A-Za-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B2\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF40\uDF42-\uDF49\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDE00-\uDE11\uDE13-\uDE2B\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDE00-\uDE2F\uDE44\uDE80-\uDEAA]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]/u;
  }
});

// node_modules/eslint/lib/rules/capitalized-comments.js
var require_capitalized_comments = __commonJS({
  "node_modules/eslint/lib/rules/capitalized-comments.js"(exports, module2) {
    "use strict";
    var LETTER_PATTERN = require_letters();
    var astUtils = require_ast_utils2();
    var DEFAULT_IGNORE_PATTERN = astUtils.COMMENTS_IGNORE_PATTERN;
    var WHITESPACE = /\s/gu;
    var MAYBE_URL = /^\s*[^:/?#\s]+:\/\/[^?#]/u;
    var SCHEMA_BODY = {
      type: "object",
      properties: {
        ignorePattern: {
          type: "string"
        },
        ignoreInlineComments: {
          type: "boolean"
        },
        ignoreConsecutiveComments: {
          type: "boolean"
        }
      },
      additionalProperties: false
    };
    var DEFAULTS = {
      ignorePattern: "",
      ignoreInlineComments: false,
      ignoreConsecutiveComments: false
    };
    function getNormalizedOptions(rawOptions, which) {
      return Object.assign({}, DEFAULTS, rawOptions[which] || rawOptions);
    }
    function getAllNormalizedOptions(rawOptions = {}) {
      return {
        Line: getNormalizedOptions(rawOptions, "line"),
        Block: getNormalizedOptions(rawOptions, "block")
      };
    }
    function createRegExpForIgnorePatterns(normalizedOptions) {
      Object.keys(normalizedOptions).forEach((key) => {
        const ignorePatternStr = normalizedOptions[key].ignorePattern;
        if (ignorePatternStr) {
          const regExp = RegExp(`^\\s*(?:${ignorePatternStr})`, "u");
          normalizedOptions[key].ignorePatternRegExp = regExp;
        }
      });
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce or disallow capitalization of the first letter of a comment",
          recommended: false,
          url: "https://eslint.org/docs/rules/capitalized-comments"
        },
        fixable: "code",
        schema: [
          { enum: ["always", "never"] },
          {
            oneOf: [
              SCHEMA_BODY,
              {
                type: "object",
                properties: {
                  line: SCHEMA_BODY,
                  block: SCHEMA_BODY
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          unexpectedLowercaseComment: "Comments should not begin with a lowercase character.",
          unexpectedUppercaseComment: "Comments should not begin with an uppercase character."
        }
      },
      create(context) {
        const capitalize = context.options[0] || "always", normalizedOptions = getAllNormalizedOptions(context.options[1]), sourceCode = context.getSourceCode();
        createRegExpForIgnorePatterns(normalizedOptions);
        function isInlineComment(comment) {
          const previousToken = sourceCode.getTokenBefore(comment, { includeComments: true }), nextToken = sourceCode.getTokenAfter(comment, { includeComments: true });
          return Boolean(
            previousToken && nextToken && comment.loc.start.line === previousToken.loc.end.line && comment.loc.end.line === nextToken.loc.start.line
          );
        }
        function isConsecutiveComment(comment) {
          const previousTokenOrComment = sourceCode.getTokenBefore(comment, { includeComments: true });
          return Boolean(
            previousTokenOrComment && ["Block", "Line"].includes(previousTokenOrComment.type)
          );
        }
        function isCommentValid(comment, options) {
          if (DEFAULT_IGNORE_PATTERN.test(comment.value)) {
            return true;
          }
          const commentWithoutAsterisks = comment.value.replace(/\*/gu, "");
          if (options.ignorePatternRegExp && options.ignorePatternRegExp.test(commentWithoutAsterisks)) {
            return true;
          }
          if (options.ignoreInlineComments && isInlineComment(comment)) {
            return true;
          }
          if (options.ignoreConsecutiveComments && isConsecutiveComment(comment)) {
            return true;
          }
          if (MAYBE_URL.test(commentWithoutAsterisks)) {
            return true;
          }
          const commentWordCharsOnly = commentWithoutAsterisks.replace(WHITESPACE, "");
          if (commentWordCharsOnly.length === 0) {
            return true;
          }
          const firstWordChar = commentWordCharsOnly[0];
          if (!LETTER_PATTERN.test(firstWordChar)) {
            return true;
          }
          const isUppercase = firstWordChar !== firstWordChar.toLocaleLowerCase(), isLowercase = firstWordChar !== firstWordChar.toLocaleUpperCase();
          if (capitalize === "always" && isLowercase) {
            return false;
          }
          if (capitalize === "never" && isUppercase) {
            return false;
          }
          return true;
        }
        function processComment(comment) {
          const options = normalizedOptions[comment.type], commentValid = isCommentValid(comment, options);
          if (!commentValid) {
            const messageId = capitalize === "always" ? "unexpectedLowercaseComment" : "unexpectedUppercaseComment";
            context.report({
              node: null,
              // Intentionally using loc instead
              loc: comment.loc,
              messageId,
              fix(fixer) {
                const match = comment.value.match(LETTER_PATTERN);
                return fixer.replaceTextRange(
                  // Offset match.index by 2 to account for the first 2 characters that start the comment (// or /*)
                  [comment.range[0] + match.index + 2, comment.range[0] + match.index + 3],
                  capitalize === "always" ? match[0].toLocaleUpperCase() : match[0].toLocaleLowerCase()
                );
              }
            });
          }
        }
        return {
          Program() {
            const comments = sourceCode.getAllComments();
            comments.filter((token) => token.type !== "Shebang").forEach(processComment);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/class-methods-use-this.js
var require_class_methods_use_this = __commonJS({
  "node_modules/eslint/lib/rules/class-methods-use-this.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce that class methods utilize `this`",
          recommended: false,
          url: "https://eslint.org/docs/rules/class-methods-use-this"
        },
        schema: [{
          type: "object",
          properties: {
            exceptMethods: {
              type: "array",
              items: {
                type: "string"
              }
            },
            enforceForClassFields: {
              type: "boolean",
              default: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          missingThis: "Expected 'this' to be used by class {{name}}."
        }
      },
      create(context) {
        const config = Object.assign({}, context.options[0]);
        const enforceForClassFields = config.enforceForClassFields !== false;
        const exceptMethods = new Set(config.exceptMethods || []);
        const stack = [];
        function pushContext() {
          stack.push(false);
        }
        function popContext() {
          return stack.pop();
        }
        function enterFunction() {
          pushContext();
        }
        function isInstanceMethod(node) {
          switch (node.type) {
            case "MethodDefinition":
              return !node.static && node.kind !== "constructor";
            case "PropertyDefinition":
              return !node.static && enforceForClassFields;
            default:
              return false;
          }
        }
        function isIncludedInstanceMethod(node) {
          if (isInstanceMethod(node)) {
            if (node.computed) {
              return true;
            }
            const hashIfNeeded = node.key.type === "PrivateIdentifier" ? "#" : "";
            const name = node.key.type === "Literal" ? astUtils.getStaticStringValue(node.key) : node.key.name || "";
            return !exceptMethods.has(hashIfNeeded + name);
          }
          return false;
        }
        function exitFunction(node) {
          const methodUsesThis = popContext();
          if (isIncludedInstanceMethod(node.parent) && !methodUsesThis) {
            context.report({
              node,
              loc: astUtils.getFunctionHeadLoc(node, context.getSourceCode()),
              messageId: "missingThis",
              data: {
                name: astUtils.getFunctionNameWithKind(node)
              }
            });
          }
        }
        function markThisUsed() {
          if (stack.length) {
            stack[stack.length - 1] = true;
          }
        }
        return {
          FunctionDeclaration: enterFunction,
          "FunctionDeclaration:exit": exitFunction,
          FunctionExpression: enterFunction,
          "FunctionExpression:exit": exitFunction,
          /*
           * Class field value are implicit functions.
           */
          "PropertyDefinition > *.key:exit": pushContext,
          "PropertyDefinition:exit": popContext,
          /*
           * Class static blocks are implicit functions. They aren't required to use `this`,
           * but we have to push context so that it captures any use of `this` in the static block
           * separately from enclosing contexts, because static blocks have their own `this` and it
           * shouldn't count as used `this` in enclosing contexts.
           */
          StaticBlock: pushContext,
          "StaticBlock:exit": popContext,
          ThisExpression: markThisUsed,
          Super: markThisUsed,
          ...enforceForClassFields && {
            "PropertyDefinition > ArrowFunctionExpression.value": enterFunction,
            "PropertyDefinition > ArrowFunctionExpression.value:exit": exitFunction
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/comma-dangle.js
var require_comma_dangle = __commonJS({
  "node_modules/eslint/lib/rules/comma-dangle.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var DEFAULT_OPTIONS = Object.freeze({
      arrays: "never",
      objects: "never",
      imports: "never",
      exports: "never",
      functions: "never"
    });
    function isTrailingCommaAllowed(lastItem) {
      return !(lastItem.type === "RestElement" || lastItem.type === "RestProperty" || lastItem.type === "ExperimentalRestProperty");
    }
    function normalizeOptions(optionValue, ecmaVersion) {
      if (typeof optionValue === "string") {
        return {
          arrays: optionValue,
          objects: optionValue,
          imports: optionValue,
          exports: optionValue,
          functions: ecmaVersion < 2017 ? "ignore" : optionValue
        };
      }
      if (typeof optionValue === "object" && optionValue !== null) {
        return {
          arrays: optionValue.arrays || DEFAULT_OPTIONS.arrays,
          objects: optionValue.objects || DEFAULT_OPTIONS.objects,
          imports: optionValue.imports || DEFAULT_OPTIONS.imports,
          exports: optionValue.exports || DEFAULT_OPTIONS.exports,
          functions: optionValue.functions || DEFAULT_OPTIONS.functions
        };
      }
      return DEFAULT_OPTIONS;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow trailing commas",
          recommended: false,
          url: "https://eslint.org/docs/rules/comma-dangle"
        },
        fixable: "code",
        schema: {
          definitions: {
            value: {
              enum: [
                "always-multiline",
                "always",
                "never",
                "only-multiline"
              ]
            },
            valueWithIgnore: {
              enum: [
                "always-multiline",
                "always",
                "ignore",
                "never",
                "only-multiline"
              ]
            }
          },
          type: "array",
          items: [
            {
              oneOf: [
                {
                  $ref: "#/definitions/value"
                },
                {
                  type: "object",
                  properties: {
                    arrays: { $ref: "#/definitions/valueWithIgnore" },
                    objects: { $ref: "#/definitions/valueWithIgnore" },
                    imports: { $ref: "#/definitions/valueWithIgnore" },
                    exports: { $ref: "#/definitions/valueWithIgnore" },
                    functions: { $ref: "#/definitions/valueWithIgnore" }
                  },
                  additionalProperties: false
                }
              ]
            }
          ],
          additionalItems: false
        },
        messages: {
          unexpected: "Unexpected trailing comma.",
          missing: "Missing trailing comma."
        }
      },
      create(context) {
        const options = normalizeOptions(context.options[0], context.languageOptions.ecmaVersion);
        const sourceCode = context.getSourceCode();
        function getLastItem(node) {
          function last2(array) {
            return array[array.length - 1];
          }
          switch (node.type) {
            case "ObjectExpression":
            case "ObjectPattern":
              return last2(node.properties);
            case "ArrayExpression":
            case "ArrayPattern":
              return last2(node.elements);
            case "ImportDeclaration":
            case "ExportNamedDeclaration":
              return last2(node.specifiers);
            case "FunctionDeclaration":
            case "FunctionExpression":
            case "ArrowFunctionExpression":
              return last2(node.params);
            case "CallExpression":
            case "NewExpression":
              return last2(node.arguments);
            default:
              return null;
          }
        }
        function getTrailingToken(node, lastItem) {
          switch (node.type) {
            case "ObjectExpression":
            case "ArrayExpression":
            case "CallExpression":
            case "NewExpression":
              return sourceCode.getLastToken(node, 1);
            default: {
              const nextToken = sourceCode.getTokenAfter(lastItem);
              if (astUtils.isCommaToken(nextToken)) {
                return nextToken;
              }
              return sourceCode.getLastToken(lastItem);
            }
          }
        }
        function isMultiline(node) {
          const lastItem = getLastItem(node);
          if (!lastItem) {
            return false;
          }
          const penultimateToken = getTrailingToken(node, lastItem);
          const lastToken = sourceCode.getTokenAfter(penultimateToken);
          return lastToken.loc.end.line !== penultimateToken.loc.end.line;
        }
        function forbidTrailingComma(node) {
          const lastItem = getLastItem(node);
          if (!lastItem || node.type === "ImportDeclaration" && lastItem.type !== "ImportSpecifier") {
            return;
          }
          const trailingToken = getTrailingToken(node, lastItem);
          if (astUtils.isCommaToken(trailingToken)) {
            context.report({
              node: lastItem,
              loc: trailingToken.loc,
              messageId: "unexpected",
              *fix(fixer) {
                yield fixer.remove(trailingToken);
                yield fixer.insertTextBefore(sourceCode.getTokenBefore(trailingToken), "");
                yield fixer.insertTextAfter(sourceCode.getTokenAfter(trailingToken), "");
              }
            });
          }
        }
        function forceTrailingComma(node) {
          const lastItem = getLastItem(node);
          if (!lastItem || node.type === "ImportDeclaration" && lastItem.type !== "ImportSpecifier") {
            return;
          }
          if (!isTrailingCommaAllowed(lastItem)) {
            forbidTrailingComma(node);
            return;
          }
          const trailingToken = getTrailingToken(node, lastItem);
          if (trailingToken.value !== ",") {
            context.report({
              node: lastItem,
              loc: {
                start: trailingToken.loc.end,
                end: astUtils.getNextLocation(sourceCode, trailingToken.loc.end)
              },
              messageId: "missing",
              *fix(fixer) {
                yield fixer.insertTextAfter(trailingToken, ",");
                yield fixer.insertTextBefore(trailingToken, "");
                yield fixer.insertTextAfter(sourceCode.getTokenAfter(trailingToken), "");
              }
            });
          }
        }
        function forceTrailingCommaIfMultiline(node) {
          if (isMultiline(node)) {
            forceTrailingComma(node);
          } else {
            forbidTrailingComma(node);
          }
        }
        function allowTrailingCommaIfMultiline(node) {
          if (!isMultiline(node)) {
            forbidTrailingComma(node);
          }
        }
        const predicate = {
          always: forceTrailingComma,
          "always-multiline": forceTrailingCommaIfMultiline,
          "only-multiline": allowTrailingCommaIfMultiline,
          never: forbidTrailingComma,
          ignore() {
          }
        };
        return {
          ObjectExpression: predicate[options.objects],
          ObjectPattern: predicate[options.objects],
          ArrayExpression: predicate[options.arrays],
          ArrayPattern: predicate[options.arrays],
          ImportDeclaration: predicate[options.imports],
          ExportNamedDeclaration: predicate[options.exports],
          FunctionDeclaration: predicate[options.functions],
          FunctionExpression: predicate[options.functions],
          ArrowFunctionExpression: predicate[options.functions],
          CallExpression: predicate[options.functions],
          NewExpression: predicate[options.functions]
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/comma-spacing.js
var require_comma_spacing = __commonJS({
  "node_modules/eslint/lib/rules/comma-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before and after commas",
          recommended: false,
          url: "https://eslint.org/docs/rules/comma-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              before: {
                type: "boolean",
                default: false
              },
              after: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          missing: "A space is required {{loc}} ','.",
          unexpected: "There should be no space {{loc}} ','."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const tokensAndComments = sourceCode.tokensAndComments;
        const options = {
          before: context.options[0] ? context.options[0].before : false,
          after: context.options[0] ? context.options[0].after : true
        };
        const commaTokensToIgnore = [];
        function report(node, loc, otherNode) {
          context.report({
            node,
            fix(fixer) {
              if (options[loc]) {
                if (loc === "before") {
                  return fixer.insertTextBefore(node, " ");
                }
                return fixer.insertTextAfter(node, " ");
              }
              let start, end;
              const newText = "";
              if (loc === "before") {
                start = otherNode.range[1];
                end = node.range[0];
              } else {
                start = node.range[1];
                end = otherNode.range[0];
              }
              return fixer.replaceTextRange([start, end], newText);
            },
            messageId: options[loc] ? "missing" : "unexpected",
            data: {
              loc
            }
          });
        }
        function addNullElementsToIgnoreList(node) {
          let previousToken = sourceCode.getFirstToken(node);
          node.elements.forEach((element) => {
            let token;
            if (element === null) {
              token = sourceCode.getTokenAfter(previousToken);
              if (astUtils.isCommaToken(token)) {
                commaTokensToIgnore.push(token);
              }
            } else {
              token = sourceCode.getTokenAfter(element);
            }
            previousToken = token;
          });
        }
        return {
          "Program:exit"() {
            tokensAndComments.forEach((token, i) => {
              if (!astUtils.isCommaToken(token)) {
                return;
              }
              const previousToken = tokensAndComments[i - 1];
              const nextToken = tokensAndComments[i + 1];
              if (previousToken && !astUtils.isCommaToken(previousToken) && // ignore spacing between two commas
              /*
               * `commaTokensToIgnore` are ending commas of `null` elements (array holes/elisions).
               * In addition to spacing between two commas, this can also ignore:
               *
               *   - Spacing after `[` (controlled by array-bracket-spacing)
               *       Example: [ , ]
               *                 ^
               *   - Spacing after a comment (for backwards compatibility, this was possibly unintentional)
               *       Example: [a, /* * / ,]
               *                          ^
               */
              !commaTokensToIgnore.includes(token) && astUtils.isTokenOnSameLine(previousToken, token) && options.before !== sourceCode.isSpaceBetweenTokens(previousToken, token)) {
                report(token, "before", previousToken);
              }
              if (nextToken && !astUtils.isCommaToken(nextToken) && // ignore spacing between two commas
              !astUtils.isClosingParenToken(nextToken) && // controlled by space-in-parens
              !astUtils.isClosingBracketToken(nextToken) && // controlled by array-bracket-spacing
              !astUtils.isClosingBraceToken(nextToken) && // controlled by object-curly-spacing
              !(!options.after && nextToken.type === "Line") && // special case, allow space before line comment
              astUtils.isTokenOnSameLine(token, nextToken) && options.after !== sourceCode.isSpaceBetweenTokens(token, nextToken)) {
                report(token, "after", nextToken);
              }
            });
          },
          ArrayExpression: addNullElementsToIgnoreList,
          ArrayPattern: addNullElementsToIgnoreList
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/comma-style.js
var require_comma_style = __commonJS({
  "node_modules/eslint/lib/rules/comma-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent comma style",
          recommended: false,
          url: "https://eslint.org/docs/rules/comma-style"
        },
        fixable: "code",
        schema: [
          {
            enum: ["first", "last"]
          },
          {
            type: "object",
            properties: {
              exceptions: {
                type: "object",
                additionalProperties: {
                  type: "boolean"
                }
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedLineBeforeAndAfterComma: "Bad line breaking before and after ','.",
          expectedCommaFirst: "',' should be placed first.",
          expectedCommaLast: "',' should be placed last."
        }
      },
      create(context) {
        const style = context.options[0] || "last", sourceCode = context.getSourceCode();
        const exceptions = {
          ArrayPattern: true,
          ArrowFunctionExpression: true,
          CallExpression: true,
          FunctionDeclaration: true,
          FunctionExpression: true,
          ImportDeclaration: true,
          ObjectPattern: true,
          NewExpression: true
        };
        if (context.options.length === 2 && Object.prototype.hasOwnProperty.call(context.options[1], "exceptions")) {
          const keys3 = Object.keys(context.options[1].exceptions);
          for (let i = 0; i < keys3.length; i++) {
            exceptions[keys3[i]] = context.options[1].exceptions[keys3[i]];
          }
        }
        function getReplacedText(styleType, text) {
          switch (styleType) {
            case "between":
              return `,${text.replace(astUtils.LINEBREAK_MATCHER, "")}`;
            case "first":
              return `${text},`;
            case "last":
              return `,${text}`;
            default:
              return "";
          }
        }
        function getFixerFunction(styleType, previousItemToken, commaToken, currentItemToken) {
          const text = sourceCode.text.slice(previousItemToken.range[1], commaToken.range[0]) + sourceCode.text.slice(commaToken.range[1], currentItemToken.range[0]);
          const range = [previousItemToken.range[1], currentItemToken.range[0]];
          return function(fixer) {
            return fixer.replaceTextRange(range, getReplacedText(styleType, text));
          };
        }
        function validateCommaItemSpacing(previousItemToken, commaToken, currentItemToken, reportItem) {
          if (astUtils.isTokenOnSameLine(commaToken, currentItemToken) && astUtils.isTokenOnSameLine(previousItemToken, commaToken)) {
          } else if (!astUtils.isTokenOnSameLine(commaToken, currentItemToken) && !astUtils.isTokenOnSameLine(previousItemToken, commaToken)) {
            const comment = sourceCode.getCommentsAfter(commaToken)[0];
            const styleType = comment && comment.type === "Block" && astUtils.isTokenOnSameLine(commaToken, comment) ? style : "between";
            context.report({
              node: reportItem,
              loc: commaToken.loc,
              messageId: "unexpectedLineBeforeAndAfterComma",
              fix: getFixerFunction(styleType, previousItemToken, commaToken, currentItemToken)
            });
          } else if (style === "first" && !astUtils.isTokenOnSameLine(commaToken, currentItemToken)) {
            context.report({
              node: reportItem,
              loc: commaToken.loc,
              messageId: "expectedCommaFirst",
              fix: getFixerFunction(style, previousItemToken, commaToken, currentItemToken)
            });
          } else if (style === "last" && astUtils.isTokenOnSameLine(commaToken, currentItemToken)) {
            context.report({
              node: reportItem,
              loc: commaToken.loc,
              messageId: "expectedCommaLast",
              fix: getFixerFunction(style, previousItemToken, commaToken, currentItemToken)
            });
          }
        }
        function validateComma(node, property) {
          const items = node[property], arrayLiteral = node.type === "ArrayExpression" || node.type === "ArrayPattern";
          if (items.length > 1 || arrayLiteral) {
            let previousItemToken = sourceCode.getFirstToken(node);
            items.forEach((item) => {
              const commaToken = item ? sourceCode.getTokenBefore(item) : previousItemToken, currentItemToken = item ? sourceCode.getFirstToken(item) : sourceCode.getTokenAfter(commaToken), reportItem = item || currentItemToken;
              if (astUtils.isCommaToken(commaToken)) {
                validateCommaItemSpacing(previousItemToken, commaToken, currentItemToken, reportItem);
              }
              if (item) {
                const tokenAfterItem = sourceCode.getTokenAfter(item, astUtils.isNotClosingParenToken);
                previousItemToken = tokenAfterItem ? sourceCode.getTokenBefore(tokenAfterItem) : sourceCode.ast.tokens[sourceCode.ast.tokens.length - 1];
              } else {
                previousItemToken = currentItemToken;
              }
            });
            if (arrayLiteral) {
              const lastToken = sourceCode.getLastToken(node), nextToLastToken = sourceCode.getTokenBefore(lastToken);
              if (astUtils.isCommaToken(nextToLastToken)) {
                validateCommaItemSpacing(
                  sourceCode.getTokenBefore(nextToLastToken),
                  nextToLastToken,
                  lastToken,
                  lastToken
                );
              }
            }
          }
        }
        const nodes = {};
        if (!exceptions.VariableDeclaration) {
          nodes.VariableDeclaration = function(node) {
            validateComma(node, "declarations");
          };
        }
        if (!exceptions.ObjectExpression) {
          nodes.ObjectExpression = function(node) {
            validateComma(node, "properties");
          };
        }
        if (!exceptions.ObjectPattern) {
          nodes.ObjectPattern = function(node) {
            validateComma(node, "properties");
          };
        }
        if (!exceptions.ArrayExpression) {
          nodes.ArrayExpression = function(node) {
            validateComma(node, "elements");
          };
        }
        if (!exceptions.ArrayPattern) {
          nodes.ArrayPattern = function(node) {
            validateComma(node, "elements");
          };
        }
        if (!exceptions.FunctionDeclaration) {
          nodes.FunctionDeclaration = function(node) {
            validateComma(node, "params");
          };
        }
        if (!exceptions.FunctionExpression) {
          nodes.FunctionExpression = function(node) {
            validateComma(node, "params");
          };
        }
        if (!exceptions.ArrowFunctionExpression) {
          nodes.ArrowFunctionExpression = function(node) {
            validateComma(node, "params");
          };
        }
        if (!exceptions.CallExpression) {
          nodes.CallExpression = function(node) {
            validateComma(node, "arguments");
          };
        }
        if (!exceptions.ImportDeclaration) {
          nodes.ImportDeclaration = function(node) {
            validateComma(node, "specifiers");
          };
        }
        if (!exceptions.NewExpression) {
          nodes.NewExpression = function(node) {
            validateComma(node, "arguments");
          };
        }
        return nodes;
      }
    };
  }
});

// node_modules/eslint/lib/shared/string-utils.js
var require_string_utils = __commonJS({
  "node_modules/eslint/lib/shared/string-utils.js"(exports, module2) {
    "use strict";
    function upperCaseFirst(string) {
      if (string.length <= 1) {
        return string.toUpperCase();
      }
      return string[0].toUpperCase() + string.slice(1);
    }
    module2.exports = {
      upperCaseFirst
    };
  }
});

// node_modules/eslint/lib/rules/complexity.js
var require_complexity = __commonJS({
  "node_modules/eslint/lib/rules/complexity.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { upperCaseFirst } = require_string_utils();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum cyclomatic complexity allowed in a program",
          recommended: false,
          url: "https://eslint.org/docs/rules/complexity"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  maximum: {
                    type: "integer",
                    minimum: 0
                  },
                  max: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          complex: "{{name}} has a complexity of {{complexity}}. Maximum allowed is {{max}}."
        }
      },
      create(context) {
        const option = context.options[0];
        let THRESHOLD = 20;
        if (typeof option === "object" && (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
          THRESHOLD = option.maximum || option.max;
        } else if (typeof option === "number") {
          THRESHOLD = option;
        }
        const complexities = [];
        function increaseComplexity() {
          complexities[complexities.length - 1]++;
        }
        return {
          onCodePathStart() {
            complexities.push(1);
          },
          // Each branching in the code adds 1 to the complexity
          CatchClause: increaseComplexity,
          ConditionalExpression: increaseComplexity,
          LogicalExpression: increaseComplexity,
          ForStatement: increaseComplexity,
          ForInStatement: increaseComplexity,
          ForOfStatement: increaseComplexity,
          IfStatement: increaseComplexity,
          WhileStatement: increaseComplexity,
          DoWhileStatement: increaseComplexity,
          // Avoid `default`
          "SwitchCase[test]": increaseComplexity,
          // Logical assignment operators have short-circuiting behavior
          AssignmentExpression(node) {
            if (astUtils.isLogicalAssignmentOperator(node.operator)) {
              increaseComplexity();
            }
          },
          onCodePathEnd(codePath, node) {
            const complexity = complexities.pop();
            if (codePath.origin !== "function" && codePath.origin !== "class-field-initializer" && codePath.origin !== "class-static-block") {
              return;
            }
            if (complexity > THRESHOLD) {
              let name;
              if (codePath.origin === "class-field-initializer") {
                name = "class field initializer";
              } else if (codePath.origin === "class-static-block") {
                name = "class static block";
              } else {
                name = astUtils.getFunctionNameWithKind(node);
              }
              context.report({
                node,
                messageId: "complex",
                data: {
                  name: upperCaseFirst(name),
                  complexity,
                  max: THRESHOLD
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/computed-property-spacing.js
var require_computed_property_spacing = __commonJS({
  "node_modules/eslint/lib/rules/computed-property-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing inside computed property brackets",
          recommended: false,
          url: "https://eslint.org/docs/rules/computed-property-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              enforceForClassMembers: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedSpaceBefore: "There should be no space before '{{tokenValue}}'.",
          unexpectedSpaceAfter: "There should be no space after '{{tokenValue}}'.",
          missingSpaceBefore: "A space is required before '{{tokenValue}}'.",
          missingSpaceAfter: "A space is required after '{{tokenValue}}'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const propertyNameMustBeSpaced = context.options[0] === "always";
        const enforceForClassMembers = !context.options[1] || context.options[1].enforceForClassMembers;
        function reportNoBeginningSpace(node, token, tokenAfter) {
          context.report({
            node,
            loc: { start: token.loc.end, end: tokenAfter.loc.start },
            messageId: "unexpectedSpaceAfter",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.removeRange([token.range[1], tokenAfter.range[0]]);
            }
          });
        }
        function reportNoEndingSpace(node, token, tokenBefore) {
          context.report({
            node,
            loc: { start: tokenBefore.loc.end, end: token.loc.start },
            messageId: "unexpectedSpaceBefore",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.removeRange([tokenBefore.range[1], token.range[0]]);
            }
          });
        }
        function reportRequiredBeginningSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingSpaceAfter",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.insertTextAfter(token, " ");
            }
          });
        }
        function reportRequiredEndingSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "missingSpaceBefore",
            data: {
              tokenValue: token.value
            },
            fix(fixer) {
              return fixer.insertTextBefore(token, " ");
            }
          });
        }
        function checkSpacing(propertyName) {
          return function(node) {
            if (!node.computed) {
              return;
            }
            const property = node[propertyName];
            const before = sourceCode.getTokenBefore(property, astUtils.isOpeningBracketToken), first2 = sourceCode.getTokenAfter(before, { includeComments: true }), after = sourceCode.getTokenAfter(property, astUtils.isClosingBracketToken), last2 = sourceCode.getTokenBefore(after, { includeComments: true });
            if (astUtils.isTokenOnSameLine(before, first2)) {
              if (propertyNameMustBeSpaced) {
                if (!sourceCode.isSpaceBetweenTokens(before, first2) && astUtils.isTokenOnSameLine(before, first2)) {
                  reportRequiredBeginningSpace(node, before);
                }
              } else {
                if (sourceCode.isSpaceBetweenTokens(before, first2)) {
                  reportNoBeginningSpace(node, before, first2);
                }
              }
            }
            if (astUtils.isTokenOnSameLine(last2, after)) {
              if (propertyNameMustBeSpaced) {
                if (!sourceCode.isSpaceBetweenTokens(last2, after) && astUtils.isTokenOnSameLine(last2, after)) {
                  reportRequiredEndingSpace(node, after);
                }
              } else {
                if (sourceCode.isSpaceBetweenTokens(last2, after)) {
                  reportNoEndingSpace(node, after, last2);
                }
              }
            }
          };
        }
        const listeners = {
          Property: checkSpacing("key"),
          MemberExpression: checkSpacing("property")
        };
        if (enforceForClassMembers) {
          listeners.MethodDefinition = listeners.PropertyDefinition = listeners.Property;
        }
        return listeners;
      }
    };
  }
});

// node_modules/eslint/lib/rules/consistent-return.js
var require_consistent_return = __commonJS({
  "node_modules/eslint/lib/rules/consistent-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { upperCaseFirst } = require_string_utils();
    function isUnreachable(segment) {
      return !segment.reachable;
    }
    function isClassConstructor(node) {
      return node.type === "FunctionExpression" && node.parent && node.parent.type === "MethodDefinition" && node.parent.kind === "constructor";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `return` statements to either always or never specify values",
          recommended: false,
          url: "https://eslint.org/docs/rules/consistent-return"
        },
        schema: [{
          type: "object",
          properties: {
            treatUndefinedAsUnspecified: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          missingReturn: "Expected to return a value at the end of {{name}}.",
          missingReturnValue: "{{name}} expected a return value.",
          unexpectedReturnValue: "{{name}} expected no return value."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const treatUndefinedAsUnspecified = options.treatUndefinedAsUnspecified === true;
        let funcInfo = null;
        function checkLastSegment(node) {
          let loc, name;
          if (!funcInfo.hasReturnValue || funcInfo.codePath.currentSegments.every(isUnreachable) || astUtils.isES5Constructor(node) || isClassConstructor(node)) {
            return;
          }
          if (node.type === "Program") {
            loc = { line: 1, column: 0 };
            name = "program";
          } else if (node.type === "ArrowFunctionExpression") {
            loc = context.getSourceCode().getTokenBefore(node.body, astUtils.isArrowToken).loc;
          } else if (node.parent.type === "MethodDefinition" || node.parent.type === "Property" && node.parent.method) {
            loc = node.parent.key.loc;
          } else {
            loc = (node.id || context.getSourceCode().getFirstToken(node)).loc;
          }
          if (!name) {
            name = astUtils.getFunctionNameWithKind(node);
          }
          context.report({
            node,
            loc,
            messageId: "missingReturn",
            data: { name }
          });
        }
        return {
          // Initializes/Disposes state of each code path.
          onCodePathStart(codePath, node) {
            funcInfo = {
              upper: funcInfo,
              codePath,
              hasReturn: false,
              hasReturnValue: false,
              messageId: "",
              node
            };
          },
          onCodePathEnd() {
            funcInfo = funcInfo.upper;
          },
          // Reports a given return statement if it's inconsistent.
          ReturnStatement(node) {
            const argument = node.argument;
            let hasReturnValue = Boolean(argument);
            if (treatUndefinedAsUnspecified && hasReturnValue) {
              hasReturnValue = !astUtils.isSpecificId(argument, "undefined") && argument.operator !== "void";
            }
            if (!funcInfo.hasReturn) {
              funcInfo.hasReturn = true;
              funcInfo.hasReturnValue = hasReturnValue;
              funcInfo.messageId = hasReturnValue ? "missingReturnValue" : "unexpectedReturnValue";
              funcInfo.data = {
                name: funcInfo.node.type === "Program" ? "Program" : upperCaseFirst(astUtils.getFunctionNameWithKind(funcInfo.node))
              };
            } else if (funcInfo.hasReturnValue !== hasReturnValue) {
              context.report({
                node,
                messageId: funcInfo.messageId,
                data: funcInfo.data
              });
            }
          },
          // Reports a given program/function if the implicit returning is not consistent.
          "Program:exit": checkLastSegment,
          "FunctionDeclaration:exit": checkLastSegment,
          "FunctionExpression:exit": checkLastSegment,
          "ArrowFunctionExpression:exit": checkLastSegment
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/consistent-this.js
var require_consistent_this = __commonJS({
  "node_modules/eslint/lib/rules/consistent-this.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce consistent naming when capturing the current execution context",
          recommended: false,
          url: "https://eslint.org/docs/rules/consistent-this"
        },
        schema: {
          type: "array",
          items: {
            type: "string",
            minLength: 1
          },
          uniqueItems: true
        },
        messages: {
          aliasNotAssignedToThis: "Designated alias '{{name}}' is not assigned to 'this'.",
          unexpectedAlias: "Unexpected alias '{{name}}' for 'this'."
        }
      },
      create(context) {
        let aliases = [];
        if (context.options.length === 0) {
          aliases.push("that");
        } else {
          aliases = context.options;
        }
        function reportBadAssignment(node, name) {
          context.report({ node, messageId: "aliasNotAssignedToThis", data: { name } });
        }
        function checkAssignment(node, name, value2) {
          const isThis = value2.type === "ThisExpression";
          if (aliases.includes(name)) {
            if (!isThis || node.operator && node.operator !== "=") {
              reportBadAssignment(node, name);
            }
          } else if (isThis) {
            context.report({ node, messageId: "unexpectedAlias", data: { name } });
          }
        }
        function checkWasAssigned(alias, scope) {
          const variable = scope.set.get(alias);
          if (!variable) {
            return;
          }
          if (variable.defs.some((def) => def.node.type === "VariableDeclarator" && def.node.init !== null)) {
            return;
          }
          if (!variable.references.some((reference) => {
            const write = reference.writeExpr;
            return reference.from === scope && write && write.type === "ThisExpression" && write.parent.operator === "=";
          })) {
            variable.defs.map((def) => def.node).forEach((node) => {
              reportBadAssignment(node, alias);
            });
          }
        }
        function ensureWasAssigned() {
          const scope = context.getScope();
          aliases.forEach((alias) => {
            checkWasAssigned(alias, scope);
          });
        }
        return {
          "Program:exit": ensureWasAssigned,
          "FunctionExpression:exit": ensureWasAssigned,
          "FunctionDeclaration:exit": ensureWasAssigned,
          VariableDeclarator(node) {
            const id = node.id;
            const isDestructuring = id.type === "ArrayPattern" || id.type === "ObjectPattern";
            if (node.init !== null && !isDestructuring) {
              checkAssignment(node, id.name, node.init);
            }
          },
          AssignmentExpression(node) {
            if (node.left.type === "Identifier") {
              checkAssignment(node, node.left.name, node.right);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/constructor-super.js
var require_constructor_super = __commonJS({
  "node_modules/eslint/lib/rules/constructor-super.js"(exports, module2) {
    "use strict";
    function isReachable(segment) {
      return segment.reachable;
    }
    function isConstructorFunction(node) {
      return node.type === "FunctionExpression" && node.parent.type === "MethodDefinition" && node.parent.kind === "constructor";
    }
    function isPossibleConstructor(node) {
      if (!node) {
        return false;
      }
      switch (node.type) {
        case "ClassExpression":
        case "FunctionExpression":
        case "ThisExpression":
        case "MemberExpression":
        case "CallExpression":
        case "NewExpression":
        case "ChainExpression":
        case "YieldExpression":
        case "TaggedTemplateExpression":
        case "MetaProperty":
          return true;
        case "Identifier":
          return node.name !== "undefined";
        case "AssignmentExpression":
          if (["=", "&&="].includes(node.operator)) {
            return isPossibleConstructor(node.right);
          }
          if (["||=", "??="].includes(node.operator)) {
            return isPossibleConstructor(node.left) || isPossibleConstructor(node.right);
          }
          return false;
        case "LogicalExpression":
          if (node.operator === "&&") {
            return isPossibleConstructor(node.right);
          }
          return isPossibleConstructor(node.left) || isPossibleConstructor(node.right);
        case "ConditionalExpression":
          return isPossibleConstructor(node.alternate) || isPossibleConstructor(node.consequent);
        case "SequenceExpression": {
          const lastExpression = node.expressions[node.expressions.length - 1];
          return isPossibleConstructor(lastExpression);
        }
        default:
          return false;
      }
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Require `super()` calls in constructors",
          recommended: true,
          url: "https://eslint.org/docs/rules/constructor-super"
        },
        schema: [],
        messages: {
          missingSome: "Lacked a call of 'super()' in some code paths.",
          missingAll: "Expected to call 'super()'.",
          duplicate: "Unexpected duplicate 'super()'.",
          badSuper: "Unexpected 'super()' because 'super' is not a constructor.",
          unexpected: "Unexpected 'super()'."
        }
      },
      create(context) {
        let funcInfo = null;
        let segInfoMap = /* @__PURE__ */ Object.create(null);
        function isCalledInSomePath(segment) {
          return segment.reachable && segInfoMap[segment.id].calledInSomePaths;
        }
        function isCalledInEveryPath(segment) {
          if (segment.nextSegments.length === 1 && segment.nextSegments[0].isLoopedPrevSegment(segment)) {
            return true;
          }
          return segment.reachable && segInfoMap[segment.id].calledInEveryPaths;
        }
        return {
          /**
           * Stacks a constructor information.
           * @param {CodePath} codePath A code path which was started.
           * @param {ASTNode} node The current node.
           * @returns {void}
           */
          onCodePathStart(codePath, node) {
            if (isConstructorFunction(node)) {
              const classNode = node.parent.parent.parent;
              const superClass = classNode.superClass;
              funcInfo = {
                upper: funcInfo,
                isConstructor: true,
                hasExtends: Boolean(superClass),
                superIsConstructor: isPossibleConstructor(superClass),
                codePath
              };
            } else {
              funcInfo = {
                upper: funcInfo,
                isConstructor: false,
                hasExtends: false,
                superIsConstructor: false,
                codePath
              };
            }
          },
          /**
           * Pops a constructor information.
           * And reports if `super()` lacked.
           * @param {CodePath} codePath A code path which was ended.
           * @param {ASTNode} node The current node.
           * @returns {void}
           */
          onCodePathEnd(codePath, node) {
            const hasExtends = funcInfo.hasExtends;
            funcInfo = funcInfo.upper;
            if (!hasExtends) {
              return;
            }
            const segments = codePath.returnedSegments;
            const calledInEveryPaths = segments.every(isCalledInEveryPath);
            const calledInSomePaths = segments.some(isCalledInSomePath);
            if (!calledInEveryPaths) {
              context.report({
                messageId: calledInSomePaths ? "missingSome" : "missingAll",
                node: node.parent
              });
            }
          },
          /**
           * Initialize information of a given code path segment.
           * @param {CodePathSegment} segment A code path segment to initialize.
           * @returns {void}
           */
          onCodePathSegmentStart(segment) {
            if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
              return;
            }
            const info = segInfoMap[segment.id] = {
              calledInSomePaths: false,
              calledInEveryPaths: false,
              validNodes: []
            };
            const prevSegments = segment.prevSegments;
            if (prevSegments.length > 0) {
              info.calledInSomePaths = prevSegments.some(isCalledInSomePath);
              info.calledInEveryPaths = prevSegments.every(isCalledInEveryPath);
            }
          },
          /**
           * Update information of the code path segment when a code path was
           * looped.
           * @param {CodePathSegment} fromSegment The code path segment of the
           *      end of a loop.
           * @param {CodePathSegment} toSegment A code path segment of the head
           *      of a loop.
           * @returns {void}
           */
          onCodePathSegmentLoop(fromSegment, toSegment) {
            if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
              return;
            }
            const isRealLoop = toSegment.prevSegments.length >= 2;
            funcInfo.codePath.traverseSegments(
              { first: toSegment, last: fromSegment },
              (segment) => {
                const info = segInfoMap[segment.id];
                const prevSegments = segment.prevSegments;
                info.calledInSomePaths = prevSegments.some(isCalledInSomePath);
                info.calledInEveryPaths = prevSegments.every(isCalledInEveryPath);
                if (info.calledInSomePaths || isRealLoop) {
                  const nodes = info.validNodes;
                  info.validNodes = [];
                  for (let i = 0; i < nodes.length; ++i) {
                    const node = nodes[i];
                    context.report({
                      messageId: "duplicate",
                      node
                    });
                  }
                }
              }
            );
          },
          /**
           * Checks for a call of `super()`.
           * @param {ASTNode} node A CallExpression node to check.
           * @returns {void}
           */
          "CallExpression:exit"(node) {
            if (!(funcInfo && funcInfo.isConstructor)) {
              return;
            }
            if (node.callee.type !== "Super") {
              return;
            }
            if (funcInfo.hasExtends) {
              const segments = funcInfo.codePath.currentSegments;
              let duplicate = false;
              let info = null;
              for (let i = 0; i < segments.length; ++i) {
                const segment = segments[i];
                if (segment.reachable) {
                  info = segInfoMap[segment.id];
                  duplicate = duplicate || info.calledInSomePaths;
                  info.calledInSomePaths = info.calledInEveryPaths = true;
                }
              }
              if (info) {
                if (duplicate) {
                  context.report({
                    messageId: "duplicate",
                    node
                  });
                } else if (!funcInfo.superIsConstructor) {
                  context.report({
                    messageId: "badSuper",
                    node
                  });
                } else {
                  info.validNodes.push(node);
                }
              }
            } else if (funcInfo.codePath.currentSegments.some(isReachable)) {
              context.report({
                messageId: "unexpected",
                node
              });
            }
          },
          /**
           * Set the mark to the returned path as `super()` was called.
           * @param {ASTNode} node A ReturnStatement node to check.
           * @returns {void}
           */
          ReturnStatement(node) {
            if (!(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends)) {
              return;
            }
            if (!node.argument) {
              return;
            }
            const segments = funcInfo.codePath.currentSegments;
            for (let i = 0; i < segments.length; ++i) {
              const segment = segments[i];
              if (segment.reachable) {
                const info = segInfoMap[segment.id];
                info.calledInSomePaths = info.calledInEveryPaths = true;
              }
            }
          },
          /**
           * Resets state.
           * @returns {void}
           */
          "Program:exit"() {
            segInfoMap = /* @__PURE__ */ Object.create(null);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/curly.js
var require_curly = __commonJS({
  "node_modules/eslint/lib/rules/curly.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce consistent brace style for all control statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/curly"
        },
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["all"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["multi", "multi-line", "multi-or-nest"]
                },
                {
                  enum: ["consistent"]
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        fixable: "code",
        messages: {
          missingCurlyAfter: "Expected { after '{{name}}'.",
          missingCurlyAfterCondition: "Expected { after '{{name}}' condition.",
          unexpectedCurlyAfter: "Unnecessary { after '{{name}}'.",
          unexpectedCurlyAfterCondition: "Unnecessary { after '{{name}}' condition."
        }
      },
      create(context) {
        const multiOnly = context.options[0] === "multi";
        const multiLine = context.options[0] === "multi-line";
        const multiOrNest = context.options[0] === "multi-or-nest";
        const consistent = context.options[1] === "consistent";
        const sourceCode = context.getSourceCode();
        function isCollapsedOneLiner(node) {
          const before = sourceCode.getTokenBefore(node);
          const last2 = sourceCode.getLastToken(node);
          const lastExcludingSemicolon = astUtils.isSemicolonToken(last2) ? sourceCode.getTokenBefore(last2) : last2;
          return before.loc.start.line === lastExcludingSemicolon.loc.end.line;
        }
        function isOneLiner(node) {
          if (node.type === "EmptyStatement") {
            return true;
          }
          const first2 = sourceCode.getFirstToken(node);
          const last2 = sourceCode.getLastToken(node);
          const lastExcludingSemicolon = astUtils.isSemicolonToken(last2) ? sourceCode.getTokenBefore(last2) : last2;
          return first2.loc.start.line === lastExcludingSemicolon.loc.end.line;
        }
        function isLexicalDeclaration(node) {
          if (node.type === "VariableDeclaration") {
            return node.kind === "const" || node.kind === "let";
          }
          return node.type === "FunctionDeclaration" || node.type === "ClassDeclaration";
        }
        function isElseKeywordToken(token) {
          return token.value === "else" && token.type === "Keyword";
        }
        function isFollowedByElseKeyword(node) {
          const nextToken = sourceCode.getTokenAfter(node);
          return Boolean(nextToken) && isElseKeywordToken(nextToken);
        }
        function needsSemicolon(closingBracket) {
          const tokenBefore = sourceCode.getTokenBefore(closingBracket);
          const tokenAfter = sourceCode.getTokenAfter(closingBracket);
          const lastBlockNode = sourceCode.getNodeByRangeIndex(tokenBefore.range[0]);
          if (astUtils.isSemicolonToken(tokenBefore)) {
            return false;
          }
          if (!tokenAfter) {
            return false;
          }
          if (lastBlockNode.type === "BlockStatement" && lastBlockNode.parent.type !== "FunctionExpression" && lastBlockNode.parent.type !== "ArrowFunctionExpression") {
            return false;
          }
          if (tokenBefore.loc.end.line === tokenAfter.loc.start.line) {
            return true;
          }
          if (/^[([/`+-]/u.test(tokenAfter.value)) {
            return true;
          }
          if (tokenBefore.type === "Punctuator" && (tokenBefore.value === "++" || tokenBefore.value === "--")) {
            return true;
          }
          return false;
        }
        function hasUnsafeIf(node) {
          switch (node.type) {
            case "IfStatement":
              if (!node.alternate) {
                return true;
              }
              return hasUnsafeIf(node.alternate);
            case "ForStatement":
            case "ForInStatement":
            case "ForOfStatement":
            case "LabeledStatement":
            case "WithStatement":
            case "WhileStatement":
              return hasUnsafeIf(node.body);
            default:
              return false;
          }
        }
        function areBracesNecessary(node) {
          const statement = node.body[0];
          return isLexicalDeclaration(statement) || hasUnsafeIf(statement) && isFollowedByElseKeyword(node);
        }
        function prepareCheck(node, body, name, opts) {
          const hasBlock = body.type === "BlockStatement";
          let expected = null;
          if (hasBlock && (body.body.length !== 1 || areBracesNecessary(body))) {
            expected = true;
          } else if (multiOnly) {
            expected = false;
          } else if (multiLine) {
            if (!isCollapsedOneLiner(body)) {
              expected = true;
            }
          } else if (multiOrNest) {
            if (hasBlock) {
              const statement = body.body[0];
              const leadingCommentsInBlock = sourceCode.getCommentsBefore(statement);
              expected = !isOneLiner(statement) || leadingCommentsInBlock.length > 0;
            } else {
              expected = !isOneLiner(body);
            }
          } else {
            expected = true;
          }
          return {
            actual: hasBlock,
            expected,
            check() {
              if (this.expected !== null && this.expected !== this.actual) {
                if (this.expected) {
                  context.report({
                    node,
                    loc: body.loc,
                    messageId: opts && opts.condition ? "missingCurlyAfterCondition" : "missingCurlyAfter",
                    data: {
                      name
                    },
                    fix: (fixer) => fixer.replaceText(body, `{${sourceCode.getText(body)}}`)
                  });
                } else {
                  context.report({
                    node,
                    loc: body.loc,
                    messageId: opts && opts.condition ? "unexpectedCurlyAfterCondition" : "unexpectedCurlyAfter",
                    data: {
                      name
                    },
                    fix(fixer) {
                      const needsPrecedingSpace = node.type === "DoWhileStatement" && sourceCode.getTokenBefore(body).range[1] === body.range[0] && !astUtils.canTokensBeAdjacent("do", sourceCode.getFirstToken(body, { skip: 1 }));
                      const openingBracket = sourceCode.getFirstToken(body);
                      const closingBracket = sourceCode.getLastToken(body);
                      const lastTokenInBlock = sourceCode.getTokenBefore(closingBracket);
                      if (needsSemicolon(closingBracket)) {
                        return null;
                      }
                      const resultingBodyText = sourceCode.getText().slice(openingBracket.range[1], lastTokenInBlock.range[0]) + sourceCode.getText(lastTokenInBlock) + sourceCode.getText().slice(lastTokenInBlock.range[1], closingBracket.range[0]);
                      return fixer.replaceText(body, (needsPrecedingSpace ? " " : "") + resultingBodyText);
                    }
                  });
                }
              }
            }
          };
        }
        function prepareIfChecks(node) {
          const preparedChecks = [];
          for (let currentNode = node; currentNode; currentNode = currentNode.alternate) {
            preparedChecks.push(prepareCheck(currentNode, currentNode.consequent, "if", { condition: true }));
            if (currentNode.alternate && currentNode.alternate.type !== "IfStatement") {
              preparedChecks.push(prepareCheck(currentNode, currentNode.alternate, "else"));
              break;
            }
          }
          if (consistent) {
            const expected = preparedChecks.some((preparedCheck) => {
              if (preparedCheck.expected !== null) {
                return preparedCheck.expected;
              }
              return preparedCheck.actual;
            });
            preparedChecks.forEach((preparedCheck) => {
              preparedCheck.expected = expected;
            });
          }
          return preparedChecks;
        }
        return {
          IfStatement(node) {
            const parent = node.parent;
            const isElseIf = parent.type === "IfStatement" && parent.alternate === node;
            if (!isElseIf) {
              prepareIfChecks(node).forEach((preparedCheck) => {
                preparedCheck.check();
              });
            }
          },
          WhileStatement(node) {
            prepareCheck(node, node.body, "while", { condition: true }).check();
          },
          DoWhileStatement(node) {
            prepareCheck(node, node.body, "do").check();
          },
          ForStatement(node) {
            prepareCheck(node, node.body, "for", { condition: true }).check();
          },
          ForInStatement(node) {
            prepareCheck(node, node.body, "for-in").check();
          },
          ForOfStatement(node) {
            prepareCheck(node, node.body, "for-of").check();
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/default-case.js
var require_default_case = __commonJS({
  "node_modules/eslint/lib/rules/default-case.js"(exports, module2) {
    "use strict";
    var DEFAULT_COMMENT_PATTERN = /^no default$/iu;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `default` cases in `switch` statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/default-case"
        },
        schema: [{
          type: "object",
          properties: {
            commentPattern: {
              type: "string"
            }
          },
          additionalProperties: false
        }],
        messages: {
          missingDefaultCase: "Expected a default case."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const commentPattern = options.commentPattern ? new RegExp(options.commentPattern, "u") : DEFAULT_COMMENT_PATTERN;
        const sourceCode = context.getSourceCode();
        function last2(collection) {
          return collection[collection.length - 1];
        }
        return {
          SwitchStatement(node) {
            if (!node.cases.length) {
              return;
            }
            const hasDefault = node.cases.some((v) => v.test === null);
            if (!hasDefault) {
              let comment;
              const lastCase = last2(node.cases);
              const comments = sourceCode.getCommentsAfter(lastCase);
              if (comments.length) {
                comment = last2(comments);
              }
              if (!comment || !commentPattern.test(comment.value.trim())) {
                context.report({ node, messageId: "missingDefaultCase" });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/default-case-last.js
var require_default_case_last = __commonJS({
  "node_modules/eslint/lib/rules/default-case-last.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce default clauses in switch statements to be last",
          recommended: false,
          url: "https://eslint.org/docs/rules/default-case-last"
        },
        schema: [],
        messages: {
          notLast: "Default clause should be the last clause."
        }
      },
      create(context) {
        return {
          SwitchStatement(node) {
            const cases = node.cases, indexOfDefault = cases.findIndex((c) => c.test === null);
            if (indexOfDefault !== -1 && indexOfDefault !== cases.length - 1) {
              const defaultClause = cases[indexOfDefault];
              context.report({ node: defaultClause, messageId: "notLast" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/default-param-last.js
var require_default_param_last = __commonJS({
  "node_modules/eslint/lib/rules/default-param-last.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce default parameters to be last",
          recommended: false,
          url: "https://eslint.org/docs/rules/default-param-last"
        },
        schema: [],
        messages: {
          shouldBeLast: "Default parameters should be last."
        }
      },
      create(context) {
        function handleFunction(node) {
          let hasSeenPlainParam = false;
          for (let i = node.params.length - 1; i >= 0; i -= 1) {
            const param = node.params[i];
            if (param.type !== "AssignmentPattern" && param.type !== "RestElement") {
              hasSeenPlainParam = true;
              continue;
            }
            if (hasSeenPlainParam && param.type === "AssignmentPattern") {
              context.report({
                node: param,
                messageId: "shouldBeLast"
              });
            }
          }
        }
        return {
          FunctionDeclaration: handleFunction,
          FunctionExpression: handleFunction,
          ArrowFunctionExpression: handleFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/dot-location.js
var require_dot_location = __commonJS({
  "node_modules/eslint/lib/rules/dot-location.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent newlines before and after dots",
          recommended: false,
          url: "https://eslint.org/docs/rules/dot-location"
        },
        schema: [
          {
            enum: ["object", "property"]
          }
        ],
        fixable: "code",
        messages: {
          expectedDotAfterObject: "Expected dot to be on same line as object.",
          expectedDotBeforeProperty: "Expected dot to be on same line as property."
        }
      },
      create(context) {
        const config = context.options[0];
        const onObject = config === "object" || !config;
        const sourceCode = context.getSourceCode();
        function checkDotLocation(node) {
          const property = node.property;
          const dotToken = sourceCode.getTokenBefore(property);
          if (onObject) {
            const tokenBeforeDot = sourceCode.getTokenBefore(dotToken);
            if (!astUtils.isTokenOnSameLine(tokenBeforeDot, dotToken)) {
              context.report({
                node,
                loc: dotToken.loc,
                messageId: "expectedDotAfterObject",
                *fix(fixer) {
                  if (dotToken.value.startsWith(".") && astUtils.isDecimalIntegerNumericToken(tokenBeforeDot)) {
                    yield fixer.insertTextAfter(tokenBeforeDot, ` ${dotToken.value}`);
                  } else {
                    yield fixer.insertTextAfter(tokenBeforeDot, dotToken.value);
                  }
                  yield fixer.remove(dotToken);
                }
              });
            }
          } else if (!astUtils.isTokenOnSameLine(dotToken, property)) {
            context.report({
              node,
              loc: dotToken.loc,
              messageId: "expectedDotBeforeProperty",
              *fix(fixer) {
                yield fixer.remove(dotToken);
                yield fixer.insertTextBefore(property, dotToken.value);
              }
            });
          }
        }
        function checkNode(node) {
          if (!node.computed) {
            checkDotLocation(node);
          }
        }
        return {
          MemberExpression: checkNode
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/utils/keywords.js
var require_keywords = __commonJS({
  "node_modules/eslint/lib/rules/utils/keywords.js"(exports, module2) {
    "use strict";
    module2.exports = [
      "abstract",
      "boolean",
      "break",
      "byte",
      "case",
      "catch",
      "char",
      "class",
      "const",
      "continue",
      "debugger",
      "default",
      "delete",
      "do",
      "double",
      "else",
      "enum",
      "export",
      "extends",
      "false",
      "final",
      "finally",
      "float",
      "for",
      "function",
      "goto",
      "if",
      "implements",
      "import",
      "in",
      "instanceof",
      "int",
      "interface",
      "long",
      "native",
      "new",
      "null",
      "package",
      "private",
      "protected",
      "public",
      "return",
      "short",
      "static",
      "super",
      "switch",
      "synchronized",
      "this",
      "throw",
      "throws",
      "transient",
      "true",
      "try",
      "typeof",
      "var",
      "void",
      "volatile",
      "while",
      "with"
    ];
  }
});

// node_modules/eslint/lib/rules/dot-notation.js
var require_dot_notation = __commonJS({
  "node_modules/eslint/lib/rules/dot-notation.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var keywords = require_keywords();
    var validIdentifier = /^[a-zA-Z_$][a-zA-Z0-9_$]*$/u;
    var literalTypesToCheck = /* @__PURE__ */ new Set(["string", "boolean"]);
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce dot notation whenever possible",
          recommended: false,
          url: "https://eslint.org/docs/rules/dot-notation"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowKeywords: {
                type: "boolean",
                default: true
              },
              allowPattern: {
                type: "string",
                default: ""
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          useDot: "[{{key}}] is better written in dot notation.",
          useBrackets: ".{{key}} is a syntax error."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const allowKeywords = options.allowKeywords === void 0 || options.allowKeywords;
        const sourceCode = context.getSourceCode();
        let allowPattern;
        if (options.allowPattern) {
          allowPattern = new RegExp(options.allowPattern, "u");
        }
        function checkComputedProperty(node, value2) {
          if (validIdentifier.test(value2) && (allowKeywords || !keywords.includes(String(value2))) && !(allowPattern && allowPattern.test(value2))) {
            const formattedValue = node.property.type === "Literal" ? JSON.stringify(value2) : `\`${value2}\``;
            context.report({
              node: node.property,
              messageId: "useDot",
              data: {
                key: formattedValue
              },
              *fix(fixer) {
                const leftBracket = sourceCode.getTokenAfter(node.object, astUtils.isOpeningBracketToken);
                const rightBracket = sourceCode.getLastToken(node);
                const nextToken = sourceCode.getTokenAfter(node);
                if (sourceCode.commentsExistBetween(leftBracket, rightBracket)) {
                  return;
                }
                if (!node.optional) {
                  yield fixer.insertTextBefore(
                    leftBracket,
                    astUtils.isDecimalInteger(node.object) ? " ." : "."
                  );
                }
                yield fixer.replaceTextRange(
                  [leftBracket.range[0], rightBracket.range[1]],
                  value2
                );
                if (nextToken && rightBracket.range[1] === nextToken.range[0] && !astUtils.canTokensBeAdjacent(String(value2), nextToken)) {
                  yield fixer.insertTextAfter(node, " ");
                }
              }
            });
          }
        }
        return {
          MemberExpression(node) {
            if (node.computed && node.property.type === "Literal" && (literalTypesToCheck.has(typeof node.property.value) || astUtils.isNullLiteral(node.property))) {
              checkComputedProperty(node, node.property.value);
            }
            if (node.computed && node.property.type === "TemplateLiteral" && node.property.expressions.length === 0) {
              checkComputedProperty(node, node.property.quasis[0].value.cooked);
            }
            if (!allowKeywords && !node.computed && node.property.type === "Identifier" && keywords.includes(String(node.property.name))) {
              context.report({
                node: node.property,
                messageId: "useBrackets",
                data: {
                  key: node.property.name
                },
                *fix(fixer) {
                  const dotToken = sourceCode.getTokenBefore(node.property);
                  if (node.object.type === "Identifier" && node.object.name === "let" && !node.optional) {
                    return;
                  }
                  if (sourceCode.commentsExistBetween(dotToken, node.property)) {
                    return;
                  }
                  if (!node.optional) {
                    yield fixer.remove(dotToken);
                  }
                  yield fixer.replaceText(node.property, `["${node.property.name}"]`);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/eol-last.js
var require_eol_last = __commonJS({
  "node_modules/eslint/lib/rules/eol-last.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow newline at the end of files",
          recommended: false,
          url: "https://eslint.org/docs/rules/eol-last"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never", "unix", "windows"]
          }
        ],
        messages: {
          missing: "Newline required at end of file but not found.",
          unexpected: "Newline not allowed at end of file."
        }
      },
      create(context) {
        return {
          Program: function checkBadEOF(node) {
            const sourceCode = context.getSourceCode(), src = sourceCode.getText(), lastLine = sourceCode.lines[sourceCode.lines.length - 1], location = {
              column: lastLine.length,
              line: sourceCode.lines.length
            }, LF = "\n", CRLF = `\r${LF}`, endsWithNewline = src.endsWith(LF);
            if (!src.length) {
              return;
            }
            let mode = context.options[0] || "always", appendCRLF = false;
            if (mode === "unix") {
              mode = "always";
            }
            if (mode === "windows") {
              mode = "always";
              appendCRLF = true;
            }
            if (mode === "always" && !endsWithNewline) {
              context.report({
                node,
                loc: location,
                messageId: "missing",
                fix(fixer) {
                  return fixer.insertTextAfterRange([0, src.length], appendCRLF ? CRLF : LF);
                }
              });
            } else if (mode === "never" && endsWithNewline) {
              const secondLastLine = sourceCode.lines[sourceCode.lines.length - 2];
              context.report({
                node,
                loc: {
                  start: { line: sourceCode.lines.length - 1, column: secondLastLine.length },
                  end: { line: sourceCode.lines.length, column: 0 }
                },
                messageId: "unexpected",
                fix(fixer) {
                  const finalEOLs = /(?:\r?\n)+$/u, match = finalEOLs.exec(sourceCode.text), start = match.index, end = sourceCode.text.length;
                  return fixer.replaceTextRange([start, end], "");
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/eqeqeq.js
var require_eqeqeq = __commonJS({
  "node_modules/eslint/lib/rules/eqeqeq.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require the use of `===` and `!==`",
          recommended: false,
          url: "https://eslint.org/docs/rules/eqeqeq"
        },
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always"]
                },
                {
                  type: "object",
                  properties: {
                    null: {
                      enum: ["always", "never", "ignore"]
                    }
                  },
                  additionalProperties: false
                }
              ],
              additionalItems: false
            },
            {
              type: "array",
              items: [
                {
                  enum: ["smart", "allow-null"]
                }
              ],
              additionalItems: false
            }
          ]
        },
        fixable: "code",
        messages: {
          unexpected: "Expected '{{expectedOperator}}' and instead saw '{{actualOperator}}'."
        }
      },
      create(context) {
        const config = context.options[0] || "always";
        const options = context.options[1] || {};
        const sourceCode = context.getSourceCode();
        const nullOption = config === "always" ? options.null || "always" : "ignore";
        const enforceRuleForNull = nullOption === "always";
        const enforceInverseRuleForNull = nullOption === "never";
        function isTypeOf(node) {
          return node.type === "UnaryExpression" && node.operator === "typeof";
        }
        function isTypeOfBinary(node) {
          return isTypeOf(node.left) || isTypeOf(node.right);
        }
        function areLiteralsAndSameType(node) {
          return node.left.type === "Literal" && node.right.type === "Literal" && typeof node.left.value === typeof node.right.value;
        }
        function isNullCheck(node) {
          return astUtils.isNullLiteral(node.right) || astUtils.isNullLiteral(node.left);
        }
        function report(node, expectedOperator) {
          const operatorToken = sourceCode.getFirstTokenBetween(
            node.left,
            node.right,
            (token) => token.value === node.operator
          );
          context.report({
            node,
            loc: operatorToken.loc,
            messageId: "unexpected",
            data: { expectedOperator, actualOperator: node.operator },
            fix(fixer) {
              if (isTypeOfBinary(node) || areLiteralsAndSameType(node)) {
                return fixer.replaceText(operatorToken, expectedOperator);
              }
              return null;
            }
          });
        }
        return {
          BinaryExpression(node) {
            const isNull2 = isNullCheck(node);
            if (node.operator !== "==" && node.operator !== "!=") {
              if (enforceInverseRuleForNull && isNull2) {
                report(node, node.operator.slice(0, -1));
              }
              return;
            }
            if (config === "smart" && (isTypeOfBinary(node) || areLiteralsAndSameType(node) || isNull2)) {
              return;
            }
            if (!enforceRuleForNull && isNull2) {
              return;
            }
            report(node, `${node.operator}=`);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/for-direction.js
var require_for_direction = __commonJS({
  "node_modules/eslint/lib/rules/for-direction.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: 'Enforce "for" loop update clause moving the counter in the right direction',
          recommended: true,
          url: "https://eslint.org/docs/rules/for-direction"
        },
        fixable: null,
        schema: [],
        messages: {
          incorrectDirection: "The update clause in this loop moves the variable in the wrong direction."
        }
      },
      create(context) {
        function report(node) {
          context.report({
            node,
            messageId: "incorrectDirection"
          });
        }
        function getRightDirection(update, dir) {
          if (update.right.type === "UnaryExpression") {
            if (update.right.operator === "-") {
              return -dir;
            }
          } else if (update.right.type === "Identifier") {
            return 0;
          }
          return dir;
        }
        function getUpdateDirection(update, counter) {
          if (update.argument.type === "Identifier" && update.argument.name === counter) {
            if (update.operator === "++") {
              return 1;
            }
            if (update.operator === "--") {
              return -1;
            }
          }
          return 0;
        }
        function getAssignmentDirection(update, counter) {
          if (update.left.name === counter) {
            if (update.operator === "+=") {
              return getRightDirection(update, 1);
            }
            if (update.operator === "-=") {
              return getRightDirection(update, -1);
            }
          }
          return 0;
        }
        return {
          ForStatement(node) {
            if (node.test && node.test.type === "BinaryExpression" && node.test.left.type === "Identifier" && node.update) {
              const counter = node.test.left.name;
              const operator = node.test.operator;
              const update = node.update;
              let wrongDirection;
              if (operator === "<" || operator === "<=") {
                wrongDirection = -1;
              } else if (operator === ">" || operator === ">=") {
                wrongDirection = 1;
              } else {
                return;
              }
              if (update.type === "UpdateExpression") {
                if (getUpdateDirection(update, counter) === wrongDirection) {
                  report(node);
                }
              } else if (update.type === "AssignmentExpression" && getAssignmentDirection(update, counter) === wrongDirection) {
                report(node);
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/func-call-spacing.js
var require_func_call_spacing = __commonJS({
  "node_modules/eslint/lib/rules/func-call-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow spacing between function identifiers and their invocations",
          recommended: false,
          url: "https://eslint.org/docs/rules/func-call-spacing"
        },
        fixable: "whitespace",
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["never"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["always"]
                },
                {
                  type: "object",
                  properties: {
                    allowNewlines: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        messages: {
          unexpectedWhitespace: "Unexpected whitespace between function name and paren.",
          unexpectedNewline: "Unexpected newline between function name and paren.",
          missing: "Missing space between function name and paren."
        }
      },
      create(context) {
        const never = context.options[0] !== "always";
        const allowNewlines = !never && context.options[1] && context.options[1].allowNewlines;
        const sourceCode = context.getSourceCode();
        const text = sourceCode.getText();
        function checkSpacing(node, leftToken, rightToken) {
          const textBetweenTokens = text.slice(leftToken.range[1], rightToken.range[0]).replace(/\/\*.*?\*\//gu, "");
          const hasWhitespace = /\s/u.test(textBetweenTokens);
          const hasNewline = hasWhitespace && astUtils.LINEBREAK_MATCHER.test(textBetweenTokens);
          if (never && hasWhitespace) {
            context.report({
              node,
              loc: {
                start: leftToken.loc.end,
                end: {
                  line: rightToken.loc.start.line,
                  column: rightToken.loc.start.column - 1
                }
              },
              messageId: "unexpectedWhitespace",
              fix(fixer) {
                if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                  return null;
                }
                if (node.optional) {
                  return fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], "?.");
                }
                if (hasNewline) {
                  return null;
                }
                return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
              }
            });
          } else if (!never && !hasWhitespace) {
            context.report({
              node,
              loc: {
                start: {
                  line: leftToken.loc.end.line,
                  column: leftToken.loc.end.column - 1
                },
                end: rightToken.loc.start
              },
              messageId: "missing",
              fix(fixer) {
                if (node.optional) {
                  return null;
                }
                return fixer.insertTextBefore(rightToken, " ");
              }
            });
          } else if (!never && !allowNewlines && hasNewline) {
            context.report({
              node,
              loc: {
                start: leftToken.loc.end,
                end: rightToken.loc.start
              },
              messageId: "unexpectedNewline",
              fix(fixer) {
                if (!node.optional) {
                  return null;
                }
                if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                  return null;
                }
                const range = [leftToken.range[1], rightToken.range[0]];
                const qdToken = sourceCode.getTokenAfter(leftToken);
                if (qdToken.range[0] === leftToken.range[1]) {
                  return fixer.replaceTextRange(range, "?. ");
                }
                if (qdToken.range[1] === rightToken.range[0]) {
                  return fixer.replaceTextRange(range, " ?.");
                }
                return fixer.replaceTextRange(range, " ?. ");
              }
            });
          }
        }
        return {
          "CallExpression, NewExpression"(node) {
            const lastToken = sourceCode.getLastToken(node);
            const lastCalleeToken = sourceCode.getLastToken(node.callee);
            const parenToken = sourceCode.getFirstTokenBetween(lastCalleeToken, lastToken, astUtils.isOpeningParenToken);
            const prevToken = parenToken && sourceCode.getTokenBefore(parenToken, astUtils.isNotQuestionDotToken);
            if (!(parenToken && parenToken.range[1] < node.range[1])) {
              return;
            }
            checkSpacing(node, prevToken, parenToken);
          },
          ImportExpression(node) {
            const leftToken = sourceCode.getFirstToken(node);
            const rightToken = sourceCode.getTokenAfter(leftToken);
            checkSpacing(node, leftToken, rightToken);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/func-name-matching.js
var require_func_name_matching = __commonJS({
  "node_modules/eslint/lib/rules/func-name-matching.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var esutils = require_utils2();
    function isModuleExports(pattern) {
      if (pattern.type === "MemberExpression" && pattern.object.type === "Identifier" && pattern.object.name === "module") {
        if (pattern.property.type === "Identifier" && pattern.property.name === "exports") {
          return true;
        }
        if (pattern.property.type === "Literal" && pattern.property.value === "exports") {
          return true;
        }
      }
      return false;
    }
    function isIdentifier2(name, ecmaVersion) {
      if (ecmaVersion >= 2015) {
        return esutils.keyword.isIdentifierES6(name);
      }
      return esutils.keyword.isIdentifierES5(name);
    }
    var alwaysOrNever = { enum: ["always", "never"] };
    var optionsObject = {
      type: "object",
      properties: {
        considerPropertyDescriptor: {
          type: "boolean"
        },
        includeCommonJSModuleExports: {
          type: "boolean"
        }
      },
      additionalProperties: false
    };
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require function names to match the name of the variable or property to which they are assigned",
          recommended: false,
          url: "https://eslint.org/docs/rules/func-name-matching"
        },
        schema: {
          anyOf: [{
            type: "array",
            additionalItems: false,
            items: [alwaysOrNever, optionsObject]
          }, {
            type: "array",
            additionalItems: false,
            items: [optionsObject]
          }]
        },
        messages: {
          matchProperty: "Function name `{{funcName}}` should match property name `{{name}}`.",
          matchVariable: "Function name `{{funcName}}` should match variable name `{{name}}`.",
          notMatchProperty: "Function name `{{funcName}}` should not match property name `{{name}}`.",
          notMatchVariable: "Function name `{{funcName}}` should not match variable name `{{name}}`."
        }
      },
      create(context) {
        const options = (typeof context.options[0] === "object" ? context.options[0] : context.options[1]) || {};
        const nameMatches = typeof context.options[0] === "string" ? context.options[0] : "always";
        const considerPropertyDescriptor = options.considerPropertyDescriptor;
        const includeModuleExports = options.includeCommonJSModuleExports;
        const ecmaVersion = context.languageOptions.ecmaVersion;
        function isPropertyCall(objName, funcName, node) {
          if (!node) {
            return false;
          }
          return node.type === "CallExpression" && astUtils.isSpecificMemberAccess(node.callee, objName, funcName);
        }
        function shouldWarn(x, y) {
          return nameMatches === "always" && x !== y || nameMatches === "never" && x === y;
        }
        function report(node, name, funcName, isProp) {
          let messageId;
          if (nameMatches === "always" && isProp) {
            messageId = "matchProperty";
          } else if (nameMatches === "always") {
            messageId = "matchVariable";
          } else if (isProp) {
            messageId = "notMatchProperty";
          } else {
            messageId = "notMatchVariable";
          }
          context.report({
            node,
            messageId,
            data: {
              name,
              funcName
            }
          });
        }
        function isStringLiteral3(node) {
          return node.type === "Literal" && typeof node.value === "string";
        }
        return {
          VariableDeclarator(node) {
            if (!node.init || node.init.type !== "FunctionExpression" || node.id.type !== "Identifier") {
              return;
            }
            if (node.init.id && shouldWarn(node.id.name, node.init.id.name)) {
              report(node, node.id.name, node.init.id.name, false);
            }
          },
          AssignmentExpression(node) {
            if (node.right.type !== "FunctionExpression" || node.left.computed && node.left.property.type !== "Literal" || !includeModuleExports && isModuleExports(node.left) || node.left.type !== "Identifier" && node.left.type !== "MemberExpression") {
              return;
            }
            const isProp = node.left.type === "MemberExpression";
            const name = isProp ? astUtils.getStaticPropertyName(node.left) : node.left.name;
            if (node.right.id && name && isIdentifier2(name) && shouldWarn(name, node.right.id.name)) {
              report(node, name, node.right.id.name, isProp);
            }
          },
          "Property, PropertyDefinition[value]"(node) {
            if (!(node.value.type === "FunctionExpression" && node.value.id)) {
              return;
            }
            if (node.key.type === "Identifier" && !node.computed) {
              const functionName = node.value.id.name;
              let propertyName = node.key.name;
              if (considerPropertyDescriptor && propertyName === "value" && node.parent.type === "ObjectExpression") {
                if (isPropertyCall("Object", "defineProperty", node.parent.parent) || isPropertyCall("Reflect", "defineProperty", node.parent.parent)) {
                  const property = node.parent.parent.arguments[1];
                  if (isStringLiteral3(property) && shouldWarn(property.value, functionName)) {
                    report(node, property.value, functionName, true);
                  }
                } else if (isPropertyCall("Object", "defineProperties", node.parent.parent.parent.parent)) {
                  propertyName = node.parent.parent.key.name;
                  if (!node.parent.parent.computed && shouldWarn(propertyName, functionName)) {
                    report(node, propertyName, functionName, true);
                  }
                } else if (isPropertyCall("Object", "create", node.parent.parent.parent.parent)) {
                  propertyName = node.parent.parent.key.name;
                  if (!node.parent.parent.computed && shouldWarn(propertyName, functionName)) {
                    report(node, propertyName, functionName, true);
                  }
                } else if (shouldWarn(propertyName, functionName)) {
                  report(node, propertyName, functionName, true);
                }
              } else if (shouldWarn(propertyName, functionName)) {
                report(node, propertyName, functionName, true);
              }
              return;
            }
            if (isStringLiteral3(node.key) && isIdentifier2(node.key.value, ecmaVersion) && shouldWarn(node.key.value, node.value.id.name)) {
              report(node, node.key.value, node.value.id.name, true);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/func-names.js
var require_func_names = __commonJS({
  "node_modules/eslint/lib/rules/func-names.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isFunctionName(variable) {
      return variable && variable.defs[0].type === "FunctionName";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow named `function` expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/func-names"
        },
        schema: {
          definitions: {
            value: {
              enum: [
                "always",
                "as-needed",
                "never"
              ]
            }
          },
          items: [
            {
              $ref: "#/definitions/value"
            },
            {
              type: "object",
              properties: {
                generators: {
                  $ref: "#/definitions/value"
                }
              },
              additionalProperties: false
            }
          ]
        },
        messages: {
          unnamed: "Unexpected unnamed {{name}}.",
          named: "Unexpected named {{name}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function getConfigForNode(node) {
          if (node.generator && context.options.length > 1 && context.options[1].generators) {
            return context.options[1].generators;
          }
          return context.options[0] || "always";
        }
        function isObjectOrClassMethod(node) {
          const parent = node.parent;
          return parent.type === "MethodDefinition" || parent.type === "Property" && (parent.method || parent.kind === "get" || parent.kind === "set");
        }
        function hasInferredName(node) {
          const parent = node.parent;
          return isObjectOrClassMethod(node) || parent.type === "VariableDeclarator" && parent.id.type === "Identifier" && parent.init === node || parent.type === "Property" && parent.value === node || parent.type === "PropertyDefinition" && parent.value === node || parent.type === "AssignmentExpression" && parent.left.type === "Identifier" && parent.right === node || parent.type === "AssignmentPattern" && parent.left.type === "Identifier" && parent.right === node;
        }
        function reportUnexpectedUnnamedFunction(node) {
          context.report({
            node,
            messageId: "unnamed",
            loc: astUtils.getFunctionHeadLoc(node, sourceCode),
            data: { name: astUtils.getFunctionNameWithKind(node) }
          });
        }
        function reportUnexpectedNamedFunction(node) {
          context.report({
            node,
            messageId: "named",
            loc: astUtils.getFunctionHeadLoc(node, sourceCode),
            data: { name: astUtils.getFunctionNameWithKind(node) }
          });
        }
        function handleFunction(node) {
          const nameVar = context.getDeclaredVariables(node)[0];
          if (isFunctionName(nameVar) && nameVar.references.length > 0) {
            return;
          }
          const hasName = Boolean(node.id && node.id.name);
          const config = getConfigForNode(node);
          if (config === "never") {
            if (hasName && node.type !== "FunctionDeclaration") {
              reportUnexpectedNamedFunction(node);
            }
          } else if (config === "as-needed") {
            if (!hasName && !hasInferredName(node)) {
              reportUnexpectedUnnamedFunction(node);
            }
          } else {
            if (!hasName && !isObjectOrClassMethod(node)) {
              reportUnexpectedUnnamedFunction(node);
            }
          }
        }
        return {
          "FunctionExpression:exit": handleFunction,
          "ExportDefaultDeclaration > FunctionDeclaration": handleFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/func-style.js
var require_func_style = __commonJS({
  "node_modules/eslint/lib/rules/func-style.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce the consistent use of either `function` declarations or expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/func-style"
        },
        schema: [
          {
            enum: ["declaration", "expression"]
          },
          {
            type: "object",
            properties: {
              allowArrowFunctions: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expression: "Expected a function expression.",
          declaration: "Expected a function declaration."
        }
      },
      create(context) {
        const style = context.options[0], allowArrowFunctions = context.options[1] && context.options[1].allowArrowFunctions, enforceDeclarations = style === "declaration", stack = [];
        const nodesToCheck = {
          FunctionDeclaration(node) {
            stack.push(false);
            if (!enforceDeclarations && node.parent.type !== "ExportDefaultDeclaration") {
              context.report({ node, messageId: "expression" });
            }
          },
          "FunctionDeclaration:exit"() {
            stack.pop();
          },
          FunctionExpression(node) {
            stack.push(false);
            if (enforceDeclarations && node.parent.type === "VariableDeclarator") {
              context.report({ node: node.parent, messageId: "declaration" });
            }
          },
          "FunctionExpression:exit"() {
            stack.pop();
          },
          ThisExpression() {
            if (stack.length > 0) {
              stack[stack.length - 1] = true;
            }
          }
        };
        if (!allowArrowFunctions) {
          nodesToCheck.ArrowFunctionExpression = function() {
            stack.push(false);
          };
          nodesToCheck["ArrowFunctionExpression:exit"] = function(node) {
            const hasThisExpr = stack.pop();
            if (enforceDeclarations && !hasThisExpr && node.parent.type === "VariableDeclarator") {
              context.report({ node: node.parent, messageId: "declaration" });
            }
          };
        }
        return nodesToCheck;
      }
    };
  }
});

// node_modules/eslint/lib/rules/function-call-argument-newline.js
var require_function_call_argument_newline = __commonJS({
  "node_modules/eslint/lib/rules/function-call-argument-newline.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce line breaks between arguments of a function call",
          recommended: false,
          url: "https://eslint.org/docs/rules/function-call-argument-newline"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never", "consistent"]
          }
        ],
        messages: {
          unexpectedLineBreak: "There should be no line break here.",
          missingLineBreak: "There should be a line break after this argument."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const checkers = {
          unexpected: {
            messageId: "unexpectedLineBreak",
            check: (prevToken, currentToken) => prevToken.loc.end.line !== currentToken.loc.start.line,
            createFix: (token, tokenBefore) => (fixer) => fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], " ")
          },
          missing: {
            messageId: "missingLineBreak",
            check: (prevToken, currentToken) => prevToken.loc.end.line === currentToken.loc.start.line,
            createFix: (token, tokenBefore) => (fixer) => fixer.replaceTextRange([tokenBefore.range[1], token.range[0]], "\n")
          }
        };
        function checkArguments(node, checker) {
          for (let i = 1; i < node.arguments.length; i++) {
            const prevArgToken = sourceCode.getLastToken(node.arguments[i - 1]);
            const currentArgToken = sourceCode.getFirstToken(node.arguments[i]);
            if (checker.check(prevArgToken, currentArgToken)) {
              const tokenBefore = sourceCode.getTokenBefore(
                currentArgToken,
                { includeComments: true }
              );
              const hasLineCommentBefore = tokenBefore.type === "Line";
              context.report({
                node,
                loc: {
                  start: tokenBefore.loc.end,
                  end: currentArgToken.loc.start
                },
                messageId: checker.messageId,
                fix: hasLineCommentBefore ? null : checker.createFix(currentArgToken, tokenBefore)
              });
            }
          }
        }
        function check(node) {
          if (node.arguments.length < 2) {
            return;
          }
          const option = context.options[0] || "always";
          if (option === "never") {
            checkArguments(node, checkers.unexpected);
          } else if (option === "always") {
            checkArguments(node, checkers.missing);
          } else if (option === "consistent") {
            const firstArgToken = sourceCode.getLastToken(node.arguments[0]);
            const secondArgToken = sourceCode.getFirstToken(node.arguments[1]);
            if (firstArgToken.loc.end.line === secondArgToken.loc.start.line) {
              checkArguments(node, checkers.unexpected);
            } else {
              checkArguments(node, checkers.missing);
            }
          }
        }
        return {
          CallExpression: check,
          NewExpression: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/function-paren-newline.js
var require_function_paren_newline = __commonJS({
  "node_modules/eslint/lib/rules/function-paren-newline.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent line breaks inside function parentheses",
          recommended: false,
          url: "https://eslint.org/docs/rules/function-paren-newline"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never", "consistent", "multiline", "multiline-arguments"]
              },
              {
                type: "object",
                properties: {
                  minItems: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          expectedBefore: "Expected newline before ')'.",
          expectedAfter: "Expected newline after '('.",
          expectedBetween: "Expected newline between arguments/params.",
          unexpectedBefore: "Unexpected newline before ')'.",
          unexpectedAfter: "Unexpected newline after '('."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const rawOption = context.options[0] || "multiline";
        const multilineOption = rawOption === "multiline";
        const multilineArgumentsOption = rawOption === "multiline-arguments";
        const consistentOption = rawOption === "consistent";
        let minItems;
        if (typeof rawOption === "object") {
          minItems = rawOption.minItems;
        } else if (rawOption === "always") {
          minItems = 0;
        } else if (rawOption === "never") {
          minItems = Infinity;
        } else {
          minItems = null;
        }
        function shouldHaveNewlines(elements, hasLeftNewline) {
          if (multilineArgumentsOption && elements.length === 1) {
            return hasLeftNewline;
          }
          if (multilineOption || multilineArgumentsOption) {
            return elements.some((element, index) => index !== elements.length - 1 && element.loc.end.line !== elements[index + 1].loc.start.line);
          }
          if (consistentOption) {
            return hasLeftNewline;
          }
          return elements.length >= minItems;
        }
        function validateParens(parens, elements) {
          const leftParen = parens.leftParen;
          const rightParen = parens.rightParen;
          const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParen);
          const tokenBeforeRightParen = sourceCode.getTokenBefore(rightParen);
          const hasLeftNewline = !astUtils.isTokenOnSameLine(leftParen, tokenAfterLeftParen);
          const hasRightNewline = !astUtils.isTokenOnSameLine(tokenBeforeRightParen, rightParen);
          const needsNewlines = shouldHaveNewlines(elements, hasLeftNewline);
          if (hasLeftNewline && !needsNewlines) {
            context.report({
              node: leftParen,
              messageId: "unexpectedAfter",
              fix(fixer) {
                return sourceCode.getText().slice(leftParen.range[1], tokenAfterLeftParen.range[0]).trim() ? null : fixer.removeRange([leftParen.range[1], tokenAfterLeftParen.range[0]]);
              }
            });
          } else if (!hasLeftNewline && needsNewlines) {
            context.report({
              node: leftParen,
              messageId: "expectedAfter",
              fix: (fixer) => fixer.insertTextAfter(leftParen, "\n")
            });
          }
          if (hasRightNewline && !needsNewlines) {
            context.report({
              node: rightParen,
              messageId: "unexpectedBefore",
              fix(fixer) {
                return sourceCode.getText().slice(tokenBeforeRightParen.range[1], rightParen.range[0]).trim() ? null : fixer.removeRange([tokenBeforeRightParen.range[1], rightParen.range[0]]);
              }
            });
          } else if (!hasRightNewline && needsNewlines) {
            context.report({
              node: rightParen,
              messageId: "expectedBefore",
              fix: (fixer) => fixer.insertTextBefore(rightParen, "\n")
            });
          }
        }
        function validateArguments(parens, elements) {
          const leftParen = parens.leftParen;
          const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParen);
          const hasLeftNewline = !astUtils.isTokenOnSameLine(leftParen, tokenAfterLeftParen);
          const needsNewlines = shouldHaveNewlines(elements, hasLeftNewline);
          for (let i = 0; i <= elements.length - 2; i++) {
            const currentElement = elements[i];
            const nextElement = elements[i + 1];
            const hasNewLine = currentElement.loc.end.line !== nextElement.loc.start.line;
            if (!hasNewLine && needsNewlines) {
              context.report({
                node: currentElement,
                messageId: "expectedBetween",
                fix: (fixer) => fixer.insertTextBefore(nextElement, "\n")
              });
            }
          }
        }
        function getParenTokens(node) {
          switch (node.type) {
            case "NewExpression":
              if (!node.arguments.length && !(astUtils.isOpeningParenToken(sourceCode.getLastToken(node, { skip: 1 })) && astUtils.isClosingParenToken(sourceCode.getLastToken(node)) && node.callee.range[1] < node.range[1])) {
                return null;
              }
            case "CallExpression":
              return {
                leftParen: sourceCode.getTokenAfter(node.callee, astUtils.isOpeningParenToken),
                rightParen: sourceCode.getLastToken(node)
              };
            case "FunctionDeclaration":
            case "FunctionExpression": {
              const leftParen = sourceCode.getFirstToken(node, astUtils.isOpeningParenToken);
              const rightParen = node.params.length ? sourceCode.getTokenAfter(node.params[node.params.length - 1], astUtils.isClosingParenToken) : sourceCode.getTokenAfter(leftParen);
              return { leftParen, rightParen };
            }
            case "ArrowFunctionExpression": {
              const firstToken = sourceCode.getFirstToken(node, { skip: node.async ? 1 : 0 });
              if (!astUtils.isOpeningParenToken(firstToken)) {
                return null;
              }
              const rightParen = node.params.length ? sourceCode.getTokenAfter(node.params[node.params.length - 1], astUtils.isClosingParenToken) : sourceCode.getTokenAfter(firstToken);
              return {
                leftParen: firstToken,
                rightParen
              };
            }
            case "ImportExpression": {
              const leftParen = sourceCode.getFirstToken(node, 1);
              const rightParen = sourceCode.getLastToken(node);
              return { leftParen, rightParen };
            }
            default:
              throw new TypeError(`unexpected node with type ${node.type}`);
          }
        }
        return {
          [[
            "ArrowFunctionExpression",
            "CallExpression",
            "FunctionDeclaration",
            "FunctionExpression",
            "ImportExpression",
            "NewExpression"
          ]](node) {
            const parens = getParenTokens(node);
            let params;
            if (node.type === "ImportExpression") {
              params = [node.source];
            } else if (astUtils.isFunction(node)) {
              params = node.params;
            } else {
              params = node.arguments;
            }
            if (parens) {
              validateParens(parens, params);
              if (multilineArgumentsOption) {
                validateArguments(parens, params);
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/generator-star-spacing.js
var require_generator_star_spacing = __commonJS({
  "node_modules/eslint/lib/rules/generator-star-spacing.js"(exports, module2) {
    "use strict";
    var OVERRIDE_SCHEMA = {
      oneOf: [
        {
          enum: ["before", "after", "both", "neither"]
        },
        {
          type: "object",
          properties: {
            before: { type: "boolean" },
            after: { type: "boolean" }
          },
          additionalProperties: false
        }
      ]
    };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing around `*` operators in generator functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/generator-star-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["before", "after", "both", "neither"]
              },
              {
                type: "object",
                properties: {
                  before: { type: "boolean" },
                  after: { type: "boolean" },
                  named: OVERRIDE_SCHEMA,
                  anonymous: OVERRIDE_SCHEMA,
                  method: OVERRIDE_SCHEMA
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          missingBefore: "Missing space before *.",
          missingAfter: "Missing space after *.",
          unexpectedBefore: "Unexpected space before *.",
          unexpectedAfter: "Unexpected space after *."
        }
      },
      create(context) {
        const optionDefinitions = {
          before: { before: true, after: false },
          after: { before: false, after: true },
          both: { before: true, after: true },
          neither: { before: false, after: false }
        };
        function optionToDefinition(option, defaults) {
          if (!option) {
            return defaults;
          }
          return typeof option === "string" ? optionDefinitions[option] : Object.assign({}, defaults, option);
        }
        const modes = function(option) {
          const defaults = optionToDefinition(option, optionDefinitions.before);
          return {
            named: optionToDefinition(option.named, defaults),
            anonymous: optionToDefinition(option.anonymous, defaults),
            method: optionToDefinition(option.method, defaults)
          };
        }(context.options[0] || {});
        const sourceCode = context.getSourceCode();
        function isStarToken(token) {
          return token.value === "*" && token.type === "Punctuator";
        }
        function getStarToken(node) {
          return sourceCode.getFirstToken(
            node.parent.method || node.parent.type === "MethodDefinition" ? node.parent : node,
            isStarToken
          );
        }
        function capitalize(str) {
          return str[0].toUpperCase() + str.slice(1);
        }
        function checkSpacing(kind, side, leftToken, rightToken) {
          if (!!(rightToken.range[0] - leftToken.range[1]) !== modes[kind][side]) {
            const after = leftToken.value === "*";
            const spaceRequired = modes[kind][side];
            const node = after ? leftToken : rightToken;
            const messageId = `${spaceRequired ? "missing" : "unexpected"}${capitalize(side)}`;
            context.report({
              node,
              messageId,
              fix(fixer) {
                if (spaceRequired) {
                  if (after) {
                    return fixer.insertTextAfter(node, " ");
                  }
                  return fixer.insertTextBefore(node, " ");
                }
                return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
              }
            });
          }
        }
        function checkFunction(node) {
          if (!node.generator) {
            return;
          }
          const starToken = getStarToken(node);
          const prevToken = sourceCode.getTokenBefore(starToken);
          const nextToken = sourceCode.getTokenAfter(starToken);
          let kind = "named";
          if (node.parent.type === "MethodDefinition" || node.parent.type === "Property" && node.parent.method) {
            kind = "method";
          } else if (!node.id) {
            kind = "anonymous";
          }
          if (!(kind === "method" && starToken === sourceCode.getFirstToken(node.parent))) {
            checkSpacing(kind, "before", prevToken, starToken);
          }
          checkSpacing(kind, "after", starToken, nextToken);
        }
        return {
          FunctionDeclaration: checkFunction,
          FunctionExpression: checkFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/getter-return.js
var require_getter_return = __commonJS({
  "node_modules/eslint/lib/rules/getter-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var TARGET_NODE_TYPE = /^(?:Arrow)?FunctionExpression$/u;
    function isReachable(segment) {
      return segment.reachable;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Enforce `return` statements in getters",
          recommended: true,
          url: "https://eslint.org/docs/rules/getter-return"
        },
        fixable: null,
        schema: [
          {
            type: "object",
            properties: {
              allowImplicit: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expected: "Expected to return a value in {{name}}.",
          expectedAlways: "Expected {{name}} to always return a value."
        }
      },
      create(context) {
        const options = context.options[0] || { allowImplicit: false };
        const sourceCode = context.getSourceCode();
        let funcInfo = {
          upper: null,
          codePath: null,
          hasReturn: false,
          shouldCheck: false,
          node: null
        };
        function checkLastSegment(node) {
          if (funcInfo.shouldCheck && funcInfo.codePath.currentSegments.some(isReachable)) {
            context.report({
              node,
              loc: astUtils.getFunctionHeadLoc(node, sourceCode),
              messageId: funcInfo.hasReturn ? "expectedAlways" : "expected",
              data: {
                name: astUtils.getFunctionNameWithKind(funcInfo.node)
              }
            });
          }
        }
        function isGetter(node) {
          const parent = node.parent;
          if (TARGET_NODE_TYPE.test(node.type) && node.body.type === "BlockStatement") {
            if (parent.kind === "get") {
              return true;
            }
            if (parent.type === "Property" && astUtils.getStaticPropertyName(parent) === "get" && parent.parent.type === "ObjectExpression") {
              if (parent.parent.parent.type === "CallExpression") {
                const callNode = parent.parent.parent.callee;
                if (astUtils.isSpecificMemberAccess(callNode, "Object", "defineProperty") || astUtils.isSpecificMemberAccess(callNode, "Reflect", "defineProperty")) {
                  return true;
                }
              }
              if (parent.parent.parent.type === "Property" && parent.parent.parent.parent.type === "ObjectExpression" && parent.parent.parent.parent.parent.type === "CallExpression") {
                const callNode = parent.parent.parent.parent.parent.callee;
                return astUtils.isSpecificMemberAccess(callNode, "Object", "defineProperties") || astUtils.isSpecificMemberAccess(callNode, "Object", "create");
              }
            }
          }
          return false;
        }
        return {
          // Stacks this function's information.
          onCodePathStart(codePath, node) {
            funcInfo = {
              upper: funcInfo,
              codePath,
              hasReturn: false,
              shouldCheck: isGetter(node),
              node
            };
          },
          // Pops this function's information.
          onCodePathEnd() {
            funcInfo = funcInfo.upper;
          },
          // Checks the return statement is valid.
          ReturnStatement(node) {
            if (funcInfo.shouldCheck) {
              funcInfo.hasReturn = true;
              if (!options.allowImplicit && !node.argument) {
                context.report({
                  node,
                  messageId: "expected",
                  data: {
                    name: astUtils.getFunctionNameWithKind(funcInfo.node)
                  }
                });
              }
            }
          },
          // Reports a given function if the last path is reachable.
          "FunctionExpression:exit": checkLastSegment,
          "ArrowFunctionExpression:exit": checkLastSegment
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/global-require.js
var require_global_require = __commonJS({
  "node_modules/eslint/lib/rules/global-require.js"(exports, module2) {
    "use strict";
    var ACCEPTABLE_PARENTS = /* @__PURE__ */ new Set([
      "AssignmentExpression",
      "VariableDeclarator",
      "MemberExpression",
      "ExpressionStatement",
      "CallExpression",
      "ConditionalExpression",
      "Program",
      "VariableDeclaration",
      "ChainExpression"
    ]);
    function findReference(scope, node) {
      const references = scope.references.filter((reference) => reference.identifier.range[0] === node.range[0] && reference.identifier.range[1] === node.range[1]);
      if (references.length === 1) {
        return references[0];
      }
      return null;
    }
    function isShadowed(scope, node) {
      const reference = findReference(scope, node);
      return reference && reference.resolved && reference.resolved.defs.length > 0;
    }
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Require `require()` calls to be placed at top-level module scope",
          recommended: false,
          url: "https://eslint.org/docs/rules/global-require"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected require()."
        }
      },
      create(context) {
        return {
          CallExpression(node) {
            const currentScope = context.getScope();
            if (node.callee.name === "require" && !isShadowed(currentScope, node.callee)) {
              const isGoodRequire = context.getAncestors().every((parent) => ACCEPTABLE_PARENTS.has(parent.type));
              if (!isGoodRequire) {
                context.report({ node, messageId: "unexpected" });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/grouped-accessor-pairs.js
var require_grouped_accessor_pairs = __commonJS({
  "node_modules/eslint/lib/rules/grouped-accessor-pairs.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function areEqualTokenLists(left, right) {
      if (left.length !== right.length) {
        return false;
      }
      for (let i = 0; i < left.length; i++) {
        const leftToken = left[i], rightToken = right[i];
        if (leftToken.type !== rightToken.type || leftToken.value !== rightToken.value) {
          return false;
        }
      }
      return true;
    }
    function areEqualKeys(left, right) {
      if (typeof left === "string" && typeof right === "string") {
        return left === right;
      }
      if (Array.isArray(left) && Array.isArray(right)) {
        return areEqualTokenLists(left, right);
      }
      return false;
    }
    function isAccessorKind(node) {
      return node.kind === "get" || node.kind === "set";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require grouped accessor pairs in object literals and classes",
          recommended: false,
          url: "https://eslint.org/docs/rules/grouped-accessor-pairs"
        },
        schema: [
          {
            enum: ["anyOrder", "getBeforeSet", "setBeforeGet"]
          }
        ],
        messages: {
          notGrouped: "Accessor pair {{ formerName }} and {{ latterName }} should be grouped.",
          invalidOrder: "Expected {{ latterName }} to be before {{ formerName }}."
        }
      },
      create(context) {
        const order = context.options[0] || "anyOrder";
        const sourceCode = context.getSourceCode();
        function report(messageId, formerNode, latterNode) {
          context.report({
            node: latterNode,
            messageId,
            loc: astUtils.getFunctionHeadLoc(latterNode.value, sourceCode),
            data: {
              formerName: astUtils.getFunctionNameWithKind(formerNode.value),
              latterName: astUtils.getFunctionNameWithKind(latterNode.value)
            }
          });
        }
        function createAccessorData(node) {
          const name = astUtils.getStaticPropertyName(node);
          const key = name !== null ? name : sourceCode.getTokens(node.key);
          return {
            key,
            getters: node.kind === "get" ? [node] : [],
            setters: node.kind === "set" ? [node] : []
          };
        }
        function mergeAccessorData(accessors, accessorData) {
          const equalKeyElement = accessors.find((a) => areEqualKeys(a.key, accessorData.key));
          if (equalKeyElement) {
            equalKeyElement.getters.push(...accessorData.getters);
            equalKeyElement.setters.push(...accessorData.setters);
          } else {
            accessors.push(accessorData);
          }
          return accessors;
        }
        function checkList(nodes, shouldCheck) {
          const accessors = nodes.filter(shouldCheck).filter(isAccessorKind).map(createAccessorData).reduce(mergeAccessorData, []);
          for (const { getters, setters } of accessors) {
            if (getters.length === 1 && setters.length === 1) {
              const [getter] = getters, [setter] = setters, getterIndex = nodes.indexOf(getter), setterIndex = nodes.indexOf(setter), formerNode = getterIndex < setterIndex ? getter : setter, latterNode = getterIndex < setterIndex ? setter : getter;
              if (Math.abs(getterIndex - setterIndex) > 1) {
                report("notGrouped", formerNode, latterNode);
              } else if (order === "getBeforeSet" && getterIndex > setterIndex || order === "setBeforeGet" && getterIndex < setterIndex) {
                report("invalidOrder", formerNode, latterNode);
              }
            }
          }
        }
        return {
          ObjectExpression(node) {
            checkList(node.properties, (n) => n.type === "Property");
          },
          ClassBody(node) {
            checkList(node.body, (n) => n.type === "MethodDefinition" && !n.static);
            checkList(node.body, (n) => n.type === "MethodDefinition" && n.static);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/guard-for-in.js
var require_guard_for_in = __commonJS({
  "node_modules/eslint/lib/rules/guard-for-in.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `for-in` loops to include an `if` statement",
          recommended: false,
          url: "https://eslint.org/docs/rules/guard-for-in"
        },
        schema: [],
        messages: {
          wrap: "The body of a for-in should be wrapped in an if statement to filter unwanted properties from the prototype."
        }
      },
      create(context) {
        return {
          ForInStatement(node) {
            const body = node.body;
            if (body.type === "EmptyStatement") {
              return;
            }
            if (body.type === "IfStatement") {
              return;
            }
            if (body.type === "BlockStatement" && body.body.length === 0) {
              return;
            }
            if (body.type === "BlockStatement" && body.body.length === 1 && body.body[0].type === "IfStatement") {
              return;
            }
            if (body.type === "BlockStatement" && body.body.length >= 1 && body.body[0].type === "IfStatement") {
              const i = body.body[0];
              if (i.consequent.type === "ContinueStatement") {
                return;
              }
              if (i.consequent.type === "BlockStatement" && i.consequent.body.length === 1 && i.consequent.body[0].type === "ContinueStatement") {
                return;
              }
            }
            context.report({ node, messageId: "wrap" });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/handle-callback-err.js
var require_handle_callback_err = __commonJS({
  "node_modules/eslint/lib/rules/handle-callback-err.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Require error handling in callbacks",
          recommended: false,
          url: "https://eslint.org/docs/rules/handle-callback-err"
        },
        schema: [
          {
            type: "string"
          }
        ],
        messages: {
          expected: "Expected error to be handled."
        }
      },
      create(context) {
        const errorArgument = context.options[0] || "err";
        function isPattern(stringToCheck) {
          const firstChar = stringToCheck[0];
          return firstChar === "^";
        }
        function matchesConfiguredErrorName(name) {
          if (isPattern(errorArgument)) {
            const regexp = new RegExp(errorArgument, "u");
            return regexp.test(name);
          }
          return name === errorArgument;
        }
        function getParameters(scope) {
          return scope.variables.filter((variable) => variable.defs[0] && variable.defs[0].type === "Parameter");
        }
        function checkForError(node) {
          const scope = context.getScope(), parameters = getParameters(scope), firstParameter = parameters[0];
          if (firstParameter && matchesConfiguredErrorName(firstParameter.name)) {
            if (firstParameter.references.length === 0) {
              context.report({ node, messageId: "expected" });
            }
          }
        }
        return {
          FunctionDeclaration: checkForError,
          FunctionExpression: checkForError,
          ArrowFunctionExpression: checkForError
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/id-blacklist.js
var require_id_blacklist = __commonJS({
  "node_modules/eslint/lib/rules/id-blacklist.js"(exports, module2) {
    "use strict";
    function isAssignmentTarget(node) {
      const parent = node.parent;
      return (
        // normal assignment
        parent.type === "AssignmentExpression" && parent.left === node || // destructuring
        parent.type === "ArrayPattern" || parent.type === "RestElement" || parent.type === "Property" && parent.value === node && parent.parent.type === "ObjectPattern" || parent.type === "AssignmentPattern" && parent.left === node
      );
    }
    function isRenamedImport(node) {
      const parent = node.parent;
      return parent.type === "ImportSpecifier" && parent.imported !== parent.local && parent.imported === node || parent.type === "ExportSpecifier" && parent.parent.source && // re-export
      parent.local !== parent.exported && parent.local === node;
    }
    function isRenamedInDestructuring(node) {
      const parent = node.parent;
      return !parent.computed && parent.type === "Property" && parent.parent.type === "ObjectPattern" && parent.value !== node && parent.key === node;
    }
    function isShorthandPropertyDefinition(node) {
      const parent = node.parent;
      return parent.type === "Property" && parent.parent.type === "ObjectExpression" && parent.shorthand;
    }
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: ["id-denylist"],
        type: "suggestion",
        docs: {
          description: "Disallow specified identifiers",
          recommended: false,
          url: "https://eslint.org/docs/rules/id-blacklist"
        },
        schema: {
          type: "array",
          items: {
            type: "string"
          },
          uniqueItems: true
        },
        messages: {
          restricted: "Identifier '{{name}}' is restricted."
        }
      },
      create(context) {
        const denyList = new Set(context.options);
        const reportedNodes = /* @__PURE__ */ new Set();
        let globalScope;
        function isRestricted(name) {
          return denyList.has(name);
        }
        function isReferenceToGlobalVariable(node) {
          const variable = globalScope.set.get(node.name);
          return variable && variable.defs.length === 0 && variable.references.some((ref) => ref.identifier === node);
        }
        function shouldCheck(node) {
          const parent = node.parent;
          if (parent.type === "MemberExpression" && parent.property === node && !parent.computed) {
            return isAssignmentTarget(parent);
          }
          return parent.type !== "CallExpression" && parent.type !== "NewExpression" && !isRenamedImport(node) && !isRenamedInDestructuring(node) && !(isReferenceToGlobalVariable(node) && !isShorthandPropertyDefinition(node));
        }
        function report(node) {
          if (!reportedNodes.has(node.range.toString())) {
            context.report({
              node,
              messageId: "restricted",
              data: {
                name: node.name
              }
            });
            reportedNodes.add(node.range.toString());
          }
        }
        return {
          Program() {
            globalScope = context.getScope();
          },
          Identifier(node) {
            if (isRestricted(node.name) && shouldCheck(node)) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/id-denylist.js
var require_id_denylist = __commonJS({
  "node_modules/eslint/lib/rules/id-denylist.js"(exports, module2) {
    "use strict";
    function isAssignmentTarget(node) {
      const parent = node.parent;
      return (
        // normal assignment
        parent.type === "AssignmentExpression" && parent.left === node || // destructuring
        parent.type === "ArrayPattern" || parent.type === "RestElement" || parent.type === "Property" && parent.value === node && parent.parent.type === "ObjectPattern" || parent.type === "AssignmentPattern" && parent.left === node
      );
    }
    function isRenamedImport(node) {
      const parent = node.parent;
      return parent.type === "ImportSpecifier" && parent.imported !== parent.local && parent.imported === node || parent.type === "ExportSpecifier" && parent.parent.source && // re-export
      parent.local !== parent.exported && parent.local === node;
    }
    function isPropertyNameInDestructuring(node) {
      const parent = node.parent;
      return !parent.computed && parent.type === "Property" && parent.parent.type === "ObjectPattern" && parent.key === node;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified identifiers",
          recommended: false,
          url: "https://eslint.org/docs/rules/id-denylist"
        },
        schema: {
          type: "array",
          items: {
            type: "string"
          },
          uniqueItems: true
        },
        messages: {
          restricted: "Identifier '{{name}}' is restricted.",
          restrictedPrivate: "Identifier '#{{name}}' is restricted."
        }
      },
      create(context) {
        const denyList = new Set(context.options);
        const reportedNodes = /* @__PURE__ */ new Set();
        let globalScope;
        function isRestricted(name) {
          return denyList.has(name);
        }
        function isReferenceToGlobalVariable(node) {
          const variable = globalScope.set.get(node.name);
          return variable && variable.defs.length === 0 && variable.references.some((ref) => ref.identifier === node);
        }
        function shouldCheck(node) {
          const parent = node.parent;
          if (parent.type === "MemberExpression" && parent.property === node && !parent.computed) {
            return isAssignmentTarget(parent);
          }
          return parent.type !== "CallExpression" && parent.type !== "NewExpression" && !isRenamedImport(node) && !isPropertyNameInDestructuring(node) && !isReferenceToGlobalVariable(node);
        }
        function report(node) {
          if (!reportedNodes.has(node.range.toString())) {
            const isPrivate = node.type === "PrivateIdentifier";
            context.report({
              node,
              messageId: isPrivate ? "restrictedPrivate" : "restricted",
              data: {
                name: node.name
              }
            });
            reportedNodes.add(node.range.toString());
          }
        }
        return {
          Program() {
            globalScope = context.getScope();
          },
          [[
            "Identifier",
            "PrivateIdentifier"
          ]](node) {
            if (isRestricted(node.name) && shouldCheck(node)) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/grapheme-splitter/index.js
var require_grapheme_splitter = __commonJS({
  "node_modules/grapheme-splitter/index.js"(exports, module2) {
    function GraphemeSplitter() {
      var CR = 0, LF = 1, Control = 2, Extend = 3, Regional_Indicator = 4, SpacingMark = 5, L = 6, V = 7, T = 8, LV = 9, LVT = 10, Other = 11, Prepend = 12, E_Base = 13, E_Modifier = 14, ZWJ = 15, Glue_After_Zwj = 16, E_Base_GAZ = 17;
      var NotBreak = 0, BreakStart = 1, Break = 2, BreakLastRegional = 3, BreakPenultimateRegional = 4;
      function isSurrogate(str, pos) {
        return 55296 <= str.charCodeAt(pos) && str.charCodeAt(pos) <= 56319 && 56320 <= str.charCodeAt(pos + 1) && str.charCodeAt(pos + 1) <= 57343;
      }
      function codePointAt(str, idx) {
        if (idx === void 0) {
          idx = 0;
        }
        var code = str.charCodeAt(idx);
        if (55296 <= code && code <= 56319 && idx < str.length - 1) {
          var hi = code;
          var low = str.charCodeAt(idx + 1);
          if (56320 <= low && low <= 57343) {
            return (hi - 55296) * 1024 + (low - 56320) + 65536;
          }
          return hi;
        }
        if (56320 <= code && code <= 57343 && idx >= 1) {
          var hi = str.charCodeAt(idx - 1);
          var low = code;
          if (55296 <= hi && hi <= 56319) {
            return (hi - 55296) * 1024 + (low - 56320) + 65536;
          }
          return low;
        }
        return code;
      }
      function shouldBreak(start, mid, end) {
        var all = [start].concat(mid).concat([end]);
        var previous = all[all.length - 2];
        var next = end;
        var eModifierIndex = all.lastIndexOf(E_Modifier);
        if (eModifierIndex > 1 && all.slice(1, eModifierIndex).every(function(c) {
          return c == Extend;
        }) && [Extend, E_Base, E_Base_GAZ].indexOf(start) == -1) {
          return Break;
        }
        var rIIndex = all.lastIndexOf(Regional_Indicator);
        if (rIIndex > 0 && all.slice(1, rIIndex).every(function(c) {
          return c == Regional_Indicator;
        }) && [Prepend, Regional_Indicator].indexOf(previous) == -1) {
          if (all.filter(function(c) {
            return c == Regional_Indicator;
          }).length % 2 == 1) {
            return BreakLastRegional;
          } else {
            return BreakPenultimateRegional;
          }
        }
        if (previous == CR && next == LF) {
          return NotBreak;
        } else if (previous == Control || previous == CR || previous == LF) {
          if (next == E_Modifier && mid.every(function(c) {
            return c == Extend;
          })) {
            return Break;
          } else {
            return BreakStart;
          }
        } else if (next == Control || next == CR || next == LF) {
          return BreakStart;
        } else if (previous == L && (next == L || next == V || next == LV || next == LVT)) {
          return NotBreak;
        } else if ((previous == LV || previous == V) && (next == V || next == T)) {
          return NotBreak;
        } else if ((previous == LVT || previous == T) && next == T) {
          return NotBreak;
        } else if (next == Extend || next == ZWJ) {
          return NotBreak;
        } else if (next == SpacingMark) {
          return NotBreak;
        } else if (previous == Prepend) {
          return NotBreak;
        }
        var previousNonExtendIndex = all.indexOf(Extend) != -1 ? all.lastIndexOf(Extend) - 1 : all.length - 2;
        if ([E_Base, E_Base_GAZ].indexOf(all[previousNonExtendIndex]) != -1 && all.slice(previousNonExtendIndex + 1, -1).every(function(c) {
          return c == Extend;
        }) && next == E_Modifier) {
          return NotBreak;
        }
        if (previous == ZWJ && [Glue_After_Zwj, E_Base_GAZ].indexOf(next) != -1) {
          return NotBreak;
        }
        if (mid.indexOf(Regional_Indicator) != -1) {
          return Break;
        }
        if (previous == Regional_Indicator && next == Regional_Indicator) {
          return NotBreak;
        }
        return BreakStart;
      }
      this.nextBreak = function(string, index) {
        if (index === void 0) {
          index = 0;
        }
        if (index < 0) {
          return 0;
        }
        if (index >= string.length - 1) {
          return string.length;
        }
        var prev = getGraphemeBreakProperty(codePointAt(string, index));
        var mid = [];
        for (var i = index + 1; i < string.length; i++) {
          if (isSurrogate(string, i - 1)) {
            continue;
          }
          var next = getGraphemeBreakProperty(codePointAt(string, i));
          if (shouldBreak(prev, mid, next)) {
            return i;
          }
          mid.push(next);
        }
        return string.length;
      };
      this.splitGraphemes = function(str) {
        var res = [];
        var index = 0;
        var brk;
        while ((brk = this.nextBreak(str, index)) < str.length) {
          res.push(str.slice(index, brk));
          index = brk;
        }
        if (index < str.length) {
          res.push(str.slice(index));
        }
        return res;
      };
      this.iterateGraphemes = function(str) {
        var index = 0;
        var res = {
          next: function() {
            var value2;
            var brk;
            if ((brk = this.nextBreak(str, index)) < str.length) {
              value2 = str.slice(index, brk);
              index = brk;
              return { value: value2, done: false };
            }
            if (index < str.length) {
              value2 = str.slice(index);
              index = str.length;
              return { value: value2, done: false };
            }
            return { value: void 0, done: true };
          }.bind(this)
        };
        if (typeof Symbol !== "undefined" && Symbol.iterator) {
          res[Symbol.iterator] = function() {
            return res;
          };
        }
        return res;
      };
      this.countGraphemes = function(str) {
        var count = 0;
        var index = 0;
        var brk;
        while ((brk = this.nextBreak(str, index)) < str.length) {
          index = brk;
          count++;
        }
        if (index < str.length) {
          count++;
        }
        return count;
      };
      function getGraphemeBreakProperty(code) {
        if (1536 <= code && code <= 1541 || // Cf   [6] ARABIC NUMBER SIGN..ARABIC NUMBER MARK ABOVE
        1757 == code || // Cf       ARABIC END OF AYAH
        1807 == code || // Cf       SYRIAC ABBREVIATION MARK
        2274 == code || // Cf       ARABIC DISPUTED END OF AYAH
        3406 == code || // Lo       MALAYALAM LETTER DOT REPH
        69821 == code || // Cf       KAITHI NUMBER SIGN
        70082 <= code && code <= 70083 || // Lo   [2] SHARADA SIGN JIHVAMULIYA..SHARADA SIGN UPADHMANIYA
        72250 == code || // Lo       ZANABAZAR SQUARE CLUSTER-INITIAL LETTER RA
        72326 <= code && code <= 72329 || // Lo   [4] SOYOMBO CLUSTER-INITIAL LETTER RA..SOYOMBO CLUSTER-INITIAL LETTER SA
        73030 == code) {
          return Prepend;
        }
        if (13 == code) {
          return CR;
        }
        if (10 == code) {
          return LF;
        }
        if (0 <= code && code <= 9 || // Cc  [10] <control-0000>..<control-0009>
        11 <= code && code <= 12 || // Cc   [2] <control-000B>..<control-000C>
        14 <= code && code <= 31 || // Cc  [18] <control-000E>..<control-001F>
        127 <= code && code <= 159 || // Cc  [33] <control-007F>..<control-009F>
        173 == code || // Cf       SOFT HYPHEN
        1564 == code || // Cf       ARABIC LETTER MARK
        6158 == code || // Cf       MONGOLIAN VOWEL SEPARATOR
        8203 == code || // Cf       ZERO WIDTH SPACE
        8206 <= code && code <= 8207 || // Cf   [2] LEFT-TO-RIGHT MARK..RIGHT-TO-LEFT MARK
        8232 == code || // Zl       LINE SEPARATOR
        8233 == code || // Zp       PARAGRAPH SEPARATOR
        8234 <= code && code <= 8238 || // Cf   [5] LEFT-TO-RIGHT EMBEDDING..RIGHT-TO-LEFT OVERRIDE
        8288 <= code && code <= 8292 || // Cf   [5] WORD JOINER..INVISIBLE PLUS
        8293 == code || // Cn       <reserved-2065>
        8294 <= code && code <= 8303 || // Cf  [10] LEFT-TO-RIGHT ISOLATE..NOMINAL DIGIT SHAPES
        55296 <= code && code <= 57343 || // Cs [2048] <surrogate-D800>..<surrogate-DFFF>
        65279 == code || // Cf       ZERO WIDTH NO-BREAK SPACE
        65520 <= code && code <= 65528 || // Cn   [9] <reserved-FFF0>..<reserved-FFF8>
        65529 <= code && code <= 65531 || // Cf   [3] INTERLINEAR ANNOTATION ANCHOR..INTERLINEAR ANNOTATION TERMINATOR
        113824 <= code && code <= 113827 || // Cf   [4] SHORTHAND FORMAT LETTER OVERLAP..SHORTHAND FORMAT UP STEP
        119155 <= code && code <= 119162 || // Cf   [8] MUSICAL SYMBOL BEGIN BEAM..MUSICAL SYMBOL END PHRASE
        917504 == code || // Cn       <reserved-E0000>
        917505 == code || // Cf       LANGUAGE TAG
        917506 <= code && code <= 917535 || // Cn  [30] <reserved-E0002>..<reserved-E001F>
        917632 <= code && code <= 917759 || // Cn [128] <reserved-E0080>..<reserved-E00FF>
        918e3 <= code && code <= 921599) {
          return Control;
        }
        if (768 <= code && code <= 879 || // Mn [112] COMBINING GRAVE ACCENT..COMBINING LATIN SMALL LETTER X
        1155 <= code && code <= 1159 || // Mn   [5] COMBINING CYRILLIC TITLO..COMBINING CYRILLIC POKRYTIE
        1160 <= code && code <= 1161 || // Me   [2] COMBINING CYRILLIC HUNDRED THOUSANDS SIGN..COMBINING CYRILLIC MILLIONS SIGN
        1425 <= code && code <= 1469 || // Mn  [45] HEBREW ACCENT ETNAHTA..HEBREW POINT METEG
        1471 == code || // Mn       HEBREW POINT RAFE
        1473 <= code && code <= 1474 || // Mn   [2] HEBREW POINT SHIN DOT..HEBREW POINT SIN DOT
        1476 <= code && code <= 1477 || // Mn   [2] HEBREW MARK UPPER DOT..HEBREW MARK LOWER DOT
        1479 == code || // Mn       HEBREW POINT QAMATS QATAN
        1552 <= code && code <= 1562 || // Mn  [11] ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM..ARABIC SMALL KASRA
        1611 <= code && code <= 1631 || // Mn  [21] ARABIC FATHATAN..ARABIC WAVY HAMZA BELOW
        1648 == code || // Mn       ARABIC LETTER SUPERSCRIPT ALEF
        1750 <= code && code <= 1756 || // Mn   [7] ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA..ARABIC SMALL HIGH SEEN
        1759 <= code && code <= 1764 || // Mn   [6] ARABIC SMALL HIGH ROUNDED ZERO..ARABIC SMALL HIGH MADDA
        1767 <= code && code <= 1768 || // Mn   [2] ARABIC SMALL HIGH YEH..ARABIC SMALL HIGH NOON
        1770 <= code && code <= 1773 || // Mn   [4] ARABIC EMPTY CENTRE LOW STOP..ARABIC SMALL LOW MEEM
        1809 == code || // Mn       SYRIAC LETTER SUPERSCRIPT ALAPH
        1840 <= code && code <= 1866 || // Mn  [27] SYRIAC PTHAHA ABOVE..SYRIAC BARREKH
        1958 <= code && code <= 1968 || // Mn  [11] THAANA ABAFILI..THAANA SUKUN
        2027 <= code && code <= 2035 || // Mn   [9] NKO COMBINING SHORT HIGH TONE..NKO COMBINING DOUBLE DOT ABOVE
        2070 <= code && code <= 2073 || // Mn   [4] SAMARITAN MARK IN..SAMARITAN MARK DAGESH
        2075 <= code && code <= 2083 || // Mn   [9] SAMARITAN MARK EPENTHETIC YUT..SAMARITAN VOWEL SIGN A
        2085 <= code && code <= 2087 || // Mn   [3] SAMARITAN VOWEL SIGN SHORT A..SAMARITAN VOWEL SIGN U
        2089 <= code && code <= 2093 || // Mn   [5] SAMARITAN VOWEL SIGN LONG I..SAMARITAN MARK NEQUDAA
        2137 <= code && code <= 2139 || // Mn   [3] MANDAIC AFFRICATION MARK..MANDAIC GEMINATION MARK
        2260 <= code && code <= 2273 || // Mn  [14] ARABIC SMALL HIGH WORD AR-RUB..ARABIC SMALL HIGH SIGN SAFHA
        2275 <= code && code <= 2306 || // Mn  [32] ARABIC TURNED DAMMA BELOW..DEVANAGARI SIGN ANUSVARA
        2362 == code || // Mn       DEVANAGARI VOWEL SIGN OE
        2364 == code || // Mn       DEVANAGARI SIGN NUKTA
        2369 <= code && code <= 2376 || // Mn   [8] DEVANAGARI VOWEL SIGN U..DEVANAGARI VOWEL SIGN AI
        2381 == code || // Mn       DEVANAGARI SIGN VIRAMA
        2385 <= code && code <= 2391 || // Mn   [7] DEVANAGARI STRESS SIGN UDATTA..DEVANAGARI VOWEL SIGN UUE
        2402 <= code && code <= 2403 || // Mn   [2] DEVANAGARI VOWEL SIGN VOCALIC L..DEVANAGARI VOWEL SIGN VOCALIC LL
        2433 == code || // Mn       BENGALI SIGN CANDRABINDU
        2492 == code || // Mn       BENGALI SIGN NUKTA
        2494 == code || // Mc       BENGALI VOWEL SIGN AA
        2497 <= code && code <= 2500 || // Mn   [4] BENGALI VOWEL SIGN U..BENGALI VOWEL SIGN VOCALIC RR
        2509 == code || // Mn       BENGALI SIGN VIRAMA
        2519 == code || // Mc       BENGALI AU LENGTH MARK
        2530 <= code && code <= 2531 || // Mn   [2] BENGALI VOWEL SIGN VOCALIC L..BENGALI VOWEL SIGN VOCALIC LL
        2561 <= code && code <= 2562 || // Mn   [2] GURMUKHI SIGN ADAK BINDI..GURMUKHI SIGN BINDI
        2620 == code || // Mn       GURMUKHI SIGN NUKTA
        2625 <= code && code <= 2626 || // Mn   [2] GURMUKHI VOWEL SIGN U..GURMUKHI VOWEL SIGN UU
        2631 <= code && code <= 2632 || // Mn   [2] GURMUKHI VOWEL SIGN EE..GURMUKHI VOWEL SIGN AI
        2635 <= code && code <= 2637 || // Mn   [3] GURMUKHI VOWEL SIGN OO..GURMUKHI SIGN VIRAMA
        2641 == code || // Mn       GURMUKHI SIGN UDAAT
        2672 <= code && code <= 2673 || // Mn   [2] GURMUKHI TIPPI..GURMUKHI ADDAK
        2677 == code || // Mn       GURMUKHI SIGN YAKASH
        2689 <= code && code <= 2690 || // Mn   [2] GUJARATI SIGN CANDRABINDU..GUJARATI SIGN ANUSVARA
        2748 == code || // Mn       GUJARATI SIGN NUKTA
        2753 <= code && code <= 2757 || // Mn   [5] GUJARATI VOWEL SIGN U..GUJARATI VOWEL SIGN CANDRA E
        2759 <= code && code <= 2760 || // Mn   [2] GUJARATI VOWEL SIGN E..GUJARATI VOWEL SIGN AI
        2765 == code || // Mn       GUJARATI SIGN VIRAMA
        2786 <= code && code <= 2787 || // Mn   [2] GUJARATI VOWEL SIGN VOCALIC L..GUJARATI VOWEL SIGN VOCALIC LL
        2810 <= code && code <= 2815 || // Mn   [6] GUJARATI SIGN SUKUN..GUJARATI SIGN TWO-CIRCLE NUKTA ABOVE
        2817 == code || // Mn       ORIYA SIGN CANDRABINDU
        2876 == code || // Mn       ORIYA SIGN NUKTA
        2878 == code || // Mc       ORIYA VOWEL SIGN AA
        2879 == code || // Mn       ORIYA VOWEL SIGN I
        2881 <= code && code <= 2884 || // Mn   [4] ORIYA VOWEL SIGN U..ORIYA VOWEL SIGN VOCALIC RR
        2893 == code || // Mn       ORIYA SIGN VIRAMA
        2902 == code || // Mn       ORIYA AI LENGTH MARK
        2903 == code || // Mc       ORIYA AU LENGTH MARK
        2914 <= code && code <= 2915 || // Mn   [2] ORIYA VOWEL SIGN VOCALIC L..ORIYA VOWEL SIGN VOCALIC LL
        2946 == code || // Mn       TAMIL SIGN ANUSVARA
        3006 == code || // Mc       TAMIL VOWEL SIGN AA
        3008 == code || // Mn       TAMIL VOWEL SIGN II
        3021 == code || // Mn       TAMIL SIGN VIRAMA
        3031 == code || // Mc       TAMIL AU LENGTH MARK
        3072 == code || // Mn       TELUGU SIGN COMBINING CANDRABINDU ABOVE
        3134 <= code && code <= 3136 || // Mn   [3] TELUGU VOWEL SIGN AA..TELUGU VOWEL SIGN II
        3142 <= code && code <= 3144 || // Mn   [3] TELUGU VOWEL SIGN E..TELUGU VOWEL SIGN AI
        3146 <= code && code <= 3149 || // Mn   [4] TELUGU VOWEL SIGN O..TELUGU SIGN VIRAMA
        3157 <= code && code <= 3158 || // Mn   [2] TELUGU LENGTH MARK..TELUGU AI LENGTH MARK
        3170 <= code && code <= 3171 || // Mn   [2] TELUGU VOWEL SIGN VOCALIC L..TELUGU VOWEL SIGN VOCALIC LL
        3201 == code || // Mn       KANNADA SIGN CANDRABINDU
        3260 == code || // Mn       KANNADA SIGN NUKTA
        3263 == code || // Mn       KANNADA VOWEL SIGN I
        3266 == code || // Mc       KANNADA VOWEL SIGN UU
        3270 == code || // Mn       KANNADA VOWEL SIGN E
        3276 <= code && code <= 3277 || // Mn   [2] KANNADA VOWEL SIGN AU..KANNADA SIGN VIRAMA
        3285 <= code && code <= 3286 || // Mc   [2] KANNADA LENGTH MARK..KANNADA AI LENGTH MARK
        3298 <= code && code <= 3299 || // Mn   [2] KANNADA VOWEL SIGN VOCALIC L..KANNADA VOWEL SIGN VOCALIC LL
        3328 <= code && code <= 3329 || // Mn   [2] MALAYALAM SIGN COMBINING ANUSVARA ABOVE..MALAYALAM SIGN CANDRABINDU
        3387 <= code && code <= 3388 || // Mn   [2] MALAYALAM SIGN VERTICAL BAR VIRAMA..MALAYALAM SIGN CIRCULAR VIRAMA
        3390 == code || // Mc       MALAYALAM VOWEL SIGN AA
        3393 <= code && code <= 3396 || // Mn   [4] MALAYALAM VOWEL SIGN U..MALAYALAM VOWEL SIGN VOCALIC RR
        3405 == code || // Mn       MALAYALAM SIGN VIRAMA
        3415 == code || // Mc       MALAYALAM AU LENGTH MARK
        3426 <= code && code <= 3427 || // Mn   [2] MALAYALAM VOWEL SIGN VOCALIC L..MALAYALAM VOWEL SIGN VOCALIC LL
        3530 == code || // Mn       SINHALA SIGN AL-LAKUNA
        3535 == code || // Mc       SINHALA VOWEL SIGN AELA-PILLA
        3538 <= code && code <= 3540 || // Mn   [3] SINHALA VOWEL SIGN KETTI IS-PILLA..SINHALA VOWEL SIGN KETTI PAA-PILLA
        3542 == code || // Mn       SINHALA VOWEL SIGN DIGA PAA-PILLA
        3551 == code || // Mc       SINHALA VOWEL SIGN GAYANUKITTA
        3633 == code || // Mn       THAI CHARACTER MAI HAN-AKAT
        3636 <= code && code <= 3642 || // Mn   [7] THAI CHARACTER SARA I..THAI CHARACTER PHINTHU
        3655 <= code && code <= 3662 || // Mn   [8] THAI CHARACTER MAITAIKHU..THAI CHARACTER YAMAKKAN
        3761 == code || // Mn       LAO VOWEL SIGN MAI KAN
        3764 <= code && code <= 3769 || // Mn   [6] LAO VOWEL SIGN I..LAO VOWEL SIGN UU
        3771 <= code && code <= 3772 || // Mn   [2] LAO VOWEL SIGN MAI KON..LAO SEMIVOWEL SIGN LO
        3784 <= code && code <= 3789 || // Mn   [6] LAO TONE MAI EK..LAO NIGGAHITA
        3864 <= code && code <= 3865 || // Mn   [2] TIBETAN ASTROLOGICAL SIGN -KHYUD PA..TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS
        3893 == code || // Mn       TIBETAN MARK NGAS BZUNG NYI ZLA
        3895 == code || // Mn       TIBETAN MARK NGAS BZUNG SGOR RTAGS
        3897 == code || // Mn       TIBETAN MARK TSA -PHRU
        3953 <= code && code <= 3966 || // Mn  [14] TIBETAN VOWEL SIGN AA..TIBETAN SIGN RJES SU NGA RO
        3968 <= code && code <= 3972 || // Mn   [5] TIBETAN VOWEL SIGN REVERSED I..TIBETAN MARK HALANTA
        3974 <= code && code <= 3975 || // Mn   [2] TIBETAN SIGN LCI RTAGS..TIBETAN SIGN YANG RTAGS
        3981 <= code && code <= 3991 || // Mn  [11] TIBETAN SUBJOINED SIGN LCE TSA CAN..TIBETAN SUBJOINED LETTER JA
        3993 <= code && code <= 4028 || // Mn  [36] TIBETAN SUBJOINED LETTER NYA..TIBETAN SUBJOINED LETTER FIXED-FORM RA
        4038 == code || // Mn       TIBETAN SYMBOL PADMA GDAN
        4141 <= code && code <= 4144 || // Mn   [4] MYANMAR VOWEL SIGN I..MYANMAR VOWEL SIGN UU
        4146 <= code && code <= 4151 || // Mn   [6] MYANMAR VOWEL SIGN AI..MYANMAR SIGN DOT BELOW
        4153 <= code && code <= 4154 || // Mn   [2] MYANMAR SIGN VIRAMA..MYANMAR SIGN ASAT
        4157 <= code && code <= 4158 || // Mn   [2] MYANMAR CONSONANT SIGN MEDIAL WA..MYANMAR CONSONANT SIGN MEDIAL HA
        4184 <= code && code <= 4185 || // Mn   [2] MYANMAR VOWEL SIGN VOCALIC L..MYANMAR VOWEL SIGN VOCALIC LL
        4190 <= code && code <= 4192 || // Mn   [3] MYANMAR CONSONANT SIGN MON MEDIAL NA..MYANMAR CONSONANT SIGN MON MEDIAL LA
        4209 <= code && code <= 4212 || // Mn   [4] MYANMAR VOWEL SIGN GEBA KAREN I..MYANMAR VOWEL SIGN KAYAH EE
        4226 == code || // Mn       MYANMAR CONSONANT SIGN SHAN MEDIAL WA
        4229 <= code && code <= 4230 || // Mn   [2] MYANMAR VOWEL SIGN SHAN E ABOVE..MYANMAR VOWEL SIGN SHAN FINAL Y
        4237 == code || // Mn       MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE
        4253 == code || // Mn       MYANMAR VOWEL SIGN AITON AI
        4957 <= code && code <= 4959 || // Mn   [3] ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK..ETHIOPIC COMBINING GEMINATION MARK
        5906 <= code && code <= 5908 || // Mn   [3] TAGALOG VOWEL SIGN I..TAGALOG SIGN VIRAMA
        5938 <= code && code <= 5940 || // Mn   [3] HANUNOO VOWEL SIGN I..HANUNOO SIGN PAMUDPOD
        5970 <= code && code <= 5971 || // Mn   [2] BUHID VOWEL SIGN I..BUHID VOWEL SIGN U
        6002 <= code && code <= 6003 || // Mn   [2] TAGBANWA VOWEL SIGN I..TAGBANWA VOWEL SIGN U
        6068 <= code && code <= 6069 || // Mn   [2] KHMER VOWEL INHERENT AQ..KHMER VOWEL INHERENT AA
        6071 <= code && code <= 6077 || // Mn   [7] KHMER VOWEL SIGN I..KHMER VOWEL SIGN UA
        6086 == code || // Mn       KHMER SIGN NIKAHIT
        6089 <= code && code <= 6099 || // Mn  [11] KHMER SIGN MUUSIKATOAN..KHMER SIGN BATHAMASAT
        6109 == code || // Mn       KHMER SIGN ATTHACAN
        6155 <= code && code <= 6157 || // Mn   [3] MONGOLIAN FREE VARIATION SELECTOR ONE..MONGOLIAN FREE VARIATION SELECTOR THREE
        6277 <= code && code <= 6278 || // Mn   [2] MONGOLIAN LETTER ALI GALI BALUDA..MONGOLIAN LETTER ALI GALI THREE BALUDA
        6313 == code || // Mn       MONGOLIAN LETTER ALI GALI DAGALGA
        6432 <= code && code <= 6434 || // Mn   [3] LIMBU VOWEL SIGN A..LIMBU VOWEL SIGN U
        6439 <= code && code <= 6440 || // Mn   [2] LIMBU VOWEL SIGN E..LIMBU VOWEL SIGN O
        6450 == code || // Mn       LIMBU SMALL LETTER ANUSVARA
        6457 <= code && code <= 6459 || // Mn   [3] LIMBU SIGN MUKPHRENG..LIMBU SIGN SA-I
        6679 <= code && code <= 6680 || // Mn   [2] BUGINESE VOWEL SIGN I..BUGINESE VOWEL SIGN U
        6683 == code || // Mn       BUGINESE VOWEL SIGN AE
        6742 == code || // Mn       TAI THAM CONSONANT SIGN MEDIAL LA
        6744 <= code && code <= 6750 || // Mn   [7] TAI THAM SIGN MAI KANG LAI..TAI THAM CONSONANT SIGN SA
        6752 == code || // Mn       TAI THAM SIGN SAKOT
        6754 == code || // Mn       TAI THAM VOWEL SIGN MAI SAT
        6757 <= code && code <= 6764 || // Mn   [8] TAI THAM VOWEL SIGN I..TAI THAM VOWEL SIGN OA BELOW
        6771 <= code && code <= 6780 || // Mn  [10] TAI THAM VOWEL SIGN OA ABOVE..TAI THAM SIGN KHUEN-LUE KARAN
        6783 == code || // Mn       TAI THAM COMBINING CRYPTOGRAMMIC DOT
        6832 <= code && code <= 6845 || // Mn  [14] COMBINING DOUBLED CIRCUMFLEX ACCENT..COMBINING PARENTHESES BELOW
        6846 == code || // Me       COMBINING PARENTHESES OVERLAY
        6912 <= code && code <= 6915 || // Mn   [4] BALINESE SIGN ULU RICEM..BALINESE SIGN SURANG
        6964 == code || // Mn       BALINESE SIGN REREKAN
        6966 <= code && code <= 6970 || // Mn   [5] BALINESE VOWEL SIGN ULU..BALINESE VOWEL SIGN RA REPA
        6972 == code || // Mn       BALINESE VOWEL SIGN LA LENGA
        6978 == code || // Mn       BALINESE VOWEL SIGN PEPET
        7019 <= code && code <= 7027 || // Mn   [9] BALINESE MUSICAL SYMBOL COMBINING TEGEH..BALINESE MUSICAL SYMBOL COMBINING GONG
        7040 <= code && code <= 7041 || // Mn   [2] SUNDANESE SIGN PANYECEK..SUNDANESE SIGN PANGLAYAR
        7074 <= code && code <= 7077 || // Mn   [4] SUNDANESE CONSONANT SIGN PANYAKRA..SUNDANESE VOWEL SIGN PANYUKU
        7080 <= code && code <= 7081 || // Mn   [2] SUNDANESE VOWEL SIGN PAMEPET..SUNDANESE VOWEL SIGN PANEULEUNG
        7083 <= code && code <= 7085 || // Mn   [3] SUNDANESE SIGN VIRAMA..SUNDANESE CONSONANT SIGN PASANGAN WA
        7142 == code || // Mn       BATAK SIGN TOMPI
        7144 <= code && code <= 7145 || // Mn   [2] BATAK VOWEL SIGN PAKPAK E..BATAK VOWEL SIGN EE
        7149 == code || // Mn       BATAK VOWEL SIGN KARO O
        7151 <= code && code <= 7153 || // Mn   [3] BATAK VOWEL SIGN U FOR SIMALUNGUN SA..BATAK CONSONANT SIGN H
        7212 <= code && code <= 7219 || // Mn   [8] LEPCHA VOWEL SIGN E..LEPCHA CONSONANT SIGN T
        7222 <= code && code <= 7223 || // Mn   [2] LEPCHA SIGN RAN..LEPCHA SIGN NUKTA
        7376 <= code && code <= 7378 || // Mn   [3] VEDIC TONE KARSHANA..VEDIC TONE PRENKHA
        7380 <= code && code <= 7392 || // Mn  [13] VEDIC SIGN YAJURVEDIC MIDLINE SVARITA..VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA
        7394 <= code && code <= 7400 || // Mn   [7] VEDIC SIGN VISARGA SVARITA..VEDIC SIGN VISARGA ANUDATTA WITH TAIL
        7405 == code || // Mn       VEDIC SIGN TIRYAK
        7412 == code || // Mn       VEDIC TONE CANDRA ABOVE
        7416 <= code && code <= 7417 || // Mn   [2] VEDIC TONE RING ABOVE..VEDIC TONE DOUBLE RING ABOVE
        7616 <= code && code <= 7673 || // Mn  [58] COMBINING DOTTED GRAVE ACCENT..COMBINING WIDE INVERTED BRIDGE BELOW
        7675 <= code && code <= 7679 || // Mn   [5] COMBINING DELETION MARK..COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW
        8204 == code || // Cf       ZERO WIDTH NON-JOINER
        8400 <= code && code <= 8412 || // Mn  [13] COMBINING LEFT HARPOON ABOVE..COMBINING FOUR DOTS ABOVE
        8413 <= code && code <= 8416 || // Me   [4] COMBINING ENCLOSING CIRCLE..COMBINING ENCLOSING CIRCLE BACKSLASH
        8417 == code || // Mn       COMBINING LEFT RIGHT ARROW ABOVE
        8418 <= code && code <= 8420 || // Me   [3] COMBINING ENCLOSING SCREEN..COMBINING ENCLOSING UPWARD POINTING TRIANGLE
        8421 <= code && code <= 8432 || // Mn  [12] COMBINING REVERSE SOLIDUS OVERLAY..COMBINING ASTERISK ABOVE
        11503 <= code && code <= 11505 || // Mn   [3] COPTIC COMBINING NI ABOVE..COPTIC COMBINING SPIRITUS LENIS
        11647 == code || // Mn       TIFINAGH CONSONANT JOINER
        11744 <= code && code <= 11775 || // Mn  [32] COMBINING CYRILLIC LETTER BE..COMBINING CYRILLIC LETTER IOTIFIED BIG YUS
        12330 <= code && code <= 12333 || // Mn   [4] IDEOGRAPHIC LEVEL TONE MARK..IDEOGRAPHIC ENTERING TONE MARK
        12334 <= code && code <= 12335 || // Mc   [2] HANGUL SINGLE DOT TONE MARK..HANGUL DOUBLE DOT TONE MARK
        12441 <= code && code <= 12442 || // Mn   [2] COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK..COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
        42607 == code || // Mn       COMBINING CYRILLIC VZMET
        42608 <= code && code <= 42610 || // Me   [3] COMBINING CYRILLIC TEN MILLIONS SIGN..COMBINING CYRILLIC THOUSAND MILLIONS SIGN
        42612 <= code && code <= 42621 || // Mn  [10] COMBINING CYRILLIC LETTER UKRAINIAN IE..COMBINING CYRILLIC PAYEROK
        42654 <= code && code <= 42655 || // Mn   [2] COMBINING CYRILLIC LETTER EF..COMBINING CYRILLIC LETTER IOTIFIED E
        42736 <= code && code <= 42737 || // Mn   [2] BAMUM COMBINING MARK KOQNDON..BAMUM COMBINING MARK TUKWENTIS
        43010 == code || // Mn       SYLOTI NAGRI SIGN DVISVARA
        43014 == code || // Mn       SYLOTI NAGRI SIGN HASANTA
        43019 == code || // Mn       SYLOTI NAGRI SIGN ANUSVARA
        43045 <= code && code <= 43046 || // Mn   [2] SYLOTI NAGRI VOWEL SIGN U..SYLOTI NAGRI VOWEL SIGN E
        43204 <= code && code <= 43205 || // Mn   [2] SAURASHTRA SIGN VIRAMA..SAURASHTRA SIGN CANDRABINDU
        43232 <= code && code <= 43249 || // Mn  [18] COMBINING DEVANAGARI DIGIT ZERO..COMBINING DEVANAGARI SIGN AVAGRAHA
        43302 <= code && code <= 43309 || // Mn   [8] KAYAH LI VOWEL UE..KAYAH LI TONE CALYA PLOPHU
        43335 <= code && code <= 43345 || // Mn  [11] REJANG VOWEL SIGN I..REJANG CONSONANT SIGN R
        43392 <= code && code <= 43394 || // Mn   [3] JAVANESE SIGN PANYANGGA..JAVANESE SIGN LAYAR
        43443 == code || // Mn       JAVANESE SIGN CECAK TELU
        43446 <= code && code <= 43449 || // Mn   [4] JAVANESE VOWEL SIGN WULU..JAVANESE VOWEL SIGN SUKU MENDUT
        43452 == code || // Mn       JAVANESE VOWEL SIGN PEPET
        43493 == code || // Mn       MYANMAR SIGN SHAN SAW
        43561 <= code && code <= 43566 || // Mn   [6] CHAM VOWEL SIGN AA..CHAM VOWEL SIGN OE
        43569 <= code && code <= 43570 || // Mn   [2] CHAM VOWEL SIGN AU..CHAM VOWEL SIGN UE
        43573 <= code && code <= 43574 || // Mn   [2] CHAM CONSONANT SIGN LA..CHAM CONSONANT SIGN WA
        43587 == code || // Mn       CHAM CONSONANT SIGN FINAL NG
        43596 == code || // Mn       CHAM CONSONANT SIGN FINAL M
        43644 == code || // Mn       MYANMAR SIGN TAI LAING TONE-2
        43696 == code || // Mn       TAI VIET MAI KANG
        43698 <= code && code <= 43700 || // Mn   [3] TAI VIET VOWEL I..TAI VIET VOWEL U
        43703 <= code && code <= 43704 || // Mn   [2] TAI VIET MAI KHIT..TAI VIET VOWEL IA
        43710 <= code && code <= 43711 || // Mn   [2] TAI VIET VOWEL AM..TAI VIET TONE MAI EK
        43713 == code || // Mn       TAI VIET TONE MAI THO
        43756 <= code && code <= 43757 || // Mn   [2] MEETEI MAYEK VOWEL SIGN UU..MEETEI MAYEK VOWEL SIGN AAI
        43766 == code || // Mn       MEETEI MAYEK VIRAMA
        44005 == code || // Mn       MEETEI MAYEK VOWEL SIGN ANAP
        44008 == code || // Mn       MEETEI MAYEK VOWEL SIGN UNAP
        44013 == code || // Mn       MEETEI MAYEK APUN IYEK
        64286 == code || // Mn       HEBREW POINT JUDEO-SPANISH VARIKA
        65024 <= code && code <= 65039 || // Mn  [16] VARIATION SELECTOR-1..VARIATION SELECTOR-16
        65056 <= code && code <= 65071 || // Mn  [16] COMBINING LIGATURE LEFT HALF..COMBINING CYRILLIC TITLO RIGHT HALF
        65438 <= code && code <= 65439 || // Lm   [2] HALFWIDTH KATAKANA VOICED SOUND MARK..HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK
        66045 == code || // Mn       PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE
        66272 == code || // Mn       COPTIC EPACT THOUSANDS MARK
        66422 <= code && code <= 66426 || // Mn   [5] COMBINING OLD PERMIC LETTER AN..COMBINING OLD PERMIC LETTER SII
        68097 <= code && code <= 68099 || // Mn   [3] KHAROSHTHI VOWEL SIGN I..KHAROSHTHI VOWEL SIGN VOCALIC R
        68101 <= code && code <= 68102 || // Mn   [2] KHAROSHTHI VOWEL SIGN E..KHAROSHTHI VOWEL SIGN O
        68108 <= code && code <= 68111 || // Mn   [4] KHAROSHTHI VOWEL LENGTH MARK..KHAROSHTHI SIGN VISARGA
        68152 <= code && code <= 68154 || // Mn   [3] KHAROSHTHI SIGN BAR ABOVE..KHAROSHTHI SIGN DOT BELOW
        68159 == code || // Mn       KHAROSHTHI VIRAMA
        68325 <= code && code <= 68326 || // Mn   [2] MANICHAEAN ABBREVIATION MARK ABOVE..MANICHAEAN ABBREVIATION MARK BELOW
        69633 == code || // Mn       BRAHMI SIGN ANUSVARA
        69688 <= code && code <= 69702 || // Mn  [15] BRAHMI VOWEL SIGN AA..BRAHMI VIRAMA
        69759 <= code && code <= 69761 || // Mn   [3] BRAHMI NUMBER JOINER..KAITHI SIGN ANUSVARA
        69811 <= code && code <= 69814 || // Mn   [4] KAITHI VOWEL SIGN U..KAITHI VOWEL SIGN AI
        69817 <= code && code <= 69818 || // Mn   [2] KAITHI SIGN VIRAMA..KAITHI SIGN NUKTA
        69888 <= code && code <= 69890 || // Mn   [3] CHAKMA SIGN CANDRABINDU..CHAKMA SIGN VISARGA
        69927 <= code && code <= 69931 || // Mn   [5] CHAKMA VOWEL SIGN A..CHAKMA VOWEL SIGN UU
        69933 <= code && code <= 69940 || // Mn   [8] CHAKMA VOWEL SIGN AI..CHAKMA MAAYYAA
        70003 == code || // Mn       MAHAJANI SIGN NUKTA
        70016 <= code && code <= 70017 || // Mn   [2] SHARADA SIGN CANDRABINDU..SHARADA SIGN ANUSVARA
        70070 <= code && code <= 70078 || // Mn   [9] SHARADA VOWEL SIGN U..SHARADA VOWEL SIGN O
        70090 <= code && code <= 70092 || // Mn   [3] SHARADA SIGN NUKTA..SHARADA EXTRA SHORT VOWEL MARK
        70191 <= code && code <= 70193 || // Mn   [3] KHOJKI VOWEL SIGN U..KHOJKI VOWEL SIGN AI
        70196 == code || // Mn       KHOJKI SIGN ANUSVARA
        70198 <= code && code <= 70199 || // Mn   [2] KHOJKI SIGN NUKTA..KHOJKI SIGN SHADDA
        70206 == code || // Mn       KHOJKI SIGN SUKUN
        70367 == code || // Mn       KHUDAWADI SIGN ANUSVARA
        70371 <= code && code <= 70378 || // Mn   [8] KHUDAWADI VOWEL SIGN U..KHUDAWADI SIGN VIRAMA
        70400 <= code && code <= 70401 || // Mn   [2] GRANTHA SIGN COMBINING ANUSVARA ABOVE..GRANTHA SIGN CANDRABINDU
        70460 == code || // Mn       GRANTHA SIGN NUKTA
        70462 == code || // Mc       GRANTHA VOWEL SIGN AA
        70464 == code || // Mn       GRANTHA VOWEL SIGN II
        70487 == code || // Mc       GRANTHA AU LENGTH MARK
        70502 <= code && code <= 70508 || // Mn   [7] COMBINING GRANTHA DIGIT ZERO..COMBINING GRANTHA DIGIT SIX
        70512 <= code && code <= 70516 || // Mn   [5] COMBINING GRANTHA LETTER A..COMBINING GRANTHA LETTER PA
        70712 <= code && code <= 70719 || // Mn   [8] NEWA VOWEL SIGN U..NEWA VOWEL SIGN AI
        70722 <= code && code <= 70724 || // Mn   [3] NEWA SIGN VIRAMA..NEWA SIGN ANUSVARA
        70726 == code || // Mn       NEWA SIGN NUKTA
        70832 == code || // Mc       TIRHUTA VOWEL SIGN AA
        70835 <= code && code <= 70840 || // Mn   [6] TIRHUTA VOWEL SIGN U..TIRHUTA VOWEL SIGN VOCALIC LL
        70842 == code || // Mn       TIRHUTA VOWEL SIGN SHORT E
        70845 == code || // Mc       TIRHUTA VOWEL SIGN SHORT O
        70847 <= code && code <= 70848 || // Mn   [2] TIRHUTA SIGN CANDRABINDU..TIRHUTA SIGN ANUSVARA
        70850 <= code && code <= 70851 || // Mn   [2] TIRHUTA SIGN VIRAMA..TIRHUTA SIGN NUKTA
        71087 == code || // Mc       SIDDHAM VOWEL SIGN AA
        71090 <= code && code <= 71093 || // Mn   [4] SIDDHAM VOWEL SIGN U..SIDDHAM VOWEL SIGN VOCALIC RR
        71100 <= code && code <= 71101 || // Mn   [2] SIDDHAM SIGN CANDRABINDU..SIDDHAM SIGN ANUSVARA
        71103 <= code && code <= 71104 || // Mn   [2] SIDDHAM SIGN VIRAMA..SIDDHAM SIGN NUKTA
        71132 <= code && code <= 71133 || // Mn   [2] SIDDHAM VOWEL SIGN ALTERNATE U..SIDDHAM VOWEL SIGN ALTERNATE UU
        71219 <= code && code <= 71226 || // Mn   [8] MODI VOWEL SIGN U..MODI VOWEL SIGN AI
        71229 == code || // Mn       MODI SIGN ANUSVARA
        71231 <= code && code <= 71232 || // Mn   [2] MODI SIGN VIRAMA..MODI SIGN ARDHACANDRA
        71339 == code || // Mn       TAKRI SIGN ANUSVARA
        71341 == code || // Mn       TAKRI VOWEL SIGN AA
        71344 <= code && code <= 71349 || // Mn   [6] TAKRI VOWEL SIGN U..TAKRI VOWEL SIGN AU
        71351 == code || // Mn       TAKRI SIGN NUKTA
        71453 <= code && code <= 71455 || // Mn   [3] AHOM CONSONANT SIGN MEDIAL LA..AHOM CONSONANT SIGN MEDIAL LIGATING RA
        71458 <= code && code <= 71461 || // Mn   [4] AHOM VOWEL SIGN I..AHOM VOWEL SIGN UU
        71463 <= code && code <= 71467 || // Mn   [5] AHOM VOWEL SIGN AW..AHOM SIGN KILLER
        72193 <= code && code <= 72198 || // Mn   [6] ZANABAZAR SQUARE VOWEL SIGN I..ZANABAZAR SQUARE VOWEL SIGN O
        72201 <= code && code <= 72202 || // Mn   [2] ZANABAZAR SQUARE VOWEL SIGN REVERSED I..ZANABAZAR SQUARE VOWEL LENGTH MARK
        72243 <= code && code <= 72248 || // Mn   [6] ZANABAZAR SQUARE FINAL CONSONANT MARK..ZANABAZAR SQUARE SIGN ANUSVARA
        72251 <= code && code <= 72254 || // Mn   [4] ZANABAZAR SQUARE CLUSTER-FINAL LETTER YA..ZANABAZAR SQUARE CLUSTER-FINAL LETTER VA
        72263 == code || // Mn       ZANABAZAR SQUARE SUBJOINER
        72273 <= code && code <= 72278 || // Mn   [6] SOYOMBO VOWEL SIGN I..SOYOMBO VOWEL SIGN OE
        72281 <= code && code <= 72283 || // Mn   [3] SOYOMBO VOWEL SIGN VOCALIC R..SOYOMBO VOWEL LENGTH MARK
        72330 <= code && code <= 72342 || // Mn  [13] SOYOMBO FINAL CONSONANT SIGN G..SOYOMBO SIGN ANUSVARA
        72344 <= code && code <= 72345 || // Mn   [2] SOYOMBO GEMINATION MARK..SOYOMBO SUBJOINER
        72752 <= code && code <= 72758 || // Mn   [7] BHAIKSUKI VOWEL SIGN I..BHAIKSUKI VOWEL SIGN VOCALIC L
        72760 <= code && code <= 72765 || // Mn   [6] BHAIKSUKI VOWEL SIGN E..BHAIKSUKI SIGN ANUSVARA
        72767 == code || // Mn       BHAIKSUKI SIGN VIRAMA
        72850 <= code && code <= 72871 || // Mn  [22] MARCHEN SUBJOINED LETTER KA..MARCHEN SUBJOINED LETTER ZA
        72874 <= code && code <= 72880 || // Mn   [7] MARCHEN SUBJOINED LETTER RA..MARCHEN VOWEL SIGN AA
        72882 <= code && code <= 72883 || // Mn   [2] MARCHEN VOWEL SIGN U..MARCHEN VOWEL SIGN E
        72885 <= code && code <= 72886 || // Mn   [2] MARCHEN SIGN ANUSVARA..MARCHEN SIGN CANDRABINDU
        73009 <= code && code <= 73014 || // Mn   [6] MASARAM GONDI VOWEL SIGN AA..MASARAM GONDI VOWEL SIGN VOCALIC R
        73018 == code || // Mn       MASARAM GONDI VOWEL SIGN E
        73020 <= code && code <= 73021 || // Mn   [2] MASARAM GONDI VOWEL SIGN AI..MASARAM GONDI VOWEL SIGN O
        73023 <= code && code <= 73029 || // Mn   [7] MASARAM GONDI VOWEL SIGN AU..MASARAM GONDI VIRAMA
        73031 == code || // Mn       MASARAM GONDI RA-KARA
        92912 <= code && code <= 92916 || // Mn   [5] BASSA VAH COMBINING HIGH TONE..BASSA VAH COMBINING HIGH-LOW TONE
        92976 <= code && code <= 92982 || // Mn   [7] PAHAWH HMONG MARK CIM TUB..PAHAWH HMONG MARK CIM TAUM
        94095 <= code && code <= 94098 || // Mn   [4] MIAO TONE RIGHT..MIAO TONE BELOW
        113821 <= code && code <= 113822 || // Mn   [2] DUPLOYAN THICK LETTER SELECTOR..DUPLOYAN DOUBLE MARK
        119141 == code || // Mc       MUSICAL SYMBOL COMBINING STEM
        119143 <= code && code <= 119145 || // Mn   [3] MUSICAL SYMBOL COMBINING TREMOLO-1..MUSICAL SYMBOL COMBINING TREMOLO-3
        119150 <= code && code <= 119154 || // Mc   [5] MUSICAL SYMBOL COMBINING FLAG-1..MUSICAL SYMBOL COMBINING FLAG-5
        119163 <= code && code <= 119170 || // Mn   [8] MUSICAL SYMBOL COMBINING ACCENT..MUSICAL SYMBOL COMBINING LOURE
        119173 <= code && code <= 119179 || // Mn   [7] MUSICAL SYMBOL COMBINING DOIT..MUSICAL SYMBOL COMBINING TRIPLE TONGUE
        119210 <= code && code <= 119213 || // Mn   [4] MUSICAL SYMBOL COMBINING DOWN BOW..MUSICAL SYMBOL COMBINING SNAP PIZZICATO
        119362 <= code && code <= 119364 || // Mn   [3] COMBINING GREEK MUSICAL TRISEME..COMBINING GREEK MUSICAL PENTASEME
        121344 <= code && code <= 121398 || // Mn  [55] SIGNWRITING HEAD RIM..SIGNWRITING AIR SUCKING IN
        121403 <= code && code <= 121452 || // Mn  [50] SIGNWRITING MOUTH CLOSED NEUTRAL..SIGNWRITING EXCITEMENT
        121461 == code || // Mn       SIGNWRITING UPPER BODY TILTING FROM HIP JOINTS
        121476 == code || // Mn       SIGNWRITING LOCATION HEAD NECK
        121499 <= code && code <= 121503 || // Mn   [5] SIGNWRITING FILL MODIFIER-2..SIGNWRITING FILL MODIFIER-6
        121505 <= code && code <= 121519 || // Mn  [15] SIGNWRITING ROTATION MODIFIER-2..SIGNWRITING ROTATION MODIFIER-16
        122880 <= code && code <= 122886 || // Mn   [7] COMBINING GLAGOLITIC LETTER AZU..COMBINING GLAGOLITIC LETTER ZHIVETE
        122888 <= code && code <= 122904 || // Mn  [17] COMBINING GLAGOLITIC LETTER ZEMLJA..COMBINING GLAGOLITIC LETTER HERU
        122907 <= code && code <= 122913 || // Mn   [7] COMBINING GLAGOLITIC LETTER SHTA..COMBINING GLAGOLITIC LETTER YATI
        122915 <= code && code <= 122916 || // Mn   [2] COMBINING GLAGOLITIC LETTER YU..COMBINING GLAGOLITIC LETTER SMALL YUS
        122918 <= code && code <= 122922 || // Mn   [5] COMBINING GLAGOLITIC LETTER YO..COMBINING GLAGOLITIC LETTER FITA
        125136 <= code && code <= 125142 || // Mn   [7] MENDE KIKAKUI COMBINING NUMBER TEENS..MENDE KIKAKUI COMBINING NUMBER MILLIONS
        125252 <= code && code <= 125258 || // Mn   [7] ADLAM ALIF LENGTHENER..ADLAM NUKTA
        917536 <= code && code <= 917631 || // Cf  [96] TAG SPACE..CANCEL TAG
        917760 <= code && code <= 917999) {
          return Extend;
        }
        if (127462 <= code && code <= 127487) {
          return Regional_Indicator;
        }
        if (2307 == code || // Mc       DEVANAGARI SIGN VISARGA
        2363 == code || // Mc       DEVANAGARI VOWEL SIGN OOE
        2366 <= code && code <= 2368 || // Mc   [3] DEVANAGARI VOWEL SIGN AA..DEVANAGARI VOWEL SIGN II
        2377 <= code && code <= 2380 || // Mc   [4] DEVANAGARI VOWEL SIGN CANDRA O..DEVANAGARI VOWEL SIGN AU
        2382 <= code && code <= 2383 || // Mc   [2] DEVANAGARI VOWEL SIGN PRISHTHAMATRA E..DEVANAGARI VOWEL SIGN AW
        2434 <= code && code <= 2435 || // Mc   [2] BENGALI SIGN ANUSVARA..BENGALI SIGN VISARGA
        2495 <= code && code <= 2496 || // Mc   [2] BENGALI VOWEL SIGN I..BENGALI VOWEL SIGN II
        2503 <= code && code <= 2504 || // Mc   [2] BENGALI VOWEL SIGN E..BENGALI VOWEL SIGN AI
        2507 <= code && code <= 2508 || // Mc   [2] BENGALI VOWEL SIGN O..BENGALI VOWEL SIGN AU
        2563 == code || // Mc       GURMUKHI SIGN VISARGA
        2622 <= code && code <= 2624 || // Mc   [3] GURMUKHI VOWEL SIGN AA..GURMUKHI VOWEL SIGN II
        2691 == code || // Mc       GUJARATI SIGN VISARGA
        2750 <= code && code <= 2752 || // Mc   [3] GUJARATI VOWEL SIGN AA..GUJARATI VOWEL SIGN II
        2761 == code || // Mc       GUJARATI VOWEL SIGN CANDRA O
        2763 <= code && code <= 2764 || // Mc   [2] GUJARATI VOWEL SIGN O..GUJARATI VOWEL SIGN AU
        2818 <= code && code <= 2819 || // Mc   [2] ORIYA SIGN ANUSVARA..ORIYA SIGN VISARGA
        2880 == code || // Mc       ORIYA VOWEL SIGN II
        2887 <= code && code <= 2888 || // Mc   [2] ORIYA VOWEL SIGN E..ORIYA VOWEL SIGN AI
        2891 <= code && code <= 2892 || // Mc   [2] ORIYA VOWEL SIGN O..ORIYA VOWEL SIGN AU
        3007 == code || // Mc       TAMIL VOWEL SIGN I
        3009 <= code && code <= 3010 || // Mc   [2] TAMIL VOWEL SIGN U..TAMIL VOWEL SIGN UU
        3014 <= code && code <= 3016 || // Mc   [3] TAMIL VOWEL SIGN E..TAMIL VOWEL SIGN AI
        3018 <= code && code <= 3020 || // Mc   [3] TAMIL VOWEL SIGN O..TAMIL VOWEL SIGN AU
        3073 <= code && code <= 3075 || // Mc   [3] TELUGU SIGN CANDRABINDU..TELUGU SIGN VISARGA
        3137 <= code && code <= 3140 || // Mc   [4] TELUGU VOWEL SIGN U..TELUGU VOWEL SIGN VOCALIC RR
        3202 <= code && code <= 3203 || // Mc   [2] KANNADA SIGN ANUSVARA..KANNADA SIGN VISARGA
        3262 == code || // Mc       KANNADA VOWEL SIGN AA
        3264 <= code && code <= 3265 || // Mc   [2] KANNADA VOWEL SIGN II..KANNADA VOWEL SIGN U
        3267 <= code && code <= 3268 || // Mc   [2] KANNADA VOWEL SIGN VOCALIC R..KANNADA VOWEL SIGN VOCALIC RR
        3271 <= code && code <= 3272 || // Mc   [2] KANNADA VOWEL SIGN EE..KANNADA VOWEL SIGN AI
        3274 <= code && code <= 3275 || // Mc   [2] KANNADA VOWEL SIGN O..KANNADA VOWEL SIGN OO
        3330 <= code && code <= 3331 || // Mc   [2] MALAYALAM SIGN ANUSVARA..MALAYALAM SIGN VISARGA
        3391 <= code && code <= 3392 || // Mc   [2] MALAYALAM VOWEL SIGN I..MALAYALAM VOWEL SIGN II
        3398 <= code && code <= 3400 || // Mc   [3] MALAYALAM VOWEL SIGN E..MALAYALAM VOWEL SIGN AI
        3402 <= code && code <= 3404 || // Mc   [3] MALAYALAM VOWEL SIGN O..MALAYALAM VOWEL SIGN AU
        3458 <= code && code <= 3459 || // Mc   [2] SINHALA SIGN ANUSVARAYA..SINHALA SIGN VISARGAYA
        3536 <= code && code <= 3537 || // Mc   [2] SINHALA VOWEL SIGN KETTI AEDA-PILLA..SINHALA VOWEL SIGN DIGA AEDA-PILLA
        3544 <= code && code <= 3550 || // Mc   [7] SINHALA VOWEL SIGN GAETTA-PILLA..SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA
        3570 <= code && code <= 3571 || // Mc   [2] SINHALA VOWEL SIGN DIGA GAETTA-PILLA..SINHALA VOWEL SIGN DIGA GAYANUKITTA
        3635 == code || // Lo       THAI CHARACTER SARA AM
        3763 == code || // Lo       LAO VOWEL SIGN AM
        3902 <= code && code <= 3903 || // Mc   [2] TIBETAN SIGN YAR TSHES..TIBETAN SIGN MAR TSHES
        3967 == code || // Mc       TIBETAN SIGN RNAM BCAD
        4145 == code || // Mc       MYANMAR VOWEL SIGN E
        4155 <= code && code <= 4156 || // Mc   [2] MYANMAR CONSONANT SIGN MEDIAL YA..MYANMAR CONSONANT SIGN MEDIAL RA
        4182 <= code && code <= 4183 || // Mc   [2] MYANMAR VOWEL SIGN VOCALIC R..MYANMAR VOWEL SIGN VOCALIC RR
        4228 == code || // Mc       MYANMAR VOWEL SIGN SHAN E
        6070 == code || // Mc       KHMER VOWEL SIGN AA
        6078 <= code && code <= 6085 || // Mc   [8] KHMER VOWEL SIGN OE..KHMER VOWEL SIGN AU
        6087 <= code && code <= 6088 || // Mc   [2] KHMER SIGN REAHMUK..KHMER SIGN YUUKALEAPINTU
        6435 <= code && code <= 6438 || // Mc   [4] LIMBU VOWEL SIGN EE..LIMBU VOWEL SIGN AU
        6441 <= code && code <= 6443 || // Mc   [3] LIMBU SUBJOINED LETTER YA..LIMBU SUBJOINED LETTER WA
        6448 <= code && code <= 6449 || // Mc   [2] LIMBU SMALL LETTER KA..LIMBU SMALL LETTER NGA
        6451 <= code && code <= 6456 || // Mc   [6] LIMBU SMALL LETTER TA..LIMBU SMALL LETTER LA
        6681 <= code && code <= 6682 || // Mc   [2] BUGINESE VOWEL SIGN E..BUGINESE VOWEL SIGN O
        6741 == code || // Mc       TAI THAM CONSONANT SIGN MEDIAL RA
        6743 == code || // Mc       TAI THAM CONSONANT SIGN LA TANG LAI
        6765 <= code && code <= 6770 || // Mc   [6] TAI THAM VOWEL SIGN OY..TAI THAM VOWEL SIGN THAM AI
        6916 == code || // Mc       BALINESE SIGN BISAH
        6965 == code || // Mc       BALINESE VOWEL SIGN TEDUNG
        6971 == code || // Mc       BALINESE VOWEL SIGN RA REPA TEDUNG
        6973 <= code && code <= 6977 || // Mc   [5] BALINESE VOWEL SIGN LA LENGA TEDUNG..BALINESE VOWEL SIGN TALING REPA TEDUNG
        6979 <= code && code <= 6980 || // Mc   [2] BALINESE VOWEL SIGN PEPET TEDUNG..BALINESE ADEG ADEG
        7042 == code || // Mc       SUNDANESE SIGN PANGWISAD
        7073 == code || // Mc       SUNDANESE CONSONANT SIGN PAMINGKAL
        7078 <= code && code <= 7079 || // Mc   [2] SUNDANESE VOWEL SIGN PANAELAENG..SUNDANESE VOWEL SIGN PANOLONG
        7082 == code || // Mc       SUNDANESE SIGN PAMAAEH
        7143 == code || // Mc       BATAK VOWEL SIGN E
        7146 <= code && code <= 7148 || // Mc   [3] BATAK VOWEL SIGN I..BATAK VOWEL SIGN O
        7150 == code || // Mc       BATAK VOWEL SIGN U
        7154 <= code && code <= 7155 || // Mc   [2] BATAK PANGOLAT..BATAK PANONGONAN
        7204 <= code && code <= 7211 || // Mc   [8] LEPCHA SUBJOINED LETTER YA..LEPCHA VOWEL SIGN UU
        7220 <= code && code <= 7221 || // Mc   [2] LEPCHA CONSONANT SIGN NYIN-DO..LEPCHA CONSONANT SIGN KANG
        7393 == code || // Mc       VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA
        7410 <= code && code <= 7411 || // Mc   [2] VEDIC SIGN ARDHAVISARGA..VEDIC SIGN ROTATED ARDHAVISARGA
        7415 == code || // Mc       VEDIC SIGN ATIKRAMA
        43043 <= code && code <= 43044 || // Mc   [2] SYLOTI NAGRI VOWEL SIGN A..SYLOTI NAGRI VOWEL SIGN I
        43047 == code || // Mc       SYLOTI NAGRI VOWEL SIGN OO
        43136 <= code && code <= 43137 || // Mc   [2] SAURASHTRA SIGN ANUSVARA..SAURASHTRA SIGN VISARGA
        43188 <= code && code <= 43203 || // Mc  [16] SAURASHTRA CONSONANT SIGN HAARU..SAURASHTRA VOWEL SIGN AU
        43346 <= code && code <= 43347 || // Mc   [2] REJANG CONSONANT SIGN H..REJANG VIRAMA
        43395 == code || // Mc       JAVANESE SIGN WIGNYAN
        43444 <= code && code <= 43445 || // Mc   [2] JAVANESE VOWEL SIGN TARUNG..JAVANESE VOWEL SIGN TOLONG
        43450 <= code && code <= 43451 || // Mc   [2] JAVANESE VOWEL SIGN TALING..JAVANESE VOWEL SIGN DIRGA MURE
        43453 <= code && code <= 43456 || // Mc   [4] JAVANESE CONSONANT SIGN KERET..JAVANESE PANGKON
        43567 <= code && code <= 43568 || // Mc   [2] CHAM VOWEL SIGN O..CHAM VOWEL SIGN AI
        43571 <= code && code <= 43572 || // Mc   [2] CHAM CONSONANT SIGN YA..CHAM CONSONANT SIGN RA
        43597 == code || // Mc       CHAM CONSONANT SIGN FINAL H
        43755 == code || // Mc       MEETEI MAYEK VOWEL SIGN II
        43758 <= code && code <= 43759 || // Mc   [2] MEETEI MAYEK VOWEL SIGN AU..MEETEI MAYEK VOWEL SIGN AAU
        43765 == code || // Mc       MEETEI MAYEK VOWEL SIGN VISARGA
        44003 <= code && code <= 44004 || // Mc   [2] MEETEI MAYEK VOWEL SIGN ONAP..MEETEI MAYEK VOWEL SIGN INAP
        44006 <= code && code <= 44007 || // Mc   [2] MEETEI MAYEK VOWEL SIGN YENAP..MEETEI MAYEK VOWEL SIGN SOUNAP
        44009 <= code && code <= 44010 || // Mc   [2] MEETEI MAYEK VOWEL SIGN CHEINAP..MEETEI MAYEK VOWEL SIGN NUNG
        44012 == code || // Mc       MEETEI MAYEK LUM IYEK
        69632 == code || // Mc       BRAHMI SIGN CANDRABINDU
        69634 == code || // Mc       BRAHMI SIGN VISARGA
        69762 == code || // Mc       KAITHI SIGN VISARGA
        69808 <= code && code <= 69810 || // Mc   [3] KAITHI VOWEL SIGN AA..KAITHI VOWEL SIGN II
        69815 <= code && code <= 69816 || // Mc   [2] KAITHI VOWEL SIGN O..KAITHI VOWEL SIGN AU
        69932 == code || // Mc       CHAKMA VOWEL SIGN E
        70018 == code || // Mc       SHARADA SIGN VISARGA
        70067 <= code && code <= 70069 || // Mc   [3] SHARADA VOWEL SIGN AA..SHARADA VOWEL SIGN II
        70079 <= code && code <= 70080 || // Mc   [2] SHARADA VOWEL SIGN AU..SHARADA SIGN VIRAMA
        70188 <= code && code <= 70190 || // Mc   [3] KHOJKI VOWEL SIGN AA..KHOJKI VOWEL SIGN II
        70194 <= code && code <= 70195 || // Mc   [2] KHOJKI VOWEL SIGN O..KHOJKI VOWEL SIGN AU
        70197 == code || // Mc       KHOJKI SIGN VIRAMA
        70368 <= code && code <= 70370 || // Mc   [3] KHUDAWADI VOWEL SIGN AA..KHUDAWADI VOWEL SIGN II
        70402 <= code && code <= 70403 || // Mc   [2] GRANTHA SIGN ANUSVARA..GRANTHA SIGN VISARGA
        70463 == code || // Mc       GRANTHA VOWEL SIGN I
        70465 <= code && code <= 70468 || // Mc   [4] GRANTHA VOWEL SIGN U..GRANTHA VOWEL SIGN VOCALIC RR
        70471 <= code && code <= 70472 || // Mc   [2] GRANTHA VOWEL SIGN EE..GRANTHA VOWEL SIGN AI
        70475 <= code && code <= 70477 || // Mc   [3] GRANTHA VOWEL SIGN OO..GRANTHA SIGN VIRAMA
        70498 <= code && code <= 70499 || // Mc   [2] GRANTHA VOWEL SIGN VOCALIC L..GRANTHA VOWEL SIGN VOCALIC LL
        70709 <= code && code <= 70711 || // Mc   [3] NEWA VOWEL SIGN AA..NEWA VOWEL SIGN II
        70720 <= code && code <= 70721 || // Mc   [2] NEWA VOWEL SIGN O..NEWA VOWEL SIGN AU
        70725 == code || // Mc       NEWA SIGN VISARGA
        70833 <= code && code <= 70834 || // Mc   [2] TIRHUTA VOWEL SIGN I..TIRHUTA VOWEL SIGN II
        70841 == code || // Mc       TIRHUTA VOWEL SIGN E
        70843 <= code && code <= 70844 || // Mc   [2] TIRHUTA VOWEL SIGN AI..TIRHUTA VOWEL SIGN O
        70846 == code || // Mc       TIRHUTA VOWEL SIGN AU
        70849 == code || // Mc       TIRHUTA SIGN VISARGA
        71088 <= code && code <= 71089 || // Mc   [2] SIDDHAM VOWEL SIGN I..SIDDHAM VOWEL SIGN II
        71096 <= code && code <= 71099 || // Mc   [4] SIDDHAM VOWEL SIGN E..SIDDHAM VOWEL SIGN AU
        71102 == code || // Mc       SIDDHAM SIGN VISARGA
        71216 <= code && code <= 71218 || // Mc   [3] MODI VOWEL SIGN AA..MODI VOWEL SIGN II
        71227 <= code && code <= 71228 || // Mc   [2] MODI VOWEL SIGN O..MODI VOWEL SIGN AU
        71230 == code || // Mc       MODI SIGN VISARGA
        71340 == code || // Mc       TAKRI SIGN VISARGA
        71342 <= code && code <= 71343 || // Mc   [2] TAKRI VOWEL SIGN I..TAKRI VOWEL SIGN II
        71350 == code || // Mc       TAKRI SIGN VIRAMA
        71456 <= code && code <= 71457 || // Mc   [2] AHOM VOWEL SIGN A..AHOM VOWEL SIGN AA
        71462 == code || // Mc       AHOM VOWEL SIGN E
        72199 <= code && code <= 72200 || // Mc   [2] ZANABAZAR SQUARE VOWEL SIGN AI..ZANABAZAR SQUARE VOWEL SIGN AU
        72249 == code || // Mc       ZANABAZAR SQUARE SIGN VISARGA
        72279 <= code && code <= 72280 || // Mc   [2] SOYOMBO VOWEL SIGN AI..SOYOMBO VOWEL SIGN AU
        72343 == code || // Mc       SOYOMBO SIGN VISARGA
        72751 == code || // Mc       BHAIKSUKI VOWEL SIGN AA
        72766 == code || // Mc       BHAIKSUKI SIGN VISARGA
        72873 == code || // Mc       MARCHEN SUBJOINED LETTER YA
        72881 == code || // Mc       MARCHEN VOWEL SIGN I
        72884 == code || // Mc       MARCHEN VOWEL SIGN O
        94033 <= code && code <= 94078 || // Mc  [46] MIAO SIGN ASPIRATION..MIAO VOWEL SIGN NG
        119142 == code || // Mc       MUSICAL SYMBOL COMBINING SPRECHGESANG STEM
        119149 == code) {
          return SpacingMark;
        }
        if (4352 <= code && code <= 4447 || // Lo  [96] HANGUL CHOSEONG KIYEOK..HANGUL CHOSEONG FILLER
        43360 <= code && code <= 43388) {
          return L;
        }
        if (4448 <= code && code <= 4519 || // Lo  [72] HANGUL JUNGSEONG FILLER..HANGUL JUNGSEONG O-YAE
        55216 <= code && code <= 55238) {
          return V;
        }
        if (4520 <= code && code <= 4607 || // Lo  [88] HANGUL JONGSEONG KIYEOK..HANGUL JONGSEONG SSANGNIEUN
        55243 <= code && code <= 55291) {
          return T;
        }
        if (44032 == code || // Lo       HANGUL SYLLABLE GA
        44060 == code || // Lo       HANGUL SYLLABLE GAE
        44088 == code || // Lo       HANGUL SYLLABLE GYA
        44116 == code || // Lo       HANGUL SYLLABLE GYAE
        44144 == code || // Lo       HANGUL SYLLABLE GEO
        44172 == code || // Lo       HANGUL SYLLABLE GE
        44200 == code || // Lo       HANGUL SYLLABLE GYEO
        44228 == code || // Lo       HANGUL SYLLABLE GYE
        44256 == code || // Lo       HANGUL SYLLABLE GO
        44284 == code || // Lo       HANGUL SYLLABLE GWA
        44312 == code || // Lo       HANGUL SYLLABLE GWAE
        44340 == code || // Lo       HANGUL SYLLABLE GOE
        44368 == code || // Lo       HANGUL SYLLABLE GYO
        44396 == code || // Lo       HANGUL SYLLABLE GU
        44424 == code || // Lo       HANGUL SYLLABLE GWEO
        44452 == code || // Lo       HANGUL SYLLABLE GWE
        44480 == code || // Lo       HANGUL SYLLABLE GWI
        44508 == code || // Lo       HANGUL SYLLABLE GYU
        44536 == code || // Lo       HANGUL SYLLABLE GEU
        44564 == code || // Lo       HANGUL SYLLABLE GYI
        44592 == code || // Lo       HANGUL SYLLABLE GI
        44620 == code || // Lo       HANGUL SYLLABLE GGA
        44648 == code || // Lo       HANGUL SYLLABLE GGAE
        44676 == code || // Lo       HANGUL SYLLABLE GGYA
        44704 == code || // Lo       HANGUL SYLLABLE GGYAE
        44732 == code || // Lo       HANGUL SYLLABLE GGEO
        44760 == code || // Lo       HANGUL SYLLABLE GGE
        44788 == code || // Lo       HANGUL SYLLABLE GGYEO
        44816 == code || // Lo       HANGUL SYLLABLE GGYE
        44844 == code || // Lo       HANGUL SYLLABLE GGO
        44872 == code || // Lo       HANGUL SYLLABLE GGWA
        44900 == code || // Lo       HANGUL SYLLABLE GGWAE
        44928 == code || // Lo       HANGUL SYLLABLE GGOE
        44956 == code || // Lo       HANGUL SYLLABLE GGYO
        44984 == code || // Lo       HANGUL SYLLABLE GGU
        45012 == code || // Lo       HANGUL SYLLABLE GGWEO
        45040 == code || // Lo       HANGUL SYLLABLE GGWE
        45068 == code || // Lo       HANGUL SYLLABLE GGWI
        45096 == code || // Lo       HANGUL SYLLABLE GGYU
        45124 == code || // Lo       HANGUL SYLLABLE GGEU
        45152 == code || // Lo       HANGUL SYLLABLE GGYI
        45180 == code || // Lo       HANGUL SYLLABLE GGI
        45208 == code || // Lo       HANGUL SYLLABLE NA
        45236 == code || // Lo       HANGUL SYLLABLE NAE
        45264 == code || // Lo       HANGUL SYLLABLE NYA
        45292 == code || // Lo       HANGUL SYLLABLE NYAE
        45320 == code || // Lo       HANGUL SYLLABLE NEO
        45348 == code || // Lo       HANGUL SYLLABLE NE
        45376 == code || // Lo       HANGUL SYLLABLE NYEO
        45404 == code || // Lo       HANGUL SYLLABLE NYE
        45432 == code || // Lo       HANGUL SYLLABLE NO
        45460 == code || // Lo       HANGUL SYLLABLE NWA
        45488 == code || // Lo       HANGUL SYLLABLE NWAE
        45516 == code || // Lo       HANGUL SYLLABLE NOE
        45544 == code || // Lo       HANGUL SYLLABLE NYO
        45572 == code || // Lo       HANGUL SYLLABLE NU
        45600 == code || // Lo       HANGUL SYLLABLE NWEO
        45628 == code || // Lo       HANGUL SYLLABLE NWE
        45656 == code || // Lo       HANGUL SYLLABLE NWI
        45684 == code || // Lo       HANGUL SYLLABLE NYU
        45712 == code || // Lo       HANGUL SYLLABLE NEU
        45740 == code || // Lo       HANGUL SYLLABLE NYI
        45768 == code || // Lo       HANGUL SYLLABLE NI
        45796 == code || // Lo       HANGUL SYLLABLE DA
        45824 == code || // Lo       HANGUL SYLLABLE DAE
        45852 == code || // Lo       HANGUL SYLLABLE DYA
        45880 == code || // Lo       HANGUL SYLLABLE DYAE
        45908 == code || // Lo       HANGUL SYLLABLE DEO
        45936 == code || // Lo       HANGUL SYLLABLE DE
        45964 == code || // Lo       HANGUL SYLLABLE DYEO
        45992 == code || // Lo       HANGUL SYLLABLE DYE
        46020 == code || // Lo       HANGUL SYLLABLE DO
        46048 == code || // Lo       HANGUL SYLLABLE DWA
        46076 == code || // Lo       HANGUL SYLLABLE DWAE
        46104 == code || // Lo       HANGUL SYLLABLE DOE
        46132 == code || // Lo       HANGUL SYLLABLE DYO
        46160 == code || // Lo       HANGUL SYLLABLE DU
        46188 == code || // Lo       HANGUL SYLLABLE DWEO
        46216 == code || // Lo       HANGUL SYLLABLE DWE
        46244 == code || // Lo       HANGUL SYLLABLE DWI
        46272 == code || // Lo       HANGUL SYLLABLE DYU
        46300 == code || // Lo       HANGUL SYLLABLE DEU
        46328 == code || // Lo       HANGUL SYLLABLE DYI
        46356 == code || // Lo       HANGUL SYLLABLE DI
        46384 == code || // Lo       HANGUL SYLLABLE DDA
        46412 == code || // Lo       HANGUL SYLLABLE DDAE
        46440 == code || // Lo       HANGUL SYLLABLE DDYA
        46468 == code || // Lo       HANGUL SYLLABLE DDYAE
        46496 == code || // Lo       HANGUL SYLLABLE DDEO
        46524 == code || // Lo       HANGUL SYLLABLE DDE
        46552 == code || // Lo       HANGUL SYLLABLE DDYEO
        46580 == code || // Lo       HANGUL SYLLABLE DDYE
        46608 == code || // Lo       HANGUL SYLLABLE DDO
        46636 == code || // Lo       HANGUL SYLLABLE DDWA
        46664 == code || // Lo       HANGUL SYLLABLE DDWAE
        46692 == code || // Lo       HANGUL SYLLABLE DDOE
        46720 == code || // Lo       HANGUL SYLLABLE DDYO
        46748 == code || // Lo       HANGUL SYLLABLE DDU
        46776 == code || // Lo       HANGUL SYLLABLE DDWEO
        46804 == code || // Lo       HANGUL SYLLABLE DDWE
        46832 == code || // Lo       HANGUL SYLLABLE DDWI
        46860 == code || // Lo       HANGUL SYLLABLE DDYU
        46888 == code || // Lo       HANGUL SYLLABLE DDEU
        46916 == code || // Lo       HANGUL SYLLABLE DDYI
        46944 == code || // Lo       HANGUL SYLLABLE DDI
        46972 == code || // Lo       HANGUL SYLLABLE RA
        47e3 == code || // Lo       HANGUL SYLLABLE RAE
        47028 == code || // Lo       HANGUL SYLLABLE RYA
        47056 == code || // Lo       HANGUL SYLLABLE RYAE
        47084 == code || // Lo       HANGUL SYLLABLE REO
        47112 == code || // Lo       HANGUL SYLLABLE RE
        47140 == code || // Lo       HANGUL SYLLABLE RYEO
        47168 == code || // Lo       HANGUL SYLLABLE RYE
        47196 == code || // Lo       HANGUL SYLLABLE RO
        47224 == code || // Lo       HANGUL SYLLABLE RWA
        47252 == code || // Lo       HANGUL SYLLABLE RWAE
        47280 == code || // Lo       HANGUL SYLLABLE ROE
        47308 == code || // Lo       HANGUL SYLLABLE RYO
        47336 == code || // Lo       HANGUL SYLLABLE RU
        47364 == code || // Lo       HANGUL SYLLABLE RWEO
        47392 == code || // Lo       HANGUL SYLLABLE RWE
        47420 == code || // Lo       HANGUL SYLLABLE RWI
        47448 == code || // Lo       HANGUL SYLLABLE RYU
        47476 == code || // Lo       HANGUL SYLLABLE REU
        47504 == code || // Lo       HANGUL SYLLABLE RYI
        47532 == code || // Lo       HANGUL SYLLABLE RI
        47560 == code || // Lo       HANGUL SYLLABLE MA
        47588 == code || // Lo       HANGUL SYLLABLE MAE
        47616 == code || // Lo       HANGUL SYLLABLE MYA
        47644 == code || // Lo       HANGUL SYLLABLE MYAE
        47672 == code || // Lo       HANGUL SYLLABLE MEO
        47700 == code || // Lo       HANGUL SYLLABLE ME
        47728 == code || // Lo       HANGUL SYLLABLE MYEO
        47756 == code || // Lo       HANGUL SYLLABLE MYE
        47784 == code || // Lo       HANGUL SYLLABLE MO
        47812 == code || // Lo       HANGUL SYLLABLE MWA
        47840 == code || // Lo       HANGUL SYLLABLE MWAE
        47868 == code || // Lo       HANGUL SYLLABLE MOE
        47896 == code || // Lo       HANGUL SYLLABLE MYO
        47924 == code || // Lo       HANGUL SYLLABLE MU
        47952 == code || // Lo       HANGUL SYLLABLE MWEO
        47980 == code || // Lo       HANGUL SYLLABLE MWE
        48008 == code || // Lo       HANGUL SYLLABLE MWI
        48036 == code || // Lo       HANGUL SYLLABLE MYU
        48064 == code || // Lo       HANGUL SYLLABLE MEU
        48092 == code || // Lo       HANGUL SYLLABLE MYI
        48120 == code || // Lo       HANGUL SYLLABLE MI
        48148 == code || // Lo       HANGUL SYLLABLE BA
        48176 == code || // Lo       HANGUL SYLLABLE BAE
        48204 == code || // Lo       HANGUL SYLLABLE BYA
        48232 == code || // Lo       HANGUL SYLLABLE BYAE
        48260 == code || // Lo       HANGUL SYLLABLE BEO
        48288 == code || // Lo       HANGUL SYLLABLE BE
        48316 == code || // Lo       HANGUL SYLLABLE BYEO
        48344 == code || // Lo       HANGUL SYLLABLE BYE
        48372 == code || // Lo       HANGUL SYLLABLE BO
        48400 == code || // Lo       HANGUL SYLLABLE BWA
        48428 == code || // Lo       HANGUL SYLLABLE BWAE
        48456 == code || // Lo       HANGUL SYLLABLE BOE
        48484 == code || // Lo       HANGUL SYLLABLE BYO
        48512 == code || // Lo       HANGUL SYLLABLE BU
        48540 == code || // Lo       HANGUL SYLLABLE BWEO
        48568 == code || // Lo       HANGUL SYLLABLE BWE
        48596 == code || // Lo       HANGUL SYLLABLE BWI
        48624 == code || // Lo       HANGUL SYLLABLE BYU
        48652 == code || // Lo       HANGUL SYLLABLE BEU
        48680 == code || // Lo       HANGUL SYLLABLE BYI
        48708 == code || // Lo       HANGUL SYLLABLE BI
        48736 == code || // Lo       HANGUL SYLLABLE BBA
        48764 == code || // Lo       HANGUL SYLLABLE BBAE
        48792 == code || // Lo       HANGUL SYLLABLE BBYA
        48820 == code || // Lo       HANGUL SYLLABLE BBYAE
        48848 == code || // Lo       HANGUL SYLLABLE BBEO
        48876 == code || // Lo       HANGUL SYLLABLE BBE
        48904 == code || // Lo       HANGUL SYLLABLE BBYEO
        48932 == code || // Lo       HANGUL SYLLABLE BBYE
        48960 == code || // Lo       HANGUL SYLLABLE BBO
        48988 == code || // Lo       HANGUL SYLLABLE BBWA
        49016 == code || // Lo       HANGUL SYLLABLE BBWAE
        49044 == code || // Lo       HANGUL SYLLABLE BBOE
        49072 == code || // Lo       HANGUL SYLLABLE BBYO
        49100 == code || // Lo       HANGUL SYLLABLE BBU
        49128 == code || // Lo       HANGUL SYLLABLE BBWEO
        49156 == code || // Lo       HANGUL SYLLABLE BBWE
        49184 == code || // Lo       HANGUL SYLLABLE BBWI
        49212 == code || // Lo       HANGUL SYLLABLE BBYU
        49240 == code || // Lo       HANGUL SYLLABLE BBEU
        49268 == code || // Lo       HANGUL SYLLABLE BBYI
        49296 == code || // Lo       HANGUL SYLLABLE BBI
        49324 == code || // Lo       HANGUL SYLLABLE SA
        49352 == code || // Lo       HANGUL SYLLABLE SAE
        49380 == code || // Lo       HANGUL SYLLABLE SYA
        49408 == code || // Lo       HANGUL SYLLABLE SYAE
        49436 == code || // Lo       HANGUL SYLLABLE SEO
        49464 == code || // Lo       HANGUL SYLLABLE SE
        49492 == code || // Lo       HANGUL SYLLABLE SYEO
        49520 == code || // Lo       HANGUL SYLLABLE SYE
        49548 == code || // Lo       HANGUL SYLLABLE SO
        49576 == code || // Lo       HANGUL SYLLABLE SWA
        49604 == code || // Lo       HANGUL SYLLABLE SWAE
        49632 == code || // Lo       HANGUL SYLLABLE SOE
        49660 == code || // Lo       HANGUL SYLLABLE SYO
        49688 == code || // Lo       HANGUL SYLLABLE SU
        49716 == code || // Lo       HANGUL SYLLABLE SWEO
        49744 == code || // Lo       HANGUL SYLLABLE SWE
        49772 == code || // Lo       HANGUL SYLLABLE SWI
        49800 == code || // Lo       HANGUL SYLLABLE SYU
        49828 == code || // Lo       HANGUL SYLLABLE SEU
        49856 == code || // Lo       HANGUL SYLLABLE SYI
        49884 == code || // Lo       HANGUL SYLLABLE SI
        49912 == code || // Lo       HANGUL SYLLABLE SSA
        49940 == code || // Lo       HANGUL SYLLABLE SSAE
        49968 == code || // Lo       HANGUL SYLLABLE SSYA
        49996 == code || // Lo       HANGUL SYLLABLE SSYAE
        50024 == code || // Lo       HANGUL SYLLABLE SSEO
        50052 == code || // Lo       HANGUL SYLLABLE SSE
        50080 == code || // Lo       HANGUL SYLLABLE SSYEO
        50108 == code || // Lo       HANGUL SYLLABLE SSYE
        50136 == code || // Lo       HANGUL SYLLABLE SSO
        50164 == code || // Lo       HANGUL SYLLABLE SSWA
        50192 == code || // Lo       HANGUL SYLLABLE SSWAE
        50220 == code || // Lo       HANGUL SYLLABLE SSOE
        50248 == code || // Lo       HANGUL SYLLABLE SSYO
        50276 == code || // Lo       HANGUL SYLLABLE SSU
        50304 == code || // Lo       HANGUL SYLLABLE SSWEO
        50332 == code || // Lo       HANGUL SYLLABLE SSWE
        50360 == code || // Lo       HANGUL SYLLABLE SSWI
        50388 == code || // Lo       HANGUL SYLLABLE SSYU
        50416 == code || // Lo       HANGUL SYLLABLE SSEU
        50444 == code || // Lo       HANGUL SYLLABLE SSYI
        50472 == code || // Lo       HANGUL SYLLABLE SSI
        50500 == code || // Lo       HANGUL SYLLABLE A
        50528 == code || // Lo       HANGUL SYLLABLE AE
        50556 == code || // Lo       HANGUL SYLLABLE YA
        50584 == code || // Lo       HANGUL SYLLABLE YAE
        50612 == code || // Lo       HANGUL SYLLABLE EO
        50640 == code || // Lo       HANGUL SYLLABLE E
        50668 == code || // Lo       HANGUL SYLLABLE YEO
        50696 == code || // Lo       HANGUL SYLLABLE YE
        50724 == code || // Lo       HANGUL SYLLABLE O
        50752 == code || // Lo       HANGUL SYLLABLE WA
        50780 == code || // Lo       HANGUL SYLLABLE WAE
        50808 == code || // Lo       HANGUL SYLLABLE OE
        50836 == code || // Lo       HANGUL SYLLABLE YO
        50864 == code || // Lo       HANGUL SYLLABLE U
        50892 == code || // Lo       HANGUL SYLLABLE WEO
        50920 == code || // Lo       HANGUL SYLLABLE WE
        50948 == code || // Lo       HANGUL SYLLABLE WI
        50976 == code || // Lo       HANGUL SYLLABLE YU
        51004 == code || // Lo       HANGUL SYLLABLE EU
        51032 == code || // Lo       HANGUL SYLLABLE YI
        51060 == code || // Lo       HANGUL SYLLABLE I
        51088 == code || // Lo       HANGUL SYLLABLE JA
        51116 == code || // Lo       HANGUL SYLLABLE JAE
        51144 == code || // Lo       HANGUL SYLLABLE JYA
        51172 == code || // Lo       HANGUL SYLLABLE JYAE
        51200 == code || // Lo       HANGUL SYLLABLE JEO
        51228 == code || // Lo       HANGUL SYLLABLE JE
        51256 == code || // Lo       HANGUL SYLLABLE JYEO
        51284 == code || // Lo       HANGUL SYLLABLE JYE
        51312 == code || // Lo       HANGUL SYLLABLE JO
        51340 == code || // Lo       HANGUL SYLLABLE JWA
        51368 == code || // Lo       HANGUL SYLLABLE JWAE
        51396 == code || // Lo       HANGUL SYLLABLE JOE
        51424 == code || // Lo       HANGUL SYLLABLE JYO
        51452 == code || // Lo       HANGUL SYLLABLE JU
        51480 == code || // Lo       HANGUL SYLLABLE JWEO
        51508 == code || // Lo       HANGUL SYLLABLE JWE
        51536 == code || // Lo       HANGUL SYLLABLE JWI
        51564 == code || // Lo       HANGUL SYLLABLE JYU
        51592 == code || // Lo       HANGUL SYLLABLE JEU
        51620 == code || // Lo       HANGUL SYLLABLE JYI
        51648 == code || // Lo       HANGUL SYLLABLE JI
        51676 == code || // Lo       HANGUL SYLLABLE JJA
        51704 == code || // Lo       HANGUL SYLLABLE JJAE
        51732 == code || // Lo       HANGUL SYLLABLE JJYA
        51760 == code || // Lo       HANGUL SYLLABLE JJYAE
        51788 == code || // Lo       HANGUL SYLLABLE JJEO
        51816 == code || // Lo       HANGUL SYLLABLE JJE
        51844 == code || // Lo       HANGUL SYLLABLE JJYEO
        51872 == code || // Lo       HANGUL SYLLABLE JJYE
        51900 == code || // Lo       HANGUL SYLLABLE JJO
        51928 == code || // Lo       HANGUL SYLLABLE JJWA
        51956 == code || // Lo       HANGUL SYLLABLE JJWAE
        51984 == code || // Lo       HANGUL SYLLABLE JJOE
        52012 == code || // Lo       HANGUL SYLLABLE JJYO
        52040 == code || // Lo       HANGUL SYLLABLE JJU
        52068 == code || // Lo       HANGUL SYLLABLE JJWEO
        52096 == code || // Lo       HANGUL SYLLABLE JJWE
        52124 == code || // Lo       HANGUL SYLLABLE JJWI
        52152 == code || // Lo       HANGUL SYLLABLE JJYU
        52180 == code || // Lo       HANGUL SYLLABLE JJEU
        52208 == code || // Lo       HANGUL SYLLABLE JJYI
        52236 == code || // Lo       HANGUL SYLLABLE JJI
        52264 == code || // Lo       HANGUL SYLLABLE CA
        52292 == code || // Lo       HANGUL SYLLABLE CAE
        52320 == code || // Lo       HANGUL SYLLABLE CYA
        52348 == code || // Lo       HANGUL SYLLABLE CYAE
        52376 == code || // Lo       HANGUL SYLLABLE CEO
        52404 == code || // Lo       HANGUL SYLLABLE CE
        52432 == code || // Lo       HANGUL SYLLABLE CYEO
        52460 == code || // Lo       HANGUL SYLLABLE CYE
        52488 == code || // Lo       HANGUL SYLLABLE CO
        52516 == code || // Lo       HANGUL SYLLABLE CWA
        52544 == code || // Lo       HANGUL SYLLABLE CWAE
        52572 == code || // Lo       HANGUL SYLLABLE COE
        52600 == code || // Lo       HANGUL SYLLABLE CYO
        52628 == code || // Lo       HANGUL SYLLABLE CU
        52656 == code || // Lo       HANGUL SYLLABLE CWEO
        52684 == code || // Lo       HANGUL SYLLABLE CWE
        52712 == code || // Lo       HANGUL SYLLABLE CWI
        52740 == code || // Lo       HANGUL SYLLABLE CYU
        52768 == code || // Lo       HANGUL SYLLABLE CEU
        52796 == code || // Lo       HANGUL SYLLABLE CYI
        52824 == code || // Lo       HANGUL SYLLABLE CI
        52852 == code || // Lo       HANGUL SYLLABLE KA
        52880 == code || // Lo       HANGUL SYLLABLE KAE
        52908 == code || // Lo       HANGUL SYLLABLE KYA
        52936 == code || // Lo       HANGUL SYLLABLE KYAE
        52964 == code || // Lo       HANGUL SYLLABLE KEO
        52992 == code || // Lo       HANGUL SYLLABLE KE
        53020 == code || // Lo       HANGUL SYLLABLE KYEO
        53048 == code || // Lo       HANGUL SYLLABLE KYE
        53076 == code || // Lo       HANGUL SYLLABLE KO
        53104 == code || // Lo       HANGUL SYLLABLE KWA
        53132 == code || // Lo       HANGUL SYLLABLE KWAE
        53160 == code || // Lo       HANGUL SYLLABLE KOE
        53188 == code || // Lo       HANGUL SYLLABLE KYO
        53216 == code || // Lo       HANGUL SYLLABLE KU
        53244 == code || // Lo       HANGUL SYLLABLE KWEO
        53272 == code || // Lo       HANGUL SYLLABLE KWE
        53300 == code || // Lo       HANGUL SYLLABLE KWI
        53328 == code || // Lo       HANGUL SYLLABLE KYU
        53356 == code || // Lo       HANGUL SYLLABLE KEU
        53384 == code || // Lo       HANGUL SYLLABLE KYI
        53412 == code || // Lo       HANGUL SYLLABLE KI
        53440 == code || // Lo       HANGUL SYLLABLE TA
        53468 == code || // Lo       HANGUL SYLLABLE TAE
        53496 == code || // Lo       HANGUL SYLLABLE TYA
        53524 == code || // Lo       HANGUL SYLLABLE TYAE
        53552 == code || // Lo       HANGUL SYLLABLE TEO
        53580 == code || // Lo       HANGUL SYLLABLE TE
        53608 == code || // Lo       HANGUL SYLLABLE TYEO
        53636 == code || // Lo       HANGUL SYLLABLE TYE
        53664 == code || // Lo       HANGUL SYLLABLE TO
        53692 == code || // Lo       HANGUL SYLLABLE TWA
        53720 == code || // Lo       HANGUL SYLLABLE TWAE
        53748 == code || // Lo       HANGUL SYLLABLE TOE
        53776 == code || // Lo       HANGUL SYLLABLE TYO
        53804 == code || // Lo       HANGUL SYLLABLE TU
        53832 == code || // Lo       HANGUL SYLLABLE TWEO
        53860 == code || // Lo       HANGUL SYLLABLE TWE
        53888 == code || // Lo       HANGUL SYLLABLE TWI
        53916 == code || // Lo       HANGUL SYLLABLE TYU
        53944 == code || // Lo       HANGUL SYLLABLE TEU
        53972 == code || // Lo       HANGUL SYLLABLE TYI
        54e3 == code || // Lo       HANGUL SYLLABLE TI
        54028 == code || // Lo       HANGUL SYLLABLE PA
        54056 == code || // Lo       HANGUL SYLLABLE PAE
        54084 == code || // Lo       HANGUL SYLLABLE PYA
        54112 == code || // Lo       HANGUL SYLLABLE PYAE
        54140 == code || // Lo       HANGUL SYLLABLE PEO
        54168 == code || // Lo       HANGUL SYLLABLE PE
        54196 == code || // Lo       HANGUL SYLLABLE PYEO
        54224 == code || // Lo       HANGUL SYLLABLE PYE
        54252 == code || // Lo       HANGUL SYLLABLE PO
        54280 == code || // Lo       HANGUL SYLLABLE PWA
        54308 == code || // Lo       HANGUL SYLLABLE PWAE
        54336 == code || // Lo       HANGUL SYLLABLE POE
        54364 == code || // Lo       HANGUL SYLLABLE PYO
        54392 == code || // Lo       HANGUL SYLLABLE PU
        54420 == code || // Lo       HANGUL SYLLABLE PWEO
        54448 == code || // Lo       HANGUL SYLLABLE PWE
        54476 == code || // Lo       HANGUL SYLLABLE PWI
        54504 == code || // Lo       HANGUL SYLLABLE PYU
        54532 == code || // Lo       HANGUL SYLLABLE PEU
        54560 == code || // Lo       HANGUL SYLLABLE PYI
        54588 == code || // Lo       HANGUL SYLLABLE PI
        54616 == code || // Lo       HANGUL SYLLABLE HA
        54644 == code || // Lo       HANGUL SYLLABLE HAE
        54672 == code || // Lo       HANGUL SYLLABLE HYA
        54700 == code || // Lo       HANGUL SYLLABLE HYAE
        54728 == code || // Lo       HANGUL SYLLABLE HEO
        54756 == code || // Lo       HANGUL SYLLABLE HE
        54784 == code || // Lo       HANGUL SYLLABLE HYEO
        54812 == code || // Lo       HANGUL SYLLABLE HYE
        54840 == code || // Lo       HANGUL SYLLABLE HO
        54868 == code || // Lo       HANGUL SYLLABLE HWA
        54896 == code || // Lo       HANGUL SYLLABLE HWAE
        54924 == code || // Lo       HANGUL SYLLABLE HOE
        54952 == code || // Lo       HANGUL SYLLABLE HYO
        54980 == code || // Lo       HANGUL SYLLABLE HU
        55008 == code || // Lo       HANGUL SYLLABLE HWEO
        55036 == code || // Lo       HANGUL SYLLABLE HWE
        55064 == code || // Lo       HANGUL SYLLABLE HWI
        55092 == code || // Lo       HANGUL SYLLABLE HYU
        55120 == code || // Lo       HANGUL SYLLABLE HEU
        55148 == code || // Lo       HANGUL SYLLABLE HYI
        55176 == code) {
          return LV;
        }
        if (44033 <= code && code <= 44059 || // Lo  [27] HANGUL SYLLABLE GAG..HANGUL SYLLABLE GAH
        44061 <= code && code <= 44087 || // Lo  [27] HANGUL SYLLABLE GAEG..HANGUL SYLLABLE GAEH
        44089 <= code && code <= 44115 || // Lo  [27] HANGUL SYLLABLE GYAG..HANGUL SYLLABLE GYAH
        44117 <= code && code <= 44143 || // Lo  [27] HANGUL SYLLABLE GYAEG..HANGUL SYLLABLE GYAEH
        44145 <= code && code <= 44171 || // Lo  [27] HANGUL SYLLABLE GEOG..HANGUL SYLLABLE GEOH
        44173 <= code && code <= 44199 || // Lo  [27] HANGUL SYLLABLE GEG..HANGUL SYLLABLE GEH
        44201 <= code && code <= 44227 || // Lo  [27] HANGUL SYLLABLE GYEOG..HANGUL SYLLABLE GYEOH
        44229 <= code && code <= 44255 || // Lo  [27] HANGUL SYLLABLE GYEG..HANGUL SYLLABLE GYEH
        44257 <= code && code <= 44283 || // Lo  [27] HANGUL SYLLABLE GOG..HANGUL SYLLABLE GOH
        44285 <= code && code <= 44311 || // Lo  [27] HANGUL SYLLABLE GWAG..HANGUL SYLLABLE GWAH
        44313 <= code && code <= 44339 || // Lo  [27] HANGUL SYLLABLE GWAEG..HANGUL SYLLABLE GWAEH
        44341 <= code && code <= 44367 || // Lo  [27] HANGUL SYLLABLE GOEG..HANGUL SYLLABLE GOEH
        44369 <= code && code <= 44395 || // Lo  [27] HANGUL SYLLABLE GYOG..HANGUL SYLLABLE GYOH
        44397 <= code && code <= 44423 || // Lo  [27] HANGUL SYLLABLE GUG..HANGUL SYLLABLE GUH
        44425 <= code && code <= 44451 || // Lo  [27] HANGUL SYLLABLE GWEOG..HANGUL SYLLABLE GWEOH
        44453 <= code && code <= 44479 || // Lo  [27] HANGUL SYLLABLE GWEG..HANGUL SYLLABLE GWEH
        44481 <= code && code <= 44507 || // Lo  [27] HANGUL SYLLABLE GWIG..HANGUL SYLLABLE GWIH
        44509 <= code && code <= 44535 || // Lo  [27] HANGUL SYLLABLE GYUG..HANGUL SYLLABLE GYUH
        44537 <= code && code <= 44563 || // Lo  [27] HANGUL SYLLABLE GEUG..HANGUL SYLLABLE GEUH
        44565 <= code && code <= 44591 || // Lo  [27] HANGUL SYLLABLE GYIG..HANGUL SYLLABLE GYIH
        44593 <= code && code <= 44619 || // Lo  [27] HANGUL SYLLABLE GIG..HANGUL SYLLABLE GIH
        44621 <= code && code <= 44647 || // Lo  [27] HANGUL SYLLABLE GGAG..HANGUL SYLLABLE GGAH
        44649 <= code && code <= 44675 || // Lo  [27] HANGUL SYLLABLE GGAEG..HANGUL SYLLABLE GGAEH
        44677 <= code && code <= 44703 || // Lo  [27] HANGUL SYLLABLE GGYAG..HANGUL SYLLABLE GGYAH
        44705 <= code && code <= 44731 || // Lo  [27] HANGUL SYLLABLE GGYAEG..HANGUL SYLLABLE GGYAEH
        44733 <= code && code <= 44759 || // Lo  [27] HANGUL SYLLABLE GGEOG..HANGUL SYLLABLE GGEOH
        44761 <= code && code <= 44787 || // Lo  [27] HANGUL SYLLABLE GGEG..HANGUL SYLLABLE GGEH
        44789 <= code && code <= 44815 || // Lo  [27] HANGUL SYLLABLE GGYEOG..HANGUL SYLLABLE GGYEOH
        44817 <= code && code <= 44843 || // Lo  [27] HANGUL SYLLABLE GGYEG..HANGUL SYLLABLE GGYEH
        44845 <= code && code <= 44871 || // Lo  [27] HANGUL SYLLABLE GGOG..HANGUL SYLLABLE GGOH
        44873 <= code && code <= 44899 || // Lo  [27] HANGUL SYLLABLE GGWAG..HANGUL SYLLABLE GGWAH
        44901 <= code && code <= 44927 || // Lo  [27] HANGUL SYLLABLE GGWAEG..HANGUL SYLLABLE GGWAEH
        44929 <= code && code <= 44955 || // Lo  [27] HANGUL SYLLABLE GGOEG..HANGUL SYLLABLE GGOEH
        44957 <= code && code <= 44983 || // Lo  [27] HANGUL SYLLABLE GGYOG..HANGUL SYLLABLE GGYOH
        44985 <= code && code <= 45011 || // Lo  [27] HANGUL SYLLABLE GGUG..HANGUL SYLLABLE GGUH
        45013 <= code && code <= 45039 || // Lo  [27] HANGUL SYLLABLE GGWEOG..HANGUL SYLLABLE GGWEOH
        45041 <= code && code <= 45067 || // Lo  [27] HANGUL SYLLABLE GGWEG..HANGUL SYLLABLE GGWEH
        45069 <= code && code <= 45095 || // Lo  [27] HANGUL SYLLABLE GGWIG..HANGUL SYLLABLE GGWIH
        45097 <= code && code <= 45123 || // Lo  [27] HANGUL SYLLABLE GGYUG..HANGUL SYLLABLE GGYUH
        45125 <= code && code <= 45151 || // Lo  [27] HANGUL SYLLABLE GGEUG..HANGUL SYLLABLE GGEUH
        45153 <= code && code <= 45179 || // Lo  [27] HANGUL SYLLABLE GGYIG..HANGUL SYLLABLE GGYIH
        45181 <= code && code <= 45207 || // Lo  [27] HANGUL SYLLABLE GGIG..HANGUL SYLLABLE GGIH
        45209 <= code && code <= 45235 || // Lo  [27] HANGUL SYLLABLE NAG..HANGUL SYLLABLE NAH
        45237 <= code && code <= 45263 || // Lo  [27] HANGUL SYLLABLE NAEG..HANGUL SYLLABLE NAEH
        45265 <= code && code <= 45291 || // Lo  [27] HANGUL SYLLABLE NYAG..HANGUL SYLLABLE NYAH
        45293 <= code && code <= 45319 || // Lo  [27] HANGUL SYLLABLE NYAEG..HANGUL SYLLABLE NYAEH
        45321 <= code && code <= 45347 || // Lo  [27] HANGUL SYLLABLE NEOG..HANGUL SYLLABLE NEOH
        45349 <= code && code <= 45375 || // Lo  [27] HANGUL SYLLABLE NEG..HANGUL SYLLABLE NEH
        45377 <= code && code <= 45403 || // Lo  [27] HANGUL SYLLABLE NYEOG..HANGUL SYLLABLE NYEOH
        45405 <= code && code <= 45431 || // Lo  [27] HANGUL SYLLABLE NYEG..HANGUL SYLLABLE NYEH
        45433 <= code && code <= 45459 || // Lo  [27] HANGUL SYLLABLE NOG..HANGUL SYLLABLE NOH
        45461 <= code && code <= 45487 || // Lo  [27] HANGUL SYLLABLE NWAG..HANGUL SYLLABLE NWAH
        45489 <= code && code <= 45515 || // Lo  [27] HANGUL SYLLABLE NWAEG..HANGUL SYLLABLE NWAEH
        45517 <= code && code <= 45543 || // Lo  [27] HANGUL SYLLABLE NOEG..HANGUL SYLLABLE NOEH
        45545 <= code && code <= 45571 || // Lo  [27] HANGUL SYLLABLE NYOG..HANGUL SYLLABLE NYOH
        45573 <= code && code <= 45599 || // Lo  [27] HANGUL SYLLABLE NUG..HANGUL SYLLABLE NUH
        45601 <= code && code <= 45627 || // Lo  [27] HANGUL SYLLABLE NWEOG..HANGUL SYLLABLE NWEOH
        45629 <= code && code <= 45655 || // Lo  [27] HANGUL SYLLABLE NWEG..HANGUL SYLLABLE NWEH
        45657 <= code && code <= 45683 || // Lo  [27] HANGUL SYLLABLE NWIG..HANGUL SYLLABLE NWIH
        45685 <= code && code <= 45711 || // Lo  [27] HANGUL SYLLABLE NYUG..HANGUL SYLLABLE NYUH
        45713 <= code && code <= 45739 || // Lo  [27] HANGUL SYLLABLE NEUG..HANGUL SYLLABLE NEUH
        45741 <= code && code <= 45767 || // Lo  [27] HANGUL SYLLABLE NYIG..HANGUL SYLLABLE NYIH
        45769 <= code && code <= 45795 || // Lo  [27] HANGUL SYLLABLE NIG..HANGUL SYLLABLE NIH
        45797 <= code && code <= 45823 || // Lo  [27] HANGUL SYLLABLE DAG..HANGUL SYLLABLE DAH
        45825 <= code && code <= 45851 || // Lo  [27] HANGUL SYLLABLE DAEG..HANGUL SYLLABLE DAEH
        45853 <= code && code <= 45879 || // Lo  [27] HANGUL SYLLABLE DYAG..HANGUL SYLLABLE DYAH
        45881 <= code && code <= 45907 || // Lo  [27] HANGUL SYLLABLE DYAEG..HANGUL SYLLABLE DYAEH
        45909 <= code && code <= 45935 || // Lo  [27] HANGUL SYLLABLE DEOG..HANGUL SYLLABLE DEOH
        45937 <= code && code <= 45963 || // Lo  [27] HANGUL SYLLABLE DEG..HANGUL SYLLABLE DEH
        45965 <= code && code <= 45991 || // Lo  [27] HANGUL SYLLABLE DYEOG..HANGUL SYLLABLE DYEOH
        45993 <= code && code <= 46019 || // Lo  [27] HANGUL SYLLABLE DYEG..HANGUL SYLLABLE DYEH
        46021 <= code && code <= 46047 || // Lo  [27] HANGUL SYLLABLE DOG..HANGUL SYLLABLE DOH
        46049 <= code && code <= 46075 || // Lo  [27] HANGUL SYLLABLE DWAG..HANGUL SYLLABLE DWAH
        46077 <= code && code <= 46103 || // Lo  [27] HANGUL SYLLABLE DWAEG..HANGUL SYLLABLE DWAEH
        46105 <= code && code <= 46131 || // Lo  [27] HANGUL SYLLABLE DOEG..HANGUL SYLLABLE DOEH
        46133 <= code && code <= 46159 || // Lo  [27] HANGUL SYLLABLE DYOG..HANGUL SYLLABLE DYOH
        46161 <= code && code <= 46187 || // Lo  [27] HANGUL SYLLABLE DUG..HANGUL SYLLABLE DUH
        46189 <= code && code <= 46215 || // Lo  [27] HANGUL SYLLABLE DWEOG..HANGUL SYLLABLE DWEOH
        46217 <= code && code <= 46243 || // Lo  [27] HANGUL SYLLABLE DWEG..HANGUL SYLLABLE DWEH
        46245 <= code && code <= 46271 || // Lo  [27] HANGUL SYLLABLE DWIG..HANGUL SYLLABLE DWIH
        46273 <= code && code <= 46299 || // Lo  [27] HANGUL SYLLABLE DYUG..HANGUL SYLLABLE DYUH
        46301 <= code && code <= 46327 || // Lo  [27] HANGUL SYLLABLE DEUG..HANGUL SYLLABLE DEUH
        46329 <= code && code <= 46355 || // Lo  [27] HANGUL SYLLABLE DYIG..HANGUL SYLLABLE DYIH
        46357 <= code && code <= 46383 || // Lo  [27] HANGUL SYLLABLE DIG..HANGUL SYLLABLE DIH
        46385 <= code && code <= 46411 || // Lo  [27] HANGUL SYLLABLE DDAG..HANGUL SYLLABLE DDAH
        46413 <= code && code <= 46439 || // Lo  [27] HANGUL SYLLABLE DDAEG..HANGUL SYLLABLE DDAEH
        46441 <= code && code <= 46467 || // Lo  [27] HANGUL SYLLABLE DDYAG..HANGUL SYLLABLE DDYAH
        46469 <= code && code <= 46495 || // Lo  [27] HANGUL SYLLABLE DDYAEG..HANGUL SYLLABLE DDYAEH
        46497 <= code && code <= 46523 || // Lo  [27] HANGUL SYLLABLE DDEOG..HANGUL SYLLABLE DDEOH
        46525 <= code && code <= 46551 || // Lo  [27] HANGUL SYLLABLE DDEG..HANGUL SYLLABLE DDEH
        46553 <= code && code <= 46579 || // Lo  [27] HANGUL SYLLABLE DDYEOG..HANGUL SYLLABLE DDYEOH
        46581 <= code && code <= 46607 || // Lo  [27] HANGUL SYLLABLE DDYEG..HANGUL SYLLABLE DDYEH
        46609 <= code && code <= 46635 || // Lo  [27] HANGUL SYLLABLE DDOG..HANGUL SYLLABLE DDOH
        46637 <= code && code <= 46663 || // Lo  [27] HANGUL SYLLABLE DDWAG..HANGUL SYLLABLE DDWAH
        46665 <= code && code <= 46691 || // Lo  [27] HANGUL SYLLABLE DDWAEG..HANGUL SYLLABLE DDWAEH
        46693 <= code && code <= 46719 || // Lo  [27] HANGUL SYLLABLE DDOEG..HANGUL SYLLABLE DDOEH
        46721 <= code && code <= 46747 || // Lo  [27] HANGUL SYLLABLE DDYOG..HANGUL SYLLABLE DDYOH
        46749 <= code && code <= 46775 || // Lo  [27] HANGUL SYLLABLE DDUG..HANGUL SYLLABLE DDUH
        46777 <= code && code <= 46803 || // Lo  [27] HANGUL SYLLABLE DDWEOG..HANGUL SYLLABLE DDWEOH
        46805 <= code && code <= 46831 || // Lo  [27] HANGUL SYLLABLE DDWEG..HANGUL SYLLABLE DDWEH
        46833 <= code && code <= 46859 || // Lo  [27] HANGUL SYLLABLE DDWIG..HANGUL SYLLABLE DDWIH
        46861 <= code && code <= 46887 || // Lo  [27] HANGUL SYLLABLE DDYUG..HANGUL SYLLABLE DDYUH
        46889 <= code && code <= 46915 || // Lo  [27] HANGUL SYLLABLE DDEUG..HANGUL SYLLABLE DDEUH
        46917 <= code && code <= 46943 || // Lo  [27] HANGUL SYLLABLE DDYIG..HANGUL SYLLABLE DDYIH
        46945 <= code && code <= 46971 || // Lo  [27] HANGUL SYLLABLE DDIG..HANGUL SYLLABLE DDIH
        46973 <= code && code <= 46999 || // Lo  [27] HANGUL SYLLABLE RAG..HANGUL SYLLABLE RAH
        47001 <= code && code <= 47027 || // Lo  [27] HANGUL SYLLABLE RAEG..HANGUL SYLLABLE RAEH
        47029 <= code && code <= 47055 || // Lo  [27] HANGUL SYLLABLE RYAG..HANGUL SYLLABLE RYAH
        47057 <= code && code <= 47083 || // Lo  [27] HANGUL SYLLABLE RYAEG..HANGUL SYLLABLE RYAEH
        47085 <= code && code <= 47111 || // Lo  [27] HANGUL SYLLABLE REOG..HANGUL SYLLABLE REOH
        47113 <= code && code <= 47139 || // Lo  [27] HANGUL SYLLABLE REG..HANGUL SYLLABLE REH
        47141 <= code && code <= 47167 || // Lo  [27] HANGUL SYLLABLE RYEOG..HANGUL SYLLABLE RYEOH
        47169 <= code && code <= 47195 || // Lo  [27] HANGUL SYLLABLE RYEG..HANGUL SYLLABLE RYEH
        47197 <= code && code <= 47223 || // Lo  [27] HANGUL SYLLABLE ROG..HANGUL SYLLABLE ROH
        47225 <= code && code <= 47251 || // Lo  [27] HANGUL SYLLABLE RWAG..HANGUL SYLLABLE RWAH
        47253 <= code && code <= 47279 || // Lo  [27] HANGUL SYLLABLE RWAEG..HANGUL SYLLABLE RWAEH
        47281 <= code && code <= 47307 || // Lo  [27] HANGUL SYLLABLE ROEG..HANGUL SYLLABLE ROEH
        47309 <= code && code <= 47335 || // Lo  [27] HANGUL SYLLABLE RYOG..HANGUL SYLLABLE RYOH
        47337 <= code && code <= 47363 || // Lo  [27] HANGUL SYLLABLE RUG..HANGUL SYLLABLE RUH
        47365 <= code && code <= 47391 || // Lo  [27] HANGUL SYLLABLE RWEOG..HANGUL SYLLABLE RWEOH
        47393 <= code && code <= 47419 || // Lo  [27] HANGUL SYLLABLE RWEG..HANGUL SYLLABLE RWEH
        47421 <= code && code <= 47447 || // Lo  [27] HANGUL SYLLABLE RWIG..HANGUL SYLLABLE RWIH
        47449 <= code && code <= 47475 || // Lo  [27] HANGUL SYLLABLE RYUG..HANGUL SYLLABLE RYUH
        47477 <= code && code <= 47503 || // Lo  [27] HANGUL SYLLABLE REUG..HANGUL SYLLABLE REUH
        47505 <= code && code <= 47531 || // Lo  [27] HANGUL SYLLABLE RYIG..HANGUL SYLLABLE RYIH
        47533 <= code && code <= 47559 || // Lo  [27] HANGUL SYLLABLE RIG..HANGUL SYLLABLE RIH
        47561 <= code && code <= 47587 || // Lo  [27] HANGUL SYLLABLE MAG..HANGUL SYLLABLE MAH
        47589 <= code && code <= 47615 || // Lo  [27] HANGUL SYLLABLE MAEG..HANGUL SYLLABLE MAEH
        47617 <= code && code <= 47643 || // Lo  [27] HANGUL SYLLABLE MYAG..HANGUL SYLLABLE MYAH
        47645 <= code && code <= 47671 || // Lo  [27] HANGUL SYLLABLE MYAEG..HANGUL SYLLABLE MYAEH
        47673 <= code && code <= 47699 || // Lo  [27] HANGUL SYLLABLE MEOG..HANGUL SYLLABLE MEOH
        47701 <= code && code <= 47727 || // Lo  [27] HANGUL SYLLABLE MEG..HANGUL SYLLABLE MEH
        47729 <= code && code <= 47755 || // Lo  [27] HANGUL SYLLABLE MYEOG..HANGUL SYLLABLE MYEOH
        47757 <= code && code <= 47783 || // Lo  [27] HANGUL SYLLABLE MYEG..HANGUL SYLLABLE MYEH
        47785 <= code && code <= 47811 || // Lo  [27] HANGUL SYLLABLE MOG..HANGUL SYLLABLE MOH
        47813 <= code && code <= 47839 || // Lo  [27] HANGUL SYLLABLE MWAG..HANGUL SYLLABLE MWAH
        47841 <= code && code <= 47867 || // Lo  [27] HANGUL SYLLABLE MWAEG..HANGUL SYLLABLE MWAEH
        47869 <= code && code <= 47895 || // Lo  [27] HANGUL SYLLABLE MOEG..HANGUL SYLLABLE MOEH
        47897 <= code && code <= 47923 || // Lo  [27] HANGUL SYLLABLE MYOG..HANGUL SYLLABLE MYOH
        47925 <= code && code <= 47951 || // Lo  [27] HANGUL SYLLABLE MUG..HANGUL SYLLABLE MUH
        47953 <= code && code <= 47979 || // Lo  [27] HANGUL SYLLABLE MWEOG..HANGUL SYLLABLE MWEOH
        47981 <= code && code <= 48007 || // Lo  [27] HANGUL SYLLABLE MWEG..HANGUL SYLLABLE MWEH
        48009 <= code && code <= 48035 || // Lo  [27] HANGUL SYLLABLE MWIG..HANGUL SYLLABLE MWIH
        48037 <= code && code <= 48063 || // Lo  [27] HANGUL SYLLABLE MYUG..HANGUL SYLLABLE MYUH
        48065 <= code && code <= 48091 || // Lo  [27] HANGUL SYLLABLE MEUG..HANGUL SYLLABLE MEUH
        48093 <= code && code <= 48119 || // Lo  [27] HANGUL SYLLABLE MYIG..HANGUL SYLLABLE MYIH
        48121 <= code && code <= 48147 || // Lo  [27] HANGUL SYLLABLE MIG..HANGUL SYLLABLE MIH
        48149 <= code && code <= 48175 || // Lo  [27] HANGUL SYLLABLE BAG..HANGUL SYLLABLE BAH
        48177 <= code && code <= 48203 || // Lo  [27] HANGUL SYLLABLE BAEG..HANGUL SYLLABLE BAEH
        48205 <= code && code <= 48231 || // Lo  [27] HANGUL SYLLABLE BYAG..HANGUL SYLLABLE BYAH
        48233 <= code && code <= 48259 || // Lo  [27] HANGUL SYLLABLE BYAEG..HANGUL SYLLABLE BYAEH
        48261 <= code && code <= 48287 || // Lo  [27] HANGUL SYLLABLE BEOG..HANGUL SYLLABLE BEOH
        48289 <= code && code <= 48315 || // Lo  [27] HANGUL SYLLABLE BEG..HANGUL SYLLABLE BEH
        48317 <= code && code <= 48343 || // Lo  [27] HANGUL SYLLABLE BYEOG..HANGUL SYLLABLE BYEOH
        48345 <= code && code <= 48371 || // Lo  [27] HANGUL SYLLABLE BYEG..HANGUL SYLLABLE BYEH
        48373 <= code && code <= 48399 || // Lo  [27] HANGUL SYLLABLE BOG..HANGUL SYLLABLE BOH
        48401 <= code && code <= 48427 || // Lo  [27] HANGUL SYLLABLE BWAG..HANGUL SYLLABLE BWAH
        48429 <= code && code <= 48455 || // Lo  [27] HANGUL SYLLABLE BWAEG..HANGUL SYLLABLE BWAEH
        48457 <= code && code <= 48483 || // Lo  [27] HANGUL SYLLABLE BOEG..HANGUL SYLLABLE BOEH
        48485 <= code && code <= 48511 || // Lo  [27] HANGUL SYLLABLE BYOG..HANGUL SYLLABLE BYOH
        48513 <= code && code <= 48539 || // Lo  [27] HANGUL SYLLABLE BUG..HANGUL SYLLABLE BUH
        48541 <= code && code <= 48567 || // Lo  [27] HANGUL SYLLABLE BWEOG..HANGUL SYLLABLE BWEOH
        48569 <= code && code <= 48595 || // Lo  [27] HANGUL SYLLABLE BWEG..HANGUL SYLLABLE BWEH
        48597 <= code && code <= 48623 || // Lo  [27] HANGUL SYLLABLE BWIG..HANGUL SYLLABLE BWIH
        48625 <= code && code <= 48651 || // Lo  [27] HANGUL SYLLABLE BYUG..HANGUL SYLLABLE BYUH
        48653 <= code && code <= 48679 || // Lo  [27] HANGUL SYLLABLE BEUG..HANGUL SYLLABLE BEUH
        48681 <= code && code <= 48707 || // Lo  [27] HANGUL SYLLABLE BYIG..HANGUL SYLLABLE BYIH
        48709 <= code && code <= 48735 || // Lo  [27] HANGUL SYLLABLE BIG..HANGUL SYLLABLE BIH
        48737 <= code && code <= 48763 || // Lo  [27] HANGUL SYLLABLE BBAG..HANGUL SYLLABLE BBAH
        48765 <= code && code <= 48791 || // Lo  [27] HANGUL SYLLABLE BBAEG..HANGUL SYLLABLE BBAEH
        48793 <= code && code <= 48819 || // Lo  [27] HANGUL SYLLABLE BBYAG..HANGUL SYLLABLE BBYAH
        48821 <= code && code <= 48847 || // Lo  [27] HANGUL SYLLABLE BBYAEG..HANGUL SYLLABLE BBYAEH
        48849 <= code && code <= 48875 || // Lo  [27] HANGUL SYLLABLE BBEOG..HANGUL SYLLABLE BBEOH
        48877 <= code && code <= 48903 || // Lo  [27] HANGUL SYLLABLE BBEG..HANGUL SYLLABLE BBEH
        48905 <= code && code <= 48931 || // Lo  [27] HANGUL SYLLABLE BBYEOG..HANGUL SYLLABLE BBYEOH
        48933 <= code && code <= 48959 || // Lo  [27] HANGUL SYLLABLE BBYEG..HANGUL SYLLABLE BBYEH
        48961 <= code && code <= 48987 || // Lo  [27] HANGUL SYLLABLE BBOG..HANGUL SYLLABLE BBOH
        48989 <= code && code <= 49015 || // Lo  [27] HANGUL SYLLABLE BBWAG..HANGUL SYLLABLE BBWAH
        49017 <= code && code <= 49043 || // Lo  [27] HANGUL SYLLABLE BBWAEG..HANGUL SYLLABLE BBWAEH
        49045 <= code && code <= 49071 || // Lo  [27] HANGUL SYLLABLE BBOEG..HANGUL SYLLABLE BBOEH
        49073 <= code && code <= 49099 || // Lo  [27] HANGUL SYLLABLE BBYOG..HANGUL SYLLABLE BBYOH
        49101 <= code && code <= 49127 || // Lo  [27] HANGUL SYLLABLE BBUG..HANGUL SYLLABLE BBUH
        49129 <= code && code <= 49155 || // Lo  [27] HANGUL SYLLABLE BBWEOG..HANGUL SYLLABLE BBWEOH
        49157 <= code && code <= 49183 || // Lo  [27] HANGUL SYLLABLE BBWEG..HANGUL SYLLABLE BBWEH
        49185 <= code && code <= 49211 || // Lo  [27] HANGUL SYLLABLE BBWIG..HANGUL SYLLABLE BBWIH
        49213 <= code && code <= 49239 || // Lo  [27] HANGUL SYLLABLE BBYUG..HANGUL SYLLABLE BBYUH
        49241 <= code && code <= 49267 || // Lo  [27] HANGUL SYLLABLE BBEUG..HANGUL SYLLABLE BBEUH
        49269 <= code && code <= 49295 || // Lo  [27] HANGUL SYLLABLE BBYIG..HANGUL SYLLABLE BBYIH
        49297 <= code && code <= 49323 || // Lo  [27] HANGUL SYLLABLE BBIG..HANGUL SYLLABLE BBIH
        49325 <= code && code <= 49351 || // Lo  [27] HANGUL SYLLABLE SAG..HANGUL SYLLABLE SAH
        49353 <= code && code <= 49379 || // Lo  [27] HANGUL SYLLABLE SAEG..HANGUL SYLLABLE SAEH
        49381 <= code && code <= 49407 || // Lo  [27] HANGUL SYLLABLE SYAG..HANGUL SYLLABLE SYAH
        49409 <= code && code <= 49435 || // Lo  [27] HANGUL SYLLABLE SYAEG..HANGUL SYLLABLE SYAEH
        49437 <= code && code <= 49463 || // Lo  [27] HANGUL SYLLABLE SEOG..HANGUL SYLLABLE SEOH
        49465 <= code && code <= 49491 || // Lo  [27] HANGUL SYLLABLE SEG..HANGUL SYLLABLE SEH
        49493 <= code && code <= 49519 || // Lo  [27] HANGUL SYLLABLE SYEOG..HANGUL SYLLABLE SYEOH
        49521 <= code && code <= 49547 || // Lo  [27] HANGUL SYLLABLE SYEG..HANGUL SYLLABLE SYEH
        49549 <= code && code <= 49575 || // Lo  [27] HANGUL SYLLABLE SOG..HANGUL SYLLABLE SOH
        49577 <= code && code <= 49603 || // Lo  [27] HANGUL SYLLABLE SWAG..HANGUL SYLLABLE SWAH
        49605 <= code && code <= 49631 || // Lo  [27] HANGUL SYLLABLE SWAEG..HANGUL SYLLABLE SWAEH
        49633 <= code && code <= 49659 || // Lo  [27] HANGUL SYLLABLE SOEG..HANGUL SYLLABLE SOEH
        49661 <= code && code <= 49687 || // Lo  [27] HANGUL SYLLABLE SYOG..HANGUL SYLLABLE SYOH
        49689 <= code && code <= 49715 || // Lo  [27] HANGUL SYLLABLE SUG..HANGUL SYLLABLE SUH
        49717 <= code && code <= 49743 || // Lo  [27] HANGUL SYLLABLE SWEOG..HANGUL SYLLABLE SWEOH
        49745 <= code && code <= 49771 || // Lo  [27] HANGUL SYLLABLE SWEG..HANGUL SYLLABLE SWEH
        49773 <= code && code <= 49799 || // Lo  [27] HANGUL SYLLABLE SWIG..HANGUL SYLLABLE SWIH
        49801 <= code && code <= 49827 || // Lo  [27] HANGUL SYLLABLE SYUG..HANGUL SYLLABLE SYUH
        49829 <= code && code <= 49855 || // Lo  [27] HANGUL SYLLABLE SEUG..HANGUL SYLLABLE SEUH
        49857 <= code && code <= 49883 || // Lo  [27] HANGUL SYLLABLE SYIG..HANGUL SYLLABLE SYIH
        49885 <= code && code <= 49911 || // Lo  [27] HANGUL SYLLABLE SIG..HANGUL SYLLABLE SIH
        49913 <= code && code <= 49939 || // Lo  [27] HANGUL SYLLABLE SSAG..HANGUL SYLLABLE SSAH
        49941 <= code && code <= 49967 || // Lo  [27] HANGUL SYLLABLE SSAEG..HANGUL SYLLABLE SSAEH
        49969 <= code && code <= 49995 || // Lo  [27] HANGUL SYLLABLE SSYAG..HANGUL SYLLABLE SSYAH
        49997 <= code && code <= 50023 || // Lo  [27] HANGUL SYLLABLE SSYAEG..HANGUL SYLLABLE SSYAEH
        50025 <= code && code <= 50051 || // Lo  [27] HANGUL SYLLABLE SSEOG..HANGUL SYLLABLE SSEOH
        50053 <= code && code <= 50079 || // Lo  [27] HANGUL SYLLABLE SSEG..HANGUL SYLLABLE SSEH
        50081 <= code && code <= 50107 || // Lo  [27] HANGUL SYLLABLE SSYEOG..HANGUL SYLLABLE SSYEOH
        50109 <= code && code <= 50135 || // Lo  [27] HANGUL SYLLABLE SSYEG..HANGUL SYLLABLE SSYEH
        50137 <= code && code <= 50163 || // Lo  [27] HANGUL SYLLABLE SSOG..HANGUL SYLLABLE SSOH
        50165 <= code && code <= 50191 || // Lo  [27] HANGUL SYLLABLE SSWAG..HANGUL SYLLABLE SSWAH
        50193 <= code && code <= 50219 || // Lo  [27] HANGUL SYLLABLE SSWAEG..HANGUL SYLLABLE SSWAEH
        50221 <= code && code <= 50247 || // Lo  [27] HANGUL SYLLABLE SSOEG..HANGUL SYLLABLE SSOEH
        50249 <= code && code <= 50275 || // Lo  [27] HANGUL SYLLABLE SSYOG..HANGUL SYLLABLE SSYOH
        50277 <= code && code <= 50303 || // Lo  [27] HANGUL SYLLABLE SSUG..HANGUL SYLLABLE SSUH
        50305 <= code && code <= 50331 || // Lo  [27] HANGUL SYLLABLE SSWEOG..HANGUL SYLLABLE SSWEOH
        50333 <= code && code <= 50359 || // Lo  [27] HANGUL SYLLABLE SSWEG..HANGUL SYLLABLE SSWEH
        50361 <= code && code <= 50387 || // Lo  [27] HANGUL SYLLABLE SSWIG..HANGUL SYLLABLE SSWIH
        50389 <= code && code <= 50415 || // Lo  [27] HANGUL SYLLABLE SSYUG..HANGUL SYLLABLE SSYUH
        50417 <= code && code <= 50443 || // Lo  [27] HANGUL SYLLABLE SSEUG..HANGUL SYLLABLE SSEUH
        50445 <= code && code <= 50471 || // Lo  [27] HANGUL SYLLABLE SSYIG..HANGUL SYLLABLE SSYIH
        50473 <= code && code <= 50499 || // Lo  [27] HANGUL SYLLABLE SSIG..HANGUL SYLLABLE SSIH
        50501 <= code && code <= 50527 || // Lo  [27] HANGUL SYLLABLE AG..HANGUL SYLLABLE AH
        50529 <= code && code <= 50555 || // Lo  [27] HANGUL SYLLABLE AEG..HANGUL SYLLABLE AEH
        50557 <= code && code <= 50583 || // Lo  [27] HANGUL SYLLABLE YAG..HANGUL SYLLABLE YAH
        50585 <= code && code <= 50611 || // Lo  [27] HANGUL SYLLABLE YAEG..HANGUL SYLLABLE YAEH
        50613 <= code && code <= 50639 || // Lo  [27] HANGUL SYLLABLE EOG..HANGUL SYLLABLE EOH
        50641 <= code && code <= 50667 || // Lo  [27] HANGUL SYLLABLE EG..HANGUL SYLLABLE EH
        50669 <= code && code <= 50695 || // Lo  [27] HANGUL SYLLABLE YEOG..HANGUL SYLLABLE YEOH
        50697 <= code && code <= 50723 || // Lo  [27] HANGUL SYLLABLE YEG..HANGUL SYLLABLE YEH
        50725 <= code && code <= 50751 || // Lo  [27] HANGUL SYLLABLE OG..HANGUL SYLLABLE OH
        50753 <= code && code <= 50779 || // Lo  [27] HANGUL SYLLABLE WAG..HANGUL SYLLABLE WAH
        50781 <= code && code <= 50807 || // Lo  [27] HANGUL SYLLABLE WAEG..HANGUL SYLLABLE WAEH
        50809 <= code && code <= 50835 || // Lo  [27] HANGUL SYLLABLE OEG..HANGUL SYLLABLE OEH
        50837 <= code && code <= 50863 || // Lo  [27] HANGUL SYLLABLE YOG..HANGUL SYLLABLE YOH
        50865 <= code && code <= 50891 || // Lo  [27] HANGUL SYLLABLE UG..HANGUL SYLLABLE UH
        50893 <= code && code <= 50919 || // Lo  [27] HANGUL SYLLABLE WEOG..HANGUL SYLLABLE WEOH
        50921 <= code && code <= 50947 || // Lo  [27] HANGUL SYLLABLE WEG..HANGUL SYLLABLE WEH
        50949 <= code && code <= 50975 || // Lo  [27] HANGUL SYLLABLE WIG..HANGUL SYLLABLE WIH
        50977 <= code && code <= 51003 || // Lo  [27] HANGUL SYLLABLE YUG..HANGUL SYLLABLE YUH
        51005 <= code && code <= 51031 || // Lo  [27] HANGUL SYLLABLE EUG..HANGUL SYLLABLE EUH
        51033 <= code && code <= 51059 || // Lo  [27] HANGUL SYLLABLE YIG..HANGUL SYLLABLE YIH
        51061 <= code && code <= 51087 || // Lo  [27] HANGUL SYLLABLE IG..HANGUL SYLLABLE IH
        51089 <= code && code <= 51115 || // Lo  [27] HANGUL SYLLABLE JAG..HANGUL SYLLABLE JAH
        51117 <= code && code <= 51143 || // Lo  [27] HANGUL SYLLABLE JAEG..HANGUL SYLLABLE JAEH
        51145 <= code && code <= 51171 || // Lo  [27] HANGUL SYLLABLE JYAG..HANGUL SYLLABLE JYAH
        51173 <= code && code <= 51199 || // Lo  [27] HANGUL SYLLABLE JYAEG..HANGUL SYLLABLE JYAEH
        51201 <= code && code <= 51227 || // Lo  [27] HANGUL SYLLABLE JEOG..HANGUL SYLLABLE JEOH
        51229 <= code && code <= 51255 || // Lo  [27] HANGUL SYLLABLE JEG..HANGUL SYLLABLE JEH
        51257 <= code && code <= 51283 || // Lo  [27] HANGUL SYLLABLE JYEOG..HANGUL SYLLABLE JYEOH
        51285 <= code && code <= 51311 || // Lo  [27] HANGUL SYLLABLE JYEG..HANGUL SYLLABLE JYEH
        51313 <= code && code <= 51339 || // Lo  [27] HANGUL SYLLABLE JOG..HANGUL SYLLABLE JOH
        51341 <= code && code <= 51367 || // Lo  [27] HANGUL SYLLABLE JWAG..HANGUL SYLLABLE JWAH
        51369 <= code && code <= 51395 || // Lo  [27] HANGUL SYLLABLE JWAEG..HANGUL SYLLABLE JWAEH
        51397 <= code && code <= 51423 || // Lo  [27] HANGUL SYLLABLE JOEG..HANGUL SYLLABLE JOEH
        51425 <= code && code <= 51451 || // Lo  [27] HANGUL SYLLABLE JYOG..HANGUL SYLLABLE JYOH
        51453 <= code && code <= 51479 || // Lo  [27] HANGUL SYLLABLE JUG..HANGUL SYLLABLE JUH
        51481 <= code && code <= 51507 || // Lo  [27] HANGUL SYLLABLE JWEOG..HANGUL SYLLABLE JWEOH
        51509 <= code && code <= 51535 || // Lo  [27] HANGUL SYLLABLE JWEG..HANGUL SYLLABLE JWEH
        51537 <= code && code <= 51563 || // Lo  [27] HANGUL SYLLABLE JWIG..HANGUL SYLLABLE JWIH
        51565 <= code && code <= 51591 || // Lo  [27] HANGUL SYLLABLE JYUG..HANGUL SYLLABLE JYUH
        51593 <= code && code <= 51619 || // Lo  [27] HANGUL SYLLABLE JEUG..HANGUL SYLLABLE JEUH
        51621 <= code && code <= 51647 || // Lo  [27] HANGUL SYLLABLE JYIG..HANGUL SYLLABLE JYIH
        51649 <= code && code <= 51675 || // Lo  [27] HANGUL SYLLABLE JIG..HANGUL SYLLABLE JIH
        51677 <= code && code <= 51703 || // Lo  [27] HANGUL SYLLABLE JJAG..HANGUL SYLLABLE JJAH
        51705 <= code && code <= 51731 || // Lo  [27] HANGUL SYLLABLE JJAEG..HANGUL SYLLABLE JJAEH
        51733 <= code && code <= 51759 || // Lo  [27] HANGUL SYLLABLE JJYAG..HANGUL SYLLABLE JJYAH
        51761 <= code && code <= 51787 || // Lo  [27] HANGUL SYLLABLE JJYAEG..HANGUL SYLLABLE JJYAEH
        51789 <= code && code <= 51815 || // Lo  [27] HANGUL SYLLABLE JJEOG..HANGUL SYLLABLE JJEOH
        51817 <= code && code <= 51843 || // Lo  [27] HANGUL SYLLABLE JJEG..HANGUL SYLLABLE JJEH
        51845 <= code && code <= 51871 || // Lo  [27] HANGUL SYLLABLE JJYEOG..HANGUL SYLLABLE JJYEOH
        51873 <= code && code <= 51899 || // Lo  [27] HANGUL SYLLABLE JJYEG..HANGUL SYLLABLE JJYEH
        51901 <= code && code <= 51927 || // Lo  [27] HANGUL SYLLABLE JJOG..HANGUL SYLLABLE JJOH
        51929 <= code && code <= 51955 || // Lo  [27] HANGUL SYLLABLE JJWAG..HANGUL SYLLABLE JJWAH
        51957 <= code && code <= 51983 || // Lo  [27] HANGUL SYLLABLE JJWAEG..HANGUL SYLLABLE JJWAEH
        51985 <= code && code <= 52011 || // Lo  [27] HANGUL SYLLABLE JJOEG..HANGUL SYLLABLE JJOEH
        52013 <= code && code <= 52039 || // Lo  [27] HANGUL SYLLABLE JJYOG..HANGUL SYLLABLE JJYOH
        52041 <= code && code <= 52067 || // Lo  [27] HANGUL SYLLABLE JJUG..HANGUL SYLLABLE JJUH
        52069 <= code && code <= 52095 || // Lo  [27] HANGUL SYLLABLE JJWEOG..HANGUL SYLLABLE JJWEOH
        52097 <= code && code <= 52123 || // Lo  [27] HANGUL SYLLABLE JJWEG..HANGUL SYLLABLE JJWEH
        52125 <= code && code <= 52151 || // Lo  [27] HANGUL SYLLABLE JJWIG..HANGUL SYLLABLE JJWIH
        52153 <= code && code <= 52179 || // Lo  [27] HANGUL SYLLABLE JJYUG..HANGUL SYLLABLE JJYUH
        52181 <= code && code <= 52207 || // Lo  [27] HANGUL SYLLABLE JJEUG..HANGUL SYLLABLE JJEUH
        52209 <= code && code <= 52235 || // Lo  [27] HANGUL SYLLABLE JJYIG..HANGUL SYLLABLE JJYIH
        52237 <= code && code <= 52263 || // Lo  [27] HANGUL SYLLABLE JJIG..HANGUL SYLLABLE JJIH
        52265 <= code && code <= 52291 || // Lo  [27] HANGUL SYLLABLE CAG..HANGUL SYLLABLE CAH
        52293 <= code && code <= 52319 || // Lo  [27] HANGUL SYLLABLE CAEG..HANGUL SYLLABLE CAEH
        52321 <= code && code <= 52347 || // Lo  [27] HANGUL SYLLABLE CYAG..HANGUL SYLLABLE CYAH
        52349 <= code && code <= 52375 || // Lo  [27] HANGUL SYLLABLE CYAEG..HANGUL SYLLABLE CYAEH
        52377 <= code && code <= 52403 || // Lo  [27] HANGUL SYLLABLE CEOG..HANGUL SYLLABLE CEOH
        52405 <= code && code <= 52431 || // Lo  [27] HANGUL SYLLABLE CEG..HANGUL SYLLABLE CEH
        52433 <= code && code <= 52459 || // Lo  [27] HANGUL SYLLABLE CYEOG..HANGUL SYLLABLE CYEOH
        52461 <= code && code <= 52487 || // Lo  [27] HANGUL SYLLABLE CYEG..HANGUL SYLLABLE CYEH
        52489 <= code && code <= 52515 || // Lo  [27] HANGUL SYLLABLE COG..HANGUL SYLLABLE COH
        52517 <= code && code <= 52543 || // Lo  [27] HANGUL SYLLABLE CWAG..HANGUL SYLLABLE CWAH
        52545 <= code && code <= 52571 || // Lo  [27] HANGUL SYLLABLE CWAEG..HANGUL SYLLABLE CWAEH
        52573 <= code && code <= 52599 || // Lo  [27] HANGUL SYLLABLE COEG..HANGUL SYLLABLE COEH
        52601 <= code && code <= 52627 || // Lo  [27] HANGUL SYLLABLE CYOG..HANGUL SYLLABLE CYOH
        52629 <= code && code <= 52655 || // Lo  [27] HANGUL SYLLABLE CUG..HANGUL SYLLABLE CUH
        52657 <= code && code <= 52683 || // Lo  [27] HANGUL SYLLABLE CWEOG..HANGUL SYLLABLE CWEOH
        52685 <= code && code <= 52711 || // Lo  [27] HANGUL SYLLABLE CWEG..HANGUL SYLLABLE CWEH
        52713 <= code && code <= 52739 || // Lo  [27] HANGUL SYLLABLE CWIG..HANGUL SYLLABLE CWIH
        52741 <= code && code <= 52767 || // Lo  [27] HANGUL SYLLABLE CYUG..HANGUL SYLLABLE CYUH
        52769 <= code && code <= 52795 || // Lo  [27] HANGUL SYLLABLE CEUG..HANGUL SYLLABLE CEUH
        52797 <= code && code <= 52823 || // Lo  [27] HANGUL SYLLABLE CYIG..HANGUL SYLLABLE CYIH
        52825 <= code && code <= 52851 || // Lo  [27] HANGUL SYLLABLE CIG..HANGUL SYLLABLE CIH
        52853 <= code && code <= 52879 || // Lo  [27] HANGUL SYLLABLE KAG..HANGUL SYLLABLE KAH
        52881 <= code && code <= 52907 || // Lo  [27] HANGUL SYLLABLE KAEG..HANGUL SYLLABLE KAEH
        52909 <= code && code <= 52935 || // Lo  [27] HANGUL SYLLABLE KYAG..HANGUL SYLLABLE KYAH
        52937 <= code && code <= 52963 || // Lo  [27] HANGUL SYLLABLE KYAEG..HANGUL SYLLABLE KYAEH
        52965 <= code && code <= 52991 || // Lo  [27] HANGUL SYLLABLE KEOG..HANGUL SYLLABLE KEOH
        52993 <= code && code <= 53019 || // Lo  [27] HANGUL SYLLABLE KEG..HANGUL SYLLABLE KEH
        53021 <= code && code <= 53047 || // Lo  [27] HANGUL SYLLABLE KYEOG..HANGUL SYLLABLE KYEOH
        53049 <= code && code <= 53075 || // Lo  [27] HANGUL SYLLABLE KYEG..HANGUL SYLLABLE KYEH
        53077 <= code && code <= 53103 || // Lo  [27] HANGUL SYLLABLE KOG..HANGUL SYLLABLE KOH
        53105 <= code && code <= 53131 || // Lo  [27] HANGUL SYLLABLE KWAG..HANGUL SYLLABLE KWAH
        53133 <= code && code <= 53159 || // Lo  [27] HANGUL SYLLABLE KWAEG..HANGUL SYLLABLE KWAEH
        53161 <= code && code <= 53187 || // Lo  [27] HANGUL SYLLABLE KOEG..HANGUL SYLLABLE KOEH
        53189 <= code && code <= 53215 || // Lo  [27] HANGUL SYLLABLE KYOG..HANGUL SYLLABLE KYOH
        53217 <= code && code <= 53243 || // Lo  [27] HANGUL SYLLABLE KUG..HANGUL SYLLABLE KUH
        53245 <= code && code <= 53271 || // Lo  [27] HANGUL SYLLABLE KWEOG..HANGUL SYLLABLE KWEOH
        53273 <= code && code <= 53299 || // Lo  [27] HANGUL SYLLABLE KWEG..HANGUL SYLLABLE KWEH
        53301 <= code && code <= 53327 || // Lo  [27] HANGUL SYLLABLE KWIG..HANGUL SYLLABLE KWIH
        53329 <= code && code <= 53355 || // Lo  [27] HANGUL SYLLABLE KYUG..HANGUL SYLLABLE KYUH
        53357 <= code && code <= 53383 || // Lo  [27] HANGUL SYLLABLE KEUG..HANGUL SYLLABLE KEUH
        53385 <= code && code <= 53411 || // Lo  [27] HANGUL SYLLABLE KYIG..HANGUL SYLLABLE KYIH
        53413 <= code && code <= 53439 || // Lo  [27] HANGUL SYLLABLE KIG..HANGUL SYLLABLE KIH
        53441 <= code && code <= 53467 || // Lo  [27] HANGUL SYLLABLE TAG..HANGUL SYLLABLE TAH
        53469 <= code && code <= 53495 || // Lo  [27] HANGUL SYLLABLE TAEG..HANGUL SYLLABLE TAEH
        53497 <= code && code <= 53523 || // Lo  [27] HANGUL SYLLABLE TYAG..HANGUL SYLLABLE TYAH
        53525 <= code && code <= 53551 || // Lo  [27] HANGUL SYLLABLE TYAEG..HANGUL SYLLABLE TYAEH
        53553 <= code && code <= 53579 || // Lo  [27] HANGUL SYLLABLE TEOG..HANGUL SYLLABLE TEOH
        53581 <= code && code <= 53607 || // Lo  [27] HANGUL SYLLABLE TEG..HANGUL SYLLABLE TEH
        53609 <= code && code <= 53635 || // Lo  [27] HANGUL SYLLABLE TYEOG..HANGUL SYLLABLE TYEOH
        53637 <= code && code <= 53663 || // Lo  [27] HANGUL SYLLABLE TYEG..HANGUL SYLLABLE TYEH
        53665 <= code && code <= 53691 || // Lo  [27] HANGUL SYLLABLE TOG..HANGUL SYLLABLE TOH
        53693 <= code && code <= 53719 || // Lo  [27] HANGUL SYLLABLE TWAG..HANGUL SYLLABLE TWAH
        53721 <= code && code <= 53747 || // Lo  [27] HANGUL SYLLABLE TWAEG..HANGUL SYLLABLE TWAEH
        53749 <= code && code <= 53775 || // Lo  [27] HANGUL SYLLABLE TOEG..HANGUL SYLLABLE TOEH
        53777 <= code && code <= 53803 || // Lo  [27] HANGUL SYLLABLE TYOG..HANGUL SYLLABLE TYOH
        53805 <= code && code <= 53831 || // Lo  [27] HANGUL SYLLABLE TUG..HANGUL SYLLABLE TUH
        53833 <= code && code <= 53859 || // Lo  [27] HANGUL SYLLABLE TWEOG..HANGUL SYLLABLE TWEOH
        53861 <= code && code <= 53887 || // Lo  [27] HANGUL SYLLABLE TWEG..HANGUL SYLLABLE TWEH
        53889 <= code && code <= 53915 || // Lo  [27] HANGUL SYLLABLE TWIG..HANGUL SYLLABLE TWIH
        53917 <= code && code <= 53943 || // Lo  [27] HANGUL SYLLABLE TYUG..HANGUL SYLLABLE TYUH
        53945 <= code && code <= 53971 || // Lo  [27] HANGUL SYLLABLE TEUG..HANGUL SYLLABLE TEUH
        53973 <= code && code <= 53999 || // Lo  [27] HANGUL SYLLABLE TYIG..HANGUL SYLLABLE TYIH
        54001 <= code && code <= 54027 || // Lo  [27] HANGUL SYLLABLE TIG..HANGUL SYLLABLE TIH
        54029 <= code && code <= 54055 || // Lo  [27] HANGUL SYLLABLE PAG..HANGUL SYLLABLE PAH
        54057 <= code && code <= 54083 || // Lo  [27] HANGUL SYLLABLE PAEG..HANGUL SYLLABLE PAEH
        54085 <= code && code <= 54111 || // Lo  [27] HANGUL SYLLABLE PYAG..HANGUL SYLLABLE PYAH
        54113 <= code && code <= 54139 || // Lo  [27] HANGUL SYLLABLE PYAEG..HANGUL SYLLABLE PYAEH
        54141 <= code && code <= 54167 || // Lo  [27] HANGUL SYLLABLE PEOG..HANGUL SYLLABLE PEOH
        54169 <= code && code <= 54195 || // Lo  [27] HANGUL SYLLABLE PEG..HANGUL SYLLABLE PEH
        54197 <= code && code <= 54223 || // Lo  [27] HANGUL SYLLABLE PYEOG..HANGUL SYLLABLE PYEOH
        54225 <= code && code <= 54251 || // Lo  [27] HANGUL SYLLABLE PYEG..HANGUL SYLLABLE PYEH
        54253 <= code && code <= 54279 || // Lo  [27] HANGUL SYLLABLE POG..HANGUL SYLLABLE POH
        54281 <= code && code <= 54307 || // Lo  [27] HANGUL SYLLABLE PWAG..HANGUL SYLLABLE PWAH
        54309 <= code && code <= 54335 || // Lo  [27] HANGUL SYLLABLE PWAEG..HANGUL SYLLABLE PWAEH
        54337 <= code && code <= 54363 || // Lo  [27] HANGUL SYLLABLE POEG..HANGUL SYLLABLE POEH
        54365 <= code && code <= 54391 || // Lo  [27] HANGUL SYLLABLE PYOG..HANGUL SYLLABLE PYOH
        54393 <= code && code <= 54419 || // Lo  [27] HANGUL SYLLABLE PUG..HANGUL SYLLABLE PUH
        54421 <= code && code <= 54447 || // Lo  [27] HANGUL SYLLABLE PWEOG..HANGUL SYLLABLE PWEOH
        54449 <= code && code <= 54475 || // Lo  [27] HANGUL SYLLABLE PWEG..HANGUL SYLLABLE PWEH
        54477 <= code && code <= 54503 || // Lo  [27] HANGUL SYLLABLE PWIG..HANGUL SYLLABLE PWIH
        54505 <= code && code <= 54531 || // Lo  [27] HANGUL SYLLABLE PYUG..HANGUL SYLLABLE PYUH
        54533 <= code && code <= 54559 || // Lo  [27] HANGUL SYLLABLE PEUG..HANGUL SYLLABLE PEUH
        54561 <= code && code <= 54587 || // Lo  [27] HANGUL SYLLABLE PYIG..HANGUL SYLLABLE PYIH
        54589 <= code && code <= 54615 || // Lo  [27] HANGUL SYLLABLE PIG..HANGUL SYLLABLE PIH
        54617 <= code && code <= 54643 || // Lo  [27] HANGUL SYLLABLE HAG..HANGUL SYLLABLE HAH
        54645 <= code && code <= 54671 || // Lo  [27] HANGUL SYLLABLE HAEG..HANGUL SYLLABLE HAEH
        54673 <= code && code <= 54699 || // Lo  [27] HANGUL SYLLABLE HYAG..HANGUL SYLLABLE HYAH
        54701 <= code && code <= 54727 || // Lo  [27] HANGUL SYLLABLE HYAEG..HANGUL SYLLABLE HYAEH
        54729 <= code && code <= 54755 || // Lo  [27] HANGUL SYLLABLE HEOG..HANGUL SYLLABLE HEOH
        54757 <= code && code <= 54783 || // Lo  [27] HANGUL SYLLABLE HEG..HANGUL SYLLABLE HEH
        54785 <= code && code <= 54811 || // Lo  [27] HANGUL SYLLABLE HYEOG..HANGUL SYLLABLE HYEOH
        54813 <= code && code <= 54839 || // Lo  [27] HANGUL SYLLABLE HYEG..HANGUL SYLLABLE HYEH
        54841 <= code && code <= 54867 || // Lo  [27] HANGUL SYLLABLE HOG..HANGUL SYLLABLE HOH
        54869 <= code && code <= 54895 || // Lo  [27] HANGUL SYLLABLE HWAG..HANGUL SYLLABLE HWAH
        54897 <= code && code <= 54923 || // Lo  [27] HANGUL SYLLABLE HWAEG..HANGUL SYLLABLE HWAEH
        54925 <= code && code <= 54951 || // Lo  [27] HANGUL SYLLABLE HOEG..HANGUL SYLLABLE HOEH
        54953 <= code && code <= 54979 || // Lo  [27] HANGUL SYLLABLE HYOG..HANGUL SYLLABLE HYOH
        54981 <= code && code <= 55007 || // Lo  [27] HANGUL SYLLABLE HUG..HANGUL SYLLABLE HUH
        55009 <= code && code <= 55035 || // Lo  [27] HANGUL SYLLABLE HWEOG..HANGUL SYLLABLE HWEOH
        55037 <= code && code <= 55063 || // Lo  [27] HANGUL SYLLABLE HWEG..HANGUL SYLLABLE HWEH
        55065 <= code && code <= 55091 || // Lo  [27] HANGUL SYLLABLE HWIG..HANGUL SYLLABLE HWIH
        55093 <= code && code <= 55119 || // Lo  [27] HANGUL SYLLABLE HYUG..HANGUL SYLLABLE HYUH
        55121 <= code && code <= 55147 || // Lo  [27] HANGUL SYLLABLE HEUG..HANGUL SYLLABLE HEUH
        55149 <= code && code <= 55175 || // Lo  [27] HANGUL SYLLABLE HYIG..HANGUL SYLLABLE HYIH
        55177 <= code && code <= 55203) {
          return LVT;
        }
        if (9757 == code || // So       WHITE UP POINTING INDEX
        9977 == code || // So       PERSON WITH BALL
        9994 <= code && code <= 9997 || // So   [4] RAISED FIST..WRITING HAND
        127877 == code || // So       FATHER CHRISTMAS
        127938 <= code && code <= 127940 || // So   [3] SNOWBOARDER..SURFER
        127943 == code || // So       HORSE RACING
        127946 <= code && code <= 127948 || // So   [3] SWIMMER..GOLFER
        128066 <= code && code <= 128067 || // So   [2] EAR..NOSE
        128070 <= code && code <= 128080 || // So  [11] WHITE UP POINTING BACKHAND INDEX..OPEN HANDS SIGN
        128110 == code || // So       POLICE OFFICER
        128112 <= code && code <= 128120 || // So   [9] BRIDE WITH VEIL..PRINCESS
        128124 == code || // So       BABY ANGEL
        128129 <= code && code <= 128131 || // So   [3] INFORMATION DESK PERSON..DANCER
        128133 <= code && code <= 128135 || // So   [3] NAIL POLISH..HAIRCUT
        128170 == code || // So       FLEXED BICEPS
        128372 <= code && code <= 128373 || // So   [2] MAN IN BUSINESS SUIT LEVITATING..SLEUTH OR SPY
        128378 == code || // So       MAN DANCING
        128400 == code || // So       RAISED HAND WITH FINGERS SPLAYED
        128405 <= code && code <= 128406 || // So   [2] REVERSED HAND WITH MIDDLE FINGER EXTENDED..RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS
        128581 <= code && code <= 128583 || // So   [3] FACE WITH NO GOOD GESTURE..PERSON BOWING DEEPLY
        128587 <= code && code <= 128591 || // So   [5] HAPPY PERSON RAISING ONE HAND..PERSON WITH FOLDED HANDS
        128675 == code || // So       ROWBOAT
        128692 <= code && code <= 128694 || // So   [3] BICYCLIST..PEDESTRIAN
        128704 == code || // So       BATH
        128716 == code || // So       SLEEPING ACCOMMODATION
        129304 <= code && code <= 129308 || // So   [5] SIGN OF THE HORNS..RIGHT-FACING FIST
        129310 <= code && code <= 129311 || // So   [2] HAND WITH INDEX AND MIDDLE FINGERS CROSSED..I LOVE YOU HAND SIGN
        129318 == code || // So       FACE PALM
        129328 <= code && code <= 129337 || // So  [10] PREGNANT WOMAN..JUGGLING
        129341 <= code && code <= 129342 || // So   [2] WATER POLO..HANDBALL
        129489 <= code && code <= 129501) {
          return E_Base;
        }
        if (127995 <= code && code <= 127999) {
          return E_Modifier;
        }
        if (8205 == code) {
          return ZWJ;
        }
        if (9792 == code || // So       FEMALE SIGN
        9794 == code || // So       MALE SIGN
        9877 <= code && code <= 9878 || // So   [2] STAFF OF AESCULAPIUS..SCALES
        9992 == code || // So       AIRPLANE
        10084 == code || // So       HEAVY BLACK HEART
        127752 == code || // So       RAINBOW
        127806 == code || // So       EAR OF RICE
        127859 == code || // So       COOKING
        127891 == code || // So       GRADUATION CAP
        127908 == code || // So       MICROPHONE
        127912 == code || // So       ARTIST PALETTE
        127979 == code || // So       SCHOOL
        127981 == code || // So       FACTORY
        128139 == code || // So       KISS MARK
        128187 <= code && code <= 128188 || // So   [2] PERSONAL COMPUTER..BRIEFCASE
        128295 == code || // So       WRENCH
        128300 == code || // So       MICROSCOPE
        128488 == code || // So       LEFT SPEECH BUBBLE
        128640 == code || // So       ROCKET
        128658 == code) {
          return Glue_After_Zwj;
        }
        if (128102 <= code && code <= 128105) {
          return E_Base_GAZ;
        }
        return Other;
      }
      return this;
    }
    if (typeof module2 != "undefined" && module2.exports) {
      module2.exports = GraphemeSplitter;
    }
  }
});

// node_modules/eslint/lib/rules/id-length.js
var require_id_length = __commonJS({
  "node_modules/eslint/lib/rules/id-length.js"(exports, module2) {
    "use strict";
    var GraphemeSplitter = require_grapheme_splitter();
    function isASCII(value2) {
      if (typeof value2 !== "string") {
        return false;
      }
      return /^[\u0020-\u007f]*$/u.test(value2);
    }
    var splitter;
    function getStringLength(value2) {
      if (isASCII(value2)) {
        return value2.length;
      }
      if (!splitter) {
        splitter = new GraphemeSplitter();
      }
      return splitter.countGraphemes(value2);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce minimum and maximum identifier lengths",
          recommended: false,
          url: "https://eslint.org/docs/rules/id-length"
        },
        schema: [
          {
            type: "object",
            properties: {
              min: {
                type: "integer",
                default: 2
              },
              max: {
                type: "integer"
              },
              exceptions: {
                type: "array",
                uniqueItems: true,
                items: {
                  type: "string"
                }
              },
              exceptionPatterns: {
                type: "array",
                uniqueItems: true,
                items: {
                  type: "string"
                }
              },
              properties: {
                enum: ["always", "never"]
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          tooShort: "Identifier name '{{name}}' is too short (< {{min}}).",
          tooShortPrivate: "Identifier name '#{{name}}' is too short (< {{min}}).",
          tooLong: "Identifier name '{{name}}' is too long (> {{max}}).",
          tooLongPrivate: "Identifier name #'{{name}}' is too long (> {{max}})."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const minLength = typeof options.min !== "undefined" ? options.min : 2;
        const maxLength = typeof options.max !== "undefined" ? options.max : Infinity;
        const properties = options.properties !== "never";
        const exceptions = new Set(options.exceptions);
        const exceptionPatterns = (options.exceptionPatterns || []).map((pattern) => new RegExp(pattern, "u"));
        const reportedNodes = /* @__PURE__ */ new Set();
        function matchesExceptionPattern(name) {
          return exceptionPatterns.some((pattern) => pattern.test(name));
        }
        const SUPPORTED_EXPRESSIONS = {
          MemberExpression: properties && function(parent) {
            return !parent.computed && // regular property assignment
            (parent.parent.left === parent && parent.parent.type === "AssignmentExpression" || // or the last identifier in an ObjectPattern destructuring
            parent.parent.type === "Property" && parent.parent.value === parent && parent.parent.parent.type === "ObjectPattern" && parent.parent.parent.parent.left === parent.parent.parent);
          },
          AssignmentPattern(parent, node) {
            return parent.left === node;
          },
          VariableDeclarator(parent, node) {
            return parent.id === node;
          },
          Property(parent, node) {
            if (parent.parent.type === "ObjectPattern") {
              const isKeyAndValueSame = parent.value.name === parent.key.name;
              return !isKeyAndValueSame && parent.value === node || isKeyAndValueSame && parent.key === node && properties;
            }
            return properties && !parent.computed && parent.key.name === node.name;
          },
          ImportDefaultSpecifier: true,
          RestElement: true,
          FunctionExpression: true,
          ArrowFunctionExpression: true,
          ClassDeclaration: true,
          FunctionDeclaration: true,
          MethodDefinition: true,
          PropertyDefinition: true,
          CatchClause: true,
          ArrayPattern: true
        };
        return {
          [[
            "Identifier",
            "PrivateIdentifier"
          ]](node) {
            const name = node.name;
            const parent = node.parent;
            const nameLength = getStringLength(name);
            const isShort = nameLength < minLength;
            const isLong = nameLength > maxLength;
            if (!(isShort || isLong) || exceptions.has(name) || matchesExceptionPattern(name)) {
              return;
            }
            const isValidExpression = SUPPORTED_EXPRESSIONS[parent.type];
            if (isValidExpression && !reportedNodes.has(node.range.toString()) && (isValidExpression === true || isValidExpression(parent, node))) {
              reportedNodes.add(node.range.toString());
              let messageId = isShort ? "tooShort" : "tooLong";
              if (node.type === "PrivateIdentifier") {
                messageId += "Private";
              }
              context.report({
                node,
                messageId,
                data: { name, min: minLength, max: maxLength }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/id-match.js
var require_id_match = __commonJS({
  "node_modules/eslint/lib/rules/id-match.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require identifiers to match a specified regular expression",
          recommended: false,
          url: "https://eslint.org/docs/rules/id-match"
        },
        schema: [
          {
            type: "string"
          },
          {
            type: "object",
            properties: {
              properties: {
                type: "boolean",
                default: false
              },
              classFields: {
                type: "boolean",
                default: false
              },
              onlyDeclarations: {
                type: "boolean",
                default: false
              },
              ignoreDestructuring: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          notMatch: "Identifier '{{name}}' does not match the pattern '{{pattern}}'.",
          notMatchPrivate: "Identifier '#{{name}}' does not match the pattern '{{pattern}}'."
        }
      },
      create(context) {
        const pattern = context.options[0] || "^.+$", regexp = new RegExp(pattern, "u");
        const options = context.options[1] || {}, checkProperties = !!options.properties, checkClassFields = !!options.classFields, onlyDeclarations = !!options.onlyDeclarations, ignoreDestructuring = !!options.ignoreDestructuring;
        let globalScope;
        const reportedNodes = /* @__PURE__ */ new Set();
        const ALLOWED_PARENT_TYPES = /* @__PURE__ */ new Set(["CallExpression", "NewExpression"]);
        const DECLARATION_TYPES = /* @__PURE__ */ new Set(["FunctionDeclaration", "VariableDeclarator"]);
        const IMPORT_TYPES = /* @__PURE__ */ new Set(["ImportSpecifier", "ImportNamespaceSpecifier", "ImportDefaultSpecifier"]);
        function isReferenceToGlobalVariable(node) {
          const variable = globalScope.set.get(node.name);
          return variable && variable.defs.length === 0 && variable.references.some((ref) => ref.identifier === node);
        }
        function isInvalid(name) {
          return !regexp.test(name);
        }
        function isInsideObjectPattern(node) {
          let { parent } = node;
          while (parent) {
            if (parent.type === "ObjectPattern") {
              return true;
            }
            parent = parent.parent;
          }
          return false;
        }
        function shouldReport(effectiveParent, name) {
          return (!onlyDeclarations || DECLARATION_TYPES.has(effectiveParent.type)) && !ALLOWED_PARENT_TYPES.has(effectiveParent.type) && isInvalid(name);
        }
        function report(node) {
          if (!reportedNodes.has(node.range.toString())) {
            const messageId = node.type === "PrivateIdentifier" ? "notMatchPrivate" : "notMatch";
            context.report({
              node,
              messageId,
              data: {
                name: node.name,
                pattern
              }
            });
            reportedNodes.add(node.range.toString());
          }
        }
        return {
          Program() {
            globalScope = context.getScope();
          },
          Identifier(node) {
            const name = node.name, parent = node.parent, effectiveParent = parent.type === "MemberExpression" ? parent.parent : parent;
            if (isReferenceToGlobalVariable(node)) {
              return;
            }
            if (parent.type === "MemberExpression") {
              if (!checkProperties) {
                return;
              }
              if (parent.object.type === "Identifier" && parent.object.name === name) {
                if (isInvalid(name)) {
                  report(node);
                }
              } else if (effectiveParent.type === "AssignmentExpression" && effectiveParent.left.type === "MemberExpression" && effectiveParent.left.property.name === node.name) {
                if (isInvalid(name)) {
                  report(node);
                }
              } else if (effectiveParent.type === "AssignmentExpression" && effectiveParent.right.type !== "MemberExpression") {
                if (isInvalid(name)) {
                  report(node);
                }
              }
            } else if (parent.type === "Property" && parent.parent.type === "ObjectExpression" && parent.key === node && !parent.computed) {
              if (checkProperties && isInvalid(name)) {
                report(node);
              }
            } else if (parent.type === "Property" || parent.type === "AssignmentPattern") {
              if (parent.parent && parent.parent.type === "ObjectPattern") {
                if (!ignoreDestructuring && parent.shorthand && parent.value.left && isInvalid(name)) {
                  report(node);
                }
                const assignmentKeyEqualsValue = parent.key.name === parent.value.name;
                if (!assignmentKeyEqualsValue && parent.key === node) {
                  return;
                }
                const valueIsInvalid = parent.value.name && isInvalid(name);
                if (valueIsInvalid && !(assignmentKeyEqualsValue && ignoreDestructuring)) {
                  report(node);
                }
              }
              if (!checkProperties && !parent.computed || ignoreDestructuring && isInsideObjectPattern(node)) {
                return;
              }
              if (parent.right !== node && shouldReport(effectiveParent, name)) {
                report(node);
              }
            } else if (IMPORT_TYPES.has(parent.type)) {
              if (parent.local && parent.local.name === node.name && isInvalid(name)) {
                report(node);
              }
            } else if (parent.type === "PropertyDefinition") {
              if (checkClassFields && isInvalid(name)) {
                report(node);
              }
            } else if (shouldReport(effectiveParent, name)) {
              report(node);
            }
          },
          "PrivateIdentifier"(node) {
            const isClassField = node.parent.type === "PropertyDefinition";
            if (isClassField && !checkClassFields) {
              return;
            }
            if (isInvalid(node.name)) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/implicit-arrow-linebreak.js
var require_implicit_arrow_linebreak = __commonJS({
  "node_modules/eslint/lib/rules/implicit-arrow-linebreak.js"(exports, module2) {
    "use strict";
    var { isCommentToken, isNotOpeningParenToken } = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce the location of arrow function bodies",
          recommended: false,
          url: "https://eslint.org/docs/rules/implicit-arrow-linebreak"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["beside", "below"]
          }
        ],
        messages: {
          expected: "Expected a linebreak before this expression.",
          unexpected: "Expected no linebreak before this expression."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const option = context.options[0] || "beside";
        function validateExpression(node) {
          if (node.body.type === "BlockStatement") {
            return;
          }
          const arrowToken = sourceCode.getTokenBefore(node.body, isNotOpeningParenToken);
          const firstTokenOfBody = sourceCode.getTokenAfter(arrowToken);
          if (arrowToken.loc.end.line === firstTokenOfBody.loc.start.line && option === "below") {
            context.report({
              node: firstTokenOfBody,
              messageId: "expected",
              fix: (fixer) => fixer.insertTextBefore(firstTokenOfBody, "\n")
            });
          } else if (arrowToken.loc.end.line !== firstTokenOfBody.loc.start.line && option === "beside") {
            context.report({
              node: firstTokenOfBody,
              messageId: "unexpected",
              fix(fixer) {
                if (sourceCode.getFirstTokenBetween(arrowToken, firstTokenOfBody, { includeComments: true, filter: isCommentToken })) {
                  return null;
                }
                return fixer.replaceTextRange([arrowToken.range[1], firstTokenOfBody.range[0]], " ");
              }
            });
          }
        }
        return {
          ArrowFunctionExpression: (node) => validateExpression(node)
        };
      }
    };
  }
});

// node_modules/js-sdsl/dist/cjs/container/ContainerBase/index.js
var require_ContainerBase = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/ContainerBase/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.ContainerIterator = exports.Container = exports.Base = void 0;
    var ContainerIterator = class {
      constructor(t3 = 0) {
        this.iteratorType = t3;
      }
      equals(t3) {
        return this.o === t3.o;
      }
    };
    exports.ContainerIterator = ContainerIterator;
    var Base = class {
      constructor() {
        this.i = 0;
      }
      get length() {
        return this.i;
      }
      size() {
        return this.i;
      }
      empty() {
        return this.i === 0;
      }
    };
    exports.Base = Base;
    var Container = class extends Base {
    };
    exports.Container = Container;
  }
});

// node_modules/js-sdsl/dist/cjs/container/OtherContainer/Stack.js
var require_Stack2 = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/OtherContainer/Stack.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _ContainerBase = require_ContainerBase();
    var Stack = class extends _ContainerBase.Base {
      constructor(t3 = []) {
        super();
        this.S = [];
        const s = this;
        t3.forEach(function(t4) {
          s.push(t4);
        });
      }
      clear() {
        this.i = 0;
        this.S = [];
      }
      push(t3) {
        this.S.push(t3);
        this.i += 1;
        return this.i;
      }
      pop() {
        if (this.i === 0)
          return;
        this.i -= 1;
        return this.S.pop();
      }
      top() {
        return this.S[this.i - 1];
      }
    };
    var _default = Stack;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Base/index.js
var require_Base = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Base/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _ContainerBase = require_ContainerBase();
    var SequentialContainer = class extends _ContainerBase.Container {
    };
    var _default = SequentialContainer;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/utils/throwError.js
var require_throwError2 = __commonJS({
  "node_modules/js-sdsl/dist/cjs/utils/throwError.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.throwIteratorAccessError = throwIteratorAccessError;
    function throwIteratorAccessError() {
      throw new RangeError("Iterator access denied!");
    }
  }
});

// node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Base/RandomIterator.js
var require_RandomIterator = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Base/RandomIterator.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.RandomIterator = void 0;
    var _ContainerBase = require_ContainerBase();
    var _throwError = require_throwError2();
    var RandomIterator = class extends _ContainerBase.ContainerIterator {
      constructor(t3, r, i, s, h) {
        super(h);
        this.o = t3;
        this.D = r;
        this.R = i;
        this.N = s;
        if (this.iteratorType === 0) {
          this.pre = function() {
            if (this.o === 0) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o -= 1;
            return this;
          };
          this.next = function() {
            if (this.o === this.D()) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o += 1;
            return this;
          };
        } else {
          this.pre = function() {
            if (this.o === this.D() - 1) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o += 1;
            return this;
          };
          this.next = function() {
            if (this.o === -1) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o -= 1;
            return this;
          };
        }
      }
      get pointer() {
        if (this.o < 0 || this.o > this.D() - 1) {
          throw new RangeError();
        }
        return this.R(this.o);
      }
      set pointer(t3) {
        if (this.o < 0 || this.o > this.D() - 1) {
          throw new RangeError();
        }
        this.N(this.o, t3);
      }
    };
    exports.RandomIterator = RandomIterator;
  }
});

// node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Deque.js
var require_Deque = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Deque.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require_Base());
    var _RandomIterator = require_RandomIterator();
    function _interopRequireDefault(t3) {
      return t3 && t3.t ? t3 : {
        default: t3
      };
    }
    var DequeIterator = class _DequeIterator extends _RandomIterator.RandomIterator {
      copy() {
        return new _DequeIterator(this.o, this.D, this.R, this.N, this.iteratorType);
      }
    };
    var Deque = class extends _Base.default {
      constructor(t3 = [], s = 1 << 12) {
        super();
        this.P = 0;
        this.A = 0;
        this.F = 0;
        this.j = 0;
        this.O = 0;
        this.T = [];
        let i;
        if ("size" in t3) {
          if (typeof t3.size === "number") {
            i = t3.size;
          } else {
            i = t3.size();
          }
        } else if ("length" in t3) {
          i = t3.length;
        } else {
          throw new RangeError("Can't get container's size!");
        }
        this.V = s;
        this.O = Math.max(Math.ceil(i / this.V), 1);
        for (let t4 = 0; t4 < this.O; ++t4) {
          this.T.push(new Array(this.V));
        }
        const h = Math.ceil(i / this.V);
        this.P = this.F = (this.O >> 1) - (h >> 1);
        this.A = this.j = this.V - i % this.V >> 1;
        const e = this;
        t3.forEach(function(t4) {
          e.pushBack(t4);
        });
        this.size = this.size.bind(this);
        this.getElementByPos = this.getElementByPos.bind(this);
        this.setElementByPos = this.setElementByPos.bind(this);
      }
      G() {
        const t3 = [];
        const s = Math.max(this.O >> 1, 1);
        for (let i = 0; i < s; ++i) {
          t3[i] = new Array(this.V);
        }
        for (let s2 = this.P; s2 < this.O; ++s2) {
          t3[t3.length] = this.T[s2];
        }
        for (let s2 = 0; s2 < this.F; ++s2) {
          t3[t3.length] = this.T[s2];
        }
        t3[t3.length] = [...this.T[this.F]];
        this.P = s;
        this.F = t3.length - 1;
        for (let i = 0; i < s; ++i) {
          t3[t3.length] = new Array(this.V);
        }
        this.T = t3;
        this.O = t3.length;
      }
      J(t3) {
        const s = this.A + t3 + 1;
        const i = s % this.V;
        let h = i - 1;
        let e = this.P + (s - i) / this.V;
        if (i === 0)
          e -= 1;
        e %= this.O;
        if (h < 0)
          h += this.V;
        return {
          curNodeBucketIndex: e,
          curNodePointerIndex: h
        };
      }
      clear() {
        this.T = [[]];
        this.O = 1;
        this.P = this.F = this.i = 0;
        this.A = this.j = this.V >> 1;
      }
      begin() {
        return new DequeIterator(0, this.size, this.getElementByPos, this.setElementByPos);
      }
      end() {
        return new DequeIterator(this.i, this.size, this.getElementByPos, this.setElementByPos);
      }
      rBegin() {
        return new DequeIterator(this.i - 1, this.size, this.getElementByPos, this.setElementByPos, 1);
      }
      rEnd() {
        return new DequeIterator(-1, this.size, this.getElementByPos, this.setElementByPos, 1);
      }
      front() {
        return this.T[this.P][this.A];
      }
      back() {
        return this.T[this.F][this.j];
      }
      pushBack(t3) {
        if (this.i) {
          if (this.j < this.V - 1) {
            this.j += 1;
          } else if (this.F < this.O - 1) {
            this.F += 1;
            this.j = 0;
          } else {
            this.F = 0;
            this.j = 0;
          }
          if (this.F === this.P && this.j === this.A)
            this.G();
        }
        this.i += 1;
        this.T[this.F][this.j] = t3;
        return this.i;
      }
      popBack() {
        if (this.i === 0)
          return;
        const t3 = this.T[this.F][this.j];
        delete this.T[this.F][this.j];
        if (this.i !== 1) {
          if (this.j > 0) {
            this.j -= 1;
          } else if (this.F > 0) {
            this.F -= 1;
            this.j = this.V - 1;
          } else {
            this.F = this.O - 1;
            this.j = this.V - 1;
          }
        }
        this.i -= 1;
        return t3;
      }
      pushFront(t3) {
        if (this.i) {
          if (this.A > 0) {
            this.A -= 1;
          } else if (this.P > 0) {
            this.P -= 1;
            this.A = this.V - 1;
          } else {
            this.P = this.O - 1;
            this.A = this.V - 1;
          }
          if (this.P === this.F && this.A === this.j)
            this.G();
        }
        this.i += 1;
        this.T[this.P][this.A] = t3;
        return this.i;
      }
      popFront() {
        if (this.i === 0)
          return;
        const t3 = this.T[this.P][this.A];
        delete this.T[this.P][this.A];
        if (this.i !== 1) {
          if (this.A < this.V - 1) {
            this.A += 1;
          } else if (this.P < this.O - 1) {
            this.P += 1;
            this.A = 0;
          } else {
            this.P = 0;
            this.A = 0;
          }
        }
        this.i -= 1;
        return t3;
      }
      getElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        const { curNodeBucketIndex: s, curNodePointerIndex: i } = this.J(t3);
        return this.T[s][i];
      }
      setElementByPos(t3, s) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        const { curNodeBucketIndex: i, curNodePointerIndex: h } = this.J(t3);
        this.T[i][h] = s;
      }
      insert(t3, s, i = 1) {
        if (t3 < 0 || t3 > this.i) {
          throw new RangeError();
        }
        if (t3 === 0) {
          while (i--)
            this.pushFront(s);
        } else if (t3 === this.i) {
          while (i--)
            this.pushBack(s);
        } else {
          const h = [];
          for (let s2 = t3; s2 < this.i; ++s2) {
            h.push(this.getElementByPos(s2));
          }
          this.cut(t3 - 1);
          for (let t4 = 0; t4 < i; ++t4)
            this.pushBack(s);
          for (let t4 = 0; t4 < h.length; ++t4)
            this.pushBack(h[t4]);
        }
        return this.i;
      }
      cut(t3) {
        if (t3 < 0) {
          this.clear();
          return 0;
        }
        const { curNodeBucketIndex: s, curNodePointerIndex: i } = this.J(t3);
        this.F = s;
        this.j = i;
        this.i = t3 + 1;
        return this.i;
      }
      eraseElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        if (t3 === 0)
          this.popFront();
        else if (t3 === this.i - 1)
          this.popBack();
        else {
          const s = [];
          for (let i2 = t3 + 1; i2 < this.i; ++i2) {
            s.push(this.getElementByPos(i2));
          }
          this.cut(t3);
          this.popBack();
          const i = this;
          s.forEach(function(t4) {
            i.pushBack(t4);
          });
        }
        return this.i;
      }
      eraseElementByValue(t3) {
        if (this.i === 0)
          return 0;
        const s = [];
        for (let i2 = 0; i2 < this.i; ++i2) {
          const h = this.getElementByPos(i2);
          if (h !== t3)
            s.push(h);
        }
        const i = s.length;
        for (let t4 = 0; t4 < i; ++t4)
          this.setElementByPos(t4, s[t4]);
        return this.cut(i - 1);
      }
      eraseElementByIterator(t3) {
        const s = t3.o;
        this.eraseElementByPos(s);
        t3 = t3.next();
        return t3;
      }
      find(t3) {
        for (let s = 0; s < this.i; ++s) {
          if (this.getElementByPos(s) === t3) {
            return new DequeIterator(s, this.size, this.getElementByPos, this.setElementByPos);
          }
        }
        return this.end();
      }
      reverse() {
        let t3 = 0;
        let s = this.i - 1;
        while (t3 < s) {
          const i = this.getElementByPos(t3);
          this.setElementByPos(t3, this.getElementByPos(s));
          this.setElementByPos(s, i);
          t3 += 1;
          s -= 1;
        }
      }
      unique() {
        if (this.i <= 1) {
          return this.i;
        }
        let t3 = 1;
        let s = this.getElementByPos(0);
        for (let i = 1; i < this.i; ++i) {
          const h = this.getElementByPos(i);
          if (h !== s) {
            s = h;
            this.setElementByPos(t3++, h);
          }
        }
        while (this.i > t3)
          this.popBack();
        return this.i;
      }
      sort(t3) {
        const s = [];
        for (let t4 = 0; t4 < this.i; ++t4) {
          s.push(this.getElementByPos(t4));
        }
        s.sort(t3);
        for (let t4 = 0; t4 < this.i; ++t4)
          this.setElementByPos(t4, s[t4]);
      }
      shrinkToFit() {
        if (this.i === 0)
          return;
        const t3 = [];
        this.forEach(function(s) {
          t3.push(s);
        });
        this.O = Math.max(Math.ceil(this.i / this.V), 1);
        this.i = this.P = this.F = this.A = this.j = 0;
        this.T = [];
        for (let t4 = 0; t4 < this.O; ++t4) {
          this.T.push(new Array(this.V));
        }
        for (let s = 0; s < t3.length; ++s)
          this.pushBack(t3[s]);
      }
      forEach(t3) {
        for (let s = 0; s < this.i; ++s) {
          t3(this.getElementByPos(s), s, this);
        }
      }
      [Symbol.iterator]() {
        return function* () {
          for (let t3 = 0; t3 < this.i; ++t3) {
            yield this.getElementByPos(t3);
          }
        }.bind(this)();
      }
    };
    var _default = Deque;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/OtherContainer/Queue.js
var require_Queue = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/OtherContainer/Queue.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _ContainerBase = require_ContainerBase();
    var _Deque = _interopRequireDefault(require_Deque());
    function _interopRequireDefault(e) {
      return e && e.t ? e : {
        default: e
      };
    }
    var Queue = class extends _ContainerBase.Base {
      constructor(e = []) {
        super();
        this.q = new _Deque.default(e);
        this.i = this.q.size();
      }
      clear() {
        this.q.clear();
        this.i = 0;
      }
      push(e) {
        this.q.pushBack(e);
        this.i += 1;
        return this.i;
      }
      pop() {
        if (this.i === 0)
          return;
        this.i -= 1;
        return this.q.popFront();
      }
      front() {
        return this.q.front();
      }
    };
    var _default = Queue;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/OtherContainer/PriorityQueue.js
var require_PriorityQueue = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/OtherContainer/PriorityQueue.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _ContainerBase = require_ContainerBase();
    var PriorityQueue = class extends _ContainerBase.Base {
      constructor(t3 = [], s = function(t4, s2) {
        if (t4 > s2)
          return -1;
        if (t4 < s2)
          return 1;
        return 0;
      }, i = true) {
        super();
        this.v = s;
        if (Array.isArray(t3)) {
          this.C = i ? [...t3] : t3;
        } else {
          this.C = [];
          const s2 = this;
          t3.forEach(function(t4) {
            s2.C.push(t4);
          });
        }
        this.i = this.C.length;
        const e = this.i >> 1;
        for (let t4 = this.i - 1 >> 1; t4 >= 0; --t4) {
          this.k(t4, e);
        }
      }
      m(t3) {
        const s = this.C[t3];
        while (t3 > 0) {
          const i = t3 - 1 >> 1;
          const e = this.C[i];
          if (this.v(e, s) <= 0)
            break;
          this.C[t3] = e;
          t3 = i;
        }
        this.C[t3] = s;
      }
      k(t3, s) {
        const i = this.C[t3];
        while (t3 < s) {
          let s2 = t3 << 1 | 1;
          const e = s2 + 1;
          let h = this.C[s2];
          if (e < this.i && this.v(h, this.C[e]) > 0) {
            s2 = e;
            h = this.C[e];
          }
          if (this.v(h, i) >= 0)
            break;
          this.C[t3] = h;
          t3 = s2;
        }
        this.C[t3] = i;
      }
      clear() {
        this.i = 0;
        this.C.length = 0;
      }
      push(t3) {
        this.C.push(t3);
        this.m(this.i);
        this.i += 1;
      }
      pop() {
        if (this.i === 0)
          return;
        const t3 = this.C[0];
        const s = this.C.pop();
        this.i -= 1;
        if (this.i) {
          this.C[0] = s;
          this.k(0, this.i >> 1);
        }
        return t3;
      }
      top() {
        return this.C[0];
      }
      find(t3) {
        return this.C.indexOf(t3) >= 0;
      }
      remove(t3) {
        const s = this.C.indexOf(t3);
        if (s < 0)
          return false;
        if (s === 0) {
          this.pop();
        } else if (s === this.i - 1) {
          this.C.pop();
          this.i -= 1;
        } else {
          this.C.splice(s, 1, this.C.pop());
          this.i -= 1;
          this.m(s);
          this.k(s, this.i >> 1);
        }
        return true;
      }
      updateItem(t3) {
        const s = this.C.indexOf(t3);
        if (s < 0)
          return false;
        this.m(s);
        this.k(s, this.i >> 1);
        return true;
      }
      toArray() {
        return [...this.C];
      }
    };
    var _default = PriorityQueue;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Vector.js
var require_Vector = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/SequentialContainer/Vector.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require_Base());
    var _RandomIterator = require_RandomIterator();
    function _interopRequireDefault(t3) {
      return t3 && t3.t ? t3 : {
        default: t3
      };
    }
    var VectorIterator = class _VectorIterator extends _RandomIterator.RandomIterator {
      copy() {
        return new _VectorIterator(this.o, this.D, this.R, this.N, this.iteratorType);
      }
    };
    var Vector = class extends _Base.default {
      constructor(t3 = [], r = true) {
        super();
        if (Array.isArray(t3)) {
          this.W = r ? [...t3] : t3;
          this.i = t3.length;
        } else {
          this.W = [];
          const r2 = this;
          t3.forEach(function(t4) {
            r2.pushBack(t4);
          });
        }
        this.size = this.size.bind(this);
        this.getElementByPos = this.getElementByPos.bind(this);
        this.setElementByPos = this.setElementByPos.bind(this);
      }
      clear() {
        this.i = 0;
        this.W.length = 0;
      }
      begin() {
        return new VectorIterator(0, this.size, this.getElementByPos, this.setElementByPos);
      }
      end() {
        return new VectorIterator(this.i, this.size, this.getElementByPos, this.setElementByPos);
      }
      rBegin() {
        return new VectorIterator(this.i - 1, this.size, this.getElementByPos, this.setElementByPos, 1);
      }
      rEnd() {
        return new VectorIterator(-1, this.size, this.getElementByPos, this.setElementByPos, 1);
      }
      front() {
        return this.W[0];
      }
      back() {
        return this.W[this.i - 1];
      }
      getElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        return this.W[t3];
      }
      eraseElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        this.W.splice(t3, 1);
        this.i -= 1;
        return this.i;
      }
      eraseElementByValue(t3) {
        let r = 0;
        for (let e = 0; e < this.i; ++e) {
          if (this.W[e] !== t3) {
            this.W[r++] = this.W[e];
          }
        }
        this.i = this.W.length = r;
        return this.i;
      }
      eraseElementByIterator(t3) {
        const r = t3.o;
        t3 = t3.next();
        this.eraseElementByPos(r);
        return t3;
      }
      pushBack(t3) {
        this.W.push(t3);
        this.i += 1;
        return this.i;
      }
      popBack() {
        if (this.i === 0)
          return;
        this.i -= 1;
        return this.W.pop();
      }
      setElementByPos(t3, r) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        this.W[t3] = r;
      }
      insert(t3, r, e = 1) {
        if (t3 < 0 || t3 > this.i) {
          throw new RangeError();
        }
        this.W.splice(t3, 0, ...new Array(e).fill(r));
        this.i += e;
        return this.i;
      }
      find(t3) {
        for (let r = 0; r < this.i; ++r) {
          if (this.W[r] === t3) {
            return new VectorIterator(r, this.size, this.getElementByPos, this.getElementByPos);
          }
        }
        return this.end();
      }
      reverse() {
        this.W.reverse();
      }
      unique() {
        let t3 = 1;
        for (let r = 1; r < this.i; ++r) {
          if (this.W[r] !== this.W[r - 1]) {
            this.W[t3++] = this.W[r];
          }
        }
        this.i = this.W.length = t3;
        return this.i;
      }
      sort(t3) {
        this.W.sort(t3);
      }
      forEach(t3) {
        for (let r = 0; r < this.i; ++r) {
          t3(this.W[r], r, this);
        }
      }
      [Symbol.iterator]() {
        return function* () {
          yield* this.W;
        }.bind(this)();
      }
    };
    var _default = Vector;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/SequentialContainer/LinkList.js
var require_LinkList = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/SequentialContainer/LinkList.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require_Base());
    var _ContainerBase = require_ContainerBase();
    var _throwError = require_throwError2();
    function _interopRequireDefault(t3) {
      return t3 && t3.t ? t3 : {
        default: t3
      };
    }
    var LinkListIterator = class _LinkListIterator extends _ContainerBase.ContainerIterator {
      constructor(t3, i, s) {
        super(s);
        this.o = t3;
        this.h = i;
        if (this.iteratorType === 0) {
          this.pre = function() {
            if (this.o.L === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L;
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B;
            return this;
          };
        } else {
          this.pre = function() {
            if (this.o.B === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B;
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L;
            return this;
          };
        }
      }
      get pointer() {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        return this.o.l;
      }
      set pointer(t3) {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        this.o.l = t3;
      }
      copy() {
        return new _LinkListIterator(this.o, this.h, this.iteratorType);
      }
    };
    var LinkList = class extends _Base.default {
      constructor(t3 = []) {
        super();
        this.h = {};
        this.p = this._ = this.h.L = this.h.B = this.h;
        const i = this;
        t3.forEach(function(t4) {
          i.pushBack(t4);
        });
      }
      K(t3) {
        const { L: i, B: s } = t3;
        i.B = s;
        s.L = i;
        if (t3 === this.p) {
          this.p = s;
        }
        if (t3 === this._) {
          this._ = i;
        }
        this.i -= 1;
      }
      U(t3, i) {
        const s = i.B;
        const r = {
          l: t3,
          L: i,
          B: s
        };
        i.B = r;
        s.L = r;
        if (i === this.h) {
          this.p = r;
        }
        if (s === this.h) {
          this._ = r;
        }
        this.i += 1;
      }
      clear() {
        this.i = 0;
        this.p = this._ = this.h.L = this.h.B = this.h;
      }
      begin() {
        return new LinkListIterator(this.p, this.h);
      }
      end() {
        return new LinkListIterator(this.h, this.h);
      }
      rBegin() {
        return new LinkListIterator(this._, this.h, 1);
      }
      rEnd() {
        return new LinkListIterator(this.h, this.h, 1);
      }
      front() {
        return this.p.l;
      }
      back() {
        return this._.l;
      }
      getElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let i = this.p;
        while (t3--) {
          i = i.B;
        }
        return i.l;
      }
      eraseElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let i = this.p;
        while (t3--) {
          i = i.B;
        }
        this.K(i);
        return this.i;
      }
      eraseElementByValue(t3) {
        let i = this.p;
        while (i !== this.h) {
          if (i.l === t3) {
            this.K(i);
          }
          i = i.B;
        }
        return this.i;
      }
      eraseElementByIterator(t3) {
        const i = t3.o;
        if (i === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        t3 = t3.next();
        this.K(i);
        return t3;
      }
      pushBack(t3) {
        this.U(t3, this._);
        return this.i;
      }
      popBack() {
        if (this.i === 0)
          return;
        const t3 = this._.l;
        this.K(this._);
        return t3;
      }
      pushFront(t3) {
        this.U(t3, this.h);
        return this.i;
      }
      popFront() {
        if (this.i === 0)
          return;
        const t3 = this.p.l;
        this.K(this.p);
        return t3;
      }
      setElementByPos(t3, i) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let s = this.p;
        while (t3--) {
          s = s.B;
        }
        s.l = i;
      }
      insert(t3, i, s = 1) {
        if (t3 < 0 || t3 > this.i) {
          throw new RangeError();
        }
        if (s <= 0)
          return this.i;
        if (t3 === 0) {
          while (s--)
            this.pushFront(i);
        } else if (t3 === this.i) {
          while (s--)
            this.pushBack(i);
        } else {
          let r = this.p;
          for (let i2 = 1; i2 < t3; ++i2) {
            r = r.B;
          }
          const e = r.B;
          this.i += s;
          while (s--) {
            r.B = {
              l: i,
              L: r
            };
            r.B.L = r;
            r = r.B;
          }
          r.B = e;
          e.L = r;
        }
        return this.i;
      }
      find(t3) {
        let i = this.p;
        while (i !== this.h) {
          if (i.l === t3) {
            return new LinkListIterator(i, this.h);
          }
          i = i.B;
        }
        return this.end();
      }
      reverse() {
        if (this.i <= 1)
          return;
        let t3 = this.p;
        let i = this._;
        let s = 0;
        while (s << 1 < this.i) {
          const r = t3.l;
          t3.l = i.l;
          i.l = r;
          t3 = t3.B;
          i = i.L;
          s += 1;
        }
      }
      unique() {
        if (this.i <= 1) {
          return this.i;
        }
        let t3 = this.p;
        while (t3 !== this.h) {
          let i = t3;
          while (i.B !== this.h && i.l === i.B.l) {
            i = i.B;
            this.i -= 1;
          }
          t3.B = i.B;
          t3.B.L = t3;
          t3 = t3.B;
        }
        return this.i;
      }
      sort(t3) {
        if (this.i <= 1)
          return;
        const i = [];
        this.forEach(function(t4) {
          i.push(t4);
        });
        i.sort(t3);
        let s = this.p;
        i.forEach(function(t4) {
          s.l = t4;
          s = s.B;
        });
      }
      merge(t3) {
        const i = this;
        if (this.i === 0) {
          t3.forEach(function(t4) {
            i.pushBack(t4);
          });
        } else {
          let s = this.p;
          t3.forEach(function(t4) {
            while (s !== i.h && s.l <= t4) {
              s = s.B;
            }
            i.U(t4, s.L);
          });
        }
        return this.i;
      }
      forEach(t3) {
        let i = this.p;
        let s = 0;
        while (i !== this.h) {
          t3(i.l, s++, this);
          i = i.B;
        }
      }
      [Symbol.iterator]() {
        return function* () {
          if (this.i === 0)
            return;
          let t3 = this.p;
          while (t3 !== this.h) {
            yield t3.l;
            t3 = t3.B;
          }
        }.bind(this)();
      }
    };
    var _default = LinkList;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/TreeNode.js
var require_TreeNode = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/TreeNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.TreeNodeEnableIndex = exports.TreeNode = void 0;
    var TreeNode = class {
      constructor(e, t3) {
        this.ee = 1;
        this.u = void 0;
        this.l = void 0;
        this.Y = void 0;
        this.Z = void 0;
        this.tt = void 0;
        this.u = e;
        this.l = t3;
      }
      L() {
        let e = this;
        if (e.ee === 1 && e.tt.tt === e) {
          e = e.Z;
        } else if (e.Y) {
          e = e.Y;
          while (e.Z) {
            e = e.Z;
          }
        } else {
          let t3 = e.tt;
          while (t3.Y === e) {
            e = t3;
            t3 = e.tt;
          }
          e = t3;
        }
        return e;
      }
      B() {
        let e = this;
        if (e.Z) {
          e = e.Z;
          while (e.Y) {
            e = e.Y;
          }
          return e;
        } else {
          let t3 = e.tt;
          while (t3.Z === e) {
            e = t3;
            t3 = e.tt;
          }
          if (e.Z !== t3) {
            return t3;
          } else
            return e;
        }
      }
      te() {
        const e = this.tt;
        const t3 = this.Z;
        const s = t3.Y;
        if (e.tt === this)
          e.tt = t3;
        else if (e.Y === this)
          e.Y = t3;
        else
          e.Z = t3;
        t3.tt = e;
        t3.Y = this;
        this.tt = t3;
        this.Z = s;
        if (s)
          s.tt = this;
        return t3;
      }
      se() {
        const e = this.tt;
        const t3 = this.Y;
        const s = t3.Z;
        if (e.tt === this)
          e.tt = t3;
        else if (e.Y === this)
          e.Y = t3;
        else
          e.Z = t3;
        t3.tt = e;
        t3.Z = this;
        this.tt = t3;
        this.Y = s;
        if (s)
          s.tt = this;
        return t3;
      }
    };
    exports.TreeNode = TreeNode;
    var TreeNodeEnableIndex = class extends TreeNode {
      constructor() {
        super(...arguments);
        this.rt = 1;
      }
      te() {
        const e = super.te();
        this.ie();
        e.ie();
        return e;
      }
      se() {
        const e = super.se();
        this.ie();
        e.ie();
        return e;
      }
      ie() {
        this.rt = 1;
        if (this.Y) {
          this.rt += this.Y.rt;
        }
        if (this.Z) {
          this.rt += this.Z.rt;
        }
      }
    };
    exports.TreeNodeEnableIndex = TreeNodeEnableIndex;
  }
});

// node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/index.js
var require_Base2 = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _TreeNode = require_TreeNode();
    var _ContainerBase = require_ContainerBase();
    var _throwError = require_throwError2();
    var TreeContainer = class extends _ContainerBase.Container {
      constructor(e = function(e2, t4) {
        if (e2 < t4)
          return -1;
        if (e2 > t4)
          return 1;
        return 0;
      }, t3 = false) {
        super();
        this.rr = void 0;
        this.v = e;
        if (t3) {
          this.re = _TreeNode.TreeNodeEnableIndex;
          this.M = function(e2, t4, i) {
            const s = this.ne(e2, t4, i);
            if (s) {
              let e3 = s.tt;
              while (e3 !== this.h) {
                e3.rt += 1;
                e3 = e3.tt;
              }
              const t5 = this.he(s);
              if (t5) {
                const { parentNode: e4, grandParent: i2, curNode: s2 } = t5;
                e4.ie();
                i2.ie();
                s2.ie();
              }
            }
            return this.i;
          };
          this.K = function(e2) {
            let t4 = this.fe(e2);
            while (t4 !== this.h) {
              t4.rt -= 1;
              t4 = t4.tt;
            }
          };
        } else {
          this.re = _TreeNode.TreeNode;
          this.M = function(e2, t4, i) {
            const s = this.ne(e2, t4, i);
            if (s)
              this.he(s);
            return this.i;
          };
          this.K = this.fe;
        }
        this.h = new this.re();
      }
      $(e, t3) {
        let i = this.h;
        while (e) {
          const s = this.v(e.u, t3);
          if (s < 0) {
            e = e.Z;
          } else if (s > 0) {
            i = e;
            e = e.Y;
          } else
            return e;
        }
        return i;
      }
      er(e, t3) {
        let i = this.h;
        while (e) {
          const s = this.v(e.u, t3);
          if (s <= 0) {
            e = e.Z;
          } else {
            i = e;
            e = e.Y;
          }
        }
        return i;
      }
      tr(e, t3) {
        let i = this.h;
        while (e) {
          const s = this.v(e.u, t3);
          if (s < 0) {
            i = e;
            e = e.Z;
          } else if (s > 0) {
            e = e.Y;
          } else
            return e;
        }
        return i;
      }
      sr(e, t3) {
        let i = this.h;
        while (e) {
          const s = this.v(e.u, t3);
          if (s < 0) {
            i = e;
            e = e.Z;
          } else {
            e = e.Y;
          }
        }
        return i;
      }
      ue(e) {
        while (true) {
          const t3 = e.tt;
          if (t3 === this.h)
            return;
          if (e.ee === 1) {
            e.ee = 0;
            return;
          }
          if (e === t3.Y) {
            const i = t3.Z;
            if (i.ee === 1) {
              i.ee = 0;
              t3.ee = 1;
              if (t3 === this.rr) {
                this.rr = t3.te();
              } else
                t3.te();
            } else {
              if (i.Z && i.Z.ee === 1) {
                i.ee = t3.ee;
                t3.ee = 0;
                i.Z.ee = 0;
                if (t3 === this.rr) {
                  this.rr = t3.te();
                } else
                  t3.te();
                return;
              } else if (i.Y && i.Y.ee === 1) {
                i.ee = 1;
                i.Y.ee = 0;
                i.se();
              } else {
                i.ee = 1;
                e = t3;
              }
            }
          } else {
            const i = t3.Y;
            if (i.ee === 1) {
              i.ee = 0;
              t3.ee = 1;
              if (t3 === this.rr) {
                this.rr = t3.se();
              } else
                t3.se();
            } else {
              if (i.Y && i.Y.ee === 1) {
                i.ee = t3.ee;
                t3.ee = 0;
                i.Y.ee = 0;
                if (t3 === this.rr) {
                  this.rr = t3.se();
                } else
                  t3.se();
                return;
              } else if (i.Z && i.Z.ee === 1) {
                i.ee = 1;
                i.Z.ee = 0;
                i.te();
              } else {
                i.ee = 1;
                e = t3;
              }
            }
          }
        }
      }
      fe(e) {
        if (this.i === 1) {
          this.clear();
          return this.h;
        }
        let t3 = e;
        while (t3.Y || t3.Z) {
          if (t3.Z) {
            t3 = t3.Z;
            while (t3.Y)
              t3 = t3.Y;
          } else {
            t3 = t3.Y;
          }
          [e.u, t3.u] = [t3.u, e.u];
          [e.l, t3.l] = [t3.l, e.l];
          e = t3;
        }
        if (this.h.Y === t3) {
          this.h.Y = t3.tt;
        } else if (this.h.Z === t3) {
          this.h.Z = t3.tt;
        }
        this.ue(t3);
        const i = t3.tt;
        if (t3 === i.Y) {
          i.Y = void 0;
        } else
          i.Z = void 0;
        this.i -= 1;
        this.rr.ee = 0;
        return i;
      }
      oe(e, t3) {
        if (e === void 0)
          return false;
        const i = this.oe(e.Y, t3);
        if (i)
          return true;
        if (t3(e))
          return true;
        return this.oe(e.Z, t3);
      }
      he(e) {
        while (true) {
          const t3 = e.tt;
          if (t3.ee === 0)
            return;
          const i = t3.tt;
          if (t3 === i.Y) {
            const s = i.Z;
            if (s && s.ee === 1) {
              s.ee = t3.ee = 0;
              if (i === this.rr)
                return;
              i.ee = 1;
              e = i;
              continue;
            } else if (e === t3.Z) {
              e.ee = 0;
              if (e.Y)
                e.Y.tt = t3;
              if (e.Z)
                e.Z.tt = i;
              t3.Z = e.Y;
              i.Y = e.Z;
              e.Y = t3;
              e.Z = i;
              if (i === this.rr) {
                this.rr = e;
                this.h.tt = e;
              } else {
                const t4 = i.tt;
                if (t4.Y === i) {
                  t4.Y = e;
                } else
                  t4.Z = e;
              }
              e.tt = i.tt;
              t3.tt = e;
              i.tt = e;
              i.ee = 1;
              return {
                parentNode: t3,
                grandParent: i,
                curNode: e
              };
            } else {
              t3.ee = 0;
              if (i === this.rr) {
                this.rr = i.se();
              } else
                i.se();
              i.ee = 1;
            }
          } else {
            const s = i.Y;
            if (s && s.ee === 1) {
              s.ee = t3.ee = 0;
              if (i === this.rr)
                return;
              i.ee = 1;
              e = i;
              continue;
            } else if (e === t3.Y) {
              e.ee = 0;
              if (e.Y)
                e.Y.tt = i;
              if (e.Z)
                e.Z.tt = t3;
              i.Z = e.Y;
              t3.Y = e.Z;
              e.Y = i;
              e.Z = t3;
              if (i === this.rr) {
                this.rr = e;
                this.h.tt = e;
              } else {
                const t4 = i.tt;
                if (t4.Y === i) {
                  t4.Y = e;
                } else
                  t4.Z = e;
              }
              e.tt = i.tt;
              t3.tt = e;
              i.tt = e;
              i.ee = 1;
              return {
                parentNode: t3,
                grandParent: i,
                curNode: e
              };
            } else {
              t3.ee = 0;
              if (i === this.rr) {
                this.rr = i.te();
              } else
                i.te();
              i.ee = 1;
            }
          }
          return;
        }
      }
      ne(e, t3, i) {
        if (this.rr === void 0) {
          this.i += 1;
          this.rr = new this.re(e, t3);
          this.rr.ee = 0;
          this.rr.tt = this.h;
          this.h.tt = this.rr;
          this.h.Y = this.rr;
          this.h.Z = this.rr;
          return;
        }
        let s;
        const r = this.h.Y;
        const n = this.v(r.u, e);
        if (n === 0) {
          r.l = t3;
          return;
        } else if (n > 0) {
          r.Y = new this.re(e, t3);
          r.Y.tt = r;
          s = r.Y;
          this.h.Y = s;
        } else {
          const r2 = this.h.Z;
          const n2 = this.v(r2.u, e);
          if (n2 === 0) {
            r2.l = t3;
            return;
          } else if (n2 < 0) {
            r2.Z = new this.re(e, t3);
            r2.Z.tt = r2;
            s = r2.Z;
            this.h.Z = s;
          } else {
            if (i !== void 0) {
              const r3 = i.o;
              if (r3 !== this.h) {
                const i2 = this.v(r3.u, e);
                if (i2 === 0) {
                  r3.l = t3;
                  return;
                } else if (i2 > 0) {
                  const i3 = r3.L();
                  const n3 = this.v(i3.u, e);
                  if (n3 === 0) {
                    i3.l = t3;
                    return;
                  } else if (n3 < 0) {
                    s = new this.re(e, t3);
                    if (i3.Z === void 0) {
                      i3.Z = s;
                      s.tt = i3;
                    } else {
                      r3.Y = s;
                      s.tt = r3;
                    }
                  }
                }
              }
            }
            if (s === void 0) {
              s = this.rr;
              while (true) {
                const i2 = this.v(s.u, e);
                if (i2 > 0) {
                  if (s.Y === void 0) {
                    s.Y = new this.re(e, t3);
                    s.Y.tt = s;
                    s = s.Y;
                    break;
                  }
                  s = s.Y;
                } else if (i2 < 0) {
                  if (s.Z === void 0) {
                    s.Z = new this.re(e, t3);
                    s.Z.tt = s;
                    s = s.Z;
                    break;
                  }
                  s = s.Z;
                } else {
                  s.l = t3;
                  return;
                }
              }
            }
          }
        }
        this.i += 1;
        return s;
      }
      I(e, t3) {
        while (e) {
          const i = this.v(e.u, t3);
          if (i < 0) {
            e = e.Z;
          } else if (i > 0) {
            e = e.Y;
          } else
            return e;
        }
        return e || this.h;
      }
      clear() {
        this.i = 0;
        this.rr = void 0;
        this.h.tt = void 0;
        this.h.Y = this.h.Z = void 0;
      }
      updateKeyByIterator(e, t3) {
        const i = e.o;
        if (i === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        if (this.i === 1) {
          i.u = t3;
          return true;
        }
        if (i === this.h.Y) {
          if (this.v(i.B().u, t3) > 0) {
            i.u = t3;
            return true;
          }
          return false;
        }
        if (i === this.h.Z) {
          if (this.v(i.L().u, t3) < 0) {
            i.u = t3;
            return true;
          }
          return false;
        }
        const s = i.L().u;
        if (this.v(s, t3) >= 0)
          return false;
        const r = i.B().u;
        if (this.v(r, t3) <= 0)
          return false;
        i.u = t3;
        return true;
      }
      eraseElementByPos(e) {
        if (e < 0 || e > this.i - 1) {
          throw new RangeError();
        }
        let t3 = 0;
        const i = this;
        this.oe(this.rr, function(s) {
          if (e === t3) {
            i.K(s);
            return true;
          }
          t3 += 1;
          return false;
        });
        return this.i;
      }
      eraseElementByKey(e) {
        if (this.i === 0)
          return false;
        const t3 = this.I(this.rr, e);
        if (t3 === this.h)
          return false;
        this.K(t3);
        return true;
      }
      eraseElementByIterator(e) {
        const t3 = e.o;
        if (t3 === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        const i = t3.Z === void 0;
        const s = e.iteratorType === 0;
        if (s) {
          if (i)
            e.next();
        } else {
          if (!i || t3.Y === void 0)
            e.next();
        }
        this.K(t3);
        return e;
      }
      forEach(e) {
        let t3 = 0;
        for (const i of this)
          e(i, t3++, this);
      }
      getElementByPos(e) {
        if (e < 0 || e > this.i - 1) {
          throw new RangeError();
        }
        let t3;
        let i = 0;
        for (const s of this) {
          if (i === e) {
            t3 = s;
            break;
          }
          i += 1;
        }
        return t3;
      }
      getHeight() {
        if (this.i === 0)
          return 0;
        const traversal = function(e) {
          if (!e)
            return 0;
          return Math.max(traversal(e.Y), traversal(e.Z)) + 1;
        };
        return traversal(this.rr);
      }
    };
    var _default = TreeContainer;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/TreeIterator.js
var require_TreeIterator = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/TreeContainer/Base/TreeIterator.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _ContainerBase = require_ContainerBase();
    var _throwError = require_throwError2();
    var TreeIterator = class extends _ContainerBase.ContainerIterator {
      constructor(t3, r, i) {
        super(i);
        this.o = t3;
        this.h = r;
        if (this.iteratorType === 0) {
          this.pre = function() {
            if (this.o === this.h.Y) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L();
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B();
            return this;
          };
        } else {
          this.pre = function() {
            if (this.o === this.h.Z) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B();
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L();
            return this;
          };
        }
      }
      get index() {
        let t3 = this.o;
        const r = this.h.tt;
        if (t3 === this.h) {
          if (r) {
            return r.rt - 1;
          }
          return 0;
        }
        let i = 0;
        if (t3.Y) {
          i += t3.Y.rt;
        }
        while (t3 !== r) {
          const r2 = t3.tt;
          if (t3 === r2.Z) {
            i += 1;
            if (r2.Y) {
              i += r2.Y.rt;
            }
          }
          t3 = r2;
        }
        return i;
      }
    };
    var _default = TreeIterator;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/TreeContainer/OrderedSet.js
var require_OrderedSet = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/TreeContainer/OrderedSet.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require_Base2());
    var _TreeIterator = _interopRequireDefault(require_TreeIterator());
    var _throwError = require_throwError2();
    function _interopRequireDefault(e) {
      return e && e.t ? e : {
        default: e
      };
    }
    var OrderedSetIterator = class _OrderedSetIterator extends _TreeIterator.default {
      get pointer() {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        return this.o.u;
      }
      copy() {
        return new _OrderedSetIterator(this.o, this.h, this.iteratorType);
      }
    };
    var OrderedSet = class extends _Base.default {
      constructor(e = [], r, t3) {
        super(r, t3);
        const i = this;
        e.forEach(function(e2) {
          i.insert(e2);
        });
      }
      *X(e) {
        if (e === void 0)
          return;
        yield* this.X(e.Y);
        yield e.u;
        yield* this.X(e.Z);
      }
      begin() {
        return new OrderedSetIterator(this.h.Y || this.h, this.h);
      }
      end() {
        return new OrderedSetIterator(this.h, this.h);
      }
      rBegin() {
        return new OrderedSetIterator(this.h.Z || this.h, this.h, 1);
      }
      rEnd() {
        return new OrderedSetIterator(this.h, this.h, 1);
      }
      front() {
        return this.h.Y ? this.h.Y.u : void 0;
      }
      back() {
        return this.h.Z ? this.h.Z.u : void 0;
      }
      insert(e, r) {
        return this.M(e, void 0, r);
      }
      find(e) {
        const r = this.I(this.rr, e);
        return new OrderedSetIterator(r, this.h);
      }
      lowerBound(e) {
        const r = this.$(this.rr, e);
        return new OrderedSetIterator(r, this.h);
      }
      upperBound(e) {
        const r = this.er(this.rr, e);
        return new OrderedSetIterator(r, this.h);
      }
      reverseLowerBound(e) {
        const r = this.tr(this.rr, e);
        return new OrderedSetIterator(r, this.h);
      }
      reverseUpperBound(e) {
        const r = this.sr(this.rr, e);
        return new OrderedSetIterator(r, this.h);
      }
      union(e) {
        const r = this;
        e.forEach(function(e2) {
          r.insert(e2);
        });
        return this.i;
      }
      [Symbol.iterator]() {
        return this.X(this.rr);
      }
    };
    var _default = OrderedSet;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/TreeContainer/OrderedMap.js
var require_OrderedMap = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/TreeContainer/OrderedMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = _interopRequireDefault(require_Base2());
    var _TreeIterator = _interopRequireDefault(require_TreeIterator());
    var _throwError = require_throwError2();
    function _interopRequireDefault(r) {
      return r && r.t ? r : {
        default: r
      };
    }
    var OrderedMapIterator = class _OrderedMapIterator extends _TreeIterator.default {
      get pointer() {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        const r = this;
        return new Proxy([], {
          get(e, t3) {
            if (t3 === "0")
              return r.o.u;
            else if (t3 === "1")
              return r.o.l;
          },
          set(e, t3, s) {
            if (t3 !== "1") {
              throw new TypeError("props must be 1");
            }
            r.o.l = s;
            return true;
          }
        });
      }
      copy() {
        return new _OrderedMapIterator(this.o, this.h, this.iteratorType);
      }
    };
    var OrderedMap = class extends _Base.default {
      constructor(r = [], e, t3) {
        super(e, t3);
        const s = this;
        r.forEach(function(r2) {
          s.setElement(r2[0], r2[1]);
        });
      }
      *X(r) {
        if (r === void 0)
          return;
        yield* this.X(r.Y);
        yield [r.u, r.l];
        yield* this.X(r.Z);
      }
      begin() {
        return new OrderedMapIterator(this.h.Y || this.h, this.h);
      }
      end() {
        return new OrderedMapIterator(this.h, this.h);
      }
      rBegin() {
        return new OrderedMapIterator(this.h.Z || this.h, this.h, 1);
      }
      rEnd() {
        return new OrderedMapIterator(this.h, this.h, 1);
      }
      front() {
        if (this.i === 0)
          return;
        const r = this.h.Y;
        return [r.u, r.l];
      }
      back() {
        if (this.i === 0)
          return;
        const r = this.h.Z;
        return [r.u, r.l];
      }
      lowerBound(r) {
        const e = this.$(this.rr, r);
        return new OrderedMapIterator(e, this.h);
      }
      upperBound(r) {
        const e = this.er(this.rr, r);
        return new OrderedMapIterator(e, this.h);
      }
      reverseLowerBound(r) {
        const e = this.tr(this.rr, r);
        return new OrderedMapIterator(e, this.h);
      }
      reverseUpperBound(r) {
        const e = this.sr(this.rr, r);
        return new OrderedMapIterator(e, this.h);
      }
      setElement(r, e, t3) {
        return this.M(r, e, t3);
      }
      find(r) {
        const e = this.I(this.rr, r);
        return new OrderedMapIterator(e, this.h);
      }
      getElementByKey(r) {
        const e = this.I(this.rr, r);
        return e.l;
      }
      union(r) {
        const e = this;
        r.forEach(function(r2) {
          e.setElement(r2[0], r2[1]);
        });
        return this.i;
      }
      [Symbol.iterator]() {
        return this.X(this.rr);
      }
    };
    var _default = OrderedMap;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/utils/checkObject.js
var require_checkObject = __commonJS({
  "node_modules/js-sdsl/dist/cjs/utils/checkObject.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = checkObject;
    function checkObject(e) {
      const t3 = typeof e;
      return t3 === "object" && e !== null || t3 === "function";
    }
  }
});

// node_modules/js-sdsl/dist/cjs/container/HashContainer/Base/index.js
var require_Base3 = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/HashContainer/Base/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.HashContainerIterator = exports.HashContainer = void 0;
    var _ContainerBase = require_ContainerBase();
    var _checkObject = _interopRequireDefault(require_checkObject());
    var _throwError = require_throwError2();
    function _interopRequireDefault(t3) {
      return t3 && t3.t ? t3 : {
        default: t3
      };
    }
    var HashContainerIterator = class extends _ContainerBase.ContainerIterator {
      constructor(t3, e, i) {
        super(i);
        this.o = t3;
        this.h = e;
        if (this.iteratorType === 0) {
          this.pre = function() {
            if (this.o.L === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L;
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B;
            return this;
          };
        } else {
          this.pre = function() {
            if (this.o.B === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.B;
            return this;
          };
          this.next = function() {
            if (this.o === this.h) {
              (0, _throwError.throwIteratorAccessError)();
            }
            this.o = this.o.L;
            return this;
          };
        }
      }
    };
    exports.HashContainerIterator = HashContainerIterator;
    var HashContainer = class extends _ContainerBase.Container {
      constructor() {
        super();
        this.H = [];
        this.g = {};
        this.HASH_TAG = Symbol("@@HASH_TAG");
        Object.setPrototypeOf(this.g, null);
        this.h = {};
        this.h.L = this.h.B = this.p = this._ = this.h;
      }
      K(t3) {
        const { L: e, B: i } = t3;
        e.B = i;
        i.L = e;
        if (t3 === this.p) {
          this.p = i;
        }
        if (t3 === this._) {
          this._ = e;
        }
        this.i -= 1;
      }
      M(t3, e, i) {
        if (i === void 0)
          i = (0, _checkObject.default)(t3);
        let s;
        if (i) {
          const i2 = t3[this.HASH_TAG];
          if (i2 !== void 0) {
            this.H[i2].l = e;
            return this.i;
          }
          Object.defineProperty(t3, this.HASH_TAG, {
            value: this.H.length,
            configurable: true
          });
          s = {
            u: t3,
            l: e,
            L: this._,
            B: this.h
          };
          this.H.push(s);
        } else {
          const i2 = this.g[t3];
          if (i2) {
            i2.l = e;
            return this.i;
          }
          s = {
            u: t3,
            l: e,
            L: this._,
            B: this.h
          };
          this.g[t3] = s;
        }
        if (this.i === 0) {
          this.p = s;
          this.h.B = s;
        } else {
          this._.B = s;
        }
        this._ = s;
        this.h.L = s;
        return ++this.i;
      }
      I(t3, e) {
        if (e === void 0)
          e = (0, _checkObject.default)(t3);
        if (e) {
          const e2 = t3[this.HASH_TAG];
          if (e2 === void 0)
            return this.h;
          return this.H[e2];
        } else {
          return this.g[t3] || this.h;
        }
      }
      clear() {
        const t3 = this.HASH_TAG;
        this.H.forEach(function(e) {
          delete e.u[t3];
        });
        this.H = [];
        this.g = {};
        Object.setPrototypeOf(this.g, null);
        this.i = 0;
        this.p = this._ = this.h.L = this.h.B = this.h;
      }
      eraseElementByKey(t3, e) {
        let i;
        if (e === void 0)
          e = (0, _checkObject.default)(t3);
        if (e) {
          const e2 = t3[this.HASH_TAG];
          if (e2 === void 0)
            return false;
          delete t3[this.HASH_TAG];
          i = this.H[e2];
          delete this.H[e2];
        } else {
          i = this.g[t3];
          if (i === void 0)
            return false;
          delete this.g[t3];
        }
        this.K(i);
        return true;
      }
      eraseElementByIterator(t3) {
        const e = t3.o;
        if (e === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        this.K(e);
        return t3.next();
      }
      eraseElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let e = this.p;
        while (t3--) {
          e = e.B;
        }
        this.K(e);
        return this.i;
      }
    };
    exports.HashContainer = HashContainer;
  }
});

// node_modules/js-sdsl/dist/cjs/container/HashContainer/HashSet.js
var require_HashSet = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/HashContainer/HashSet.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = require_Base3();
    var _throwError = require_throwError2();
    var HashSetIterator = class _HashSetIterator extends _Base.HashContainerIterator {
      get pointer() {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        return this.o.u;
      }
      copy() {
        return new _HashSetIterator(this.o, this.h, this.iteratorType);
      }
    };
    var HashSet = class extends _Base.HashContainer {
      constructor(t3 = []) {
        super();
        const e = this;
        t3.forEach(function(t4) {
          e.insert(t4);
        });
      }
      begin() {
        return new HashSetIterator(this.p, this.h);
      }
      end() {
        return new HashSetIterator(this.h, this.h);
      }
      rBegin() {
        return new HashSetIterator(this._, this.h, 1);
      }
      rEnd() {
        return new HashSetIterator(this.h, this.h, 1);
      }
      front() {
        return this.p.u;
      }
      back() {
        return this._.u;
      }
      insert(t3, e) {
        return this.M(t3, void 0, e);
      }
      getElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let e = this.p;
        while (t3--) {
          e = e.B;
        }
        return e.u;
      }
      find(t3, e) {
        const r = this.I(t3, e);
        return new HashSetIterator(r, this.h);
      }
      forEach(t3) {
        let e = 0;
        let r = this.p;
        while (r !== this.h) {
          t3(r.u, e++, this);
          r = r.B;
        }
      }
      [Symbol.iterator]() {
        return function* () {
          let t3 = this.p;
          while (t3 !== this.h) {
            yield t3.u;
            t3 = t3.B;
          }
        }.bind(this)();
      }
    };
    var _default = HashSet;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/container/HashContainer/HashMap.js
var require_HashMap = __commonJS({
  "node_modules/js-sdsl/dist/cjs/container/HashContainer/HashMap.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    exports.default = void 0;
    var _Base = require_Base3();
    var _checkObject = _interopRequireDefault(require_checkObject());
    var _throwError = require_throwError2();
    function _interopRequireDefault(t3) {
      return t3 && t3.t ? t3 : {
        default: t3
      };
    }
    var HashMapIterator = class _HashMapIterator extends _Base.HashContainerIterator {
      get pointer() {
        if (this.o === this.h) {
          (0, _throwError.throwIteratorAccessError)();
        }
        const t3 = this;
        return new Proxy([], {
          get(e, r) {
            if (r === "0")
              return t3.o.u;
            else if (r === "1")
              return t3.o.l;
          },
          set(e, r, s) {
            if (r !== "1") {
              throw new TypeError("props must be 1");
            }
            t3.o.l = s;
            return true;
          }
        });
      }
      copy() {
        return new _HashMapIterator(this.o, this.h, this.iteratorType);
      }
    };
    var HashMap = class extends _Base.HashContainer {
      constructor(t3 = []) {
        super();
        const e = this;
        t3.forEach(function(t4) {
          e.setElement(t4[0], t4[1]);
        });
      }
      begin() {
        return new HashMapIterator(this.p, this.h);
      }
      end() {
        return new HashMapIterator(this.h, this.h);
      }
      rBegin() {
        return new HashMapIterator(this._, this.h, 1);
      }
      rEnd() {
        return new HashMapIterator(this.h, this.h, 1);
      }
      front() {
        if (this.i === 0)
          return;
        return [this.p.u, this.p.l];
      }
      back() {
        if (this.i === 0)
          return;
        return [this._.u, this._.l];
      }
      setElement(t3, e, r) {
        return this.M(t3, e, r);
      }
      getElementByKey(t3, e) {
        if (e === void 0)
          e = (0, _checkObject.default)(t3);
        if (e) {
          const e2 = t3[this.HASH_TAG];
          return e2 !== void 0 ? this.H[e2].l : void 0;
        }
        const r = this.g[t3];
        return r ? r.l : void 0;
      }
      getElementByPos(t3) {
        if (t3 < 0 || t3 > this.i - 1) {
          throw new RangeError();
        }
        let e = this.p;
        while (t3--) {
          e = e.B;
        }
        return [e.u, e.l];
      }
      find(t3, e) {
        const r = this.I(t3, e);
        return new HashMapIterator(r, this.h);
      }
      forEach(t3) {
        let e = 0;
        let r = this.p;
        while (r !== this.h) {
          t3([r.u, r.l], e++, this);
          r = r.B;
        }
      }
      [Symbol.iterator]() {
        return function* () {
          let t3 = this.p;
          while (t3 !== this.h) {
            yield [t3.u, t3.l];
            t3 = t3.B;
          }
        }.bind(this)();
      }
    };
    var _default = HashMap;
    exports.default = _default;
  }
});

// node_modules/js-sdsl/dist/cjs/index.js
var require_cjs2 = __commonJS({
  "node_modules/js-sdsl/dist/cjs/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "t", {
      value: true
    });
    Object.defineProperty(exports, "Deque", {
      enumerable: true,
      get: function() {
        return _Deque.default;
      }
    });
    Object.defineProperty(exports, "HashMap", {
      enumerable: true,
      get: function() {
        return _HashMap.default;
      }
    });
    Object.defineProperty(exports, "HashSet", {
      enumerable: true,
      get: function() {
        return _HashSet.default;
      }
    });
    Object.defineProperty(exports, "LinkList", {
      enumerable: true,
      get: function() {
        return _LinkList.default;
      }
    });
    Object.defineProperty(exports, "OrderedMap", {
      enumerable: true,
      get: function() {
        return _OrderedMap.default;
      }
    });
    Object.defineProperty(exports, "OrderedSet", {
      enumerable: true,
      get: function() {
        return _OrderedSet.default;
      }
    });
    Object.defineProperty(exports, "PriorityQueue", {
      enumerable: true,
      get: function() {
        return _PriorityQueue.default;
      }
    });
    Object.defineProperty(exports, "Queue", {
      enumerable: true,
      get: function() {
        return _Queue.default;
      }
    });
    Object.defineProperty(exports, "Stack", {
      enumerable: true,
      get: function() {
        return _Stack.default;
      }
    });
    Object.defineProperty(exports, "Vector", {
      enumerable: true,
      get: function() {
        return _Vector.default;
      }
    });
    var _Stack = _interopRequireDefault(require_Stack2());
    var _Queue = _interopRequireDefault(require_Queue());
    var _PriorityQueue = _interopRequireDefault(require_PriorityQueue());
    var _Vector = _interopRequireDefault(require_Vector());
    var _LinkList = _interopRequireDefault(require_LinkList());
    var _Deque = _interopRequireDefault(require_Deque());
    var _OrderedSet = _interopRequireDefault(require_OrderedSet());
    var _OrderedMap = _interopRequireDefault(require_OrderedMap());
    var _HashSet = _interopRequireDefault(require_HashSet());
    var _HashMap = _interopRequireDefault(require_HashMap());
    function _interopRequireDefault(e) {
      return e && e.t ? e : {
        default: e
      };
    }
  }
});

// node_modules/eslint/lib/rules/indent.js
var require_indent = __commonJS({
  "node_modules/eslint/lib/rules/indent.js"(exports, module2) {
    "use strict";
    var { OrderedMap } = require_cjs2();
    var astUtils = require_ast_utils2();
    var KNOWN_NODES = /* @__PURE__ */ new Set([
      "AssignmentExpression",
      "AssignmentPattern",
      "ArrayExpression",
      "ArrayPattern",
      "ArrowFunctionExpression",
      "AwaitExpression",
      "BlockStatement",
      "BinaryExpression",
      "BreakStatement",
      "CallExpression",
      "CatchClause",
      "ChainExpression",
      "ClassBody",
      "ClassDeclaration",
      "ClassExpression",
      "ConditionalExpression",
      "ContinueStatement",
      "DoWhileStatement",
      "DebuggerStatement",
      "EmptyStatement",
      "ExperimentalRestProperty",
      "ExperimentalSpreadProperty",
      "ExpressionStatement",
      "ForStatement",
      "ForInStatement",
      "ForOfStatement",
      "FunctionDeclaration",
      "FunctionExpression",
      "Identifier",
      "IfStatement",
      "Literal",
      "LabeledStatement",
      "LogicalExpression",
      "MemberExpression",
      "MetaProperty",
      "MethodDefinition",
      "NewExpression",
      "ObjectExpression",
      "ObjectPattern",
      "PrivateIdentifier",
      "Program",
      "Property",
      "PropertyDefinition",
      "RestElement",
      "ReturnStatement",
      "SequenceExpression",
      "SpreadElement",
      "StaticBlock",
      "Super",
      "SwitchCase",
      "SwitchStatement",
      "TaggedTemplateExpression",
      "TemplateElement",
      "TemplateLiteral",
      "ThisExpression",
      "ThrowStatement",
      "TryStatement",
      "UnaryExpression",
      "UpdateExpression",
      "VariableDeclaration",
      "VariableDeclarator",
      "WhileStatement",
      "WithStatement",
      "YieldExpression",
      "JSXFragment",
      "JSXOpeningFragment",
      "JSXClosingFragment",
      "JSXIdentifier",
      "JSXNamespacedName",
      "JSXMemberExpression",
      "JSXEmptyExpression",
      "JSXExpressionContainer",
      "JSXElement",
      "JSXClosingElement",
      "JSXOpeningElement",
      "JSXAttribute",
      "JSXSpreadAttribute",
      "JSXText",
      "ExportDefaultDeclaration",
      "ExportNamedDeclaration",
      "ExportAllDeclaration",
      "ExportSpecifier",
      "ImportDeclaration",
      "ImportSpecifier",
      "ImportDefaultSpecifier",
      "ImportNamespaceSpecifier",
      "ImportExpression"
    ]);
    var BinarySearchTree = class {
      /**
       * Creates an empty tree
       */
      constructor() {
        this._orderedMap = new OrderedMap();
        this._orderedMapEnd = this._orderedMap.end();
      }
      /**
       * Inserts an entry into the tree.
       * @param {number} key The entry's key
       * @param {any} value The entry's value
       * @returns {void}
       */
      insert(key, value2) {
        this._orderedMap.setElement(key, value2);
      }
      /**
       * Finds the entry with the largest key less than or equal to the provided key
       * @param {number} key The provided key
       * @returns {{key: number, value: *}|null} The found entry, or null if no such entry exists.
       */
      findLe(key) {
        const iterator = this._orderedMap.reverseLowerBound(key);
        if (iterator.equals(this._orderedMapEnd)) {
          return {};
        }
        return { key: iterator.pointer[0], value: iterator.pointer[1] };
      }
      /**
       * Deletes all of the keys in the interval [start, end)
       * @param {number} start The start of the range
       * @param {number} end The end of the range
       * @returns {void}
       */
      deleteRange(start, end) {
        if (start === end) {
          return;
        }
        const iterator = this._orderedMap.lowerBound(start);
        if (iterator.equals(this._orderedMapEnd)) {
          return;
        }
        if (end > this._orderedMap.back()[0]) {
          while (!iterator.equals(this._orderedMapEnd)) {
            this._orderedMap.eraseElementByIterator(iterator);
          }
        } else {
          while (iterator.pointer[0] < end) {
            this._orderedMap.eraseElementByIterator(iterator);
          }
        }
      }
    };
    var TokenInfo = class {
      /**
       * @param {SourceCode} sourceCode A SourceCode object
       */
      constructor(sourceCode) {
        this.sourceCode = sourceCode;
        this.firstTokensByLineNumber = sourceCode.tokensAndComments.reduce((map, token) => {
          if (!map.has(token.loc.start.line)) {
            map.set(token.loc.start.line, token);
          }
          if (!map.has(token.loc.end.line) && sourceCode.text.slice(token.range[1] - token.loc.end.column, token.range[1]).trim()) {
            map.set(token.loc.end.line, token);
          }
          return map;
        }, /* @__PURE__ */ new Map());
      }
      /**
       * Gets the first token on a given token's line
       * @param {Token|ASTNode} token a node or token
       * @returns {Token} The first token on the given line
       */
      getFirstTokenOfLine(token) {
        return this.firstTokensByLineNumber.get(token.loc.start.line);
      }
      /**
       * Determines whether a token is the first token in its line
       * @param {Token} token The token
       * @returns {boolean} `true` if the token is the first on its line
       */
      isFirstTokenOfLine(token) {
        return this.getFirstTokenOfLine(token) === token;
      }
      /**
       * Get the actual indent of a token
       * @param {Token} token Token to examine. This should be the first token on its line.
       * @returns {string} The indentation characters that precede the token
       */
      getTokenIndent(token) {
        return this.sourceCode.text.slice(token.range[0] - token.loc.start.column, token.range[0]);
      }
    };
    var OffsetStorage = class {
      /**
       * @param {TokenInfo} tokenInfo a TokenInfo instance
       * @param {number} indentSize The desired size of each indentation level
       * @param {string} indentType The indentation character
       */
      constructor(tokenInfo, indentSize, indentType) {
        this._tokenInfo = tokenInfo;
        this._indentSize = indentSize;
        this._indentType = indentType;
        this._tree = new BinarySearchTree();
        this._tree.insert(0, { offset: 0, from: null, force: false });
        this._lockedFirstTokens = /* @__PURE__ */ new WeakMap();
        this._desiredIndentCache = /* @__PURE__ */ new WeakMap();
        this._ignoredTokens = /* @__PURE__ */ new WeakSet();
      }
      _getOffsetDescriptor(token) {
        return this._tree.findLe(token.range[0]).value;
      }
      /**
       * Sets the offset column of token B to match the offset column of token A.
       * - **WARNING**: This matches a *column*, even if baseToken is not the first token on its line. In
       * most cases, `setDesiredOffset` should be used instead.
       * @param {Token} baseToken The first token
       * @param {Token} offsetToken The second token, whose offset should be matched to the first token
       * @returns {void}
       */
      matchOffsetOf(baseToken, offsetToken) {
        this._lockedFirstTokens.set(offsetToken, baseToken);
      }
      /**
       * Sets the desired offset of a token.
       *
       * This uses a line-based offset collapsing behavior to handle tokens on the same line.
       * For example, consider the following two cases:
       *
       * (
       *     [
       *         bar
       *     ]
       * )
       *
       * ([
       *     bar
       * ])
       *
       * Based on the first case, it's clear that the `bar` token needs to have an offset of 1 indent level (4 spaces) from
       * the `[` token, and the `[` token has to have an offset of 1 indent level from the `(` token. Since the `(` token is
       * the first on its line (with an indent of 0 spaces), the `bar` token needs to be offset by 2 indent levels (8 spaces)
       * from the start of its line.
       *
       * However, in the second case `bar` should only be indented by 4 spaces. This is because the offset of 1 indent level
       * between the `(` and the `[` tokens gets "collapsed" because the two tokens are on the same line. As a result, the
       * `(` token is mapped to the `[` token with an offset of 0, and the rule correctly decides that `bar` should be indented
       * by 1 indent level from the start of the line.
       *
       * This is useful because rule listeners can usually just call `setDesiredOffset` for all the tokens in the node,
       * without needing to check which lines those tokens are on.
       *
       * Note that since collapsing only occurs when two tokens are on the same line, there are a few cases where non-intuitive
       * behavior can occur. For example, consider the following cases:
       *
       * foo(
       * ).
       *     bar(
       *         baz
       *     )
       *
       * foo(
       * ).bar(
       *     baz
       * )
       *
       * Based on the first example, it would seem that `bar` should be offset by 1 indent level from `foo`, and `baz`
       * should be offset by 1 indent level from `bar`. However, this is not correct, because it would result in `baz`
       * being indented by 2 indent levels in the second case (since `foo`, `bar`, and `baz` are all on separate lines, no
       * collapsing would occur).
       *
       * Instead, the correct way would be to offset `baz` by 1 level from `bar`, offset `bar` by 1 level from the `)`, and
       * offset the `)` by 0 levels from `foo`. This ensures that the offset between `bar` and the `)` are correctly collapsed
       * in the second case.
       * @param {Token} token The token
       * @param {Token} fromToken The token that `token` should be offset from
       * @param {number} offset The desired indent level
       * @returns {void}
       */
      setDesiredOffset(token, fromToken, offset) {
        return this.setDesiredOffsets(token.range, fromToken, offset);
      }
      /**
       * Sets the desired offset of all tokens in a range
       * It's common for node listeners in this file to need to apply the same offset to a large, contiguous range of tokens.
       * Moreover, the offset of any given token is usually updated multiple times (roughly once for each node that contains
       * it). This means that the offset of each token is updated O(AST depth) times.
       * It would not be performant to store and update the offsets for each token independently, because the rule would end
       * up having a time complexity of O(number of tokens * AST depth), which is quite slow for large files.
       *
       * Instead, the offset tree is represented as a collection of contiguous offset ranges in a file. For example, the following
       * list could represent the state of the offset tree at a given point:
       *
       * - Tokens starting in the interval [0, 15) are aligned with the beginning of the file
       * - Tokens starting in the interval [15, 30) are offset by 1 indent level from the `bar` token
       * - Tokens starting in the interval [30, 43) are offset by 1 indent level from the `foo` token
       * - Tokens starting in the interval [43, 820) are offset by 2 indent levels from the `bar` token
       * - Tokens starting in the interval [820, ∞) are offset by 1 indent level from the `baz` token
       *
       * The `setDesiredOffsets` methods inserts ranges like the ones above. The third line above would be inserted by using:
       * `setDesiredOffsets([30, 43], fooToken, 1);`
       * @param {[number, number]} range A [start, end] pair. All tokens with range[0] <= token.start < range[1] will have the offset applied.
       * @param {Token} fromToken The token that this is offset from
       * @param {number} offset The desired indent level
       * @param {boolean} force `true` if this offset should not use the normal collapsing behavior. This should almost always be false.
       * @returns {void}
       */
      setDesiredOffsets(range, fromToken, offset, force) {
        const descriptorToInsert = { offset, from: fromToken, force };
        const descriptorAfterRange = this._tree.findLe(range[1]).value;
        const fromTokenIsInRange = fromToken && fromToken.range[0] >= range[0] && fromToken.range[1] <= range[1];
        const fromTokenDescriptor = fromTokenIsInRange && this._getOffsetDescriptor(fromToken);
        this._tree.deleteRange(range[0] + 1, range[1]);
        this._tree.insert(range[0], descriptorToInsert);
        if (fromTokenIsInRange) {
          this._tree.insert(fromToken.range[0], fromTokenDescriptor);
          this._tree.insert(fromToken.range[1], descriptorToInsert);
        }
        this._tree.insert(range[1], descriptorAfterRange);
      }
      /**
       * Gets the desired indent of a token
       * @param {Token} token The token
       * @returns {string} The desired indent of the token
       */
      getDesiredIndent(token) {
        if (!this._desiredIndentCache.has(token)) {
          if (this._ignoredTokens.has(token)) {
            this._desiredIndentCache.set(
              token,
              this._tokenInfo.getTokenIndent(token)
            );
          } else if (this._lockedFirstTokens.has(token)) {
            const firstToken = this._lockedFirstTokens.get(token);
            this._desiredIndentCache.set(
              token,
              // (indentation for the first element's line)
              this.getDesiredIndent(this._tokenInfo.getFirstTokenOfLine(firstToken)) + // (space between the start of the first element's line and the first element)
              this._indentType.repeat(firstToken.loc.start.column - this._tokenInfo.getFirstTokenOfLine(firstToken).loc.start.column)
            );
          } else {
            const offsetInfo = this._getOffsetDescriptor(token);
            const offset = offsetInfo.from && offsetInfo.from.loc.start.line === token.loc.start.line && !/^\s*?\n/u.test(token.value) && !offsetInfo.force ? 0 : offsetInfo.offset * this._indentSize;
            this._desiredIndentCache.set(
              token,
              (offsetInfo.from ? this.getDesiredIndent(offsetInfo.from) : "") + this._indentType.repeat(offset)
            );
          }
        }
        return this._desiredIndentCache.get(token);
      }
      /**
       * Ignores a token, preventing it from being reported.
       * @param {Token} token The token
       * @returns {void}
       */
      ignoreToken(token) {
        if (this._tokenInfo.isFirstTokenOfLine(token)) {
          this._ignoredTokens.add(token);
        }
      }
      /**
       * Gets the first token that the given token's indentation is dependent on
       * @param {Token} token The token
       * @returns {Token} The token that the given token depends on, or `null` if the given token is at the top level
       */
      getFirstDependency(token) {
        return this._getOffsetDescriptor(token).from;
      }
    };
    var ELEMENT_LIST_SCHEMA = {
      oneOf: [
        {
          type: "integer",
          minimum: 0
        },
        {
          enum: ["first", "off"]
        }
      ]
    };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent indentation",
          recommended: false,
          url: "https://eslint.org/docs/rules/indent"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["tab"]
              },
              {
                type: "integer",
                minimum: 0
              }
            ]
          },
          {
            type: "object",
            properties: {
              SwitchCase: {
                type: "integer",
                minimum: 0,
                default: 0
              },
              VariableDeclarator: {
                oneOf: [
                  ELEMENT_LIST_SCHEMA,
                  {
                    type: "object",
                    properties: {
                      var: ELEMENT_LIST_SCHEMA,
                      let: ELEMENT_LIST_SCHEMA,
                      const: ELEMENT_LIST_SCHEMA
                    },
                    additionalProperties: false
                  }
                ]
              },
              outerIIFEBody: {
                oneOf: [
                  {
                    type: "integer",
                    minimum: 0
                  },
                  {
                    enum: ["off"]
                  }
                ]
              },
              MemberExpression: {
                oneOf: [
                  {
                    type: "integer",
                    minimum: 0
                  },
                  {
                    enum: ["off"]
                  }
                ]
              },
              FunctionDeclaration: {
                type: "object",
                properties: {
                  parameters: ELEMENT_LIST_SCHEMA,
                  body: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              },
              FunctionExpression: {
                type: "object",
                properties: {
                  parameters: ELEMENT_LIST_SCHEMA,
                  body: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              },
              StaticBlock: {
                type: "object",
                properties: {
                  body: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              },
              CallExpression: {
                type: "object",
                properties: {
                  arguments: ELEMENT_LIST_SCHEMA
                },
                additionalProperties: false
              },
              ArrayExpression: ELEMENT_LIST_SCHEMA,
              ObjectExpression: ELEMENT_LIST_SCHEMA,
              ImportDeclaration: ELEMENT_LIST_SCHEMA,
              flatTernaryExpressions: {
                type: "boolean",
                default: false
              },
              offsetTernaryExpressions: {
                type: "boolean",
                default: false
              },
              ignoredNodes: {
                type: "array",
                items: {
                  type: "string",
                  not: {
                    pattern: ":exit$"
                  }
                }
              },
              ignoreComments: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          wrongIndentation: "Expected indentation of {{expected}} but found {{actual}}."
        }
      },
      create(context) {
        const DEFAULT_VARIABLE_INDENT = 1;
        const DEFAULT_PARAMETER_INDENT = 1;
        const DEFAULT_FUNCTION_BODY_INDENT = 1;
        let indentType = "space";
        let indentSize = 4;
        const options = {
          SwitchCase: 0,
          VariableDeclarator: {
            var: DEFAULT_VARIABLE_INDENT,
            let: DEFAULT_VARIABLE_INDENT,
            const: DEFAULT_VARIABLE_INDENT
          },
          outerIIFEBody: 1,
          FunctionDeclaration: {
            parameters: DEFAULT_PARAMETER_INDENT,
            body: DEFAULT_FUNCTION_BODY_INDENT
          },
          FunctionExpression: {
            parameters: DEFAULT_PARAMETER_INDENT,
            body: DEFAULT_FUNCTION_BODY_INDENT
          },
          StaticBlock: {
            body: DEFAULT_FUNCTION_BODY_INDENT
          },
          CallExpression: {
            arguments: DEFAULT_PARAMETER_INDENT
          },
          MemberExpression: 1,
          ArrayExpression: 1,
          ObjectExpression: 1,
          ImportDeclaration: 1,
          flatTernaryExpressions: false,
          ignoredNodes: [],
          ignoreComments: false
        };
        if (context.options.length) {
          if (context.options[0] === "tab") {
            indentSize = 1;
            indentType = "tab";
          } else {
            indentSize = context.options[0];
            indentType = "space";
          }
          if (context.options[1]) {
            Object.assign(options, context.options[1]);
            if (typeof options.VariableDeclarator === "number" || options.VariableDeclarator === "first") {
              options.VariableDeclarator = {
                var: options.VariableDeclarator,
                let: options.VariableDeclarator,
                const: options.VariableDeclarator
              };
            }
          }
        }
        const sourceCode = context.getSourceCode();
        const tokenInfo = new TokenInfo(sourceCode);
        const offsets = new OffsetStorage(tokenInfo, indentSize, indentType === "space" ? " " : "	");
        const parameterParens = /* @__PURE__ */ new WeakSet();
        function createErrorMessageData(expectedAmount, actualSpaces, actualTabs) {
          const expectedStatement = `${expectedAmount} ${indentType}${expectedAmount === 1 ? "" : "s"}`;
          const foundSpacesWord = `space${actualSpaces === 1 ? "" : "s"}`;
          const foundTabsWord = `tab${actualTabs === 1 ? "" : "s"}`;
          let foundStatement;
          if (actualSpaces > 0) {
            foundStatement = indentType === "space" ? actualSpaces : `${actualSpaces} ${foundSpacesWord}`;
          } else if (actualTabs > 0) {
            foundStatement = indentType === "tab" ? actualTabs : `${actualTabs} ${foundTabsWord}`;
          } else {
            foundStatement = "0";
          }
          return {
            expected: expectedStatement,
            actual: foundStatement
          };
        }
        function report(token, neededIndent) {
          const actualIndent = Array.from(tokenInfo.getTokenIndent(token));
          const numSpaces = actualIndent.filter((char) => char === " ").length;
          const numTabs = actualIndent.filter((char) => char === "	").length;
          context.report({
            node: token,
            messageId: "wrongIndentation",
            data: createErrorMessageData(neededIndent.length, numSpaces, numTabs),
            loc: {
              start: { line: token.loc.start.line, column: 0 },
              end: { line: token.loc.start.line, column: token.loc.start.column }
            },
            fix(fixer) {
              const range = [token.range[0] - token.loc.start.column, token.range[0]];
              const newText = neededIndent;
              return fixer.replaceTextRange(range, newText);
            }
          });
        }
        function validateTokenIndent(token, desiredIndent) {
          const indentation = tokenInfo.getTokenIndent(token);
          return indentation === desiredIndent || // To avoid conflicts with no-mixed-spaces-and-tabs, don't report mixed spaces and tabs.
          indentation.includes(" ") && indentation.includes("	");
        }
        function isOuterIIFE(node) {
          if (!node.parent || node.parent.type !== "CallExpression" || node.parent.callee !== node) {
            return false;
          }
          let statement = node.parent && node.parent.parent;
          while (statement.type === "UnaryExpression" && ["!", "~", "+", "-"].includes(statement.operator) || statement.type === "AssignmentExpression" || statement.type === "LogicalExpression" || statement.type === "SequenceExpression" || statement.type === "VariableDeclarator") {
            statement = statement.parent;
          }
          return (statement.type === "ExpressionStatement" || statement.type === "VariableDeclaration") && statement.parent.type === "Program";
        }
        function countTrailingLinebreaks(string) {
          const trailingWhitespace = string.match(/\s*$/u)[0];
          const linebreakMatches = trailingWhitespace.match(astUtils.createGlobalLinebreakMatcher());
          return linebreakMatches === null ? 0 : linebreakMatches.length;
        }
        function addElementListIndent(elements, startToken, endToken, offset) {
          function getFirstToken(element) {
            let token = sourceCode.getTokenBefore(element);
            while (astUtils.isOpeningParenToken(token) && token !== startToken) {
              token = sourceCode.getTokenBefore(token);
            }
            return sourceCode.getTokenAfter(token);
          }
          offsets.setDesiredOffsets(
            [startToken.range[1], endToken.range[0]],
            startToken,
            typeof offset === "number" ? offset : 1
          );
          offsets.setDesiredOffset(endToken, startToken, 0);
          if (offset === "first" && elements.length && !elements[0]) {
            return;
          }
          elements.forEach((element, index) => {
            if (!element) {
              return;
            }
            if (offset === "off") {
              offsets.ignoreToken(getFirstToken(element));
            }
            if (index === 0) {
              return;
            }
            if (offset === "first" && tokenInfo.isFirstTokenOfLine(getFirstToken(element))) {
              offsets.matchOffsetOf(getFirstToken(elements[0]), getFirstToken(element));
            } else {
              const previousElement = elements[index - 1];
              const firstTokenOfPreviousElement = previousElement && getFirstToken(previousElement);
              const previousElementLastToken = previousElement && sourceCode.getLastToken(previousElement);
              if (previousElement && previousElementLastToken.loc.end.line - countTrailingLinebreaks(previousElementLastToken.value) > startToken.loc.end.line) {
                offsets.setDesiredOffsets(
                  [previousElement.range[1], element.range[1]],
                  firstTokenOfPreviousElement,
                  0
                );
              }
            }
          });
        }
        function addBlocklessNodeIndent(node) {
          if (node.type !== "BlockStatement") {
            const lastParentToken = sourceCode.getTokenBefore(node, astUtils.isNotOpeningParenToken);
            let firstBodyToken = sourceCode.getFirstToken(node);
            let lastBodyToken = sourceCode.getLastToken(node);
            while (astUtils.isOpeningParenToken(sourceCode.getTokenBefore(firstBodyToken)) && astUtils.isClosingParenToken(sourceCode.getTokenAfter(lastBodyToken))) {
              firstBodyToken = sourceCode.getTokenBefore(firstBodyToken);
              lastBodyToken = sourceCode.getTokenAfter(lastBodyToken);
            }
            offsets.setDesiredOffsets([firstBodyToken.range[0], lastBodyToken.range[1]], lastParentToken, 1);
          }
        }
        function addFunctionCallIndent(node) {
          let openingParen;
          if (node.arguments.length) {
            openingParen = sourceCode.getFirstTokenBetween(node.callee, node.arguments[0], astUtils.isOpeningParenToken);
          } else {
            openingParen = sourceCode.getLastToken(node, 1);
          }
          const closingParen = sourceCode.getLastToken(node);
          parameterParens.add(openingParen);
          parameterParens.add(closingParen);
          if (node.optional) {
            const dotToken = sourceCode.getTokenAfter(node.callee, astUtils.isQuestionDotToken);
            const calleeParenCount = sourceCode.getTokensBetween(node.callee, dotToken, { filter: astUtils.isClosingParenToken }).length;
            const firstTokenOfCallee = calleeParenCount ? sourceCode.getTokenBefore(node.callee, { skip: calleeParenCount - 1 }) : sourceCode.getFirstToken(node.callee);
            const lastTokenOfCallee = sourceCode.getTokenBefore(dotToken);
            const offsetBase = lastTokenOfCallee.loc.end.line === openingParen.loc.start.line ? lastTokenOfCallee : firstTokenOfCallee;
            offsets.setDesiredOffset(dotToken, offsetBase, 1);
          }
          const offsetAfterToken = node.callee.type === "TaggedTemplateExpression" ? sourceCode.getFirstToken(node.callee.quasi) : openingParen;
          const offsetToken = sourceCode.getTokenBefore(offsetAfterToken);
          offsets.setDesiredOffset(openingParen, offsetToken, 0);
          addElementListIndent(node.arguments, openingParen, closingParen, options.CallExpression.arguments);
        }
        function addParensIndent(tokens) {
          const parenStack = [];
          const parenPairs = [];
          tokens.forEach((nextToken) => {
            if (astUtils.isOpeningParenToken(nextToken)) {
              parenStack.push(nextToken);
            } else if (astUtils.isClosingParenToken(nextToken)) {
              parenPairs.unshift({ left: parenStack.pop(), right: nextToken });
            }
          });
          parenPairs.forEach((pair) => {
            const leftParen = pair.left;
            const rightParen = pair.right;
            if (!parameterParens.has(leftParen) && !parameterParens.has(rightParen)) {
              const parenthesizedTokens = new Set(sourceCode.getTokensBetween(leftParen, rightParen));
              parenthesizedTokens.forEach((token) => {
                if (!parenthesizedTokens.has(offsets.getFirstDependency(token))) {
                  offsets.setDesiredOffset(token, leftParen, 1);
                }
              });
            }
            offsets.setDesiredOffset(rightParen, leftParen, 0);
          });
        }
        function ignoreNode(node) {
          const unknownNodeTokens = new Set(sourceCode.getTokens(node, { includeComments: true }));
          unknownNodeTokens.forEach((token) => {
            if (!unknownNodeTokens.has(offsets.getFirstDependency(token))) {
              const firstTokenOfLine = tokenInfo.getFirstTokenOfLine(token);
              if (token === firstTokenOfLine) {
                offsets.ignoreToken(token);
              } else {
                offsets.setDesiredOffset(token, firstTokenOfLine, 0);
              }
            }
          });
        }
        function isOnFirstLineOfStatement(token, leafNode) {
          let node = leafNode;
          while (node.parent && !node.parent.type.endsWith("Statement") && !node.parent.type.endsWith("Declaration")) {
            node = node.parent;
          }
          node = node.parent;
          return !node || node.loc.start.line === token.loc.start.line;
        }
        function hasBlankLinesBetween(firstToken, secondToken) {
          const firstTokenLine = firstToken.loc.end.line;
          const secondTokenLine = secondToken.loc.start.line;
          if (firstTokenLine === secondTokenLine || firstTokenLine === secondTokenLine - 1) {
            return false;
          }
          for (let line = firstTokenLine + 1; line < secondTokenLine; ++line) {
            if (!tokenInfo.firstTokensByLineNumber.has(line)) {
              return true;
            }
          }
          return false;
        }
        const ignoredNodeFirstTokens = /* @__PURE__ */ new Set();
        const baseOffsetListeners = {
          "ArrayExpression, ArrayPattern"(node) {
            const openingBracket = sourceCode.getFirstToken(node);
            const closingBracket = sourceCode.getTokenAfter([...node.elements].reverse().find((_) => _) || openingBracket, astUtils.isClosingBracketToken);
            addElementListIndent(node.elements, openingBracket, closingBracket, options.ArrayExpression);
          },
          "ObjectExpression, ObjectPattern"(node) {
            const openingCurly = sourceCode.getFirstToken(node);
            const closingCurly = sourceCode.getTokenAfter(
              node.properties.length ? node.properties[node.properties.length - 1] : openingCurly,
              astUtils.isClosingBraceToken
            );
            addElementListIndent(node.properties, openingCurly, closingCurly, options.ObjectExpression);
          },
          ArrowFunctionExpression(node) {
            const maybeOpeningParen = sourceCode.getFirstToken(node, { skip: node.async ? 1 : 0 });
            if (astUtils.isOpeningParenToken(maybeOpeningParen)) {
              const openingParen = maybeOpeningParen;
              const closingParen = sourceCode.getTokenBefore(node.body, astUtils.isClosingParenToken);
              parameterParens.add(openingParen);
              parameterParens.add(closingParen);
              addElementListIndent(node.params, openingParen, closingParen, options.FunctionExpression.parameters);
            }
            addBlocklessNodeIndent(node.body);
          },
          AssignmentExpression(node) {
            const operator = sourceCode.getFirstTokenBetween(node.left, node.right, (token) => token.value === node.operator);
            offsets.setDesiredOffsets([operator.range[0], node.range[1]], sourceCode.getLastToken(node.left), 1);
            offsets.ignoreToken(operator);
            offsets.ignoreToken(sourceCode.getTokenAfter(operator));
          },
          "BinaryExpression, LogicalExpression"(node) {
            const operator = sourceCode.getFirstTokenBetween(node.left, node.right, (token) => token.value === node.operator);
            const tokenAfterOperator = sourceCode.getTokenAfter(operator);
            offsets.ignoreToken(operator);
            offsets.ignoreToken(tokenAfterOperator);
            offsets.setDesiredOffset(tokenAfterOperator, operator, 0);
          },
          "BlockStatement, ClassBody"(node) {
            let blockIndentLevel;
            if (node.parent && isOuterIIFE(node.parent)) {
              blockIndentLevel = options.outerIIFEBody;
            } else if (node.parent && (node.parent.type === "FunctionExpression" || node.parent.type === "ArrowFunctionExpression")) {
              blockIndentLevel = options.FunctionExpression.body;
            } else if (node.parent && node.parent.type === "FunctionDeclaration") {
              blockIndentLevel = options.FunctionDeclaration.body;
            } else {
              blockIndentLevel = 1;
            }
            if (!astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
              offsets.setDesiredOffset(sourceCode.getFirstToken(node), sourceCode.getFirstToken(node.parent), 0);
            }
            addElementListIndent(node.body, sourceCode.getFirstToken(node), sourceCode.getLastToken(node), blockIndentLevel);
          },
          CallExpression: addFunctionCallIndent,
          "ClassDeclaration[superClass], ClassExpression[superClass]"(node) {
            const classToken = sourceCode.getFirstToken(node);
            const extendsToken = sourceCode.getTokenBefore(node.superClass, astUtils.isNotOpeningParenToken);
            offsets.setDesiredOffsets([extendsToken.range[0], node.body.range[0]], classToken, 1);
          },
          ConditionalExpression(node) {
            const firstToken = sourceCode.getFirstToken(node);
            if (!options.flatTernaryExpressions || !astUtils.isTokenOnSameLine(node.test, node.consequent) || isOnFirstLineOfStatement(firstToken, node)) {
              const questionMarkToken = sourceCode.getFirstTokenBetween(node.test, node.consequent, (token) => token.type === "Punctuator" && token.value === "?");
              const colonToken = sourceCode.getFirstTokenBetween(node.consequent, node.alternate, (token) => token.type === "Punctuator" && token.value === ":");
              const firstConsequentToken = sourceCode.getTokenAfter(questionMarkToken);
              const lastConsequentToken = sourceCode.getTokenBefore(colonToken);
              const firstAlternateToken = sourceCode.getTokenAfter(colonToken);
              offsets.setDesiredOffset(questionMarkToken, firstToken, 1);
              offsets.setDesiredOffset(colonToken, firstToken, 1);
              offsets.setDesiredOffset(firstConsequentToken, firstToken, firstConsequentToken.type === "Punctuator" && options.offsetTernaryExpressions ? 2 : 1);
              if (lastConsequentToken.loc.end.line === firstAlternateToken.loc.start.line) {
                offsets.setDesiredOffset(firstAlternateToken, firstConsequentToken, 0);
              } else {
                offsets.setDesiredOffset(firstAlternateToken, firstToken, firstAlternateToken.type === "Punctuator" && options.offsetTernaryExpressions ? 2 : 1);
              }
            }
          },
          "DoWhileStatement, WhileStatement, ForInStatement, ForOfStatement, WithStatement": (node) => addBlocklessNodeIndent(node.body),
          ExportNamedDeclaration(node) {
            if (node.declaration === null) {
              const closingCurly = sourceCode.getLastToken(node, astUtils.isClosingBraceToken);
              addElementListIndent(node.specifiers, sourceCode.getFirstToken(node, { skip: 1 }), closingCurly, 1);
              if (node.source) {
                offsets.setDesiredOffsets([closingCurly.range[1], node.range[1]], sourceCode.getFirstToken(node), 1);
              }
            }
          },
          ForStatement(node) {
            const forOpeningParen = sourceCode.getFirstToken(node, 1);
            if (node.init) {
              offsets.setDesiredOffsets(node.init.range, forOpeningParen, 1);
            }
            if (node.test) {
              offsets.setDesiredOffsets(node.test.range, forOpeningParen, 1);
            }
            if (node.update) {
              offsets.setDesiredOffsets(node.update.range, forOpeningParen, 1);
            }
            addBlocklessNodeIndent(node.body);
          },
          "FunctionDeclaration, FunctionExpression"(node) {
            const closingParen = sourceCode.getTokenBefore(node.body);
            const openingParen = sourceCode.getTokenBefore(node.params.length ? node.params[0] : closingParen);
            parameterParens.add(openingParen);
            parameterParens.add(closingParen);
            addElementListIndent(node.params, openingParen, closingParen, options[node.type].parameters);
          },
          IfStatement(node) {
            addBlocklessNodeIndent(node.consequent);
            if (node.alternate && node.alternate.type !== "IfStatement") {
              addBlocklessNodeIndent(node.alternate);
            }
          },
          /*
           * For blockless nodes with semicolon-first style, don't indent the semicolon.
           * e.g.
           * if (foo)
           *     bar()
           * ; [1, 2, 3].map(foo)
           *
           * Traversal into the node sets indentation of the semicolon, so we need to override it on exit.
           */
          ":matches(DoWhileStatement, ForStatement, ForInStatement, ForOfStatement, IfStatement, WhileStatement, WithStatement):exit"(node) {
            let nodesToCheck;
            if (node.type === "IfStatement") {
              nodesToCheck = [node.consequent];
              if (node.alternate) {
                nodesToCheck.push(node.alternate);
              }
            } else {
              nodesToCheck = [node.body];
            }
            for (const nodeToCheck of nodesToCheck) {
              const lastToken = sourceCode.getLastToken(nodeToCheck);
              if (astUtils.isSemicolonToken(lastToken)) {
                const tokenBeforeLast = sourceCode.getTokenBefore(lastToken);
                const tokenAfterLast = sourceCode.getTokenAfter(lastToken);
                if (!astUtils.isTokenOnSameLine(tokenBeforeLast, lastToken) && tokenAfterLast && astUtils.isTokenOnSameLine(lastToken, tokenAfterLast)) {
                  offsets.setDesiredOffset(
                    lastToken,
                    sourceCode.getFirstToken(node),
                    0
                  );
                }
              }
            }
          },
          ImportDeclaration(node) {
            if (node.specifiers.some((specifier) => specifier.type === "ImportSpecifier")) {
              const openingCurly = sourceCode.getFirstToken(node, astUtils.isOpeningBraceToken);
              const closingCurly = sourceCode.getLastToken(node, astUtils.isClosingBraceToken);
              addElementListIndent(node.specifiers.filter((specifier) => specifier.type === "ImportSpecifier"), openingCurly, closingCurly, options.ImportDeclaration);
            }
            const fromToken = sourceCode.getLastToken(node, (token) => token.type === "Identifier" && token.value === "from");
            const sourceToken = sourceCode.getLastToken(node, (token) => token.type === "String");
            const semiToken = sourceCode.getLastToken(node, (token) => token.type === "Punctuator" && token.value === ";");
            if (fromToken) {
              const end = semiToken && semiToken.range[1] === sourceToken.range[1] ? node.range[1] : sourceToken.range[1];
              offsets.setDesiredOffsets([fromToken.range[0], end], sourceCode.getFirstToken(node), 1);
            }
          },
          ImportExpression(node) {
            const openingParen = sourceCode.getFirstToken(node, 1);
            const closingParen = sourceCode.getLastToken(node);
            parameterParens.add(openingParen);
            parameterParens.add(closingParen);
            offsets.setDesiredOffset(openingParen, sourceCode.getTokenBefore(openingParen), 0);
            addElementListIndent([node.source], openingParen, closingParen, options.CallExpression.arguments);
          },
          "MemberExpression, JSXMemberExpression, MetaProperty"(node) {
            const object = node.type === "MetaProperty" ? node.meta : node.object;
            const firstNonObjectToken = sourceCode.getFirstTokenBetween(object, node.property, astUtils.isNotClosingParenToken);
            const secondNonObjectToken = sourceCode.getTokenAfter(firstNonObjectToken);
            const objectParenCount = sourceCode.getTokensBetween(object, node.property, { filter: astUtils.isClosingParenToken }).length;
            const firstObjectToken = objectParenCount ? sourceCode.getTokenBefore(object, { skip: objectParenCount - 1 }) : sourceCode.getFirstToken(object);
            const lastObjectToken = sourceCode.getTokenBefore(firstNonObjectToken);
            const firstPropertyToken = node.computed ? firstNonObjectToken : secondNonObjectToken;
            if (node.computed) {
              offsets.setDesiredOffset(sourceCode.getLastToken(node), firstNonObjectToken, 0);
              offsets.setDesiredOffsets(node.property.range, firstNonObjectToken, 1);
            }
            const offsetBase = lastObjectToken.loc.end.line === firstPropertyToken.loc.start.line ? lastObjectToken : firstObjectToken;
            if (typeof options.MemberExpression === "number") {
              offsets.setDesiredOffset(firstNonObjectToken, offsetBase, options.MemberExpression);
              offsets.setDesiredOffset(secondNonObjectToken, node.computed ? firstNonObjectToken : offsetBase, options.MemberExpression);
            } else {
              offsets.ignoreToken(firstNonObjectToken);
              offsets.ignoreToken(secondNonObjectToken);
              offsets.setDesiredOffset(firstNonObjectToken, offsetBase, 0);
              offsets.setDesiredOffset(secondNonObjectToken, firstNonObjectToken, 0);
            }
          },
          NewExpression(node) {
            if (node.arguments.length > 0 || astUtils.isClosingParenToken(sourceCode.getLastToken(node)) && astUtils.isOpeningParenToken(sourceCode.getLastToken(node, 1))) {
              addFunctionCallIndent(node);
            }
          },
          Property(node) {
            if (!node.shorthand && !node.method && node.kind === "init") {
              const colon = sourceCode.getFirstTokenBetween(node.key, node.value, astUtils.isColonToken);
              offsets.ignoreToken(sourceCode.getTokenAfter(colon));
            }
          },
          PropertyDefinition(node) {
            const firstToken = sourceCode.getFirstToken(node);
            const maybeSemicolonToken = sourceCode.getLastToken(node);
            let keyLastToken = null;
            if (node.computed) {
              const bracketTokenL = sourceCode.getTokenBefore(node.key, astUtils.isOpeningBracketToken);
              const bracketTokenR = keyLastToken = sourceCode.getTokenAfter(node.key, astUtils.isClosingBracketToken);
              const keyRange = [bracketTokenL.range[1], bracketTokenR.range[0]];
              if (bracketTokenL !== firstToken) {
                offsets.setDesiredOffset(bracketTokenL, firstToken, 0);
              }
              offsets.setDesiredOffsets(keyRange, bracketTokenL, 1);
              offsets.setDesiredOffset(bracketTokenR, bracketTokenL, 0);
            } else {
              const idToken = keyLastToken = sourceCode.getFirstToken(node.key);
              if (idToken !== firstToken) {
                offsets.setDesiredOffset(idToken, firstToken, 1);
              }
            }
            if (node.value) {
              const eqToken = sourceCode.getTokenBefore(node.value, astUtils.isEqToken);
              const valueToken = sourceCode.getTokenAfter(eqToken);
              offsets.setDesiredOffset(eqToken, keyLastToken, 1);
              offsets.setDesiredOffset(valueToken, eqToken, 1);
              if (astUtils.isSemicolonToken(maybeSemicolonToken)) {
                offsets.setDesiredOffset(maybeSemicolonToken, eqToken, 1);
              }
            } else if (astUtils.isSemicolonToken(maybeSemicolonToken)) {
              offsets.setDesiredOffset(maybeSemicolonToken, keyLastToken, 1);
            }
          },
          StaticBlock(node) {
            const openingCurly = sourceCode.getFirstToken(node, { skip: 1 });
            const closingCurly = sourceCode.getLastToken(node);
            addElementListIndent(node.body, openingCurly, closingCurly, options.StaticBlock.body);
          },
          SwitchStatement(node) {
            const openingCurly = sourceCode.getTokenAfter(node.discriminant, astUtils.isOpeningBraceToken);
            const closingCurly = sourceCode.getLastToken(node);
            offsets.setDesiredOffsets([openingCurly.range[1], closingCurly.range[0]], openingCurly, options.SwitchCase);
            if (node.cases.length) {
              sourceCode.getTokensBetween(
                node.cases[node.cases.length - 1],
                closingCurly,
                { includeComments: true, filter: astUtils.isCommentToken }
              ).forEach((token) => offsets.ignoreToken(token));
            }
          },
          SwitchCase(node) {
            if (!(node.consequent.length === 1 && node.consequent[0].type === "BlockStatement")) {
              const caseKeyword = sourceCode.getFirstToken(node);
              const tokenAfterCurrentCase = sourceCode.getTokenAfter(node);
              offsets.setDesiredOffsets([caseKeyword.range[1], tokenAfterCurrentCase.range[0]], caseKeyword, 1);
            }
          },
          TemplateLiteral(node) {
            node.expressions.forEach((expression, index) => {
              const previousQuasi = node.quasis[index];
              const nextQuasi = node.quasis[index + 1];
              const tokenToAlignFrom = previousQuasi.loc.start.line === previousQuasi.loc.end.line ? sourceCode.getFirstToken(previousQuasi) : null;
              offsets.setDesiredOffsets([previousQuasi.range[1], nextQuasi.range[0]], tokenToAlignFrom, 1);
              offsets.setDesiredOffset(sourceCode.getFirstToken(nextQuasi), tokenToAlignFrom, 0);
            });
          },
          VariableDeclaration(node) {
            let variableIndent = Object.prototype.hasOwnProperty.call(options.VariableDeclarator, node.kind) ? options.VariableDeclarator[node.kind] : DEFAULT_VARIABLE_INDENT;
            const firstToken = sourceCode.getFirstToken(node), lastToken = sourceCode.getLastToken(node);
            if (options.VariableDeclarator[node.kind] === "first") {
              if (node.declarations.length > 1) {
                addElementListIndent(
                  node.declarations,
                  firstToken,
                  lastToken,
                  "first"
                );
                return;
              }
              variableIndent = DEFAULT_VARIABLE_INDENT;
            }
            if (node.declarations[node.declarations.length - 1].loc.start.line > node.loc.start.line) {
              offsets.setDesiredOffsets(node.range, firstToken, variableIndent, true);
            } else {
              offsets.setDesiredOffsets(node.range, firstToken, variableIndent);
            }
            if (astUtils.isSemicolonToken(lastToken)) {
              offsets.ignoreToken(lastToken);
            }
          },
          VariableDeclarator(node) {
            if (node.init) {
              const equalOperator = sourceCode.getTokenBefore(node.init, astUtils.isNotOpeningParenToken);
              const tokenAfterOperator = sourceCode.getTokenAfter(equalOperator);
              offsets.ignoreToken(equalOperator);
              offsets.ignoreToken(tokenAfterOperator);
              offsets.setDesiredOffsets([tokenAfterOperator.range[0], node.range[1]], equalOperator, 1);
              offsets.setDesiredOffset(equalOperator, sourceCode.getLastToken(node.id), 0);
            }
          },
          "JSXAttribute[value]"(node) {
            const equalsToken = sourceCode.getFirstTokenBetween(node.name, node.value, (token) => token.type === "Punctuator" && token.value === "=");
            offsets.setDesiredOffsets([equalsToken.range[0], node.value.range[1]], sourceCode.getFirstToken(node.name), 1);
          },
          JSXElement(node) {
            if (node.closingElement) {
              addElementListIndent(node.children, sourceCode.getFirstToken(node.openingElement), sourceCode.getFirstToken(node.closingElement), 1);
            }
          },
          JSXOpeningElement(node) {
            const firstToken = sourceCode.getFirstToken(node);
            let closingToken;
            if (node.selfClosing) {
              closingToken = sourceCode.getLastToken(node, { skip: 1 });
              offsets.setDesiredOffset(sourceCode.getLastToken(node), closingToken, 0);
            } else {
              closingToken = sourceCode.getLastToken(node);
            }
            offsets.setDesiredOffsets(node.name.range, sourceCode.getFirstToken(node));
            addElementListIndent(node.attributes, firstToken, closingToken, 1);
          },
          JSXClosingElement(node) {
            const firstToken = sourceCode.getFirstToken(node);
            offsets.setDesiredOffsets(node.name.range, firstToken, 1);
          },
          JSXFragment(node) {
            const firstOpeningToken = sourceCode.getFirstToken(node.openingFragment);
            const firstClosingToken = sourceCode.getFirstToken(node.closingFragment);
            addElementListIndent(node.children, firstOpeningToken, firstClosingToken, 1);
          },
          JSXOpeningFragment(node) {
            const firstToken = sourceCode.getFirstToken(node);
            const closingToken = sourceCode.getLastToken(node);
            offsets.setDesiredOffsets(node.range, firstToken, 1);
            offsets.matchOffsetOf(firstToken, closingToken);
          },
          JSXClosingFragment(node) {
            const firstToken = sourceCode.getFirstToken(node);
            const slashToken = sourceCode.getLastToken(node, { skip: 1 });
            const closingToken = sourceCode.getLastToken(node);
            const tokenToMatch = astUtils.isTokenOnSameLine(slashToken, closingToken) ? slashToken : closingToken;
            offsets.setDesiredOffsets(node.range, firstToken, 1);
            offsets.matchOffsetOf(firstToken, tokenToMatch);
          },
          JSXExpressionContainer(node) {
            const openingCurly = sourceCode.getFirstToken(node);
            const closingCurly = sourceCode.getLastToken(node);
            offsets.setDesiredOffsets(
              [openingCurly.range[1], closingCurly.range[0]],
              openingCurly,
              1
            );
          },
          JSXSpreadAttribute(node) {
            const openingCurly = sourceCode.getFirstToken(node);
            const closingCurly = sourceCode.getLastToken(node);
            offsets.setDesiredOffsets(
              [openingCurly.range[1], closingCurly.range[0]],
              openingCurly,
              1
            );
          },
          "*"(node) {
            const firstToken = sourceCode.getFirstToken(node);
            if (firstToken && !ignoredNodeFirstTokens.has(firstToken)) {
              offsets.setDesiredOffsets(node.range, firstToken, 0);
            }
          }
        };
        const listenerCallQueue = [];
        const offsetListeners = {};
        for (const [selector, listener] of Object.entries(baseOffsetListeners)) {
          offsetListeners[selector] = (node) => listenerCallQueue.push({ listener, node });
        }
        const ignoredNodes = /* @__PURE__ */ new Set();
        function addToIgnoredNodes(node) {
          ignoredNodes.add(node);
          ignoredNodeFirstTokens.add(sourceCode.getFirstToken(node));
        }
        const ignoredNodeListeners = options.ignoredNodes.reduce(
          (listeners, ignoredSelector) => Object.assign(listeners, { [ignoredSelector]: addToIgnoredNodes }),
          {}
        );
        return Object.assign(
          offsetListeners,
          ignoredNodeListeners,
          {
            "*:exit"(node) {
              if (!KNOWN_NODES.has(node.type)) {
                addToIgnoredNodes(node);
              }
            },
            "Program:exit"() {
              if (options.ignoreComments) {
                sourceCode.getAllComments().forEach((comment) => offsets.ignoreToken(comment));
              }
              listenerCallQueue.filter((nodeInfo) => !ignoredNodes.has(nodeInfo.node)).forEach((nodeInfo) => nodeInfo.listener(nodeInfo.node));
              ignoredNodes.forEach(ignoreNode);
              addParensIndent(sourceCode.ast.tokens);
              const precedingTokens = sourceCode.ast.comments.reduce((commentMap, comment) => {
                const tokenOrCommentBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
                return commentMap.set(comment, commentMap.has(tokenOrCommentBefore) ? commentMap.get(tokenOrCommentBefore) : tokenOrCommentBefore);
              }, /* @__PURE__ */ new WeakMap());
              sourceCode.lines.forEach((line, lineIndex) => {
                const lineNumber = lineIndex + 1;
                if (!tokenInfo.firstTokensByLineNumber.has(lineNumber)) {
                  return;
                }
                const firstTokenOfLine = tokenInfo.firstTokensByLineNumber.get(lineNumber);
                if (firstTokenOfLine.loc.start.line !== lineNumber) {
                  return;
                }
                if (astUtils.isCommentToken(firstTokenOfLine)) {
                  const tokenBefore = precedingTokens.get(firstTokenOfLine);
                  const tokenAfter = tokenBefore ? sourceCode.getTokenAfter(tokenBefore) : sourceCode.ast.tokens[0];
                  const mayAlignWithBefore = tokenBefore && !hasBlankLinesBetween(tokenBefore, firstTokenOfLine);
                  const mayAlignWithAfter = tokenAfter && !hasBlankLinesBetween(firstTokenOfLine, tokenAfter);
                  if (tokenAfter && astUtils.isSemicolonToken(tokenAfter) && !astUtils.isTokenOnSameLine(firstTokenOfLine, tokenAfter)) {
                    offsets.setDesiredOffset(firstTokenOfLine, tokenAfter, 0);
                  }
                  if (mayAlignWithBefore && validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(tokenBefore)) || mayAlignWithAfter && validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(tokenAfter))) {
                    return;
                  }
                }
                if (validateTokenIndent(firstTokenOfLine, offsets.getDesiredIndent(firstTokenOfLine))) {
                  return;
                }
                report(firstTokenOfLine, offsets.getDesiredIndent(firstTokenOfLine));
              });
            }
          }
        );
      }
    };
  }
});

// node_modules/eslint/lib/rules/indent-legacy.js
var require_indent_legacy = __commonJS({
  "node_modules/eslint/lib/rules/indent-legacy.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent indentation",
          recommended: false,
          url: "https://eslint.org/docs/rules/indent-legacy"
        },
        deprecated: true,
        replacedBy: ["indent"],
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["tab"]
              },
              {
                type: "integer",
                minimum: 0
              }
            ]
          },
          {
            type: "object",
            properties: {
              SwitchCase: {
                type: "integer",
                minimum: 0
              },
              VariableDeclarator: {
                oneOf: [
                  {
                    type: "integer",
                    minimum: 0
                  },
                  {
                    type: "object",
                    properties: {
                      var: {
                        type: "integer",
                        minimum: 0
                      },
                      let: {
                        type: "integer",
                        minimum: 0
                      },
                      const: {
                        type: "integer",
                        minimum: 0
                      }
                    }
                  }
                ]
              },
              outerIIFEBody: {
                type: "integer",
                minimum: 0
              },
              MemberExpression: {
                type: "integer",
                minimum: 0
              },
              FunctionDeclaration: {
                type: "object",
                properties: {
                  parameters: {
                    oneOf: [
                      {
                        type: "integer",
                        minimum: 0
                      },
                      {
                        enum: ["first"]
                      }
                    ]
                  },
                  body: {
                    type: "integer",
                    minimum: 0
                  }
                }
              },
              FunctionExpression: {
                type: "object",
                properties: {
                  parameters: {
                    oneOf: [
                      {
                        type: "integer",
                        minimum: 0
                      },
                      {
                        enum: ["first"]
                      }
                    ]
                  },
                  body: {
                    type: "integer",
                    minimum: 0
                  }
                }
              },
              CallExpression: {
                type: "object",
                properties: {
                  parameters: {
                    oneOf: [
                      {
                        type: "integer",
                        minimum: 0
                      },
                      {
                        enum: ["first"]
                      }
                    ]
                  }
                }
              },
              ArrayExpression: {
                oneOf: [
                  {
                    type: "integer",
                    minimum: 0
                  },
                  {
                    enum: ["first"]
                  }
                ]
              },
              ObjectExpression: {
                oneOf: [
                  {
                    type: "integer",
                    minimum: 0
                  },
                  {
                    enum: ["first"]
                  }
                ]
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expected: "Expected indentation of {{expected}} but found {{actual}}."
        }
      },
      create(context) {
        const DEFAULT_VARIABLE_INDENT = 1;
        const DEFAULT_PARAMETER_INDENT = null;
        const DEFAULT_FUNCTION_BODY_INDENT = 1;
        let indentType = "space";
        let indentSize = 4;
        const options = {
          SwitchCase: 0,
          VariableDeclarator: {
            var: DEFAULT_VARIABLE_INDENT,
            let: DEFAULT_VARIABLE_INDENT,
            const: DEFAULT_VARIABLE_INDENT
          },
          outerIIFEBody: null,
          FunctionDeclaration: {
            parameters: DEFAULT_PARAMETER_INDENT,
            body: DEFAULT_FUNCTION_BODY_INDENT
          },
          FunctionExpression: {
            parameters: DEFAULT_PARAMETER_INDENT,
            body: DEFAULT_FUNCTION_BODY_INDENT
          },
          CallExpression: {
            arguments: DEFAULT_PARAMETER_INDENT
          },
          ArrayExpression: 1,
          ObjectExpression: 1
        };
        const sourceCode = context.getSourceCode();
        if (context.options.length) {
          if (context.options[0] === "tab") {
            indentSize = 1;
            indentType = "tab";
          } else if (typeof context.options[0] === "number") {
            indentSize = context.options[0];
            indentType = "space";
          }
          if (context.options[1]) {
            const opts = context.options[1];
            options.SwitchCase = opts.SwitchCase || 0;
            const variableDeclaratorRules = opts.VariableDeclarator;
            if (typeof variableDeclaratorRules === "number") {
              options.VariableDeclarator = {
                var: variableDeclaratorRules,
                let: variableDeclaratorRules,
                const: variableDeclaratorRules
              };
            } else if (typeof variableDeclaratorRules === "object") {
              Object.assign(options.VariableDeclarator, variableDeclaratorRules);
            }
            if (typeof opts.outerIIFEBody === "number") {
              options.outerIIFEBody = opts.outerIIFEBody;
            }
            if (typeof opts.MemberExpression === "number") {
              options.MemberExpression = opts.MemberExpression;
            }
            if (typeof opts.FunctionDeclaration === "object") {
              Object.assign(options.FunctionDeclaration, opts.FunctionDeclaration);
            }
            if (typeof opts.FunctionExpression === "object") {
              Object.assign(options.FunctionExpression, opts.FunctionExpression);
            }
            if (typeof opts.CallExpression === "object") {
              Object.assign(options.CallExpression, opts.CallExpression);
            }
            if (typeof opts.ArrayExpression === "number" || typeof opts.ArrayExpression === "string") {
              options.ArrayExpression = opts.ArrayExpression;
            }
            if (typeof opts.ObjectExpression === "number" || typeof opts.ObjectExpression === "string") {
              options.ObjectExpression = opts.ObjectExpression;
            }
          }
        }
        const caseIndentStore = {};
        function createErrorMessageData(expectedAmount, actualSpaces, actualTabs) {
          const expectedStatement = `${expectedAmount} ${indentType}${expectedAmount === 1 ? "" : "s"}`;
          const foundSpacesWord = `space${actualSpaces === 1 ? "" : "s"}`;
          const foundTabsWord = `tab${actualTabs === 1 ? "" : "s"}`;
          let foundStatement;
          if (actualSpaces > 0 && actualTabs > 0) {
            foundStatement = `${actualSpaces} ${foundSpacesWord} and ${actualTabs} ${foundTabsWord}`;
          } else if (actualSpaces > 0) {
            foundStatement = indentType === "space" ? actualSpaces : `${actualSpaces} ${foundSpacesWord}`;
          } else if (actualTabs > 0) {
            foundStatement = indentType === "tab" ? actualTabs : `${actualTabs} ${foundTabsWord}`;
          } else {
            foundStatement = "0";
          }
          return {
            expected: expectedStatement,
            actual: foundStatement
          };
        }
        function report(node, needed, gottenSpaces, gottenTabs, loc, isLastNodeCheck) {
          if (gottenSpaces && gottenTabs) {
            return;
          }
          const desiredIndent = (indentType === "space" ? " " : "	").repeat(needed);
          const textRange = isLastNodeCheck ? [node.range[1] - node.loc.end.column, node.range[1] - node.loc.end.column + gottenSpaces + gottenTabs] : [node.range[0] - node.loc.start.column, node.range[0] - node.loc.start.column + gottenSpaces + gottenTabs];
          context.report({
            node,
            loc,
            messageId: "expected",
            data: createErrorMessageData(needed, gottenSpaces, gottenTabs),
            fix: (fixer) => fixer.replaceTextRange(textRange, desiredIndent)
          });
        }
        function getNodeIndent(node, byLastLine) {
          const token = byLastLine ? sourceCode.getLastToken(node) : sourceCode.getFirstToken(node);
          const srcCharsBeforeNode = sourceCode.getText(token, token.loc.start.column).split("");
          const indentChars = srcCharsBeforeNode.slice(0, srcCharsBeforeNode.findIndex((char) => char !== " " && char !== "	"));
          const spaces = indentChars.filter((char) => char === " ").length;
          const tabs = indentChars.filter((char) => char === "	").length;
          return {
            space: spaces,
            tab: tabs,
            goodChar: indentType === "space" ? spaces : tabs,
            badChar: indentType === "space" ? tabs : spaces
          };
        }
        function isNodeFirstInLine(node, byEndLocation) {
          const firstToken = byEndLocation === true ? sourceCode.getLastToken(node, 1) : sourceCode.getTokenBefore(node), startLine = byEndLocation === true ? node.loc.end.line : node.loc.start.line, endLine = firstToken ? firstToken.loc.end.line : -1;
          return startLine !== endLine;
        }
        function checkNodeIndent(node, neededIndent) {
          const actualIndent = getNodeIndent(node, false);
          if (node.type !== "ArrayExpression" && node.type !== "ObjectExpression" && (actualIndent.goodChar !== neededIndent || actualIndent.badChar !== 0) && isNodeFirstInLine(node)) {
            report(node, neededIndent, actualIndent.space, actualIndent.tab);
          }
          if (node.type === "IfStatement" && node.alternate) {
            const elseToken = sourceCode.getTokenBefore(node.alternate);
            checkNodeIndent(elseToken, neededIndent);
            if (!isNodeFirstInLine(node.alternate)) {
              checkNodeIndent(node.alternate, neededIndent);
            }
          }
          if (node.type === "TryStatement" && node.handler) {
            const catchToken = sourceCode.getFirstToken(node.handler);
            checkNodeIndent(catchToken, neededIndent);
          }
          if (node.type === "TryStatement" && node.finalizer) {
            const finallyToken = sourceCode.getTokenBefore(node.finalizer);
            checkNodeIndent(finallyToken, neededIndent);
          }
          if (node.type === "DoWhileStatement") {
            const whileToken = sourceCode.getTokenAfter(node.body);
            checkNodeIndent(whileToken, neededIndent);
          }
        }
        function checkNodesIndent(nodes, indent) {
          nodes.forEach((node) => checkNodeIndent(node, indent));
        }
        function checkLastNodeLineIndent(node, lastLineIndent) {
          const lastToken = sourceCode.getLastToken(node);
          const endIndent = getNodeIndent(lastToken, true);
          if ((endIndent.goodChar !== lastLineIndent || endIndent.badChar !== 0) && isNodeFirstInLine(node, true)) {
            report(
              node,
              lastLineIndent,
              endIndent.space,
              endIndent.tab,
              { line: lastToken.loc.start.line, column: lastToken.loc.start.column },
              true
            );
          }
        }
        function checkLastReturnStatementLineIndent(node, firstLineIndent) {
          const lastToken = sourceCode.getLastToken(node, astUtils.isClosingParenToken);
          const textBeforeClosingParenthesis = sourceCode.getText(lastToken, lastToken.loc.start.column).slice(0, -1);
          if (textBeforeClosingParenthesis.trim()) {
            return;
          }
          const endIndent = getNodeIndent(lastToken, true);
          if (endIndent.goodChar !== firstLineIndent) {
            report(
              node,
              firstLineIndent,
              endIndent.space,
              endIndent.tab,
              { line: lastToken.loc.start.line, column: lastToken.loc.start.column },
              true
            );
          }
        }
        function checkFirstNodeLineIndent(node, firstLineIndent) {
          const startIndent = getNodeIndent(node, false);
          if ((startIndent.goodChar !== firstLineIndent || startIndent.badChar !== 0) && isNodeFirstInLine(node)) {
            report(
              node,
              firstLineIndent,
              startIndent.space,
              startIndent.tab,
              { line: node.loc.start.line, column: node.loc.start.column }
            );
          }
        }
        function getParentNodeByType(node, type, stopAtList) {
          let parent = node.parent;
          const stopAtSet = new Set(stopAtList || ["Program"]);
          while (parent.type !== type && !stopAtSet.has(parent.type) && parent.type !== "Program") {
            parent = parent.parent;
          }
          return parent.type === type ? parent : null;
        }
        function getVariableDeclaratorNode(node) {
          return getParentNodeByType(node, "VariableDeclarator");
        }
        function isNodeInVarOnTop(node, varNode) {
          return varNode && varNode.parent.loc.start.line === node.loc.start.line && varNode.parent.declarations.length > 1;
        }
        function isArgBeforeCalleeNodeMultiline(node) {
          const parent = node.parent;
          if (parent.arguments.length >= 2 && parent.arguments[1] === node) {
            return parent.arguments[0].loc.end.line > parent.arguments[0].loc.start.line;
          }
          return false;
        }
        function isOuterIIFE(node) {
          const parent = node.parent;
          let stmt = parent.parent;
          if (parent.type !== "CallExpression" || parent.callee !== node) {
            return false;
          }
          while (stmt.type === "UnaryExpression" && (stmt.operator === "!" || stmt.operator === "~" || stmt.operator === "+" || stmt.operator === "-") || stmt.type === "AssignmentExpression" || stmt.type === "LogicalExpression" || stmt.type === "SequenceExpression" || stmt.type === "VariableDeclarator") {
            stmt = stmt.parent;
          }
          return (stmt.type === "ExpressionStatement" || stmt.type === "VariableDeclaration") && stmt.parent && stmt.parent.type === "Program";
        }
        function checkIndentInFunctionBlock(node) {
          const calleeNode = node.parent;
          let indent;
          if (calleeNode.parent && (calleeNode.parent.type === "Property" || calleeNode.parent.type === "ArrayExpression")) {
            indent = getNodeIndent(calleeNode, false).goodChar;
          } else {
            indent = getNodeIndent(calleeNode).goodChar;
          }
          if (calleeNode.parent.type === "CallExpression") {
            const calleeParent = calleeNode.parent;
            if (calleeNode.type !== "FunctionExpression" && calleeNode.type !== "ArrowFunctionExpression") {
              if (calleeParent && calleeParent.loc.start.line < node.loc.start.line) {
                indent = getNodeIndent(calleeParent).goodChar;
              }
            } else {
              if (isArgBeforeCalleeNodeMultiline(calleeNode) && calleeParent.callee.loc.start.line === calleeParent.callee.loc.end.line && !isNodeFirstInLine(calleeNode)) {
                indent = getNodeIndent(calleeParent).goodChar;
              }
            }
          }
          let functionOffset = indentSize;
          if (options.outerIIFEBody !== null && isOuterIIFE(calleeNode)) {
            functionOffset = options.outerIIFEBody * indentSize;
          } else if (calleeNode.type === "FunctionExpression") {
            functionOffset = options.FunctionExpression.body * indentSize;
          } else if (calleeNode.type === "FunctionDeclaration") {
            functionOffset = options.FunctionDeclaration.body * indentSize;
          }
          indent += functionOffset;
          const parentVarNode = getVariableDeclaratorNode(node);
          if (parentVarNode && isNodeInVarOnTop(node, parentVarNode)) {
            indent += indentSize * options.VariableDeclarator[parentVarNode.parent.kind];
          }
          if (node.body.length > 0) {
            checkNodesIndent(node.body, indent);
          }
          checkLastNodeLineIndent(node, indent - functionOffset);
        }
        function isSingleLineNode(node) {
          const lastToken = sourceCode.getLastToken(node), startLine = node.loc.start.line, endLine = lastToken.loc.end.line;
          return startLine === endLine;
        }
        function checkIndentInArrayOrObjectBlock(node) {
          if (isSingleLineNode(node)) {
            return;
          }
          let elements = node.type === "ArrayExpression" ? node.elements : node.properties;
          elements = elements.filter((elem) => elem !== null);
          let nodeIndent;
          let elementsIndent;
          const parentVarNode = getVariableDeclaratorNode(node);
          if (isNodeFirstInLine(node)) {
            const parent = node.parent;
            nodeIndent = getNodeIndent(parent).goodChar;
            if (!parentVarNode || parentVarNode.loc.start.line !== node.loc.start.line) {
              if (parent.type !== "VariableDeclarator" || parentVarNode === parentVarNode.parent.declarations[0]) {
                if (parent.type === "VariableDeclarator" && parentVarNode.loc.start.line === parent.loc.start.line) {
                  nodeIndent += indentSize * options.VariableDeclarator[parentVarNode.parent.kind];
                } else if (parent.type === "ObjectExpression" || parent.type === "ArrayExpression") {
                  const parentElements = node.parent.type === "ObjectExpression" ? node.parent.properties : node.parent.elements;
                  if (parentElements[0] && parentElements[0].loc.start.line === parent.loc.start.line && parentElements[0].loc.end.line !== parent.loc.start.line) {
                  } else if (typeof options[parent.type] === "number") {
                    nodeIndent += options[parent.type] * indentSize;
                  } else {
                    nodeIndent = parentElements[0].loc.start.column;
                  }
                } else if (parent.type === "CallExpression" || parent.type === "NewExpression") {
                  if (typeof options.CallExpression.arguments === "number") {
                    nodeIndent += options.CallExpression.arguments * indentSize;
                  } else if (options.CallExpression.arguments === "first") {
                    if (parent.arguments.includes(node)) {
                      nodeIndent = parent.arguments[0].loc.start.column;
                    }
                  } else {
                    nodeIndent += indentSize;
                  }
                } else if (parent.type === "LogicalExpression" || parent.type === "ArrowFunctionExpression") {
                  nodeIndent += indentSize;
                }
              }
            }
            checkFirstNodeLineIndent(node, nodeIndent);
          } else {
            nodeIndent = getNodeIndent(node).goodChar;
          }
          if (options[node.type] === "first") {
            elementsIndent = elements.length ? elements[0].loc.start.column : 0;
          } else {
            elementsIndent = nodeIndent + indentSize * options[node.type];
          }
          if (isNodeInVarOnTop(node, parentVarNode)) {
            elementsIndent += indentSize * options.VariableDeclarator[parentVarNode.parent.kind];
          }
          checkNodesIndent(elements, elementsIndent);
          if (elements.length > 0) {
            if (elements[elements.length - 1].loc.end.line === node.loc.end.line) {
              return;
            }
          }
          checkLastNodeLineIndent(node, nodeIndent + (isNodeInVarOnTop(node, parentVarNode) ? options.VariableDeclarator[parentVarNode.parent.kind] * indentSize : 0));
        }
        function isNodeBodyBlock(node) {
          return node.type === "BlockStatement" || node.type === "ClassBody" || node.body && node.body.type === "BlockStatement" || node.consequent && node.consequent.type === "BlockStatement";
        }
        function blockIndentationCheck(node) {
          if (isSingleLineNode(node)) {
            return;
          }
          if (node.parent && (node.parent.type === "FunctionExpression" || node.parent.type === "FunctionDeclaration" || node.parent.type === "ArrowFunctionExpression")) {
            checkIndentInFunctionBlock(node);
            return;
          }
          let indent;
          let nodesToCheck = [];
          const statementsWithProperties = [
            "IfStatement",
            "WhileStatement",
            "ForStatement",
            "ForInStatement",
            "ForOfStatement",
            "DoWhileStatement",
            "ClassDeclaration",
            "TryStatement"
          ];
          if (node.parent && statementsWithProperties.includes(node.parent.type) && isNodeBodyBlock(node)) {
            indent = getNodeIndent(node.parent).goodChar;
          } else if (node.parent && node.parent.type === "CatchClause") {
            indent = getNodeIndent(node.parent.parent).goodChar;
          } else {
            indent = getNodeIndent(node).goodChar;
          }
          if (node.type === "IfStatement" && node.consequent.type !== "BlockStatement") {
            nodesToCheck = [node.consequent];
          } else if (Array.isArray(node.body)) {
            nodesToCheck = node.body;
          } else {
            nodesToCheck = [node.body];
          }
          if (nodesToCheck.length > 0) {
            checkNodesIndent(nodesToCheck, indent + indentSize);
          }
          if (node.type === "BlockStatement") {
            checkLastNodeLineIndent(node, indent);
          }
        }
        function filterOutSameLineVars(node) {
          return node.declarations.reduce((finalCollection, elem) => {
            const lastElem = finalCollection[finalCollection.length - 1];
            if (elem.loc.start.line !== node.loc.start.line && !lastElem || lastElem && lastElem.loc.start.line !== elem.loc.start.line) {
              finalCollection.push(elem);
            }
            return finalCollection;
          }, []);
        }
        function checkIndentInVariableDeclarations(node) {
          const elements = filterOutSameLineVars(node);
          const nodeIndent = getNodeIndent(node).goodChar;
          const lastElement = elements[elements.length - 1];
          const elementsIndent = nodeIndent + indentSize * options.VariableDeclarator[node.kind];
          checkNodesIndent(elements, elementsIndent);
          if (sourceCode.getLastToken(node).loc.end.line <= lastElement.loc.end.line) {
            return;
          }
          const tokenBeforeLastElement = sourceCode.getTokenBefore(lastElement);
          if (tokenBeforeLastElement.value === ",") {
            checkLastNodeLineIndent(node, getNodeIndent(tokenBeforeLastElement).goodChar);
          } else {
            checkLastNodeLineIndent(node, elementsIndent - indentSize);
          }
        }
        function blockLessNodes(node) {
          if (node.body.type !== "BlockStatement") {
            blockIndentationCheck(node);
          }
        }
        function expectedCaseIndent(node, providedSwitchIndent) {
          const switchNode = node.type === "SwitchStatement" ? node : node.parent;
          const switchIndent = typeof providedSwitchIndent === "undefined" ? getNodeIndent(switchNode).goodChar : providedSwitchIndent;
          let caseIndent;
          if (caseIndentStore[switchNode.loc.start.line]) {
            return caseIndentStore[switchNode.loc.start.line];
          }
          if (switchNode.cases.length > 0 && options.SwitchCase === 0) {
            caseIndent = switchIndent;
          } else {
            caseIndent = switchIndent + indentSize * options.SwitchCase;
          }
          caseIndentStore[switchNode.loc.start.line] = caseIndent;
          return caseIndent;
        }
        function isWrappedInParenthesis(node) {
          const regex = /^return\s*?\(\s*?\);*?/u;
          const statementWithoutArgument = sourceCode.getText(node).replace(
            sourceCode.getText(node.argument),
            ""
          );
          return regex.test(statementWithoutArgument);
        }
        return {
          Program(node) {
            if (node.body.length > 0) {
              checkNodesIndent(node.body, getNodeIndent(node).goodChar);
            }
          },
          ClassBody: blockIndentationCheck,
          BlockStatement: blockIndentationCheck,
          WhileStatement: blockLessNodes,
          ForStatement: blockLessNodes,
          ForInStatement: blockLessNodes,
          ForOfStatement: blockLessNodes,
          DoWhileStatement: blockLessNodes,
          IfStatement(node) {
            if (node.consequent.type !== "BlockStatement" && node.consequent.loc.start.line > node.loc.start.line) {
              blockIndentationCheck(node);
            }
          },
          VariableDeclaration(node) {
            if (node.declarations[node.declarations.length - 1].loc.start.line > node.declarations[0].loc.start.line) {
              checkIndentInVariableDeclarations(node);
            }
          },
          ObjectExpression(node) {
            checkIndentInArrayOrObjectBlock(node);
          },
          ArrayExpression(node) {
            checkIndentInArrayOrObjectBlock(node);
          },
          MemberExpression(node) {
            if (typeof options.MemberExpression === "undefined") {
              return;
            }
            if (isSingleLineNode(node)) {
              return;
            }
            if (getParentNodeByType(node, "VariableDeclarator", ["FunctionExpression", "ArrowFunctionExpression"])) {
              return;
            }
            if (getParentNodeByType(node, "AssignmentExpression", ["FunctionExpression"])) {
              return;
            }
            const propertyIndent = getNodeIndent(node).goodChar + indentSize * options.MemberExpression;
            const checkNodes = [node.property];
            const dot = sourceCode.getTokenBefore(node.property);
            if (dot.type === "Punctuator" && dot.value === ".") {
              checkNodes.push(dot);
            }
            checkNodesIndent(checkNodes, propertyIndent);
          },
          SwitchStatement(node) {
            const switchIndent = getNodeIndent(node).goodChar;
            const caseIndent = expectedCaseIndent(node, switchIndent);
            checkNodesIndent(node.cases, caseIndent);
            checkLastNodeLineIndent(node, switchIndent);
          },
          SwitchCase(node) {
            if (isSingleLineNode(node)) {
              return;
            }
            const caseIndent = expectedCaseIndent(node);
            checkNodesIndent(node.consequent, caseIndent + indentSize);
          },
          FunctionDeclaration(node) {
            if (isSingleLineNode(node)) {
              return;
            }
            if (options.FunctionDeclaration.parameters === "first" && node.params.length) {
              checkNodesIndent(node.params.slice(1), node.params[0].loc.start.column);
            } else if (options.FunctionDeclaration.parameters !== null) {
              checkNodesIndent(node.params, getNodeIndent(node).goodChar + indentSize * options.FunctionDeclaration.parameters);
            }
          },
          FunctionExpression(node) {
            if (isSingleLineNode(node)) {
              return;
            }
            if (options.FunctionExpression.parameters === "first" && node.params.length) {
              checkNodesIndent(node.params.slice(1), node.params[0].loc.start.column);
            } else if (options.FunctionExpression.parameters !== null) {
              checkNodesIndent(node.params, getNodeIndent(node).goodChar + indentSize * options.FunctionExpression.parameters);
            }
          },
          ReturnStatement(node) {
            if (isSingleLineNode(node)) {
              return;
            }
            const firstLineIndent = getNodeIndent(node).goodChar;
            if (isWrappedInParenthesis(node)) {
              checkLastReturnStatementLineIndent(node, firstLineIndent);
            } else {
              checkNodeIndent(node, firstLineIndent);
            }
          },
          CallExpression(node) {
            if (isSingleLineNode(node)) {
              return;
            }
            if (options.CallExpression.arguments === "first" && node.arguments.length) {
              checkNodesIndent(node.arguments.slice(1), node.arguments[0].loc.start.column);
            } else if (options.CallExpression.arguments !== null) {
              checkNodesIndent(node.arguments, getNodeIndent(node).goodChar + indentSize * options.CallExpression.arguments);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/init-declarations.js
var require_init_declarations = __commonJS({
  "node_modules/eslint/lib/rules/init-declarations.js"(exports, module2) {
    "use strict";
    function isForLoop(block) {
      return block.type === "ForInStatement" || block.type === "ForOfStatement" || block.type === "ForStatement";
    }
    function isInitialized(node) {
      const declaration = node.parent;
      const block = declaration.parent;
      if (isForLoop(block)) {
        if (block.type === "ForStatement") {
          return block.init === declaration;
        }
        return block.left === declaration;
      }
      return Boolean(node.init);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow initialization in variable declarations",
          recommended: false,
          url: "https://eslint.org/docs/rules/init-declarations"
        },
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["never"]
                },
                {
                  type: "object",
                  properties: {
                    ignoreForLoopInit: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        messages: {
          initialized: "Variable '{{idName}}' should be initialized on declaration.",
          notInitialized: "Variable '{{idName}}' should not be initialized on declaration."
        }
      },
      create(context) {
        const MODE_ALWAYS = "always", MODE_NEVER = "never";
        const mode = context.options[0] || MODE_ALWAYS;
        const params = context.options[1] || {};
        return {
          "VariableDeclaration:exit"(node) {
            const kind = node.kind, declarations = node.declarations;
            for (let i = 0; i < declarations.length; ++i) {
              const declaration = declarations[i], id = declaration.id, initialized = isInitialized(declaration), isIgnoredForLoop = params.ignoreForLoopInit && isForLoop(node.parent);
              let messageId = "";
              if (mode === MODE_ALWAYS && !initialized) {
                messageId = "initialized";
              } else if (mode === MODE_NEVER && kind !== "const" && initialized && !isIgnoredForLoop) {
                messageId = "notInitialized";
              }
              if (id.type === "Identifier" && messageId) {
                context.report({
                  node: declaration,
                  messageId,
                  data: {
                    idName: id.name
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/jsx-quotes.js
var require_jsx_quotes = __commonJS({
  "node_modules/eslint/lib/rules/jsx-quotes.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var QUOTE_SETTINGS = {
      "prefer-double": {
        quote: '"',
        description: "singlequote",
        convert(str) {
          return str.replace(/'/gu, '"');
        }
      },
      "prefer-single": {
        quote: "'",
        description: "doublequote",
        convert(str) {
          return str.replace(/"/gu, "'");
        }
      }
    };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce the consistent use of either double or single quotes in JSX attributes",
          recommended: false,
          url: "https://eslint.org/docs/rules/jsx-quotes"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["prefer-single", "prefer-double"]
          }
        ],
        messages: {
          unexpected: "Unexpected usage of {{description}}."
        }
      },
      create(context) {
        const quoteOption = context.options[0] || "prefer-double", setting = QUOTE_SETTINGS[quoteOption];
        function usesExpectedQuotes(node) {
          return node.value.includes(setting.quote) || astUtils.isSurroundedBy(node.raw, setting.quote);
        }
        return {
          JSXAttribute(node) {
            const attributeValue = node.value;
            if (attributeValue && astUtils.isStringLiteral(attributeValue) && !usesExpectedQuotes(attributeValue)) {
              context.report({
                node: attributeValue,
                messageId: "unexpected",
                data: {
                  description: setting.description
                },
                fix(fixer) {
                  return fixer.replaceText(attributeValue, setting.convert(attributeValue.raw));
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/key-spacing.js
var require_key_spacing = __commonJS({
  "node_modules/eslint/lib/rules/key-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var GraphemeSplitter = require_grapheme_splitter();
    var splitter = new GraphemeSplitter();
    function containsLineTerminator(str) {
      return astUtils.LINEBREAK_MATCHER.test(str);
    }
    function last2(arr) {
      return arr[arr.length - 1];
    }
    function isSingleLine(node) {
      return node.loc.end.line === node.loc.start.line;
    }
    function isSingleLineProperties(properties) {
      const [firstProp] = properties, lastProp = last2(properties);
      return firstProp.loc.start.line === lastProp.loc.end.line;
    }
    function initOptionProperty(toOptions, fromOptions) {
      toOptions.mode = fromOptions.mode || "strict";
      if (typeof fromOptions.beforeColon !== "undefined") {
        toOptions.beforeColon = +fromOptions.beforeColon;
      } else {
        toOptions.beforeColon = 0;
      }
      if (typeof fromOptions.afterColon !== "undefined") {
        toOptions.afterColon = +fromOptions.afterColon;
      } else {
        toOptions.afterColon = 1;
      }
      if (typeof fromOptions.align !== "undefined") {
        if (typeof fromOptions.align === "object") {
          toOptions.align = fromOptions.align;
        } else {
          toOptions.align = {
            on: fromOptions.align,
            mode: toOptions.mode,
            beforeColon: toOptions.beforeColon,
            afterColon: toOptions.afterColon
          };
        }
      }
      return toOptions;
    }
    function initOptions(toOptions, fromOptions) {
      if (typeof fromOptions.align === "object") {
        toOptions.align = initOptionProperty({}, fromOptions.align);
        toOptions.align.on = fromOptions.align.on || "colon";
        toOptions.align.mode = fromOptions.align.mode || "strict";
        toOptions.multiLine = initOptionProperty({}, fromOptions.multiLine || fromOptions);
        toOptions.singleLine = initOptionProperty({}, fromOptions.singleLine || fromOptions);
      } else {
        toOptions.multiLine = initOptionProperty({}, fromOptions.multiLine || fromOptions);
        toOptions.singleLine = initOptionProperty({}, fromOptions.singleLine || fromOptions);
        if (toOptions.multiLine.align) {
          toOptions.align = {
            on: toOptions.multiLine.align.on,
            mode: toOptions.multiLine.align.mode || toOptions.multiLine.mode,
            beforeColon: toOptions.multiLine.align.beforeColon,
            afterColon: toOptions.multiLine.align.afterColon
          };
        }
      }
      return toOptions;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing between keys and values in object literal properties",
          recommended: false,
          url: "https://eslint.org/docs/rules/key-spacing"
        },
        fixable: "whitespace",
        schema: [{
          anyOf: [
            {
              type: "object",
              properties: {
                align: {
                  anyOf: [
                    {
                      enum: ["colon", "value"]
                    },
                    {
                      type: "object",
                      properties: {
                        mode: {
                          enum: ["strict", "minimum"]
                        },
                        on: {
                          enum: ["colon", "value"]
                        },
                        beforeColon: {
                          type: "boolean"
                        },
                        afterColon: {
                          type: "boolean"
                        }
                      },
                      additionalProperties: false
                    }
                  ]
                },
                mode: {
                  enum: ["strict", "minimum"]
                },
                beforeColon: {
                  type: "boolean"
                },
                afterColon: {
                  type: "boolean"
                }
              },
              additionalProperties: false
            },
            {
              type: "object",
              properties: {
                singleLine: {
                  type: "object",
                  properties: {
                    mode: {
                      enum: ["strict", "minimum"]
                    },
                    beforeColon: {
                      type: "boolean"
                    },
                    afterColon: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                },
                multiLine: {
                  type: "object",
                  properties: {
                    align: {
                      anyOf: [
                        {
                          enum: ["colon", "value"]
                        },
                        {
                          type: "object",
                          properties: {
                            mode: {
                              enum: ["strict", "minimum"]
                            },
                            on: {
                              enum: ["colon", "value"]
                            },
                            beforeColon: {
                              type: "boolean"
                            },
                            afterColon: {
                              type: "boolean"
                            }
                          },
                          additionalProperties: false
                        }
                      ]
                    },
                    mode: {
                      enum: ["strict", "minimum"]
                    },
                    beforeColon: {
                      type: "boolean"
                    },
                    afterColon: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              },
              additionalProperties: false
            },
            {
              type: "object",
              properties: {
                singleLine: {
                  type: "object",
                  properties: {
                    mode: {
                      enum: ["strict", "minimum"]
                    },
                    beforeColon: {
                      type: "boolean"
                    },
                    afterColon: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                },
                multiLine: {
                  type: "object",
                  properties: {
                    mode: {
                      enum: ["strict", "minimum"]
                    },
                    beforeColon: {
                      type: "boolean"
                    },
                    afterColon: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                },
                align: {
                  type: "object",
                  properties: {
                    mode: {
                      enum: ["strict", "minimum"]
                    },
                    on: {
                      enum: ["colon", "value"]
                    },
                    beforeColon: {
                      type: "boolean"
                    },
                    afterColon: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              },
              additionalProperties: false
            }
          ]
        }],
        messages: {
          extraKey: "Extra space after {{computed}}key '{{key}}'.",
          extraValue: "Extra space before value for {{computed}}key '{{key}}'.",
          missingKey: "Missing space after {{computed}}key '{{key}}'.",
          missingValue: "Missing space before value for {{computed}}key '{{key}}'."
        }
      },
      create(context) {
        const options = context.options[0] || {}, ruleOptions = initOptions({}, options), multiLineOptions = ruleOptions.multiLine, singleLineOptions = ruleOptions.singleLine, alignmentOptions = ruleOptions.align || null;
        const sourceCode = context.getSourceCode();
        function isKeyValueProperty(property) {
          return !(property.method || property.shorthand || property.kind !== "init" || property.type !== "Property");
        }
        function getNextColon(node) {
          return sourceCode.getTokenAfter(node, astUtils.isColonToken);
        }
        function getLastTokenBeforeColon(node) {
          const colonToken = getNextColon(node);
          return sourceCode.getTokenBefore(colonToken);
        }
        function getFirstTokenAfterColon(node) {
          const colonToken = getNextColon(node);
          return sourceCode.getTokenAfter(colonToken);
        }
        function continuesPropertyGroup(lastMember, candidate) {
          const groupEndLine = lastMember.loc.start.line, candidateValueStartLine = (isKeyValueProperty(candidate) ? getFirstTokenAfterColon(candidate.key) : candidate).loc.start.line;
          if (candidateValueStartLine - groupEndLine <= 1) {
            return true;
          }
          const leadingComments = sourceCode.getCommentsBefore(candidate);
          if (leadingComments.length && leadingComments[0].loc.start.line - groupEndLine <= 1 && candidateValueStartLine - last2(leadingComments).loc.end.line <= 1) {
            for (let i = 1; i < leadingComments.length; i++) {
              if (leadingComments[i].loc.start.line - leadingComments[i - 1].loc.end.line > 1) {
                return false;
              }
            }
            return true;
          }
          return false;
        }
        function getKey(property) {
          const key = property.key;
          if (property.computed) {
            return sourceCode.getText().slice(key.range[0], key.range[1]);
          }
          return astUtils.getStaticPropertyName(property);
        }
        function report(property, side, whitespace, expected, mode) {
          const diff = whitespace.length - expected;
          if ((diff && mode === "strict" || diff < 0 && mode === "minimum" || diff > 0 && !expected && mode === "minimum") && !(expected && containsLineTerminator(whitespace))) {
            const nextColon = getNextColon(property.key), tokenBeforeColon = sourceCode.getTokenBefore(nextColon, { includeComments: true }), tokenAfterColon = sourceCode.getTokenAfter(nextColon, { includeComments: true }), isKeySide = side === "key", isExtra = diff > 0, diffAbs = Math.abs(diff), spaces = Array(diffAbs + 1).join(" ");
            const locStart = isKeySide ? tokenBeforeColon.loc.end : nextColon.loc.start;
            const locEnd = isKeySide ? nextColon.loc.start : tokenAfterColon.loc.start;
            const missingLoc = isKeySide ? tokenBeforeColon.loc : tokenAfterColon.loc;
            const loc = isExtra ? { start: locStart, end: locEnd } : missingLoc;
            let fix;
            if (isExtra) {
              let range;
              if (isKeySide) {
                range = [tokenBeforeColon.range[1], tokenBeforeColon.range[1] + diffAbs];
              } else {
                range = [tokenAfterColon.range[0] - diffAbs, tokenAfterColon.range[0]];
              }
              fix = function(fixer) {
                return fixer.removeRange(range);
              };
            } else {
              if (isKeySide) {
                fix = function(fixer) {
                  return fixer.insertTextAfter(tokenBeforeColon, spaces);
                };
              } else {
                fix = function(fixer) {
                  return fixer.insertTextBefore(tokenAfterColon, spaces);
                };
              }
            }
            let messageId = "";
            if (isExtra) {
              messageId = side === "key" ? "extraKey" : "extraValue";
            } else {
              messageId = side === "key" ? "missingKey" : "missingValue";
            }
            context.report({
              node: property[side],
              loc,
              messageId,
              data: {
                computed: property.computed ? "computed " : "",
                key: getKey(property)
              },
              fix
            });
          }
        }
        function getKeyWidth(property) {
          const startToken = sourceCode.getFirstToken(property);
          const endToken = getLastTokenBeforeColon(property.key);
          return splitter.countGraphemes(sourceCode.getText().slice(startToken.range[0], endToken.range[1]));
        }
        function getPropertyWhitespace(property) {
          const whitespace = /(\s*):(\s*)/u.exec(sourceCode.getText().slice(
            property.key.range[1],
            property.value.range[0]
          ));
          if (whitespace) {
            return {
              beforeColon: whitespace[1],
              afterColon: whitespace[2]
            };
          }
          return null;
        }
        function createGroups(node) {
          if (node.properties.length === 1) {
            return [node.properties];
          }
          return node.properties.reduce((groups, property) => {
            const currentGroup = last2(groups), prev = last2(currentGroup);
            if (!prev || continuesPropertyGroup(prev, property)) {
              currentGroup.push(property);
            } else {
              groups.push([property]);
            }
            return groups;
          }, [
            []
          ]);
        }
        function verifyGroupAlignment(properties) {
          const length = properties.length, widths = properties.map(getKeyWidth), align = alignmentOptions.on;
          let targetWidth = Math.max(...widths), beforeColon, afterColon, mode;
          if (alignmentOptions && length > 1) {
            beforeColon = alignmentOptions.beforeColon;
            afterColon = alignmentOptions.afterColon;
            mode = alignmentOptions.mode;
          } else {
            beforeColon = multiLineOptions.beforeColon;
            afterColon = multiLineOptions.afterColon;
            mode = alignmentOptions.mode;
          }
          targetWidth += align === "colon" ? beforeColon : afterColon;
          for (let i = 0; i < length; i++) {
            const property = properties[i];
            const whitespace = getPropertyWhitespace(property);
            if (whitespace) {
              const width = widths[i];
              if (align === "value") {
                report(property, "key", whitespace.beforeColon, beforeColon, mode);
                report(property, "value", whitespace.afterColon, targetWidth - width, mode);
              } else {
                report(property, "key", whitespace.beforeColon, targetWidth - width, mode);
                report(property, "value", whitespace.afterColon, afterColon, mode);
              }
            }
          }
        }
        function verifySpacing(node, lineOptions) {
          const actual = getPropertyWhitespace(node);
          if (actual) {
            report(node, "key", actual.beforeColon, lineOptions.beforeColon, lineOptions.mode);
            report(node, "value", actual.afterColon, lineOptions.afterColon, lineOptions.mode);
          }
        }
        function verifyListSpacing(properties, lineOptions) {
          const length = properties.length;
          for (let i = 0; i < length; i++) {
            verifySpacing(properties[i], lineOptions);
          }
        }
        function verifyAlignment(node) {
          createGroups(node).forEach((group) => {
            const properties = group.filter(isKeyValueProperty);
            if (properties.length > 0 && isSingleLineProperties(properties)) {
              verifyListSpacing(properties, multiLineOptions);
            } else {
              verifyGroupAlignment(properties);
            }
          });
        }
        if (alignmentOptions) {
          return {
            ObjectExpression(node) {
              if (isSingleLine(node)) {
                verifyListSpacing(node.properties.filter(isKeyValueProperty), singleLineOptions);
              } else {
                verifyAlignment(node);
              }
            }
          };
        }
        return {
          Property(node) {
            verifySpacing(node, isSingleLine(node.parent) ? singleLineOptions : multiLineOptions);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/keyword-spacing.js
var require_keyword_spacing = __commonJS({
  "node_modules/eslint/lib/rules/keyword-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var keywords = require_keywords();
    var PREV_TOKEN = /^[)\]}>]$/u;
    var NEXT_TOKEN = /^(?:[([{<~!]|\+\+?|--?)$/u;
    var PREV_TOKEN_M = /^[)\]}>*]$/u;
    var NEXT_TOKEN_M = /^[{*]$/u;
    var TEMPLATE_OPEN_PAREN = /\$\{$/u;
    var TEMPLATE_CLOSE_PAREN = /^\}/u;
    var CHECK_TYPE = /^(?:JSXElement|RegularExpression|String|Template|PrivateIdentifier)$/u;
    var KEYS = keywords.concat(["as", "async", "await", "from", "get", "let", "of", "set", "yield"]);
    (function() {
      KEYS.sort();
      for (let i = 1; i < KEYS.length; ++i) {
        if (KEYS[i] === KEYS[i - 1]) {
          throw new Error(`Duplication was found in the keyword list: ${KEYS[i]}`);
        }
      }
    })();
    function isOpenParenOfTemplate(token) {
      return token.type === "Template" && TEMPLATE_OPEN_PAREN.test(token.value);
    }
    function isCloseParenOfTemplate(token) {
      return token.type === "Template" && TEMPLATE_CLOSE_PAREN.test(token.value);
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before and after keywords",
          recommended: false,
          url: "https://eslint.org/docs/rules/keyword-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              before: { type: "boolean", default: true },
              after: { type: "boolean", default: true },
              overrides: {
                type: "object",
                properties: KEYS.reduce((retv, key) => {
                  retv[key] = {
                    type: "object",
                    properties: {
                      before: { type: "boolean" },
                      after: { type: "boolean" }
                    },
                    additionalProperties: false
                  };
                  return retv;
                }, {}),
                additionalProperties: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expectedBefore: 'Expected space(s) before "{{value}}".',
          expectedAfter: 'Expected space(s) after "{{value}}".',
          unexpectedBefore: 'Unexpected space(s) before "{{value}}".',
          unexpectedAfter: 'Unexpected space(s) after "{{value}}".'
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const tokensToIgnore = /* @__PURE__ */ new WeakSet();
        function expectSpaceBefore(token, pattern) {
          const prevToken = sourceCode.getTokenBefore(token);
          if (prevToken && (CHECK_TYPE.test(prevToken.type) || pattern.test(prevToken.value)) && !isOpenParenOfTemplate(prevToken) && !tokensToIgnore.has(prevToken) && astUtils.isTokenOnSameLine(prevToken, token) && !sourceCode.isSpaceBetweenTokens(prevToken, token)) {
            context.report({
              loc: token.loc,
              messageId: "expectedBefore",
              data: token,
              fix(fixer) {
                return fixer.insertTextBefore(token, " ");
              }
            });
          }
        }
        function unexpectSpaceBefore(token, pattern) {
          const prevToken = sourceCode.getTokenBefore(token);
          if (prevToken && (CHECK_TYPE.test(prevToken.type) || pattern.test(prevToken.value)) && !isOpenParenOfTemplate(prevToken) && !tokensToIgnore.has(prevToken) && astUtils.isTokenOnSameLine(prevToken, token) && sourceCode.isSpaceBetweenTokens(prevToken, token)) {
            context.report({
              loc: { start: prevToken.loc.end, end: token.loc.start },
              messageId: "unexpectedBefore",
              data: token,
              fix(fixer) {
                return fixer.removeRange([prevToken.range[1], token.range[0]]);
              }
            });
          }
        }
        function expectSpaceAfter(token, pattern) {
          const nextToken = sourceCode.getTokenAfter(token);
          if (nextToken && (CHECK_TYPE.test(nextToken.type) || pattern.test(nextToken.value)) && !isCloseParenOfTemplate(nextToken) && !tokensToIgnore.has(nextToken) && astUtils.isTokenOnSameLine(token, nextToken) && !sourceCode.isSpaceBetweenTokens(token, nextToken)) {
            context.report({
              loc: token.loc,
              messageId: "expectedAfter",
              data: token,
              fix(fixer) {
                return fixer.insertTextAfter(token, " ");
              }
            });
          }
        }
        function unexpectSpaceAfter(token, pattern) {
          const nextToken = sourceCode.getTokenAfter(token);
          if (nextToken && (CHECK_TYPE.test(nextToken.type) || pattern.test(nextToken.value)) && !isCloseParenOfTemplate(nextToken) && !tokensToIgnore.has(nextToken) && astUtils.isTokenOnSameLine(token, nextToken) && sourceCode.isSpaceBetweenTokens(token, nextToken)) {
            context.report({
              loc: { start: token.loc.end, end: nextToken.loc.start },
              messageId: "unexpectedAfter",
              data: token,
              fix(fixer) {
                return fixer.removeRange([token.range[1], nextToken.range[0]]);
              }
            });
          }
        }
        function parseOptions(options = {}) {
          const before = options.before !== false;
          const after = options.after !== false;
          const defaultValue = {
            before: before ? expectSpaceBefore : unexpectSpaceBefore,
            after: after ? expectSpaceAfter : unexpectSpaceAfter
          };
          const overrides = options && options.overrides || {};
          const retv = /* @__PURE__ */ Object.create(null);
          for (let i = 0; i < KEYS.length; ++i) {
            const key = KEYS[i];
            const override = overrides[key];
            if (override) {
              const thisBefore = "before" in override ? override.before : before;
              const thisAfter = "after" in override ? override.after : after;
              retv[key] = {
                before: thisBefore ? expectSpaceBefore : unexpectSpaceBefore,
                after: thisAfter ? expectSpaceAfter : unexpectSpaceAfter
              };
            } else {
              retv[key] = defaultValue;
            }
          }
          return retv;
        }
        const checkMethodMap = parseOptions(context.options[0]);
        function checkSpacingBefore(token, pattern) {
          checkMethodMap[token.value].before(token, pattern || PREV_TOKEN);
        }
        function checkSpacingAfter(token, pattern) {
          checkMethodMap[token.value].after(token, pattern || NEXT_TOKEN);
        }
        function checkSpacingAround(token) {
          checkSpacingBefore(token);
          checkSpacingAfter(token);
        }
        function checkSpacingAroundFirstToken(node) {
          const firstToken = node && sourceCode.getFirstToken(node);
          if (firstToken && firstToken.type === "Keyword") {
            checkSpacingAround(firstToken);
          }
        }
        function checkSpacingBeforeFirstToken(node) {
          const firstToken = node && sourceCode.getFirstToken(node);
          if (firstToken && firstToken.type === "Keyword") {
            checkSpacingBefore(firstToken);
          }
        }
        function checkSpacingAroundTokenBefore(node) {
          if (node) {
            const token = sourceCode.getTokenBefore(node, astUtils.isKeywordToken);
            checkSpacingAround(token);
          }
        }
        function checkSpacingForFunction(node) {
          const firstToken = node && sourceCode.getFirstToken(node);
          if (firstToken && (firstToken.type === "Keyword" && firstToken.value === "function" || firstToken.value === "async")) {
            checkSpacingBefore(firstToken);
          }
        }
        function checkSpacingForClass(node) {
          checkSpacingAroundFirstToken(node);
          checkSpacingAroundTokenBefore(node.superClass);
        }
        function checkSpacingForIfStatement(node) {
          checkSpacingAroundFirstToken(node);
          checkSpacingAroundTokenBefore(node.alternate);
        }
        function checkSpacingForTryStatement(node) {
          checkSpacingAroundFirstToken(node);
          checkSpacingAroundFirstToken(node.handler);
          checkSpacingAroundTokenBefore(node.finalizer);
        }
        function checkSpacingForDoWhileStatement(node) {
          checkSpacingAroundFirstToken(node);
          checkSpacingAroundTokenBefore(node.test);
        }
        function checkSpacingForForInStatement(node) {
          checkSpacingAroundFirstToken(node);
          const inToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
          const previousToken = sourceCode.getTokenBefore(inToken);
          if (previousToken.type !== "PrivateIdentifier") {
            checkSpacingBefore(inToken);
          }
          checkSpacingAfter(inToken);
        }
        function checkSpacingForForOfStatement(node) {
          if (node.await) {
            checkSpacingBefore(sourceCode.getFirstToken(node, 0));
            checkSpacingAfter(sourceCode.getFirstToken(node, 1));
          } else {
            checkSpacingAroundFirstToken(node);
          }
          const ofToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
          const previousToken = sourceCode.getTokenBefore(ofToken);
          if (previousToken.type !== "PrivateIdentifier") {
            checkSpacingBefore(ofToken);
          }
          checkSpacingAfter(ofToken);
        }
        function checkSpacingForModuleDeclaration(node) {
          const firstToken = sourceCode.getFirstToken(node);
          checkSpacingBefore(firstToken, PREV_TOKEN_M);
          checkSpacingAfter(firstToken, NEXT_TOKEN_M);
          if (node.type === "ExportDefaultDeclaration") {
            checkSpacingAround(sourceCode.getTokenAfter(firstToken));
          }
          if (node.type === "ExportAllDeclaration" && node.exported) {
            const asToken = sourceCode.getTokenBefore(node.exported);
            checkSpacingBefore(asToken, PREV_TOKEN_M);
            checkSpacingAfter(asToken, NEXT_TOKEN_M);
          }
          if (node.source) {
            const fromToken = sourceCode.getTokenBefore(node.source);
            checkSpacingBefore(fromToken, PREV_TOKEN_M);
            checkSpacingAfter(fromToken, NEXT_TOKEN_M);
          }
        }
        function checkSpacingForImportSpecifier(node) {
          if (node.imported.range[0] !== node.local.range[0]) {
            const asToken = sourceCode.getTokenBefore(node.local);
            checkSpacingBefore(asToken, PREV_TOKEN_M);
          }
        }
        function checkSpacingForExportSpecifier(node) {
          if (node.local.range[0] !== node.exported.range[0]) {
            const asToken = sourceCode.getTokenBefore(node.exported);
            checkSpacingBefore(asToken, PREV_TOKEN_M);
            checkSpacingAfter(asToken, NEXT_TOKEN_M);
          }
        }
        function checkSpacingForImportNamespaceSpecifier(node) {
          const asToken = sourceCode.getFirstToken(node, 1);
          checkSpacingBefore(asToken, PREV_TOKEN_M);
        }
        function checkSpacingForProperty(node) {
          if (node.static) {
            checkSpacingAroundFirstToken(node);
          }
          if (node.kind === "get" || node.kind === "set" || (node.method || node.type === "MethodDefinition") && node.value.async) {
            const token = sourceCode.getTokenBefore(
              node.key,
              (tok) => {
                switch (tok.value) {
                  case "get":
                  case "set":
                  case "async":
                    return true;
                  default:
                    return false;
                }
              }
            );
            if (!token) {
              throw new Error("Failed to find token get, set, or async beside method name");
            }
            checkSpacingAround(token);
          }
        }
        function checkSpacingForAwaitExpression(node) {
          checkSpacingBefore(sourceCode.getFirstToken(node));
        }
        return {
          // Statements
          DebuggerStatement: checkSpacingAroundFirstToken,
          WithStatement: checkSpacingAroundFirstToken,
          // Statements - Control flow
          BreakStatement: checkSpacingAroundFirstToken,
          ContinueStatement: checkSpacingAroundFirstToken,
          ReturnStatement: checkSpacingAroundFirstToken,
          ThrowStatement: checkSpacingAroundFirstToken,
          TryStatement: checkSpacingForTryStatement,
          // Statements - Choice
          IfStatement: checkSpacingForIfStatement,
          SwitchStatement: checkSpacingAroundFirstToken,
          SwitchCase: checkSpacingAroundFirstToken,
          // Statements - Loops
          DoWhileStatement: checkSpacingForDoWhileStatement,
          ForInStatement: checkSpacingForForInStatement,
          ForOfStatement: checkSpacingForForOfStatement,
          ForStatement: checkSpacingAroundFirstToken,
          WhileStatement: checkSpacingAroundFirstToken,
          // Statements - Declarations
          ClassDeclaration: checkSpacingForClass,
          ExportNamedDeclaration: checkSpacingForModuleDeclaration,
          ExportDefaultDeclaration: checkSpacingForModuleDeclaration,
          ExportAllDeclaration: checkSpacingForModuleDeclaration,
          FunctionDeclaration: checkSpacingForFunction,
          ImportDeclaration: checkSpacingForModuleDeclaration,
          VariableDeclaration: checkSpacingAroundFirstToken,
          // Expressions
          ArrowFunctionExpression: checkSpacingForFunction,
          AwaitExpression: checkSpacingForAwaitExpression,
          ClassExpression: checkSpacingForClass,
          FunctionExpression: checkSpacingForFunction,
          NewExpression: checkSpacingBeforeFirstToken,
          Super: checkSpacingBeforeFirstToken,
          ThisExpression: checkSpacingBeforeFirstToken,
          UnaryExpression: checkSpacingBeforeFirstToken,
          YieldExpression: checkSpacingBeforeFirstToken,
          // Others
          ImportSpecifier: checkSpacingForImportSpecifier,
          ExportSpecifier: checkSpacingForExportSpecifier,
          ImportNamespaceSpecifier: checkSpacingForImportNamespaceSpecifier,
          MethodDefinition: checkSpacingForProperty,
          PropertyDefinition: checkSpacingForProperty,
          StaticBlock: checkSpacingAroundFirstToken,
          Property: checkSpacingForProperty,
          // To avoid conflicts with `space-infix-ops`, e.g. `a > this.b`
          "BinaryExpression[operator='>']"(node) {
            const operatorToken = sourceCode.getTokenBefore(node.right, astUtils.isNotOpeningParenToken);
            tokensToIgnore.add(operatorToken);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/line-comment-position.js
var require_line_comment_position = __commonJS({
  "node_modules/eslint/lib/rules/line-comment-position.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce position of line comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/line-comment-position"
        },
        schema: [
          {
            oneOf: [
              {
                enum: ["above", "beside"]
              },
              {
                type: "object",
                properties: {
                  position: {
                    enum: ["above", "beside"]
                  },
                  ignorePattern: {
                    type: "string"
                  },
                  applyDefaultPatterns: {
                    type: "boolean"
                  },
                  applyDefaultIgnorePatterns: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          above: "Expected comment to be above code.",
          beside: "Expected comment to be beside code."
        }
      },
      create(context) {
        const options = context.options[0];
        let above, ignorePattern, applyDefaultIgnorePatterns = true;
        if (!options || typeof options === "string") {
          above = !options || options === "above";
        } else {
          above = !options.position || options.position === "above";
          ignorePattern = options.ignorePattern;
          if (Object.prototype.hasOwnProperty.call(options, "applyDefaultIgnorePatterns")) {
            applyDefaultIgnorePatterns = options.applyDefaultIgnorePatterns;
          } else {
            applyDefaultIgnorePatterns = options.applyDefaultPatterns !== false;
          }
        }
        const defaultIgnoreRegExp = astUtils.COMMENTS_IGNORE_PATTERN;
        const fallThroughRegExp = /^\s*falls?\s?through/u;
        const customIgnoreRegExp = new RegExp(ignorePattern, "u");
        const sourceCode = context.getSourceCode();
        return {
          Program() {
            const comments = sourceCode.getAllComments();
            comments.filter((token) => token.type === "Line").forEach((node) => {
              if (applyDefaultIgnorePatterns && (defaultIgnoreRegExp.test(node.value) || fallThroughRegExp.test(node.value))) {
                return;
              }
              if (ignorePattern && customIgnoreRegExp.test(node.value)) {
                return;
              }
              const previous = sourceCode.getTokenBefore(node, { includeComments: true });
              const isOnSameLine = previous && previous.loc.end.line === node.loc.start.line;
              if (above) {
                if (isOnSameLine) {
                  context.report({
                    node,
                    messageId: "above"
                  });
                }
              } else {
                if (!isOnSameLine) {
                  context.report({
                    node,
                    messageId: "beside"
                  });
                }
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/linebreak-style.js
var require_linebreak_style = __commonJS({
  "node_modules/eslint/lib/rules/linebreak-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent linebreak style",
          recommended: false,
          url: "https://eslint.org/docs/rules/linebreak-style"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["unix", "windows"]
          }
        ],
        messages: {
          expectedLF: "Expected linebreaks to be 'LF' but found 'CRLF'.",
          expectedCRLF: "Expected linebreaks to be 'CRLF' but found 'LF'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function createFix(range, text) {
          return function(fixer) {
            return fixer.replaceTextRange(range, text);
          };
        }
        return {
          Program: function checkForLinebreakStyle(node) {
            const linebreakStyle = context.options[0] || "unix", expectedLF = linebreakStyle === "unix", expectedLFChars = expectedLF ? "\n" : "\r\n", source = sourceCode.getText(), pattern = astUtils.createGlobalLinebreakMatcher();
            let match;
            let i = 0;
            while ((match = pattern.exec(source)) !== null) {
              i++;
              if (match[0] === expectedLFChars) {
                continue;
              }
              const index = match.index;
              const range = [index, index + match[0].length];
              context.report({
                node,
                loc: {
                  start: {
                    line: i,
                    column: sourceCode.lines[i - 1].length
                  },
                  end: {
                    line: i + 1,
                    column: 0
                  }
                },
                messageId: expectedLF ? "expectedLF" : "expectedCRLF",
                fix: createFix(range, expectedLFChars)
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/lines-around-comment.js
var require_lines_around_comment = __commonJS({
  "node_modules/eslint/lib/rules/lines-around-comment.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function getEmptyLineNums(lines) {
      const emptyLines = lines.map((line, i) => ({
        code: line.trim(),
        num: i + 1
      })).filter((line) => !line.code).map((line) => line.num);
      return emptyLines;
    }
    function getCommentLineNums(comments) {
      const lines = [];
      comments.forEach((token) => {
        const start = token.loc.start.line;
        const end = token.loc.end.line;
        lines.push(start, end);
      });
      return lines;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require empty lines around comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/lines-around-comment"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              beforeBlockComment: {
                type: "boolean",
                default: true
              },
              afterBlockComment: {
                type: "boolean",
                default: false
              },
              beforeLineComment: {
                type: "boolean",
                default: false
              },
              afterLineComment: {
                type: "boolean",
                default: false
              },
              allowBlockStart: {
                type: "boolean",
                default: false
              },
              allowBlockEnd: {
                type: "boolean",
                default: false
              },
              allowClassStart: {
                type: "boolean"
              },
              allowClassEnd: {
                type: "boolean"
              },
              allowObjectStart: {
                type: "boolean"
              },
              allowObjectEnd: {
                type: "boolean"
              },
              allowArrayStart: {
                type: "boolean"
              },
              allowArrayEnd: {
                type: "boolean"
              },
              ignorePattern: {
                type: "string"
              },
              applyDefaultIgnorePatterns: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          after: "Expected line after comment.",
          before: "Expected line before comment."
        }
      },
      create(context) {
        const options = Object.assign({}, context.options[0]);
        const ignorePattern = options.ignorePattern;
        const defaultIgnoreRegExp = astUtils.COMMENTS_IGNORE_PATTERN;
        const customIgnoreRegExp = new RegExp(ignorePattern, "u");
        const applyDefaultIgnorePatterns = options.applyDefaultIgnorePatterns !== false;
        options.beforeBlockComment = typeof options.beforeBlockComment !== "undefined" ? options.beforeBlockComment : true;
        const sourceCode = context.getSourceCode();
        const lines = sourceCode.lines, numLines = lines.length + 1, comments = sourceCode.getAllComments(), commentLines = getCommentLineNums(comments), emptyLines = getEmptyLineNums(lines), commentAndEmptyLines = new Set(commentLines.concat(emptyLines));
        function codeAroundComment(token) {
          let currentToken = token;
          do {
            currentToken = sourceCode.getTokenBefore(currentToken, { includeComments: true });
          } while (currentToken && astUtils.isCommentToken(currentToken));
          if (currentToken && astUtils.isTokenOnSameLine(currentToken, token)) {
            return true;
          }
          currentToken = token;
          do {
            currentToken = sourceCode.getTokenAfter(currentToken, { includeComments: true });
          } while (currentToken && astUtils.isCommentToken(currentToken));
          if (currentToken && astUtils.isTokenOnSameLine(token, currentToken)) {
            return true;
          }
          return false;
        }
        function isParentNodeType(parent, nodeType) {
          return parent.type === nodeType || parent.body && parent.body.type === nodeType || parent.consequent && parent.consequent.type === nodeType;
        }
        function getParentNodeOfToken(token) {
          const node = sourceCode.getNodeByRangeIndex(token.range[0]);
          if (node && node.type === "StaticBlock") {
            const openingBrace = sourceCode.getFirstToken(node, { skip: 1 });
            return token.range[0] >= openingBrace.range[0] ? node : null;
          }
          return node;
        }
        function isCommentAtParentStart(token, nodeType) {
          const parent = getParentNodeOfToken(token);
          if (parent && isParentNodeType(parent, nodeType)) {
            let parentStartNodeOrToken = parent;
            if (parent.type === "StaticBlock") {
              parentStartNodeOrToken = sourceCode.getFirstToken(parent, { skip: 1 });
            } else if (parent.type === "SwitchStatement") {
              parentStartNodeOrToken = sourceCode.getTokenAfter(parent.discriminant, {
                filter: astUtils.isOpeningBraceToken
              });
            }
            return token.loc.start.line - parentStartNodeOrToken.loc.start.line === 1;
          }
          return false;
        }
        function isCommentAtParentEnd(token, nodeType) {
          const parent = getParentNodeOfToken(token);
          return !!parent && isParentNodeType(parent, nodeType) && parent.loc.end.line - token.loc.end.line === 1;
        }
        function isCommentAtBlockStart(token) {
          return isCommentAtParentStart(token, "ClassBody") || isCommentAtParentStart(token, "BlockStatement") || isCommentAtParentStart(token, "StaticBlock") || isCommentAtParentStart(token, "SwitchCase") || isCommentAtParentStart(token, "SwitchStatement");
        }
        function isCommentAtBlockEnd(token) {
          return isCommentAtParentEnd(token, "ClassBody") || isCommentAtParentEnd(token, "BlockStatement") || isCommentAtParentEnd(token, "StaticBlock") || isCommentAtParentEnd(token, "SwitchCase") || isCommentAtParentEnd(token, "SwitchStatement");
        }
        function isCommentAtClassStart(token) {
          return isCommentAtParentStart(token, "ClassBody");
        }
        function isCommentAtClassEnd(token) {
          return isCommentAtParentEnd(token, "ClassBody");
        }
        function isCommentAtObjectStart(token) {
          return isCommentAtParentStart(token, "ObjectExpression") || isCommentAtParentStart(token, "ObjectPattern");
        }
        function isCommentAtObjectEnd(token) {
          return isCommentAtParentEnd(token, "ObjectExpression") || isCommentAtParentEnd(token, "ObjectPattern");
        }
        function isCommentAtArrayStart(token) {
          return isCommentAtParentStart(token, "ArrayExpression") || isCommentAtParentStart(token, "ArrayPattern");
        }
        function isCommentAtArrayEnd(token) {
          return isCommentAtParentEnd(token, "ArrayExpression") || isCommentAtParentEnd(token, "ArrayPattern");
        }
        function checkForEmptyLine(token, opts) {
          if (applyDefaultIgnorePatterns && defaultIgnoreRegExp.test(token.value)) {
            return;
          }
          if (ignorePattern && customIgnoreRegExp.test(token.value)) {
            return;
          }
          let after = opts.after, before = opts.before;
          const prevLineNum = token.loc.start.line - 1, nextLineNum = token.loc.end.line + 1, commentIsNotAlone = codeAroundComment(token);
          const blockStartAllowed = options.allowBlockStart && isCommentAtBlockStart(token) && !(options.allowClassStart === false && isCommentAtClassStart(token)), blockEndAllowed = options.allowBlockEnd && isCommentAtBlockEnd(token) && !(options.allowClassEnd === false && isCommentAtClassEnd(token)), classStartAllowed = options.allowClassStart && isCommentAtClassStart(token), classEndAllowed = options.allowClassEnd && isCommentAtClassEnd(token), objectStartAllowed = options.allowObjectStart && isCommentAtObjectStart(token), objectEndAllowed = options.allowObjectEnd && isCommentAtObjectEnd(token), arrayStartAllowed = options.allowArrayStart && isCommentAtArrayStart(token), arrayEndAllowed = options.allowArrayEnd && isCommentAtArrayEnd(token);
          const exceptionStartAllowed = blockStartAllowed || classStartAllowed || objectStartAllowed || arrayStartAllowed;
          const exceptionEndAllowed = blockEndAllowed || classEndAllowed || objectEndAllowed || arrayEndAllowed;
          if (prevLineNum < 1) {
            before = false;
          }
          if (nextLineNum >= numLines) {
            after = false;
          }
          if (commentIsNotAlone) {
            return;
          }
          const previousTokenOrComment = sourceCode.getTokenBefore(token, { includeComments: true });
          const nextTokenOrComment = sourceCode.getTokenAfter(token, { includeComments: true });
          if (!exceptionStartAllowed && before && !commentAndEmptyLines.has(prevLineNum) && !(astUtils.isCommentToken(previousTokenOrComment) && astUtils.isTokenOnSameLine(previousTokenOrComment, token))) {
            const lineStart = token.range[0] - token.loc.start.column;
            const range = [lineStart, lineStart];
            context.report({
              node: token,
              messageId: "before",
              fix(fixer) {
                return fixer.insertTextBeforeRange(range, "\n");
              }
            });
          }
          if (!exceptionEndAllowed && after && !commentAndEmptyLines.has(nextLineNum) && !(astUtils.isCommentToken(nextTokenOrComment) && astUtils.isTokenOnSameLine(token, nextTokenOrComment))) {
            context.report({
              node: token,
              messageId: "after",
              fix(fixer) {
                return fixer.insertTextAfter(token, "\n");
              }
            });
          }
        }
        return {
          Program() {
            comments.forEach((token) => {
              if (token.type === "Line") {
                if (options.beforeLineComment || options.afterLineComment) {
                  checkForEmptyLine(token, {
                    after: options.afterLineComment,
                    before: options.beforeLineComment
                  });
                }
              } else if (token.type === "Block") {
                if (options.beforeBlockComment || options.afterBlockComment) {
                  checkForEmptyLine(token, {
                    after: options.afterBlockComment,
                    before: options.beforeBlockComment
                  });
                }
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/lines-around-directive.js
var require_lines_around_directive = __commonJS({
  "node_modules/eslint/lib/rules/lines-around-directive.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow newlines around directives",
          recommended: false,
          url: "https://eslint.org/docs/rules/lines-around-directive"
        },
        schema: [{
          oneOf: [
            {
              enum: ["always", "never"]
            },
            {
              type: "object",
              properties: {
                before: {
                  enum: ["always", "never"]
                },
                after: {
                  enum: ["always", "never"]
                }
              },
              additionalProperties: false,
              minProperties: 2
            }
          ]
        }],
        fixable: "whitespace",
        messages: {
          expected: 'Expected newline {{location}} "{{value}}" directive.',
          unexpected: 'Unexpected newline {{location}} "{{value}}" directive.'
        },
        deprecated: true,
        replacedBy: ["padding-line-between-statements"]
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const config = context.options[0] || "always";
        const expectLineBefore = typeof config === "string" ? config : config.before;
        const expectLineAfter = typeof config === "string" ? config : config.after;
        function hasNewlineBefore(node) {
          const tokenBefore = sourceCode.getTokenBefore(node, { includeComments: true });
          const tokenLineBefore = tokenBefore ? tokenBefore.loc.end.line : 0;
          return node.loc.start.line - tokenLineBefore >= 2;
        }
        function getLastTokenOnLine(node) {
          const lastToken = sourceCode.getLastToken(node);
          const secondToLastToken = sourceCode.getTokenBefore(lastToken);
          return astUtils.isSemicolonToken(lastToken) && lastToken.loc.start.line > secondToLastToken.loc.end.line ? secondToLastToken : lastToken;
        }
        function hasNewlineAfter(node) {
          const lastToken = getLastTokenOnLine(node);
          const tokenAfter = sourceCode.getTokenAfter(lastToken, { includeComments: true });
          return tokenAfter.loc.start.line - lastToken.loc.end.line >= 2;
        }
        function reportError(node, location, expected) {
          context.report({
            node,
            messageId: expected ? "expected" : "unexpected",
            data: {
              value: node.expression.value,
              location
            },
            fix(fixer) {
              const lastToken = getLastTokenOnLine(node);
              if (expected) {
                return location === "before" ? fixer.insertTextBefore(node, "\n") : fixer.insertTextAfter(lastToken, "\n");
              }
              return fixer.removeRange(location === "before" ? [node.range[0] - 1, node.range[0]] : [lastToken.range[1], lastToken.range[1] + 1]);
            }
          });
        }
        function checkDirectives(node) {
          const directives = astUtils.getDirectivePrologue(node);
          if (!directives.length) {
            return;
          }
          const firstDirective = directives[0];
          const leadingComments = sourceCode.getCommentsBefore(firstDirective);
          if (leadingComments.length) {
            if (expectLineBefore === "always" && !hasNewlineBefore(firstDirective)) {
              reportError(firstDirective, "before", true);
            }
            if (expectLineBefore === "never" && hasNewlineBefore(firstDirective)) {
              reportError(firstDirective, "before", false);
            }
          } else if (node.type === "Program" && expectLineBefore === "never" && !leadingComments.length && hasNewlineBefore(firstDirective)) {
            reportError(firstDirective, "before", false);
          }
          const lastDirective = directives[directives.length - 1];
          const statements = node.type === "Program" ? node.body : node.body.body;
          if (lastDirective === statements[statements.length - 1] && !lastDirective.trailingComments) {
            return;
          }
          if (expectLineAfter === "always" && !hasNewlineAfter(lastDirective)) {
            reportError(lastDirective, "after", true);
          }
          if (expectLineAfter === "never" && hasNewlineAfter(lastDirective)) {
            reportError(lastDirective, "after", false);
          }
        }
        return {
          Program: checkDirectives,
          FunctionDeclaration: checkDirectives,
          FunctionExpression: checkDirectives,
          ArrowFunctionExpression: checkDirectives
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/lines-between-class-members.js
var require_lines_between_class_members = __commonJS({
  "node_modules/eslint/lib/rules/lines-between-class-members.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow an empty line between class members",
          recommended: false,
          url: "https://eslint.org/docs/rules/lines-between-class-members"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              exceptAfterSingleLine: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          never: "Unexpected blank line between class members.",
          always: "Expected blank line between class members."
        }
      },
      create(context) {
        const options = [];
        options[0] = context.options[0] || "always";
        options[1] = context.options[1] || { exceptAfterSingleLine: false };
        const sourceCode = context.getSourceCode();
        function getBoundaryTokens(curNode, nextNode) {
          const lastToken = sourceCode.getLastToken(curNode);
          const prevToken = sourceCode.getTokenBefore(lastToken);
          const nextToken = sourceCode.getFirstToken(nextNode);
          const isSemicolonLessStyle = astUtils.isSemicolonToken(lastToken) && !astUtils.isTokenOnSameLine(prevToken, lastToken) && astUtils.isTokenOnSameLine(lastToken, nextToken);
          return isSemicolonLessStyle ? { curLast: prevToken, nextFirst: lastToken } : { curLast: lastToken, nextFirst: nextToken };
        }
        function findLastConsecutiveTokenAfter(prevLastToken, nextFirstToken, maxLine) {
          const after = sourceCode.getTokenAfter(prevLastToken, { includeComments: true });
          if (after !== nextFirstToken && after.loc.start.line - prevLastToken.loc.end.line <= maxLine) {
            return findLastConsecutiveTokenAfter(after, nextFirstToken, maxLine);
          }
          return prevLastToken;
        }
        function findFirstConsecutiveTokenBefore(nextFirstToken, prevLastToken, maxLine) {
          const before = sourceCode.getTokenBefore(nextFirstToken, { includeComments: true });
          if (before !== prevLastToken && nextFirstToken.loc.start.line - before.loc.end.line <= maxLine) {
            return findFirstConsecutiveTokenBefore(before, prevLastToken, maxLine);
          }
          return nextFirstToken;
        }
        function hasTokenOrCommentBetween(before, after) {
          return sourceCode.getTokensBetween(before, after, { includeComments: true }).length !== 0;
        }
        return {
          ClassBody(node) {
            const body = node.body;
            for (let i = 0; i < body.length - 1; i++) {
              const curFirst = sourceCode.getFirstToken(body[i]);
              const { curLast, nextFirst } = getBoundaryTokens(body[i], body[i + 1]);
              const isMulti = !astUtils.isTokenOnSameLine(curFirst, curLast);
              const skip = !isMulti && options[1].exceptAfterSingleLine;
              const beforePadding = findLastConsecutiveTokenAfter(curLast, nextFirst, 1);
              const afterPadding = findFirstConsecutiveTokenBefore(nextFirst, curLast, 1);
              const isPadded = afterPadding.loc.start.line - beforePadding.loc.end.line > 1;
              const hasTokenInPadding = hasTokenOrCommentBetween(beforePadding, afterPadding);
              const curLineLastToken = findLastConsecutiveTokenAfter(curLast, nextFirst, 0);
              if (options[0] === "always" && !skip && !isPadded || options[0] === "never" && isPadded) {
                context.report({
                  node: body[i + 1],
                  messageId: isPadded ? "never" : "always",
                  fix(fixer) {
                    if (hasTokenInPadding) {
                      return null;
                    }
                    return isPadded ? fixer.replaceTextRange([beforePadding.range[1], afterPadding.range[0]], "\n") : fixer.insertTextAfter(curLineLastToken, "\n");
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/logical-assignment-operators.js
var require_logical_assignment_operators = __commonJS({
  "node_modules/eslint/lib/rules/logical-assignment-operators.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var baseTypes = /* @__PURE__ */ new Set(["Identifier", "Super", "ThisExpression"]);
    function isUndefined2(expression, scope) {
      if (expression.type === "Identifier" && expression.name === "undefined") {
        return astUtils.isReferenceToGlobalVariable(scope, expression);
      }
      return expression.type === "UnaryExpression" && expression.operator === "void" && expression.argument.type === "Literal" && expression.argument.value === 0;
    }
    function isReference(expression) {
      return expression.type === "Identifier" && expression.name !== "undefined" || expression.type === "MemberExpression";
    }
    function isImplicitNullishComparison(expression, scope) {
      if (expression.type !== "BinaryExpression" || expression.operator !== "==") {
        return false;
      }
      const reference = isReference(expression.left) ? "left" : "right";
      const nullish = reference === "left" ? "right" : "left";
      return isReference(expression[reference]) && (astUtils.isNullLiteral(expression[nullish]) || isUndefined2(expression[nullish], scope));
    }
    function isDoubleComparison(expression) {
      return expression.type === "LogicalExpression" && expression.operator === "||" && expression.left.type === "BinaryExpression" && expression.left.operator === "===" && expression.right.type === "BinaryExpression" && expression.right.operator === "===";
    }
    function isExplicitNullishComparison(expression, scope) {
      if (!isDoubleComparison(expression)) {
        return false;
      }
      const leftReference = isReference(expression.left.left) ? "left" : "right";
      const leftNullish = leftReference === "left" ? "right" : "left";
      const rightReference = isReference(expression.right.left) ? "left" : "right";
      const rightNullish = rightReference === "left" ? "right" : "left";
      return astUtils.isSameReference(expression.left[leftReference], expression.right[rightReference]) && (astUtils.isNullLiteral(expression.left[leftNullish]) && isUndefined2(expression.right[rightNullish], scope) || isUndefined2(expression.left[leftNullish], scope) && astUtils.isNullLiteral(expression.right[rightNullish]));
    }
    function isBooleanCast(expression, scope) {
      return expression.type === "CallExpression" && expression.callee.name === "Boolean" && expression.arguments.length === 1 && astUtils.isReferenceToGlobalVariable(scope, expression.callee);
    }
    function getExistence(expression, scope) {
      const isNegated = expression.type === "UnaryExpression" && expression.operator === "!";
      const base = isNegated ? expression.argument : expression;
      switch (true) {
        case isReference(base):
          return { reference: base, operator: isNegated ? "||" : "&&" };
        case (base.type === "UnaryExpression" && base.operator === "!" && isReference(base.argument)):
          return { reference: base.argument, operator: "&&" };
        case (isBooleanCast(base, scope) && isReference(base.arguments[0])):
          return { reference: base.arguments[0], operator: isNegated ? "||" : "&&" };
        case isImplicitNullishComparison(expression, scope):
          return { reference: isReference(expression.left) ? expression.left : expression.right, operator: "??" };
        case isExplicitNullishComparison(expression, scope):
          return { reference: isReference(expression.left.left) ? expression.left.left : expression.left.right, operator: "??" };
        default:
          return null;
      }
    }
    function isInsideWithBlock(node) {
      if (node.type === "Program") {
        return false;
      }
      return node.parent.type === "WithStatement" && node.parent.body === node ? true : isInsideWithBlock(node.parent);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow logical assignment logical operator shorthand",
          recommended: false,
          url: "https://eslint.org/docs/rules/logical-assignment-operators"
        },
        schema: {
          type: "array",
          oneOf: [{
            items: [
              { const: "always" },
              {
                type: "object",
                properties: {
                  enforceForIfStatements: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ],
            minItems: 0,
            // 0 for allowing passing no options
            maxItems: 2
          }, {
            items: [{ const: "never" }],
            minItems: 1,
            maxItems: 1
          }]
        },
        fixable: "code",
        // eslint-disable-next-line eslint-plugin/require-meta-has-suggestions -- Does not detect conditional suggestions
        hasSuggestions: true,
        messages: {
          assignment: "Assignment (=) can be replaced with operator assignment ({{operator}}).",
          useLogicalOperator: "Convert this assignment to use the operator {{ operator }}.",
          logical: "Logical expression can be replaced with an assignment ({{ operator }}).",
          convertLogical: "Replace this logical expression with an assignment with the operator {{ operator }}.",
          if: "'if' statement can be replaced with a logical operator assignment with operator {{ operator }}.",
          convertIf: "Replace this 'if' statement with a logical assignment with operator {{ operator }}.",
          unexpected: "Unexpected logical operator assignment ({{operator}}) shorthand.",
          separate: "Separate the logical assignment into an assignment with a logical operator."
        }
      },
      create(context) {
        const mode = context.options[0] === "never" ? "never" : "always";
        const checkIf = mode === "always" && context.options.length > 1 && context.options[1].enforceForIfStatements;
        const sourceCode = context.getSourceCode();
        const isStrict = context.getScope().isStrict;
        function cannotBeGetter(node) {
          return node.type === "Identifier" && (isStrict || !isInsideWithBlock(node));
        }
        function accessesSingleProperty(node) {
          if (!isStrict && isInsideWithBlock(node)) {
            return node.type === "Identifier";
          }
          return node.type === "MemberExpression" && baseTypes.has(node.object.type) && (!node.computed || node.property.type !== "MemberExpression" && node.property.type !== "ChainExpression");
        }
        function createConditionalFixer(descriptor, suggestion, shouldBeFixed) {
          if (shouldBeFixed) {
            return {
              ...descriptor,
              fix: suggestion.fix
            };
          }
          return {
            ...descriptor,
            suggest: [suggestion]
          };
        }
        function getOperatorToken(node) {
          return sourceCode.getFirstTokenBetween(node.left, node.right, (token) => token.value === node.operator);
        }
        if (mode === "never") {
          return {
            // foo ||= bar
            "AssignmentExpression"(assignment) {
              if (!astUtils.isLogicalAssignmentOperator(assignment.operator)) {
                return;
              }
              const descriptor = {
                messageId: "unexpected",
                node: assignment,
                data: { operator: assignment.operator }
              };
              const suggestion = {
                messageId: "separate",
                *fix(ruleFixer) {
                  if (sourceCode.getCommentsInside(assignment).length > 0) {
                    return;
                  }
                  const operatorToken = getOperatorToken(assignment);
                  yield ruleFixer.replaceText(operatorToken, "=");
                  const assignmentText = sourceCode.getText(assignment.left);
                  const operator = assignment.operator.slice(0, -1);
                  yield ruleFixer.insertTextAfter(operatorToken, ` ${assignmentText} ${operator}`);
                  const precedence = astUtils.getPrecedence(assignment.right) <= astUtils.getPrecedence({ type: "LogicalExpression", operator });
                  const mixed = assignment.operator === "??=" && astUtils.isLogicalExpression(assignment.right);
                  if (!astUtils.isParenthesised(sourceCode, assignment.right) && (precedence || mixed)) {
                    yield ruleFixer.insertTextBefore(assignment.right, "(");
                    yield ruleFixer.insertTextAfter(assignment.right, ")");
                  }
                }
              };
              context.report(createConditionalFixer(descriptor, suggestion, cannotBeGetter(assignment.left)));
            }
          };
        }
        return {
          // foo = foo || bar
          "AssignmentExpression[operator='='][right.type='LogicalExpression']"(assignment) {
            if (!astUtils.isSameReference(assignment.left, assignment.right.left)) {
              return;
            }
            const descriptor = {
              messageId: "assignment",
              node: assignment,
              data: { operator: `${assignment.right.operator}=` }
            };
            const suggestion = {
              messageId: "useLogicalOperator",
              data: { operator: `${assignment.right.operator}=` },
              *fix(ruleFixer) {
                if (sourceCode.getCommentsInside(assignment).length > 0) {
                  return;
                }
                const assignmentOperatorToken = getOperatorToken(assignment);
                yield ruleFixer.insertTextBefore(assignmentOperatorToken, assignment.right.operator);
                const logicalOperatorToken = getOperatorToken(assignment.right);
                const firstRightOperandToken = sourceCode.getTokenAfter(logicalOperatorToken);
                yield ruleFixer.removeRange([assignment.right.range[0], firstRightOperandToken.range[0]]);
              }
            };
            context.report(createConditionalFixer(descriptor, suggestion, cannotBeGetter(assignment.left)));
          },
          // foo || (foo = bar)
          'LogicalExpression[right.type="AssignmentExpression"][right.operator="="]'(logical) {
            if (isReference(logical.left) && astUtils.isSameReference(logical.left, logical.right.left)) {
              const descriptor = {
                messageId: "logical",
                node: logical,
                data: { operator: `${logical.operator}=` }
              };
              const suggestion = {
                messageId: "convertLogical",
                data: { operator: `${logical.operator}=` },
                *fix(ruleFixer) {
                  if (sourceCode.getCommentsInside(logical).length > 0) {
                    return;
                  }
                  const requiresOuterParenthesis = logical.parent.type !== "ExpressionStatement" && astUtils.getPrecedence({ type: "AssignmentExpression" }) < astUtils.getPrecedence(logical.parent);
                  if (!astUtils.isParenthesised(sourceCode, logical) && requiresOuterParenthesis) {
                    yield ruleFixer.insertTextBefore(logical, "(");
                    yield ruleFixer.insertTextAfter(logical, ")");
                  }
                  yield ruleFixer.removeRange([logical.range[0], logical.right.range[0]]);
                  yield ruleFixer.removeRange([logical.right.range[1], logical.range[1]]);
                  const operatorToken = getOperatorToken(logical.right);
                  yield ruleFixer.insertTextBefore(operatorToken, logical.operator);
                }
              };
              const fix = cannotBeGetter(logical.left) || accessesSingleProperty(logical.left);
              context.report(createConditionalFixer(descriptor, suggestion, fix));
            }
          },
          // if (foo) foo = bar
          "IfStatement[alternate=null]"(ifNode) {
            if (!checkIf) {
              return;
            }
            const hasBody = ifNode.consequent.type === "BlockStatement";
            if (hasBody && ifNode.consequent.body.length !== 1) {
              return;
            }
            const body = hasBody ? ifNode.consequent.body[0] : ifNode.consequent;
            const scope = context.getScope();
            const existence = getExistence(ifNode.test, scope);
            if (body.type === "ExpressionStatement" && body.expression.type === "AssignmentExpression" && body.expression.operator === "=" && existence !== null && astUtils.isSameReference(existence.reference, body.expression.left)) {
              const descriptor = {
                messageId: "if",
                node: ifNode,
                data: { operator: `${existence.operator}=` }
              };
              const suggestion = {
                messageId: "convertIf",
                data: { operator: `${existence.operator}=` },
                *fix(ruleFixer) {
                  if (sourceCode.getCommentsInside(ifNode).length > 0) {
                    return;
                  }
                  const firstBodyToken = sourceCode.getFirstToken(body);
                  const prevToken = sourceCode.getTokenBefore(ifNode);
                  if (prevToken !== null && prevToken.value !== ";" && prevToken.value !== "{" && firstBodyToken.type !== "Identifier" && firstBodyToken.type !== "Keyword") {
                    return;
                  }
                  const operatorToken = getOperatorToken(body.expression);
                  yield ruleFixer.insertTextBefore(operatorToken, existence.operator);
                  yield ruleFixer.removeRange([ifNode.range[0], body.range[0]]);
                  yield ruleFixer.removeRange([body.range[1], ifNode.range[1]]);
                  const nextToken = sourceCode.getTokenAfter(body.expression);
                  if (hasBody && (nextToken !== null && nextToken.value !== ";")) {
                    yield ruleFixer.insertTextAfter(ifNode, ";");
                  }
                }
              };
              const shouldBeFixed = cannotBeGetter(existence.reference) || ifNode.test.type !== "LogicalExpression" && accessesSingleProperty(existence.reference);
              context.report(createConditionalFixer(descriptor, suggestion, shouldBeFixed));
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-classes-per-file.js
var require_max_classes_per_file = __commonJS({
  "node_modules/eslint/lib/rules/max-classes-per-file.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum number of classes per file",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-classes-per-file"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 1
              },
              {
                type: "object",
                properties: {
                  ignoreExpressions: {
                    type: "boolean"
                  },
                  max: {
                    type: "integer",
                    minimum: 1
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          maximumExceeded: "File has too many classes ({{ classCount }}). Maximum allowed is {{ max }}."
        }
      },
      create(context) {
        const [option = {}] = context.options;
        const [ignoreExpressions, max2] = typeof option === "number" ? [false, option || 1] : [option.ignoreExpressions, option.max || 1];
        let classCount = 0;
        return {
          Program() {
            classCount = 0;
          },
          "Program:exit"(node) {
            if (classCount > max2) {
              context.report({
                node,
                messageId: "maximumExceeded",
                data: {
                  classCount,
                  max: max2
                }
              });
            }
          },
          "ClassDeclaration"() {
            classCount++;
          },
          "ClassExpression"() {
            if (!ignoreExpressions) {
              classCount++;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-depth.js
var require_max_depth = __commonJS({
  "node_modules/eslint/lib/rules/max-depth.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum depth that blocks can be nested",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-depth"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  maximum: {
                    type: "integer",
                    minimum: 0
                  },
                  max: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          tooDeeply: "Blocks are nested too deeply ({{depth}}). Maximum allowed is {{maxDepth}}."
        }
      },
      create(context) {
        const functionStack = [], option = context.options[0];
        let maxDepth = 4;
        if (typeof option === "object" && (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
          maxDepth = option.maximum || option.max;
        }
        if (typeof option === "number") {
          maxDepth = option;
        }
        function startFunction() {
          functionStack.push(0);
        }
        function endFunction() {
          functionStack.pop();
        }
        function pushBlock(node) {
          const len = ++functionStack[functionStack.length - 1];
          if (len > maxDepth) {
            context.report({ node, messageId: "tooDeeply", data: { depth: len, maxDepth } });
          }
        }
        function popBlock() {
          functionStack[functionStack.length - 1]--;
        }
        return {
          Program: startFunction,
          FunctionDeclaration: startFunction,
          FunctionExpression: startFunction,
          ArrowFunctionExpression: startFunction,
          StaticBlock: startFunction,
          IfStatement(node) {
            if (node.parent.type !== "IfStatement") {
              pushBlock(node);
            }
          },
          SwitchStatement: pushBlock,
          TryStatement: pushBlock,
          DoWhileStatement: pushBlock,
          WhileStatement: pushBlock,
          WithStatement: pushBlock,
          ForStatement: pushBlock,
          ForInStatement: pushBlock,
          ForOfStatement: pushBlock,
          "IfStatement:exit": popBlock,
          "SwitchStatement:exit": popBlock,
          "TryStatement:exit": popBlock,
          "DoWhileStatement:exit": popBlock,
          "WhileStatement:exit": popBlock,
          "WithStatement:exit": popBlock,
          "ForStatement:exit": popBlock,
          "ForInStatement:exit": popBlock,
          "ForOfStatement:exit": popBlock,
          "FunctionDeclaration:exit": endFunction,
          "FunctionExpression:exit": endFunction,
          "ArrowFunctionExpression:exit": endFunction,
          "StaticBlock:exit": endFunction,
          "Program:exit": endFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-len.js
var require_max_len = __commonJS({
  "node_modules/eslint/lib/rules/max-len.js"(exports, module2) {
    "use strict";
    var OPTIONS_SCHEMA = {
      type: "object",
      properties: {
        code: {
          type: "integer",
          minimum: 0
        },
        comments: {
          type: "integer",
          minimum: 0
        },
        tabWidth: {
          type: "integer",
          minimum: 0
        },
        ignorePattern: {
          type: "string"
        },
        ignoreComments: {
          type: "boolean"
        },
        ignoreStrings: {
          type: "boolean"
        },
        ignoreUrls: {
          type: "boolean"
        },
        ignoreTemplateLiterals: {
          type: "boolean"
        },
        ignoreRegExpLiterals: {
          type: "boolean"
        },
        ignoreTrailingComments: {
          type: "boolean"
        }
      },
      additionalProperties: false
    };
    var OPTIONS_OR_INTEGER_SCHEMA = {
      anyOf: [
        OPTIONS_SCHEMA,
        {
          type: "integer",
          minimum: 0
        }
      ]
    };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce a maximum line length",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-len"
        },
        schema: [
          OPTIONS_OR_INTEGER_SCHEMA,
          OPTIONS_OR_INTEGER_SCHEMA,
          OPTIONS_SCHEMA
        ],
        messages: {
          max: "This line has a length of {{lineLength}}. Maximum allowed is {{maxLength}}.",
          maxComment: "This line has a comment length of {{lineLength}}. Maximum allowed is {{maxCommentLength}}."
        }
      },
      create(context) {
        const URL_REGEXP = /[^:/?#]:\/\/[^?#]/u;
        const sourceCode = context.getSourceCode();
        function computeLineLength(line, tabWidth2) {
          let extraCharacterCount = 0;
          line.replace(/\t/gu, (match, offset) => {
            const totalOffset = offset + extraCharacterCount, previousTabStopOffset = tabWidth2 ? totalOffset % tabWidth2 : 0, spaceCount = tabWidth2 - previousTabStopOffset;
            extraCharacterCount += spaceCount - 1;
          });
          return Array.from(line).length + extraCharacterCount;
        }
        const options = Object.assign({}, context.options[context.options.length - 1]);
        if (typeof context.options[0] === "number") {
          options.code = context.options[0];
        }
        if (typeof context.options[1] === "number") {
          options.tabWidth = context.options[1];
        }
        const maxLength = typeof options.code === "number" ? options.code : 80, tabWidth = typeof options.tabWidth === "number" ? options.tabWidth : 4, ignoreComments = !!options.ignoreComments, ignoreStrings = !!options.ignoreStrings, ignoreTemplateLiterals = !!options.ignoreTemplateLiterals, ignoreRegExpLiterals = !!options.ignoreRegExpLiterals, ignoreTrailingComments = !!options.ignoreTrailingComments || !!options.ignoreComments, ignoreUrls = !!options.ignoreUrls, maxCommentLength = options.comments;
        let ignorePattern = options.ignorePattern || null;
        if (ignorePattern) {
          ignorePattern = new RegExp(ignorePattern, "u");
        }
        function isTrailingComment(line, lineNumber, comment) {
          return comment && (comment.loc.start.line === lineNumber && lineNumber <= comment.loc.end.line) && (comment.loc.end.line > lineNumber || comment.loc.end.column === line.length);
        }
        function isFullLineComment(line, lineNumber, comment) {
          const start = comment.loc.start, end = comment.loc.end, isFirstTokenOnLine = !line.slice(0, comment.loc.start.column).trim();
          return comment && (start.line < lineNumber || start.line === lineNumber && isFirstTokenOnLine) && (end.line > lineNumber || end.line === lineNumber && end.column === line.length);
        }
        function isJSXEmptyExpressionInSingleLineContainer(node) {
          if (!node || !node.parent || node.type !== "JSXEmptyExpression" || node.parent.type !== "JSXExpressionContainer") {
            return false;
          }
          const parent = node.parent;
          return parent.loc.start.line === parent.loc.end.line;
        }
        function stripTrailingComment(line, comment) {
          return line.slice(0, comment.loc.start.column).replace(/\s+$/u, "");
        }
        function ensureArrayAndPush(object, key, value2) {
          if (!Array.isArray(object[key])) {
            object[key] = [];
          }
          object[key].push(value2);
        }
        function getAllStrings() {
          return sourceCode.ast.tokens.filter((token) => token.type === "String" || token.type === "JSXText" && sourceCode.getNodeByRangeIndex(token.range[0] - 1).type === "JSXAttribute");
        }
        function getAllTemplateLiterals() {
          return sourceCode.ast.tokens.filter((token) => token.type === "Template");
        }
        function getAllRegExpLiterals() {
          return sourceCode.ast.tokens.filter((token) => token.type === "RegularExpression");
        }
        function groupByLineNumber(acc, node) {
          for (let i = node.loc.start.line; i <= node.loc.end.line; ++i) {
            ensureArrayAndPush(acc, i, node);
          }
          return acc;
        }
        function getAllComments() {
          const comments = [];
          sourceCode.getAllComments().forEach((commentNode) => {
            const containingNode = sourceCode.getNodeByRangeIndex(commentNode.range[0]);
            if (isJSXEmptyExpressionInSingleLineContainer(containingNode)) {
              if (comments[comments.length - 1] !== containingNode.parent) {
                comments.push(containingNode.parent);
              }
            } else {
              comments.push(commentNode);
            }
          });
          return comments;
        }
        function checkProgramForMaxLength(node) {
          const lines = sourceCode.lines, comments = ignoreComments || maxCommentLength || ignoreTrailingComments ? getAllComments() : [];
          let commentsIndex = 0;
          const strings = getAllStrings();
          const stringsByLine = strings.reduce(groupByLineNumber, {});
          const templateLiterals = getAllTemplateLiterals();
          const templateLiteralsByLine = templateLiterals.reduce(groupByLineNumber, {});
          const regExpLiterals = getAllRegExpLiterals();
          const regExpLiteralsByLine = regExpLiterals.reduce(groupByLineNumber, {});
          lines.forEach((line, i) => {
            const lineNumber = i + 1;
            let lineIsComment = false;
            let textToMeasure;
            if (commentsIndex < comments.length) {
              let comment = null;
              do {
                comment = comments[++commentsIndex];
              } while (comment && comment.loc.start.line <= lineNumber);
              comment = comments[--commentsIndex];
              if (isFullLineComment(line, lineNumber, comment)) {
                lineIsComment = true;
                textToMeasure = line;
              } else if (ignoreTrailingComments && isTrailingComment(line, lineNumber, comment)) {
                textToMeasure = stripTrailingComment(line, comment);
                let lastIndex = commentsIndex;
                while (isTrailingComment(textToMeasure, lineNumber, comments[--lastIndex])) {
                  textToMeasure = stripTrailingComment(textToMeasure, comments[lastIndex]);
                }
              } else {
                textToMeasure = line;
              }
            } else {
              textToMeasure = line;
            }
            if (ignorePattern && ignorePattern.test(textToMeasure) || ignoreUrls && URL_REGEXP.test(textToMeasure) || ignoreStrings && stringsByLine[lineNumber] || ignoreTemplateLiterals && templateLiteralsByLine[lineNumber] || ignoreRegExpLiterals && regExpLiteralsByLine[lineNumber]) {
              return;
            }
            const lineLength = computeLineLength(textToMeasure, tabWidth);
            const commentLengthApplies = lineIsComment && maxCommentLength;
            if (lineIsComment && ignoreComments) {
              return;
            }
            const loc = {
              start: {
                line: lineNumber,
                column: 0
              },
              end: {
                line: lineNumber,
                column: textToMeasure.length
              }
            };
            if (commentLengthApplies) {
              if (lineLength > maxCommentLength) {
                context.report({
                  node,
                  loc,
                  messageId: "maxComment",
                  data: {
                    lineLength,
                    maxCommentLength
                  }
                });
              }
            } else if (lineLength > maxLength) {
              context.report({
                node,
                loc,
                messageId: "max",
                data: {
                  lineLength,
                  maxLength
                }
              });
            }
          });
        }
        return {
          Program: checkProgramForMaxLength
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-lines.js
var require_max_lines = __commonJS({
  "node_modules/eslint/lib/rules/max-lines.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function range(start, end) {
      return [...Array(end - start).keys()].map((x) => x + start);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum number of lines per file",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-lines"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  max: {
                    type: "integer",
                    minimum: 0
                  },
                  skipComments: {
                    type: "boolean"
                  },
                  skipBlankLines: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          exceed: "File has too many lines ({{actual}}). Maximum allowed is {{max}}."
        }
      },
      create(context) {
        const option = context.options[0];
        let max2 = 300;
        if (typeof option === "object" && Object.prototype.hasOwnProperty.call(option, "max")) {
          max2 = option.max;
        } else if (typeof option === "number") {
          max2 = option;
        }
        const skipComments = option && option.skipComments;
        const skipBlankLines = option && option.skipBlankLines;
        const sourceCode = context.getSourceCode();
        function isCommentNodeType(token) {
          return token && (token.type === "Block" || token.type === "Line");
        }
        function getLinesWithoutCode(comment) {
          let start = comment.loc.start.line;
          let end = comment.loc.end.line;
          let token;
          token = comment;
          do {
            token = sourceCode.getTokenBefore(token, {
              includeComments: true
            });
          } while (isCommentNodeType(token));
          if (token && astUtils.isTokenOnSameLine(token, comment)) {
            start += 1;
          }
          token = comment;
          do {
            token = sourceCode.getTokenAfter(token, {
              includeComments: true
            });
          } while (isCommentNodeType(token));
          if (token && astUtils.isTokenOnSameLine(comment, token)) {
            end -= 1;
          }
          if (start <= end) {
            return range(start, end + 1);
          }
          return [];
        }
        return {
          "Program:exit"() {
            let lines = sourceCode.lines.map((text, i) => ({
              lineNumber: i + 1,
              text
            }));
            if (lines.length > 1 && lines[lines.length - 1].text === "") {
              lines.pop();
            }
            if (skipBlankLines) {
              lines = lines.filter((l) => l.text.trim() !== "");
            }
            if (skipComments) {
              const comments = sourceCode.getAllComments();
              const commentLines = new Set(comments.flatMap(getLinesWithoutCode));
              lines = lines.filter(
                (l) => !commentLines.has(l.lineNumber)
              );
            }
            if (lines.length > max2) {
              const loc = {
                start: {
                  line: lines[max2].lineNumber,
                  column: 0
                },
                end: {
                  line: sourceCode.lines.length,
                  column: sourceCode.lines[sourceCode.lines.length - 1].length
                }
              };
              context.report({
                loc,
                messageId: "exceed",
                data: {
                  max: max2,
                  actual: lines.length
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-lines-per-function.js
var require_max_lines_per_function = __commonJS({
  "node_modules/eslint/lib/rules/max-lines-per-function.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { upperCaseFirst } = require_string_utils();
    var OPTIONS_SCHEMA = {
      type: "object",
      properties: {
        max: {
          type: "integer",
          minimum: 0
        },
        skipComments: {
          type: "boolean"
        },
        skipBlankLines: {
          type: "boolean"
        },
        IIFEs: {
          type: "boolean"
        }
      },
      additionalProperties: false
    };
    var OPTIONS_OR_INTEGER_SCHEMA = {
      oneOf: [
        OPTIONS_SCHEMA,
        {
          type: "integer",
          minimum: 1
        }
      ]
    };
    function getCommentLineNumbers(comments) {
      const map = /* @__PURE__ */ new Map();
      comments.forEach((comment) => {
        for (let i = comment.loc.start.line; i <= comment.loc.end.line; i++) {
          map.set(i, comment);
        }
      });
      return map;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum number of lines of code in a function",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-lines-per-function"
        },
        schema: [
          OPTIONS_OR_INTEGER_SCHEMA
        ],
        messages: {
          exceed: "{{name}} has too many lines ({{lineCount}}). Maximum allowed is {{maxLines}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const lines = sourceCode.lines;
        const option = context.options[0];
        let maxLines = 50;
        let skipComments = false;
        let skipBlankLines = false;
        let IIFEs = false;
        if (typeof option === "object") {
          maxLines = typeof option.max === "number" ? option.max : 50;
          skipComments = !!option.skipComments;
          skipBlankLines = !!option.skipBlankLines;
          IIFEs = !!option.IIFEs;
        } else if (typeof option === "number") {
          maxLines = option;
        }
        const commentLineNumbers = getCommentLineNumbers(sourceCode.getAllComments());
        function isFullLineComment(line, lineNumber, comment) {
          const start = comment.loc.start, end = comment.loc.end, isFirstTokenOnLine = start.line === lineNumber && !line.slice(0, start.column).trim(), isLastTokenOnLine = end.line === lineNumber && !line.slice(end.column).trim();
          return comment && (start.line < lineNumber || isFirstTokenOnLine) && (end.line > lineNumber || isLastTokenOnLine);
        }
        function isIIFE(node) {
          return (node.type === "FunctionExpression" || node.type === "ArrowFunctionExpression") && node.parent && node.parent.type === "CallExpression" && node.parent.callee === node;
        }
        function isEmbedded(node) {
          if (!node.parent) {
            return false;
          }
          if (node !== node.parent.value) {
            return false;
          }
          if (node.parent.type === "MethodDefinition") {
            return true;
          }
          if (node.parent.type === "Property") {
            return node.parent.method === true || node.parent.kind === "get" || node.parent.kind === "set";
          }
          return false;
        }
        function processFunction(funcNode) {
          const node = isEmbedded(funcNode) ? funcNode.parent : funcNode;
          if (!IIFEs && isIIFE(node)) {
            return;
          }
          let lineCount = 0;
          for (let i = node.loc.start.line - 1; i < node.loc.end.line; ++i) {
            const line = lines[i];
            if (skipComments) {
              if (commentLineNumbers.has(i + 1) && isFullLineComment(line, i + 1, commentLineNumbers.get(i + 1))) {
                continue;
              }
            }
            if (skipBlankLines) {
              if (line.match(/^\s*$/u)) {
                continue;
              }
            }
            lineCount++;
          }
          if (lineCount > maxLines) {
            const name = upperCaseFirst(astUtils.getFunctionNameWithKind(funcNode));
            context.report({
              node,
              messageId: "exceed",
              data: { name, lineCount, maxLines }
            });
          }
        }
        return {
          FunctionDeclaration: processFunction,
          FunctionExpression: processFunction,
          ArrowFunctionExpression: processFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-nested-callbacks.js
var require_max_nested_callbacks = __commonJS({
  "node_modules/eslint/lib/rules/max-nested-callbacks.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum depth that callbacks can be nested",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-nested-callbacks"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  maximum: {
                    type: "integer",
                    minimum: 0
                  },
                  max: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          exceed: "Too many nested callbacks ({{num}}). Maximum allowed is {{max}}."
        }
      },
      create(context) {
        const option = context.options[0];
        let THRESHOLD = 10;
        if (typeof option === "object" && (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
          THRESHOLD = option.maximum || option.max;
        } else if (typeof option === "number") {
          THRESHOLD = option;
        }
        const callbackStack = [];
        function checkFunction(node) {
          const parent = node.parent;
          if (parent.type === "CallExpression") {
            callbackStack.push(node);
          }
          if (callbackStack.length > THRESHOLD) {
            const opts = { num: callbackStack.length, max: THRESHOLD };
            context.report({ node, messageId: "exceed", data: opts });
          }
        }
        function popStack() {
          callbackStack.pop();
        }
        return {
          ArrowFunctionExpression: checkFunction,
          "ArrowFunctionExpression:exit": popStack,
          FunctionExpression: checkFunction,
          "FunctionExpression:exit": popStack
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-params.js
var require_max_params = __commonJS({
  "node_modules/eslint/lib/rules/max-params.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { upperCaseFirst } = require_string_utils();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum number of parameters in function definitions",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-params"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  maximum: {
                    type: "integer",
                    minimum: 0
                  },
                  max: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          exceed: "{{name}} has too many parameters ({{count}}). Maximum allowed is {{max}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const option = context.options[0];
        let numParams = 3;
        if (typeof option === "object" && (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
          numParams = option.maximum || option.max;
        }
        if (typeof option === "number") {
          numParams = option;
        }
        function checkFunction(node) {
          if (node.params.length > numParams) {
            context.report({
              loc: astUtils.getFunctionHeadLoc(node, sourceCode),
              node,
              messageId: "exceed",
              data: {
                name: upperCaseFirst(astUtils.getFunctionNameWithKind(node)),
                count: node.params.length,
                max: numParams
              }
            });
          }
        }
        return {
          FunctionDeclaration: checkFunction,
          ArrowFunctionExpression: checkFunction,
          FunctionExpression: checkFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-statements.js
var require_max_statements = __commonJS({
  "node_modules/eslint/lib/rules/max-statements.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { upperCaseFirst } = require_string_utils();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a maximum number of statements allowed in function blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-statements"
        },
        schema: [
          {
            oneOf: [
              {
                type: "integer",
                minimum: 0
              },
              {
                type: "object",
                properties: {
                  maximum: {
                    type: "integer",
                    minimum: 0
                  },
                  max: {
                    type: "integer",
                    minimum: 0
                  }
                },
                additionalProperties: false
              }
            ]
          },
          {
            type: "object",
            properties: {
              ignoreTopLevelFunctions: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          exceed: "{{name}} has too many statements ({{count}}). Maximum allowed is {{max}}."
        }
      },
      create(context) {
        const functionStack = [], option = context.options[0], ignoreTopLevelFunctions = context.options[1] && context.options[1].ignoreTopLevelFunctions || false, topLevelFunctions = [];
        let maxStatements = 10;
        if (typeof option === "object" && (Object.prototype.hasOwnProperty.call(option, "maximum") || Object.prototype.hasOwnProperty.call(option, "max"))) {
          maxStatements = option.maximum || option.max;
        } else if (typeof option === "number") {
          maxStatements = option;
        }
        function reportIfTooManyStatements(node, count, max2) {
          if (count > max2) {
            const name = upperCaseFirst(astUtils.getFunctionNameWithKind(node));
            context.report({
              node,
              messageId: "exceed",
              data: { name, count, max: max2 }
            });
          }
        }
        function startFunction() {
          functionStack.push(0);
        }
        function endFunction(node) {
          const count = functionStack.pop();
          if (node.type === "StaticBlock") {
            return;
          }
          if (ignoreTopLevelFunctions && functionStack.length === 0) {
            topLevelFunctions.push({ node, count });
          } else {
            reportIfTooManyStatements(node, count, maxStatements);
          }
        }
        function countStatements(node) {
          functionStack[functionStack.length - 1] += node.body.length;
        }
        return {
          FunctionDeclaration: startFunction,
          FunctionExpression: startFunction,
          ArrowFunctionExpression: startFunction,
          StaticBlock: startFunction,
          BlockStatement: countStatements,
          "FunctionDeclaration:exit": endFunction,
          "FunctionExpression:exit": endFunction,
          "ArrowFunctionExpression:exit": endFunction,
          "StaticBlock:exit": endFunction,
          "Program:exit"() {
            if (topLevelFunctions.length === 1) {
              return;
            }
            topLevelFunctions.forEach((element) => {
              const count = element.count;
              const node = element.node;
              reportIfTooManyStatements(node, count, maxStatements);
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/max-statements-per-line.js
var require_max_statements_per_line = __commonJS({
  "node_modules/eslint/lib/rules/max-statements-per-line.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce a maximum number of statements allowed per line",
          recommended: false,
          url: "https://eslint.org/docs/rules/max-statements-per-line"
        },
        schema: [
          {
            type: "object",
            properties: {
              max: {
                type: "integer",
                minimum: 1,
                default: 1
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          exceed: "This line has {{numberOfStatementsOnThisLine}} {{statements}}. Maximum allowed is {{maxStatementsPerLine}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode(), options = context.options[0] || {}, maxStatementsPerLine = typeof options.max !== "undefined" ? options.max : 1;
        let lastStatementLine = 0, numberOfStatementsOnThisLine = 0, firstExtraStatement;
        const SINGLE_CHILD_ALLOWED = /^(?:(?:DoWhile|For|ForIn|ForOf|If|Labeled|While)Statement|Export(?:Default|Named)Declaration)$/u;
        function reportFirstExtraStatementAndClear() {
          if (firstExtraStatement) {
            context.report({
              node: firstExtraStatement,
              messageId: "exceed",
              data: {
                numberOfStatementsOnThisLine,
                maxStatementsPerLine,
                statements: numberOfStatementsOnThisLine === 1 ? "statement" : "statements"
              }
            });
          }
          firstExtraStatement = null;
        }
        function getActualLastToken(node) {
          return sourceCode.getLastToken(node, astUtils.isNotSemicolonToken);
        }
        function enterStatement(node) {
          const line = node.loc.start.line;
          if (SINGLE_CHILD_ALLOWED.test(node.parent.type) && node.parent.alternate !== node) {
            return;
          }
          if (line === lastStatementLine) {
            numberOfStatementsOnThisLine += 1;
          } else {
            reportFirstExtraStatementAndClear();
            numberOfStatementsOnThisLine = 1;
            lastStatementLine = line;
          }
          if (numberOfStatementsOnThisLine === maxStatementsPerLine + 1) {
            firstExtraStatement = firstExtraStatement || node;
          }
        }
        function leaveStatement(node) {
          const line = getActualLastToken(node).loc.end.line;
          if (line !== lastStatementLine) {
            reportFirstExtraStatementAndClear();
            numberOfStatementsOnThisLine = 1;
            lastStatementLine = line;
          }
        }
        return {
          BreakStatement: enterStatement,
          ClassDeclaration: enterStatement,
          ContinueStatement: enterStatement,
          DebuggerStatement: enterStatement,
          DoWhileStatement: enterStatement,
          ExpressionStatement: enterStatement,
          ForInStatement: enterStatement,
          ForOfStatement: enterStatement,
          ForStatement: enterStatement,
          FunctionDeclaration: enterStatement,
          IfStatement: enterStatement,
          ImportDeclaration: enterStatement,
          LabeledStatement: enterStatement,
          ReturnStatement: enterStatement,
          SwitchStatement: enterStatement,
          ThrowStatement: enterStatement,
          TryStatement: enterStatement,
          VariableDeclaration: enterStatement,
          WhileStatement: enterStatement,
          WithStatement: enterStatement,
          ExportNamedDeclaration: enterStatement,
          ExportDefaultDeclaration: enterStatement,
          ExportAllDeclaration: enterStatement,
          "BreakStatement:exit": leaveStatement,
          "ClassDeclaration:exit": leaveStatement,
          "ContinueStatement:exit": leaveStatement,
          "DebuggerStatement:exit": leaveStatement,
          "DoWhileStatement:exit": leaveStatement,
          "ExpressionStatement:exit": leaveStatement,
          "ForInStatement:exit": leaveStatement,
          "ForOfStatement:exit": leaveStatement,
          "ForStatement:exit": leaveStatement,
          "FunctionDeclaration:exit": leaveStatement,
          "IfStatement:exit": leaveStatement,
          "ImportDeclaration:exit": leaveStatement,
          "LabeledStatement:exit": leaveStatement,
          "ReturnStatement:exit": leaveStatement,
          "SwitchStatement:exit": leaveStatement,
          "ThrowStatement:exit": leaveStatement,
          "TryStatement:exit": leaveStatement,
          "VariableDeclaration:exit": leaveStatement,
          "WhileStatement:exit": leaveStatement,
          "WithStatement:exit": leaveStatement,
          "ExportNamedDeclaration:exit": leaveStatement,
          "ExportDefaultDeclaration:exit": leaveStatement,
          "ExportAllDeclaration:exit": leaveStatement,
          "Program:exit": reportFirstExtraStatementAndClear
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/multiline-comment-style.js
var require_multiline_comment_style = __commonJS({
  "node_modules/eslint/lib/rules/multiline-comment-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce a particular style for multiline comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/multiline-comment-style"
        },
        fixable: "whitespace",
        schema: [{ enum: ["starred-block", "separate-lines", "bare-block"] }],
        messages: {
          expectedBlock: "Expected a block comment instead of consecutive line comments.",
          expectedBareBlock: "Expected a block comment without padding stars.",
          startNewline: "Expected a linebreak after '/*'.",
          endNewline: "Expected a linebreak before '*/'.",
          missingStar: "Expected a '*' at the start of this line.",
          alignment: "Expected this line to be aligned with the start of the comment.",
          expectedLines: "Expected multiple line comments instead of a block comment."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const option = context.options[0] || "starred-block";
        function isStarredCommentLine(line) {
          return /^\s*\*/u.test(line);
        }
        function isStarredBlockComment([firstComment]) {
          if (firstComment.type !== "Block") {
            return false;
          }
          const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
          return lines.length > 0 && lines.every((line, i) => (i === 0 || i === lines.length - 1 ? /^\s*$/u : /^\s*\*/u).test(line));
        }
        function isJSDocComment([firstComment]) {
          if (firstComment.type !== "Block") {
            return false;
          }
          const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
          return /^\*\s*$/u.test(lines[0]) && lines.slice(1, -1).every((line) => /^\s* /u.test(line)) && /^\s*$/u.test(lines[lines.length - 1]);
        }
        function processSeparateLineComments(commentGroup) {
          const allLinesHaveLeadingSpace = commentGroup.map(({ value: value2 }) => value2).filter((line) => line.trim().length).every((line) => line.startsWith(" "));
          return commentGroup.map(({ value: value2 }) => allLinesHaveLeadingSpace ? value2.replace(/^ /u, "") : value2);
        }
        function processStarredBlockComment(comment) {
          const lines = comment.value.split(astUtils.LINEBREAK_MATCHER).filter((line, i, linesArr) => !(i === 0 || i === linesArr.length - 1)).map((line) => line.replace(/^\s*$/u, ""));
          const allLinesHaveLeadingSpace = lines.map((line) => line.replace(/\s*\*/u, "")).filter((line) => line.trim().length).every((line) => line.startsWith(" "));
          return lines.map((line) => line.replace(allLinesHaveLeadingSpace ? /\s*\* ?/u : /\s*\*/u, ""));
        }
        function processBareBlockComment(comment) {
          const lines = comment.value.split(astUtils.LINEBREAK_MATCHER).map((line) => line.replace(/^\s*$/u, ""));
          const leadingWhitespace = `${sourceCode.text.slice(comment.range[0] - comment.loc.start.column, comment.range[0])}   `;
          let offset = "";
          for (const [i, line] of lines.entries()) {
            if (!line.trim().length || i === 0) {
              continue;
            }
            const [, lineOffset] = line.match(/^(\s*\*?\s*)/u);
            if (lineOffset.length < leadingWhitespace.length) {
              const newOffset = leadingWhitespace.slice(lineOffset.length - leadingWhitespace.length);
              if (newOffset.length > offset.length) {
                offset = newOffset;
              }
            }
          }
          return lines.map((line) => {
            const match = line.match(/^(\s*\*?\s*)(.*)/u);
            const [, lineOffset, lineContents] = match;
            if (lineOffset.length > leadingWhitespace.length) {
              return `${lineOffset.slice(leadingWhitespace.length - (offset.length + lineOffset.length))}${lineContents}`;
            }
            if (lineOffset.length < leadingWhitespace.length) {
              return `${lineOffset.slice(leadingWhitespace.length)}${lineContents}`;
            }
            return lineContents;
          });
        }
        function getCommentLines(commentGroup) {
          const [firstComment] = commentGroup;
          if (firstComment.type === "Line") {
            return processSeparateLineComments(commentGroup);
          }
          if (isStarredBlockComment(commentGroup)) {
            return processStarredBlockComment(firstComment);
          }
          return processBareBlockComment(firstComment);
        }
        function getInitialOffset(comment) {
          return sourceCode.text.slice(comment.range[0] - comment.loc.start.column, comment.range[0]);
        }
        function convertToStarredBlock(firstComment, commentLinesList) {
          const initialOffset = getInitialOffset(firstComment);
          return `/*
${commentLinesList.map((line) => `${initialOffset} * ${line}`).join("\n")}
${initialOffset} */`;
        }
        function convertToSeparateLines(firstComment, commentLinesList) {
          return commentLinesList.map((line) => `// ${line}`).join(`
${getInitialOffset(firstComment)}`);
        }
        function convertToBlock(firstComment, commentLinesList) {
          return `/* ${commentLinesList.join(`
${getInitialOffset(firstComment)}   `)} */`;
        }
        const commentGroupCheckers = {
          "starred-block"(commentGroup) {
            const [firstComment] = commentGroup;
            const commentLines = getCommentLines(commentGroup);
            if (commentLines.some((value2) => value2.includes("*/"))) {
              return;
            }
            if (commentGroup.length > 1) {
              context.report({
                loc: {
                  start: firstComment.loc.start,
                  end: commentGroup[commentGroup.length - 1].loc.end
                },
                messageId: "expectedBlock",
                fix(fixer) {
                  const range = [firstComment.range[0], commentGroup[commentGroup.length - 1].range[1]];
                  return commentLines.some((value2) => value2.startsWith("/")) ? null : fixer.replaceTextRange(range, convertToStarredBlock(firstComment, commentLines));
                }
              });
            } else {
              const lines = firstComment.value.split(astUtils.LINEBREAK_MATCHER);
              const expectedLeadingWhitespace = getInitialOffset(firstComment);
              const expectedLinePrefix = `${expectedLeadingWhitespace} *`;
              if (!/^\*?\s*$/u.test(lines[0])) {
                const start = firstComment.value.startsWith("*") ? firstComment.range[0] + 1 : firstComment.range[0];
                context.report({
                  loc: {
                    start: firstComment.loc.start,
                    end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
                  },
                  messageId: "startNewline",
                  fix: (fixer) => fixer.insertTextAfterRange([start, start + 2], `
${expectedLinePrefix}`)
                });
              }
              if (!/^\s*$/u.test(lines[lines.length - 1])) {
                context.report({
                  loc: {
                    start: { line: firstComment.loc.end.line, column: firstComment.loc.end.column - 2 },
                    end: firstComment.loc.end
                  },
                  messageId: "endNewline",
                  fix: (fixer) => fixer.replaceTextRange([firstComment.range[1] - 2, firstComment.range[1]], `
${expectedLinePrefix}/`)
                });
              }
              for (let lineNumber = firstComment.loc.start.line + 1; lineNumber <= firstComment.loc.end.line; lineNumber++) {
                const lineText = sourceCode.lines[lineNumber - 1];
                const errorType = isStarredCommentLine(lineText) ? "alignment" : "missingStar";
                if (!lineText.startsWith(expectedLinePrefix)) {
                  context.report({
                    loc: {
                      start: { line: lineNumber, column: 0 },
                      end: { line: lineNumber, column: lineText.length }
                    },
                    messageId: errorType,
                    fix(fixer) {
                      const lineStartIndex = sourceCode.getIndexFromLoc({ line: lineNumber, column: 0 });
                      if (errorType === "alignment") {
                        const [, commentTextPrefix2 = ""] = lineText.match(/^(\s*\*)/u) || [];
                        const commentTextStartIndex2 = lineStartIndex + commentTextPrefix2.length;
                        return fixer.replaceTextRange([lineStartIndex, commentTextStartIndex2], expectedLinePrefix);
                      }
                      const [, commentTextPrefix = ""] = lineText.match(/^(\s*)/u) || [];
                      const commentTextStartIndex = lineStartIndex + commentTextPrefix.length;
                      let offset;
                      for (const [idx, line] of lines.entries()) {
                        if (!/\S+/u.test(line)) {
                          continue;
                        }
                        const lineTextToAlignWith = sourceCode.lines[firstComment.loc.start.line - 1 + idx];
                        const [, prefix = "", initialOffset = ""] = lineTextToAlignWith.match(/^(\s*(?:\/?\*)?(\s*))/u) || [];
                        offset = `${commentTextPrefix.slice(prefix.length)}${initialOffset}`;
                        if (/^\s*\//u.test(lineText) && offset.length === 0) {
                          offset += " ";
                        }
                        break;
                      }
                      return fixer.replaceTextRange([lineStartIndex, commentTextStartIndex], `${expectedLinePrefix}${offset}`);
                    }
                  });
                }
              }
            }
          },
          "separate-lines"(commentGroup) {
            const [firstComment] = commentGroup;
            if (firstComment.type !== "Block" || isJSDocComment(commentGroup)) {
              return;
            }
            const commentLines = getCommentLines(commentGroup);
            const tokenAfter = sourceCode.getTokenAfter(firstComment, { includeComments: true });
            if (tokenAfter && firstComment.loc.end.line === tokenAfter.loc.start.line) {
              return;
            }
            context.report({
              loc: {
                start: firstComment.loc.start,
                end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
              },
              messageId: "expectedLines",
              fix(fixer) {
                return fixer.replaceText(firstComment, convertToSeparateLines(firstComment, commentLines));
              }
            });
          },
          "bare-block"(commentGroup) {
            if (isJSDocComment(commentGroup)) {
              return;
            }
            const [firstComment] = commentGroup;
            const commentLines = getCommentLines(commentGroup);
            if (firstComment.type === "Line" && commentLines.length > 1 && !commentLines.some((value2) => value2.includes("*/"))) {
              context.report({
                loc: {
                  start: firstComment.loc.start,
                  end: commentGroup[commentGroup.length - 1].loc.end
                },
                messageId: "expectedBlock",
                fix(fixer) {
                  return fixer.replaceTextRange(
                    [firstComment.range[0], commentGroup[commentGroup.length - 1].range[1]],
                    convertToBlock(firstComment, commentLines)
                  );
                }
              });
            }
            if (isStarredBlockComment(commentGroup)) {
              context.report({
                loc: {
                  start: firstComment.loc.start,
                  end: { line: firstComment.loc.start.line, column: firstComment.loc.start.column + 2 }
                },
                messageId: "expectedBareBlock",
                fix(fixer) {
                  return fixer.replaceText(firstComment, convertToBlock(firstComment, commentLines));
                }
              });
            }
          }
        };
        return {
          Program() {
            return sourceCode.getAllComments().filter((comment) => comment.type !== "Shebang").filter((comment) => !astUtils.COMMENTS_IGNORE_PATTERN.test(comment.value)).filter((comment) => {
              const tokenBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
              return !tokenBefore || tokenBefore.loc.end.line < comment.loc.start.line;
            }).reduce((commentGroups, comment, index, commentList) => {
              const tokenBefore = sourceCode.getTokenBefore(comment, { includeComments: true });
              if (comment.type === "Line" && index && commentList[index - 1].type === "Line" && tokenBefore && tokenBefore.loc.end.line === comment.loc.start.line - 1 && tokenBefore === commentList[index - 1]) {
                commentGroups[commentGroups.length - 1].push(comment);
              } else {
                commentGroups.push([comment]);
              }
              return commentGroups;
            }, []).filter((commentGroup) => !(commentGroup.length === 1 && commentGroup[0].loc.start.line === commentGroup[0].loc.end.line)).forEach(commentGroupCheckers[option]);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/multiline-ternary.js
var require_multiline_ternary = __commonJS({
  "node_modules/eslint/lib/rules/multiline-ternary.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce newlines between operands of ternary expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/multiline-ternary"
        },
        schema: [
          {
            enum: ["always", "always-multiline", "never"]
          }
        ],
        messages: {
          expectedTestCons: "Expected newline between test and consequent of ternary expression.",
          expectedConsAlt: "Expected newline between consequent and alternate of ternary expression.",
          unexpectedTestCons: "Unexpected newline between test and consequent of ternary expression.",
          unexpectedConsAlt: "Unexpected newline between consequent and alternate of ternary expression."
        },
        fixable: "whitespace"
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const option = context.options[0];
        const multiline = option !== "never";
        const allowSingleLine = option === "always-multiline";
        return {
          ConditionalExpression(node) {
            const questionToken = sourceCode.getTokenAfter(node.test, astUtils.isNotClosingParenToken);
            const colonToken = sourceCode.getTokenAfter(node.consequent, astUtils.isNotClosingParenToken);
            const firstTokenOfTest = sourceCode.getFirstToken(node);
            const lastTokenOfTest = sourceCode.getTokenBefore(questionToken);
            const firstTokenOfConsequent = sourceCode.getTokenAfter(questionToken);
            const lastTokenOfConsequent = sourceCode.getTokenBefore(colonToken);
            const firstTokenOfAlternate = sourceCode.getTokenAfter(colonToken);
            const areTestAndConsequentOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfTest, firstTokenOfConsequent);
            const areConsequentAndAlternateOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfConsequent, firstTokenOfAlternate);
            const hasComments = !!sourceCode.getCommentsInside(node).length;
            if (!multiline) {
              if (!areTestAndConsequentOnSameLine) {
                context.report({
                  node: node.test,
                  loc: {
                    start: firstTokenOfTest.loc.start,
                    end: lastTokenOfTest.loc.end
                  },
                  messageId: "unexpectedTestCons",
                  fix(fixer) {
                    if (hasComments) {
                      return null;
                    }
                    const fixers = [];
                    const areTestAndQuestionOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfTest, questionToken);
                    const areQuestionAndConsOnSameLine = astUtils.isTokenOnSameLine(questionToken, firstTokenOfConsequent);
                    if (!areTestAndQuestionOnSameLine) {
                      fixers.push(fixer.removeRange([lastTokenOfTest.range[1], questionToken.range[0]]));
                    }
                    if (!areQuestionAndConsOnSameLine) {
                      fixers.push(fixer.removeRange([questionToken.range[1], firstTokenOfConsequent.range[0]]));
                    }
                    return fixers;
                  }
                });
              }
              if (!areConsequentAndAlternateOnSameLine) {
                context.report({
                  node: node.consequent,
                  loc: {
                    start: firstTokenOfConsequent.loc.start,
                    end: lastTokenOfConsequent.loc.end
                  },
                  messageId: "unexpectedConsAlt",
                  fix(fixer) {
                    if (hasComments) {
                      return null;
                    }
                    const fixers = [];
                    const areConsAndColonOnSameLine = astUtils.isTokenOnSameLine(lastTokenOfConsequent, colonToken);
                    const areColonAndAltOnSameLine = astUtils.isTokenOnSameLine(colonToken, firstTokenOfAlternate);
                    if (!areConsAndColonOnSameLine) {
                      fixers.push(fixer.removeRange([lastTokenOfConsequent.range[1], colonToken.range[0]]));
                    }
                    if (!areColonAndAltOnSameLine) {
                      fixers.push(fixer.removeRange([colonToken.range[1], firstTokenOfAlternate.range[0]]));
                    }
                    return fixers;
                  }
                });
              }
            } else {
              if (allowSingleLine && node.loc.start.line === node.loc.end.line) {
                return;
              }
              if (areTestAndConsequentOnSameLine) {
                context.report({
                  node: node.test,
                  loc: {
                    start: firstTokenOfTest.loc.start,
                    end: lastTokenOfTest.loc.end
                  },
                  messageId: "expectedTestCons",
                  fix: (fixer) => hasComments ? null : fixer.replaceTextRange(
                    [
                      lastTokenOfTest.range[1],
                      questionToken.range[0]
                    ],
                    "\n"
                  )
                });
              }
              if (areConsequentAndAlternateOnSameLine) {
                context.report({
                  node: node.consequent,
                  loc: {
                    start: firstTokenOfConsequent.loc.start,
                    end: lastTokenOfConsequent.loc.end
                  },
                  messageId: "expectedConsAlt",
                  fix: (fixer) => hasComments ? null : fixer.replaceTextRange(
                    [
                      lastTokenOfConsequent.range[1],
                      colonToken.range[0]
                    ],
                    "\n"
                  )
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/new-cap.js
var require_new_cap = __commonJS({
  "node_modules/eslint/lib/rules/new-cap.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var CAPS_ALLOWED = [
      "Array",
      "Boolean",
      "Date",
      "Error",
      "Function",
      "Number",
      "Object",
      "RegExp",
      "String",
      "Symbol",
      "BigInt"
    ];
    function checkArray(obj, key, fallback) {
      if (Object.prototype.hasOwnProperty.call(obj, key) && !Array.isArray(obj[key])) {
        throw new TypeError(`${key}, if provided, must be an Array`);
      }
      return obj[key] || fallback;
    }
    function invert(map, key) {
      map[key] = true;
      return map;
    }
    function calculateCapIsNewExceptions(config) {
      let capIsNewExceptions = checkArray(config, "capIsNewExceptions", CAPS_ALLOWED);
      if (capIsNewExceptions !== CAPS_ALLOWED) {
        capIsNewExceptions = capIsNewExceptions.concat(CAPS_ALLOWED);
      }
      return capIsNewExceptions.reduce(invert, {});
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require constructor names to begin with a capital letter",
          recommended: false,
          url: "https://eslint.org/docs/rules/new-cap"
        },
        schema: [
          {
            type: "object",
            properties: {
              newIsCap: {
                type: "boolean",
                default: true
              },
              capIsNew: {
                type: "boolean",
                default: true
              },
              newIsCapExceptions: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              newIsCapExceptionPattern: {
                type: "string"
              },
              capIsNewExceptions: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              capIsNewExceptionPattern: {
                type: "string"
              },
              properties: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          upper: "A function with a name starting with an uppercase letter should only be used as a constructor.",
          lower: "A constructor name should not start with a lowercase letter."
        }
      },
      create(context) {
        const config = Object.assign({}, context.options[0]);
        config.newIsCap = config.newIsCap !== false;
        config.capIsNew = config.capIsNew !== false;
        const skipProperties = config.properties === false;
        const newIsCapExceptions = checkArray(config, "newIsCapExceptions", []).reduce(invert, {});
        const newIsCapExceptionPattern = config.newIsCapExceptionPattern ? new RegExp(config.newIsCapExceptionPattern, "u") : null;
        const capIsNewExceptions = calculateCapIsNewExceptions(config);
        const capIsNewExceptionPattern = config.capIsNewExceptionPattern ? new RegExp(config.capIsNewExceptionPattern, "u") : null;
        const listeners = {};
        const sourceCode = context.getSourceCode();
        function extractNameFromExpression(node) {
          return node.callee.type === "Identifier" ? node.callee.name : astUtils.getStaticPropertyName(node.callee) || "";
        }
        function getCap(str) {
          const firstChar = str.charAt(0);
          const firstCharLower = firstChar.toLowerCase();
          const firstCharUpper = firstChar.toUpperCase();
          if (firstCharLower === firstCharUpper) {
            return "non-alpha";
          }
          if (firstChar === firstCharLower) {
            return "lower";
          }
          return "upper";
        }
        function isCapAllowed(allowedMap, node, calleeName, pattern) {
          const sourceText = sourceCode.getText(node.callee);
          if (allowedMap[calleeName] || allowedMap[sourceText]) {
            return true;
          }
          if (pattern && pattern.test(sourceText)) {
            return true;
          }
          const callee = astUtils.skipChainExpression(node.callee);
          if (calleeName === "UTC" && callee.type === "MemberExpression") {
            return callee.object.type === "Identifier" && callee.object.name === "Date";
          }
          return skipProperties && callee.type === "MemberExpression";
        }
        function report(node, messageId) {
          let callee = astUtils.skipChainExpression(node.callee);
          if (callee.type === "MemberExpression") {
            callee = callee.property;
          }
          context.report({ node, loc: callee.loc, messageId });
        }
        if (config.newIsCap) {
          listeners.NewExpression = function(node) {
            const constructorName = extractNameFromExpression(node);
            if (constructorName) {
              const capitalization = getCap(constructorName);
              const isAllowed = capitalization !== "lower" || isCapAllowed(newIsCapExceptions, node, constructorName, newIsCapExceptionPattern);
              if (!isAllowed) {
                report(node, "lower");
              }
            }
          };
        }
        if (config.capIsNew) {
          listeners.CallExpression = function(node) {
            const calleeName = extractNameFromExpression(node);
            if (calleeName) {
              const capitalization = getCap(calleeName);
              const isAllowed = capitalization !== "upper" || isCapAllowed(capIsNewExceptions, node, calleeName, capIsNewExceptionPattern);
              if (!isAllowed) {
                report(node, "upper");
              }
            }
          };
        }
        return listeners;
      }
    };
  }
});

// node_modules/eslint/lib/rules/new-parens.js
var require_new_parens = __commonJS({
  "node_modules/eslint/lib/rules/new-parens.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce or disallow parentheses when invoking a constructor with no arguments",
          recommended: false,
          url: "https://eslint.org/docs/rules/new-parens"
        },
        fixable: "code",
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always", "never"]
                }
              ],
              minItems: 0,
              maxItems: 1
            }
          ]
        },
        messages: {
          missing: "Missing '()' invoking a constructor.",
          unnecessary: "Unnecessary '()' invoking a constructor with no arguments."
        }
      },
      create(context) {
        const options = context.options;
        const always = options[0] !== "never";
        const sourceCode = context.getSourceCode();
        return {
          NewExpression(node) {
            if (node.arguments.length !== 0) {
              return;
            }
            const lastToken = sourceCode.getLastToken(node);
            const hasLastParen = lastToken && astUtils.isClosingParenToken(lastToken);
            const hasParens = hasLastParen && astUtils.isOpeningParenToken(sourceCode.getTokenBefore(lastToken)) && node.callee.range[1] < node.range[1];
            if (always) {
              if (!hasParens) {
                context.report({
                  node,
                  messageId: "missing",
                  fix: (fixer) => fixer.insertTextAfter(node, "()")
                });
              }
            } else {
              if (hasParens) {
                context.report({
                  node,
                  messageId: "unnecessary",
                  fix: (fixer) => [
                    fixer.remove(sourceCode.getTokenBefore(lastToken)),
                    fixer.remove(lastToken),
                    fixer.insertTextBefore(node, "("),
                    fixer.insertTextAfter(node, ")")
                  ]
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/newline-after-var.js
var require_newline_after_var = __commonJS({
  "node_modules/eslint/lib/rules/newline-after-var.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow an empty line after variable declarations",
          recommended: false,
          url: "https://eslint.org/docs/rules/newline-after-var"
        },
        schema: [
          {
            enum: ["never", "always"]
          }
        ],
        fixable: "whitespace",
        messages: {
          expected: "Expected blank line after variable declarations.",
          unexpected: "Unexpected blank line after variable declarations."
        },
        deprecated: true,
        replacedBy: ["padding-line-between-statements"]
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const mode = context.options[0] === "never" ? "never" : "always";
        const commentEndLine = sourceCode.getAllComments().reduce((result, token) => {
          result[token.loc.start.line] = token.loc.end.line;
          return result;
        }, {});
        function getLastToken(node) {
          const lastToken = sourceCode.getLastToken(node);
          if (lastToken.type === "Punctuator" && lastToken.value === ";") {
            const prevToken = sourceCode.getTokenBefore(lastToken);
            if (prevToken.loc.end.line !== lastToken.loc.start.line) {
              return prevToken;
            }
          }
          return lastToken;
        }
        function isVar(keyword) {
          return keyword === "var" || keyword === "let" || keyword === "const";
        }
        function isForTypeSpecifier(keyword) {
          return keyword === "ForStatement" || keyword === "ForInStatement" || keyword === "ForOfStatement";
        }
        function isExportSpecifier(nodeType) {
          return nodeType === "ExportNamedDeclaration" || nodeType === "ExportSpecifier" || nodeType === "ExportDefaultDeclaration" || nodeType === "ExportAllDeclaration";
        }
        function isLastNode(node) {
          const token = sourceCode.getTokenAfter(node);
          return !token || token.type === "Punctuator" && token.value === "}";
        }
        function getLastCommentLineOfBlock(commentStartLine) {
          const currentCommentEnd = commentEndLine[commentStartLine];
          return commentEndLine[currentCommentEnd + 1] ? getLastCommentLineOfBlock(currentCommentEnd + 1) : currentCommentEnd;
        }
        function hasBlankLineAfterComment(token, commentStartLine) {
          return token.loc.start.line > getLastCommentLineOfBlock(commentStartLine) + 1;
        }
        function checkForBlankLine(node) {
          const lastToken = getLastToken(node), nextToken = lastToken === sourceCode.getLastToken(node) ? sourceCode.getTokenAfter(node) : sourceCode.getLastToken(node), nextLineNum = lastToken.loc.end.line + 1;
          if (!nextToken) {
            return;
          }
          if (isForTypeSpecifier(node.parent.type)) {
            return;
          }
          if (isExportSpecifier(node.parent.type)) {
            return;
          }
          if (nextToken.type === "Keyword" && isVar(nextToken.value)) {
            return;
          }
          if (isLastNode(node)) {
            return;
          }
          const noNextLineToken = nextToken.loc.start.line > nextLineNum;
          const hasNextLineComment = typeof commentEndLine[nextLineNum] !== "undefined";
          if (mode === "never" && noNextLineToken && !hasNextLineComment) {
            context.report({
              node,
              messageId: "unexpected",
              data: { identifier: node.name },
              fix(fixer) {
                const linesBetween = sourceCode.getText().slice(lastToken.range[1], nextToken.range[0]).split(astUtils.LINEBREAK_MATCHER);
                return fixer.replaceTextRange([lastToken.range[1], nextToken.range[0]], `${linesBetween.slice(0, -1).join("")}
${linesBetween[linesBetween.length - 1]}`);
              }
            });
          }
          if (mode === "always" && (!noNextLineToken || hasNextLineComment && !hasBlankLineAfterComment(nextToken, nextLineNum))) {
            context.report({
              node,
              messageId: "expected",
              data: { identifier: node.name },
              fix(fixer) {
                if ((noNextLineToken ? getLastCommentLineOfBlock(nextLineNum) : lastToken.loc.end.line) === nextToken.loc.start.line) {
                  return fixer.insertTextBefore(nextToken, "\n\n");
                }
                return fixer.insertTextBeforeRange([nextToken.range[0] - nextToken.loc.start.column, nextToken.range[1]], "\n");
              }
            });
          }
        }
        return {
          VariableDeclaration: checkForBlankLine
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/newline-before-return.js
var require_newline_before_return = __commonJS({
  "node_modules/eslint/lib/rules/newline-before-return.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require an empty line before `return` statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/newline-before-return"
        },
        fixable: "whitespace",
        schema: [],
        messages: {
          expected: "Expected newline before return statement."
        },
        deprecated: true,
        replacedBy: ["padding-line-between-statements"]
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function isPrecededByTokens(node, testTokens) {
          const tokenBefore = sourceCode.getTokenBefore(node);
          return testTokens.includes(tokenBefore.value);
        }
        function isFirstNode(node) {
          const parentType = node.parent.type;
          if (node.parent.body) {
            return Array.isArray(node.parent.body) ? node.parent.body[0] === node : node.parent.body === node;
          }
          if (parentType === "IfStatement") {
            return isPrecededByTokens(node, ["else", ")"]);
          }
          if (parentType === "DoWhileStatement") {
            return isPrecededByTokens(node, ["do"]);
          }
          if (parentType === "SwitchCase") {
            return isPrecededByTokens(node, [":"]);
          }
          return isPrecededByTokens(node, [")"]);
        }
        function calcCommentLines(node, lineNumTokenBefore) {
          const comments = sourceCode.getCommentsBefore(node);
          let numLinesComments = 0;
          if (!comments.length) {
            return numLinesComments;
          }
          comments.forEach((comment) => {
            numLinesComments++;
            if (comment.type === "Block") {
              numLinesComments += comment.loc.end.line - comment.loc.start.line;
            }
            if (comment.loc.start.line === lineNumTokenBefore) {
              numLinesComments--;
            }
            if (comment.loc.end.line === node.loc.start.line) {
              numLinesComments--;
            }
          });
          return numLinesComments;
        }
        function getLineNumberOfTokenBefore(node) {
          const tokenBefore = sourceCode.getTokenBefore(node);
          let lineNumTokenBefore;
          if (tokenBefore) {
            lineNumTokenBefore = tokenBefore.loc.end.line;
          } else {
            lineNumTokenBefore = 0;
          }
          return lineNumTokenBefore;
        }
        function hasNewlineBefore(node) {
          const lineNumNode = node.loc.start.line;
          const lineNumTokenBefore = getLineNumberOfTokenBefore(node);
          const commentLines = calcCommentLines(node, lineNumTokenBefore);
          return lineNumNode - lineNumTokenBefore - commentLines > 1;
        }
        function canFix(node) {
          const leadingComments = sourceCode.getCommentsBefore(node);
          const lastLeadingComment = leadingComments[leadingComments.length - 1];
          const tokenBefore = sourceCode.getTokenBefore(node);
          if (leadingComments.length === 0) {
            return true;
          }
          if (lastLeadingComment.loc.end.line === tokenBefore.loc.end.line && lastLeadingComment.loc.end.line !== node.loc.start.line) {
            return true;
          }
          return false;
        }
        return {
          ReturnStatement(node) {
            if (!isFirstNode(node) && !hasNewlineBefore(node)) {
              context.report({
                node,
                messageId: "expected",
                fix(fixer) {
                  if (canFix(node)) {
                    const tokenBefore = sourceCode.getTokenBefore(node);
                    const newlines = node.loc.start.line === tokenBefore.loc.end.line ? "\n\n" : "\n";
                    return fixer.insertTextBefore(node, newlines);
                  }
                  return null;
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/newline-per-chained-call.js
var require_newline_per_chained_call = __commonJS({
  "node_modules/eslint/lib/rules/newline-per-chained-call.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require a newline after each call in a method chain",
          recommended: false,
          url: "https://eslint.org/docs/rules/newline-per-chained-call"
        },
        fixable: "whitespace",
        schema: [{
          type: "object",
          properties: {
            ignoreChainWithDepth: {
              type: "integer",
              minimum: 1,
              maximum: 10,
              default: 2
            }
          },
          additionalProperties: false
        }],
        messages: {
          expected: "Expected line break before `{{callee}}`."
        }
      },
      create(context) {
        const options = context.options[0] || {}, ignoreChainWithDepth = options.ignoreChainWithDepth || 2;
        const sourceCode = context.getSourceCode();
        function getPrefix(node) {
          if (node.computed) {
            if (node.optional) {
              return "?.[";
            }
            return "[";
          }
          if (node.optional) {
            return "?.";
          }
          return ".";
        }
        function getPropertyText(node) {
          const prefix = getPrefix(node);
          const lines = sourceCode.getText(node.property).split(astUtils.LINEBREAK_MATCHER);
          const suffix = node.computed && lines.length === 1 ? "]" : "";
          return prefix + lines[0] + suffix;
        }
        return {
          "CallExpression:exit"(node) {
            const callee = astUtils.skipChainExpression(node.callee);
            if (callee.type !== "MemberExpression") {
              return;
            }
            let parent = astUtils.skipChainExpression(callee.object);
            let depth = 1;
            while (parent && parent.callee) {
              depth += 1;
              parent = astUtils.skipChainExpression(astUtils.skipChainExpression(parent.callee).object);
            }
            if (depth > ignoreChainWithDepth && astUtils.isTokenOnSameLine(callee.object, callee.property)) {
              const firstTokenAfterObject = sourceCode.getTokenAfter(callee.object, astUtils.isNotClosingParenToken);
              context.report({
                node: callee.property,
                loc: {
                  start: firstTokenAfterObject.loc.start,
                  end: callee.loc.end
                },
                messageId: "expected",
                data: {
                  callee: getPropertyText(callee)
                },
                fix(fixer) {
                  return fixer.insertTextBefore(firstTokenAfterObject, "\n");
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-alert.js
var require_no_alert = __commonJS({
  "node_modules/eslint/lib/rules/no-alert.js"(exports, module2) {
    "use strict";
    var {
      getStaticPropertyName: getPropertyName,
      getVariableByName,
      skipChainExpression
    } = require_ast_utils2();
    function isProhibitedIdentifier(name) {
      return /^(alert|confirm|prompt)$/u.test(name);
    }
    function findReference(scope, node) {
      const references = scope.references.filter((reference) => reference.identifier.range[0] === node.range[0] && reference.identifier.range[1] === node.range[1]);
      if (references.length === 1) {
        return references[0];
      }
      return null;
    }
    function isShadowed(scope, node) {
      const reference = findReference(scope, node);
      return reference && reference.resolved && reference.resolved.defs.length > 0;
    }
    function isGlobalThisReferenceOrGlobalWindow(scope, node) {
      if (scope.type === "global" && node.type === "ThisExpression") {
        return true;
      }
      if (node.type === "Identifier" && (node.name === "window" || node.name === "globalThis" && getVariableByName(scope, "globalThis"))) {
        return !isShadowed(scope, node);
      }
      return false;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `alert`, `confirm`, and `prompt`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-alert"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected {{name}}."
        }
      },
      create(context) {
        return {
          CallExpression(node) {
            const callee = skipChainExpression(node.callee), currentScope = context.getScope();
            if (callee.type === "Identifier") {
              const name = callee.name;
              if (!isShadowed(currentScope, callee) && isProhibitedIdentifier(callee.name)) {
                context.report({
                  node,
                  messageId: "unexpected",
                  data: { name }
                });
              }
            } else if (callee.type === "MemberExpression" && isGlobalThisReferenceOrGlobalWindow(currentScope, callee.object)) {
              const name = getPropertyName(callee);
              if (isProhibitedIdentifier(name)) {
                context.report({
                  node,
                  messageId: "unexpected",
                  data: { name }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-array-constructor.js
var require_no_array_constructor = __commonJS({
  "node_modules/eslint/lib/rules/no-array-constructor.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `Array` constructors",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-array-constructor"
        },
        schema: [],
        messages: {
          preferLiteral: "The array literal notation [] is preferable."
        }
      },
      create(context) {
        function check(node) {
          if (node.arguments.length !== 1 && node.callee.type === "Identifier" && node.callee.name === "Array") {
            context.report({ node, messageId: "preferLiteral" });
          }
        }
        return {
          CallExpression: check,
          NewExpression: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-async-promise-executor.js
var require_no_async_promise_executor = __commonJS({
  "node_modules/eslint/lib/rules/no-async-promise-executor.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow using an async function as a Promise executor",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-async-promise-executor"
        },
        fixable: null,
        schema: [],
        messages: {
          async: "Promise executor functions should not be async."
        }
      },
      create(context) {
        return {
          "NewExpression[callee.name='Promise'][arguments.0.async=true]"(node) {
            context.report({
              node: context.getSourceCode().getFirstToken(node.arguments[0], (token) => token.value === "async"),
              messageId: "async"
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-await-in-loop.js
var require_no_await_in_loop = __commonJS({
  "node_modules/eslint/lib/rules/no-await-in-loop.js"(exports, module2) {
    "use strict";
    function isBoundary(node) {
      const t3 = node.type;
      return t3 === "FunctionDeclaration" || t3 === "FunctionExpression" || t3 === "ArrowFunctionExpression" || /*
       * Don't report the await expressions on for-await-of loop since it's
       * asynchronous iteration intentionally.
       */
      t3 === "ForOfStatement" && node.await === true;
    }
    function isLooped(node, parent) {
      switch (parent.type) {
        case "ForStatement":
          return node === parent.test || node === parent.update || node === parent.body;
        case "ForOfStatement":
        case "ForInStatement":
          return node === parent.body;
        case "WhileStatement":
        case "DoWhileStatement":
          return node === parent.test || node === parent.body;
        default:
          return false;
      }
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow `await` inside of loops",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-await-in-loop"
        },
        schema: [],
        messages: {
          unexpectedAwait: "Unexpected `await` inside a loop."
        }
      },
      create(context) {
        function validate(awaitNode) {
          if (awaitNode.type === "ForOfStatement" && !awaitNode.await) {
            return;
          }
          let node = awaitNode;
          let parent = node.parent;
          while (parent && !isBoundary(parent)) {
            if (isLooped(node, parent)) {
              context.report({
                node: awaitNode,
                messageId: "unexpectedAwait"
              });
              return;
            }
            node = parent;
            parent = parent.parent;
          }
        }
        return {
          AwaitExpression: validate,
          ForOfStatement: validate
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-bitwise.js
var require_no_bitwise = __commonJS({
  "node_modules/eslint/lib/rules/no-bitwise.js"(exports, module2) {
    "use strict";
    var BITWISE_OPERATORS = [
      "^",
      "|",
      "&",
      "<<",
      ">>",
      ">>>",
      "^=",
      "|=",
      "&=",
      "<<=",
      ">>=",
      ">>>=",
      "~"
    ];
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow bitwise operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-bitwise"
        },
        schema: [
          {
            type: "object",
            properties: {
              allow: {
                type: "array",
                items: {
                  enum: BITWISE_OPERATORS
                },
                uniqueItems: true
              },
              int32Hint: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "Unexpected use of '{{operator}}'."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const allowed = options.allow || [];
        const int32Hint = options.int32Hint === true;
        function report(node) {
          context.report({ node, messageId: "unexpected", data: { operator: node.operator } });
        }
        function hasBitwiseOperator(node) {
          return BITWISE_OPERATORS.includes(node.operator);
        }
        function allowedOperator(node) {
          return allowed.includes(node.operator);
        }
        function isInt32Hint(node) {
          return int32Hint && node.operator === "|" && node.right && node.right.type === "Literal" && node.right.value === 0;
        }
        function checkNodeForBitwiseOperator(node) {
          if (hasBitwiseOperator(node) && !allowedOperator(node) && !isInt32Hint(node)) {
            report(node);
          }
        }
        return {
          AssignmentExpression: checkNodeForBitwiseOperator,
          BinaryExpression: checkNodeForBitwiseOperator,
          UnaryExpression: checkNodeForBitwiseOperator
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-buffer-constructor.js
var require_no_buffer_constructor = __commonJS({
  "node_modules/eslint/lib/rules/no-buffer-constructor.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "problem",
        docs: {
          description: "Disallow use of the `Buffer()` constructor",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-buffer-constructor"
        },
        schema: [],
        messages: {
          deprecated: "{{expr}} is deprecated. Use Buffer.from(), Buffer.alloc(), or Buffer.allocUnsafe() instead."
        }
      },
      create(context) {
        return {
          "CallExpression[callee.name='Buffer'], NewExpression[callee.name='Buffer']"(node) {
            context.report({
              node,
              messageId: "deprecated",
              data: { expr: node.type === "CallExpression" ? "Buffer()" : "new Buffer()" }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-caller.js
var require_no_caller = __commonJS({
  "node_modules/eslint/lib/rules/no-caller.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `arguments.caller` or `arguments.callee`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-caller"
        },
        schema: [],
        messages: {
          unexpected: "Avoid arguments.{{prop}}."
        }
      },
      create(context) {
        return {
          MemberExpression(node) {
            const objectName = node.object.name, propertyName = node.property.name;
            if (objectName === "arguments" && !node.computed && propertyName && propertyName.match(/^calle[er]$/u)) {
              context.report({ node, messageId: "unexpected", data: { prop: propertyName } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-case-declarations.js
var require_no_case_declarations = __commonJS({
  "node_modules/eslint/lib/rules/no-case-declarations.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow lexical declarations in case clauses",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-case-declarations"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected lexical declaration in case block."
        }
      },
      create(context) {
        function isLexicalDeclaration(node) {
          switch (node.type) {
            case "FunctionDeclaration":
            case "ClassDeclaration":
              return true;
            case "VariableDeclaration":
              return node.kind !== "var";
            default:
              return false;
          }
        }
        return {
          SwitchCase(node) {
            for (let i = 0; i < node.consequent.length; i++) {
              const statement = node.consequent[i];
              if (isLexicalDeclaration(statement)) {
                context.report({
                  node: statement,
                  messageId: "unexpected"
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-catch-shadow.js
var require_no_catch_shadow = __commonJS({
  "node_modules/eslint/lib/rules/no-catch-shadow.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `catch` clause parameters from shadowing variables in the outer scope",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-catch-shadow"
        },
        replacedBy: ["no-shadow"],
        deprecated: true,
        schema: [],
        messages: {
          mutable: "Value of '{{name}}' may be overwritten in IE 8 and earlier."
        }
      },
      create(context) {
        function paramIsShadowing(scope, name) {
          return astUtils.getVariableByName(scope, name) !== null;
        }
        return {
          "CatchClause[param!=null]"(node) {
            let scope = context.getScope();
            if (scope.block === node) {
              scope = scope.upper;
            }
            if (paramIsShadowing(scope, node.param.name)) {
              context.report({ node, messageId: "mutable", data: { name: node.param.name } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-class-assign.js
var require_no_class_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-class-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow reassigning class members",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-class-assign"
        },
        schema: [],
        messages: {
          class: "'{{name}}' is a class."
        }
      },
      create(context) {
        function checkVariable(variable) {
          astUtils.getModifyingReferences(variable.references).forEach((reference) => {
            context.report({ node: reference.identifier, messageId: "class", data: { name: reference.identifier.name } });
          });
        }
        function checkForClass(node) {
          context.getDeclaredVariables(node).forEach(checkVariable);
        }
        return {
          ClassDeclaration: checkForClass,
          ClassExpression: checkForClass
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-compare-neg-zero.js
var require_no_compare_neg_zero = __commonJS({
  "node_modules/eslint/lib/rules/no-compare-neg-zero.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow comparing against -0",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-compare-neg-zero"
        },
        fixable: null,
        schema: [],
        messages: {
          unexpected: "Do not use the '{{operator}}' operator to compare against -0."
        }
      },
      create(context) {
        function isNegZero(node) {
          return node.type === "UnaryExpression" && node.operator === "-" && node.argument.type === "Literal" && node.argument.value === 0;
        }
        const OPERATORS_TO_CHECK = /* @__PURE__ */ new Set([">", ">=", "<", "<=", "==", "===", "!=", "!=="]);
        return {
          BinaryExpression(node) {
            if (OPERATORS_TO_CHECK.has(node.operator)) {
              if (isNegZero(node.left) || isNegZero(node.right)) {
                context.report({
                  node,
                  messageId: "unexpected",
                  data: { operator: node.operator }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-cond-assign.js
var require_no_cond_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-cond-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var TEST_CONDITION_PARENT_TYPES = /* @__PURE__ */ new Set(["IfStatement", "WhileStatement", "DoWhileStatement", "ForStatement", "ConditionalExpression"]);
    var NODE_DESCRIPTIONS = {
      DoWhileStatement: "a 'do...while' statement",
      ForStatement: "a 'for' statement",
      IfStatement: "an 'if' statement",
      WhileStatement: "a 'while' statement"
    };
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow assignment operators in conditional expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-cond-assign"
        },
        schema: [
          {
            enum: ["except-parens", "always"]
          }
        ],
        messages: {
          unexpected: "Unexpected assignment within {{type}}.",
          // must match JSHint's error message
          missing: "Expected a conditional expression and instead saw an assignment."
        }
      },
      create(context) {
        const prohibitAssign = context.options[0] || "except-parens";
        const sourceCode = context.getSourceCode();
        function isConditionalTestExpression(node) {
          return node.parent && TEST_CONDITION_PARENT_TYPES.has(node.parent.type) && node === node.parent.test;
        }
        function findConditionalAncestor(node) {
          let currentAncestor = node;
          do {
            if (isConditionalTestExpression(currentAncestor)) {
              return currentAncestor.parent;
            }
          } while ((currentAncestor = currentAncestor.parent) && !astUtils.isFunction(currentAncestor));
          return null;
        }
        function isParenthesisedTwice(node) {
          const previousToken = sourceCode.getTokenBefore(node, 1), nextToken = sourceCode.getTokenAfter(node, 1);
          return astUtils.isParenthesised(sourceCode, node) && previousToken && astUtils.isOpeningParenToken(previousToken) && previousToken.range[1] <= node.range[0] && astUtils.isClosingParenToken(nextToken) && nextToken.range[0] >= node.range[1];
        }
        function testForAssign(node) {
          if (node.test && node.test.type === "AssignmentExpression" && (node.type === "ForStatement" ? !astUtils.isParenthesised(sourceCode, node.test) : !isParenthesisedTwice(node.test))) {
            context.report({
              node: node.test,
              messageId: "missing"
            });
          }
        }
        function testForConditionalAncestor(node) {
          const ancestor = findConditionalAncestor(node);
          if (ancestor) {
            context.report({
              node,
              messageId: "unexpected",
              data: {
                type: NODE_DESCRIPTIONS[ancestor.type] || ancestor.type
              }
            });
          }
        }
        if (prohibitAssign === "always") {
          return {
            AssignmentExpression: testForConditionalAncestor
          };
        }
        return {
          DoWhileStatement: testForAssign,
          ForStatement: testForAssign,
          IfStatement: testForAssign,
          WhileStatement: testForAssign,
          ConditionalExpression: testForAssign
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-confusing-arrow.js
var require_no_confusing_arrow = __commonJS({
  "node_modules/eslint/lib/rules/no-confusing-arrow.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isConditional(node) {
      return node && node.type === "ConditionalExpression";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow arrow functions where they could be confused with comparisons",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-confusing-arrow"
        },
        fixable: "code",
        schema: [{
          type: "object",
          properties: {
            allowParens: { type: "boolean", default: true },
            onlyOneSimpleParam: { type: "boolean", default: false }
          },
          additionalProperties: false
        }],
        messages: {
          confusing: "Arrow function used ambiguously with a conditional expression."
        }
      },
      create(context) {
        const config = context.options[0] || {};
        const allowParens = config.allowParens || config.allowParens === void 0;
        const onlyOneSimpleParam = config.onlyOneSimpleParam;
        const sourceCode = context.getSourceCode();
        function checkArrowFunc(node) {
          const body = node.body;
          if (isConditional(body) && !(allowParens && astUtils.isParenthesised(sourceCode, body)) && !(onlyOneSimpleParam && !(node.params.length === 1 && node.params[0].type === "Identifier"))) {
            context.report({
              node,
              messageId: "confusing",
              fix(fixer) {
                return allowParens && fixer.replaceText(node.body, `(${sourceCode.getText(node.body)})`);
              }
            });
          }
        }
        return {
          ArrowFunctionExpression: checkArrowFunc
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-console.js
var require_no_console = __commonJS({
  "node_modules/eslint/lib/rules/no-console.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `console`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-console"
        },
        schema: [
          {
            type: "object",
            properties: {
              allow: {
                type: "array",
                items: {
                  type: "string"
                },
                minItems: 1,
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "Unexpected console statement."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const allowed = options.allow || [];
        function isConsole(reference) {
          const id = reference.identifier;
          return id && id.name === "console";
        }
        function isAllowed(node) {
          const propertyName = astUtils.getStaticPropertyName(node);
          return propertyName && allowed.includes(propertyName);
        }
        function isMemberAccessExceptAllowed(reference) {
          const node = reference.identifier;
          const parent = node.parent;
          return parent.type === "MemberExpression" && parent.object === node && !isAllowed(parent);
        }
        function report(reference) {
          const node = reference.identifier.parent;
          context.report({
            node,
            loc: node.loc,
            messageId: "unexpected"
          });
        }
        return {
          "Program:exit"() {
            const scope = context.getScope();
            const consoleVar = astUtils.getVariableByName(scope, "console");
            const shadowed = consoleVar && consoleVar.defs.length > 0;
            const references = consoleVar ? consoleVar.references : scope.through.filter(isConsole);
            if (!shadowed) {
              references.filter(isMemberAccessExceptAllowed).forEach(report);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-const-assign.js
var require_no_const_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-const-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow reassigning `const` variables",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-const-assign"
        },
        schema: [],
        messages: {
          const: "'{{name}}' is constant."
        }
      },
      create(context) {
        function checkVariable(variable) {
          astUtils.getModifyingReferences(variable.references).forEach((reference) => {
            context.report({ node: reference.identifier, messageId: "const", data: { name: reference.identifier.name } });
          });
        }
        return {
          VariableDeclaration(node) {
            if (node.kind === "const") {
              context.getDeclaredVariables(node).forEach(checkVariable);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/node_modules/globals/globals.json
var require_globals3 = __commonJS({
  "node_modules/eslint/node_modules/globals/globals.json"(exports, module2) {
    module2.exports = {
      builtin: {
        AggregateError: false,
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        FinalizationRegistry: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakRef: false,
        WeakSet: false
      },
      es5: {
        Array: false,
        Boolean: false,
        constructor: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        propertyIsEnumerable: false,
        RangeError: false,
        ReferenceError: false,
        RegExp: false,
        String: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false
      },
      es2015: {
        Array: false,
        ArrayBuffer: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2017: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2020: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2021: {
        AggregateError: false,
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        FinalizationRegistry: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakRef: false,
        WeakSet: false
      },
      browser: {
        AbortController: false,
        AbortSignal: false,
        addEventListener: false,
        alert: false,
        AnalyserNode: false,
        Animation: false,
        AnimationEffectReadOnly: false,
        AnimationEffectTiming: false,
        AnimationEffectTimingReadOnly: false,
        AnimationEvent: false,
        AnimationPlaybackEvent: false,
        AnimationTimeline: false,
        applicationCache: false,
        ApplicationCache: false,
        ApplicationCacheErrorEvent: false,
        atob: false,
        Attr: false,
        Audio: false,
        AudioBuffer: false,
        AudioBufferSourceNode: false,
        AudioContext: false,
        AudioDestinationNode: false,
        AudioListener: false,
        AudioNode: false,
        AudioParam: false,
        AudioProcessingEvent: false,
        AudioScheduledSourceNode: false,
        AudioWorkletGlobalScope: false,
        AudioWorkletNode: false,
        AudioWorkletProcessor: false,
        BarProp: false,
        BaseAudioContext: false,
        BatteryManager: false,
        BeforeUnloadEvent: false,
        BiquadFilterNode: false,
        Blob: false,
        BlobEvent: false,
        blur: false,
        BroadcastChannel: false,
        btoa: false,
        BudgetService: false,
        ByteLengthQueuingStrategy: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        cancelAnimationFrame: false,
        cancelIdleCallback: false,
        CanvasCaptureMediaStreamTrack: false,
        CanvasGradient: false,
        CanvasPattern: false,
        CanvasRenderingContext2D: false,
        ChannelMergerNode: false,
        ChannelSplitterNode: false,
        CharacterData: false,
        clearInterval: false,
        clearTimeout: false,
        clientInformation: false,
        ClipboardEvent: false,
        ClipboardItem: false,
        close: false,
        closed: false,
        CloseEvent: false,
        Comment: false,
        CompositionEvent: false,
        confirm: false,
        console: false,
        ConstantSourceNode: false,
        ConvolverNode: false,
        CountQueuingStrategy: false,
        createImageBitmap: false,
        Credential: false,
        CredentialsContainer: false,
        crypto: false,
        Crypto: false,
        CryptoKey: false,
        CSS: false,
        CSSConditionRule: false,
        CSSFontFaceRule: false,
        CSSGroupingRule: false,
        CSSImportRule: false,
        CSSKeyframeRule: false,
        CSSKeyframesRule: false,
        CSSMatrixComponent: false,
        CSSMediaRule: false,
        CSSNamespaceRule: false,
        CSSPageRule: false,
        CSSPerspective: false,
        CSSRotate: false,
        CSSRule: false,
        CSSRuleList: false,
        CSSScale: false,
        CSSSkew: false,
        CSSSkewX: false,
        CSSSkewY: false,
        CSSStyleDeclaration: false,
        CSSStyleRule: false,
        CSSStyleSheet: false,
        CSSSupportsRule: false,
        CSSTransformValue: false,
        CSSTranslate: false,
        CustomElementRegistry: false,
        customElements: false,
        CustomEvent: false,
        DataTransfer: false,
        DataTransferItem: false,
        DataTransferItemList: false,
        defaultstatus: false,
        defaultStatus: false,
        DelayNode: false,
        DeviceMotionEvent: false,
        DeviceOrientationEvent: false,
        devicePixelRatio: false,
        dispatchEvent: false,
        document: false,
        Document: false,
        DocumentFragment: false,
        DocumentType: false,
        DOMError: false,
        DOMException: false,
        DOMImplementation: false,
        DOMMatrix: false,
        DOMMatrixReadOnly: false,
        DOMParser: false,
        DOMPoint: false,
        DOMPointReadOnly: false,
        DOMQuad: false,
        DOMRect: false,
        DOMRectList: false,
        DOMRectReadOnly: false,
        DOMStringList: false,
        DOMStringMap: false,
        DOMTokenList: false,
        DragEvent: false,
        DynamicsCompressorNode: false,
        Element: false,
        ErrorEvent: false,
        event: false,
        Event: false,
        EventSource: false,
        EventTarget: false,
        external: false,
        fetch: false,
        File: false,
        FileList: false,
        FileReader: false,
        find: false,
        focus: false,
        FocusEvent: false,
        FontFace: false,
        FontFaceSetLoadEvent: false,
        FormData: false,
        FormDataEvent: false,
        frameElement: false,
        frames: false,
        GainNode: false,
        Gamepad: false,
        GamepadButton: false,
        GamepadEvent: false,
        getComputedStyle: false,
        getSelection: false,
        HashChangeEvent: false,
        Headers: false,
        history: false,
        History: false,
        HTMLAllCollection: false,
        HTMLAnchorElement: false,
        HTMLAreaElement: false,
        HTMLAudioElement: false,
        HTMLBaseElement: false,
        HTMLBodyElement: false,
        HTMLBRElement: false,
        HTMLButtonElement: false,
        HTMLCanvasElement: false,
        HTMLCollection: false,
        HTMLContentElement: false,
        HTMLDataElement: false,
        HTMLDataListElement: false,
        HTMLDetailsElement: false,
        HTMLDialogElement: false,
        HTMLDirectoryElement: false,
        HTMLDivElement: false,
        HTMLDListElement: false,
        HTMLDocument: false,
        HTMLElement: false,
        HTMLEmbedElement: false,
        HTMLFieldSetElement: false,
        HTMLFontElement: false,
        HTMLFormControlsCollection: false,
        HTMLFormElement: false,
        HTMLFrameElement: false,
        HTMLFrameSetElement: false,
        HTMLHeadElement: false,
        HTMLHeadingElement: false,
        HTMLHRElement: false,
        HTMLHtmlElement: false,
        HTMLIFrameElement: false,
        HTMLImageElement: false,
        HTMLInputElement: false,
        HTMLLabelElement: false,
        HTMLLegendElement: false,
        HTMLLIElement: false,
        HTMLLinkElement: false,
        HTMLMapElement: false,
        HTMLMarqueeElement: false,
        HTMLMediaElement: false,
        HTMLMenuElement: false,
        HTMLMetaElement: false,
        HTMLMeterElement: false,
        HTMLModElement: false,
        HTMLObjectElement: false,
        HTMLOListElement: false,
        HTMLOptGroupElement: false,
        HTMLOptionElement: false,
        HTMLOptionsCollection: false,
        HTMLOutputElement: false,
        HTMLParagraphElement: false,
        HTMLParamElement: false,
        HTMLPictureElement: false,
        HTMLPreElement: false,
        HTMLProgressElement: false,
        HTMLQuoteElement: false,
        HTMLScriptElement: false,
        HTMLSelectElement: false,
        HTMLShadowElement: false,
        HTMLSlotElement: false,
        HTMLSourceElement: false,
        HTMLSpanElement: false,
        HTMLStyleElement: false,
        HTMLTableCaptionElement: false,
        HTMLTableCellElement: false,
        HTMLTableColElement: false,
        HTMLTableElement: false,
        HTMLTableRowElement: false,
        HTMLTableSectionElement: false,
        HTMLTemplateElement: false,
        HTMLTextAreaElement: false,
        HTMLTimeElement: false,
        HTMLTitleElement: false,
        HTMLTrackElement: false,
        HTMLUListElement: false,
        HTMLUnknownElement: false,
        HTMLVideoElement: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        IdleDeadline: false,
        IIRFilterNode: false,
        Image: false,
        ImageBitmap: false,
        ImageBitmapRenderingContext: false,
        ImageCapture: false,
        ImageData: false,
        indexedDB: false,
        innerHeight: false,
        innerWidth: false,
        InputEvent: false,
        IntersectionObserver: false,
        IntersectionObserverEntry: false,
        Intl: false,
        isSecureContext: false,
        KeyboardEvent: false,
        KeyframeEffect: false,
        KeyframeEffectReadOnly: false,
        length: false,
        localStorage: false,
        location: true,
        Location: false,
        locationbar: false,
        matchMedia: false,
        MediaDeviceInfo: false,
        MediaDevices: false,
        MediaElementAudioSourceNode: false,
        MediaEncryptedEvent: false,
        MediaError: false,
        MediaKeyMessageEvent: false,
        MediaKeySession: false,
        MediaKeyStatusMap: false,
        MediaKeySystemAccess: false,
        MediaList: false,
        MediaMetadata: false,
        MediaQueryList: false,
        MediaQueryListEvent: false,
        MediaRecorder: false,
        MediaSettingsRange: false,
        MediaSource: false,
        MediaStream: false,
        MediaStreamAudioDestinationNode: false,
        MediaStreamAudioSourceNode: false,
        MediaStreamEvent: false,
        MediaStreamTrack: false,
        MediaStreamTrackEvent: false,
        menubar: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        MIDIAccess: false,
        MIDIConnectionEvent: false,
        MIDIInput: false,
        MIDIInputMap: false,
        MIDIMessageEvent: false,
        MIDIOutput: false,
        MIDIOutputMap: false,
        MIDIPort: false,
        MimeType: false,
        MimeTypeArray: false,
        MouseEvent: false,
        moveBy: false,
        moveTo: false,
        MutationEvent: false,
        MutationObserver: false,
        MutationRecord: false,
        name: false,
        NamedNodeMap: false,
        NavigationPreloadManager: false,
        navigator: false,
        Navigator: false,
        NavigatorUAData: false,
        NetworkInformation: false,
        Node: false,
        NodeFilter: false,
        NodeIterator: false,
        NodeList: false,
        Notification: false,
        OfflineAudioCompletionEvent: false,
        OfflineAudioContext: false,
        offscreenBuffering: false,
        OffscreenCanvas: true,
        OffscreenCanvasRenderingContext2D: false,
        onabort: true,
        onafterprint: true,
        onanimationend: true,
        onanimationiteration: true,
        onanimationstart: true,
        onappinstalled: true,
        onauxclick: true,
        onbeforeinstallprompt: true,
        onbeforeprint: true,
        onbeforeunload: true,
        onblur: true,
        oncancel: true,
        oncanplay: true,
        oncanplaythrough: true,
        onchange: true,
        onclick: true,
        onclose: true,
        oncontextmenu: true,
        oncuechange: true,
        ondblclick: true,
        ondevicemotion: true,
        ondeviceorientation: true,
        ondeviceorientationabsolute: true,
        ondrag: true,
        ondragend: true,
        ondragenter: true,
        ondragleave: true,
        ondragover: true,
        ondragstart: true,
        ondrop: true,
        ondurationchange: true,
        onemptied: true,
        onended: true,
        onerror: true,
        onfocus: true,
        ongotpointercapture: true,
        onhashchange: true,
        oninput: true,
        oninvalid: true,
        onkeydown: true,
        onkeypress: true,
        onkeyup: true,
        onlanguagechange: true,
        onload: true,
        onloadeddata: true,
        onloadedmetadata: true,
        onloadstart: true,
        onlostpointercapture: true,
        onmessage: true,
        onmessageerror: true,
        onmousedown: true,
        onmouseenter: true,
        onmouseleave: true,
        onmousemove: true,
        onmouseout: true,
        onmouseover: true,
        onmouseup: true,
        onmousewheel: true,
        onoffline: true,
        ononline: true,
        onpagehide: true,
        onpageshow: true,
        onpause: true,
        onplay: true,
        onplaying: true,
        onpointercancel: true,
        onpointerdown: true,
        onpointerenter: true,
        onpointerleave: true,
        onpointermove: true,
        onpointerout: true,
        onpointerover: true,
        onpointerup: true,
        onpopstate: true,
        onprogress: true,
        onratechange: true,
        onrejectionhandled: true,
        onreset: true,
        onresize: true,
        onscroll: true,
        onsearch: true,
        onseeked: true,
        onseeking: true,
        onselect: true,
        onstalled: true,
        onstorage: true,
        onsubmit: true,
        onsuspend: true,
        ontimeupdate: true,
        ontoggle: true,
        ontransitionend: true,
        onunhandledrejection: true,
        onunload: true,
        onvolumechange: true,
        onwaiting: true,
        onwheel: true,
        open: false,
        openDatabase: false,
        opener: false,
        Option: false,
        origin: false,
        OscillatorNode: false,
        outerHeight: false,
        outerWidth: false,
        OverconstrainedError: false,
        PageTransitionEvent: false,
        pageXOffset: false,
        pageYOffset: false,
        PannerNode: false,
        parent: false,
        Path2D: false,
        PaymentAddress: false,
        PaymentRequest: false,
        PaymentRequestUpdateEvent: false,
        PaymentResponse: false,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceLongTaskTiming: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceNavigationTiming: false,
        PerformanceObserver: false,
        PerformanceObserverEntryList: false,
        PerformancePaintTiming: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        PeriodicWave: false,
        Permissions: false,
        PermissionStatus: false,
        personalbar: false,
        PhotoCapabilities: false,
        Plugin: false,
        PluginArray: false,
        PointerEvent: false,
        PopStateEvent: false,
        postMessage: false,
        Presentation: false,
        PresentationAvailability: false,
        PresentationConnection: false,
        PresentationConnectionAvailableEvent: false,
        PresentationConnectionCloseEvent: false,
        PresentationConnectionList: false,
        PresentationReceiver: false,
        PresentationRequest: false,
        print: false,
        ProcessingInstruction: false,
        ProgressEvent: false,
        PromiseRejectionEvent: false,
        prompt: false,
        PushManager: false,
        PushSubscription: false,
        PushSubscriptionOptions: false,
        queueMicrotask: false,
        RadioNodeList: false,
        Range: false,
        ReadableStream: false,
        registerProcessor: false,
        RemotePlayback: false,
        removeEventListener: false,
        reportError: false,
        Request: false,
        requestAnimationFrame: false,
        requestIdleCallback: false,
        resizeBy: false,
        ResizeObserver: false,
        ResizeObserverEntry: false,
        resizeTo: false,
        Response: false,
        RTCCertificate: false,
        RTCDataChannel: false,
        RTCDataChannelEvent: false,
        RTCDtlsTransport: false,
        RTCIceCandidate: false,
        RTCIceGatherer: false,
        RTCIceTransport: false,
        RTCPeerConnection: false,
        RTCPeerConnectionIceEvent: false,
        RTCRtpContributingSource: false,
        RTCRtpReceiver: false,
        RTCRtpSender: false,
        RTCSctpTransport: false,
        RTCSessionDescription: false,
        RTCStatsReport: false,
        RTCTrackEvent: false,
        screen: false,
        Screen: false,
        screenLeft: false,
        ScreenOrientation: false,
        screenTop: false,
        screenX: false,
        screenY: false,
        ScriptProcessorNode: false,
        scroll: false,
        scrollbars: false,
        scrollBy: false,
        scrollTo: false,
        scrollX: false,
        scrollY: false,
        SecurityPolicyViolationEvent: false,
        Selection: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerRegistration: false,
        sessionStorage: false,
        setInterval: false,
        setTimeout: false,
        ShadowRoot: false,
        SharedWorker: false,
        SourceBuffer: false,
        SourceBufferList: false,
        speechSynthesis: false,
        SpeechSynthesisEvent: false,
        SpeechSynthesisUtterance: false,
        StaticRange: false,
        status: false,
        statusbar: false,
        StereoPannerNode: false,
        stop: false,
        Storage: false,
        StorageEvent: false,
        StorageManager: false,
        structuredClone: false,
        styleMedia: false,
        StyleSheet: false,
        StyleSheetList: false,
        SubmitEvent: false,
        SubtleCrypto: false,
        SVGAElement: false,
        SVGAngle: false,
        SVGAnimatedAngle: false,
        SVGAnimatedBoolean: false,
        SVGAnimatedEnumeration: false,
        SVGAnimatedInteger: false,
        SVGAnimatedLength: false,
        SVGAnimatedLengthList: false,
        SVGAnimatedNumber: false,
        SVGAnimatedNumberList: false,
        SVGAnimatedPreserveAspectRatio: false,
        SVGAnimatedRect: false,
        SVGAnimatedString: false,
        SVGAnimatedTransformList: false,
        SVGAnimateElement: false,
        SVGAnimateMotionElement: false,
        SVGAnimateTransformElement: false,
        SVGAnimationElement: false,
        SVGCircleElement: false,
        SVGClipPathElement: false,
        SVGComponentTransferFunctionElement: false,
        SVGDefsElement: false,
        SVGDescElement: false,
        SVGDiscardElement: false,
        SVGElement: false,
        SVGEllipseElement: false,
        SVGFEBlendElement: false,
        SVGFEColorMatrixElement: false,
        SVGFEComponentTransferElement: false,
        SVGFECompositeElement: false,
        SVGFEConvolveMatrixElement: false,
        SVGFEDiffuseLightingElement: false,
        SVGFEDisplacementMapElement: false,
        SVGFEDistantLightElement: false,
        SVGFEDropShadowElement: false,
        SVGFEFloodElement: false,
        SVGFEFuncAElement: false,
        SVGFEFuncBElement: false,
        SVGFEFuncGElement: false,
        SVGFEFuncRElement: false,
        SVGFEGaussianBlurElement: false,
        SVGFEImageElement: false,
        SVGFEMergeElement: false,
        SVGFEMergeNodeElement: false,
        SVGFEMorphologyElement: false,
        SVGFEOffsetElement: false,
        SVGFEPointLightElement: false,
        SVGFESpecularLightingElement: false,
        SVGFESpotLightElement: false,
        SVGFETileElement: false,
        SVGFETurbulenceElement: false,
        SVGFilterElement: false,
        SVGForeignObjectElement: false,
        SVGGElement: false,
        SVGGeometryElement: false,
        SVGGradientElement: false,
        SVGGraphicsElement: false,
        SVGImageElement: false,
        SVGLength: false,
        SVGLengthList: false,
        SVGLinearGradientElement: false,
        SVGLineElement: false,
        SVGMarkerElement: false,
        SVGMaskElement: false,
        SVGMatrix: false,
        SVGMetadataElement: false,
        SVGMPathElement: false,
        SVGNumber: false,
        SVGNumberList: false,
        SVGPathElement: false,
        SVGPatternElement: false,
        SVGPoint: false,
        SVGPointList: false,
        SVGPolygonElement: false,
        SVGPolylineElement: false,
        SVGPreserveAspectRatio: false,
        SVGRadialGradientElement: false,
        SVGRect: false,
        SVGRectElement: false,
        SVGScriptElement: false,
        SVGSetElement: false,
        SVGStopElement: false,
        SVGStringList: false,
        SVGStyleElement: false,
        SVGSVGElement: false,
        SVGSwitchElement: false,
        SVGSymbolElement: false,
        SVGTextContentElement: false,
        SVGTextElement: false,
        SVGTextPathElement: false,
        SVGTextPositioningElement: false,
        SVGTitleElement: false,
        SVGTransform: false,
        SVGTransformList: false,
        SVGTSpanElement: false,
        SVGUnitTypes: false,
        SVGUseElement: false,
        SVGViewElement: false,
        TaskAttributionTiming: false,
        Text: false,
        TextDecoder: false,
        TextEncoder: false,
        TextEvent: false,
        TextMetrics: false,
        TextTrack: false,
        TextTrackCue: false,
        TextTrackCueList: false,
        TextTrackList: false,
        TimeRanges: false,
        toolbar: false,
        top: false,
        Touch: false,
        TouchEvent: false,
        TouchList: false,
        TrackEvent: false,
        TransformStream: false,
        TransitionEvent: false,
        TreeWalker: false,
        UIEvent: false,
        URL: false,
        URLSearchParams: false,
        ValidityState: false,
        visualViewport: false,
        VisualViewport: false,
        VTTCue: false,
        WaveShaperNode: false,
        WebAssembly: false,
        WebGL2RenderingContext: false,
        WebGLActiveInfo: false,
        WebGLBuffer: false,
        WebGLContextEvent: false,
        WebGLFramebuffer: false,
        WebGLProgram: false,
        WebGLQuery: false,
        WebGLRenderbuffer: false,
        WebGLRenderingContext: false,
        WebGLSampler: false,
        WebGLShader: false,
        WebGLShaderPrecisionFormat: false,
        WebGLSync: false,
        WebGLTexture: false,
        WebGLTransformFeedback: false,
        WebGLUniformLocation: false,
        WebGLVertexArrayObject: false,
        WebSocket: false,
        WheelEvent: false,
        window: false,
        Window: false,
        Worker: false,
        WritableStream: false,
        XMLDocument: false,
        XMLHttpRequest: false,
        XMLHttpRequestEventTarget: false,
        XMLHttpRequestUpload: false,
        XMLSerializer: false,
        XPathEvaluator: false,
        XPathExpression: false,
        XPathResult: false,
        XSLTProcessor: false
      },
      worker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        clearInterval: false,
        clearTimeout: false,
        close: true,
        console: false,
        CustomEvent: false,
        ErrorEvent: false,
        Event: false,
        fetch: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: true,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onlanguagechange: true,
        onmessage: true,
        onoffline: true,
        ononline: true,
        onrejectionhandled: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        removeEventListener: false,
        reportError: false,
        Request: false,
        Response: false,
        self: true,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      node: {
        __dirname: false,
        __filename: false,
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        Buffer: false,
        clearImmediate: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        exports: true,
        fetch: false,
        global: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        module: false,
        performance: false,
        process: false,
        queueMicrotask: false,
        require: false,
        setImmediate: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      nodeBuiltin: {
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        Buffer: false,
        clearImmediate: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        fetch: false,
        global: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        performance: false,
        process: false,
        queueMicrotask: false,
        setImmediate: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      commonjs: {
        exports: true,
        global: false,
        module: false,
        require: false
      },
      amd: {
        define: false,
        require: false
      },
      mocha: {
        after: false,
        afterEach: false,
        before: false,
        beforeEach: false,
        context: false,
        describe: false,
        it: false,
        mocha: false,
        run: false,
        setup: false,
        specify: false,
        suite: false,
        suiteSetup: false,
        suiteTeardown: false,
        teardown: false,
        test: false,
        xcontext: false,
        xdescribe: false,
        xit: false,
        xspecify: false
      },
      jasmine: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        expectAsync: false,
        fail: false,
        fdescribe: false,
        fit: false,
        it: false,
        jasmine: false,
        pending: false,
        runs: false,
        spyOn: false,
        spyOnAllFunctions: false,
        spyOnProperty: false,
        waits: false,
        waitsFor: false,
        xdescribe: false,
        xit: false
      },
      jest: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        fdescribe: false,
        fit: false,
        it: false,
        jest: false,
        pit: false,
        require: false,
        test: false,
        xdescribe: false,
        xit: false,
        xtest: false
      },
      qunit: {
        asyncTest: false,
        deepEqual: false,
        equal: false,
        expect: false,
        module: false,
        notDeepEqual: false,
        notEqual: false,
        notOk: false,
        notPropEqual: false,
        notStrictEqual: false,
        ok: false,
        propEqual: false,
        QUnit: false,
        raises: false,
        start: false,
        stop: false,
        strictEqual: false,
        test: false,
        throws: false
      },
      phantomjs: {
        console: true,
        exports: true,
        phantom: true,
        require: true,
        WebPage: true
      },
      couch: {
        emit: false,
        exports: false,
        getRow: false,
        log: false,
        module: false,
        provides: false,
        require: false,
        respond: false,
        send: false,
        start: false,
        sum: false
      },
      rhino: {
        defineClass: false,
        deserialize: false,
        gc: false,
        help: false,
        importClass: false,
        importPackage: false,
        java: false,
        load: false,
        loadClass: false,
        Packages: false,
        print: false,
        quit: false,
        readFile: false,
        readUrl: false,
        runCommand: false,
        seal: false,
        serialize: false,
        spawn: false,
        sync: false,
        toint32: false,
        version: false
      },
      nashorn: {
        __DIR__: false,
        __FILE__: false,
        __LINE__: false,
        com: false,
        edu: false,
        exit: false,
        java: false,
        Java: false,
        javafx: false,
        JavaImporter: false,
        javax: false,
        JSAdapter: false,
        load: false,
        loadWithNewGlobal: false,
        org: false,
        Packages: false,
        print: false,
        quit: false
      },
      wsh: {
        ActiveXObject: false,
        CollectGarbage: false,
        Debug: false,
        Enumerator: false,
        GetObject: false,
        RuntimeObject: false,
        ScriptEngine: false,
        ScriptEngineBuildVersion: false,
        ScriptEngineMajorVersion: false,
        ScriptEngineMinorVersion: false,
        VBArray: false,
        WScript: false,
        WSH: false
      },
      jquery: {
        $: false,
        jQuery: false
      },
      yui: {
        YAHOO: false,
        YAHOO_config: false,
        YUI: false,
        YUI_config: false
      },
      shelljs: {
        cat: false,
        cd: false,
        chmod: false,
        config: false,
        cp: false,
        dirs: false,
        echo: false,
        env: false,
        error: false,
        exec: false,
        exit: false,
        find: false,
        grep: false,
        ln: false,
        ls: false,
        mkdir: false,
        mv: false,
        popd: false,
        pushd: false,
        pwd: false,
        rm: false,
        sed: false,
        set: false,
        target: false,
        tempdir: false,
        test: false,
        touch: false,
        which: false
      },
      prototypejs: {
        $: false,
        $$: false,
        $A: false,
        $break: false,
        $continue: false,
        $F: false,
        $H: false,
        $R: false,
        $w: false,
        Abstract: false,
        Ajax: false,
        Autocompleter: false,
        Builder: false,
        Class: false,
        Control: false,
        Draggable: false,
        Draggables: false,
        Droppables: false,
        Effect: false,
        Element: false,
        Enumerable: false,
        Event: false,
        Field: false,
        Form: false,
        Hash: false,
        Insertion: false,
        ObjectRange: false,
        PeriodicalExecuter: false,
        Position: false,
        Prototype: false,
        Scriptaculous: false,
        Selector: false,
        Sortable: false,
        SortableObserver: false,
        Sound: false,
        Template: false,
        Toggle: false,
        Try: false
      },
      meteor: {
        $: false,
        Accounts: false,
        AccountsClient: false,
        AccountsCommon: false,
        AccountsServer: false,
        App: false,
        Assets: false,
        Blaze: false,
        check: false,
        Cordova: false,
        DDP: false,
        DDPRateLimiter: false,
        DDPServer: false,
        Deps: false,
        EJSON: false,
        Email: false,
        HTTP: false,
        Log: false,
        Match: false,
        Meteor: false,
        Mongo: false,
        MongoInternals: false,
        Npm: false,
        Package: false,
        Plugin: false,
        process: false,
        Random: false,
        ReactiveDict: false,
        ReactiveVar: false,
        Router: false,
        ServiceConfiguration: false,
        Session: false,
        share: false,
        Spacebars: false,
        Template: false,
        Tinytest: false,
        Tracker: false,
        UI: false,
        Utils: false,
        WebApp: false,
        WebAppInternals: false
      },
      mongo: {
        _isWindows: false,
        _rand: false,
        BulkWriteResult: false,
        cat: false,
        cd: false,
        connect: false,
        db: false,
        getHostName: false,
        getMemInfo: false,
        hostname: false,
        ISODate: false,
        listFiles: false,
        load: false,
        ls: false,
        md5sumFile: false,
        mkdir: false,
        Mongo: false,
        NumberInt: false,
        NumberLong: false,
        ObjectId: false,
        PlanCache: false,
        print: false,
        printjson: false,
        pwd: false,
        quit: false,
        removeFile: false,
        rs: false,
        sh: false,
        UUID: false,
        version: false,
        WriteResult: false
      },
      applescript: {
        $: false,
        Application: false,
        Automation: false,
        console: false,
        delay: false,
        Library: false,
        ObjC: false,
        ObjectSpecifier: false,
        Path: false,
        Progress: false,
        Ref: false
      },
      serviceworker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        clearInterval: false,
        clearTimeout: false,
        Client: false,
        clients: false,
        Clients: false,
        close: true,
        console: false,
        CustomEvent: false,
        ErrorEvent: false,
        Event: false,
        ExtendableEvent: false,
        ExtendableMessageEvent: false,
        fetch: false,
        FetchEvent: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: false,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onfetch: true,
        oninstall: true,
        onlanguagechange: true,
        onmessage: true,
        onmessageerror: true,
        onnotificationclick: true,
        onnotificationclose: true,
        onoffline: true,
        ononline: true,
        onpush: true,
        onpushsubscriptionchange: true,
        onrejectionhandled: true,
        onsync: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        registration: false,
        removeEventListener: false,
        Request: false,
        Response: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerGlobalScope: false,
        ServiceWorkerMessageEvent: false,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        skipWaiting: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        WindowClient: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      atomtest: {
        advanceClock: false,
        atom: false,
        fakeClearInterval: false,
        fakeClearTimeout: false,
        fakeSetInterval: false,
        fakeSetTimeout: false,
        resetTimeouts: false,
        waitsForPromise: false
      },
      embertest: {
        andThen: false,
        click: false,
        currentPath: false,
        currentRouteName: false,
        currentURL: false,
        fillIn: false,
        find: false,
        findAll: false,
        findWithAssert: false,
        keyEvent: false,
        pauseTest: false,
        resumeTest: false,
        triggerEvent: false,
        visit: false,
        wait: false
      },
      protractor: {
        $: false,
        $$: false,
        browser: false,
        by: false,
        By: false,
        DartObject: false,
        element: false,
        protractor: false
      },
      "shared-node-browser": {
        AbortController: false,
        AbortSignal: false,
        atob: false,
        btoa: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        DOMException: false,
        Event: false,
        EventTarget: false,
        fetch: false,
        Intl: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        performance: false,
        queueMicrotask: false,
        setInterval: false,
        setTimeout: false,
        structuredClone: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      webextensions: {
        browser: false,
        chrome: false,
        opr: false
      },
      greasemonkey: {
        cloneInto: false,
        createObjectIn: false,
        exportFunction: false,
        GM: false,
        GM_addElement: false,
        GM_addStyle: false,
        GM_addValueChangeListener: false,
        GM_deleteValue: false,
        GM_download: false,
        GM_getResourceText: false,
        GM_getResourceURL: false,
        GM_getTab: false,
        GM_getTabs: false,
        GM_getValue: false,
        GM_info: false,
        GM_listValues: false,
        GM_log: false,
        GM_notification: false,
        GM_openInTab: false,
        GM_registerMenuCommand: false,
        GM_removeValueChangeListener: false,
        GM_saveTab: false,
        GM_setClipboard: false,
        GM_setValue: false,
        GM_unregisterMenuCommand: false,
        GM_xmlhttpRequest: false,
        unsafeWindow: false
      },
      devtools: {
        $: false,
        $_: false,
        $$: false,
        $0: false,
        $1: false,
        $2: false,
        $3: false,
        $4: false,
        $x: false,
        chrome: false,
        clear: false,
        copy: false,
        debug: false,
        dir: false,
        dirxml: false,
        getEventListeners: false,
        inspect: false,
        keys: false,
        monitor: false,
        monitorEvents: false,
        profile: false,
        profileEnd: false,
        queryObjects: false,
        table: false,
        undebug: false,
        unmonitor: false,
        unmonitorEvents: false,
        values: false
      }
    };
  }
});

// node_modules/eslint/node_modules/globals/index.js
var require_globals4 = __commonJS({
  "node_modules/eslint/node_modules/globals/index.js"(exports, module2) {
    "use strict";
    module2.exports = require_globals3();
  }
});

// node_modules/eslint/lib/rules/no-constant-binary-expression.js
var require_no_constant_binary_expression = __commonJS({
  "node_modules/eslint/lib/rules/no-constant-binary-expression.js"(exports, module2) {
    "use strict";
    var globals = require_globals4();
    var { isNullLiteral, isConstant, isReferenceToGlobalVariable, isLogicalAssignmentOperator } = require_ast_utils2();
    var NUMERIC_OR_STRING_BINARY_OPERATORS = /* @__PURE__ */ new Set(["+", "-", "*", "/", "%", "|", "^", "&", "**", "<<", ">>", ">>>"]);
    function hasConstantNullishness(scope, node) {
      switch (node.type) {
        case "ObjectExpression":
        case "ArrayExpression":
        case "ArrowFunctionExpression":
        case "FunctionExpression":
        case "ClassExpression":
        case "NewExpression":
        case "Literal":
        case "TemplateLiteral":
        case "UpdateExpression":
        case "BinaryExpression":
          return true;
        case "CallExpression": {
          if (node.callee.type !== "Identifier") {
            return false;
          }
          const functionName = node.callee.name;
          return (functionName === "Boolean" || functionName === "String" || functionName === "Number") && isReferenceToGlobalVariable(scope, node.callee);
        }
        case "AssignmentExpression":
          if (node.operator === "=") {
            return hasConstantNullishness(scope, node.right);
          }
          if (isLogicalAssignmentOperator(node.operator)) {
            return false;
          }
          return true;
        case "UnaryExpression":
          return true;
        case "SequenceExpression": {
          const last2 = node.expressions[node.expressions.length - 1];
          return hasConstantNullishness(scope, last2);
        }
        case "Identifier":
          return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
        case "JSXElement":
        case "JSXFragment":
          return false;
        default:
          return false;
      }
    }
    function isStaticBoolean(scope, node) {
      switch (node.type) {
        case "Literal":
          return typeof node.value === "boolean";
        case "CallExpression":
          return node.callee.type === "Identifier" && node.callee.name === "Boolean" && isReferenceToGlobalVariable(scope, node.callee) && (node.arguments.length === 0 || isConstant(scope, node.arguments[0], true));
        case "UnaryExpression":
          return node.operator === "!" && isConstant(scope, node.argument, true);
        default:
          return false;
      }
    }
    function hasConstantLooseBooleanComparison(scope, node) {
      switch (node.type) {
        case "ObjectExpression":
        case "ClassExpression":
          return true;
        case "ArrayExpression": {
          const nonSpreadElements = node.elements.filter((e) => (
            // Elements can be `null` in sparse arrays: `[,,]`;
            e !== null && e.type !== "SpreadElement"
          ));
          return node.elements.length === 0 || nonSpreadElements.length > 1;
        }
        case "ArrowFunctionExpression":
        case "FunctionExpression":
          return true;
        case "UnaryExpression":
          if (node.operator === "void" || // Always returns `undefined`
          node.operator === "typeof") {
            return true;
          }
          if (node.operator === "!") {
            return isConstant(scope, node.argument, true);
          }
          return false;
        case "NewExpression":
          return false;
        case "CallExpression": {
          if (node.callee.type === "Identifier" && node.callee.name === "Boolean" && isReferenceToGlobalVariable(scope, node.callee)) {
            return node.arguments.length === 0 || isConstant(scope, node.arguments[0], true);
          }
          return false;
        }
        case "Literal":
          return true;
        case "Identifier":
          return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
        case "TemplateLiteral":
          return node.expressions.length === 0;
        case "AssignmentExpression":
          if (node.operator === "=") {
            return hasConstantLooseBooleanComparison(scope, node.right);
          }
          return false;
        case "SequenceExpression": {
          const last2 = node.expressions[node.expressions.length - 1];
          return hasConstantLooseBooleanComparison(scope, last2);
        }
        case "JSXElement":
        case "JSXFragment":
          return false;
        default:
          return false;
      }
    }
    function hasConstantStrictBooleanComparison(scope, node) {
      switch (node.type) {
        case "ObjectExpression":
        case "ArrayExpression":
        case "ArrowFunctionExpression":
        case "FunctionExpression":
        case "ClassExpression":
        case "NewExpression":
        case "TemplateLiteral":
        case "Literal":
        case "UpdateExpression":
          return true;
        case "BinaryExpression":
          return NUMERIC_OR_STRING_BINARY_OPERATORS.has(node.operator);
        case "UnaryExpression": {
          if (node.operator === "delete") {
            return false;
          }
          if (node.operator === "!") {
            return isConstant(scope, node.argument, true);
          }
          return true;
        }
        case "SequenceExpression": {
          const last2 = node.expressions[node.expressions.length - 1];
          return hasConstantStrictBooleanComparison(scope, last2);
        }
        case "Identifier":
          return node.name === "undefined" && isReferenceToGlobalVariable(scope, node);
        case "AssignmentExpression":
          if (node.operator === "=") {
            return hasConstantStrictBooleanComparison(scope, node.right);
          }
          if (isLogicalAssignmentOperator(node.operator)) {
            return false;
          }
          return true;
        case "CallExpression": {
          if (node.callee.type !== "Identifier") {
            return false;
          }
          const functionName = node.callee.name;
          if ((functionName === "String" || functionName === "Number") && isReferenceToGlobalVariable(scope, node.callee)) {
            return true;
          }
          if (functionName === "Boolean" && isReferenceToGlobalVariable(scope, node.callee)) {
            return node.arguments.length === 0 || isConstant(scope, node.arguments[0], true);
          }
          return false;
        }
        case "JSXElement":
        case "JSXFragment":
          return false;
        default:
          return false;
      }
    }
    function isAlwaysNew(scope, node) {
      switch (node.type) {
        case "ObjectExpression":
        case "ArrayExpression":
        case "ArrowFunctionExpression":
        case "FunctionExpression":
        case "ClassExpression":
          return true;
        case "NewExpression": {
          if (node.callee.type !== "Identifier") {
            return false;
          }
          return Object.hasOwnProperty.call(globals.builtin, node.callee.name) && isReferenceToGlobalVariable(scope, node.callee);
        }
        case "Literal":
          return typeof node.regex === "object";
        case "SequenceExpression": {
          const last2 = node.expressions[node.expressions.length - 1];
          return isAlwaysNew(scope, last2);
        }
        case "AssignmentExpression":
          if (node.operator === "=") {
            return isAlwaysNew(scope, node.right);
          }
          return false;
        case "ConditionalExpression":
          return isAlwaysNew(scope, node.consequent) && isAlwaysNew(scope, node.alternate);
        case "JSXElement":
        case "JSXFragment":
          return false;
        default:
          return false;
      }
    }
    function isNullOrUndefined(scope, node) {
      return isNullLiteral(node) || node.type === "Identifier" && node.name === "undefined" && isReferenceToGlobalVariable(scope, node) || node.type === "UnaryExpression" && node.operator === "void";
    }
    function findBinaryExpressionConstantOperand(scope, a, b, operator) {
      if (operator === "==" || operator === "!=") {
        if (isNullOrUndefined(scope, a) && hasConstantNullishness(scope, b) || isStaticBoolean(scope, a) && hasConstantLooseBooleanComparison(scope, b)) {
          return b;
        }
      } else if (operator === "===" || operator === "!==") {
        if (isNullOrUndefined(scope, a) && hasConstantNullishness(scope, b) || isStaticBoolean(scope, a) && hasConstantStrictBooleanComparison(scope, b)) {
          return b;
        }
      }
      return null;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow expressions where the operation doesn't affect the value",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-constant-binary-expression"
        },
        schema: [],
        messages: {
          constantBinaryOperand: "Unexpected constant binary expression. Compares constantly with the {{otherSide}}-hand side of the `{{operator}}`.",
          constantShortCircuit: "Unexpected constant {{property}} on the left-hand side of a `{{operator}}` expression.",
          alwaysNew: "Unexpected comparison to newly constructed object. These two values can never be equal.",
          bothAlwaysNew: "Unexpected comparison of two newly constructed objects. These two values can never be equal."
        }
      },
      create(context) {
        return {
          LogicalExpression(node) {
            const { operator, left } = node;
            const scope = context.getScope();
            if ((operator === "&&" || operator === "||") && isConstant(scope, left, true)) {
              context.report({ node: left, messageId: "constantShortCircuit", data: { property: "truthiness", operator } });
            } else if (operator === "??" && hasConstantNullishness(scope, left)) {
              context.report({ node: left, messageId: "constantShortCircuit", data: { property: "nullishness", operator } });
            }
          },
          BinaryExpression(node) {
            const scope = context.getScope();
            const { right, left, operator } = node;
            const rightConstantOperand = findBinaryExpressionConstantOperand(scope, left, right, operator);
            const leftConstantOperand = findBinaryExpressionConstantOperand(scope, right, left, operator);
            if (rightConstantOperand) {
              context.report({ node: rightConstantOperand, messageId: "constantBinaryOperand", data: { operator, otherSide: "left" } });
            } else if (leftConstantOperand) {
              context.report({ node: leftConstantOperand, messageId: "constantBinaryOperand", data: { operator, otherSide: "right" } });
            } else if (operator === "===" || operator === "!==") {
              if (isAlwaysNew(scope, left)) {
                context.report({ node: left, messageId: "alwaysNew" });
              } else if (isAlwaysNew(scope, right)) {
                context.report({ node: right, messageId: "alwaysNew" });
              }
            } else if (operator === "==" || operator === "!=") {
              if (isAlwaysNew(scope, left) && isAlwaysNew(scope, right)) {
                context.report({ node: left, messageId: "bothAlwaysNew" });
              }
            }
          }
          /*
           * In theory we could handle short-circuiting assignment operators,
           * for some constant values, but that would require walking the
           * scope to find the value of the variable being assigned. This is
           * dependant on https://github.com/eslint/eslint/issues/13776
           *
           * AssignmentExpression() {},
           */
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-constant-condition.js
var require_no_constant_condition = __commonJS({
  "node_modules/eslint/lib/rules/no-constant-condition.js"(exports, module2) {
    "use strict";
    var { isConstant } = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow constant expressions in conditions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-constant-condition"
        },
        schema: [
          {
            type: "object",
            properties: {
              checkLoops: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "Unexpected constant condition."
        }
      },
      create(context) {
        const options = context.options[0] || {}, checkLoops = options.checkLoops !== false, loopSetStack = [];
        let loopsInCurrentScope = /* @__PURE__ */ new Set();
        function trackConstantConditionLoop(node) {
          if (node.test && isConstant(context.getScope(), node.test, true)) {
            loopsInCurrentScope.add(node);
          }
        }
        function checkConstantConditionLoopInSet(node) {
          if (loopsInCurrentScope.has(node)) {
            loopsInCurrentScope.delete(node);
            context.report({ node: node.test, messageId: "unexpected" });
          }
        }
        function reportIfConstant(node) {
          if (node.test && isConstant(context.getScope(), node.test, true)) {
            context.report({ node: node.test, messageId: "unexpected" });
          }
        }
        function enterFunction() {
          loopSetStack.push(loopsInCurrentScope);
          loopsInCurrentScope = /* @__PURE__ */ new Set();
        }
        function exitFunction() {
          loopsInCurrentScope = loopSetStack.pop();
        }
        function checkLoop(node) {
          if (checkLoops) {
            trackConstantConditionLoop(node);
          }
        }
        return {
          ConditionalExpression: reportIfConstant,
          IfStatement: reportIfConstant,
          WhileStatement: checkLoop,
          "WhileStatement:exit": checkConstantConditionLoopInSet,
          DoWhileStatement: checkLoop,
          "DoWhileStatement:exit": checkConstantConditionLoopInSet,
          ForStatement: checkLoop,
          "ForStatement > .test": (node) => checkLoop(node.parent),
          "ForStatement:exit": checkConstantConditionLoopInSet,
          FunctionDeclaration: enterFunction,
          "FunctionDeclaration:exit": exitFunction,
          FunctionExpression: enterFunction,
          "FunctionExpression:exit": exitFunction,
          YieldExpression: () => loopsInCurrentScope.clear()
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-constructor-return.js
var require_no_constructor_return = __commonJS({
  "node_modules/eslint/lib/rules/no-constructor-return.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow returning value from constructor",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-constructor-return"
        },
        schema: {},
        fixable: null,
        messages: {
          unexpected: "Unexpected return statement in constructor."
        }
      },
      create(context) {
        const stack = [];
        return {
          onCodePathStart(_, node) {
            stack.push(node);
          },
          onCodePathEnd() {
            stack.pop();
          },
          ReturnStatement(node) {
            const last2 = stack[stack.length - 1];
            if (!last2.parent) {
              return;
            }
            if (last2.parent.type === "MethodDefinition" && last2.parent.kind === "constructor" && (node.parent.parent === last2 || node.argument)) {
              context.report({
                node,
                messageId: "unexpected"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-continue.js
var require_no_continue = __commonJS({
  "node_modules/eslint/lib/rules/no-continue.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `continue` statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-continue"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected use of continue statement."
        }
      },
      create(context) {
        return {
          ContinueStatement(node) {
            context.report({ node, messageId: "unexpected" });
          }
        };
      }
    };
  }
});

// node_modules/regexpp/index.js
var require_regexpp = __commonJS({
  "node_modules/regexpp/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var ast = /* @__PURE__ */ Object.freeze({});
    var largeIdStartRanges = void 0;
    var largeIdContinueRanges = void 0;
    function isIdStart(cp) {
      if (cp < 65)
        return false;
      if (cp < 91)
        return true;
      if (cp < 97)
        return false;
      if (cp < 123)
        return true;
      return isLargeIdStart(cp);
    }
    function isIdContinue(cp) {
      if (cp < 48)
        return false;
      if (cp < 58)
        return true;
      if (cp < 65)
        return false;
      if (cp < 91)
        return true;
      if (cp === 95)
        return true;
      if (cp < 97)
        return false;
      if (cp < 123)
        return true;
      return isLargeIdStart(cp) || isLargeIdContinue(cp);
    }
    function isLargeIdStart(cp) {
      return isInRange(cp, largeIdStartRanges || (largeIdStartRanges = initLargeIdStartRanges()));
    }
    function isLargeIdContinue(cp) {
      return isInRange(cp, largeIdContinueRanges || (largeIdContinueRanges = initLargeIdContinueRanges()));
    }
    function initLargeIdStartRanges() {
      return restoreRanges("4q 0 b 0 5 0 6 m 2 u 2 cp 5 b f 4 8 0 2 0 3m 4 2 1 3 3 2 0 7 0 2 2 2 0 2 j 2 2a 2 3u 9 4l 2 11 3 0 7 14 20 q 5 3 1a 16 10 1 2 2q 2 0 g 1 8 1 b 2 3 0 h 0 2 t u 2g c 0 p w a 1 5 0 6 l 5 0 a 0 4 0 o o 8 a 1i k 2 h 1p 1h 4 0 j 0 8 9 g f 5 7 3 1 3 l 2 6 2 0 4 3 4 0 h 0 e 1 2 2 f 1 b 0 9 5 5 1 3 l 2 6 2 1 2 1 2 1 w 3 2 0 k 2 h 8 2 2 2 l 2 6 2 1 2 4 4 0 j 0 g 1 o 0 c 7 3 1 3 l 2 6 2 1 2 4 4 0 v 1 2 2 g 0 i 0 2 5 4 2 2 3 4 1 2 0 2 1 4 1 4 2 4 b n 0 1h 7 2 2 2 m 2 f 4 0 r 2 6 1 v 0 5 7 2 2 2 m 2 9 2 4 4 0 x 0 2 1 g 1 i 8 2 2 2 14 3 0 h 0 6 2 9 2 p 5 6 h 4 n 2 8 2 0 3 6 1n 1b 2 1 d 6 1n 1 2 0 2 4 2 n 2 0 2 9 2 1 a 0 3 4 2 0 m 3 x 0 1s 7 2 z s 4 38 16 l 0 h 5 5 3 4 0 4 1 8 2 5 c d 0 i 11 2 0 6 0 3 16 2 98 2 3 3 6 2 0 2 3 3 14 2 3 3 w 2 3 3 6 2 0 2 3 3 e 2 1k 2 3 3 1u 12 f h 2d 3 5 4 h7 3 g 2 p 6 22 4 a 8 c 2 3 f h f h f c 2 2 g 1f 10 0 5 0 1w 2g 8 14 2 0 6 1x b u 1e t 3 4 c 17 5 p 1j m a 1g 2b 0 2m 1a i 6 1k t e 1 b 17 r z 16 2 b z 3 8 8 16 3 2 16 3 2 5 2 1 4 0 6 5b 1t 7p 3 5 3 11 3 5 3 7 2 0 2 0 2 0 2 u 3 1g 2 6 2 0 4 2 2 6 4 3 3 5 5 c 6 2 2 6 39 0 e 0 h c 2u 0 5 0 3 9 2 0 3 5 7 0 2 0 2 0 2 f 3 3 6 4 5 0 i 14 22g 1a 2 1a 2 3o 7 3 4 1 d 11 2 0 6 0 3 1j 8 0 h m a 6 2 6 2 6 2 6 2 6 2 6 2 6 2 6 fb 2 q 8 8 4 3 4 5 2d 5 4 2 2h 2 3 6 16 2 2l i v 1d f e9 533 1t g70 4 wc 1w 19 3 7g 4 f b 1 l 1a h u 3 27 14 8 3 2u 3 1g 3 8 17 c 2 2 2 3 2 m u 1f f 1d 1r 5 4 0 2 1 c r b m q s 8 1a t 0 h 4 2 9 b 4 2 14 o 2 2 7 l m 4 0 4 1d 2 0 4 1 3 4 3 0 2 0 p 2 3 a 8 2 d 5 3 5 3 5 a 6 2 6 2 16 2 d 7 36 u 8mb d m 5 1c 6it a5 3 2x 13 6 d 4 6 0 2 9 2 c 2 4 2 0 2 1 2 1 2 2z y a2 j 1r 3 1h 15 b 39 4 2 3q 11 p 7 p c 2g 4 5 3 5 3 5 3 2 10 b 2 p 2 i 2 1 2 e 3 d z 3e 1y 1g 7g s 4 1c 1c v e t 6 11 b t 3 z 5 7 2 4 17 4d j z 5 z 5 13 9 1f 4d 8m a l b 7 49 5 3 0 2 17 2 1 4 0 3 m b m a u 1u i 2 1 b l b p 1z 1j 7 1 1t 0 g 3 2 2 2 s 17 s 4 s 10 7 2 r s 1h b l b i e h 33 20 1k 1e e 1e e z 9p 15 7 1 27 s b 0 9 l 2z k s m d 1g 24 18 x o r z u 0 3 0 9 y 4 0 d 1b f 3 m 0 2 0 10 h 2 o 2d 6 2 0 2 3 2 e 2 9 8 1a 13 7 3 1 3 l 2 6 2 1 2 4 4 0 j 0 d 4 4f 1g j 3 l 2 v 1b l 1 2 0 55 1a 16 3 11 1b l 0 1o 16 e 0 20 q 6e 17 39 1r w 7 3 0 3 7 2 1 2 n g 0 2 0 2n 7 3 12 h 0 2 0 t 0 b 13 8 0 m 0 c 19 k 0 z 1k 7c 8 2 10 i 0 1e t 35 6 2 1 2 11 m 0 q 5 2 1 2 v f 0 94 i 5a 0 28 pl 2v 32 i 5f 24d tq 34i g6 6nu fs 8 u 36 t j 1b h 3 w k 6 i j5 1r 3l 22 6 0 1v c 1t 1 2 0 t 4qf 9 yd 17 8 6wo 7y 1e 2 i 3 9 az 1s5 2y 6 c 4 8 8 9 4mf 2c 2 1y 2 1 3 0 3 1 3 3 2 b 2 0 2 6 2 1s 2 3 3 7 2 6 2 r 2 3 2 4 2 0 4 6 2 9f 3 o 2 o 2 u 2 o 2 u 2 o 2 u 2 o 2 u 2 o 2 7 1th 18 b 6 h 0 aa 17 105 5g 1o 1v 8 0 xh 3 2 q 2 1 2 0 3 0 2 9 2 3 2 0 2 0 7 0 5 0 2 0 2 0 2 2 2 1 2 0 3 0 2 0 2 0 2 0 2 0 2 1 2 0 3 3 2 6 2 3 2 3 2 0 2 9 2 g 6 2 2 4 2 g 3et wyl z 378 c 65 3 4g1 f 5rk 2e8 f1 15v 3t6");
    }
    function initLargeIdContinueRanges() {
      return restoreRanges("53 0 g9 33 o 0 70 4 7e 18 2 0 2 1 2 1 2 0 21 a 1d u 7 0 2u 6 3 5 3 1 2 3 3 9 o 0 v q 2k a g 9 y 8 a 0 p 3 2 8 2 2 2 4 18 2 3c e 2 w 1j 2 2 h 2 6 b 1 3 9 i 2 1l 0 2 6 3 1 3 2 a 0 b 1 3 9 f 0 3 2 1l 0 2 4 5 1 3 2 4 0 l b 4 0 c 2 1l 0 2 7 2 2 2 2 l 1 3 9 b 5 2 2 1l 0 2 6 3 1 3 2 8 2 b 1 3 9 j 0 1o 4 4 2 2 3 a 0 f 9 h 4 1m 6 2 2 2 3 8 1 c 1 3 9 i 2 1l 0 2 6 2 2 2 3 8 1 c 1 3 9 h 3 1k 1 2 6 2 2 2 3 a 0 b 1 3 9 i 2 1z 0 5 5 2 0 2 7 7 9 3 1 1q 0 3 6 d 7 2 9 2g 0 3 8 c 5 3 9 1r 1 7 9 c 0 2 0 2 0 5 1 1e j 2 1 6 a 2 z a 0 2t j 2 9 d 3 5 2 2 2 3 6 4 3 e b 2 e jk 2 a 8 pt 2 u 2 u 1 v 1 1t v a 0 3 9 y 2 3 9 40 0 3b b 5 b b 9 3l a 1p 4 1m 9 2 s 3 a 7 9 n d 2 1 1s 4 1c g c 9 i 8 d 2 v c 3 9 19 d 1d j 9 9 7 9 3b 2 2 k 5 0 7 0 3 2 5j 1l 2 4 g0 1 k 0 3g c 5 0 4 b 2db 2 3y 0 2p v ff 5 2y 1 n7q 9 1y 0 5 9 x 1 29 1 7l 0 4 0 5 0 o 4 5 0 2c 1 1f h b 9 7 h e a t 7 q c 19 3 1c d g 9 c 0 b 9 1c d d 0 9 1 3 9 y 2 1f 0 2 2 3 1 6 1 2 0 16 4 6 1 6l 7 2 1 3 9 fmt 0 ki f h f 4 1 p 2 5d 9 12 0 ji 0 6b 0 46 4 86 9 120 2 2 1 6 3 15 2 5 0 4m 1 fy 3 9 9 aa 1 4a a 4w 2 1i e w 9 g 3 1a a 1i 9 7 2 11 d 2 9 6 1 19 0 d 2 1d d 9 3 2 b 2b b 7 0 4h b 6 9 7 3 1k 1 2 6 3 1 3 2 a 0 b 1 3 6 4 4 5d h a 9 5 0 2a j d 9 5y 6 3 8 s 1 2b g g 9 2a c 9 9 2c e 5 9 6r e 4m 9 1z 5 2 1 3 3 2 0 2 1 d 9 3c 6 3 6 4 0 t 9 15 6 2 3 9 0 a a 1b f ba 7 2 7 h 9 1l l 2 d 3f 5 4 0 2 1 2 6 2 0 9 9 1d 4 2 1 2 4 9 9 96 3 ewa 9 3r 4 1o 6 q 9 s6 0 2 1i 8 3 2a 0 c 1 f58 1 43r 4 4 5 9 7 3 6 v 3 45 2 13e 1d e9 1i 5 1d 9 0 f 0 n 4 2 e 11t 6 2 g 3 6 2 1 2 4 7a 6 a 9 bn d 15j 6 32 6 6 9 3o7 9 gvt3 6n");
    }
    function isInRange(cp, ranges) {
      let l = 0, r = ranges.length / 2 | 0, i = 0, min2 = 0, max2 = 0;
      while (l < r) {
        i = (l + r) / 2 | 0;
        min2 = ranges[2 * i];
        max2 = ranges[2 * i + 1];
        if (cp < min2) {
          r = i;
        } else if (cp > max2) {
          l = i + 1;
        } else {
          return true;
        }
      }
      return false;
    }
    function restoreRanges(data) {
      let last2 = 0;
      return data.split(" ").map((s) => last2 += parseInt(s, 36) | 0);
    }
    var DataSet = class {
      constructor(raw2018, raw2019, raw2020, raw2021) {
        this._raw2018 = raw2018;
        this._raw2019 = raw2019;
        this._raw2020 = raw2020;
        this._raw2021 = raw2021;
      }
      get es2018() {
        return this._set2018 || (this._set2018 = new Set(this._raw2018.split(" ")));
      }
      get es2019() {
        return this._set2019 || (this._set2019 = new Set(this._raw2019.split(" ")));
      }
      get es2020() {
        return this._set2020 || (this._set2020 = new Set(this._raw2020.split(" ")));
      }
      get es2021() {
        return this._set2021 || (this._set2021 = new Set(this._raw2021.split(" ")));
      }
    };
    var gcNameSet = /* @__PURE__ */ new Set(["General_Category", "gc"]);
    var scNameSet = /* @__PURE__ */ new Set(["Script", "Script_Extensions", "sc", "scx"]);
    var gcValueSets = new DataSet("C Cased_Letter Cc Cf Close_Punctuation Cn Co Combining_Mark Connector_Punctuation Control Cs Currency_Symbol Dash_Punctuation Decimal_Number Enclosing_Mark Final_Punctuation Format Initial_Punctuation L LC Letter Letter_Number Line_Separator Ll Lm Lo Lowercase_Letter Lt Lu M Mark Math_Symbol Mc Me Mn Modifier_Letter Modifier_Symbol N Nd Nl No Nonspacing_Mark Number Open_Punctuation Other Other_Letter Other_Number Other_Punctuation Other_Symbol P Paragraph_Separator Pc Pd Pe Pf Pi Po Private_Use Ps Punctuation S Sc Separator Sk Sm So Space_Separator Spacing_Mark Surrogate Symbol Titlecase_Letter Unassigned Uppercase_Letter Z Zl Zp Zs cntrl digit punct", "", "", "");
    var scValueSets = new DataSet("Adlam Adlm Aghb Ahom Anatolian_Hieroglyphs Arab Arabic Armenian Armi Armn Avestan Avst Bali Balinese Bamu Bamum Bass Bassa_Vah Batak Batk Beng Bengali Bhaiksuki Bhks Bopo Bopomofo Brah Brahmi Brai Braille Bugi Buginese Buhd Buhid Cakm Canadian_Aboriginal Cans Cari Carian Caucasian_Albanian Chakma Cham Cher Cherokee Common Copt Coptic Cprt Cuneiform Cypriot Cyrillic Cyrl Deseret Deva Devanagari Dsrt Dupl Duployan Egyp Egyptian_Hieroglyphs Elba Elbasan Ethi Ethiopic Geor Georgian Glag Glagolitic Gonm Goth Gothic Gran Grantha Greek Grek Gujarati Gujr Gurmukhi Guru Han Hang Hangul Hani Hano Hanunoo Hatr Hatran Hebr Hebrew Hira Hiragana Hluw Hmng Hung Imperial_Aramaic Inherited Inscriptional_Pahlavi Inscriptional_Parthian Ital Java Javanese Kaithi Kali Kana Kannada Katakana Kayah_Li Khar Kharoshthi Khmer Khmr Khoj Khojki Khudawadi Knda Kthi Lana Lao Laoo Latin Latn Lepc Lepcha Limb Limbu Lina Linb Linear_A Linear_B Lisu Lyci Lycian Lydi Lydian Mahajani Mahj Malayalam Mand Mandaic Mani Manichaean Marc Marchen Masaram_Gondi Meetei_Mayek Mend Mende_Kikakui Merc Mero Meroitic_Cursive Meroitic_Hieroglyphs Miao Mlym Modi Mong Mongolian Mro Mroo Mtei Mult Multani Myanmar Mymr Nabataean Narb Nbat New_Tai_Lue Newa Nko Nkoo Nshu Nushu Ogam Ogham Ol_Chiki Olck Old_Hungarian Old_Italic Old_North_Arabian Old_Permic Old_Persian Old_South_Arabian Old_Turkic Oriya Orkh Orya Osage Osge Osma Osmanya Pahawh_Hmong Palm Palmyrene Pau_Cin_Hau Pauc Perm Phag Phags_Pa Phli Phlp Phnx Phoenician Plrd Prti Psalter_Pahlavi Qaac Qaai Rejang Rjng Runic Runr Samaritan Samr Sarb Saur Saurashtra Sgnw Sharada Shavian Shaw Shrd Sidd Siddham SignWriting Sind Sinh Sinhala Sora Sora_Sompeng Soyo Soyombo Sund Sundanese Sylo Syloti_Nagri Syrc Syriac Tagalog Tagb Tagbanwa Tai_Le Tai_Tham Tai_Viet Takr Takri Tale Talu Tamil Taml Tang Tangut Tavt Telu Telugu Tfng Tglg Thaa Thaana Thai Tibetan Tibt Tifinagh Tirh Tirhuta Ugar Ugaritic Vai Vaii Wara Warang_Citi Xpeo Xsux Yi Yiii Zanabazar_Square Zanb Zinh Zyyy", "Dogr Dogra Gong Gunjala_Gondi Hanifi_Rohingya Maka Makasar Medefaidrin Medf Old_Sogdian Rohg Sogd Sogdian Sogo", "Elym Elymaic Hmnp Nand Nandinagari Nyiakeng_Puachue_Hmong Wancho Wcho", "Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi");
    var binPropertySets = new DataSet("AHex ASCII ASCII_Hex_Digit Alpha Alphabetic Any Assigned Bidi_C Bidi_Control Bidi_M Bidi_Mirrored CI CWCF CWCM CWKCF CWL CWT CWU Case_Ignorable Cased Changes_When_Casefolded Changes_When_Casemapped Changes_When_Lowercased Changes_When_NFKC_Casefolded Changes_When_Titlecased Changes_When_Uppercased DI Dash Default_Ignorable_Code_Point Dep Deprecated Dia Diacritic Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Ext Extender Gr_Base Gr_Ext Grapheme_Base Grapheme_Extend Hex Hex_Digit IDC IDS IDSB IDST IDS_Binary_Operator IDS_Trinary_Operator ID_Continue ID_Start Ideo Ideographic Join_C Join_Control LOE Logical_Order_Exception Lower Lowercase Math NChar Noncharacter_Code_Point Pat_Syn Pat_WS Pattern_Syntax Pattern_White_Space QMark Quotation_Mark RI Radical Regional_Indicator SD STerm Sentence_Terminal Soft_Dotted Term Terminal_Punctuation UIdeo Unified_Ideograph Upper Uppercase VS Variation_Selector White_Space XIDC XIDS XID_Continue XID_Start space", "Extended_Pictographic", "", "EBase EComp EMod EPres ExtPict");
    function isValidUnicodeProperty(version2, name, value2) {
      if (gcNameSet.has(name)) {
        return version2 >= 2018 && gcValueSets.es2018.has(value2);
      }
      if (scNameSet.has(name)) {
        return version2 >= 2018 && scValueSets.es2018.has(value2) || version2 >= 2019 && scValueSets.es2019.has(value2) || version2 >= 2020 && scValueSets.es2020.has(value2) || version2 >= 2021 && scValueSets.es2021.has(value2);
      }
      return false;
    }
    function isValidLoneUnicodeProperty(version2, value2) {
      return version2 >= 2018 && binPropertySets.es2018.has(value2) || version2 >= 2019 && binPropertySets.es2019.has(value2) || version2 >= 2021 && binPropertySets.es2021.has(value2);
    }
    var Backspace = 8;
    var CharacterTabulation = 9;
    var LineFeed = 10;
    var LineTabulation = 11;
    var FormFeed = 12;
    var CarriageReturn = 13;
    var ExclamationMark = 33;
    var DollarSign = 36;
    var LeftParenthesis = 40;
    var RightParenthesis = 41;
    var Asterisk = 42;
    var PlusSign = 43;
    var Comma = 44;
    var HyphenMinus = 45;
    var FullStop = 46;
    var Solidus = 47;
    var DigitZero = 48;
    var DigitOne = 49;
    var DigitSeven = 55;
    var DigitNine = 57;
    var Colon = 58;
    var LessThanSign = 60;
    var EqualsSign = 61;
    var GreaterThanSign = 62;
    var QuestionMark = 63;
    var LatinCapitalLetterA = 65;
    var LatinCapitalLetterB = 66;
    var LatinCapitalLetterD = 68;
    var LatinCapitalLetterF = 70;
    var LatinCapitalLetterP = 80;
    var LatinCapitalLetterS = 83;
    var LatinCapitalLetterW = 87;
    var LatinCapitalLetterZ = 90;
    var LowLine = 95;
    var LatinSmallLetterA = 97;
    var LatinSmallLetterB = 98;
    var LatinSmallLetterC = 99;
    var LatinSmallLetterD = 100;
    var LatinSmallLetterF = 102;
    var LatinSmallLetterG = 103;
    var LatinSmallLetterI = 105;
    var LatinSmallLetterK = 107;
    var LatinSmallLetterM = 109;
    var LatinSmallLetterN = 110;
    var LatinSmallLetterP = 112;
    var LatinSmallLetterR = 114;
    var LatinSmallLetterS = 115;
    var LatinSmallLetterT = 116;
    var LatinSmallLetterU = 117;
    var LatinSmallLetterV = 118;
    var LatinSmallLetterW = 119;
    var LatinSmallLetterX = 120;
    var LatinSmallLetterY = 121;
    var LatinSmallLetterZ = 122;
    var LeftSquareBracket = 91;
    var ReverseSolidus = 92;
    var RightSquareBracket = 93;
    var CircumflexAccent = 94;
    var LeftCurlyBracket = 123;
    var VerticalLine = 124;
    var RightCurlyBracket = 125;
    var ZeroWidthNonJoiner = 8204;
    var ZeroWidthJoiner = 8205;
    var LineSeparator = 8232;
    var ParagraphSeparator = 8233;
    var MinCodePoint = 0;
    var MaxCodePoint = 1114111;
    function isLatinLetter(code) {
      return code >= LatinCapitalLetterA && code <= LatinCapitalLetterZ || code >= LatinSmallLetterA && code <= LatinSmallLetterZ;
    }
    function isDecimalDigit(code) {
      return code >= DigitZero && code <= DigitNine;
    }
    function isOctalDigit(code) {
      return code >= DigitZero && code <= DigitSeven;
    }
    function isHexDigit(code) {
      return code >= DigitZero && code <= DigitNine || code >= LatinCapitalLetterA && code <= LatinCapitalLetterF || code >= LatinSmallLetterA && code <= LatinSmallLetterF;
    }
    function isLineTerminator(code) {
      return code === LineFeed || code === CarriageReturn || code === LineSeparator || code === ParagraphSeparator;
    }
    function isValidUnicode(code) {
      return code >= MinCodePoint && code <= MaxCodePoint;
    }
    function digitToInt(code) {
      if (code >= LatinSmallLetterA && code <= LatinSmallLetterF) {
        return code - LatinSmallLetterA + 10;
      }
      if (code >= LatinCapitalLetterA && code <= LatinCapitalLetterF) {
        return code - LatinCapitalLetterA + 10;
      }
      return code - DigitZero;
    }
    function isLeadSurrogate(code) {
      return code >= 55296 && code <= 56319;
    }
    function isTrailSurrogate(code) {
      return code >= 56320 && code <= 57343;
    }
    function combineSurrogatePair(lead, trail) {
      return (lead - 55296) * 1024 + (trail - 56320) + 65536;
    }
    var legacyImpl = {
      at(s, end, i) {
        return i < end ? s.charCodeAt(i) : -1;
      },
      width(c) {
        return 1;
      }
    };
    var unicodeImpl = {
      at(s, end, i) {
        return i < end ? s.codePointAt(i) : -1;
      },
      width(c) {
        return c > 65535 ? 2 : 1;
      }
    };
    var Reader = class {
      constructor() {
        this._impl = legacyImpl;
        this._s = "";
        this._i = 0;
        this._end = 0;
        this._cp1 = -1;
        this._w1 = 1;
        this._cp2 = -1;
        this._w2 = 1;
        this._cp3 = -1;
        this._w3 = 1;
        this._cp4 = -1;
      }
      get source() {
        return this._s;
      }
      get index() {
        return this._i;
      }
      get currentCodePoint() {
        return this._cp1;
      }
      get nextCodePoint() {
        return this._cp2;
      }
      get nextCodePoint2() {
        return this._cp3;
      }
      get nextCodePoint3() {
        return this._cp4;
      }
      reset(source, start, end, uFlag) {
        this._impl = uFlag ? unicodeImpl : legacyImpl;
        this._s = source;
        this._end = end;
        this.rewind(start);
      }
      rewind(index) {
        const impl = this._impl;
        this._i = index;
        this._cp1 = impl.at(this._s, this._end, index);
        this._w1 = impl.width(this._cp1);
        this._cp2 = impl.at(this._s, this._end, index + this._w1);
        this._w2 = impl.width(this._cp2);
        this._cp3 = impl.at(this._s, this._end, index + this._w1 + this._w2);
        this._w3 = impl.width(this._cp3);
        this._cp4 = impl.at(this._s, this._end, index + this._w1 + this._w2 + this._w3);
      }
      advance() {
        if (this._cp1 !== -1) {
          const impl = this._impl;
          this._i += this._w1;
          this._cp1 = this._cp2;
          this._w1 = this._w2;
          this._cp2 = this._cp3;
          this._w2 = impl.width(this._cp2);
          this._cp3 = this._cp4;
          this._w3 = impl.width(this._cp3);
          this._cp4 = impl.at(this._s, this._end, this._i + this._w1 + this._w2 + this._w3);
        }
      }
      eat(cp) {
        if (this._cp1 === cp) {
          this.advance();
          return true;
        }
        return false;
      }
      eat2(cp1, cp2) {
        if (this._cp1 === cp1 && this._cp2 === cp2) {
          this.advance();
          this.advance();
          return true;
        }
        return false;
      }
      eat3(cp1, cp2, cp3) {
        if (this._cp1 === cp1 && this._cp2 === cp2 && this._cp3 === cp3) {
          this.advance();
          this.advance();
          this.advance();
          return true;
        }
        return false;
      }
    };
    var RegExpSyntaxError = class extends SyntaxError {
      constructor(source, uFlag, index, message) {
        if (source) {
          if (!source.startsWith("/")) {
            source = `/${source}/${uFlag ? "u" : ""}`;
          }
          source = `: ${source}`;
        }
        super(`Invalid regular expression${source}: ${message}`);
        this.index = index;
      }
    };
    function isSyntaxCharacter(cp) {
      return cp === CircumflexAccent || cp === DollarSign || cp === ReverseSolidus || cp === FullStop || cp === Asterisk || cp === PlusSign || cp === QuestionMark || cp === LeftParenthesis || cp === RightParenthesis || cp === LeftSquareBracket || cp === RightSquareBracket || cp === LeftCurlyBracket || cp === RightCurlyBracket || cp === VerticalLine;
    }
    function isRegExpIdentifierStart(cp) {
      return isIdStart(cp) || cp === DollarSign || cp === LowLine;
    }
    function isRegExpIdentifierPart(cp) {
      return isIdContinue(cp) || cp === DollarSign || cp === LowLine || cp === ZeroWidthNonJoiner || cp === ZeroWidthJoiner;
    }
    function isUnicodePropertyNameCharacter(cp) {
      return isLatinLetter(cp) || cp === LowLine;
    }
    function isUnicodePropertyValueCharacter(cp) {
      return isUnicodePropertyNameCharacter(cp) || isDecimalDigit(cp);
    }
    var RegExpValidator = class {
      constructor(options) {
        this._reader = new Reader();
        this._uFlag = false;
        this._nFlag = false;
        this._lastIntValue = 0;
        this._lastMinValue = 0;
        this._lastMaxValue = 0;
        this._lastStrValue = "";
        this._lastKeyValue = "";
        this._lastValValue = "";
        this._lastAssertionIsQuantifiable = false;
        this._numCapturingParens = 0;
        this._groupNames = /* @__PURE__ */ new Set();
        this._backreferenceNames = /* @__PURE__ */ new Set();
        this._options = options || {};
      }
      validateLiteral(source, start = 0, end = source.length) {
        this._uFlag = this._nFlag = false;
        this.reset(source, start, end);
        this.onLiteralEnter(start);
        if (this.eat(Solidus) && this.eatRegExpBody() && this.eat(Solidus)) {
          const flagStart = this.index;
          const uFlag = source.includes("u", flagStart);
          this.validateFlags(source, flagStart, end);
          this.validatePattern(source, start + 1, flagStart - 1, uFlag);
        } else if (start >= end) {
          this.raise("Empty");
        } else {
          const c = String.fromCodePoint(this.currentCodePoint);
          this.raise(`Unexpected character '${c}'`);
        }
        this.onLiteralLeave(start, end);
      }
      validateFlags(source, start = 0, end = source.length) {
        const existingFlags = /* @__PURE__ */ new Set();
        let global2 = false;
        let ignoreCase = false;
        let multiline = false;
        let sticky = false;
        let unicode = false;
        let dotAll = false;
        let hasIndices = false;
        for (let i = start; i < end; ++i) {
          const flag = source.charCodeAt(i);
          if (existingFlags.has(flag)) {
            this.raise(`Duplicated flag '${source[i]}'`);
          }
          existingFlags.add(flag);
          if (flag === LatinSmallLetterG) {
            global2 = true;
          } else if (flag === LatinSmallLetterI) {
            ignoreCase = true;
          } else if (flag === LatinSmallLetterM) {
            multiline = true;
          } else if (flag === LatinSmallLetterU && this.ecmaVersion >= 2015) {
            unicode = true;
          } else if (flag === LatinSmallLetterY && this.ecmaVersion >= 2015) {
            sticky = true;
          } else if (flag === LatinSmallLetterS && this.ecmaVersion >= 2018) {
            dotAll = true;
          } else if (flag === LatinSmallLetterD && this.ecmaVersion >= 2022) {
            hasIndices = true;
          } else {
            this.raise(`Invalid flag '${source[i]}'`);
          }
        }
        this.onFlags(start, end, global2, ignoreCase, multiline, unicode, sticky, dotAll, hasIndices);
      }
      validatePattern(source, start = 0, end = source.length, uFlag = false) {
        this._uFlag = uFlag && this.ecmaVersion >= 2015;
        this._nFlag = uFlag && this.ecmaVersion >= 2018;
        this.reset(source, start, end);
        this.consumePattern();
        if (!this._nFlag && this.ecmaVersion >= 2018 && this._groupNames.size > 0) {
          this._nFlag = true;
          this.rewind(start);
          this.consumePattern();
        }
      }
      get strict() {
        return Boolean(this._options.strict || this._uFlag);
      }
      get ecmaVersion() {
        return this._options.ecmaVersion || 2022;
      }
      onLiteralEnter(start) {
        if (this._options.onLiteralEnter) {
          this._options.onLiteralEnter(start);
        }
      }
      onLiteralLeave(start, end) {
        if (this._options.onLiteralLeave) {
          this._options.onLiteralLeave(start, end);
        }
      }
      onFlags(start, end, global2, ignoreCase, multiline, unicode, sticky, dotAll, hasIndices) {
        if (this._options.onFlags) {
          this._options.onFlags(start, end, global2, ignoreCase, multiline, unicode, sticky, dotAll, hasIndices);
        }
      }
      onPatternEnter(start) {
        if (this._options.onPatternEnter) {
          this._options.onPatternEnter(start);
        }
      }
      onPatternLeave(start, end) {
        if (this._options.onPatternLeave) {
          this._options.onPatternLeave(start, end);
        }
      }
      onDisjunctionEnter(start) {
        if (this._options.onDisjunctionEnter) {
          this._options.onDisjunctionEnter(start);
        }
      }
      onDisjunctionLeave(start, end) {
        if (this._options.onDisjunctionLeave) {
          this._options.onDisjunctionLeave(start, end);
        }
      }
      onAlternativeEnter(start, index) {
        if (this._options.onAlternativeEnter) {
          this._options.onAlternativeEnter(start, index);
        }
      }
      onAlternativeLeave(start, end, index) {
        if (this._options.onAlternativeLeave) {
          this._options.onAlternativeLeave(start, end, index);
        }
      }
      onGroupEnter(start) {
        if (this._options.onGroupEnter) {
          this._options.onGroupEnter(start);
        }
      }
      onGroupLeave(start, end) {
        if (this._options.onGroupLeave) {
          this._options.onGroupLeave(start, end);
        }
      }
      onCapturingGroupEnter(start, name) {
        if (this._options.onCapturingGroupEnter) {
          this._options.onCapturingGroupEnter(start, name);
        }
      }
      onCapturingGroupLeave(start, end, name) {
        if (this._options.onCapturingGroupLeave) {
          this._options.onCapturingGroupLeave(start, end, name);
        }
      }
      onQuantifier(start, end, min2, max2, greedy) {
        if (this._options.onQuantifier) {
          this._options.onQuantifier(start, end, min2, max2, greedy);
        }
      }
      onLookaroundAssertionEnter(start, kind, negate) {
        if (this._options.onLookaroundAssertionEnter) {
          this._options.onLookaroundAssertionEnter(start, kind, negate);
        }
      }
      onLookaroundAssertionLeave(start, end, kind, negate) {
        if (this._options.onLookaroundAssertionLeave) {
          this._options.onLookaroundAssertionLeave(start, end, kind, negate);
        }
      }
      onEdgeAssertion(start, end, kind) {
        if (this._options.onEdgeAssertion) {
          this._options.onEdgeAssertion(start, end, kind);
        }
      }
      onWordBoundaryAssertion(start, end, kind, negate) {
        if (this._options.onWordBoundaryAssertion) {
          this._options.onWordBoundaryAssertion(start, end, kind, negate);
        }
      }
      onAnyCharacterSet(start, end, kind) {
        if (this._options.onAnyCharacterSet) {
          this._options.onAnyCharacterSet(start, end, kind);
        }
      }
      onEscapeCharacterSet(start, end, kind, negate) {
        if (this._options.onEscapeCharacterSet) {
          this._options.onEscapeCharacterSet(start, end, kind, negate);
        }
      }
      onUnicodePropertyCharacterSet(start, end, kind, key, value2, negate) {
        if (this._options.onUnicodePropertyCharacterSet) {
          this._options.onUnicodePropertyCharacterSet(start, end, kind, key, value2, negate);
        }
      }
      onCharacter(start, end, value2) {
        if (this._options.onCharacter) {
          this._options.onCharacter(start, end, value2);
        }
      }
      onBackreference(start, end, ref) {
        if (this._options.onBackreference) {
          this._options.onBackreference(start, end, ref);
        }
      }
      onCharacterClassEnter(start, negate) {
        if (this._options.onCharacterClassEnter) {
          this._options.onCharacterClassEnter(start, negate);
        }
      }
      onCharacterClassLeave(start, end, negate) {
        if (this._options.onCharacterClassLeave) {
          this._options.onCharacterClassLeave(start, end, negate);
        }
      }
      onCharacterClassRange(start, end, min2, max2) {
        if (this._options.onCharacterClassRange) {
          this._options.onCharacterClassRange(start, end, min2, max2);
        }
      }
      get source() {
        return this._reader.source;
      }
      get index() {
        return this._reader.index;
      }
      get currentCodePoint() {
        return this._reader.currentCodePoint;
      }
      get nextCodePoint() {
        return this._reader.nextCodePoint;
      }
      get nextCodePoint2() {
        return this._reader.nextCodePoint2;
      }
      get nextCodePoint3() {
        return this._reader.nextCodePoint3;
      }
      reset(source, start, end) {
        this._reader.reset(source, start, end, this._uFlag);
      }
      rewind(index) {
        this._reader.rewind(index);
      }
      advance() {
        this._reader.advance();
      }
      eat(cp) {
        return this._reader.eat(cp);
      }
      eat2(cp1, cp2) {
        return this._reader.eat2(cp1, cp2);
      }
      eat3(cp1, cp2, cp3) {
        return this._reader.eat3(cp1, cp2, cp3);
      }
      raise(message) {
        throw new RegExpSyntaxError(this.source, this._uFlag, this.index, message);
      }
      eatRegExpBody() {
        const start = this.index;
        let inClass = false;
        let escaped = false;
        for (; ; ) {
          const cp = this.currentCodePoint;
          if (cp === -1 || isLineTerminator(cp)) {
            const kind = inClass ? "character class" : "regular expression";
            this.raise(`Unterminated ${kind}`);
          }
          if (escaped) {
            escaped = false;
          } else if (cp === ReverseSolidus) {
            escaped = true;
          } else if (cp === LeftSquareBracket) {
            inClass = true;
          } else if (cp === RightSquareBracket) {
            inClass = false;
          } else if (cp === Solidus && !inClass || cp === Asterisk && this.index === start) {
            break;
          }
          this.advance();
        }
        return this.index !== start;
      }
      consumePattern() {
        const start = this.index;
        this._numCapturingParens = this.countCapturingParens();
        this._groupNames.clear();
        this._backreferenceNames.clear();
        this.onPatternEnter(start);
        this.consumeDisjunction();
        const cp = this.currentCodePoint;
        if (this.currentCodePoint !== -1) {
          if (cp === RightParenthesis) {
            this.raise("Unmatched ')'");
          }
          if (cp === ReverseSolidus) {
            this.raise("\\ at end of pattern");
          }
          if (cp === RightSquareBracket || cp === RightCurlyBracket) {
            this.raise("Lone quantifier brackets");
          }
          const c = String.fromCodePoint(cp);
          this.raise(`Unexpected character '${c}'`);
        }
        for (const name of this._backreferenceNames) {
          if (!this._groupNames.has(name)) {
            this.raise("Invalid named capture referenced");
          }
        }
        this.onPatternLeave(start, this.index);
      }
      countCapturingParens() {
        const start = this.index;
        let inClass = false;
        let escaped = false;
        let count = 0;
        let cp = 0;
        while ((cp = this.currentCodePoint) !== -1) {
          if (escaped) {
            escaped = false;
          } else if (cp === ReverseSolidus) {
            escaped = true;
          } else if (cp === LeftSquareBracket) {
            inClass = true;
          } else if (cp === RightSquareBracket) {
            inClass = false;
          } else if (cp === LeftParenthesis && !inClass && (this.nextCodePoint !== QuestionMark || this.nextCodePoint2 === LessThanSign && this.nextCodePoint3 !== EqualsSign && this.nextCodePoint3 !== ExclamationMark)) {
            count += 1;
          }
          this.advance();
        }
        this.rewind(start);
        return count;
      }
      consumeDisjunction() {
        const start = this.index;
        let i = 0;
        this.onDisjunctionEnter(start);
        do {
          this.consumeAlternative(i++);
        } while (this.eat(VerticalLine));
        if (this.consumeQuantifier(true)) {
          this.raise("Nothing to repeat");
        }
        if (this.eat(LeftCurlyBracket)) {
          this.raise("Lone quantifier brackets");
        }
        this.onDisjunctionLeave(start, this.index);
      }
      consumeAlternative(i) {
        const start = this.index;
        this.onAlternativeEnter(start, i);
        while (this.currentCodePoint !== -1 && this.consumeTerm()) {
        }
        this.onAlternativeLeave(start, this.index, i);
      }
      consumeTerm() {
        if (this._uFlag || this.strict) {
          return this.consumeAssertion() || this.consumeAtom() && this.consumeOptionalQuantifier();
        }
        return this.consumeAssertion() && (!this._lastAssertionIsQuantifiable || this.consumeOptionalQuantifier()) || this.consumeExtendedAtom() && this.consumeOptionalQuantifier();
      }
      consumeOptionalQuantifier() {
        this.consumeQuantifier();
        return true;
      }
      consumeAssertion() {
        const start = this.index;
        this._lastAssertionIsQuantifiable = false;
        if (this.eat(CircumflexAccent)) {
          this.onEdgeAssertion(start, this.index, "start");
          return true;
        }
        if (this.eat(DollarSign)) {
          this.onEdgeAssertion(start, this.index, "end");
          return true;
        }
        if (this.eat2(ReverseSolidus, LatinCapitalLetterB)) {
          this.onWordBoundaryAssertion(start, this.index, "word", true);
          return true;
        }
        if (this.eat2(ReverseSolidus, LatinSmallLetterB)) {
          this.onWordBoundaryAssertion(start, this.index, "word", false);
          return true;
        }
        if (this.eat2(LeftParenthesis, QuestionMark)) {
          const lookbehind = this.ecmaVersion >= 2018 && this.eat(LessThanSign);
          let negate = false;
          if (this.eat(EqualsSign) || (negate = this.eat(ExclamationMark))) {
            const kind = lookbehind ? "lookbehind" : "lookahead";
            this.onLookaroundAssertionEnter(start, kind, negate);
            this.consumeDisjunction();
            if (!this.eat(RightParenthesis)) {
              this.raise("Unterminated group");
            }
            this._lastAssertionIsQuantifiable = !lookbehind && !this.strict;
            this.onLookaroundAssertionLeave(start, this.index, kind, negate);
            return true;
          }
          this.rewind(start);
        }
        return false;
      }
      consumeQuantifier(noConsume = false) {
        const start = this.index;
        let min2 = 0;
        let max2 = 0;
        let greedy = false;
        if (this.eat(Asterisk)) {
          min2 = 0;
          max2 = Number.POSITIVE_INFINITY;
        } else if (this.eat(PlusSign)) {
          min2 = 1;
          max2 = Number.POSITIVE_INFINITY;
        } else if (this.eat(QuestionMark)) {
          min2 = 0;
          max2 = 1;
        } else if (this.eatBracedQuantifier(noConsume)) {
          min2 = this._lastMinValue;
          max2 = this._lastMaxValue;
        } else {
          return false;
        }
        greedy = !this.eat(QuestionMark);
        if (!noConsume) {
          this.onQuantifier(start, this.index, min2, max2, greedy);
        }
        return true;
      }
      eatBracedQuantifier(noError) {
        const start = this.index;
        if (this.eat(LeftCurlyBracket)) {
          this._lastMinValue = 0;
          this._lastMaxValue = Number.POSITIVE_INFINITY;
          if (this.eatDecimalDigits()) {
            this._lastMinValue = this._lastMaxValue = this._lastIntValue;
            if (this.eat(Comma)) {
              this._lastMaxValue = this.eatDecimalDigits() ? this._lastIntValue : Number.POSITIVE_INFINITY;
            }
            if (this.eat(RightCurlyBracket)) {
              if (!noError && this._lastMaxValue < this._lastMinValue) {
                this.raise("numbers out of order in {} quantifier");
              }
              return true;
            }
          }
          if (!noError && (this._uFlag || this.strict)) {
            this.raise("Incomplete quantifier");
          }
          this.rewind(start);
        }
        return false;
      }
      consumeAtom() {
        return this.consumePatternCharacter() || this.consumeDot() || this.consumeReverseSolidusAtomEscape() || this.consumeCharacterClass() || this.consumeUncapturingGroup() || this.consumeCapturingGroup();
      }
      consumeDot() {
        if (this.eat(FullStop)) {
          this.onAnyCharacterSet(this.index - 1, this.index, "any");
          return true;
        }
        return false;
      }
      consumeReverseSolidusAtomEscape() {
        const start = this.index;
        if (this.eat(ReverseSolidus)) {
          if (this.consumeAtomEscape()) {
            return true;
          }
          this.rewind(start);
        }
        return false;
      }
      consumeUncapturingGroup() {
        const start = this.index;
        if (this.eat3(LeftParenthesis, QuestionMark, Colon)) {
          this.onGroupEnter(start);
          this.consumeDisjunction();
          if (!this.eat(RightParenthesis)) {
            this.raise("Unterminated group");
          }
          this.onGroupLeave(start, this.index);
          return true;
        }
        return false;
      }
      consumeCapturingGroup() {
        const start = this.index;
        if (this.eat(LeftParenthesis)) {
          let name = null;
          if (this.ecmaVersion >= 2018) {
            if (this.consumeGroupSpecifier()) {
              name = this._lastStrValue;
            }
          } else if (this.currentCodePoint === QuestionMark) {
            this.raise("Invalid group");
          }
          this.onCapturingGroupEnter(start, name);
          this.consumeDisjunction();
          if (!this.eat(RightParenthesis)) {
            this.raise("Unterminated group");
          }
          this.onCapturingGroupLeave(start, this.index, name);
          return true;
        }
        return false;
      }
      consumeExtendedAtom() {
        return this.consumeDot() || this.consumeReverseSolidusAtomEscape() || this.consumeReverseSolidusFollowedByC() || this.consumeCharacterClass() || this.consumeUncapturingGroup() || this.consumeCapturingGroup() || this.consumeInvalidBracedQuantifier() || this.consumeExtendedPatternCharacter();
      }
      consumeReverseSolidusFollowedByC() {
        const start = this.index;
        if (this.currentCodePoint === ReverseSolidus && this.nextCodePoint === LatinSmallLetterC) {
          this._lastIntValue = this.currentCodePoint;
          this.advance();
          this.onCharacter(start, this.index, ReverseSolidus);
          return true;
        }
        return false;
      }
      consumeInvalidBracedQuantifier() {
        if (this.eatBracedQuantifier(true)) {
          this.raise("Nothing to repeat");
        }
        return false;
      }
      consumePatternCharacter() {
        const start = this.index;
        const cp = this.currentCodePoint;
        if (cp !== -1 && !isSyntaxCharacter(cp)) {
          this.advance();
          this.onCharacter(start, this.index, cp);
          return true;
        }
        return false;
      }
      consumeExtendedPatternCharacter() {
        const start = this.index;
        const cp = this.currentCodePoint;
        if (cp !== -1 && cp !== CircumflexAccent && cp !== DollarSign && cp !== ReverseSolidus && cp !== FullStop && cp !== Asterisk && cp !== PlusSign && cp !== QuestionMark && cp !== LeftParenthesis && cp !== RightParenthesis && cp !== LeftSquareBracket && cp !== VerticalLine) {
          this.advance();
          this.onCharacter(start, this.index, cp);
          return true;
        }
        return false;
      }
      consumeGroupSpecifier() {
        if (this.eat(QuestionMark)) {
          if (this.eatGroupName()) {
            if (!this._groupNames.has(this._lastStrValue)) {
              this._groupNames.add(this._lastStrValue);
              return true;
            }
            this.raise("Duplicate capture group name");
          }
          this.raise("Invalid group");
        }
        return false;
      }
      consumeAtomEscape() {
        if (this.consumeBackreference() || this.consumeCharacterClassEscape() || this.consumeCharacterEscape() || this._nFlag && this.consumeKGroupName()) {
          return true;
        }
        if (this.strict || this._uFlag) {
          this.raise("Invalid escape");
        }
        return false;
      }
      consumeBackreference() {
        const start = this.index;
        if (this.eatDecimalEscape()) {
          const n = this._lastIntValue;
          if (n <= this._numCapturingParens) {
            this.onBackreference(start - 1, this.index, n);
            return true;
          }
          if (this.strict || this._uFlag) {
            this.raise("Invalid escape");
          }
          this.rewind(start);
        }
        return false;
      }
      consumeCharacterClassEscape() {
        const start = this.index;
        if (this.eat(LatinSmallLetterD)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "digit", false);
          return true;
        }
        if (this.eat(LatinCapitalLetterD)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "digit", true);
          return true;
        }
        if (this.eat(LatinSmallLetterS)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "space", false);
          return true;
        }
        if (this.eat(LatinCapitalLetterS)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "space", true);
          return true;
        }
        if (this.eat(LatinSmallLetterW)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "word", false);
          return true;
        }
        if (this.eat(LatinCapitalLetterW)) {
          this._lastIntValue = -1;
          this.onEscapeCharacterSet(start - 1, this.index, "word", true);
          return true;
        }
        let negate = false;
        if (this._uFlag && this.ecmaVersion >= 2018 && (this.eat(LatinSmallLetterP) || (negate = this.eat(LatinCapitalLetterP)))) {
          this._lastIntValue = -1;
          if (this.eat(LeftCurlyBracket) && this.eatUnicodePropertyValueExpression() && this.eat(RightCurlyBracket)) {
            this.onUnicodePropertyCharacterSet(start - 1, this.index, "property", this._lastKeyValue, this._lastValValue || null, negate);
            return true;
          }
          this.raise("Invalid property name");
        }
        return false;
      }
      consumeCharacterEscape() {
        const start = this.index;
        if (this.eatControlEscape() || this.eatCControlLetter() || this.eatZero() || this.eatHexEscapeSequence() || this.eatRegExpUnicodeEscapeSequence() || !this.strict && !this._uFlag && this.eatLegacyOctalEscapeSequence() || this.eatIdentityEscape()) {
          this.onCharacter(start - 1, this.index, this._lastIntValue);
          return true;
        }
        return false;
      }
      consumeKGroupName() {
        const start = this.index;
        if (this.eat(LatinSmallLetterK)) {
          if (this.eatGroupName()) {
            const groupName = this._lastStrValue;
            this._backreferenceNames.add(groupName);
            this.onBackreference(start - 1, this.index, groupName);
            return true;
          }
          this.raise("Invalid named reference");
        }
        return false;
      }
      consumeCharacterClass() {
        const start = this.index;
        if (this.eat(LeftSquareBracket)) {
          const negate = this.eat(CircumflexAccent);
          this.onCharacterClassEnter(start, negate);
          this.consumeClassRanges();
          if (!this.eat(RightSquareBracket)) {
            this.raise("Unterminated character class");
          }
          this.onCharacterClassLeave(start, this.index, negate);
          return true;
        }
        return false;
      }
      consumeClassRanges() {
        const strict = this.strict || this._uFlag;
        for (; ; ) {
          const rangeStart = this.index;
          if (!this.consumeClassAtom()) {
            break;
          }
          const min2 = this._lastIntValue;
          if (!this.eat(HyphenMinus)) {
            continue;
          }
          this.onCharacter(this.index - 1, this.index, HyphenMinus);
          if (!this.consumeClassAtom()) {
            break;
          }
          const max2 = this._lastIntValue;
          if (min2 === -1 || max2 === -1) {
            if (strict) {
              this.raise("Invalid character class");
            }
            continue;
          }
          if (min2 > max2) {
            this.raise("Range out of order in character class");
          }
          this.onCharacterClassRange(rangeStart, this.index, min2, max2);
        }
      }
      consumeClassAtom() {
        const start = this.index;
        const cp = this.currentCodePoint;
        if (cp !== -1 && cp !== ReverseSolidus && cp !== RightSquareBracket) {
          this.advance();
          this._lastIntValue = cp;
          this.onCharacter(start, this.index, this._lastIntValue);
          return true;
        }
        if (this.eat(ReverseSolidus)) {
          if (this.consumeClassEscape()) {
            return true;
          }
          if (!this.strict && this.currentCodePoint === LatinSmallLetterC) {
            this._lastIntValue = ReverseSolidus;
            this.onCharacter(start, this.index, this._lastIntValue);
            return true;
          }
          if (this.strict || this._uFlag) {
            this.raise("Invalid escape");
          }
          this.rewind(start);
        }
        return false;
      }
      consumeClassEscape() {
        const start = this.index;
        if (this.eat(LatinSmallLetterB)) {
          this._lastIntValue = Backspace;
          this.onCharacter(start - 1, this.index, this._lastIntValue);
          return true;
        }
        if (this._uFlag && this.eat(HyphenMinus)) {
          this._lastIntValue = HyphenMinus;
          this.onCharacter(start - 1, this.index, this._lastIntValue);
          return true;
        }
        let cp = 0;
        if (!this.strict && !this._uFlag && this.currentCodePoint === LatinSmallLetterC && (isDecimalDigit(cp = this.nextCodePoint) || cp === LowLine)) {
          this.advance();
          this.advance();
          this._lastIntValue = cp % 32;
          this.onCharacter(start - 1, this.index, this._lastIntValue);
          return true;
        }
        return this.consumeCharacterClassEscape() || this.consumeCharacterEscape();
      }
      eatGroupName() {
        if (this.eat(LessThanSign)) {
          if (this.eatRegExpIdentifierName() && this.eat(GreaterThanSign)) {
            return true;
          }
          this.raise("Invalid capture group name");
        }
        return false;
      }
      eatRegExpIdentifierName() {
        if (this.eatRegExpIdentifierStart()) {
          this._lastStrValue = String.fromCodePoint(this._lastIntValue);
          while (this.eatRegExpIdentifierPart()) {
            this._lastStrValue += String.fromCodePoint(this._lastIntValue);
          }
          return true;
        }
        return false;
      }
      eatRegExpIdentifierStart() {
        const start = this.index;
        const forceUFlag = !this._uFlag && this.ecmaVersion >= 2020;
        let cp = this.currentCodePoint;
        this.advance();
        if (cp === ReverseSolidus && this.eatRegExpUnicodeEscapeSequence(forceUFlag)) {
          cp = this._lastIntValue;
        } else if (forceUFlag && isLeadSurrogate(cp) && isTrailSurrogate(this.currentCodePoint)) {
          cp = combineSurrogatePair(cp, this.currentCodePoint);
          this.advance();
        }
        if (isRegExpIdentifierStart(cp)) {
          this._lastIntValue = cp;
          return true;
        }
        if (this.index !== start) {
          this.rewind(start);
        }
        return false;
      }
      eatRegExpIdentifierPart() {
        const start = this.index;
        const forceUFlag = !this._uFlag && this.ecmaVersion >= 2020;
        let cp = this.currentCodePoint;
        this.advance();
        if (cp === ReverseSolidus && this.eatRegExpUnicodeEscapeSequence(forceUFlag)) {
          cp = this._lastIntValue;
        } else if (forceUFlag && isLeadSurrogate(cp) && isTrailSurrogate(this.currentCodePoint)) {
          cp = combineSurrogatePair(cp, this.currentCodePoint);
          this.advance();
        }
        if (isRegExpIdentifierPart(cp)) {
          this._lastIntValue = cp;
          return true;
        }
        if (this.index !== start) {
          this.rewind(start);
        }
        return false;
      }
      eatCControlLetter() {
        const start = this.index;
        if (this.eat(LatinSmallLetterC)) {
          if (this.eatControlLetter()) {
            return true;
          }
          this.rewind(start);
        }
        return false;
      }
      eatZero() {
        if (this.currentCodePoint === DigitZero && !isDecimalDigit(this.nextCodePoint)) {
          this._lastIntValue = 0;
          this.advance();
          return true;
        }
        return false;
      }
      eatControlEscape() {
        if (this.eat(LatinSmallLetterF)) {
          this._lastIntValue = FormFeed;
          return true;
        }
        if (this.eat(LatinSmallLetterN)) {
          this._lastIntValue = LineFeed;
          return true;
        }
        if (this.eat(LatinSmallLetterR)) {
          this._lastIntValue = CarriageReturn;
          return true;
        }
        if (this.eat(LatinSmallLetterT)) {
          this._lastIntValue = CharacterTabulation;
          return true;
        }
        if (this.eat(LatinSmallLetterV)) {
          this._lastIntValue = LineTabulation;
          return true;
        }
        return false;
      }
      eatControlLetter() {
        const cp = this.currentCodePoint;
        if (isLatinLetter(cp)) {
          this.advance();
          this._lastIntValue = cp % 32;
          return true;
        }
        return false;
      }
      eatRegExpUnicodeEscapeSequence(forceUFlag = false) {
        const start = this.index;
        const uFlag = forceUFlag || this._uFlag;
        if (this.eat(LatinSmallLetterU)) {
          if (uFlag && this.eatRegExpUnicodeSurrogatePairEscape() || this.eatFixedHexDigits(4) || uFlag && this.eatRegExpUnicodeCodePointEscape()) {
            return true;
          }
          if (this.strict || uFlag) {
            this.raise("Invalid unicode escape");
          }
          this.rewind(start);
        }
        return false;
      }
      eatRegExpUnicodeSurrogatePairEscape() {
        const start = this.index;
        if (this.eatFixedHexDigits(4)) {
          const lead = this._lastIntValue;
          if (isLeadSurrogate(lead) && this.eat(ReverseSolidus) && this.eat(LatinSmallLetterU) && this.eatFixedHexDigits(4)) {
            const trail = this._lastIntValue;
            if (isTrailSurrogate(trail)) {
              this._lastIntValue = combineSurrogatePair(lead, trail);
              return true;
            }
          }
          this.rewind(start);
        }
        return false;
      }
      eatRegExpUnicodeCodePointEscape() {
        const start = this.index;
        if (this.eat(LeftCurlyBracket) && this.eatHexDigits() && this.eat(RightCurlyBracket) && isValidUnicode(this._lastIntValue)) {
          return true;
        }
        this.rewind(start);
        return false;
      }
      eatIdentityEscape() {
        const cp = this.currentCodePoint;
        if (this.isValidIdentityEscape(cp)) {
          this._lastIntValue = cp;
          this.advance();
          return true;
        }
        return false;
      }
      isValidIdentityEscape(cp) {
        if (cp === -1) {
          return false;
        }
        if (this._uFlag) {
          return isSyntaxCharacter(cp) || cp === Solidus;
        }
        if (this.strict) {
          return !isIdContinue(cp);
        }
        if (this._nFlag) {
          return !(cp === LatinSmallLetterC || cp === LatinSmallLetterK);
        }
        return cp !== LatinSmallLetterC;
      }
      eatDecimalEscape() {
        this._lastIntValue = 0;
        let cp = this.currentCodePoint;
        if (cp >= DigitOne && cp <= DigitNine) {
          do {
            this._lastIntValue = 10 * this._lastIntValue + (cp - DigitZero);
            this.advance();
          } while ((cp = this.currentCodePoint) >= DigitZero && cp <= DigitNine);
          return true;
        }
        return false;
      }
      eatUnicodePropertyValueExpression() {
        const start = this.index;
        if (this.eatUnicodePropertyName() && this.eat(EqualsSign)) {
          this._lastKeyValue = this._lastStrValue;
          if (this.eatUnicodePropertyValue()) {
            this._lastValValue = this._lastStrValue;
            if (isValidUnicodeProperty(this.ecmaVersion, this._lastKeyValue, this._lastValValue)) {
              return true;
            }
            this.raise("Invalid property name");
          }
        }
        this.rewind(start);
        if (this.eatLoneUnicodePropertyNameOrValue()) {
          const nameOrValue = this._lastStrValue;
          if (isValidUnicodeProperty(this.ecmaVersion, "General_Category", nameOrValue)) {
            this._lastKeyValue = "General_Category";
            this._lastValValue = nameOrValue;
            return true;
          }
          if (isValidLoneUnicodeProperty(this.ecmaVersion, nameOrValue)) {
            this._lastKeyValue = nameOrValue;
            this._lastValValue = "";
            return true;
          }
          this.raise("Invalid property name");
        }
        return false;
      }
      eatUnicodePropertyName() {
        this._lastStrValue = "";
        while (isUnicodePropertyNameCharacter(this.currentCodePoint)) {
          this._lastStrValue += String.fromCodePoint(this.currentCodePoint);
          this.advance();
        }
        return this._lastStrValue !== "";
      }
      eatUnicodePropertyValue() {
        this._lastStrValue = "";
        while (isUnicodePropertyValueCharacter(this.currentCodePoint)) {
          this._lastStrValue += String.fromCodePoint(this.currentCodePoint);
          this.advance();
        }
        return this._lastStrValue !== "";
      }
      eatLoneUnicodePropertyNameOrValue() {
        return this.eatUnicodePropertyValue();
      }
      eatHexEscapeSequence() {
        const start = this.index;
        if (this.eat(LatinSmallLetterX)) {
          if (this.eatFixedHexDigits(2)) {
            return true;
          }
          if (this._uFlag || this.strict) {
            this.raise("Invalid escape");
          }
          this.rewind(start);
        }
        return false;
      }
      eatDecimalDigits() {
        const start = this.index;
        this._lastIntValue = 0;
        while (isDecimalDigit(this.currentCodePoint)) {
          this._lastIntValue = 10 * this._lastIntValue + digitToInt(this.currentCodePoint);
          this.advance();
        }
        return this.index !== start;
      }
      eatHexDigits() {
        const start = this.index;
        this._lastIntValue = 0;
        while (isHexDigit(this.currentCodePoint)) {
          this._lastIntValue = 16 * this._lastIntValue + digitToInt(this.currentCodePoint);
          this.advance();
        }
        return this.index !== start;
      }
      eatLegacyOctalEscapeSequence() {
        if (this.eatOctalDigit()) {
          const n1 = this._lastIntValue;
          if (this.eatOctalDigit()) {
            const n2 = this._lastIntValue;
            if (n1 <= 3 && this.eatOctalDigit()) {
              this._lastIntValue = n1 * 64 + n2 * 8 + this._lastIntValue;
            } else {
              this._lastIntValue = n1 * 8 + n2;
            }
          } else {
            this._lastIntValue = n1;
          }
          return true;
        }
        return false;
      }
      eatOctalDigit() {
        const cp = this.currentCodePoint;
        if (isOctalDigit(cp)) {
          this.advance();
          this._lastIntValue = cp - DigitZero;
          return true;
        }
        this._lastIntValue = 0;
        return false;
      }
      eatFixedHexDigits(length) {
        const start = this.index;
        this._lastIntValue = 0;
        for (let i = 0; i < length; ++i) {
          const cp = this.currentCodePoint;
          if (!isHexDigit(cp)) {
            this.rewind(start);
            return false;
          }
          this._lastIntValue = 16 * this._lastIntValue + digitToInt(cp);
          this.advance();
        }
        return true;
      }
    };
    var DummyPattern = {};
    var DummyFlags = {};
    var DummyCapturingGroup = {};
    var RegExpParserState = class {
      constructor(options) {
        this._node = DummyPattern;
        this._flags = DummyFlags;
        this._backreferences = [];
        this._capturingGroups = [];
        this.source = "";
        this.strict = Boolean(options && options.strict);
        this.ecmaVersion = options && options.ecmaVersion || 2022;
      }
      get pattern() {
        if (this._node.type !== "Pattern") {
          throw new Error("UnknownError");
        }
        return this._node;
      }
      get flags() {
        if (this._flags.type !== "Flags") {
          throw new Error("UnknownError");
        }
        return this._flags;
      }
      onFlags(start, end, global2, ignoreCase, multiline, unicode, sticky, dotAll, hasIndices) {
        this._flags = {
          type: "Flags",
          parent: null,
          start,
          end,
          raw: this.source.slice(start, end),
          global: global2,
          ignoreCase,
          multiline,
          unicode,
          sticky,
          dotAll,
          hasIndices
        };
      }
      onPatternEnter(start) {
        this._node = {
          type: "Pattern",
          parent: null,
          start,
          end: start,
          raw: "",
          alternatives: []
        };
        this._backreferences.length = 0;
        this._capturingGroups.length = 0;
      }
      onPatternLeave(start, end) {
        this._node.end = end;
        this._node.raw = this.source.slice(start, end);
        for (const reference of this._backreferences) {
          const ref = reference.ref;
          const group = typeof ref === "number" ? this._capturingGroups[ref - 1] : this._capturingGroups.find((g) => g.name === ref);
          reference.resolved = group;
          group.references.push(reference);
        }
      }
      onAlternativeEnter(start) {
        const parent = this._node;
        if (parent.type !== "Assertion" && parent.type !== "CapturingGroup" && parent.type !== "Group" && parent.type !== "Pattern") {
          throw new Error("UnknownError");
        }
        this._node = {
          type: "Alternative",
          parent,
          start,
          end: start,
          raw: "",
          elements: []
        };
        parent.alternatives.push(this._node);
      }
      onAlternativeLeave(start, end) {
        const node = this._node;
        if (node.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        node.end = end;
        node.raw = this.source.slice(start, end);
        this._node = node.parent;
      }
      onGroupEnter(start) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        this._node = {
          type: "Group",
          parent,
          start,
          end: start,
          raw: "",
          alternatives: []
        };
        parent.elements.push(this._node);
      }
      onGroupLeave(start, end) {
        const node = this._node;
        if (node.type !== "Group" || node.parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        node.end = end;
        node.raw = this.source.slice(start, end);
        this._node = node.parent;
      }
      onCapturingGroupEnter(start, name) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        this._node = {
          type: "CapturingGroup",
          parent,
          start,
          end: start,
          raw: "",
          name,
          alternatives: [],
          references: []
        };
        parent.elements.push(this._node);
        this._capturingGroups.push(this._node);
      }
      onCapturingGroupLeave(start, end) {
        const node = this._node;
        if (node.type !== "CapturingGroup" || node.parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        node.end = end;
        node.raw = this.source.slice(start, end);
        this._node = node.parent;
      }
      onQuantifier(start, end, min2, max2, greedy) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        const element = parent.elements.pop();
        if (element == null || element.type === "Quantifier" || element.type === "Assertion" && element.kind !== "lookahead") {
          throw new Error("UnknownError");
        }
        const node = {
          type: "Quantifier",
          parent,
          start: element.start,
          end,
          raw: this.source.slice(element.start, end),
          min: min2,
          max: max2,
          greedy,
          element
        };
        parent.elements.push(node);
        element.parent = node;
      }
      onLookaroundAssertionEnter(start, kind, negate) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        const node = this._node = {
          type: "Assertion",
          parent,
          start,
          end: start,
          raw: "",
          kind,
          negate,
          alternatives: []
        };
        parent.elements.push(node);
      }
      onLookaroundAssertionLeave(start, end) {
        const node = this._node;
        if (node.type !== "Assertion" || node.parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        node.end = end;
        node.raw = this.source.slice(start, end);
        this._node = node.parent;
      }
      onEdgeAssertion(start, end, kind) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "Assertion",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          kind
        });
      }
      onWordBoundaryAssertion(start, end, kind, negate) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "Assertion",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          kind,
          negate
        });
      }
      onAnyCharacterSet(start, end, kind) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "CharacterSet",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          kind
        });
      }
      onEscapeCharacterSet(start, end, kind, negate) {
        const parent = this._node;
        if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "CharacterSet",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          kind,
          negate
        });
      }
      onUnicodePropertyCharacterSet(start, end, kind, key, value2, negate) {
        const parent = this._node;
        if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "CharacterSet",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          kind,
          key,
          value: value2,
          negate
        });
      }
      onCharacter(start, end, value2) {
        const parent = this._node;
        if (parent.type !== "Alternative" && parent.type !== "CharacterClass") {
          throw new Error("UnknownError");
        }
        parent.elements.push({
          type: "Character",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          value: value2
        });
      }
      onBackreference(start, end, ref) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        const node = {
          type: "Backreference",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          ref,
          resolved: DummyCapturingGroup
        };
        parent.elements.push(node);
        this._backreferences.push(node);
      }
      onCharacterClassEnter(start, negate) {
        const parent = this._node;
        if (parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        this._node = {
          type: "CharacterClass",
          parent,
          start,
          end: start,
          raw: "",
          negate,
          elements: []
        };
        parent.elements.push(this._node);
      }
      onCharacterClassLeave(start, end) {
        const node = this._node;
        if (node.type !== "CharacterClass" || node.parent.type !== "Alternative") {
          throw new Error("UnknownError");
        }
        node.end = end;
        node.raw = this.source.slice(start, end);
        this._node = node.parent;
      }
      onCharacterClassRange(start, end) {
        const parent = this._node;
        if (parent.type !== "CharacterClass") {
          throw new Error("UnknownError");
        }
        const elements = parent.elements;
        const max2 = elements.pop();
        const hyphen = elements.pop();
        const min2 = elements.pop();
        if (!min2 || !max2 || !hyphen || min2.type !== "Character" || max2.type !== "Character" || hyphen.type !== "Character" || hyphen.value !== HyphenMinus) {
          throw new Error("UnknownError");
        }
        const node = {
          type: "CharacterClassRange",
          parent,
          start,
          end,
          raw: this.source.slice(start, end),
          min: min2,
          max: max2
        };
        min2.parent = node;
        max2.parent = node;
        elements.push(node);
      }
    };
    var RegExpParser = class {
      constructor(options) {
        this._state = new RegExpParserState(options);
        this._validator = new RegExpValidator(this._state);
      }
      parseLiteral(source, start = 0, end = source.length) {
        this._state.source = source;
        this._validator.validateLiteral(source, start, end);
        const pattern = this._state.pattern;
        const flags = this._state.flags;
        const literal = {
          type: "RegExpLiteral",
          parent: null,
          start,
          end,
          raw: source,
          pattern,
          flags
        };
        pattern.parent = literal;
        flags.parent = literal;
        return literal;
      }
      parseFlags(source, start = 0, end = source.length) {
        this._state.source = source;
        this._validator.validateFlags(source, start, end);
        return this._state.flags;
      }
      parsePattern(source, start = 0, end = source.length, uFlag = false) {
        this._state.source = source;
        this._validator.validatePattern(source, start, end, uFlag);
        return this._state.pattern;
      }
    };
    var RegExpVisitor = class {
      constructor(handlers) {
        this._handlers = handlers;
      }
      visit(node) {
        switch (node.type) {
          case "Alternative":
            this.visitAlternative(node);
            break;
          case "Assertion":
            this.visitAssertion(node);
            break;
          case "Backreference":
            this.visitBackreference(node);
            break;
          case "CapturingGroup":
            this.visitCapturingGroup(node);
            break;
          case "Character":
            this.visitCharacter(node);
            break;
          case "CharacterClass":
            this.visitCharacterClass(node);
            break;
          case "CharacterClassRange":
            this.visitCharacterClassRange(node);
            break;
          case "CharacterSet":
            this.visitCharacterSet(node);
            break;
          case "Flags":
            this.visitFlags(node);
            break;
          case "Group":
            this.visitGroup(node);
            break;
          case "Pattern":
            this.visitPattern(node);
            break;
          case "Quantifier":
            this.visitQuantifier(node);
            break;
          case "RegExpLiteral":
            this.visitRegExpLiteral(node);
            break;
          default:
            throw new Error(`Unknown type: ${node.type}`);
        }
      }
      visitAlternative(node) {
        if (this._handlers.onAlternativeEnter) {
          this._handlers.onAlternativeEnter(node);
        }
        node.elements.forEach(this.visit, this);
        if (this._handlers.onAlternativeLeave) {
          this._handlers.onAlternativeLeave(node);
        }
      }
      visitAssertion(node) {
        if (this._handlers.onAssertionEnter) {
          this._handlers.onAssertionEnter(node);
        }
        if (node.kind === "lookahead" || node.kind === "lookbehind") {
          node.alternatives.forEach(this.visit, this);
        }
        if (this._handlers.onAssertionLeave) {
          this._handlers.onAssertionLeave(node);
        }
      }
      visitBackreference(node) {
        if (this._handlers.onBackreferenceEnter) {
          this._handlers.onBackreferenceEnter(node);
        }
        if (this._handlers.onBackreferenceLeave) {
          this._handlers.onBackreferenceLeave(node);
        }
      }
      visitCapturingGroup(node) {
        if (this._handlers.onCapturingGroupEnter) {
          this._handlers.onCapturingGroupEnter(node);
        }
        node.alternatives.forEach(this.visit, this);
        if (this._handlers.onCapturingGroupLeave) {
          this._handlers.onCapturingGroupLeave(node);
        }
      }
      visitCharacter(node) {
        if (this._handlers.onCharacterEnter) {
          this._handlers.onCharacterEnter(node);
        }
        if (this._handlers.onCharacterLeave) {
          this._handlers.onCharacterLeave(node);
        }
      }
      visitCharacterClass(node) {
        if (this._handlers.onCharacterClassEnter) {
          this._handlers.onCharacterClassEnter(node);
        }
        node.elements.forEach(this.visit, this);
        if (this._handlers.onCharacterClassLeave) {
          this._handlers.onCharacterClassLeave(node);
        }
      }
      visitCharacterClassRange(node) {
        if (this._handlers.onCharacterClassRangeEnter) {
          this._handlers.onCharacterClassRangeEnter(node);
        }
        this.visitCharacter(node.min);
        this.visitCharacter(node.max);
        if (this._handlers.onCharacterClassRangeLeave) {
          this._handlers.onCharacterClassRangeLeave(node);
        }
      }
      visitCharacterSet(node) {
        if (this._handlers.onCharacterSetEnter) {
          this._handlers.onCharacterSetEnter(node);
        }
        if (this._handlers.onCharacterSetLeave) {
          this._handlers.onCharacterSetLeave(node);
        }
      }
      visitFlags(node) {
        if (this._handlers.onFlagsEnter) {
          this._handlers.onFlagsEnter(node);
        }
        if (this._handlers.onFlagsLeave) {
          this._handlers.onFlagsLeave(node);
        }
      }
      visitGroup(node) {
        if (this._handlers.onGroupEnter) {
          this._handlers.onGroupEnter(node);
        }
        node.alternatives.forEach(this.visit, this);
        if (this._handlers.onGroupLeave) {
          this._handlers.onGroupLeave(node);
        }
      }
      visitPattern(node) {
        if (this._handlers.onPatternEnter) {
          this._handlers.onPatternEnter(node);
        }
        node.alternatives.forEach(this.visit, this);
        if (this._handlers.onPatternLeave) {
          this._handlers.onPatternLeave(node);
        }
      }
      visitQuantifier(node) {
        if (this._handlers.onQuantifierEnter) {
          this._handlers.onQuantifierEnter(node);
        }
        this.visit(node.element);
        if (this._handlers.onQuantifierLeave) {
          this._handlers.onQuantifierLeave(node);
        }
      }
      visitRegExpLiteral(node) {
        if (this._handlers.onRegExpLiteralEnter) {
          this._handlers.onRegExpLiteralEnter(node);
        }
        this.visitPattern(node.pattern);
        this.visitFlags(node.flags);
        if (this._handlers.onRegExpLiteralLeave) {
          this._handlers.onRegExpLiteralLeave(node);
        }
      }
    };
    function parseRegExpLiteral(source, options) {
      return new RegExpParser(options).parseLiteral(String(source));
    }
    function validateRegExpLiteral(source, options) {
      return new RegExpValidator(options).validateLiteral(source);
    }
    function visitRegExpAST(node, handlers) {
      new RegExpVisitor(handlers).visit(node);
    }
    exports.AST = ast;
    exports.RegExpParser = RegExpParser;
    exports.RegExpValidator = RegExpValidator;
    exports.parseRegExpLiteral = parseRegExpLiteral;
    exports.validateRegExpLiteral = validateRegExpLiteral;
    exports.visitRegExpAST = visitRegExpAST;
  }
});

// node_modules/eslint/lib/rules/no-control-regex.js
var require_no_control_regex = __commonJS({
  "node_modules/eslint/lib/rules/no-control-regex.js"(exports, module2) {
    "use strict";
    var RegExpValidator = require_regexpp().RegExpValidator;
    var collector = new class {
      constructor() {
        this._source = "";
        this._controlChars = [];
        this._validator = new RegExpValidator(this);
      }
      onPatternEnter() {
        this._controlChars = [];
      }
      onCharacter(start, end, cp) {
        if (cp >= 0 && cp <= 31 && (this._source.codePointAt(start) === cp || this._source.slice(start, end).startsWith("\\x") || this._source.slice(start, end).startsWith("\\u"))) {
          this._controlChars.push(`\\x${`0${cp.toString(16)}`.slice(-2)}`);
        }
      }
      collectControlChars(regexpStr, flags) {
        const uFlag = typeof flags === "string" && flags.includes("u");
        try {
          this._source = regexpStr;
          this._validator.validatePattern(regexpStr, void 0, void 0, uFlag);
        } catch {
        }
        return this._controlChars;
      }
    }();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow control characters in regular expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-control-regex"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected control character(s) in regular expression: {{controlChars}}."
        }
      },
      create(context) {
        function getRegExp(node) {
          if (node.regex) {
            return node.regex;
          }
          if (typeof node.value === "string" && (node.parent.type === "NewExpression" || node.parent.type === "CallExpression") && node.parent.callee.type === "Identifier" && node.parent.callee.name === "RegExp" && node.parent.arguments[0] === node) {
            const pattern = node.value;
            const flags = node.parent.arguments.length > 1 && node.parent.arguments[1].type === "Literal" && typeof node.parent.arguments[1].value === "string" ? node.parent.arguments[1].value : null;
            return { pattern, flags };
          }
          return null;
        }
        return {
          Literal(node) {
            const regExp = getRegExp(node);
            if (regExp) {
              const { pattern, flags } = regExp;
              const controlCharacters = collector.collectControlChars(pattern, flags);
              if (controlCharacters.length > 0) {
                context.report({
                  node,
                  messageId: "unexpected",
                  data: {
                    controlChars: controlCharacters.join(", ")
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-debugger.js
var require_no_debugger = __commonJS({
  "node_modules/eslint/lib/rules/no-debugger.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow the use of `debugger`",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-debugger"
        },
        fixable: null,
        schema: [],
        messages: {
          unexpected: "Unexpected 'debugger' statement."
        }
      },
      create(context) {
        return {
          DebuggerStatement(node) {
            context.report({
              node,
              messageId: "unexpected"
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-delete-var.js
var require_no_delete_var = __commonJS({
  "node_modules/eslint/lib/rules/no-delete-var.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow deleting variables",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-delete-var"
        },
        schema: [],
        messages: {
          unexpected: "Variables should not be deleted."
        }
      },
      create(context) {
        return {
          UnaryExpression(node) {
            if (node.operator === "delete" && node.argument.type === "Identifier") {
              context.report({ node, messageId: "unexpected" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-div-regex.js
var require_no_div_regex = __commonJS({
  "node_modules/eslint/lib/rules/no-div-regex.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow division operators explicitly at the beginning of regular expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-div-regex"
        },
        fixable: "code",
        schema: [],
        messages: {
          unexpected: "A regular expression literal can be confused with '/='."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          Literal(node) {
            const token = sourceCode.getFirstToken(node);
            if (token.type === "RegularExpression" && token.value[1] === "=") {
              context.report({
                node,
                messageId: "unexpected",
                fix(fixer) {
                  return fixer.replaceTextRange([token.range[0] + 1, token.range[0] + 2], "[=]");
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-dupe-args.js
var require_no_dupe_args = __commonJS({
  "node_modules/eslint/lib/rules/no-dupe-args.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate arguments in `function` definitions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-dupe-args"
        },
        schema: [],
        messages: {
          unexpected: "Duplicate param '{{name}}'."
        }
      },
      create(context) {
        function isParameter(def) {
          return def.type === "Parameter";
        }
        function checkParams(node) {
          const variables = context.getDeclaredVariables(node);
          for (let i = 0; i < variables.length; ++i) {
            const variable = variables[i];
            const defs = variable.defs.filter(isParameter);
            if (defs.length >= 2) {
              context.report({
                node,
                messageId: "unexpected",
                data: { name: variable.name }
              });
            }
          }
        }
        return {
          FunctionDeclaration: checkParams,
          FunctionExpression: checkParams
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-dupe-class-members.js
var require_no_dupe_class_members = __commonJS({
  "node_modules/eslint/lib/rules/no-dupe-class-members.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate class members",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-dupe-class-members"
        },
        schema: [],
        messages: {
          unexpected: "Duplicate name '{{name}}'."
        }
      },
      create(context) {
        let stack = [];
        function getState(name, isStatic) {
          const stateMap = stack[stack.length - 1];
          const key = `$${name}`;
          if (!stateMap[key]) {
            stateMap[key] = {
              nonStatic: { init: false, get: false, set: false },
              static: { init: false, get: false, set: false }
            };
          }
          return stateMap[key][isStatic ? "static" : "nonStatic"];
        }
        return {
          // Initializes the stack of state of member declarations.
          Program() {
            stack = [];
          },
          // Initializes state of member declarations for the class.
          ClassBody() {
            stack.push(/* @__PURE__ */ Object.create(null));
          },
          // Disposes the state for the class.
          "ClassBody:exit"() {
            stack.pop();
          },
          // Reports the node if its name has been declared already.
          "MethodDefinition, PropertyDefinition"(node) {
            const name = astUtils.getStaticPropertyName(node);
            const kind = node.type === "MethodDefinition" ? node.kind : "field";
            if (name === null || kind === "constructor") {
              return;
            }
            const state = getState(name, node.static);
            let isDuplicate = false;
            if (kind === "get") {
              isDuplicate = state.init || state.get;
              state.get = true;
            } else if (kind === "set") {
              isDuplicate = state.init || state.set;
              state.set = true;
            } else {
              isDuplicate = state.init || state.get || state.set;
              state.init = true;
            }
            if (isDuplicate) {
              context.report({ node, messageId: "unexpected", data: { name } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-dupe-else-if.js
var require_no_dupe_else_if = __commonJS({
  "node_modules/eslint/lib/rules/no-dupe-else-if.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isSubsetByComparator(comparator, arrA, arrB) {
      return arrA.every((a) => arrB.some((b) => comparator(a, b)));
    }
    function splitByLogicalOperator(operator, node) {
      if (node.type === "LogicalExpression" && node.operator === operator) {
        return [...splitByLogicalOperator(operator, node.left), ...splitByLogicalOperator(operator, node.right)];
      }
      return [node];
    }
    var splitByOr = splitByLogicalOperator.bind(null, "||");
    var splitByAnd = splitByLogicalOperator.bind(null, "&&");
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate conditions in if-else-if chains",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-dupe-else-if"
        },
        schema: [],
        messages: {
          unexpected: "This branch can never execute. Its condition is a duplicate or covered by previous conditions in the if-else-if chain."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function equal(a, b) {
          if (a.type !== b.type) {
            return false;
          }
          if (a.type === "LogicalExpression" && (a.operator === "||" || a.operator === "&&") && a.operator === b.operator) {
            return equal(a.left, b.left) && equal(a.right, b.right) || equal(a.left, b.right) && equal(a.right, b.left);
          }
          return astUtils.equalTokens(a, b, sourceCode);
        }
        const isSubset = isSubsetByComparator.bind(null, equal);
        return {
          IfStatement(node) {
            const test = node.test, conditionsToCheck = test.type === "LogicalExpression" && test.operator === "&&" ? [test, ...splitByAnd(test)] : [test];
            let current = node, listToCheck = conditionsToCheck.map((c) => splitByOr(c).map(splitByAnd));
            while (current.parent && current.parent.type === "IfStatement" && current.parent.alternate === current) {
              current = current.parent;
              const currentOrOperands = splitByOr(current.test).map(splitByAnd);
              listToCheck = listToCheck.map((orOperands) => orOperands.filter(
                (orOperand) => !currentOrOperands.some((currentOrOperand) => isSubset(currentOrOperand, orOperand))
              ));
              if (listToCheck.some((orOperands) => orOperands.length === 0)) {
                context.report({ node: test, messageId: "unexpected" });
                break;
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-dupe-keys.js
var require_no_dupe_keys = __commonJS({
  "node_modules/eslint/lib/rules/no-dupe-keys.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var GET_KIND = /^(?:init|get)$/u;
    var SET_KIND = /^(?:init|set)$/u;
    var ObjectInfo = class {
      /**
       * @param {ObjectInfo|null} upper The information of the outer object.
       * @param {ASTNode} node The ObjectExpression node of this information.
       */
      constructor(upper, node) {
        this.upper = upper;
        this.node = node;
        this.properties = /* @__PURE__ */ new Map();
      }
      /**
       * Gets the information of the given Property node.
       * @param {ASTNode} node The Property node to get.
       * @returns {{get: boolean, set: boolean}} The information of the property.
       */
      getPropertyInfo(node) {
        const name = astUtils.getStaticPropertyName(node);
        if (!this.properties.has(name)) {
          this.properties.set(name, { get: false, set: false });
        }
        return this.properties.get(name);
      }
      /**
       * Checks whether the given property has been defined already or not.
       * @param {ASTNode} node The Property node to check.
       * @returns {boolean} `true` if the property has been defined.
       */
      isPropertyDefined(node) {
        const entry = this.getPropertyInfo(node);
        return GET_KIND.test(node.kind) && entry.get || SET_KIND.test(node.kind) && entry.set;
      }
      /**
       * Defines the given property.
       * @param {ASTNode} node The Property node to define.
       * @returns {void}
       */
      defineProperty(node) {
        const entry = this.getPropertyInfo(node);
        if (GET_KIND.test(node.kind)) {
          entry.get = true;
        }
        if (SET_KIND.test(node.kind)) {
          entry.set = true;
        }
      }
    };
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate keys in object literals",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-dupe-keys"
        },
        schema: [],
        messages: {
          unexpected: "Duplicate key '{{name}}'."
        }
      },
      create(context) {
        let info = null;
        return {
          ObjectExpression(node) {
            info = new ObjectInfo(info, node);
          },
          "ObjectExpression:exit"() {
            info = info.upper;
          },
          Property(node) {
            const name = astUtils.getStaticPropertyName(node);
            if (node.parent.type !== "ObjectExpression") {
              return;
            }
            if (name === null) {
              return;
            }
            if (info.isPropertyDefined(node)) {
              context.report({
                node: info.node,
                loc: node.key.loc,
                messageId: "unexpected",
                data: { name }
              });
            }
            info.defineProperty(node);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-duplicate-case.js
var require_no_duplicate_case = __commonJS({
  "node_modules/eslint/lib/rules/no-duplicate-case.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate case labels",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-duplicate-case"
        },
        schema: [],
        messages: {
          unexpected: "Duplicate case label."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function equal(a, b) {
          if (a.type !== b.type) {
            return false;
          }
          return astUtils.equalTokens(a, b, sourceCode);
        }
        return {
          SwitchStatement(node) {
            const previousTests = [];
            for (const switchCase of node.cases) {
              if (switchCase.test) {
                const test = switchCase.test;
                if (previousTests.some((previousTest) => equal(previousTest, test))) {
                  context.report({ node: switchCase, messageId: "unexpected" });
                } else {
                  previousTests.push(test);
                }
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-duplicate-imports.js
var require_no_duplicate_imports = __commonJS({
  "node_modules/eslint/lib/rules/no-duplicate-imports.js"(exports, module2) {
    "use strict";
    var NAMED_TYPES = ["ImportSpecifier", "ExportSpecifier"];
    var NAMESPACE_TYPES = [
      "ImportNamespaceSpecifier",
      "ExportNamespaceSpecifier"
    ];
    function isImportExportSpecifier(importExportType, type) {
      const arrayToCheck = type === "named" ? NAMED_TYPES : NAMESPACE_TYPES;
      return arrayToCheck.includes(importExportType);
    }
    function getImportExportType(node) {
      if (node.specifiers && node.specifiers.length > 0) {
        const nodeSpecifiers = node.specifiers;
        const index = nodeSpecifiers.findIndex(
          ({ type }) => isImportExportSpecifier(type, "named") || isImportExportSpecifier(type, "namespace")
        );
        const i = index > -1 ? index : 0;
        return nodeSpecifiers[i].type;
      }
      if (node.type === "ExportAllDeclaration") {
        if (node.exported) {
          return "ExportNamespaceSpecifier";
        }
        return "ExportAll";
      }
      return "SideEffectImport";
    }
    function isImportExportCanBeMerged(node1, node2) {
      const importExportType1 = getImportExportType(node1);
      const importExportType2 = getImportExportType(node2);
      if (importExportType1 === "ExportAll" && importExportType2 !== "ExportAll" && importExportType2 !== "SideEffectImport" || importExportType1 !== "ExportAll" && importExportType1 !== "SideEffectImport" && importExportType2 === "ExportAll") {
        return false;
      }
      if (isImportExportSpecifier(importExportType1, "namespace") && isImportExportSpecifier(importExportType2, "named") || isImportExportSpecifier(importExportType2, "namespace") && isImportExportSpecifier(importExportType1, "named")) {
        return false;
      }
      return true;
    }
    function shouldReportImportExport(node, previousNodes) {
      let i = 0;
      while (i < previousNodes.length) {
        if (isImportExportCanBeMerged(node, previousNodes[i])) {
          return true;
        }
        i++;
      }
      return false;
    }
    function getNodesByDeclarationType(nodes, type) {
      return nodes.filter(({ declarationType }) => declarationType === type).map(({ node }) => node);
    }
    function getModule(node) {
      if (node && node.source && node.source.value) {
        return node.source.value.trim();
      }
      return "";
    }
    function checkAndReport(context, node, modules, declarationType, includeExports) {
      const module3 = getModule(node);
      if (modules.has(module3)) {
        const previousNodes = modules.get(module3);
        const messagesIds = [];
        const importNodes = getNodesByDeclarationType(previousNodes, "import");
        let exportNodes;
        if (includeExports) {
          exportNodes = getNodesByDeclarationType(previousNodes, "export");
        }
        if (declarationType === "import") {
          if (shouldReportImportExport(node, importNodes)) {
            messagesIds.push("import");
          }
          if (includeExports) {
            if (shouldReportImportExport(node, exportNodes)) {
              messagesIds.push("importAs");
            }
          }
        } else if (declarationType === "export") {
          if (shouldReportImportExport(node, exportNodes)) {
            messagesIds.push("export");
          }
          if (shouldReportImportExport(node, importNodes)) {
            messagesIds.push("exportAs");
          }
        }
        messagesIds.forEach((messageId) => context.report({
          node,
          messageId,
          data: {
            module: module3
          }
        }));
      }
    }
    function handleImportsExports(context, modules, declarationType, includeExports) {
      return function(node) {
        const module3 = getModule(node);
        if (module3) {
          checkAndReport(
            context,
            node,
            modules,
            declarationType,
            includeExports
          );
          const currentNode = { node, declarationType };
          let nodes = [currentNode];
          if (modules.has(module3)) {
            const previousNodes = modules.get(module3);
            nodes = [...previousNodes, currentNode];
          }
          modules.set(module3, nodes);
        }
      };
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow duplicate module imports",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-duplicate-imports"
        },
        schema: [
          {
            type: "object",
            properties: {
              includeExports: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          import: "'{{module}}' import is duplicated.",
          importAs: "'{{module}}' import is duplicated as export.",
          export: "'{{module}}' export is duplicated.",
          exportAs: "'{{module}}' export is duplicated as import."
        }
      },
      create(context) {
        const includeExports = (context.options[0] || {}).includeExports, modules = /* @__PURE__ */ new Map();
        const handlers = {
          ImportDeclaration: handleImportsExports(
            context,
            modules,
            "import",
            includeExports
          )
        };
        if (includeExports) {
          handlers.ExportNamedDeclaration = handleImportsExports(
            context,
            modules,
            "export",
            includeExports
          );
          handlers.ExportAllDeclaration = handleImportsExports(
            context,
            modules,
            "export",
            includeExports
          );
        }
        return handlers;
      }
    };
  }
});

// node_modules/eslint/lib/rules/utils/fix-tracker.js
var require_fix_tracker = __commonJS({
  "node_modules/eslint/lib/rules/utils/fix-tracker.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var FixTracker = class {
      /**
       * Create a new FixTracker.
       * @param {ruleFixer} fixer A ruleFixer instance.
       * @param {SourceCode} sourceCode A SourceCode object for the current code.
       */
      constructor(fixer, sourceCode) {
        this.fixer = fixer;
        this.sourceCode = sourceCode;
        this.retainedRange = null;
      }
      /**
       * Mark the given range as "retained", meaning that other fixes may not
       * may not modify this region in the same pass.
       * @param {int[]} range The range to retain.
       * @returns {FixTracker} The same RuleFixer, for chained calls.
       */
      retainRange(range) {
        this.retainedRange = range;
        return this;
      }
      /**
       * Given a node, find the function containing it (or the entire program) and
       * mark it as retained, meaning that other fixes may not modify it in this
       * pass. This is useful for avoiding conflicts in fixes that modify control
       * flow.
       * @param {ASTNode} node The node to use as a starting point.
       * @returns {FixTracker} The same RuleFixer, for chained calls.
       */
      retainEnclosingFunction(node) {
        const functionNode = astUtils.getUpperFunction(node);
        return this.retainRange(functionNode ? functionNode.range : this.sourceCode.ast.range);
      }
      /**
       * Given a node or token, find the token before and afterward, and mark that
       * range as retained, meaning that other fixes may not modify it in this
       * pass. This is useful for avoiding conflicts in fixes that make a small
       * change to the code where the AST should not be changed.
       * @param {ASTNode|Token} nodeOrToken The node or token to use as a starting
       *      point. The token to the left and right are use in the range.
       * @returns {FixTracker} The same RuleFixer, for chained calls.
       */
      retainSurroundingTokens(nodeOrToken) {
        const tokenBefore = this.sourceCode.getTokenBefore(nodeOrToken) || nodeOrToken;
        const tokenAfter = this.sourceCode.getTokenAfter(nodeOrToken) || nodeOrToken;
        return this.retainRange([tokenBefore.range[0], tokenAfter.range[1]]);
      }
      /**
       * Create a fix command that replaces the given range with the given text,
       * accounting for any retained ranges.
       * @param {int[]} range The range to remove in the fix.
       * @param {string} text The text to insert in place of the range.
       * @returns {Object} The fix command.
       */
      replaceTextRange(range, text) {
        let actualRange;
        if (this.retainedRange) {
          actualRange = [
            Math.min(this.retainedRange[0], range[0]),
            Math.max(this.retainedRange[1], range[1])
          ];
        } else {
          actualRange = range;
        }
        return this.fixer.replaceTextRange(
          actualRange,
          this.sourceCode.text.slice(actualRange[0], range[0]) + text + this.sourceCode.text.slice(range[1], actualRange[1])
        );
      }
      /**
       * Create a fix command that removes the given node or token, accounting for
       * any retained ranges.
       * @param {ASTNode|Token} nodeOrToken The node or token to remove.
       * @returns {Object} The fix command.
       */
      remove(nodeOrToken) {
        return this.replaceTextRange(nodeOrToken.range, "");
      }
    };
    module2.exports = FixTracker;
  }
});

// node_modules/eslint/lib/rules/no-else-return.js
var require_no_else_return = __commonJS({
  "node_modules/eslint/lib/rules/no-else-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var FixTracker = require_fix_tracker();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `else` blocks after `return` statements in `if` statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-else-return"
        },
        schema: [{
          type: "object",
          properties: {
            allowElseIf: {
              type: "boolean",
              default: true
            }
          },
          additionalProperties: false
        }],
        fixable: "code",
        messages: {
          unexpected: "Unnecessary 'else' after 'return'."
        }
      },
      create(context) {
        function isSafeToDeclare(names, scope) {
          if (names.length === 0) {
            return true;
          }
          const functionScope = scope.variableScope;
          const declaredVariables = scope.variables.filter(({ defs }) => defs.length > 0);
          if (declaredVariables.some(({ name }) => names.includes(name))) {
            return false;
          }
          if (scope !== functionScope && scope.upper.type === "catch") {
            if (scope.upper.variables.some(({ name }) => names.includes(name))) {
              return false;
            }
          }
          const usedImplicitVariables = scope.variables.filter(({ defs, references }) => defs.length === 0 && references.length > 0);
          if (usedImplicitVariables.some(({ name }) => names.includes(name))) {
            return false;
          }
          if (scope.through.some((t3) => names.includes(t3.identifier.name))) {
            return false;
          }
          if (scope !== functionScope) {
            const scopeNodeRange = scope.block.range;
            const variablesToCheck = functionScope.variables.filter(({ name }) => names.includes(name));
            if (variablesToCheck.some((v) => v.defs.some(({ node: { range } }) => scopeNodeRange[0] <= range[0] && range[1] <= scopeNodeRange[1]))) {
              return false;
            }
          }
          return true;
        }
        function isSafeFromNameCollisions(node, scope) {
          if (node.type === "FunctionDeclaration") {
            return false;
          }
          if (node.type !== "BlockStatement") {
            return true;
          }
          const elseBlockScope = scope.childScopes.find(({ block }) => block === node);
          if (!elseBlockScope) {
            return true;
          }
          const namesToCheck = elseBlockScope.variables.map(({ name }) => name);
          return isSafeToDeclare(namesToCheck, scope);
        }
        function displayReport(node) {
          const currentScope = context.getScope();
          context.report({
            node,
            messageId: "unexpected",
            fix(fixer) {
              if (!isSafeFromNameCollisions(node, currentScope)) {
                return null;
              }
              const sourceCode = context.getSourceCode();
              const startToken = sourceCode.getFirstToken(node);
              const elseToken = sourceCode.getTokenBefore(startToken);
              const source = sourceCode.getText(node);
              const lastIfToken = sourceCode.getTokenBefore(elseToken);
              let fixedSource, firstTokenOfElseBlock;
              if (startToken.type === "Punctuator" && startToken.value === "{") {
                firstTokenOfElseBlock = sourceCode.getTokenAfter(startToken);
              } else {
                firstTokenOfElseBlock = startToken;
              }
              const ifBlockMaybeUnsafe = node.parent.consequent.type !== "BlockStatement" && lastIfToken.value !== ";";
              const elseBlockUnsafe = /^[([/+`-]/u.test(firstTokenOfElseBlock.value);
              if (ifBlockMaybeUnsafe && elseBlockUnsafe) {
                return null;
              }
              const endToken = sourceCode.getLastToken(node);
              const lastTokenOfElseBlock = sourceCode.getTokenBefore(endToken);
              if (lastTokenOfElseBlock.value !== ";") {
                const nextToken = sourceCode.getTokenAfter(endToken);
                const nextTokenUnsafe = nextToken && /^[([/+`-]/u.test(nextToken.value);
                const nextTokenOnSameLine = nextToken && nextToken.loc.start.line === lastTokenOfElseBlock.loc.start.line;
                if (nextTokenUnsafe || nextTokenOnSameLine && nextToken.value !== "}") {
                  return null;
                }
              }
              if (startToken.type === "Punctuator" && startToken.value === "{") {
                fixedSource = source.slice(1, -1);
              } else {
                fixedSource = source;
              }
              return new FixTracker(fixer, sourceCode).retainEnclosingFunction(node).replaceTextRange([elseToken.range[0], node.range[1]], fixedSource);
            }
          });
        }
        function checkForReturn(node) {
          return node.type === "ReturnStatement";
        }
        function naiveHasReturn(node) {
          if (node.type === "BlockStatement") {
            const body = node.body, lastChildNode = body[body.length - 1];
            return lastChildNode && checkForReturn(lastChildNode);
          }
          return checkForReturn(node);
        }
        function hasElse(node) {
          return node.alternate && node.consequent;
        }
        function checkForIf(node) {
          return node.type === "IfStatement" && hasElse(node) && naiveHasReturn(node.alternate) && naiveHasReturn(node.consequent);
        }
        function checkForReturnOrIf(node) {
          return checkForReturn(node) || checkForIf(node);
        }
        function alwaysReturns(node) {
          if (node.type === "BlockStatement") {
            return node.body.some(checkForReturnOrIf);
          }
          return checkForReturnOrIf(node);
        }
        function checkIfWithoutElse(node) {
          const parent = node.parent;
          if (!astUtils.STATEMENT_LIST_PARENTS.has(parent.type)) {
            return;
          }
          const consequents = [];
          let alternate;
          for (let currentNode = node; currentNode.type === "IfStatement"; currentNode = currentNode.alternate) {
            if (!currentNode.alternate) {
              return;
            }
            consequents.push(currentNode.consequent);
            alternate = currentNode.alternate;
          }
          if (consequents.every(alwaysReturns)) {
            displayReport(alternate);
          }
        }
        function checkIfWithElse(node) {
          const parent = node.parent;
          if (!astUtils.STATEMENT_LIST_PARENTS.has(parent.type)) {
            return;
          }
          const alternate = node.alternate;
          if (alternate && alwaysReturns(node.consequent)) {
            displayReport(alternate);
          }
        }
        const allowElseIf = !(context.options[0] && context.options[0].allowElseIf === false);
        return {
          "IfStatement:exit": allowElseIf ? checkIfWithoutElse : checkIfWithElse
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-empty.js
var require_no_empty = __commonJS({
  "node_modules/eslint/lib/rules/no-empty.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        hasSuggestions: true,
        type: "suggestion",
        docs: {
          description: "Disallow empty block statements",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-empty"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowEmptyCatch: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "Empty {{type}} statement.",
          suggestComment: "Add comment inside empty {{type}} statement."
        }
      },
      create(context) {
        const options = context.options[0] || {}, allowEmptyCatch = options.allowEmptyCatch || false;
        const sourceCode = context.getSourceCode();
        return {
          BlockStatement(node) {
            if (node.body.length !== 0) {
              return;
            }
            if (astUtils.isFunction(node.parent)) {
              return;
            }
            if (allowEmptyCatch && node.parent.type === "CatchClause") {
              return;
            }
            if (sourceCode.getCommentsInside(node).length > 0) {
              return;
            }
            context.report({
              node,
              messageId: "unexpected",
              data: { type: "block" },
              suggest: [
                {
                  messageId: "suggestComment",
                  data: { type: "block" },
                  fix(fixer) {
                    const range = [node.range[0] + 1, node.range[1] - 1];
                    return fixer.replaceTextRange(range, " /* empty */ ");
                  }
                }
              ]
            });
          },
          SwitchStatement(node) {
            if (typeof node.cases === "undefined" || node.cases.length === 0) {
              context.report({ node, messageId: "unexpected", data: { type: "switch" } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-empty-character-class.js
var require_no_empty_character_class = __commonJS({
  "node_modules/eslint/lib/rules/no-empty-character-class.js"(exports, module2) {
    "use strict";
    var regex = /^([^\\[]|\\.|\[([^\\\]]|\\.)+\])*$/u;
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow empty character classes in regular expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-empty-character-class"
        },
        schema: [],
        messages: {
          unexpected: "Empty class."
        }
      },
      create(context) {
        return {
          "Literal[regex]"(node) {
            if (!regex.test(node.regex.pattern)) {
              context.report({ node, messageId: "unexpected" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-empty-function.js
var require_no_empty_function = __commonJS({
  "node_modules/eslint/lib/rules/no-empty-function.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var ALLOW_OPTIONS = Object.freeze([
      "functions",
      "arrowFunctions",
      "generatorFunctions",
      "methods",
      "generatorMethods",
      "getters",
      "setters",
      "constructors",
      "asyncFunctions",
      "asyncMethods"
    ]);
    function getKind(node) {
      const parent = node.parent;
      let kind = "";
      if (node.type === "ArrowFunctionExpression") {
        return "arrowFunctions";
      }
      if (parent.type === "Property") {
        if (parent.kind === "get") {
          return "getters";
        }
        if (parent.kind === "set") {
          return "setters";
        }
        kind = parent.method ? "methods" : "functions";
      } else if (parent.type === "MethodDefinition") {
        if (parent.kind === "get") {
          return "getters";
        }
        if (parent.kind === "set") {
          return "setters";
        }
        if (parent.kind === "constructor") {
          return "constructors";
        }
        kind = "methods";
      } else {
        kind = "functions";
      }
      let prefix = "";
      if (node.generator) {
        prefix = "generator";
      } else if (node.async) {
        prefix = "async";
      } else {
        return kind;
      }
      return prefix + kind[0].toUpperCase() + kind.slice(1);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow empty functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-empty-function"
        },
        schema: [
          {
            type: "object",
            properties: {
              allow: {
                type: "array",
                items: { enum: ALLOW_OPTIONS },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "Unexpected empty {{name}}."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const allowed = options.allow || [];
        const sourceCode = context.getSourceCode();
        function reportIfEmpty(node) {
          const kind = getKind(node);
          const name = astUtils.getFunctionNameWithKind(node);
          const innerComments = sourceCode.getTokens(node.body, {
            includeComments: true,
            filter: astUtils.isCommentToken
          });
          if (!allowed.includes(kind) && node.body.type === "BlockStatement" && node.body.body.length === 0 && innerComments.length === 0) {
            context.report({
              node,
              loc: node.body.loc,
              messageId: "unexpected",
              data: { name }
            });
          }
        }
        return {
          ArrowFunctionExpression: reportIfEmpty,
          FunctionDeclaration: reportIfEmpty,
          FunctionExpression: reportIfEmpty
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-empty-pattern.js
var require_no_empty_pattern = __commonJS({
  "node_modules/eslint/lib/rules/no-empty-pattern.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow empty destructuring patterns",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-empty-pattern"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected empty {{type}} pattern."
        }
      },
      create(context) {
        return {
          ObjectPattern(node) {
            if (node.properties.length === 0) {
              context.report({ node, messageId: "unexpected", data: { type: "object" } });
            }
          },
          ArrayPattern(node) {
            if (node.elements.length === 0) {
              context.report({ node, messageId: "unexpected", data: { type: "array" } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-empty-static-block.js
var require_no_empty_static_block = __commonJS({
  "node_modules/eslint/lib/rules/no-empty-static-block.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow empty static blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-empty-static-block"
        },
        schema: [],
        messages: {
          unexpected: "Unexpected empty static block."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          StaticBlock(node) {
            if (node.body.length === 0) {
              const closingBrace = sourceCode.getLastToken(node);
              if (sourceCode.getCommentsBefore(closingBrace).length === 0) {
                context.report({
                  node,
                  messageId: "unexpected"
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-eq-null.js
var require_no_eq_null = __commonJS({
  "node_modules/eslint/lib/rules/no-eq-null.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `null` comparisons without type-checking operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-eq-null"
        },
        schema: [],
        messages: {
          unexpected: "Use '===' to compare with null."
        }
      },
      create(context) {
        return {
          BinaryExpression(node) {
            const badOperator = node.operator === "==" || node.operator === "!=";
            if (node.right.type === "Literal" && node.right.raw === "null" && badOperator || node.left.type === "Literal" && node.left.raw === "null" && badOperator) {
              context.report({ node, messageId: "unexpected" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-eval.js
var require_no_eval = __commonJS({
  "node_modules/eslint/lib/rules/no-eval.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var candidatesOfGlobalObject = Object.freeze([
      "global",
      "window",
      "globalThis"
    ]);
    function isMember(node, name) {
      return astUtils.isSpecificMemberAccess(node, null, name);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `eval()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-eval"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowIndirect: { type: "boolean", default: false }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "eval can be harmful."
        }
      },
      create(context) {
        const allowIndirect = Boolean(
          context.options[0] && context.options[0].allowIndirect
        );
        const sourceCode = context.getSourceCode();
        let funcInfo = null;
        function enterThisScope(node) {
          const strict = context.getScope().isStrict;
          funcInfo = {
            upper: funcInfo,
            node,
            strict,
            isTopLevelOfScript: false,
            defaultThis: false,
            initialized: strict
          };
        }
        function exitThisScope() {
          funcInfo = funcInfo.upper;
        }
        function report(node) {
          const parent = node.parent;
          const locationNode = node.type === "MemberExpression" ? node.property : node;
          const reportNode = parent.type === "CallExpression" && parent.callee === node ? parent : node;
          context.report({
            node: reportNode,
            loc: locationNode.loc,
            messageId: "unexpected"
          });
        }
        function reportAccessingEvalViaGlobalObject(globalScope) {
          for (let i = 0; i < candidatesOfGlobalObject.length; ++i) {
            const name = candidatesOfGlobalObject[i];
            const variable = astUtils.getVariableByName(globalScope, name);
            if (!variable) {
              continue;
            }
            const references = variable.references;
            for (let j = 0; j < references.length; ++j) {
              const identifier3 = references[j].identifier;
              let node = identifier3.parent;
              while (isMember(node, name)) {
                node = node.parent;
              }
              if (isMember(node, "eval")) {
                report(node);
              }
            }
          }
        }
        function reportAccessingEval(globalScope) {
          const variable = astUtils.getVariableByName(globalScope, "eval");
          if (!variable) {
            return;
          }
          const references = variable.references;
          for (let i = 0; i < references.length; ++i) {
            const reference = references[i];
            const id = reference.identifier;
            if (id.name === "eval" && !astUtils.isCallee(id)) {
              report(id);
            }
          }
        }
        if (allowIndirect) {
          return {
            "CallExpression:exit"(node) {
              const callee = node.callee;
              if (!node.optional && astUtils.isSpecificId(callee, "eval")) {
                report(callee);
              }
            }
          };
        }
        return {
          "CallExpression:exit"(node) {
            const callee = node.callee;
            if (astUtils.isSpecificId(callee, "eval")) {
              report(callee);
            }
          },
          Program(node) {
            const scope = context.getScope(), features = context.parserOptions.ecmaFeatures || {}, strict = scope.isStrict || node.sourceType === "module" || features.globalReturn && scope.childScopes[0].isStrict, isTopLevelOfScript = node.sourceType !== "module" && !features.globalReturn;
            funcInfo = {
              upper: null,
              node,
              strict,
              isTopLevelOfScript,
              defaultThis: true,
              initialized: true
            };
          },
          "Program:exit"() {
            const globalScope = context.getScope();
            exitThisScope();
            reportAccessingEval(globalScope);
            reportAccessingEvalViaGlobalObject(globalScope);
          },
          FunctionDeclaration: enterThisScope,
          "FunctionDeclaration:exit": exitThisScope,
          FunctionExpression: enterThisScope,
          "FunctionExpression:exit": exitThisScope,
          "PropertyDefinition > *.value": enterThisScope,
          "PropertyDefinition > *.value:exit": exitThisScope,
          StaticBlock: enterThisScope,
          "StaticBlock:exit": exitThisScope,
          ThisExpression(node) {
            if (!isMember(node.parent, "eval")) {
              return;
            }
            if (!funcInfo.initialized) {
              funcInfo.initialized = true;
              funcInfo.defaultThis = astUtils.isDefaultThisBinding(
                funcInfo.node,
                sourceCode
              );
            }
            if (funcInfo.isTopLevelOfScript || !funcInfo.strict && funcInfo.defaultThis) {
              report(node.parent);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-ex-assign.js
var require_no_ex_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-ex-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow reassigning exceptions in `catch` clauses",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-ex-assign"
        },
        schema: [],
        messages: {
          unexpected: "Do not assign to the exception parameter."
        }
      },
      create(context) {
        function checkVariable(variable) {
          astUtils.getModifyingReferences(variable.references).forEach((reference) => {
            context.report({ node: reference.identifier, messageId: "unexpected" });
          });
        }
        return {
          CatchClause(node) {
            context.getDeclaredVariables(node).forEach(checkVariable);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-extend-native.js
var require_no_extend_native = __commonJS({
  "node_modules/eslint/lib/rules/no-extend-native.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var globals = require_globals4();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow extending native types",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-extend-native"
        },
        schema: [
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: {
                  type: "string"
                },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpected: "{{builtin}} prototype is read only, properties should not be added."
        }
      },
      create(context) {
        const config = context.options[0] || {};
        const exceptions = new Set(config.exceptions || []);
        const modifiedBuiltins = new Set(
          Object.keys(globals.builtin).filter((builtin) => builtin[0].toUpperCase() === builtin[0]).filter((builtin) => !exceptions.has(builtin))
        );
        function reportNode(node, builtin) {
          context.report({
            node,
            messageId: "unexpected",
            data: {
              builtin
            }
          });
        }
        function isPrototypePropertyAccessed(identifierNode) {
          return Boolean(
            identifierNode && identifierNode.parent && identifierNode.parent.type === "MemberExpression" && identifierNode.parent.object === identifierNode && astUtils.getStaticPropertyName(identifierNode.parent) === "prototype"
          );
        }
        function isAssigningToPropertyOf(node) {
          return node.parent.type === "MemberExpression" && node.parent.object === node && node.parent.parent.type === "AssignmentExpression" && node.parent.parent.left === node.parent;
        }
        function isInDefinePropertyCall(node) {
          return node.parent.type === "CallExpression" && node.parent.arguments[0] === node && astUtils.isSpecificMemberAccess(node.parent.callee, "Object", /^definePropert(?:y|ies)$/u);
        }
        function checkAndReportPrototypeExtension(identifierNode) {
          if (!isPrototypePropertyAccessed(identifierNode)) {
            return;
          }
          const prototypeNode = identifierNode.parent.parent.type === "ChainExpression" ? identifierNode.parent.parent : identifierNode.parent;
          if (isAssigningToPropertyOf(prototypeNode)) {
            reportNode(prototypeNode.parent.parent, identifierNode.name);
          } else if (isInDefinePropertyCall(prototypeNode)) {
            reportNode(prototypeNode.parent, identifierNode.name);
          }
        }
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            modifiedBuiltins.forEach((builtin) => {
              const builtinVar = globalScope.set.get(builtin);
              if (builtinVar && builtinVar.references) {
                builtinVar.references.map((ref) => ref.identifier).forEach(checkAndReportPrototypeExtension);
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-extra-bind.js
var require_no_extra_bind = __commonJS({
  "node_modules/eslint/lib/rules/no-extra-bind.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var SIDE_EFFECT_FREE_NODE_TYPES = /* @__PURE__ */ new Set(["Literal", "Identifier", "ThisExpression", "FunctionExpression"]);
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary calls to `.bind()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-extra-bind"
        },
        schema: [],
        fixable: "code",
        messages: {
          unexpected: "The function binding is unnecessary."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let scopeInfo = null;
        function isSideEffectFree(node) {
          return SIDE_EFFECT_FREE_NODE_TYPES.has(node.type);
        }
        function report(node) {
          const memberNode = node.parent;
          const callNode = memberNode.parent.type === "ChainExpression" ? memberNode.parent.parent : memberNode.parent;
          context.report({
            node: callNode,
            messageId: "unexpected",
            loc: memberNode.property.loc,
            fix(fixer) {
              if (!isSideEffectFree(callNode.arguments[0])) {
                return null;
              }
              const tokenPairs = [
                [
                  // `.`, `?.`, or `[` token.
                  sourceCode.getTokenAfter(
                    memberNode.object,
                    astUtils.isNotClosingParenToken
                  ),
                  // property name or `]` token.
                  sourceCode.getLastToken(memberNode)
                ],
                [
                  // `?.` or `(` token of arguments.
                  sourceCode.getTokenAfter(
                    memberNode,
                    astUtils.isNotClosingParenToken
                  ),
                  // `)` token of arguments.
                  sourceCode.getLastToken(callNode)
                ]
              ];
              const firstTokenToRemove = tokenPairs[0][0];
              const lastTokenToRemove = tokenPairs[1][1];
              if (sourceCode.commentsExistBetween(firstTokenToRemove, lastTokenToRemove)) {
                return null;
              }
              return tokenPairs.map(([start, end]) => fixer.removeRange([start.range[0], end.range[1]]));
            }
          });
        }
        function isCalleeOfBindMethod(node) {
          if (!astUtils.isSpecificMemberAccess(node.parent, null, "bind")) {
            return false;
          }
          const bindNode = node.parent.parent.type === "ChainExpression" ? node.parent.parent : node.parent;
          return bindNode.parent.type === "CallExpression" && bindNode.parent.callee === bindNode && bindNode.parent.arguments.length === 1 && bindNode.parent.arguments[0].type !== "SpreadElement";
        }
        function enterFunction(node) {
          scopeInfo = {
            isBound: isCalleeOfBindMethod(node),
            thisFound: false,
            upper: scopeInfo
          };
        }
        function exitFunction(node) {
          if (scopeInfo.isBound && !scopeInfo.thisFound) {
            report(node);
          }
          scopeInfo = scopeInfo.upper;
        }
        function exitArrowFunction(node) {
          if (isCalleeOfBindMethod(node)) {
            report(node);
          }
        }
        function markAsThisFound() {
          if (scopeInfo) {
            scopeInfo.thisFound = true;
          }
        }
        return {
          "ArrowFunctionExpression:exit": exitArrowFunction,
          FunctionDeclaration: enterFunction,
          "FunctionDeclaration:exit": exitFunction,
          FunctionExpression: enterFunction,
          "FunctionExpression:exit": exitFunction,
          ThisExpression: markAsThisFound
        };
      }
    };
  }
});

// node_modules/eslint-utils/node_modules/eslint-visitor-keys/lib/visitor-keys.json
var require_visitor_keys2 = __commonJS({
  "node_modules/eslint-utils/node_modules/eslint-visitor-keys/lib/visitor-keys.json"(exports, module2) {
    module2.exports = {
      AssignmentExpression: [
        "left",
        "right"
      ],
      AssignmentPattern: [
        "left",
        "right"
      ],
      ArrayExpression: [
        "elements"
      ],
      ArrayPattern: [
        "elements"
      ],
      ArrowFunctionExpression: [
        "params",
        "body"
      ],
      AwaitExpression: [
        "argument"
      ],
      BlockStatement: [
        "body"
      ],
      BinaryExpression: [
        "left",
        "right"
      ],
      BreakStatement: [
        "label"
      ],
      CallExpression: [
        "callee",
        "arguments"
      ],
      CatchClause: [
        "param",
        "body"
      ],
      ChainExpression: [
        "expression"
      ],
      ClassBody: [
        "body"
      ],
      ClassDeclaration: [
        "id",
        "superClass",
        "body"
      ],
      ClassExpression: [
        "id",
        "superClass",
        "body"
      ],
      ConditionalExpression: [
        "test",
        "consequent",
        "alternate"
      ],
      ContinueStatement: [
        "label"
      ],
      DebuggerStatement: [],
      DoWhileStatement: [
        "body",
        "test"
      ],
      EmptyStatement: [],
      ExportAllDeclaration: [
        "exported",
        "source"
      ],
      ExportDefaultDeclaration: [
        "declaration"
      ],
      ExportNamedDeclaration: [
        "declaration",
        "specifiers",
        "source"
      ],
      ExportSpecifier: [
        "exported",
        "local"
      ],
      ExpressionStatement: [
        "expression"
      ],
      ExperimentalRestProperty: [
        "argument"
      ],
      ExperimentalSpreadProperty: [
        "argument"
      ],
      ForStatement: [
        "init",
        "test",
        "update",
        "body"
      ],
      ForInStatement: [
        "left",
        "right",
        "body"
      ],
      ForOfStatement: [
        "left",
        "right",
        "body"
      ],
      FunctionDeclaration: [
        "id",
        "params",
        "body"
      ],
      FunctionExpression: [
        "id",
        "params",
        "body"
      ],
      Identifier: [],
      IfStatement: [
        "test",
        "consequent",
        "alternate"
      ],
      ImportDeclaration: [
        "specifiers",
        "source"
      ],
      ImportDefaultSpecifier: [
        "local"
      ],
      ImportExpression: [
        "source"
      ],
      ImportNamespaceSpecifier: [
        "local"
      ],
      ImportSpecifier: [
        "imported",
        "local"
      ],
      JSXAttribute: [
        "name",
        "value"
      ],
      JSXClosingElement: [
        "name"
      ],
      JSXElement: [
        "openingElement",
        "children",
        "closingElement"
      ],
      JSXEmptyExpression: [],
      JSXExpressionContainer: [
        "expression"
      ],
      JSXIdentifier: [],
      JSXMemberExpression: [
        "object",
        "property"
      ],
      JSXNamespacedName: [
        "namespace",
        "name"
      ],
      JSXOpeningElement: [
        "name",
        "attributes"
      ],
      JSXSpreadAttribute: [
        "argument"
      ],
      JSXText: [],
      JSXFragment: [
        "openingFragment",
        "children",
        "closingFragment"
      ],
      Literal: [],
      LabeledStatement: [
        "label",
        "body"
      ],
      LogicalExpression: [
        "left",
        "right"
      ],
      MemberExpression: [
        "object",
        "property"
      ],
      MetaProperty: [
        "meta",
        "property"
      ],
      MethodDefinition: [
        "key",
        "value"
      ],
      NewExpression: [
        "callee",
        "arguments"
      ],
      ObjectExpression: [
        "properties"
      ],
      ObjectPattern: [
        "properties"
      ],
      PrivateIdentifier: [],
      Program: [
        "body"
      ],
      Property: [
        "key",
        "value"
      ],
      PropertyDefinition: [
        "key",
        "value"
      ],
      RestElement: [
        "argument"
      ],
      ReturnStatement: [
        "argument"
      ],
      SequenceExpression: [
        "expressions"
      ],
      SpreadElement: [
        "argument"
      ],
      Super: [],
      SwitchStatement: [
        "discriminant",
        "cases"
      ],
      SwitchCase: [
        "test",
        "consequent"
      ],
      TaggedTemplateExpression: [
        "tag",
        "quasi"
      ],
      TemplateElement: [],
      TemplateLiteral: [
        "quasis",
        "expressions"
      ],
      ThisExpression: [],
      ThrowStatement: [
        "argument"
      ],
      TryStatement: [
        "block",
        "handler",
        "finalizer"
      ],
      UnaryExpression: [
        "argument"
      ],
      UpdateExpression: [
        "argument"
      ],
      VariableDeclaration: [
        "declarations"
      ],
      VariableDeclarator: [
        "id",
        "init"
      ],
      WhileStatement: [
        "test",
        "body"
      ],
      WithStatement: [
        "object",
        "body"
      ],
      YieldExpression: [
        "argument"
      ]
    };
  }
});

// node_modules/eslint-utils/node_modules/eslint-visitor-keys/lib/index.js
var require_lib5 = __commonJS({
  "node_modules/eslint-utils/node_modules/eslint-visitor-keys/lib/index.js"(exports, module2) {
    "use strict";
    var KEYS = require_visitor_keys2();
    var NODE_TYPES = Object.freeze(Object.keys(KEYS));
    for (const type of NODE_TYPES) {
      Object.freeze(KEYS[type]);
    }
    Object.freeze(KEYS);
    var KEY_BLACKLIST = /* @__PURE__ */ new Set([
      "parent",
      "leadingComments",
      "trailingComments"
    ]);
    function filterKey(key) {
      return !KEY_BLACKLIST.has(key) && key[0] !== "_";
    }
    module2.exports = Object.freeze({
      /**
       * Visitor keys.
       * @type {{ [type: string]: string[] | undefined }}
       */
      KEYS,
      /**
       * Get visitor keys of a given node.
       * @param {Object} node The AST node to get keys.
       * @returns {string[]} Visitor keys of the node.
       */
      getKeys(node) {
        return Object.keys(node).filter(filterKey);
      },
      // Disable valid-jsdoc rule because it reports syntax error on the type of @returns.
      // eslint-disable-next-line valid-jsdoc
      /**
       * Make the union set with `KEYS` and given keys.
       * @param {Object} additionalKeys The additional keys.
       * @returns {{ [type: string]: string[] | undefined }} The union set.
       */
      unionWith(additionalKeys) {
        const retv = Object.assign({}, KEYS);
        for (const type of Object.keys(additionalKeys)) {
          if (retv.hasOwnProperty(type)) {
            const keys3 = new Set(additionalKeys[type]);
            for (const key of retv[type]) {
              keys3.add(key);
            }
            retv[type] = Object.freeze(Array.from(keys3));
          } else {
            retv[type] = Object.freeze(Array.from(additionalKeys[type]));
          }
        }
        return Object.freeze(retv);
      }
    });
  }
});

// node_modules/eslint-utils/index.js
var require_eslint_utils = __commonJS({
  "node_modules/eslint-utils/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function _interopDefault(ex) {
      return ex && typeof ex === "object" && "default" in ex ? ex["default"] : ex;
    }
    var evk = _interopDefault(require_lib5());
    function getInnermostScope(initialScope, node) {
      const location = node.range[0];
      let scope = initialScope;
      let found = false;
      do {
        found = false;
        for (const childScope of scope.childScopes) {
          const range = childScope.block.range;
          if (range[0] <= location && location < range[1]) {
            scope = childScope;
            found = true;
            break;
          }
        }
      } while (found);
      return scope;
    }
    function findVariable(initialScope, nameOrNode) {
      let name = "";
      let scope = initialScope;
      if (typeof nameOrNode === "string") {
        name = nameOrNode;
      } else {
        name = nameOrNode.name;
        scope = getInnermostScope(scope, nameOrNode);
      }
      while (scope != null) {
        const variable = scope.set.get(name);
        if (variable != null) {
          return variable;
        }
        scope = scope.upper;
      }
      return null;
    }
    function negate0(token) {
      return !this(token);
    }
    function negate(f) {
      return negate0.bind(f);
    }
    function isPunctuatorTokenWithValue(token, value2) {
      return token.type === "Punctuator" && token.value === value2;
    }
    function isArrowToken(token) {
      return isPunctuatorTokenWithValue(token, "=>");
    }
    function isCommaToken(token) {
      return isPunctuatorTokenWithValue(token, ",");
    }
    function isSemicolonToken(token) {
      return isPunctuatorTokenWithValue(token, ";");
    }
    function isColonToken(token) {
      return isPunctuatorTokenWithValue(token, ":");
    }
    function isOpeningParenToken(token) {
      return isPunctuatorTokenWithValue(token, "(");
    }
    function isClosingParenToken(token) {
      return isPunctuatorTokenWithValue(token, ")");
    }
    function isOpeningBracketToken(token) {
      return isPunctuatorTokenWithValue(token, "[");
    }
    function isClosingBracketToken(token) {
      return isPunctuatorTokenWithValue(token, "]");
    }
    function isOpeningBraceToken(token) {
      return isPunctuatorTokenWithValue(token, "{");
    }
    function isClosingBraceToken(token) {
      return isPunctuatorTokenWithValue(token, "}");
    }
    function isCommentToken(token) {
      return ["Block", "Line", "Shebang"].includes(token.type);
    }
    var isNotArrowToken = negate(isArrowToken);
    var isNotCommaToken = negate(isCommaToken);
    var isNotSemicolonToken = negate(isSemicolonToken);
    var isNotColonToken = negate(isColonToken);
    var isNotOpeningParenToken = negate(isOpeningParenToken);
    var isNotClosingParenToken = negate(isClosingParenToken);
    var isNotOpeningBracketToken = negate(isOpeningBracketToken);
    var isNotClosingBracketToken = negate(isClosingBracketToken);
    var isNotOpeningBraceToken = negate(isOpeningBraceToken);
    var isNotClosingBraceToken = negate(isClosingBraceToken);
    var isNotCommentToken = negate(isCommentToken);
    function getOpeningParenOfParams(node, sourceCode) {
      return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken) : sourceCode.getFirstToken(node, isOpeningParenToken);
    }
    function getFunctionHeadLocation(node, sourceCode) {
      const parent = node.parent;
      let start = null;
      let end = null;
      if (node.type === "ArrowFunctionExpression") {
        const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken);
        start = arrowToken.loc.start;
        end = arrowToken.loc.end;
      } else if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
        start = parent.loc.start;
        end = getOpeningParenOfParams(node, sourceCode).loc.start;
      } else {
        start = node.loc.start;
        end = getOpeningParenOfParams(node, sourceCode).loc.start;
      }
      return {
        start: { ...start },
        end: { ...end }
      };
    }
    var globalObject = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {};
    var builtinNames = Object.freeze(
      /* @__PURE__ */ new Set([
        "Array",
        "ArrayBuffer",
        "BigInt",
        "BigInt64Array",
        "BigUint64Array",
        "Boolean",
        "DataView",
        "Date",
        "decodeURI",
        "decodeURIComponent",
        "encodeURI",
        "encodeURIComponent",
        "escape",
        "Float32Array",
        "Float64Array",
        "Function",
        "Infinity",
        "Int16Array",
        "Int32Array",
        "Int8Array",
        "isFinite",
        "isNaN",
        "isPrototypeOf",
        "JSON",
        "Map",
        "Math",
        "NaN",
        "Number",
        "Object",
        "parseFloat",
        "parseInt",
        "Promise",
        "Proxy",
        "Reflect",
        "RegExp",
        "Set",
        "String",
        "Symbol",
        "Uint16Array",
        "Uint32Array",
        "Uint8Array",
        "Uint8ClampedArray",
        "undefined",
        "unescape",
        "WeakMap",
        "WeakSet"
      ])
    );
    var callAllowed = new Set(
      [
        Array.isArray,
        typeof BigInt === "function" ? BigInt : void 0,
        Boolean,
        Date,
        Date.parse,
        decodeURI,
        decodeURIComponent,
        encodeURI,
        encodeURIComponent,
        escape,
        isFinite,
        isNaN,
        isPrototypeOf,
        ...Object.getOwnPropertyNames(Math).map((k) => Math[k]).filter((f) => typeof f === "function"),
        Number,
        Number.isFinite,
        Number.isNaN,
        Number.parseFloat,
        Number.parseInt,
        Object,
        Object.entries,
        Object.is,
        Object.isExtensible,
        Object.isFrozen,
        Object.isSealed,
        Object.keys,
        Object.values,
        parseFloat,
        parseInt,
        RegExp,
        String,
        String.fromCharCode,
        String.fromCodePoint,
        String.raw,
        Symbol.for,
        Symbol.keyFor,
        unescape
      ].filter((f) => typeof f === "function")
    );
    var callPassThrough = /* @__PURE__ */ new Set([
      Object.freeze,
      Object.preventExtensions,
      Object.seal
    ]);
    function getPropertyDescriptor(object, name) {
      let x = object;
      while ((typeof x === "object" || typeof x === "function") && x !== null) {
        const d = Object.getOwnPropertyDescriptor(x, name);
        if (d) {
          return d;
        }
        x = Object.getPrototypeOf(x);
      }
      return null;
    }
    function isGetter(object, name) {
      const d = getPropertyDescriptor(object, name);
      return d != null && d.get != null;
    }
    function getElementValues(nodeList, initialScope) {
      const valueList = [];
      for (let i = 0; i < nodeList.length; ++i) {
        const elementNode = nodeList[i];
        if (elementNode == null) {
          valueList.length = i + 1;
        } else if (elementNode.type === "SpreadElement") {
          const argument = getStaticValueR(elementNode.argument, initialScope);
          if (argument == null) {
            return null;
          }
          valueList.push(...argument.value);
        } else {
          const element = getStaticValueR(elementNode, initialScope);
          if (element == null) {
            return null;
          }
          valueList.push(element.value);
        }
      }
      return valueList;
    }
    var operations = Object.freeze({
      ArrayExpression(node, initialScope) {
        const elements = getElementValues(node.elements, initialScope);
        return elements != null ? { value: elements } : null;
      },
      AssignmentExpression(node, initialScope) {
        if (node.operator === "=") {
          return getStaticValueR(node.right, initialScope);
        }
        return null;
      },
      //eslint-disable-next-line complexity
      BinaryExpression(node, initialScope) {
        if (node.operator === "in" || node.operator === "instanceof") {
          return null;
        }
        const left = getStaticValueR(node.left, initialScope);
        const right = getStaticValueR(node.right, initialScope);
        if (left != null && right != null) {
          switch (node.operator) {
            case "==":
              return { value: left.value == right.value };
            case "!=":
              return { value: left.value != right.value };
            case "===":
              return { value: left.value === right.value };
            case "!==":
              return { value: left.value !== right.value };
            case "<":
              return { value: left.value < right.value };
            case "<=":
              return { value: left.value <= right.value };
            case ">":
              return { value: left.value > right.value };
            case ">=":
              return { value: left.value >= right.value };
            case "<<":
              return { value: left.value << right.value };
            case ">>":
              return { value: left.value >> right.value };
            case ">>>":
              return { value: left.value >>> right.value };
            case "+":
              return { value: left.value + right.value };
            case "-":
              return { value: left.value - right.value };
            case "*":
              return { value: left.value * right.value };
            case "/":
              return { value: left.value / right.value };
            case "%":
              return { value: left.value % right.value };
            case "**":
              return { value: Math.pow(left.value, right.value) };
            case "|":
              return { value: left.value | right.value };
            case "^":
              return { value: left.value ^ right.value };
            case "&":
              return { value: left.value & right.value };
          }
        }
        return null;
      },
      CallExpression(node, initialScope) {
        const calleeNode = node.callee;
        const args = getElementValues(node.arguments, initialScope);
        if (args != null) {
          if (calleeNode.type === "MemberExpression") {
            if (calleeNode.property.type === "PrivateIdentifier") {
              return null;
            }
            const object = getStaticValueR(calleeNode.object, initialScope);
            if (object != null) {
              if (object.value == null && (object.optional || node.optional)) {
                return { value: void 0, optional: true };
              }
              const property = getStaticPropertyNameValue(
                calleeNode,
                initialScope
              );
              if (property != null) {
                const receiver = object.value;
                const methodName = property.value;
                if (callAllowed.has(receiver[methodName])) {
                  return { value: receiver[methodName](...args) };
                }
                if (callPassThrough.has(receiver[methodName])) {
                  return { value: args[0] };
                }
              }
            }
          } else {
            const callee = getStaticValueR(calleeNode, initialScope);
            if (callee != null) {
              if (callee.value == null && node.optional) {
                return { value: void 0, optional: true };
              }
              const func = callee.value;
              if (callAllowed.has(func)) {
                return { value: func(...args) };
              }
              if (callPassThrough.has(func)) {
                return { value: args[0] };
              }
            }
          }
        }
        return null;
      },
      ConditionalExpression(node, initialScope) {
        const test = getStaticValueR(node.test, initialScope);
        if (test != null) {
          return test.value ? getStaticValueR(node.consequent, initialScope) : getStaticValueR(node.alternate, initialScope);
        }
        return null;
      },
      ExpressionStatement(node, initialScope) {
        return getStaticValueR(node.expression, initialScope);
      },
      Identifier(node, initialScope) {
        if (initialScope != null) {
          const variable = findVariable(initialScope, node);
          if (variable != null && variable.defs.length === 0 && builtinNames.has(variable.name) && variable.name in globalObject) {
            return { value: globalObject[variable.name] };
          }
          if (variable != null && variable.defs.length === 1) {
            const def = variable.defs[0];
            if (def.parent && def.parent.kind === "const" && // TODO(mysticatea): don't support destructuring here.
            def.node.id.type === "Identifier") {
              return getStaticValueR(def.node.init, initialScope);
            }
          }
        }
        return null;
      },
      Literal(node) {
        if ((node.regex != null || node.bigint != null) && node.value == null) {
          return null;
        }
        return { value: node.value };
      },
      LogicalExpression(node, initialScope) {
        const left = getStaticValueR(node.left, initialScope);
        if (left != null) {
          if (node.operator === "||" && Boolean(left.value) === true || node.operator === "&&" && Boolean(left.value) === false || node.operator === "??" && left.value != null) {
            return left;
          }
          const right = getStaticValueR(node.right, initialScope);
          if (right != null) {
            return right;
          }
        }
        return null;
      },
      MemberExpression(node, initialScope) {
        if (node.property.type === "PrivateIdentifier") {
          return null;
        }
        const object = getStaticValueR(node.object, initialScope);
        if (object != null) {
          if (object.value == null && (object.optional || node.optional)) {
            return { value: void 0, optional: true };
          }
          const property = getStaticPropertyNameValue(node, initialScope);
          if (property != null && !isGetter(object.value, property.value)) {
            return { value: object.value[property.value] };
          }
        }
        return null;
      },
      ChainExpression(node, initialScope) {
        const expression = getStaticValueR(node.expression, initialScope);
        if (expression != null) {
          return { value: expression.value };
        }
        return null;
      },
      NewExpression(node, initialScope) {
        const callee = getStaticValueR(node.callee, initialScope);
        const args = getElementValues(node.arguments, initialScope);
        if (callee != null && args != null) {
          const Func = callee.value;
          if (callAllowed.has(Func)) {
            return { value: new Func(...args) };
          }
        }
        return null;
      },
      ObjectExpression(node, initialScope) {
        const object = {};
        for (const propertyNode of node.properties) {
          if (propertyNode.type === "Property") {
            if (propertyNode.kind !== "init") {
              return null;
            }
            const key = getStaticPropertyNameValue(
              propertyNode,
              initialScope
            );
            const value2 = getStaticValueR(propertyNode.value, initialScope);
            if (key == null || value2 == null) {
              return null;
            }
            object[key.value] = value2.value;
          } else if (propertyNode.type === "SpreadElement" || propertyNode.type === "ExperimentalSpreadProperty") {
            const argument = getStaticValueR(
              propertyNode.argument,
              initialScope
            );
            if (argument == null) {
              return null;
            }
            Object.assign(object, argument.value);
          } else {
            return null;
          }
        }
        return { value: object };
      },
      SequenceExpression(node, initialScope) {
        const last2 = node.expressions[node.expressions.length - 1];
        return getStaticValueR(last2, initialScope);
      },
      TaggedTemplateExpression(node, initialScope) {
        const tag = getStaticValueR(node.tag, initialScope);
        const expressions = getElementValues(
          node.quasi.expressions,
          initialScope
        );
        if (tag != null && expressions != null) {
          const func = tag.value;
          const strings = node.quasi.quasis.map((q) => q.value.cooked);
          strings.raw = node.quasi.quasis.map((q) => q.value.raw);
          if (func === String.raw) {
            return { value: func(strings, ...expressions) };
          }
        }
        return null;
      },
      TemplateLiteral(node, initialScope) {
        const expressions = getElementValues(node.expressions, initialScope);
        if (expressions != null) {
          let value2 = node.quasis[0].value.cooked;
          for (let i = 0; i < expressions.length; ++i) {
            value2 += expressions[i];
            value2 += node.quasis[i + 1].value.cooked;
          }
          return { value: value2 };
        }
        return null;
      },
      UnaryExpression(node, initialScope) {
        if (node.operator === "delete") {
          return null;
        }
        if (node.operator === "void") {
          return { value: void 0 };
        }
        const arg = getStaticValueR(node.argument, initialScope);
        if (arg != null) {
          switch (node.operator) {
            case "-":
              return { value: -arg.value };
            case "+":
              return { value: +arg.value };
            case "!":
              return { value: !arg.value };
            case "~":
              return { value: ~arg.value };
            case "typeof":
              return { value: typeof arg.value };
          }
        }
        return null;
      }
    });
    function getStaticValueR(node, initialScope) {
      if (node != null && Object.hasOwnProperty.call(operations, node.type)) {
        return operations[node.type](node, initialScope);
      }
      return null;
    }
    function getStaticPropertyNameValue(node, initialScope) {
      const nameNode = node.type === "Property" ? node.key : node.property;
      if (node.computed) {
        return getStaticValueR(nameNode, initialScope);
      }
      if (nameNode.type === "Identifier") {
        return { value: nameNode.name };
      }
      if (nameNode.type === "Literal") {
        if (nameNode.bigint) {
          return { value: nameNode.bigint };
        }
        return { value: String(nameNode.value) };
      }
      return null;
    }
    function getStaticValue(node, initialScope = null) {
      try {
        return getStaticValueR(node, initialScope);
      } catch (_error) {
        return null;
      }
    }
    function getStringIfConstant(node, initialScope = null) {
      if (node && node.type === "Literal" && node.value === null) {
        if (node.regex) {
          return `/${node.regex.pattern}/${node.regex.flags}`;
        }
        if (node.bigint) {
          return node.bigint;
        }
      }
      const evaluated = getStaticValue(node, initialScope);
      return evaluated && String(evaluated.value);
    }
    function getPropertyName(node, initialScope) {
      switch (node.type) {
        case "MemberExpression":
          if (node.computed) {
            return getStringIfConstant(node.property, initialScope);
          }
          if (node.property.type === "PrivateIdentifier") {
            return null;
          }
          return node.property.name;
        case "Property":
        case "MethodDefinition":
        case "PropertyDefinition":
          if (node.computed) {
            return getStringIfConstant(node.key, initialScope);
          }
          if (node.key.type === "Literal") {
            return String(node.key.value);
          }
          if (node.key.type === "PrivateIdentifier") {
            return null;
          }
          return node.key.name;
      }
      return null;
    }
    function getFunctionNameWithKind(node, sourceCode) {
      const parent = node.parent;
      const tokens = [];
      const isObjectMethod = parent.type === "Property" && parent.value === node;
      const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
      const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
      if (isClassMethod || isClassFieldMethod) {
        if (parent.static) {
          tokens.push("static");
        }
        if (parent.key.type === "PrivateIdentifier") {
          tokens.push("private");
        }
      }
      if (node.async) {
        tokens.push("async");
      }
      if (node.generator) {
        tokens.push("generator");
      }
      if (isObjectMethod || isClassMethod) {
        if (parent.kind === "constructor") {
          return "constructor";
        }
        if (parent.kind === "get") {
          tokens.push("getter");
        } else if (parent.kind === "set") {
          tokens.push("setter");
        } else {
          tokens.push("method");
        }
      } else if (isClassFieldMethod) {
        tokens.push("method");
      } else {
        if (node.type === "ArrowFunctionExpression") {
          tokens.push("arrow");
        }
        tokens.push("function");
      }
      if (isObjectMethod || isClassMethod || isClassFieldMethod) {
        if (parent.key.type === "PrivateIdentifier") {
          tokens.push(`#${parent.key.name}`);
        } else {
          const name = getPropertyName(parent);
          if (name) {
            tokens.push(`'${name}'`);
          } else if (sourceCode) {
            const keyText = sourceCode.getText(parent.key);
            if (!keyText.includes("\n")) {
              tokens.push(`[${keyText}]`);
            }
          }
        }
      } else if (node.id) {
        tokens.push(`'${node.id.name}'`);
      } else if (parent.type === "VariableDeclarator" && parent.id && parent.id.type === "Identifier") {
        tokens.push(`'${parent.id.name}'`);
      } else if ((parent.type === "AssignmentExpression" || parent.type === "AssignmentPattern") && parent.left && parent.left.type === "Identifier") {
        tokens.push(`'${parent.left.name}'`);
      }
      return tokens.join(" ");
    }
    var typeConversionBinaryOps = Object.freeze(
      /* @__PURE__ */ new Set([
        "==",
        "!=",
        "<",
        "<=",
        ">",
        ">=",
        "<<",
        ">>",
        ">>>",
        "+",
        "-",
        "*",
        "/",
        "%",
        "|",
        "^",
        "&",
        "in"
      ])
    );
    var typeConversionUnaryOps = Object.freeze(/* @__PURE__ */ new Set(["-", "+", "!", "~"]));
    function isNode(x) {
      return x !== null && typeof x === "object" && typeof x.type === "string";
    }
    var visitor = Object.freeze(
      Object.assign(/* @__PURE__ */ Object.create(null), {
        $visit(node, options, visitorKeys) {
          const { type } = node;
          if (typeof this[type] === "function") {
            return this[type](node, options, visitorKeys);
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        $visitChildren(node, options, visitorKeys) {
          const { type } = node;
          for (const key of visitorKeys[type] || evk.getKeys(node)) {
            const value2 = node[key];
            if (Array.isArray(value2)) {
              for (const element of value2) {
                if (isNode(element) && this.$visit(element, options, visitorKeys)) {
                  return true;
                }
              }
            } else if (isNode(value2) && this.$visit(value2, options, visitorKeys)) {
              return true;
            }
          }
          return false;
        },
        ArrowFunctionExpression() {
          return false;
        },
        AssignmentExpression() {
          return true;
        },
        AwaitExpression() {
          return true;
        },
        BinaryExpression(node, options, visitorKeys) {
          if (options.considerImplicitTypeConversion && typeConversionBinaryOps.has(node.operator) && (node.left.type !== "Literal" || node.right.type !== "Literal")) {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        CallExpression() {
          return true;
        },
        FunctionExpression() {
          return false;
        },
        ImportExpression() {
          return true;
        },
        MemberExpression(node, options, visitorKeys) {
          if (options.considerGetters) {
            return true;
          }
          if (options.considerImplicitTypeConversion && node.computed && node.property.type !== "Literal") {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        MethodDefinition(node, options, visitorKeys) {
          if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        NewExpression() {
          return true;
        },
        Property(node, options, visitorKeys) {
          if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        PropertyDefinition(node, options, visitorKeys) {
          if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        UnaryExpression(node, options, visitorKeys) {
          if (node.operator === "delete") {
            return true;
          }
          if (options.considerImplicitTypeConversion && typeConversionUnaryOps.has(node.operator) && node.argument.type !== "Literal") {
            return true;
          }
          return this.$visitChildren(node, options, visitorKeys);
        },
        UpdateExpression() {
          return true;
        },
        YieldExpression() {
          return true;
        }
      })
    );
    function hasSideEffect(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
      return visitor.$visit(
        node,
        { considerGetters, considerImplicitTypeConversion },
        sourceCode.visitorKeys || evk.KEYS
      );
    }
    function getParentSyntaxParen(node, sourceCode) {
      const parent = node.parent;
      switch (parent.type) {
        case "CallExpression":
        case "NewExpression":
          if (parent.arguments.length === 1 && parent.arguments[0] === node) {
            return sourceCode.getTokenAfter(
              parent.callee,
              isOpeningParenToken
            );
          }
          return null;
        case "DoWhileStatement":
          if (parent.test === node) {
            return sourceCode.getTokenAfter(
              parent.body,
              isOpeningParenToken
            );
          }
          return null;
        case "IfStatement":
        case "WhileStatement":
          if (parent.test === node) {
            return sourceCode.getFirstToken(parent, 1);
          }
          return null;
        case "ImportExpression":
          if (parent.source === node) {
            return sourceCode.getFirstToken(parent, 1);
          }
          return null;
        case "SwitchStatement":
          if (parent.discriminant === node) {
            return sourceCode.getFirstToken(parent, 1);
          }
          return null;
        case "WithStatement":
          if (parent.object === node) {
            return sourceCode.getFirstToken(parent, 1);
          }
          return null;
        default:
          return null;
      }
    }
    function isParenthesized(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
      let times, node, sourceCode, maybeLeftParen, maybeRightParen;
      if (typeof timesOrNode === "number") {
        times = timesOrNode | 0;
        node = nodeOrSourceCode;
        sourceCode = optionalSourceCode;
        if (!(times >= 1)) {
          throw new TypeError("'times' should be a positive integer.");
        }
      } else {
        times = 1;
        node = timesOrNode;
        sourceCode = nodeOrSourceCode;
      }
      if (node == null || // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
      node.parent.type === "CatchClause" && node.parent.param === node) {
        return false;
      }
      maybeLeftParen = maybeRightParen = node;
      do {
        maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
        maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
      } while (maybeLeftParen != null && maybeRightParen != null && isOpeningParenToken(maybeLeftParen) && isClosingParenToken(maybeRightParen) && // Avoid false positive such as `if (a) {}`
      maybeLeftParen !== getParentSyntaxParen(node, sourceCode) && --times > 0);
      return times === 0;
    }
    var placeholder = /\$(?:[$&`']|[1-9][0-9]?)/gu;
    var internal = /* @__PURE__ */ new WeakMap();
    function isEscaped(str, index2) {
      let escaped = false;
      for (let i = index2 - 1; i >= 0 && str.charCodeAt(i) === 92; --i) {
        escaped = !escaped;
      }
      return escaped;
    }
    function replaceS(matcher, str, replacement) {
      const chunks = [];
      let index2 = 0;
      let match = null;
      function replacer(key) {
        switch (key) {
          case "$$":
            return "$";
          case "$&":
            return match[0];
          case "$`":
            return str.slice(0, match.index);
          case "$'":
            return str.slice(match.index + match[0].length);
          default: {
            const i = key.slice(1);
            if (i in match) {
              return match[i];
            }
            return key;
          }
        }
      }
      for (match of matcher.execAll(str)) {
        chunks.push(str.slice(index2, match.index));
        chunks.push(replacement.replace(placeholder, replacer));
        index2 = match.index + match[0].length;
      }
      chunks.push(str.slice(index2));
      return chunks.join("");
    }
    function replaceF(matcher, str, replace) {
      const chunks = [];
      let index2 = 0;
      for (const match of matcher.execAll(str)) {
        chunks.push(str.slice(index2, match.index));
        chunks.push(String(replace(...match, match.index, match.input)));
        index2 = match.index + match[0].length;
      }
      chunks.push(str.slice(index2));
      return chunks.join("");
    }
    var PatternMatcher = class {
      /**
       * Initialize this matcher.
       * @param {RegExp} pattern The pattern to match.
       * @param {{escaped:boolean}} options The options.
       */
      constructor(pattern, { escaped = false } = {}) {
        if (!(pattern instanceof RegExp)) {
          throw new TypeError("'pattern' should be a RegExp instance.");
        }
        if (!pattern.flags.includes("g")) {
          throw new Error("'pattern' should contains 'g' flag.");
        }
        internal.set(this, {
          pattern: new RegExp(pattern.source, pattern.flags),
          escaped: Boolean(escaped)
        });
      }
      /**
       * Find the pattern in a given string.
       * @param {string} str The string to find.
       * @returns {IterableIterator<RegExpExecArray>} The iterator which iterate the matched information.
       */
      *execAll(str) {
        const { pattern, escaped } = internal.get(this);
        let match = null;
        let lastIndex = 0;
        pattern.lastIndex = 0;
        while ((match = pattern.exec(str)) != null) {
          if (escaped || !isEscaped(str, match.index)) {
            lastIndex = pattern.lastIndex;
            yield match;
            pattern.lastIndex = lastIndex;
          }
        }
      }
      /**
       * Check whether the pattern is found in a given string.
       * @param {string} str The string to check.
       * @returns {boolean} `true` if the pattern was found in the string.
       */
      test(str) {
        const it2 = this.execAll(str);
        const ret = it2.next();
        return !ret.done;
      }
      /**
       * Replace a given string.
       * @param {string} str The string to be replaced.
       * @param {(string|((...strs:string[])=>string))} replacer The string or function to replace. This is the same as the 2nd argument of `String.prototype.replace`.
       * @returns {string} The replaced string.
       */
      [Symbol.replace](str, replacer) {
        return typeof replacer === "function" ? replaceF(this, String(str), replacer) : replaceS(this, String(str), String(replacer));
      }
    };
    var IMPORT_TYPE = /^(?:Import|Export(?:All|Default|Named))Declaration$/u;
    var has = Function.call.bind(Object.hasOwnProperty);
    var READ = Symbol("read");
    var CALL = Symbol("call");
    var CONSTRUCT = Symbol("construct");
    var ESM = Symbol("esm");
    var requireCall = { require: { [CALL]: true } };
    function isModifiedGlobal(variable) {
      return variable == null || variable.defs.length !== 0 || variable.references.some((r) => r.isWrite());
    }
    function isPassThrough(node) {
      const parent = node.parent;
      switch (parent && parent.type) {
        case "ConditionalExpression":
          return parent.consequent === node || parent.alternate === node;
        case "LogicalExpression":
          return true;
        case "SequenceExpression":
          return parent.expressions[parent.expressions.length - 1] === node;
        case "ChainExpression":
          return true;
        default:
          return false;
      }
    }
    var ReferenceTracker = class {
      /**
       * Initialize this tracker.
       * @param {Scope} globalScope The global scope.
       * @param {object} [options] The options.
       * @param {"legacy"|"strict"} [options.mode="strict"] The mode to determine the ImportDeclaration's behavior for CJS modules.
       * @param {string[]} [options.globalObjectNames=["global","globalThis","self","window"]] The variable names for Global Object.
       */
      constructor(globalScope, {
        mode = "strict",
        globalObjectNames = ["global", "globalThis", "self", "window"]
      } = {}) {
        this.variableStack = [];
        this.globalScope = globalScope;
        this.mode = mode;
        this.globalObjectNames = globalObjectNames.slice(0);
      }
      /**
       * Iterate the references of global variables.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *iterateGlobalReferences(traceMap) {
        for (const key of Object.keys(traceMap)) {
          const nextTraceMap = traceMap[key];
          const path2 = [key];
          const variable = this.globalScope.set.get(key);
          if (isModifiedGlobal(variable)) {
            continue;
          }
          yield* this._iterateVariableReferences(
            variable,
            path2,
            nextTraceMap,
            true
          );
        }
        for (const key of this.globalObjectNames) {
          const path2 = [];
          const variable = this.globalScope.set.get(key);
          if (isModifiedGlobal(variable)) {
            continue;
          }
          yield* this._iterateVariableReferences(
            variable,
            path2,
            traceMap,
            false
          );
        }
      }
      /**
       * Iterate the references of CommonJS modules.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *iterateCjsReferences(traceMap) {
        for (const { node } of this.iterateGlobalReferences(requireCall)) {
          const key = getStringIfConstant(node.arguments[0]);
          if (key == null || !has(traceMap, key)) {
            continue;
          }
          const nextTraceMap = traceMap[key];
          const path2 = [key];
          if (nextTraceMap[READ]) {
            yield {
              node,
              path: path2,
              type: READ,
              info: nextTraceMap[READ]
            };
          }
          yield* this._iteratePropertyReferences(node, path2, nextTraceMap);
        }
      }
      /**
       * Iterate the references of ES modules.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *iterateEsmReferences(traceMap) {
        const programNode = this.globalScope.block;
        for (const node of programNode.body) {
          if (!IMPORT_TYPE.test(node.type) || node.source == null) {
            continue;
          }
          const moduleId = node.source.value;
          if (!has(traceMap, moduleId)) {
            continue;
          }
          const nextTraceMap = traceMap[moduleId];
          const path2 = [moduleId];
          if (nextTraceMap[READ]) {
            yield { node, path: path2, type: READ, info: nextTraceMap[READ] };
          }
          if (node.type === "ExportAllDeclaration") {
            for (const key of Object.keys(nextTraceMap)) {
              const exportTraceMap = nextTraceMap[key];
              if (exportTraceMap[READ]) {
                yield {
                  node,
                  path: path2.concat(key),
                  type: READ,
                  info: exportTraceMap[READ]
                };
              }
            }
          } else {
            for (const specifier of node.specifiers) {
              const esm = has(nextTraceMap, ESM);
              const it2 = this._iterateImportReferences(
                specifier,
                path2,
                esm ? nextTraceMap : this.mode === "legacy" ? { default: nextTraceMap, ...nextTraceMap } : { default: nextTraceMap }
              );
              if (esm) {
                yield* it2;
              } else {
                for (const report of it2) {
                  report.path = report.path.filter(exceptDefault);
                  if (report.path.length >= 2 || report.type !== READ) {
                    yield report;
                  }
                }
              }
            }
          }
        }
      }
      /**
       * Iterate the references for a given variable.
       * @param {Variable} variable The variable to iterate that references.
       * @param {string[]} path The current path.
       * @param {object} traceMap The trace map.
       * @param {boolean} shouldReport = The flag to report those references.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *_iterateVariableReferences(variable, path2, traceMap, shouldReport) {
        if (this.variableStack.includes(variable)) {
          return;
        }
        this.variableStack.push(variable);
        try {
          for (const reference of variable.references) {
            if (!reference.isRead()) {
              continue;
            }
            const node = reference.identifier;
            if (shouldReport && traceMap[READ]) {
              yield { node, path: path2, type: READ, info: traceMap[READ] };
            }
            yield* this._iteratePropertyReferences(node, path2, traceMap);
          }
        } finally {
          this.variableStack.pop();
        }
      }
      /**
       * Iterate the references for a given AST node.
       * @param rootNode The AST node to iterate references.
       * @param {string[]} path The current path.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      //eslint-disable-next-line complexity
      *_iteratePropertyReferences(rootNode, path2, traceMap) {
        let node = rootNode;
        while (isPassThrough(node)) {
          node = node.parent;
        }
        const parent = node.parent;
        if (parent.type === "MemberExpression") {
          if (parent.object === node) {
            const key = getPropertyName(parent);
            if (key == null || !has(traceMap, key)) {
              return;
            }
            path2 = path2.concat(key);
            const nextTraceMap = traceMap[key];
            if (nextTraceMap[READ]) {
              yield {
                node: parent,
                path: path2,
                type: READ,
                info: nextTraceMap[READ]
              };
            }
            yield* this._iteratePropertyReferences(
              parent,
              path2,
              nextTraceMap
            );
          }
          return;
        }
        if (parent.type === "CallExpression") {
          if (parent.callee === node && traceMap[CALL]) {
            yield { node: parent, path: path2, type: CALL, info: traceMap[CALL] };
          }
          return;
        }
        if (parent.type === "NewExpression") {
          if (parent.callee === node && traceMap[CONSTRUCT]) {
            yield {
              node: parent,
              path: path2,
              type: CONSTRUCT,
              info: traceMap[CONSTRUCT]
            };
          }
          return;
        }
        if (parent.type === "AssignmentExpression") {
          if (parent.right === node) {
            yield* this._iterateLhsReferences(parent.left, path2, traceMap);
            yield* this._iteratePropertyReferences(parent, path2, traceMap);
          }
          return;
        }
        if (parent.type === "AssignmentPattern") {
          if (parent.right === node) {
            yield* this._iterateLhsReferences(parent.left, path2, traceMap);
          }
          return;
        }
        if (parent.type === "VariableDeclarator") {
          if (parent.init === node) {
            yield* this._iterateLhsReferences(parent.id, path2, traceMap);
          }
        }
      }
      /**
       * Iterate the references for a given Pattern node.
       * @param {Node} patternNode The Pattern node to iterate references.
       * @param {string[]} path The current path.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *_iterateLhsReferences(patternNode, path2, traceMap) {
        if (patternNode.type === "Identifier") {
          const variable = findVariable(this.globalScope, patternNode);
          if (variable != null) {
            yield* this._iterateVariableReferences(
              variable,
              path2,
              traceMap,
              false
            );
          }
          return;
        }
        if (patternNode.type === "ObjectPattern") {
          for (const property of patternNode.properties) {
            const key = getPropertyName(property);
            if (key == null || !has(traceMap, key)) {
              continue;
            }
            const nextPath = path2.concat(key);
            const nextTraceMap = traceMap[key];
            if (nextTraceMap[READ]) {
              yield {
                node: property,
                path: nextPath,
                type: READ,
                info: nextTraceMap[READ]
              };
            }
            yield* this._iterateLhsReferences(
              property.value,
              nextPath,
              nextTraceMap
            );
          }
          return;
        }
        if (patternNode.type === "AssignmentPattern") {
          yield* this._iterateLhsReferences(patternNode.left, path2, traceMap);
        }
      }
      /**
       * Iterate the references for a given ModuleSpecifier node.
       * @param {Node} specifierNode The ModuleSpecifier node to iterate references.
       * @param {string[]} path The current path.
       * @param {object} traceMap The trace map.
       * @returns {IterableIterator<{node:Node,path:string[],type:symbol,info:any}>} The iterator to iterate references.
       */
      *_iterateImportReferences(specifierNode, path2, traceMap) {
        const type = specifierNode.type;
        if (type === "ImportSpecifier" || type === "ImportDefaultSpecifier") {
          const key = type === "ImportDefaultSpecifier" ? "default" : specifierNode.imported.name;
          if (!has(traceMap, key)) {
            return;
          }
          path2 = path2.concat(key);
          const nextTraceMap = traceMap[key];
          if (nextTraceMap[READ]) {
            yield {
              node: specifierNode,
              path: path2,
              type: READ,
              info: nextTraceMap[READ]
            };
          }
          yield* this._iterateVariableReferences(
            findVariable(this.globalScope, specifierNode.local),
            path2,
            nextTraceMap,
            false
          );
          return;
        }
        if (type === "ImportNamespaceSpecifier") {
          yield* this._iterateVariableReferences(
            findVariable(this.globalScope, specifierNode.local),
            path2,
            traceMap,
            false
          );
          return;
        }
        if (type === "ExportSpecifier") {
          const key = specifierNode.local.name;
          if (!has(traceMap, key)) {
            return;
          }
          path2 = path2.concat(key);
          const nextTraceMap = traceMap[key];
          if (nextTraceMap[READ]) {
            yield {
              node: specifierNode,
              path: path2,
              type: READ,
              info: nextTraceMap[READ]
            };
          }
        }
      }
    };
    ReferenceTracker.READ = READ;
    ReferenceTracker.CALL = CALL;
    ReferenceTracker.CONSTRUCT = CONSTRUCT;
    ReferenceTracker.ESM = ESM;
    function exceptDefault(name, index2) {
      return !(index2 === 1 && name === "default");
    }
    var index = {
      CALL,
      CONSTRUCT,
      ESM,
      findVariable,
      getFunctionHeadLocation,
      getFunctionNameWithKind,
      getInnermostScope,
      getPropertyName,
      getStaticValue,
      getStringIfConstant,
      hasSideEffect,
      isArrowToken,
      isClosingBraceToken,
      isClosingBracketToken,
      isClosingParenToken,
      isColonToken,
      isCommaToken,
      isCommentToken,
      isNotArrowToken,
      isNotClosingBraceToken,
      isNotClosingBracketToken,
      isNotClosingParenToken,
      isNotColonToken,
      isNotCommaToken,
      isNotCommentToken,
      isNotOpeningBraceToken,
      isNotOpeningBracketToken,
      isNotOpeningParenToken,
      isNotSemicolonToken,
      isOpeningBraceToken,
      isOpeningBracketToken,
      isOpeningParenToken,
      isParenthesized,
      isSemicolonToken,
      PatternMatcher,
      READ,
      ReferenceTracker
    };
    exports.CALL = CALL;
    exports.CONSTRUCT = CONSTRUCT;
    exports.ESM = ESM;
    exports.PatternMatcher = PatternMatcher;
    exports.READ = READ;
    exports.ReferenceTracker = ReferenceTracker;
    exports.default = index;
    exports.findVariable = findVariable;
    exports.getFunctionHeadLocation = getFunctionHeadLocation;
    exports.getFunctionNameWithKind = getFunctionNameWithKind;
    exports.getInnermostScope = getInnermostScope;
    exports.getPropertyName = getPropertyName;
    exports.getStaticValue = getStaticValue;
    exports.getStringIfConstant = getStringIfConstant;
    exports.hasSideEffect = hasSideEffect;
    exports.isArrowToken = isArrowToken;
    exports.isClosingBraceToken = isClosingBraceToken;
    exports.isClosingBracketToken = isClosingBracketToken;
    exports.isClosingParenToken = isClosingParenToken;
    exports.isColonToken = isColonToken;
    exports.isCommaToken = isCommaToken;
    exports.isCommentToken = isCommentToken;
    exports.isNotArrowToken = isNotArrowToken;
    exports.isNotClosingBraceToken = isNotClosingBraceToken;
    exports.isNotClosingBracketToken = isNotClosingBracketToken;
    exports.isNotClosingParenToken = isNotClosingParenToken;
    exports.isNotColonToken = isNotColonToken;
    exports.isNotCommaToken = isNotCommaToken;
    exports.isNotCommentToken = isNotCommentToken;
    exports.isNotOpeningBraceToken = isNotOpeningBraceToken;
    exports.isNotOpeningBracketToken = isNotOpeningBracketToken;
    exports.isNotOpeningParenToken = isNotOpeningParenToken;
    exports.isNotSemicolonToken = isNotSemicolonToken;
    exports.isOpeningBraceToken = isOpeningBraceToken;
    exports.isOpeningBracketToken = isOpeningBracketToken;
    exports.isOpeningParenToken = isOpeningParenToken;
    exports.isParenthesized = isParenthesized;
    exports.isSemicolonToken = isSemicolonToken;
  }
});

// node_modules/eslint/lib/rules/no-extra-boolean-cast.js
var require_no_extra_boolean_cast = __commonJS({
  "node_modules/eslint/lib/rules/no-extra-boolean-cast.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var eslintUtils = require_eslint_utils();
    var precedence = astUtils.getPrecedence;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary boolean casts",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-extra-boolean-cast"
        },
        schema: [{
          type: "object",
          properties: {
            enforceForLogicalOperands: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        fixable: "code",
        messages: {
          unexpectedCall: "Redundant Boolean call.",
          unexpectedNegation: "Redundant double negation."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const BOOLEAN_NODE_TYPES = /* @__PURE__ */ new Set([
          "IfStatement",
          "DoWhileStatement",
          "WhileStatement",
          "ConditionalExpression",
          "ForStatement"
        ]);
        function isBooleanFunctionOrConstructorCall(node) {
          return (node.type === "CallExpression" || node.type === "NewExpression") && node.callee.type === "Identifier" && node.callee.name === "Boolean";
        }
        function isLogicalContext(node) {
          return node.type === "LogicalExpression" && (node.operator === "||" || node.operator === "&&") && (context.options.length && context.options[0].enforceForLogicalOperands === true);
        }
        function isInBooleanContext(node) {
          return isBooleanFunctionOrConstructorCall(node.parent) && node === node.parent.arguments[0] || BOOLEAN_NODE_TYPES.has(node.parent.type) && node === node.parent.test || // !<bool>
          node.parent.type === "UnaryExpression" && node.parent.operator === "!";
        }
        function isInFlaggedContext(node) {
          if (node.parent.type === "ChainExpression") {
            return isInFlaggedContext(node.parent);
          }
          return isInBooleanContext(node) || isLogicalContext(node.parent) && // For nested logical statements
          isInFlaggedContext(node.parent);
        }
        function hasCommentsInside(node) {
          return Boolean(sourceCode.getCommentsInside(node).length);
        }
        function isParenthesized(node) {
          return eslintUtils.isParenthesized(1, node, sourceCode);
        }
        function needsParens(previousNode, node) {
          if (previousNode.parent.type === "ChainExpression") {
            return needsParens(previousNode.parent, node);
          }
          if (isParenthesized(previousNode)) {
            return false;
          }
          const parent = previousNode.parent;
          switch (parent.type) {
            case "CallExpression":
            case "NewExpression":
              return node.type === "SequenceExpression";
            case "IfStatement":
            case "DoWhileStatement":
            case "WhileStatement":
            case "ForStatement":
              return false;
            case "ConditionalExpression":
              return precedence(node) <= precedence(parent);
            case "UnaryExpression":
              return precedence(node) < precedence(parent);
            case "LogicalExpression":
              if (astUtils.isMixedLogicalAndCoalesceExpressions(node, parent)) {
                return true;
              }
              if (previousNode === parent.left) {
                return precedence(node) < precedence(parent);
              }
              return precedence(node) <= precedence(parent);
            default:
              throw new Error(`Unexpected parent type: ${parent.type}`);
          }
        }
        return {
          UnaryExpression(node) {
            const parent = node.parent;
            if (node.operator !== "!" || parent.type !== "UnaryExpression" || parent.operator !== "!") {
              return;
            }
            if (isInFlaggedContext(parent)) {
              context.report({
                node: parent,
                messageId: "unexpectedNegation",
                fix(fixer) {
                  if (hasCommentsInside(parent)) {
                    return null;
                  }
                  if (needsParens(parent, node.argument)) {
                    return fixer.replaceText(parent, `(${sourceCode.getText(node.argument)})`);
                  }
                  let prefix = "";
                  const tokenBefore = sourceCode.getTokenBefore(parent);
                  const firstReplacementToken = sourceCode.getFirstToken(node.argument);
                  if (tokenBefore && tokenBefore.range[1] === parent.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, firstReplacementToken)) {
                    prefix = " ";
                  }
                  return fixer.replaceText(parent, prefix + sourceCode.getText(node.argument));
                }
              });
            }
          },
          CallExpression(node) {
            if (node.callee.type !== "Identifier" || node.callee.name !== "Boolean") {
              return;
            }
            if (isInFlaggedContext(node)) {
              context.report({
                node,
                messageId: "unexpectedCall",
                fix(fixer) {
                  const parent = node.parent;
                  if (node.arguments.length === 0) {
                    if (parent.type === "UnaryExpression" && parent.operator === "!") {
                      if (hasCommentsInside(parent)) {
                        return null;
                      }
                      const replacement = "true";
                      let prefix = "";
                      const tokenBefore = sourceCode.getTokenBefore(parent);
                      if (tokenBefore && tokenBefore.range[1] === parent.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, replacement)) {
                        prefix = " ";
                      }
                      return fixer.replaceText(parent, prefix + replacement);
                    }
                    if (hasCommentsInside(node)) {
                      return null;
                    }
                    return fixer.replaceText(node, "false");
                  }
                  if (node.arguments.length === 1) {
                    const argument = node.arguments[0];
                    if (argument.type === "SpreadElement" || hasCommentsInside(node)) {
                      return null;
                    }
                    if (needsParens(node, argument)) {
                      return fixer.replaceText(node, `(${sourceCode.getText(argument)})`);
                    }
                    return fixer.replaceText(node, sourceCode.getText(argument));
                  }
                  return null;
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-extra-label.js
var require_no_extra_label = __commonJS({
  "node_modules/eslint/lib/rules/no-extra-label.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary labels",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-extra-label"
        },
        schema: [],
        fixable: "code",
        messages: {
          unexpected: "This label '{{name}}' is unnecessary."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let scopeInfo = null;
        function enterBreakableStatement(node) {
          scopeInfo = {
            label: node.parent.type === "LabeledStatement" ? node.parent.label : null,
            breakable: true,
            upper: scopeInfo
          };
        }
        function exitBreakableStatement() {
          scopeInfo = scopeInfo.upper;
        }
        function enterLabeledStatement(node) {
          if (!astUtils.isBreakableStatement(node.body)) {
            scopeInfo = {
              label: node.label,
              breakable: false,
              upper: scopeInfo
            };
          }
        }
        function exitLabeledStatement(node) {
          if (!astUtils.isBreakableStatement(node.body)) {
            scopeInfo = scopeInfo.upper;
          }
        }
        function reportIfUnnecessary(node) {
          if (!node.label) {
            return;
          }
          const labelNode = node.label;
          for (let info = scopeInfo; info !== null; info = info.upper) {
            if (info.breakable || info.label && info.label.name === labelNode.name) {
              if (info.breakable && info.label && info.label.name === labelNode.name) {
                context.report({
                  node: labelNode,
                  messageId: "unexpected",
                  data: labelNode,
                  fix(fixer) {
                    const breakOrContinueToken = sourceCode.getFirstToken(node);
                    if (sourceCode.commentsExistBetween(breakOrContinueToken, labelNode)) {
                      return null;
                    }
                    return fixer.removeRange([breakOrContinueToken.range[1], labelNode.range[1]]);
                  }
                });
              }
              return;
            }
          }
        }
        return {
          WhileStatement: enterBreakableStatement,
          "WhileStatement:exit": exitBreakableStatement,
          DoWhileStatement: enterBreakableStatement,
          "DoWhileStatement:exit": exitBreakableStatement,
          ForStatement: enterBreakableStatement,
          "ForStatement:exit": exitBreakableStatement,
          ForInStatement: enterBreakableStatement,
          "ForInStatement:exit": exitBreakableStatement,
          ForOfStatement: enterBreakableStatement,
          "ForOfStatement:exit": exitBreakableStatement,
          SwitchStatement: enterBreakableStatement,
          "SwitchStatement:exit": exitBreakableStatement,
          LabeledStatement: enterLabeledStatement,
          "LabeledStatement:exit": exitLabeledStatement,
          BreakStatement: reportIfUnnecessary,
          ContinueStatement: reportIfUnnecessary
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-extra-parens.js
var require_no_extra_parens = __commonJS({
  "node_modules/eslint/lib/rules/no-extra-parens.js"(exports, module2) {
    "use strict";
    var { isParenthesized: isParenthesizedRaw } = require_eslint_utils();
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow unnecessary parentheses",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-extra-parens"
        },
        fixable: "code",
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["functions"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["all"]
                },
                {
                  type: "object",
                  properties: {
                    conditionalAssign: { type: "boolean" },
                    nestedBinaryExpressions: { type: "boolean" },
                    returnAssign: { type: "boolean" },
                    ignoreJSX: { enum: ["none", "all", "single-line", "multi-line"] },
                    enforceForArrowConditionals: { type: "boolean" },
                    enforceForSequenceExpressions: { type: "boolean" },
                    enforceForNewInMemberExpressions: { type: "boolean" },
                    enforceForFunctionPrototypeMethods: { type: "boolean" },
                    allowParensAfterCommentPattern: { type: "string" }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        messages: {
          unexpected: "Unnecessary parentheses around expression."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const tokensToIgnore = /* @__PURE__ */ new WeakSet();
        const precedence = astUtils.getPrecedence;
        const ALL_NODES = context.options[0] !== "functions";
        const EXCEPT_COND_ASSIGN = ALL_NODES && context.options[1] && context.options[1].conditionalAssign === false;
        const NESTED_BINARY = ALL_NODES && context.options[1] && context.options[1].nestedBinaryExpressions === false;
        const EXCEPT_RETURN_ASSIGN = ALL_NODES && context.options[1] && context.options[1].returnAssign === false;
        const IGNORE_JSX = ALL_NODES && context.options[1] && context.options[1].ignoreJSX;
        const IGNORE_ARROW_CONDITIONALS = ALL_NODES && context.options[1] && context.options[1].enforceForArrowConditionals === false;
        const IGNORE_SEQUENCE_EXPRESSIONS = ALL_NODES && context.options[1] && context.options[1].enforceForSequenceExpressions === false;
        const IGNORE_NEW_IN_MEMBER_EXPR = ALL_NODES && context.options[1] && context.options[1].enforceForNewInMemberExpressions === false;
        const IGNORE_FUNCTION_PROTOTYPE_METHODS = ALL_NODES && context.options[1] && context.options[1].enforceForFunctionPrototypeMethods === false;
        const ALLOW_PARENS_AFTER_COMMENT_PATTERN = ALL_NODES && context.options[1] && context.options[1].allowParensAfterCommentPattern;
        const PRECEDENCE_OF_ASSIGNMENT_EXPR = precedence({ type: "AssignmentExpression" });
        const PRECEDENCE_OF_UPDATE_EXPR = precedence({ type: "UpdateExpression" });
        let reportsBuffer;
        function isImmediateFunctionPrototypeMethodCall(node) {
          const callNode = astUtils.skipChainExpression(node);
          if (callNode.type !== "CallExpression") {
            return false;
          }
          const callee = astUtils.skipChainExpression(callNode.callee);
          return callee.type === "MemberExpression" && callee.object.type === "FunctionExpression" && ["call", "apply"].includes(astUtils.getStaticPropertyName(callee));
        }
        function ruleApplies(node) {
          if (node.type === "JSXElement" || node.type === "JSXFragment") {
            const isSingleLine = node.loc.start.line === node.loc.end.line;
            switch (IGNORE_JSX) {
              case "all":
                return false;
              case "multi-line":
                return isSingleLine;
              case "single-line":
                return !isSingleLine;
              case "none":
                break;
            }
          }
          if (node.type === "SequenceExpression" && IGNORE_SEQUENCE_EXPRESSIONS) {
            return false;
          }
          if (isImmediateFunctionPrototypeMethodCall(node) && IGNORE_FUNCTION_PROTOTYPE_METHODS) {
            return false;
          }
          return ALL_NODES || node.type === "FunctionExpression" || node.type === "ArrowFunctionExpression";
        }
        function isParenthesised(node) {
          return isParenthesizedRaw(1, node, sourceCode);
        }
        function isParenthesisedTwice(node) {
          return isParenthesizedRaw(2, node, sourceCode);
        }
        function hasExcessParens(node) {
          return ruleApplies(node) && isParenthesised(node);
        }
        function hasDoubleExcessParens(node) {
          return ruleApplies(node) && isParenthesisedTwice(node);
        }
        function hasExcessParensWithPrecedence(node, precedenceLowerLimit) {
          if (ruleApplies(node) && isParenthesised(node)) {
            if (precedence(node) >= precedenceLowerLimit || isParenthesisedTwice(node)) {
              return true;
            }
          }
          return false;
        }
        function isCondAssignException(node) {
          return EXCEPT_COND_ASSIGN && node.test.type === "AssignmentExpression";
        }
        function isInReturnStatement(node) {
          for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
            if (currentNode.type === "ReturnStatement" || currentNode.type === "ArrowFunctionExpression" && currentNode.body.type !== "BlockStatement") {
              return true;
            }
          }
          return false;
        }
        function isNewExpressionWithParens(newExpression) {
          const lastToken = sourceCode.getLastToken(newExpression);
          const penultimateToken = sourceCode.getTokenBefore(lastToken);
          return newExpression.arguments.length > 0 || // The expression should end with its own parens, e.g., new new foo() is not a new expression with parens
          astUtils.isOpeningParenToken(penultimateToken) && astUtils.isClosingParenToken(lastToken) && newExpression.callee.range[1] < newExpression.range[1];
        }
        function containsAssignment(node) {
          if (node.type === "AssignmentExpression") {
            return true;
          }
          if (node.type === "ConditionalExpression" && (node.consequent.type === "AssignmentExpression" || node.alternate.type === "AssignmentExpression")) {
            return true;
          }
          if (node.left && node.left.type === "AssignmentExpression" || node.right && node.right.type === "AssignmentExpression") {
            return true;
          }
          return false;
        }
        function isReturnAssignException(node) {
          if (!EXCEPT_RETURN_ASSIGN || !isInReturnStatement(node)) {
            return false;
          }
          if (node.type === "ReturnStatement") {
            return node.argument && containsAssignment(node.argument);
          }
          if (node.type === "ArrowFunctionExpression" && node.body.type !== "BlockStatement") {
            return containsAssignment(node.body);
          }
          return containsAssignment(node);
        }
        function hasExcessParensNoLineTerminator(token, node) {
          if (token.loc.end.line === node.loc.start.line) {
            return hasExcessParens(node);
          }
          return hasDoubleExcessParens(node);
        }
        function requiresLeadingSpace(node) {
          const leftParenToken = sourceCode.getTokenBefore(node);
          const tokenBeforeLeftParen = sourceCode.getTokenBefore(leftParenToken, { includeComments: true });
          const tokenAfterLeftParen = sourceCode.getTokenAfter(leftParenToken, { includeComments: true });
          return tokenBeforeLeftParen && tokenBeforeLeftParen.range[1] === leftParenToken.range[0] && leftParenToken.range[1] === tokenAfterLeftParen.range[0] && !astUtils.canTokensBeAdjacent(tokenBeforeLeftParen, tokenAfterLeftParen);
        }
        function requiresTrailingSpace(node) {
          const nextTwoTokens = sourceCode.getTokensAfter(node, { count: 2 });
          const rightParenToken = nextTwoTokens[0];
          const tokenAfterRightParen = nextTwoTokens[1];
          const tokenBeforeRightParen = sourceCode.getLastToken(node);
          return rightParenToken && tokenAfterRightParen && !sourceCode.isSpaceBetweenTokens(rightParenToken, tokenAfterRightParen) && !astUtils.canTokensBeAdjacent(tokenBeforeRightParen, tokenAfterRightParen);
        }
        function isIIFE(node) {
          const maybeCallNode = astUtils.skipChainExpression(node);
          return maybeCallNode.type === "CallExpression" && maybeCallNode.callee.type === "FunctionExpression";
        }
        function canBeAssignmentTarget(node) {
          return node && (node.type === "Identifier" || node.type === "MemberExpression");
        }
        function report(node) {
          const leftParenToken = sourceCode.getTokenBefore(node);
          const rightParenToken = sourceCode.getTokenAfter(node);
          if (!isParenthesisedTwice(node)) {
            if (tokensToIgnore.has(sourceCode.getFirstToken(node))) {
              return;
            }
            if (isIIFE(node) && !isParenthesised(node.callee)) {
              return;
            }
            if (ALLOW_PARENS_AFTER_COMMENT_PATTERN) {
              const commentsBeforeLeftParenToken = sourceCode.getCommentsBefore(leftParenToken);
              const totalCommentsBeforeLeftParenTokenCount = commentsBeforeLeftParenToken.length;
              const ignorePattern = new RegExp(ALLOW_PARENS_AFTER_COMMENT_PATTERN, "u");
              if (totalCommentsBeforeLeftParenTokenCount > 0 && ignorePattern.test(commentsBeforeLeftParenToken[totalCommentsBeforeLeftParenTokenCount - 1].value)) {
                return;
              }
            }
          }
          function finishReport() {
            context.report({
              node,
              loc: leftParenToken.loc,
              messageId: "unexpected",
              fix(fixer) {
                const parenthesizedSource = sourceCode.text.slice(leftParenToken.range[1], rightParenToken.range[0]);
                return fixer.replaceTextRange([
                  leftParenToken.range[0],
                  rightParenToken.range[1]
                ], (requiresLeadingSpace(node) ? " " : "") + parenthesizedSource + (requiresTrailingSpace(node) ? " " : ""));
              }
            });
          }
          if (reportsBuffer) {
            reportsBuffer.reports.push({ node, finishReport });
            return;
          }
          finishReport();
        }
        function checkArgumentWithPrecedence(node) {
          if (hasExcessParensWithPrecedence(node.argument, precedence(node))) {
            report(node.argument);
          }
        }
        function doesMemberExpressionContainCallExpression(node) {
          let currentNode = node.object;
          let currentNodeType = node.object.type;
          while (currentNodeType === "MemberExpression") {
            currentNode = currentNode.object;
            currentNodeType = currentNode.type;
          }
          return currentNodeType === "CallExpression";
        }
        function checkCallNew(node) {
          const callee = node.callee;
          if (hasExcessParensWithPrecedence(callee, precedence(node))) {
            if (hasDoubleExcessParens(callee) || !(isIIFE(node) || // (new A)(); new (new A)();
            callee.type === "NewExpression" && !isNewExpressionWithParens(callee) && !(node.type === "NewExpression" && !isNewExpressionWithParens(node)) || // new (a().b)(); new (a.b().c);
            node.type === "NewExpression" && callee.type === "MemberExpression" && doesMemberExpressionContainCallExpression(callee) || // (a?.b)(); (a?.())();
            !node.optional && callee.type === "ChainExpression")) {
              report(node.callee);
            }
          }
          node.arguments.filter((arg) => hasExcessParensWithPrecedence(arg, PRECEDENCE_OF_ASSIGNMENT_EXPR)).forEach(report);
        }
        function checkBinaryLogical(node) {
          const prec = precedence(node);
          const leftPrecedence = precedence(node.left);
          const rightPrecedence = precedence(node.right);
          const isExponentiation = node.operator === "**";
          const shouldSkipLeft = NESTED_BINARY && (node.left.type === "BinaryExpression" || node.left.type === "LogicalExpression");
          const shouldSkipRight = NESTED_BINARY && (node.right.type === "BinaryExpression" || node.right.type === "LogicalExpression");
          if (!shouldSkipLeft && hasExcessParens(node.left)) {
            if (!(["AwaitExpression", "UnaryExpression"].includes(node.left.type) && isExponentiation) && !astUtils.isMixedLogicalAndCoalesceExpressions(node.left, node) && (leftPrecedence > prec || leftPrecedence === prec && !isExponentiation) || isParenthesisedTwice(node.left)) {
              report(node.left);
            }
          }
          if (!shouldSkipRight && hasExcessParens(node.right)) {
            if (!astUtils.isMixedLogicalAndCoalesceExpressions(node.right, node) && (rightPrecedence > prec || rightPrecedence === prec && isExponentiation) || isParenthesisedTwice(node.right)) {
              report(node.right);
            }
          }
        }
        function checkClass(node) {
          if (!node.superClass) {
            return;
          }
          const hasExtraParens = precedence(node.superClass) > PRECEDENCE_OF_UPDATE_EXPR ? hasExcessParens(node.superClass) : hasDoubleExcessParens(node.superClass);
          if (hasExtraParens) {
            report(node.superClass);
          }
        }
        function checkSpreadOperator(node) {
          if (hasExcessParensWithPrecedence(node.argument, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
            report(node.argument);
          }
        }
        function checkExpressionOrExportStatement(node) {
          const firstToken = isParenthesised(node) ? sourceCode.getTokenBefore(node) : sourceCode.getFirstToken(node);
          const secondToken = sourceCode.getTokenAfter(firstToken, astUtils.isNotOpeningParenToken);
          const thirdToken = secondToken ? sourceCode.getTokenAfter(secondToken) : null;
          const tokenAfterClosingParens = secondToken ? sourceCode.getTokenAfter(secondToken, astUtils.isNotClosingParenToken) : null;
          if (astUtils.isOpeningParenToken(firstToken) && (astUtils.isOpeningBraceToken(secondToken) || secondToken.type === "Keyword" && (secondToken.value === "function" || secondToken.value === "class" || secondToken.value === "let" && tokenAfterClosingParens && (astUtils.isOpeningBracketToken(tokenAfterClosingParens) || tokenAfterClosingParens.type === "Identifier")) || secondToken && secondToken.type === "Identifier" && secondToken.value === "async" && thirdToken && thirdToken.type === "Keyword" && thirdToken.value === "function")) {
            tokensToIgnore.add(secondToken);
          }
          const hasExtraParens = node.parent.type === "ExportDefaultDeclaration" ? hasExcessParensWithPrecedence(node, PRECEDENCE_OF_ASSIGNMENT_EXPR) : hasExcessParens(node);
          if (hasExtraParens) {
            report(node);
          }
        }
        function pathToAncestor(node, ancestor) {
          const path2 = [node];
          let currentNode = node;
          while (currentNode !== ancestor) {
            currentNode = currentNode.parent;
            if (currentNode === null) {
              throw new Error("Nodes are not in the ancestor-descendant relationship.");
            }
            path2.push(currentNode);
          }
          return path2;
        }
        function pathToDescendant(node, descendant) {
          return pathToAncestor(descendant, node).reverse();
        }
        function isSafelyEnclosingInExpression(node, child) {
          switch (node.type) {
            case "ArrayExpression":
            case "ArrayPattern":
            case "BlockStatement":
            case "ObjectExpression":
            case "ObjectPattern":
            case "TemplateLiteral":
              return true;
            case "ArrowFunctionExpression":
            case "FunctionExpression":
              return node.params.includes(child);
            case "CallExpression":
            case "NewExpression":
              return node.arguments.includes(child);
            case "MemberExpression":
              return node.computed && node.property === child;
            case "ConditionalExpression":
              return node.consequent === child;
            default:
              return false;
          }
        }
        function startNewReportsBuffering() {
          reportsBuffer = {
            upper: reportsBuffer,
            inExpressionNodes: [],
            reports: []
          };
        }
        function endCurrentReportsBuffering() {
          const { upper, inExpressionNodes, reports } = reportsBuffer;
          if (upper) {
            upper.inExpressionNodes.push(...inExpressionNodes);
            upper.reports.push(...reports);
          } else {
            reports.forEach(({ finishReport }) => finishReport());
          }
          reportsBuffer = upper;
        }
        function isInCurrentReportsBuffer(node) {
          return reportsBuffer.reports.some((r) => r.node === node);
        }
        function removeFromCurrentReportsBuffer(node) {
          reportsBuffer.reports = reportsBuffer.reports.filter((r) => r.node !== node);
        }
        function isMemberExpInNewCallee(node) {
          if (node.type === "MemberExpression") {
            return node.parent.type === "NewExpression" && node.parent.callee === node ? true : node.parent.object === node && isMemberExpInNewCallee(node.parent);
          }
          return false;
        }
        return {
          ArrayExpression(node) {
            node.elements.filter((e) => e && hasExcessParensWithPrecedence(e, PRECEDENCE_OF_ASSIGNMENT_EXPR)).forEach(report);
          },
          ArrayPattern(node) {
            node.elements.filter((e) => canBeAssignmentTarget(e) && hasExcessParens(e)).forEach(report);
          },
          ArrowFunctionExpression(node) {
            if (isReturnAssignException(node)) {
              return;
            }
            if (node.body.type === "ConditionalExpression" && IGNORE_ARROW_CONDITIONALS) {
              return;
            }
            if (node.body.type !== "BlockStatement") {
              const firstBodyToken = sourceCode.getFirstToken(node.body, astUtils.isNotOpeningParenToken);
              const tokenBeforeFirst = sourceCode.getTokenBefore(firstBodyToken);
              if (astUtils.isOpeningParenToken(tokenBeforeFirst) && astUtils.isOpeningBraceToken(firstBodyToken)) {
                tokensToIgnore.add(firstBodyToken);
              }
              if (hasExcessParensWithPrecedence(node.body, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                report(node.body);
              }
            }
          },
          AssignmentExpression(node) {
            if (canBeAssignmentTarget(node.left) && hasExcessParens(node.left)) {
              report(node.left);
            }
            if (!isReturnAssignException(node) && hasExcessParensWithPrecedence(node.right, precedence(node))) {
              report(node.right);
            }
          },
          BinaryExpression(node) {
            if (reportsBuffer && node.operator === "in") {
              reportsBuffer.inExpressionNodes.push(node);
            }
            checkBinaryLogical(node);
          },
          CallExpression: checkCallNew,
          ConditionalExpression(node) {
            if (isReturnAssignException(node)) {
              return;
            }
            if (!isCondAssignException(node) && hasExcessParensWithPrecedence(node.test, precedence({ type: "LogicalExpression", operator: "||" }))) {
              report(node.test);
            }
            if (hasExcessParensWithPrecedence(node.consequent, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.consequent);
            }
            if (hasExcessParensWithPrecedence(node.alternate, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.alternate);
            }
          },
          DoWhileStatement(node) {
            if (hasExcessParens(node.test) && !isCondAssignException(node)) {
              report(node.test);
            }
          },
          ExportDefaultDeclaration: (node) => checkExpressionOrExportStatement(node.declaration),
          ExpressionStatement: (node) => checkExpressionOrExportStatement(node.expression),
          ForInStatement(node) {
            if (node.left.type !== "VariableDeclaration") {
              const firstLeftToken = sourceCode.getFirstToken(node.left, astUtils.isNotOpeningParenToken);
              if (firstLeftToken.value === "let" && astUtils.isOpeningBracketToken(
                sourceCode.getTokenAfter(firstLeftToken, astUtils.isNotClosingParenToken)
              )) {
                tokensToIgnore.add(firstLeftToken);
              }
            }
            if (hasExcessParens(node.left)) {
              report(node.left);
            }
            if (hasExcessParens(node.right)) {
              report(node.right);
            }
          },
          ForOfStatement(node) {
            if (node.left.type !== "VariableDeclaration") {
              const firstLeftToken = sourceCode.getFirstToken(node.left, astUtils.isNotOpeningParenToken);
              if (firstLeftToken.value === "let") {
                tokensToIgnore.add(firstLeftToken);
              }
            }
            if (hasExcessParens(node.left)) {
              report(node.left);
            }
            if (hasExcessParensWithPrecedence(node.right, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.right);
            }
          },
          ForStatement(node) {
            if (node.test && hasExcessParens(node.test) && !isCondAssignException(node)) {
              report(node.test);
            }
            if (node.update && hasExcessParens(node.update)) {
              report(node.update);
            }
            if (node.init) {
              if (node.init.type !== "VariableDeclaration") {
                const firstToken = sourceCode.getFirstToken(node.init, astUtils.isNotOpeningParenToken);
                if (firstToken.value === "let" && astUtils.isOpeningBracketToken(
                  sourceCode.getTokenAfter(firstToken, astUtils.isNotClosingParenToken)
                )) {
                  tokensToIgnore.add(firstToken);
                }
              }
              startNewReportsBuffering();
              if (hasExcessParens(node.init)) {
                report(node.init);
              }
            }
          },
          "ForStatement > *.init:exit"(node) {
            if (reportsBuffer.reports.length) {
              reportsBuffer.inExpressionNodes.forEach((inExpressionNode) => {
                const path2 = pathToDescendant(node, inExpressionNode);
                let nodeToExclude;
                for (let i = 0; i < path2.length; i++) {
                  const pathNode = path2[i];
                  if (i < path2.length - 1) {
                    const nextPathNode = path2[i + 1];
                    if (isSafelyEnclosingInExpression(pathNode, nextPathNode)) {
                      return;
                    }
                  }
                  if (isParenthesised(pathNode)) {
                    if (isInCurrentReportsBuffer(pathNode)) {
                      if (isParenthesisedTwice(pathNode)) {
                        return;
                      }
                      if (!nodeToExclude) {
                        nodeToExclude = pathNode;
                      }
                    } else {
                      return;
                    }
                  }
                }
                removeFromCurrentReportsBuffer(nodeToExclude);
              });
            }
            endCurrentReportsBuffering();
          },
          IfStatement(node) {
            if (hasExcessParens(node.test) && !isCondAssignException(node)) {
              report(node.test);
            }
          },
          ImportExpression(node) {
            const { source } = node;
            if (source.type === "SequenceExpression") {
              if (hasDoubleExcessParens(source)) {
                report(source);
              }
            } else if (hasExcessParens(source)) {
              report(source);
            }
          },
          LogicalExpression: checkBinaryLogical,
          MemberExpression(node) {
            const shouldAllowWrapOnce = isMemberExpInNewCallee(node) && doesMemberExpressionContainCallExpression(node);
            const nodeObjHasExcessParens = shouldAllowWrapOnce ? hasDoubleExcessParens(node.object) : hasExcessParens(node.object) && !(isImmediateFunctionPrototypeMethodCall(node.parent) && node.parent.callee === node && IGNORE_FUNCTION_PROTOTYPE_METHODS);
            if (nodeObjHasExcessParens && precedence(node.object) >= precedence(node) && (node.computed || !(astUtils.isDecimalInteger(node.object) || // RegExp literal is allowed to have parens (#1589)
            node.object.type === "Literal" && node.object.regex))) {
              report(node.object);
            }
            if (nodeObjHasExcessParens && node.object.type === "CallExpression") {
              report(node.object);
            }
            if (nodeObjHasExcessParens && !IGNORE_NEW_IN_MEMBER_EXPR && node.object.type === "NewExpression" && isNewExpressionWithParens(node.object)) {
              report(node.object);
            }
            if (nodeObjHasExcessParens && node.optional && node.object.type === "ChainExpression") {
              report(node.object);
            }
            if (node.computed && hasExcessParens(node.property)) {
              report(node.property);
            }
          },
          "MethodDefinition[computed=true]"(node) {
            if (hasExcessParensWithPrecedence(node.key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.key);
            }
          },
          NewExpression: checkCallNew,
          ObjectExpression(node) {
            node.properties.filter((property) => property.value && hasExcessParensWithPrecedence(property.value, PRECEDENCE_OF_ASSIGNMENT_EXPR)).forEach((property) => report(property.value));
          },
          ObjectPattern(node) {
            node.properties.filter((property) => {
              const value2 = property.value;
              return canBeAssignmentTarget(value2) && hasExcessParens(value2);
            }).forEach((property) => report(property.value));
          },
          Property(node) {
            if (node.computed) {
              const { key } = node;
              if (key && hasExcessParensWithPrecedence(key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
                report(key);
              }
            }
          },
          PropertyDefinition(node) {
            if (node.computed && hasExcessParensWithPrecedence(node.key, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.key);
            }
            if (node.value && hasExcessParensWithPrecedence(node.value, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(node.value);
            }
          },
          RestElement(node) {
            const argument = node.argument;
            if (canBeAssignmentTarget(argument) && hasExcessParens(argument)) {
              report(argument);
            }
          },
          ReturnStatement(node) {
            const returnToken = sourceCode.getFirstToken(node);
            if (isReturnAssignException(node)) {
              return;
            }
            if (node.argument && hasExcessParensNoLineTerminator(returnToken, node.argument) && // RegExp literal is allowed to have parens (#1589)
            !(node.argument.type === "Literal" && node.argument.regex)) {
              report(node.argument);
            }
          },
          SequenceExpression(node) {
            const precedenceOfNode = precedence(node);
            node.expressions.filter((e) => hasExcessParensWithPrecedence(e, precedenceOfNode)).forEach(report);
          },
          SwitchCase(node) {
            if (node.test && hasExcessParens(node.test)) {
              report(node.test);
            }
          },
          SwitchStatement(node) {
            if (hasExcessParens(node.discriminant)) {
              report(node.discriminant);
            }
          },
          ThrowStatement(node) {
            const throwToken = sourceCode.getFirstToken(node);
            if (hasExcessParensNoLineTerminator(throwToken, node.argument)) {
              report(node.argument);
            }
          },
          UnaryExpression: checkArgumentWithPrecedence,
          UpdateExpression(node) {
            if (node.prefix) {
              checkArgumentWithPrecedence(node);
            } else {
              const { argument } = node;
              const operatorToken = sourceCode.getLastToken(node);
              if (argument.loc.end.line === operatorToken.loc.start.line) {
                checkArgumentWithPrecedence(node);
              } else {
                if (hasDoubleExcessParens(argument)) {
                  report(argument);
                }
              }
            }
          },
          AwaitExpression: checkArgumentWithPrecedence,
          VariableDeclarator(node) {
            if (node.init && hasExcessParensWithPrecedence(node.init, PRECEDENCE_OF_ASSIGNMENT_EXPR) && // RegExp literal is allowed to have parens (#1589)
            !(node.init.type === "Literal" && node.init.regex)) {
              report(node.init);
            }
          },
          WhileStatement(node) {
            if (hasExcessParens(node.test) && !isCondAssignException(node)) {
              report(node.test);
            }
          },
          WithStatement(node) {
            if (hasExcessParens(node.object)) {
              report(node.object);
            }
          },
          YieldExpression(node) {
            if (node.argument) {
              const yieldToken = sourceCode.getFirstToken(node);
              if (precedence(node.argument) >= precedence(node) && hasExcessParensNoLineTerminator(yieldToken, node.argument) || hasDoubleExcessParens(node.argument)) {
                report(node.argument);
              }
            }
          },
          ClassDeclaration: checkClass,
          ClassExpression: checkClass,
          SpreadElement: checkSpreadOperator,
          SpreadProperty: checkSpreadOperator,
          ExperimentalSpreadProperty: checkSpreadOperator,
          TemplateLiteral(node) {
            node.expressions.filter((e) => e && hasExcessParens(e)).forEach(report);
          },
          AssignmentPattern(node) {
            const { left, right } = node;
            if (canBeAssignmentTarget(left) && hasExcessParens(left)) {
              report(left);
            }
            if (right && hasExcessParensWithPrecedence(right, PRECEDENCE_OF_ASSIGNMENT_EXPR)) {
              report(right);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-extra-semi.js
var require_no_extra_semi = __commonJS({
  "node_modules/eslint/lib/rules/no-extra-semi.js"(exports, module2) {
    "use strict";
    var FixTracker = require_fix_tracker();
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary semicolons",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-extra-semi"
        },
        fixable: "code",
        schema: [],
        messages: {
          unexpected: "Unnecessary semicolon."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function report(nodeOrToken) {
          context.report({
            node: nodeOrToken,
            messageId: "unexpected",
            fix(fixer) {
              return new FixTracker(fixer, context.getSourceCode()).retainSurroundingTokens(nodeOrToken).remove(nodeOrToken);
            }
          });
        }
        function checkForPartOfClassBody(firstToken) {
          for (let token = firstToken; token.type === "Punctuator" && !astUtils.isClosingBraceToken(token); token = sourceCode.getTokenAfter(token)) {
            if (astUtils.isSemicolonToken(token)) {
              report(token);
            }
          }
        }
        return {
          /**
           * Reports this empty statement, except if the parent node is a loop.
           * @param {Node} node A EmptyStatement node to be reported.
           * @returns {void}
           */
          EmptyStatement(node) {
            const parent = node.parent, allowedParentTypes = [
              "ForStatement",
              "ForInStatement",
              "ForOfStatement",
              "WhileStatement",
              "DoWhileStatement",
              "IfStatement",
              "LabeledStatement",
              "WithStatement"
            ];
            if (!allowedParentTypes.includes(parent.type)) {
              report(node);
            }
          },
          /**
           * Checks tokens from the head of this class body to the first MethodDefinition or the end of this class body.
           * @param {Node} node A ClassBody node to check.
           * @returns {void}
           */
          ClassBody(node) {
            checkForPartOfClassBody(sourceCode.getFirstToken(node, 1));
          },
          /**
           * Checks tokens from this MethodDefinition to the next MethodDefinition or the end of this class body.
           * @param {Node} node A MethodDefinition node of the start point.
           * @returns {void}
           */
          "MethodDefinition, PropertyDefinition, StaticBlock"(node) {
            checkForPartOfClassBody(sourceCode.getTokenAfter(node));
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-fallthrough.js
var require_no_fallthrough = __commonJS({
  "node_modules/eslint/lib/rules/no-fallthrough.js"(exports, module2) {
    "use strict";
    var DEFAULT_FALLTHROUGH_COMMENT = /falls?\s?through/iu;
    function hasFallthroughComment(caseWhichFallsThrough, subsequentCase, context, fallthroughCommentPattern) {
      const sourceCode = context.getSourceCode();
      if (caseWhichFallsThrough.consequent.length === 1 && caseWhichFallsThrough.consequent[0].type === "BlockStatement") {
        const trailingCloseBrace = sourceCode.getLastToken(caseWhichFallsThrough.consequent[0]);
        const commentInBlock = sourceCode.getCommentsBefore(trailingCloseBrace).pop();
        if (commentInBlock && fallthroughCommentPattern.test(commentInBlock.value)) {
          return true;
        }
      }
      const comment = sourceCode.getCommentsBefore(subsequentCase).pop();
      return Boolean(comment && fallthroughCommentPattern.test(comment.value));
    }
    function isReachable(segment) {
      return segment.reachable;
    }
    function hasBlankLinesBetween(node, token) {
      return token.loc.start.line > node.loc.end.line + 1;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow fallthrough of `case` statements",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-fallthrough"
        },
        schema: [
          {
            type: "object",
            properties: {
              commentPattern: {
                type: "string",
                default: ""
              },
              allowEmptyCase: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          case: "Expected a 'break' statement before 'case'.",
          default: "Expected a 'break' statement before 'default'."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        let currentCodePath = null;
        const sourceCode = context.getSourceCode();
        const allowEmptyCase = options.allowEmptyCase || false;
        let fallthroughCase = null;
        let fallthroughCommentPattern = null;
        if (options.commentPattern) {
          fallthroughCommentPattern = new RegExp(options.commentPattern, "u");
        } else {
          fallthroughCommentPattern = DEFAULT_FALLTHROUGH_COMMENT;
        }
        return {
          onCodePathStart(codePath) {
            currentCodePath = codePath;
          },
          onCodePathEnd() {
            currentCodePath = currentCodePath.upper;
          },
          SwitchCase(node) {
            if (fallthroughCase && !hasFallthroughComment(fallthroughCase, node, context, fallthroughCommentPattern)) {
              context.report({
                messageId: node.test ? "case" : "default",
                node
              });
            }
            fallthroughCase = null;
          },
          "SwitchCase:exit"(node) {
            const nextToken = sourceCode.getTokenAfter(node);
            if (currentCodePath.currentSegments.some(isReachable) && (node.consequent.length > 0 || !allowEmptyCase && hasBlankLinesBetween(node, nextToken)) && node.parent.cases[node.parent.cases.length - 1] !== node) {
              fallthroughCase = node;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-floating-decimal.js
var require_no_floating_decimal = __commonJS({
  "node_modules/eslint/lib/rules/no-floating-decimal.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow leading or trailing decimal points in numeric literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-floating-decimal"
        },
        schema: [],
        fixable: "code",
        messages: {
          leading: "A leading decimal point can be confused with a dot.",
          trailing: "A trailing decimal point can be confused with a dot."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          Literal(node) {
            if (typeof node.value === "number") {
              if (node.raw.startsWith(".")) {
                context.report({
                  node,
                  messageId: "leading",
                  fix(fixer) {
                    const tokenBefore = sourceCode.getTokenBefore(node);
                    const needsSpaceBefore = tokenBefore && tokenBefore.range[1] === node.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, `0${node.raw}`);
                    return fixer.insertTextBefore(node, needsSpaceBefore ? " 0" : "0");
                  }
                });
              }
              if (node.raw.indexOf(".") === node.raw.length - 1) {
                context.report({
                  node,
                  messageId: "trailing",
                  fix: (fixer) => fixer.insertTextAfter(node, "0")
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-func-assign.js
var require_no_func_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-func-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow reassigning `function` declarations",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-func-assign"
        },
        schema: [],
        messages: {
          isAFunction: "'{{name}}' is a function."
        }
      },
      create(context) {
        function checkReference(references) {
          astUtils.getModifyingReferences(references).forEach((reference) => {
            context.report({
              node: reference.identifier,
              messageId: "isAFunction",
              data: {
                name: reference.identifier.name
              }
            });
          });
        }
        function checkVariable(variable) {
          if (variable.defs[0].type === "FunctionName") {
            checkReference(variable.references);
          }
        }
        function checkForFunction(node) {
          context.getDeclaredVariables(node).forEach(checkVariable);
        }
        return {
          FunctionDeclaration: checkForFunction,
          FunctionExpression: checkForFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-global-assign.js
var require_no_global_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-global-assign.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow assignments to native objects or read-only global variables",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-global-assign"
        },
        schema: [
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: { type: "string" },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          globalShouldNotBeModified: "Read-only global '{{name}}' should not be modified."
        }
      },
      create(context) {
        const config = context.options[0];
        const exceptions = config && config.exceptions || [];
        function checkReference(reference, index, references) {
          const identifier3 = reference.identifier;
          if (reference.init === false && reference.isWrite() && /*
           * Destructuring assignments can have multiple default value,
           * so possibly there are multiple writeable references for the same identifier.
           */
          (index === 0 || references[index - 1].identifier !== identifier3)) {
            context.report({
              node: identifier3,
              messageId: "globalShouldNotBeModified",
              data: {
                name: identifier3.name
              }
            });
          }
        }
        function checkVariable(variable) {
          if (variable.writeable === false && !exceptions.includes(variable.name)) {
            variable.references.forEach(checkReference);
          }
        }
        return {
          Program() {
            const globalScope = context.getScope();
            globalScope.variables.forEach(checkVariable);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-implicit-coercion.js
var require_no_implicit_coercion = __commonJS({
  "node_modules/eslint/lib/rules/no-implicit-coercion.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var INDEX_OF_PATTERN = /^(?:i|lastI)ndexOf$/u;
    var ALLOWABLE_OPERATORS = ["~", "!!", "+", "*"];
    function parseOptions(options) {
      return {
        boolean: "boolean" in options ? options.boolean : true,
        number: "number" in options ? options.number : true,
        string: "string" in options ? options.string : true,
        disallowTemplateShorthand: "disallowTemplateShorthand" in options ? options.disallowTemplateShorthand : false,
        allow: options.allow || []
      };
    }
    function isDoubleLogicalNegating(node) {
      return node.operator === "!" && node.argument.type === "UnaryExpression" && node.argument.operator === "!";
    }
    function isBinaryNegatingOfIndexOf(node) {
      if (node.operator !== "~") {
        return false;
      }
      const callNode = astUtils.skipChainExpression(node.argument);
      return callNode.type === "CallExpression" && astUtils.isSpecificMemberAccess(callNode.callee, null, INDEX_OF_PATTERN);
    }
    function isMultiplyByOne(node) {
      return node.operator === "*" && (node.left.type === "Literal" && node.left.value === 1 || node.right.type === "Literal" && node.right.value === 1);
    }
    function isMultiplyByFractionOfOne(node, sourceCode) {
      return node.type === "BinaryExpression" && node.operator === "*" && (node.right.type === "Literal" && node.right.value === 1) && node.parent.type === "BinaryExpression" && node.parent.operator === "/" && node.parent.left === node && !astUtils.isParenthesised(sourceCode, node);
    }
    function isNumeric(node) {
      return node.type === "Literal" && typeof node.value === "number" || node.type === "CallExpression" && (node.callee.name === "Number" || node.callee.name === "parseInt" || node.callee.name === "parseFloat");
    }
    function getNonNumericOperand(node) {
      const left = node.left, right = node.right;
      if (right.type !== "BinaryExpression" && !isNumeric(right)) {
        return right;
      }
      if (left.type !== "BinaryExpression" && !isNumeric(left)) {
        return left;
      }
      return null;
    }
    function isStringType(node) {
      return astUtils.isStringLiteral(node) || node.type === "CallExpression" && node.callee.type === "Identifier" && node.callee.name === "String";
    }
    function isEmptyString(node) {
      return astUtils.isStringLiteral(node) && (node.value === "" || node.type === "TemplateLiteral" && node.quasis.length === 1 && node.quasis[0].value.cooked === "");
    }
    function isConcatWithEmptyString(node) {
      return node.operator === "+" && (isEmptyString(node.left) && !isStringType(node.right) || isEmptyString(node.right) && !isStringType(node.left));
    }
    function isAppendEmptyString(node) {
      return node.operator === "+=" && isEmptyString(node.right);
    }
    function getNonEmptyOperand(node) {
      return isEmptyString(node.left) ? node.right : node.left;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow shorthand type conversions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-implicit-coercion"
        },
        fixable: "code",
        schema: [{
          type: "object",
          properties: {
            boolean: {
              type: "boolean",
              default: true
            },
            number: {
              type: "boolean",
              default: true
            },
            string: {
              type: "boolean",
              default: true
            },
            disallowTemplateShorthand: {
              type: "boolean",
              default: false
            },
            allow: {
              type: "array",
              items: {
                enum: ALLOWABLE_OPERATORS
              },
              uniqueItems: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          useRecommendation: "use `{{recommendation}}` instead."
        }
      },
      create(context) {
        const options = parseOptions(context.options[0] || {});
        const sourceCode = context.getSourceCode();
        function report(node, recommendation, shouldFix) {
          context.report({
            node,
            messageId: "useRecommendation",
            data: {
              recommendation
            },
            fix(fixer) {
              if (!shouldFix) {
                return null;
              }
              const tokenBefore = sourceCode.getTokenBefore(node);
              if (tokenBefore && tokenBefore.range[1] === node.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, recommendation)) {
                return fixer.replaceText(node, ` ${recommendation}`);
              }
              return fixer.replaceText(node, recommendation);
            }
          });
        }
        return {
          UnaryExpression(node) {
            let operatorAllowed;
            operatorAllowed = options.allow.includes("!!");
            if (!operatorAllowed && options.boolean && isDoubleLogicalNegating(node)) {
              const recommendation = `Boolean(${sourceCode.getText(node.argument.argument)})`;
              report(node, recommendation, true);
            }
            operatorAllowed = options.allow.includes("~");
            if (!operatorAllowed && options.boolean && isBinaryNegatingOfIndexOf(node)) {
              const comparison = node.argument.type === "ChainExpression" ? ">= 0" : "!== -1";
              const recommendation = `${sourceCode.getText(node.argument)} ${comparison}`;
              report(node, recommendation, false);
            }
            operatorAllowed = options.allow.includes("+");
            if (!operatorAllowed && options.number && node.operator === "+" && !isNumeric(node.argument)) {
              const recommendation = `Number(${sourceCode.getText(node.argument)})`;
              report(node, recommendation, true);
            }
          },
          // Use `:exit` to prevent double reporting
          "BinaryExpression:exit"(node) {
            let operatorAllowed;
            operatorAllowed = options.allow.includes("*");
            const nonNumericOperand = !operatorAllowed && options.number && isMultiplyByOne(node) && !isMultiplyByFractionOfOne(node, sourceCode) && getNonNumericOperand(node);
            if (nonNumericOperand) {
              const recommendation = `Number(${sourceCode.getText(nonNumericOperand)})`;
              report(node, recommendation, true);
            }
            operatorAllowed = options.allow.includes("+");
            if (!operatorAllowed && options.string && isConcatWithEmptyString(node)) {
              const recommendation = `String(${sourceCode.getText(getNonEmptyOperand(node))})`;
              report(node, recommendation, true);
            }
          },
          AssignmentExpression(node) {
            const operatorAllowed = options.allow.includes("+");
            if (!operatorAllowed && options.string && isAppendEmptyString(node)) {
              const code = sourceCode.getText(getNonEmptyOperand(node));
              const recommendation = `${code} = String(${code})`;
              report(node, recommendation, true);
            }
          },
          TemplateLiteral(node) {
            if (!options.disallowTemplateShorthand) {
              return;
            }
            if (node.parent.type === "TaggedTemplateExpression") {
              return;
            }
            if (node.expressions.length !== 1) {
              return;
            }
            if (node.quasis[0].value.cooked !== "") {
              return;
            }
            if (node.quasis[1].value.cooked !== "") {
              return;
            }
            if (isStringType(node.expressions[0])) {
              return;
            }
            const code = sourceCode.getText(node.expressions[0]);
            const recommendation = `String(${code})`;
            report(node, recommendation, true);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-implicit-globals.js
var require_no_implicit_globals = __commonJS({
  "node_modules/eslint/lib/rules/no-implicit-globals.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow declarations in the global scope",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-implicit-globals"
        },
        schema: [{
          type: "object",
          properties: {
            lexicalBindings: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          globalNonLexicalBinding: "Unexpected {{kind}} declaration in the global scope, wrap in an IIFE for a local variable, assign as global property for a global variable.",
          globalLexicalBinding: "Unexpected {{kind}} declaration in the global scope, wrap in a block or in an IIFE.",
          globalVariableLeak: "Global variable leak, declare the variable if it is intended to be local.",
          assignmentToReadonlyGlobal: "Unexpected assignment to read-only global variable.",
          redeclarationOfReadonlyGlobal: "Unexpected redeclaration of read-only global variable."
        }
      },
      create(context) {
        const checkLexicalBindings = context.options[0] && context.options[0].lexicalBindings === true;
        function report(node, messageId, kind) {
          context.report({
            node,
            messageId,
            data: {
              kind
            }
          });
        }
        return {
          Program() {
            const scope = context.getScope();
            scope.variables.forEach((variable) => {
              const isReadonlyEslintGlobalVariable = variable.writeable === false;
              const isWritableEslintGlobalVariable = variable.writeable === true;
              if (isWritableEslintGlobalVariable) {
                return;
              }
              if (variable.eslintExported) {
                return;
              }
              variable.defs.forEach((def) => {
                const defNode = def.node;
                if (def.type === "FunctionName" || def.type === "Variable" && def.parent.kind === "var") {
                  if (isReadonlyEslintGlobalVariable) {
                    report(defNode, "redeclarationOfReadonlyGlobal");
                  } else {
                    report(
                      defNode,
                      "globalNonLexicalBinding",
                      def.type === "FunctionName" ? "function" : `'${def.parent.kind}'`
                    );
                  }
                }
                if (checkLexicalBindings) {
                  if (def.type === "ClassName" || def.type === "Variable" && (def.parent.kind === "let" || def.parent.kind === "const")) {
                    if (isReadonlyEslintGlobalVariable) {
                      report(defNode, "redeclarationOfReadonlyGlobal");
                    } else {
                      report(
                        defNode,
                        "globalLexicalBinding",
                        def.type === "ClassName" ? "class" : `'${def.parent.kind}'`
                      );
                    }
                  }
                }
              });
            });
            scope.implicit.variables.forEach((variable) => {
              const scopeVariable = scope.set.get(variable.name);
              let messageId;
              if (scopeVariable) {
                if (scopeVariable.writeable) {
                  return;
                }
                messageId = "assignmentToReadonlyGlobal";
              } else {
                messageId = "globalVariableLeak";
              }
              variable.defs.forEach((def) => {
                report(def.node, messageId);
              });
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-implied-eval.js
var require_no_implied_eval = __commonJS({
  "node_modules/eslint/lib/rules/no-implied-eval.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { getStaticValue } = require_eslint_utils();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `eval()`-like methods",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-implied-eval"
        },
        schema: [],
        messages: {
          impliedEval: "Implied eval. Consider passing a function instead of a string."
        }
      },
      create(context) {
        const GLOBAL_CANDIDATES = Object.freeze(["global", "window", "globalThis"]);
        const EVAL_LIKE_FUNC_PATTERN = /^(?:set(?:Interval|Timeout)|execScript)$/u;
        function isEvaluatedString(node) {
          if (node.type === "Literal" && typeof node.value === "string" || node.type === "TemplateLiteral") {
            return true;
          }
          if (node.type === "BinaryExpression" && node.operator === "+") {
            return isEvaluatedString(node.left) || isEvaluatedString(node.right);
          }
          return false;
        }
        function reportImpliedEvalCallExpression(node) {
          const [firstArgument] = node.arguments;
          if (firstArgument) {
            const staticValue = getStaticValue(firstArgument, context.getScope());
            const isStaticString = staticValue && typeof staticValue.value === "string";
            const isString = isStaticString || isEvaluatedString(firstArgument);
            if (isString) {
              context.report({
                node,
                messageId: "impliedEval"
              });
            }
          }
        }
        function reportImpliedEvalViaGlobal(globalVar) {
          const { references, name } = globalVar;
          references.forEach((ref) => {
            const identifier3 = ref.identifier;
            let node = identifier3.parent;
            while (astUtils.isSpecificMemberAccess(node, null, name)) {
              node = node.parent;
            }
            if (astUtils.isSpecificMemberAccess(node, null, EVAL_LIKE_FUNC_PATTERN)) {
              const calleeNode = node.parent.type === "ChainExpression" ? node.parent : node;
              const parent = calleeNode.parent;
              if (parent.type === "CallExpression" && parent.callee === calleeNode) {
                reportImpliedEvalCallExpression(parent);
              }
            }
          });
        }
        return {
          CallExpression(node) {
            if (astUtils.isSpecificId(node.callee, EVAL_LIKE_FUNC_PATTERN)) {
              reportImpliedEvalCallExpression(node);
            }
          },
          "Program:exit"() {
            const globalScope = context.getScope();
            GLOBAL_CANDIDATES.map((candidate) => astUtils.getVariableByName(globalScope, candidate)).filter((globalVar) => !!globalVar && globalVar.defs.length === 0).forEach(reportImpliedEvalViaGlobal);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-import-assign.js
var require_no_import_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-import-assign.js"(exports, module2) {
    "use strict";
    var { findVariable } = require_eslint_utils();
    var astUtils = require_ast_utils2();
    var WellKnownMutationFunctions = {
      Object: /^(?:assign|definePropert(?:y|ies)|freeze|setPrototypeOf)$/u,
      Reflect: /^(?:(?:define|delete)Property|set(?:PrototypeOf)?)$/u
    };
    function isAssignmentLeft(node) {
      const { parent } = node;
      return parent.type === "AssignmentExpression" && parent.left === node || // Destructuring assignments
      parent.type === "ArrayPattern" || parent.type === "Property" && parent.value === node && parent.parent.type === "ObjectPattern" || parent.type === "RestElement" || parent.type === "AssignmentPattern" && parent.left === node;
    }
    function isOperandOfMutationUnaryOperator(node) {
      const argumentNode = node.parent.type === "ChainExpression" ? node.parent : node;
      const { parent } = argumentNode;
      return parent.type === "UpdateExpression" && parent.argument === argumentNode || parent.type === "UnaryExpression" && parent.operator === "delete" && parent.argument === argumentNode;
    }
    function isIterationVariable(node) {
      const { parent } = node;
      return parent.type === "ForInStatement" && parent.left === node || parent.type === "ForOfStatement" && parent.left === node;
    }
    function isArgumentOfWellKnownMutationFunction(node, scope) {
      const { parent } = node;
      if (parent.type !== "CallExpression" || parent.arguments[0] !== node) {
        return false;
      }
      const callee = astUtils.skipChainExpression(parent.callee);
      if (!astUtils.isSpecificMemberAccess(callee, "Object", WellKnownMutationFunctions.Object) && !astUtils.isSpecificMemberAccess(callee, "Reflect", WellKnownMutationFunctions.Reflect)) {
        return false;
      }
      const variable = findVariable(scope, callee.object);
      return variable !== null && variable.scope.type === "global";
    }
    function isMemberWrite(id, scope) {
      const { parent } = id;
      return parent.type === "MemberExpression" && parent.object === id && (isAssignmentLeft(parent) || isOperandOfMutationUnaryOperator(parent) || isIterationVariable(parent)) || isArgumentOfWellKnownMutationFunction(id, scope);
    }
    function getWriteNode(id) {
      let node = id.parent;
      while (node && node.type !== "AssignmentExpression" && node.type !== "UpdateExpression" && node.type !== "UnaryExpression" && node.type !== "CallExpression" && node.type !== "ForInStatement" && node.type !== "ForOfStatement") {
        node = node.parent;
      }
      return node || id;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow assigning to imported bindings",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-import-assign"
        },
        schema: [],
        messages: {
          readonly: "'{{name}}' is read-only.",
          readonlyMember: "The members of '{{name}}' are read-only."
        }
      },
      create(context) {
        return {
          ImportDeclaration(node) {
            const scope = context.getScope();
            for (const variable of context.getDeclaredVariables(node)) {
              const shouldCheckMembers = variable.defs.some(
                (d) => d.node.type === "ImportNamespaceSpecifier"
              );
              let prevIdNode = null;
              for (const reference of variable.references) {
                const idNode = reference.identifier;
                if (idNode === prevIdNode) {
                  continue;
                }
                prevIdNode = idNode;
                if (reference.isWrite()) {
                  context.report({
                    node: getWriteNode(idNode),
                    messageId: "readonly",
                    data: { name: idNode.name }
                  });
                } else if (shouldCheckMembers && isMemberWrite(idNode, scope)) {
                  context.report({
                    node: getWriteNode(idNode),
                    messageId: "readonlyMember",
                    data: { name: idNode.name }
                  });
                }
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-inline-comments.js
var require_no_inline_comments = __commonJS({
  "node_modules/eslint/lib/rules/no-inline-comments.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow inline comments after code",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-inline-comments"
        },
        schema: [
          {
            type: "object",
            properties: {
              ignorePattern: {
                type: "string"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedInlineComment: "Unexpected comment inline with code."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = context.options[0];
        let customIgnoreRegExp;
        if (options && options.ignorePattern) {
          customIgnoreRegExp = new RegExp(options.ignorePattern, "u");
        }
        function testCodeAroundComment(node) {
          const startLine = String(sourceCode.lines[node.loc.start.line - 1]), endLine = String(sourceCode.lines[node.loc.end.line - 1]), preamble = startLine.slice(0, node.loc.start.column).trim(), postamble = endLine.slice(node.loc.end.column).trim(), isPreambleEmpty = !preamble, isPostambleEmpty = !postamble;
          if (isPreambleEmpty && isPostambleEmpty) {
            return;
          }
          if (customIgnoreRegExp && customIgnoreRegExp.test(node.value)) {
            return;
          }
          if ((isPreambleEmpty || preamble === "{") && (isPostambleEmpty || postamble === "}")) {
            const enclosingNode = sourceCode.getNodeByRangeIndex(node.range[0]);
            if (enclosingNode && enclosingNode.type === "JSXEmptyExpression") {
              return;
            }
          }
          if (astUtils.isDirectiveComment(node)) {
            return;
          }
          context.report({
            node,
            messageId: "unexpectedInlineComment"
          });
        }
        return {
          Program() {
            sourceCode.getAllComments().filter((token) => token.type !== "Shebang").forEach(testCodeAroundComment);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-inner-declarations.js
var require_no_inner_declarations = __commonJS({
  "node_modules/eslint/lib/rules/no-inner-declarations.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var validParent = /* @__PURE__ */ new Set(["Program", "StaticBlock", "ExportNamedDeclaration", "ExportDefaultDeclaration"]);
    var validBlockStatementParent = /* @__PURE__ */ new Set(["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"]);
    function getAllowedBodyDescription(node) {
      let { parent } = node;
      while (parent) {
        if (parent.type === "StaticBlock") {
          return "class static block body";
        }
        if (astUtils.isFunction(parent)) {
          return "function body";
        }
        ({ parent } = parent);
      }
      return "program";
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow variable or `function` declarations in nested blocks",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-inner-declarations"
        },
        schema: [
          {
            enum: ["functions", "both"]
          }
        ],
        messages: {
          moveDeclToRoot: "Move {{type}} declaration to {{body}} root."
        }
      },
      create(context) {
        function check(node) {
          const parent = node.parent;
          if (parent.type === "BlockStatement" && validBlockStatementParent.has(parent.parent.type)) {
            return;
          }
          if (validParent.has(parent.type)) {
            return;
          }
          context.report({
            node,
            messageId: "moveDeclToRoot",
            data: {
              type: node.type === "FunctionDeclaration" ? "function" : "variable",
              body: getAllowedBodyDescription(node)
            }
          });
        }
        return {
          FunctionDeclaration: check,
          VariableDeclaration(node) {
            if (context.options[0] === "both" && node.kind === "var") {
              check(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-invalid-regexp.js
var require_no_invalid_regexp = __commonJS({
  "node_modules/eslint/lib/rules/no-invalid-regexp.js"(exports, module2) {
    "use strict";
    var RegExpValidator = require_regexpp().RegExpValidator;
    var validator = new RegExpValidator();
    var validFlags = /[dgimsuy]/gu;
    var undefined1 = void 0;
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow invalid regular expression strings in `RegExp` constructors",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-invalid-regexp"
        },
        schema: [{
          type: "object",
          properties: {
            allowConstructorFlags: {
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          additionalProperties: false
        }],
        messages: {
          regexMessage: "{{message}}."
        }
      },
      create(context) {
        const options = context.options[0];
        let allowedFlags = null;
        if (options && options.allowConstructorFlags) {
          const temp = options.allowConstructorFlags.join("").replace(validFlags, "");
          if (temp) {
            allowedFlags = new RegExp(`[${temp}]`, "giu");
          }
        }
        function report(node, message) {
          context.report({
            node,
            messageId: "regexMessage",
            data: { message }
          });
        }
        function isString(node) {
          return node && node.type === "Literal" && typeof node.value === "string";
        }
        function getFlags(node) {
          if (node.arguments.length < 2) {
            return "";
          }
          if (isString(node.arguments[1])) {
            return node.arguments[1].value;
          }
          return null;
        }
        function validateRegExpPattern(pattern, uFlag) {
          try {
            validator.validatePattern(pattern, undefined1, undefined1, uFlag);
            return null;
          } catch (err) {
            return err.message;
          }
        }
        function validateRegExpFlags(flags) {
          if (!flags) {
            return null;
          }
          try {
            validator.validateFlags(flags);
            return null;
          } catch {
            return `Invalid flags supplied to RegExp constructor '${flags}'`;
          }
        }
        return {
          "CallExpression, NewExpression"(node) {
            if (node.callee.type !== "Identifier" || node.callee.name !== "RegExp") {
              return;
            }
            let flags = getFlags(node);
            if (flags && allowedFlags) {
              flags = flags.replace(allowedFlags, "");
            }
            let message = validateRegExpFlags(flags);
            if (message) {
              report(node, message);
              return;
            }
            if (!isString(node.arguments[0])) {
              return;
            }
            const pattern = node.arguments[0].value;
            message = // If flags are unknown, report the regex only if its pattern is invalid both with and without the "u" flag
            flags === null ? validateRegExpPattern(pattern, true) && validateRegExpPattern(pattern, false) : validateRegExpPattern(pattern, flags.includes("u"));
            if (message) {
              report(node, message);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-invalid-this.js
var require_no_invalid_this = __commonJS({
  "node_modules/eslint/lib/rules/no-invalid-this.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isCodePathWithLexicalThis(codePath, node) {
      return codePath.origin === "function" && node.type === "ArrowFunctionExpression";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow use of `this` in contexts where the value of `this` is `undefined`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-invalid-this"
        },
        schema: [
          {
            type: "object",
            properties: {
              capIsConstructor: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedThis: "Unexpected 'this'."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const capIsConstructor = options.capIsConstructor !== false;
        const stack = [], sourceCode = context.getSourceCode();
        stack.getCurrent = function() {
          const current = this[this.length - 1];
          if (!current.init) {
            current.init = true;
            current.valid = !astUtils.isDefaultThisBinding(
              current.node,
              sourceCode,
              { capIsConstructor }
            );
          }
          return current;
        };
        return {
          onCodePathStart(codePath, node) {
            if (isCodePathWithLexicalThis(codePath, node)) {
              return;
            }
            if (codePath.origin === "program") {
              const scope = context.getScope();
              const features = context.parserOptions.ecmaFeatures || {};
              stack.push({
                init: true,
                node,
                valid: !(node.sourceType === "module" || features.globalReturn && scope.childScopes[0].isStrict)
              });
              return;
            }
            stack.push({
              init: !context.getScope().isStrict,
              node,
              valid: true
            });
          },
          onCodePathEnd(codePath, node) {
            if (isCodePathWithLexicalThis(codePath, node)) {
              return;
            }
            stack.pop();
          },
          // Reports if `this` of the current context is invalid.
          ThisExpression(node) {
            const current = stack.getCurrent();
            if (current && !current.valid) {
              context.report({
                node,
                messageId: "unexpectedThis"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-irregular-whitespace.js
var require_no_irregular_whitespace = __commonJS({
  "node_modules/eslint/lib/rules/no-irregular-whitespace.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var ALL_IRREGULARS = /[\f\v\u0085\ufeff\u00a0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u200b\u202f\u205f\u3000\u2028\u2029]/u;
    var IRREGULAR_WHITESPACE = /[\f\v\u0085\ufeff\u00a0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u200b\u202f\u205f\u3000]+/mgu;
    var IRREGULAR_LINE_TERMINATORS = /[\u2028\u2029]/mgu;
    var LINE_BREAK = astUtils.createGlobalLinebreakMatcher();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow irregular whitespace",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-irregular-whitespace"
        },
        schema: [
          {
            type: "object",
            properties: {
              skipComments: {
                type: "boolean",
                default: false
              },
              skipStrings: {
                type: "boolean",
                default: true
              },
              skipTemplates: {
                type: "boolean",
                default: false
              },
              skipRegExps: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          noIrregularWhitespace: "Irregular whitespace not allowed."
        }
      },
      create(context) {
        let errors = [];
        const options = context.options[0] || {};
        const skipComments = !!options.skipComments;
        const skipStrings = options.skipStrings !== false;
        const skipRegExps = !!options.skipRegExps;
        const skipTemplates = !!options.skipTemplates;
        const sourceCode = context.getSourceCode();
        const commentNodes = sourceCode.getAllComments();
        function removeWhitespaceError(node) {
          const locStart = node.loc.start;
          const locEnd = node.loc.end;
          errors = errors.filter(({ loc: { start: errorLocStart } }) => errorLocStart.line < locStart.line || errorLocStart.line === locStart.line && errorLocStart.column < locStart.column || errorLocStart.line === locEnd.line && errorLocStart.column >= locEnd.column || errorLocStart.line > locEnd.line);
        }
        function removeInvalidNodeErrorsInIdentifierOrLiteral(node) {
          const shouldCheckStrings = skipStrings && typeof node.value === "string";
          const shouldCheckRegExps = skipRegExps && Boolean(node.regex);
          if (shouldCheckStrings || shouldCheckRegExps) {
            if (ALL_IRREGULARS.test(node.raw)) {
              removeWhitespaceError(node);
            }
          }
        }
        function removeInvalidNodeErrorsInTemplateLiteral(node) {
          if (typeof node.value.raw === "string") {
            if (ALL_IRREGULARS.test(node.value.raw)) {
              removeWhitespaceError(node);
            }
          }
        }
        function removeInvalidNodeErrorsInComment(node) {
          if (ALL_IRREGULARS.test(node.value)) {
            removeWhitespaceError(node);
          }
        }
        function checkForIrregularWhitespace(node) {
          const sourceLines = sourceCode.lines;
          sourceLines.forEach((sourceLine, lineIndex) => {
            const lineNumber = lineIndex + 1;
            let match;
            while ((match = IRREGULAR_WHITESPACE.exec(sourceLine)) !== null) {
              errors.push({
                node,
                messageId: "noIrregularWhitespace",
                loc: {
                  start: {
                    line: lineNumber,
                    column: match.index
                  },
                  end: {
                    line: lineNumber,
                    column: match.index + match[0].length
                  }
                }
              });
            }
          });
        }
        function checkForIrregularLineTerminators(node) {
          const source = sourceCode.getText(), sourceLines = sourceCode.lines, linebreaks = source.match(LINE_BREAK);
          let lastLineIndex = -1, match;
          while ((match = IRREGULAR_LINE_TERMINATORS.exec(source)) !== null) {
            const lineIndex = linebreaks.indexOf(match[0], lastLineIndex + 1) || 0;
            errors.push({
              node,
              messageId: "noIrregularWhitespace",
              loc: {
                start: {
                  line: lineIndex + 1,
                  column: sourceLines[lineIndex].length
                },
                end: {
                  line: lineIndex + 2,
                  column: 0
                }
              }
            });
            lastLineIndex = lineIndex;
          }
        }
        function noop() {
        }
        const nodes = {};
        if (ALL_IRREGULARS.test(sourceCode.getText())) {
          nodes.Program = function(node) {
            checkForIrregularWhitespace(node);
            checkForIrregularLineTerminators(node);
          };
          nodes.Identifier = removeInvalidNodeErrorsInIdentifierOrLiteral;
          nodes.Literal = removeInvalidNodeErrorsInIdentifierOrLiteral;
          nodes.TemplateElement = skipTemplates ? removeInvalidNodeErrorsInTemplateLiteral : noop;
          nodes["Program:exit"] = function() {
            if (skipComments) {
              commentNodes.forEach(removeInvalidNodeErrorsInComment);
            }
            errors.forEach((error) => context.report(error));
          };
        } else {
          nodes.Program = noop;
        }
        return nodes;
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-iterator.js
var require_no_iterator = __commonJS({
  "node_modules/eslint/lib/rules/no-iterator.js"(exports, module2) {
    "use strict";
    var { getStaticPropertyName } = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of the `__iterator__` property",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-iterator"
        },
        schema: [],
        messages: {
          noIterator: "Reserved name '__iterator__'."
        }
      },
      create(context) {
        return {
          MemberExpression(node) {
            if (getStaticPropertyName(node) === "__iterator__") {
              context.report({
                node,
                messageId: "noIterator"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-label-var.js
var require_no_label_var = __commonJS({
  "node_modules/eslint/lib/rules/no-label-var.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow labels that share a name with a variable",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-label-var"
        },
        schema: [],
        messages: {
          identifierClashWithLabel: "Found identifier with same name as label."
        }
      },
      create(context) {
        function findIdentifier(scope, name) {
          return astUtils.getVariableByName(scope, name) !== null;
        }
        return {
          LabeledStatement(node) {
            const scope = context.getScope();
            if (findIdentifier(scope, node.label.name)) {
              context.report({
                node,
                messageId: "identifierClashWithLabel"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-labels.js
var require_no_labels = __commonJS({
  "node_modules/eslint/lib/rules/no-labels.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow labeled statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-labels"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowLoop: {
                type: "boolean",
                default: false
              },
              allowSwitch: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedLabel: "Unexpected labeled statement.",
          unexpectedLabelInBreak: "Unexpected label in break statement.",
          unexpectedLabelInContinue: "Unexpected label in continue statement."
        }
      },
      create(context) {
        const options = context.options[0];
        const allowLoop = options && options.allowLoop;
        const allowSwitch = options && options.allowSwitch;
        let scopeInfo = null;
        function getBodyKind(node) {
          if (astUtils.isLoop(node)) {
            return "loop";
          }
          if (node.type === "SwitchStatement") {
            return "switch";
          }
          return "other";
        }
        function isAllowed(kind) {
          switch (kind) {
            case "loop":
              return allowLoop;
            case "switch":
              return allowSwitch;
            default:
              return false;
          }
        }
        function getKind(label) {
          let info = scopeInfo;
          while (info) {
            if (info.label === label) {
              return info.kind;
            }
            info = info.upper;
          }
          return "other";
        }
        return {
          LabeledStatement(node) {
            scopeInfo = {
              label: node.label.name,
              kind: getBodyKind(node.body),
              upper: scopeInfo
            };
          },
          "LabeledStatement:exit"(node) {
            if (!isAllowed(scopeInfo.kind)) {
              context.report({
                node,
                messageId: "unexpectedLabel"
              });
            }
            scopeInfo = scopeInfo.upper;
          },
          BreakStatement(node) {
            if (node.label && !isAllowed(getKind(node.label.name))) {
              context.report({
                node,
                messageId: "unexpectedLabelInBreak"
              });
            }
          },
          ContinueStatement(node) {
            if (node.label && !isAllowed(getKind(node.label.name))) {
              context.report({
                node,
                messageId: "unexpectedLabelInContinue"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-lone-blocks.js
var require_no_lone_blocks = __commonJS({
  "node_modules/eslint/lib/rules/no-lone-blocks.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary nested blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-lone-blocks"
        },
        schema: [],
        messages: {
          redundantBlock: "Block is redundant.",
          redundantNestedBlock: "Nested block is redundant."
        }
      },
      create(context) {
        const loneBlocks = [];
        let ruleDef;
        function report(node) {
          const messageId = node.parent.type === "BlockStatement" || node.parent.type === "StaticBlock" ? "redundantNestedBlock" : "redundantBlock";
          context.report({
            node,
            messageId
          });
        }
        function isLoneBlock(node) {
          return node.parent.type === "BlockStatement" || node.parent.type === "StaticBlock" || node.parent.type === "Program" || // Don't report blocks in switch cases if the block is the only statement of the case.
          node.parent.type === "SwitchCase" && !(node.parent.consequent[0] === node && node.parent.consequent.length === 1);
        }
        function markLoneBlock() {
          if (loneBlocks.length === 0) {
            return;
          }
          const block = context.getAncestors().pop();
          if (loneBlocks[loneBlocks.length - 1] === block) {
            loneBlocks.pop();
          }
        }
        ruleDef = {
          BlockStatement(node) {
            if (isLoneBlock(node)) {
              report(node);
            }
          }
        };
        if (context.languageOptions.ecmaVersion >= 2015) {
          ruleDef = {
            BlockStatement(node) {
              if (isLoneBlock(node)) {
                loneBlocks.push(node);
              }
            },
            "BlockStatement:exit"(node) {
              if (loneBlocks.length > 0 && loneBlocks[loneBlocks.length - 1] === node) {
                loneBlocks.pop();
                report(node);
              } else if ((node.parent.type === "BlockStatement" || node.parent.type === "StaticBlock") && node.parent.body.length === 1) {
                report(node);
              }
            }
          };
          ruleDef.VariableDeclaration = function(node) {
            if (node.kind === "let" || node.kind === "const") {
              markLoneBlock();
            }
          };
          ruleDef.FunctionDeclaration = function() {
            if (context.getScope().isStrict) {
              markLoneBlock();
            }
          };
          ruleDef.ClassDeclaration = markLoneBlock;
        }
        return ruleDef;
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-lonely-if.js
var require_no_lonely_if = __commonJS({
  "node_modules/eslint/lib/rules/no-lonely-if.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `if` statements as the only statement in `else` blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-lonely-if"
        },
        schema: [],
        fixable: "code",
        messages: {
          unexpectedLonelyIf: "Unexpected if as the only statement in an else block."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          IfStatement(node) {
            const ancestors = context.getAncestors(), parent = ancestors.pop(), grandparent = ancestors.pop();
            if (parent && parent.type === "BlockStatement" && parent.body.length === 1 && grandparent && grandparent.type === "IfStatement" && parent === grandparent.alternate) {
              context.report({
                node,
                messageId: "unexpectedLonelyIf",
                fix(fixer) {
                  const openingElseCurly = sourceCode.getFirstToken(parent);
                  const closingElseCurly = sourceCode.getLastToken(parent);
                  const elseKeyword = sourceCode.getTokenBefore(openingElseCurly);
                  const tokenAfterElseBlock = sourceCode.getTokenAfter(closingElseCurly);
                  const lastIfToken = sourceCode.getLastToken(node.consequent);
                  const sourceText = sourceCode.getText();
                  if (sourceText.slice(
                    openingElseCurly.range[1],
                    node.range[0]
                  ).trim() || sourceText.slice(node.range[1], closingElseCurly.range[0]).trim()) {
                    return null;
                  }
                  if (node.consequent.type !== "BlockStatement" && lastIfToken.value !== ";" && tokenAfterElseBlock && (node.consequent.loc.end.line === tokenAfterElseBlock.loc.start.line || /^[([/+`-]/u.test(tokenAfterElseBlock.value) || lastIfToken.value === "++" || lastIfToken.value === "--")) {
                    return null;
                  }
                  return fixer.replaceTextRange(
                    [openingElseCurly.range[0], closingElseCurly.range[1]],
                    (elseKeyword.range[1] === openingElseCurly.range[0] ? " " : "") + sourceCode.getText(node)
                  );
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-loop-func.js
var require_no_loop_func = __commonJS({
  "node_modules/eslint/lib/rules/no-loop-func.js"(exports, module2) {
    "use strict";
    function getContainingLoopNode(node) {
      for (let currentNode = node; currentNode.parent; currentNode = currentNode.parent) {
        const parent = currentNode.parent;
        switch (parent.type) {
          case "WhileStatement":
          case "DoWhileStatement":
            return parent;
          case "ForStatement":
            if (parent.init !== currentNode) {
              return parent;
            }
            break;
          case "ForInStatement":
          case "ForOfStatement":
            if (parent.right !== currentNode) {
              return parent;
            }
            break;
          case "ArrowFunctionExpression":
          case "FunctionExpression":
          case "FunctionDeclaration":
            return null;
          default:
            break;
        }
      }
      return null;
    }
    function getTopLoopNode(node, excludedNode) {
      const border = excludedNode ? excludedNode.range[1] : 0;
      let retv = node;
      let containingLoopNode = node;
      while (containingLoopNode && containingLoopNode.range[0] >= border) {
        retv = containingLoopNode;
        containingLoopNode = getContainingLoopNode(containingLoopNode);
      }
      return retv;
    }
    function isSafe(loopNode, reference) {
      const variable = reference.resolved;
      const definition = variable && variable.defs[0];
      const declaration = definition && definition.parent;
      const kind = declaration && declaration.type === "VariableDeclaration" ? declaration.kind : "";
      if (kind === "const") {
        return true;
      }
      if (kind === "let" && declaration.range[0] > loopNode.range[0] && declaration.range[1] < loopNode.range[1]) {
        return true;
      }
      const border = getTopLoopNode(
        loopNode,
        kind === "let" ? declaration : null
      ).range[0];
      function isSafeReference(upperRef) {
        const id = upperRef.identifier;
        return !upperRef.isWrite() || variable.scope.variableScope === upperRef.from.variableScope && id.range[0] < border;
      }
      return Boolean(variable) && variable.references.every(isSafeReference);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow function declarations that contain unsafe references inside loop statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-loop-func"
        },
        schema: [],
        messages: {
          unsafeRefs: "Function declared in a loop contains unsafe references to variable(s) {{ varNames }}."
        }
      },
      create(context) {
        function checkForLoops(node) {
          const loopNode = getContainingLoopNode(node);
          if (!loopNode) {
            return;
          }
          const references = context.getScope().through;
          const unsafeRefs = references.filter((r) => !isSafe(loopNode, r)).map((r) => r.identifier.name);
          if (unsafeRefs.length > 0) {
            context.report({
              node,
              messageId: "unsafeRefs",
              data: { varNames: `'${unsafeRefs.join("', '")}'` }
            });
          }
        }
        return {
          ArrowFunctionExpression: checkForLoops,
          FunctionExpression: checkForLoops,
          FunctionDeclaration: checkForLoops
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-loss-of-precision.js
var require_no_loss_of_precision = __commonJS({
  "node_modules/eslint/lib/rules/no-loss-of-precision.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow literal numbers that lose precision",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-loss-of-precision"
        },
        schema: [],
        messages: {
          noLossOfPrecision: "This number literal will lose precision at runtime."
        }
      },
      create(context) {
        function isNumber(node) {
          return typeof node.value === "number";
        }
        function getRaw(node) {
          return node.raw.replace(/_/gu, "");
        }
        function isBaseTen(node) {
          const prefixes = ["0x", "0X", "0b", "0B", "0o", "0O"];
          return prefixes.every((prefix) => !node.raw.startsWith(prefix)) && !/^0[0-7]+$/u.test(node.raw);
        }
        function notBaseTenLosesPrecision(node) {
          const rawString = getRaw(node).toUpperCase();
          let base = 0;
          if (rawString.startsWith("0B")) {
            base = 2;
          } else if (rawString.startsWith("0X")) {
            base = 16;
          } else {
            base = 8;
          }
          return !rawString.endsWith(node.value.toString(base).toUpperCase());
        }
        function addDecimalPointToNumber(stringNumber) {
          return `${stringNumber.slice(0, 1)}.${stringNumber.slice(1)}`;
        }
        function removeLeadingZeros(numberAsString) {
          return numberAsString.replace(/^0*/u, "");
        }
        function removeTrailingZeros(numberAsString) {
          return numberAsString.replace(/0*$/u, "");
        }
        function normalizeInteger(stringInteger) {
          const significantDigits = removeTrailingZeros(removeLeadingZeros(stringInteger));
          return {
            magnitude: stringInteger.startsWith("0") ? stringInteger.length - 2 : stringInteger.length - 1,
            coefficient: addDecimalPointToNumber(significantDigits)
          };
        }
        function normalizeFloat(stringFloat) {
          const trimmedFloat = removeLeadingZeros(stringFloat);
          if (trimmedFloat.startsWith(".")) {
            const decimalDigits = trimmedFloat.split(".").pop();
            const significantDigits = removeLeadingZeros(decimalDigits);
            return {
              magnitude: significantDigits.length - decimalDigits.length - 1,
              coefficient: addDecimalPointToNumber(significantDigits)
            };
          }
          return {
            magnitude: trimmedFloat.indexOf(".") - 1,
            coefficient: addDecimalPointToNumber(trimmedFloat.replace(".", ""))
          };
        }
        function convertNumberToScientificNotation(stringNumber) {
          const splitNumber = stringNumber.replace("E", "e").split("e");
          const originalCoefficient = splitNumber[0];
          const normalizedNumber = stringNumber.includes(".") ? normalizeFloat(originalCoefficient) : normalizeInteger(originalCoefficient);
          const normalizedCoefficient = normalizedNumber.coefficient;
          const magnitude = splitNumber.length > 1 ? parseInt(splitNumber[1], 10) + normalizedNumber.magnitude : normalizedNumber.magnitude;
          return `${normalizedCoefficient}e${magnitude}`;
        }
        function baseTenLosesPrecision(node) {
          const normalizedRawNumber = convertNumberToScientificNotation(getRaw(node));
          const requestedPrecision = normalizedRawNumber.split("e")[0].replace(".", "").length;
          if (requestedPrecision > 100) {
            return true;
          }
          const storedNumber = node.value.toPrecision(requestedPrecision);
          const normalizedStoredNumber = convertNumberToScientificNotation(storedNumber);
          return normalizedRawNumber !== normalizedStoredNumber;
        }
        function losesPrecision(node) {
          return isBaseTen(node) ? baseTenLosesPrecision(node) : notBaseTenLosesPrecision(node);
        }
        return {
          Literal(node) {
            if (node.value && isNumber(node) && losesPrecision(node)) {
              context.report({
                messageId: "noLossOfPrecision",
                node
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-magic-numbers.js
var require_no_magic_numbers = __commonJS({
  "node_modules/eslint/lib/rules/no-magic-numbers.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var MAX_ARRAY_LENGTH = 2 ** 32 - 1;
    function normalizeIgnoreValue(x) {
      if (typeof x === "string") {
        return BigInt(x.slice(0, -1));
      }
      return x;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow magic numbers",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-magic-numbers"
        },
        schema: [{
          type: "object",
          properties: {
            detectObjects: {
              type: "boolean",
              default: false
            },
            enforceConst: {
              type: "boolean",
              default: false
            },
            ignore: {
              type: "array",
              items: {
                anyOf: [
                  { type: "number" },
                  { type: "string", pattern: "^[+-]?(?:0|[1-9][0-9]*)n$" }
                ]
              },
              uniqueItems: true
            },
            ignoreArrayIndexes: {
              type: "boolean",
              default: false
            },
            ignoreDefaultValues: {
              type: "boolean",
              default: false
            },
            ignoreClassFieldInitialValues: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          useConst: "Number constants declarations must use 'const'.",
          noMagic: "No magic number: {{raw}}."
        }
      },
      create(context) {
        const config = context.options[0] || {}, detectObjects = !!config.detectObjects, enforceConst = !!config.enforceConst, ignore = new Set((config.ignore || []).map(normalizeIgnoreValue)), ignoreArrayIndexes = !!config.ignoreArrayIndexes, ignoreDefaultValues = !!config.ignoreDefaultValues, ignoreClassFieldInitialValues = !!config.ignoreClassFieldInitialValues;
        const okTypes = detectObjects ? [] : ["ObjectExpression", "Property", "AssignmentExpression"];
        function isIgnoredValue(value2) {
          return ignore.has(value2);
        }
        function isDefaultValue(fullNumberNode) {
          const parent = fullNumberNode.parent;
          return parent.type === "AssignmentPattern" && parent.right === fullNumberNode;
        }
        function isClassFieldInitialValue(fullNumberNode) {
          const parent = fullNumberNode.parent;
          return parent.type === "PropertyDefinition" && parent.value === fullNumberNode;
        }
        function isParseIntRadix(fullNumberNode) {
          const parent = fullNumberNode.parent;
          return parent.type === "CallExpression" && fullNumberNode === parent.arguments[1] && (astUtils.isSpecificId(parent.callee, "parseInt") || astUtils.isSpecificMemberAccess(parent.callee, "Number", "parseInt"));
        }
        function isJSXNumber(fullNumberNode) {
          return fullNumberNode.parent.type.indexOf("JSX") === 0;
        }
        function isArrayIndex(fullNumberNode, value2) {
          const parent = fullNumberNode.parent;
          return parent.type === "MemberExpression" && parent.property === fullNumberNode && (Number.isInteger(value2) || typeof value2 === "bigint") && value2 >= 0 && value2 < MAX_ARRAY_LENGTH;
        }
        return {
          Literal(node) {
            if (!astUtils.isNumericLiteral(node)) {
              return;
            }
            let fullNumberNode;
            let value2;
            let raw;
            if (node.parent.type === "UnaryExpression" && node.parent.operator === "-") {
              fullNumberNode = node.parent;
              value2 = -node.value;
              raw = `-${node.raw}`;
            } else {
              fullNumberNode = node;
              value2 = node.value;
              raw = node.raw;
            }
            const parent = fullNumberNode.parent;
            if (isIgnoredValue(value2) || ignoreDefaultValues && isDefaultValue(fullNumberNode) || ignoreClassFieldInitialValues && isClassFieldInitialValue(fullNumberNode) || isParseIntRadix(fullNumberNode) || isJSXNumber(fullNumberNode) || ignoreArrayIndexes && isArrayIndex(fullNumberNode, value2)) {
              return;
            }
            if (parent.type === "VariableDeclarator") {
              if (enforceConst && parent.parent.kind !== "const") {
                context.report({
                  node: fullNumberNode,
                  messageId: "useConst"
                });
              }
            } else if (!okTypes.includes(parent.type) || parent.type === "AssignmentExpression" && parent.left.type === "Identifier") {
              context.report({
                node: fullNumberNode,
                messageId: "noMagic",
                data: {
                  raw
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/utils/unicode/is-combining-character.js
var require_is_combining_character = __commonJS({
  "node_modules/eslint/lib/rules/utils/unicode/is-combining-character.js"(exports, module2) {
    "use strict";
    module2.exports = function isCombiningCharacter(codePoint) {
      return /^[\p{Mc}\p{Me}\p{Mn}]$/u.test(String.fromCodePoint(codePoint));
    };
  }
});

// node_modules/eslint/lib/rules/utils/unicode/is-emoji-modifier.js
var require_is_emoji_modifier = __commonJS({
  "node_modules/eslint/lib/rules/utils/unicode/is-emoji-modifier.js"(exports, module2) {
    "use strict";
    module2.exports = function isEmojiModifier(code) {
      return code >= 127995 && code <= 127999;
    };
  }
});

// node_modules/eslint/lib/rules/utils/unicode/is-regional-indicator-symbol.js
var require_is_regional_indicator_symbol = __commonJS({
  "node_modules/eslint/lib/rules/utils/unicode/is-regional-indicator-symbol.js"(exports, module2) {
    "use strict";
    module2.exports = function isRegionalIndicatorSymbol(code) {
      return code >= 127462 && code <= 127487;
    };
  }
});

// node_modules/eslint/lib/rules/utils/unicode/is-surrogate-pair.js
var require_is_surrogate_pair = __commonJS({
  "node_modules/eslint/lib/rules/utils/unicode/is-surrogate-pair.js"(exports, module2) {
    "use strict";
    module2.exports = function isSurrogatePair(lead, tail) {
      return lead >= 55296 && lead < 56320 && tail >= 56320 && tail < 57344;
    };
  }
});

// node_modules/eslint/lib/rules/utils/unicode/index.js
var require_unicode2 = __commonJS({
  "node_modules/eslint/lib/rules/utils/unicode/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      isCombiningCharacter: require_is_combining_character(),
      isEmojiModifier: require_is_emoji_modifier(),
      isRegionalIndicatorSymbol: require_is_regional_indicator_symbol(),
      isSurrogatePair: require_is_surrogate_pair()
    };
  }
});

// node_modules/eslint/lib/rules/no-misleading-character-class.js
var require_no_misleading_character_class = __commonJS({
  "node_modules/eslint/lib/rules/no-misleading-character-class.js"(exports, module2) {
    "use strict";
    var { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require_eslint_utils();
    var { RegExpValidator, RegExpParser, visitRegExpAST } = require_regexpp();
    var { isCombiningCharacter, isEmojiModifier, isRegionalIndicatorSymbol, isSurrogatePair } = require_unicode2();
    var astUtils = require_ast_utils2();
    var REGEXPP_LATEST_ECMA_VERSION = 2022;
    function* iterateCharacterSequence(nodes) {
      let seq = [];
      for (const node of nodes) {
        switch (node.type) {
          case "Character":
            seq.push(node.value);
            break;
          case "CharacterClassRange":
            seq.push(node.min.value);
            yield seq;
            seq = [node.max.value];
            break;
          case "CharacterSet":
            if (seq.length > 0) {
              yield seq;
              seq = [];
            }
            break;
        }
      }
      if (seq.length > 0) {
        yield seq;
      }
    }
    var hasCharacterSequence = {
      surrogatePairWithoutUFlag(chars) {
        return chars.some((c, i) => i !== 0 && isSurrogatePair(chars[i - 1], c));
      },
      combiningClass(chars) {
        return chars.some((c, i) => i !== 0 && isCombiningCharacter(c) && !isCombiningCharacter(chars[i - 1]));
      },
      emojiModifier(chars) {
        return chars.some((c, i) => i !== 0 && isEmojiModifier(c) && !isEmojiModifier(chars[i - 1]));
      },
      regionalIndicatorSymbol(chars) {
        return chars.some((c, i) => i !== 0 && isRegionalIndicatorSymbol(c) && isRegionalIndicatorSymbol(chars[i - 1]));
      },
      zwj(chars) {
        const lastIndex = chars.length - 1;
        return chars.some((c, i) => i !== 0 && i !== lastIndex && c === 8205 && chars[i - 1] !== 8205 && chars[i + 1] !== 8205);
      }
    };
    var kinds = Object.keys(hasCharacterSequence);
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow characters which are made with multiple code points in character class syntax",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-misleading-character-class"
        },
        hasSuggestions: true,
        schema: [],
        messages: {
          surrogatePairWithoutUFlag: "Unexpected surrogate pair in character class. Use 'u' flag.",
          combiningClass: "Unexpected combined character in character class.",
          emojiModifier: "Unexpected modified Emoji in character class.",
          regionalIndicatorSymbol: "Unexpected national flag in character class.",
          zwj: "Unexpected joined character sequence in character class.",
          suggestUnicodeFlag: "Add unicode 'u' flag to regex."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const parser = new RegExpParser();
        function verify(node, pattern, flags, unicodeFixer) {
          let patternNode;
          try {
            patternNode = parser.parsePattern(
              pattern,
              0,
              pattern.length,
              flags.includes("u")
            );
          } catch {
            return;
          }
          const foundKinds = /* @__PURE__ */ new Set();
          visitRegExpAST(patternNode, {
            onCharacterClassEnter(ccNode) {
              for (const chars of iterateCharacterSequence(ccNode.elements)) {
                for (const kind of kinds) {
                  if (hasCharacterSequence[kind](chars)) {
                    foundKinds.add(kind);
                  }
                }
              }
            }
          });
          for (const kind of foundKinds) {
            let suggest;
            if (kind === "surrogatePairWithoutUFlag") {
              suggest = [{
                messageId: "suggestUnicodeFlag",
                fix: unicodeFixer
              }];
            }
            context.report({
              node,
              messageId: kind,
              suggest
            });
          }
        }
        function isValidWithUnicodeFlag(pattern) {
          const { ecmaVersion } = context.languageOptions;
          if (ecmaVersion <= 5) {
            return false;
          }
          const validator = new RegExpValidator({
            ecmaVersion: Math.min(ecmaVersion, REGEXPP_LATEST_ECMA_VERSION)
          });
          try {
            validator.validatePattern(
              pattern,
              void 0,
              void 0,
              /* uFlag = */
              true
            );
          } catch {
            return false;
          }
          return true;
        }
        return {
          "Literal[regex]"(node) {
            verify(node, node.regex.pattern, node.regex.flags, (fixer) => {
              if (!isValidWithUnicodeFlag(node.regex.pattern)) {
                return null;
              }
              return fixer.insertTextAfter(node, "u");
            });
          },
          "Program"() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            for (const { node } of tracker.iterateGlobalReferences({
              RegExp: { [CALL]: true, [CONSTRUCT]: true }
            })) {
              const [patternNode, flagsNode] = node.arguments;
              const pattern = getStringIfConstant(patternNode, scope);
              const flags = getStringIfConstant(flagsNode, scope);
              if (typeof pattern === "string") {
                verify(node, pattern, flags || "", (fixer) => {
                  if (!isValidWithUnicodeFlag(pattern)) {
                    return null;
                  }
                  if (node.arguments.length === 1) {
                    const penultimateToken = sourceCode.getLastToken(node, { skip: 1 });
                    return fixer.insertTextAfter(
                      penultimateToken,
                      astUtils.isCommaToken(penultimateToken) ? ' "u",' : ', "u"'
                    );
                  }
                  if (flagsNode.type === "Literal" && typeof flagsNode.value === "string" || flagsNode.type === "TemplateLiteral") {
                    const range = [flagsNode.range[0], flagsNode.range[1] - 1];
                    return fixer.insertTextAfterRange(range, "u");
                  }
                  return null;
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-mixed-operators.js
var require_no_mixed_operators = __commonJS({
  "node_modules/eslint/lib/rules/no-mixed-operators.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var ARITHMETIC_OPERATORS = ["+", "-", "*", "/", "%", "**"];
    var BITWISE_OPERATORS = ["&", "|", "^", "~", "<<", ">>", ">>>"];
    var COMPARISON_OPERATORS = ["==", "!=", "===", "!==", ">", ">=", "<", "<="];
    var LOGICAL_OPERATORS = ["&&", "||"];
    var RELATIONAL_OPERATORS = ["in", "instanceof"];
    var TERNARY_OPERATOR = ["?:"];
    var COALESCE_OPERATOR = ["??"];
    var ALL_OPERATORS = [].concat(
      ARITHMETIC_OPERATORS,
      BITWISE_OPERATORS,
      COMPARISON_OPERATORS,
      LOGICAL_OPERATORS,
      RELATIONAL_OPERATORS,
      TERNARY_OPERATOR,
      COALESCE_OPERATOR
    );
    var DEFAULT_GROUPS = [
      ARITHMETIC_OPERATORS,
      BITWISE_OPERATORS,
      COMPARISON_OPERATORS,
      LOGICAL_OPERATORS,
      RELATIONAL_OPERATORS
    ];
    var TARGET_NODE_TYPE = /^(?:Binary|Logical|Conditional)Expression$/u;
    function normalizeOptions(options = {}) {
      const hasGroups = options.groups && options.groups.length > 0;
      const groups = hasGroups ? options.groups : DEFAULT_GROUPS;
      const allowSamePrecedence = options.allowSamePrecedence !== false;
      return {
        groups,
        allowSamePrecedence
      };
    }
    function includesBothInAGroup(groups, left, right) {
      return groups.some((group) => group.includes(left) && group.includes(right));
    }
    function getChildNode(node) {
      return node.type === "ConditionalExpression" ? node.test : node.left;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow mixed binary operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-mixed-operators"
        },
        schema: [
          {
            type: "object",
            properties: {
              groups: {
                type: "array",
                items: {
                  type: "array",
                  items: { enum: ALL_OPERATORS },
                  minItems: 2,
                  uniqueItems: true
                },
                uniqueItems: true
              },
              allowSamePrecedence: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedMixedOperator: "Unexpected mix of '{{leftOperator}}' and '{{rightOperator}}'. Use parentheses to clarify the intended order of operations."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = normalizeOptions(context.options[0]);
        function shouldIgnore(node) {
          const a = node;
          const b = node.parent;
          return !includesBothInAGroup(options.groups, a.operator, b.type === "ConditionalExpression" ? "?:" : b.operator) || options.allowSamePrecedence && astUtils.getPrecedence(a) === astUtils.getPrecedence(b);
        }
        function isMixedWithParent(node) {
          return node.operator !== node.parent.operator && !astUtils.isParenthesised(sourceCode, node);
        }
        function getOperatorToken(node) {
          return sourceCode.getTokenAfter(getChildNode(node), astUtils.isNotClosingParenToken);
        }
        function reportBothOperators(node) {
          const parent = node.parent;
          const left = getChildNode(parent) === node ? node : parent;
          const right = getChildNode(parent) !== node ? node : parent;
          const data = {
            leftOperator: left.operator || "?:",
            rightOperator: right.operator || "?:"
          };
          context.report({
            node: left,
            loc: getOperatorToken(left).loc,
            messageId: "unexpectedMixedOperator",
            data
          });
          context.report({
            node: right,
            loc: getOperatorToken(right).loc,
            messageId: "unexpectedMixedOperator",
            data
          });
        }
        function check(node) {
          if (TARGET_NODE_TYPE.test(node.parent.type) && isMixedWithParent(node) && !shouldIgnore(node)) {
            reportBothOperators(node);
          }
        }
        return {
          BinaryExpression: check,
          LogicalExpression: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-mixed-requires.js
var require_no_mixed_requires = __commonJS({
  "node_modules/eslint/lib/rules/no-mixed-requires.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow `require` calls to be mixed with regular variable declarations",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-mixed-requires"
        },
        schema: [
          {
            oneOf: [
              {
                type: "boolean"
              },
              {
                type: "object",
                properties: {
                  grouping: {
                    type: "boolean"
                  },
                  allowCall: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          noMixRequire: "Do not mix 'require' and other declarations.",
          noMixCoreModuleFileComputed: "Do not mix core, module, file and computed requires."
        }
      },
      create(context) {
        const options = context.options[0];
        let grouping = false, allowCall = false;
        if (typeof options === "object") {
          grouping = options.grouping;
          allowCall = options.allowCall;
        } else {
          grouping = !!options;
        }
        function getBuiltinModules() {
          return [
            "assert",
            "buffer",
            "child_process",
            "cluster",
            "crypto",
            "dgram",
            "dns",
            "domain",
            "events",
            "fs",
            "http",
            "https",
            "net",
            "os",
            "path",
            "punycode",
            "querystring",
            "readline",
            "repl",
            "smalloc",
            "stream",
            "string_decoder",
            "tls",
            "tty",
            "url",
            "util",
            "v8",
            "vm",
            "zlib"
          ];
        }
        const BUILTIN_MODULES = getBuiltinModules();
        const DECL_REQUIRE = "require", DECL_UNINITIALIZED = "uninitialized", DECL_OTHER = "other";
        const REQ_CORE = "core", REQ_FILE = "file", REQ_MODULE = "module", REQ_COMPUTED = "computed";
        function getDeclarationType(initExpression) {
          if (!initExpression) {
            return DECL_UNINITIALIZED;
          }
          if (initExpression.type === "CallExpression" && initExpression.callee.type === "Identifier" && initExpression.callee.name === "require") {
            return DECL_REQUIRE;
          }
          if (allowCall && initExpression.type === "CallExpression" && initExpression.callee.type === "CallExpression") {
            return getDeclarationType(initExpression.callee);
          }
          if (initExpression.type === "MemberExpression") {
            return getDeclarationType(initExpression.object);
          }
          return DECL_OTHER;
        }
        function inferModuleType(initExpression) {
          if (initExpression.type === "MemberExpression") {
            return inferModuleType(initExpression.object);
          }
          if (initExpression.arguments.length === 0) {
            return REQ_COMPUTED;
          }
          const arg = initExpression.arguments[0];
          if (arg.type !== "Literal" || typeof arg.value !== "string") {
            return REQ_COMPUTED;
          }
          if (BUILTIN_MODULES.includes(arg.value)) {
            return REQ_CORE;
          }
          if (/^\.{0,2}\//u.test(arg.value)) {
            return REQ_FILE;
          }
          return REQ_MODULE;
        }
        function isMixed(declarations) {
          const contains = {};
          declarations.forEach((declaration) => {
            const type = getDeclarationType(declaration.init);
            contains[type] = true;
          });
          return !!(contains[DECL_REQUIRE] && (contains[DECL_UNINITIALIZED] || contains[DECL_OTHER]));
        }
        function isGrouped(declarations) {
          const found = {};
          declarations.forEach((declaration) => {
            if (getDeclarationType(declaration.init) === DECL_REQUIRE) {
              found[inferModuleType(declaration.init)] = true;
            }
          });
          return Object.keys(found).length <= 1;
        }
        return {
          VariableDeclaration(node) {
            if (isMixed(node.declarations)) {
              context.report({
                node,
                messageId: "noMixRequire"
              });
            } else if (grouping && !isGrouped(node.declarations)) {
              context.report({
                node,
                messageId: "noMixCoreModuleFileComputed"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-mixed-spaces-and-tabs.js
var require_no_mixed_spaces_and_tabs = __commonJS({
  "node_modules/eslint/lib/rules/no-mixed-spaces-and-tabs.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow mixed spaces and tabs for indentation",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-mixed-spaces-and-tabs"
        },
        schema: [
          {
            enum: ["smart-tabs", true, false]
          }
        ],
        messages: {
          mixedSpacesAndTabs: "Mixed spaces and tabs."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let smartTabs;
        switch (context.options[0]) {
          case true:
          case "smart-tabs":
            smartTabs = true;
            break;
          default:
            smartTabs = false;
        }
        return {
          "Program:exit"(node) {
            const lines = sourceCode.lines, comments = sourceCode.getAllComments(), ignoredCommentLines = /* @__PURE__ */ new Set();
            comments.forEach((comment) => {
              for (let i = comment.loc.start.line + 1; i <= comment.loc.end.line; i++) {
                ignoredCommentLines.add(i);
              }
            });
            let regex = /^(?=( +|\t+))\1(?:\t| )/u;
            if (smartTabs) {
              regex = /^(?=(\t*))\1(?=( +))\2\t/u;
            }
            lines.forEach((line, i) => {
              const match = regex.exec(line);
              if (match) {
                const lineNumber = i + 1;
                const loc = {
                  start: {
                    line: lineNumber,
                    column: match[0].length - 2
                  },
                  end: {
                    line: lineNumber,
                    column: match[0].length
                  }
                };
                if (!ignoredCommentLines.has(lineNumber)) {
                  const containingNode = sourceCode.getNodeByRangeIndex(sourceCode.getIndexFromLoc(loc.start));
                  if (!(containingNode && ["Literal", "TemplateElement"].includes(containingNode.type))) {
                    context.report({
                      node,
                      loc,
                      messageId: "mixedSpacesAndTabs"
                    });
                  }
                }
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-multi-assign.js
var require_no_multi_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-multi-assign.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow use of chained assignment expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-multi-assign"
        },
        schema: [{
          type: "object",
          properties: {
            ignoreNonDeclaration: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          unexpectedChain: "Unexpected chained assignment."
        }
      },
      create(context) {
        const options = context.options[0] || {
          ignoreNonDeclaration: false
        };
        const selectors = [
          "VariableDeclarator > AssignmentExpression.init",
          "PropertyDefinition > AssignmentExpression.value"
        ];
        if (!options.ignoreNonDeclaration) {
          selectors.push("AssignmentExpression > AssignmentExpression.right");
        }
        return {
          [selectors](node) {
            context.report({
              node,
              messageId: "unexpectedChain"
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-multi-spaces.js
var require_no_multi_spaces = __commonJS({
  "node_modules/eslint/lib/rules/no-multi-spaces.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow multiple spaces",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-multi-spaces"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              exceptions: {
                type: "object",
                patternProperties: {
                  "^([A-Z][a-z]*)+$": {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              },
              ignoreEOLComments: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          multipleSpaces: "Multiple spaces found before '{{displayValue}}'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = context.options[0] || {};
        const ignoreEOLComments = options.ignoreEOLComments;
        const exceptions = Object.assign({ Property: true }, options.exceptions);
        const hasExceptions = Object.keys(exceptions).some((key) => exceptions[key]);
        function formatReportedCommentValue(token) {
          const valueLines = token.value.split("\n");
          const value2 = valueLines[0];
          const formattedValue = `${value2.slice(0, 12)}...`;
          return valueLines.length === 1 && value2.length <= 12 ? value2 : formattedValue;
        }
        return {
          Program() {
            sourceCode.tokensAndComments.forEach((leftToken, leftIndex, tokensAndComments) => {
              if (leftIndex === tokensAndComments.length - 1) {
                return;
              }
              const rightToken = tokensAndComments[leftIndex + 1];
              if (!sourceCode.text.slice(leftToken.range[1], rightToken.range[0]).includes("  ") || leftToken.loc.end.line < rightToken.loc.start.line) {
                return;
              }
              if (ignoreEOLComments && astUtils.isCommentToken(rightToken) && (leftIndex === tokensAndComments.length - 2 || rightToken.loc.end.line < tokensAndComments[leftIndex + 2].loc.start.line)) {
                return;
              }
              if (hasExceptions) {
                const parentNode = sourceCode.getNodeByRangeIndex(rightToken.range[0] - 1);
                if (parentNode && exceptions[parentNode.type]) {
                  return;
                }
              }
              let displayValue;
              if (rightToken.type === "Block") {
                displayValue = `/*${formatReportedCommentValue(rightToken)}*/`;
              } else if (rightToken.type === "Line") {
                displayValue = `//${formatReportedCommentValue(rightToken)}`;
              } else {
                displayValue = rightToken.value;
              }
              context.report({
                node: rightToken,
                loc: { start: leftToken.loc.end, end: rightToken.loc.start },
                messageId: "multipleSpaces",
                data: { displayValue },
                fix: (fixer) => fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], " ")
              });
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-multi-str.js
var require_no_multi_str = __commonJS({
  "node_modules/eslint/lib/rules/no-multi-str.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow multiline strings",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-multi-str"
        },
        schema: [],
        messages: {
          multilineString: "Multiline support is limited to browsers supporting ES5 only."
        }
      },
      create(context) {
        function isJSXElement2(node) {
          return node.type.indexOf("JSX") === 0;
        }
        return {
          Literal(node) {
            if (astUtils.LINEBREAK_MATCHER.test(node.raw) && !isJSXElement2(node.parent)) {
              context.report({
                node,
                messageId: "multilineString"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-multiple-empty-lines.js
var require_no_multiple_empty_lines = __commonJS({
  "node_modules/eslint/lib/rules/no-multiple-empty-lines.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow multiple empty lines",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-multiple-empty-lines"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              max: {
                type: "integer",
                minimum: 0
              },
              maxEOF: {
                type: "integer",
                minimum: 0
              },
              maxBOF: {
                type: "integer",
                minimum: 0
              }
            },
            required: ["max"],
            additionalProperties: false
          }
        ],
        messages: {
          blankBeginningOfFile: "Too many blank lines at the beginning of file. Max of {{max}} allowed.",
          blankEndOfFile: "Too many blank lines at the end of file. Max of {{max}} allowed.",
          consecutiveBlank: "More than {{max}} blank {{pluralizedLines}} not allowed."
        }
      },
      create(context) {
        let max2 = 2, maxEOF = max2, maxBOF = max2;
        if (context.options.length) {
          max2 = context.options[0].max;
          maxEOF = typeof context.options[0].maxEOF !== "undefined" ? context.options[0].maxEOF : max2;
          maxBOF = typeof context.options[0].maxBOF !== "undefined" ? context.options[0].maxBOF : max2;
        }
        const sourceCode = context.getSourceCode();
        const allLines = sourceCode.lines[sourceCode.lines.length - 1] === "" ? sourceCode.lines.slice(0, -1) : sourceCode.lines;
        const templateLiteralLines = /* @__PURE__ */ new Set();
        return {
          TemplateLiteral(node) {
            node.quasis.forEach((literalPart) => {
              for (let ignoredLine = literalPart.loc.start.line; ignoredLine < literalPart.loc.end.line; ignoredLine++) {
                templateLiteralLines.add(ignoredLine);
              }
            });
          },
          "Program:exit"(node) {
            return allLines.reduce((nonEmptyLineNumbers, line, index) => {
              if (line.trim() || templateLiteralLines.has(index + 1)) {
                nonEmptyLineNumbers.push(index + 1);
              }
              return nonEmptyLineNumbers;
            }, []).concat(allLines.length + 1).reduce((lastLineNumber, lineNumber) => {
              let messageId, maxAllowed;
              if (lastLineNumber === 0) {
                messageId = "blankBeginningOfFile";
                maxAllowed = maxBOF;
              } else if (lineNumber === allLines.length + 1) {
                messageId = "blankEndOfFile";
                maxAllowed = maxEOF;
              } else {
                messageId = "consecutiveBlank";
                maxAllowed = max2;
              }
              if (lineNumber - lastLineNumber - 1 > maxAllowed) {
                context.report({
                  node,
                  loc: {
                    start: { line: lastLineNumber + maxAllowed + 1, column: 0 },
                    end: { line: lineNumber, column: 0 }
                  },
                  messageId,
                  data: {
                    max: maxAllowed,
                    pluralizedLines: maxAllowed === 1 ? "line" : "lines"
                  },
                  fix(fixer) {
                    const rangeStart = sourceCode.getIndexFromLoc({ line: lastLineNumber + 1, column: 0 });
                    const lineNumberAfterRemovedLines = lineNumber - maxAllowed;
                    const rangeEnd = lineNumberAfterRemovedLines <= allLines.length ? sourceCode.getIndexFromLoc({ line: lineNumberAfterRemovedLines, column: 0 }) : sourceCode.text.length;
                    return fixer.removeRange([rangeStart, rangeEnd]);
                  }
                });
              }
              return lineNumber;
            }, 0);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-native-reassign.js
var require_no_native_reassign = __commonJS({
  "node_modules/eslint/lib/rules/no-native-reassign.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow assignments to native objects or read-only global variables",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-native-reassign"
        },
        deprecated: true,
        replacedBy: ["no-global-assign"],
        schema: [
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: { type: "string" },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          nativeReassign: "Read-only global '{{name}}' should not be modified."
        }
      },
      create(context) {
        const config = context.options[0];
        const exceptions = config && config.exceptions || [];
        function checkReference(reference, index, references) {
          const identifier3 = reference.identifier;
          if (reference.init === false && reference.isWrite() && /*
           * Destructuring assignments can have multiple default value,
           * so possibly there are multiple writeable references for the same identifier.
           */
          (index === 0 || references[index - 1].identifier !== identifier3)) {
            context.report({
              node: identifier3,
              messageId: "nativeReassign",
              data: identifier3
            });
          }
        }
        function checkVariable(variable) {
          if (variable.writeable === false && !exceptions.includes(variable.name)) {
            variable.references.forEach(checkReference);
          }
        }
        return {
          Program() {
            const globalScope = context.getScope();
            globalScope.variables.forEach(checkVariable);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-negated-condition.js
var require_no_negated_condition = __commonJS({
  "node_modules/eslint/lib/rules/no-negated-condition.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow negated conditions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-negated-condition"
        },
        schema: [],
        messages: {
          unexpectedNegated: "Unexpected negated condition."
        }
      },
      create(context) {
        function hasElseWithoutCondition(node) {
          return node.alternate && node.alternate.type !== "IfStatement";
        }
        function isNegatedUnaryExpression(test) {
          return test.type === "UnaryExpression" && test.operator === "!";
        }
        function isNegatedBinaryExpression(test) {
          return test.type === "BinaryExpression" && (test.operator === "!=" || test.operator === "!==");
        }
        function isNegatedIf(node) {
          return isNegatedUnaryExpression(node.test) || isNegatedBinaryExpression(node.test);
        }
        return {
          IfStatement(node) {
            if (!hasElseWithoutCondition(node)) {
              return;
            }
            if (isNegatedIf(node)) {
              context.report({
                node,
                messageId: "unexpectedNegated"
              });
            }
          },
          ConditionalExpression(node) {
            if (isNegatedIf(node)) {
              context.report({
                node,
                messageId: "unexpectedNegated"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-negated-in-lhs.js
var require_no_negated_in_lhs = __commonJS({
  "node_modules/eslint/lib/rules/no-negated-in-lhs.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow negating the left operand in `in` expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-negated-in-lhs"
        },
        replacedBy: ["no-unsafe-negation"],
        deprecated: true,
        schema: [],
        messages: {
          negatedLHS: "The 'in' expression's left operand is negated."
        }
      },
      create(context) {
        return {
          BinaryExpression(node) {
            if (node.operator === "in" && node.left.type === "UnaryExpression" && node.left.operator === "!") {
              context.report({ node, messageId: "negatedLHS" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-nested-ternary.js
var require_no_nested_ternary = __commonJS({
  "node_modules/eslint/lib/rules/no-nested-ternary.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow nested ternary expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-nested-ternary"
        },
        schema: [],
        messages: {
          noNestedTernary: "Do not nest ternary expressions."
        }
      },
      create(context) {
        return {
          ConditionalExpression(node) {
            if (node.alternate.type === "ConditionalExpression" || node.consequent.type === "ConditionalExpression") {
              context.report({
                node,
                messageId: "noNestedTernary"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new.js
var require_no_new = __commonJS({
  "node_modules/eslint/lib/rules/no-new.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `new` operators outside of assignments or comparisons",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new"
        },
        schema: [],
        messages: {
          noNewStatement: "Do not use 'new' for side effects."
        }
      },
      create(context) {
        return {
          "ExpressionStatement > NewExpression"(node) {
            context.report({
              node: node.parent,
              messageId: "noNewStatement"
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-func.js
var require_no_new_func = __commonJS({
  "node_modules/eslint/lib/rules/no-new-func.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var callMethods = /* @__PURE__ */ new Set(["apply", "bind", "call"]);
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `new` operators with the `Function` object",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new-func"
        },
        schema: [],
        messages: {
          noFunctionConstructor: "The Function constructor is eval."
        }
      },
      create(context) {
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            const variable = globalScope.set.get("Function");
            if (variable && variable.defs.length === 0) {
              variable.references.forEach((ref) => {
                const node = ref.identifier;
                const { parent } = node;
                let evalNode;
                if (parent) {
                  if (node === parent.callee && (parent.type === "NewExpression" || parent.type === "CallExpression")) {
                    evalNode = parent;
                  } else if (parent.type === "MemberExpression" && node === parent.object && callMethods.has(astUtils.getStaticPropertyName(parent))) {
                    const maybeCallee = parent.parent.type === "ChainExpression" ? parent.parent : parent;
                    if (maybeCallee.parent.type === "CallExpression" && maybeCallee.parent.callee === maybeCallee) {
                      evalNode = maybeCallee.parent;
                    }
                  }
                }
                if (evalNode) {
                  context.report({
                    node: evalNode,
                    messageId: "noFunctionConstructor"
                  });
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-native-nonconstructor.js
var require_no_new_native_nonconstructor = __commonJS({
  "node_modules/eslint/lib/rules/no-new-native-nonconstructor.js"(exports, module2) {
    "use strict";
    var nonConstructorGlobalFunctionNames = ["Symbol", "BigInt"];
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow `new` operators with global non-constructor functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new-native-nonconstructor"
        },
        schema: [],
        messages: {
          noNewNonconstructor: "`{{name}}` cannot be called as a constructor."
        }
      },
      create(context) {
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            for (const nonConstructorName of nonConstructorGlobalFunctionNames) {
              const variable = globalScope.set.get(nonConstructorName);
              if (variable && variable.defs.length === 0) {
                variable.references.forEach((ref) => {
                  const node = ref.identifier;
                  const parent = node.parent;
                  if (parent && parent.type === "NewExpression" && parent.callee === node) {
                    context.report({
                      node,
                      messageId: "noNewNonconstructor",
                      data: { name: nonConstructorName }
                    });
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-object.js
var require_no_new_object = __commonJS({
  "node_modules/eslint/lib/rules/no-new-object.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `Object` constructors",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new-object"
        },
        schema: [],
        messages: {
          preferLiteral: "The object literal notation {} is preferable."
        }
      },
      create(context) {
        return {
          NewExpression(node) {
            const variable = astUtils.getVariableByName(
              context.getScope(),
              node.callee.name
            );
            if (variable && variable.identifiers.length > 0) {
              return;
            }
            if (node.callee.name === "Object") {
              context.report({
                node,
                messageId: "preferLiteral"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-require.js
var require_no_new_require = __commonJS({
  "node_modules/eslint/lib/rules/no-new-require.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow `new` operators with calls to `require`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new-require"
        },
        schema: [],
        messages: {
          noNewRequire: "Unexpected use of new with require."
        }
      },
      create(context) {
        return {
          NewExpression(node) {
            if (node.callee.type === "Identifier" && node.callee.name === "require") {
              context.report({
                node,
                messageId: "noNewRequire"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-symbol.js
var require_no_new_symbol = __commonJS({
  "node_modules/eslint/lib/rules/no-new-symbol.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow `new` operators with the `Symbol` object",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-new-symbol"
        },
        schema: [],
        messages: {
          noNewSymbol: "`Symbol` cannot be called as a constructor."
        }
      },
      create(context) {
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            const variable = globalScope.set.get("Symbol");
            if (variable && variable.defs.length === 0) {
              variable.references.forEach((ref) => {
                const node = ref.identifier;
                const parent = node.parent;
                if (parent && parent.type === "NewExpression" && parent.callee === node) {
                  context.report({
                    node,
                    messageId: "noNewSymbol"
                  });
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-new-wrappers.js
var require_no_new_wrappers = __commonJS({
  "node_modules/eslint/lib/rules/no-new-wrappers.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `new` operators with the `String`, `Number`, and `Boolean` objects",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-new-wrappers"
        },
        schema: [],
        messages: {
          noConstructor: "Do not use {{fn}} as a constructor."
        }
      },
      create(context) {
        return {
          NewExpression(node) {
            const wrapperObjects = ["String", "Number", "Boolean"];
            if (wrapperObjects.includes(node.callee.name)) {
              context.report({
                node,
                messageId: "noConstructor",
                data: { fn: node.callee.name }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-nonoctal-decimal-escape.js
var require_no_nonoctal_decimal_escape = __commonJS({
  "node_modules/eslint/lib/rules/no-nonoctal-decimal-escape.js"(exports, module2) {
    "use strict";
    var QUICK_TEST_REGEX = /\\[89]/u;
    function getUnicodeEscape(character) {
      return `\\u${character.charCodeAt(0).toString(16).padStart(4, "0")}`;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `\\8` and `\\9` escape sequences in string literals",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-nonoctal-decimal-escape"
        },
        hasSuggestions: true,
        schema: [],
        messages: {
          decimalEscape: "Don't use '{{decimalEscape}}' escape sequence.",
          // suggestions
          refactor: "Replace '{{original}}' with '{{replacement}}'. This maintains the current functionality.",
          escapeBackslash: "Replace '{{original}}' with '{{replacement}}' to include the actual backslash character."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function createSuggestion(messageId, range, replacement) {
          return {
            messageId,
            data: {
              original: sourceCode.getText().slice(...range),
              replacement
            },
            fix(fixer) {
              return fixer.replaceTextRange(range, replacement);
            }
          };
        }
        return {
          Literal(node) {
            if (typeof node.value !== "string") {
              return;
            }
            if (!QUICK_TEST_REGEX.test(node.raw)) {
              return;
            }
            const regex = /(?:[^\\]|(?<previousEscape>\\.))*?(?<decimalEscape>\\[89])/suy;
            let match;
            while (match = regex.exec(node.raw)) {
              const { previousEscape, decimalEscape } = match.groups;
              const decimalEscapeRangeEnd = node.range[0] + match.index + match[0].length;
              const decimalEscapeRangeStart = decimalEscapeRangeEnd - decimalEscape.length;
              const decimalEscapeRange = [decimalEscapeRangeStart, decimalEscapeRangeEnd];
              const suggest = [];
              if (previousEscape === "\\0") {
                suggest.push(
                  createSuggestion(
                    // "\0\8" -> "\u00008"
                    "refactor",
                    [decimalEscapeRangeStart - previousEscape.length, decimalEscapeRangeEnd],
                    `${getUnicodeEscape("\0")}${decimalEscape[1]}`
                  ),
                  createSuggestion(
                    // "\8" -> "\u0038"
                    "refactor",
                    decimalEscapeRange,
                    getUnicodeEscape(decimalEscape[1])
                  )
                );
              } else {
                suggest.push(
                  createSuggestion(
                    // "\8" -> "8"
                    "refactor",
                    decimalEscapeRange,
                    decimalEscape[1]
                  )
                );
              }
              suggest.push(
                createSuggestion(
                  // "\8" -> "\\8"
                  "escapeBackslash",
                  decimalEscapeRange,
                  `\\${decimalEscape}`
                )
              );
              context.report({
                node,
                loc: {
                  start: sourceCode.getLocFromIndex(decimalEscapeRangeStart),
                  end: sourceCode.getLocFromIndex(decimalEscapeRangeEnd)
                },
                messageId: "decimalEscape",
                data: {
                  decimalEscape
                },
                suggest
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-obj-calls.js
var require_no_obj_calls = __commonJS({
  "node_modules/eslint/lib/rules/no-obj-calls.js"(exports, module2) {
    "use strict";
    var { CALL, CONSTRUCT, ReferenceTracker } = require_eslint_utils();
    var getPropertyName = require_ast_utils2().getStaticPropertyName;
    var nonCallableGlobals = ["Atomics", "JSON", "Math", "Reflect", "Intl"];
    function getReportNodeName(node) {
      if (node.type === "ChainExpression") {
        return getReportNodeName(node.expression);
      }
      if (node.type === "MemberExpression") {
        return getPropertyName(node);
      }
      return node.name;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow calling global object properties as functions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-obj-calls"
        },
        schema: [],
        messages: {
          unexpectedCall: "'{{name}}' is not a function.",
          unexpectedRefCall: "'{{name}}' is reference to '{{ref}}', which is not a function."
        }
      },
      create(context) {
        return {
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const traceMap = {};
            for (const g of nonCallableGlobals) {
              traceMap[g] = {
                [CALL]: true,
                [CONSTRUCT]: true
              };
            }
            for (const { node, path: path2 } of tracker.iterateGlobalReferences(traceMap)) {
              const name = getReportNodeName(node.callee);
              const ref = path2[0];
              const messageId = name === ref ? "unexpectedCall" : "unexpectedRefCall";
              context.report({ node, messageId, data: { name, ref } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-octal.js
var require_no_octal = __commonJS({
  "node_modules/eslint/lib/rules/no-octal.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow octal literals",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-octal"
        },
        schema: [],
        messages: {
          noOctal: "Octal literals should not be used."
        }
      },
      create(context) {
        return {
          Literal(node) {
            if (typeof node.value === "number" && /^0[0-9]/u.test(node.raw)) {
              context.report({
                node,
                messageId: "noOctal"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-octal-escape.js
var require_no_octal_escape = __commonJS({
  "node_modules/eslint/lib/rules/no-octal-escape.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow octal escape sequences in string literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-octal-escape"
        },
        schema: [],
        messages: {
          octalEscapeSequence: "Don't use octal: '\\{{sequence}}'. Use '\\u....' instead."
        }
      },
      create(context) {
        return {
          Literal(node) {
            if (typeof node.value !== "string") {
              return;
            }
            const match = node.raw.match(
              /^(?:[^\\]|\\.)*?\\([0-3][0-7]{1,2}|[4-7][0-7]|0(?=[89])|[1-7])/su
            );
            if (match) {
              context.report({
                node,
                messageId: "octalEscapeSequence",
                data: { sequence: match[1] }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-param-reassign.js
var require_no_param_reassign = __commonJS({
  "node_modules/eslint/lib/rules/no-param-reassign.js"(exports, module2) {
    "use strict";
    var stopNodePattern = /(?:Statement|Declaration|Function(?:Expression)?|Program)$/u;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow reassigning `function` parameters",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-param-reassign"
        },
        schema: [
          {
            oneOf: [
              {
                type: "object",
                properties: {
                  props: {
                    enum: [false]
                  }
                },
                additionalProperties: false
              },
              {
                type: "object",
                properties: {
                  props: {
                    enum: [true]
                  },
                  ignorePropertyModificationsFor: {
                    type: "array",
                    items: {
                      type: "string"
                    },
                    uniqueItems: true
                  },
                  ignorePropertyModificationsForRegex: {
                    type: "array",
                    items: {
                      type: "string"
                    },
                    uniqueItems: true
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          assignmentToFunctionParam: "Assignment to function parameter '{{name}}'.",
          assignmentToFunctionParamProp: "Assignment to property of function parameter '{{name}}'."
        }
      },
      create(context) {
        const props = context.options[0] && context.options[0].props;
        const ignoredPropertyAssignmentsFor = context.options[0] && context.options[0].ignorePropertyModificationsFor || [];
        const ignoredPropertyAssignmentsForRegex = context.options[0] && context.options[0].ignorePropertyModificationsForRegex || [];
        function isModifyingProp(reference) {
          let node = reference.identifier;
          let parent = node.parent;
          while (parent && (!stopNodePattern.test(parent.type) || parent.type === "ForInStatement" || parent.type === "ForOfStatement")) {
            switch (parent.type) {
              case "AssignmentExpression":
                return parent.left === node;
              case "UpdateExpression":
                return true;
              case "UnaryExpression":
                if (parent.operator === "delete") {
                  return true;
                }
                break;
              case "ForInStatement":
              case "ForOfStatement":
                if (parent.left === node) {
                  return true;
                }
                return false;
              case "CallExpression":
                if (parent.callee !== node) {
                  return false;
                }
                break;
              case "MemberExpression":
                if (parent.property === node) {
                  return false;
                }
                break;
              case "Property":
                if (parent.key === node) {
                  return false;
                }
                break;
              case "ConditionalExpression":
                if (parent.test === node) {
                  return false;
                }
                break;
            }
            node = parent;
            parent = node.parent;
          }
          return false;
        }
        function isIgnoredPropertyAssignment(identifierName) {
          return ignoredPropertyAssignmentsFor.includes(identifierName) || ignoredPropertyAssignmentsForRegex.some((ignored) => new RegExp(ignored, "u").test(identifierName));
        }
        function checkReference(reference, index, references) {
          const identifier3 = reference.identifier;
          if (identifier3 && !reference.init && /*
           * Destructuring assignments can have multiple default value,
           * so possibly there are multiple writeable references for the same identifier.
           */
          (index === 0 || references[index - 1].identifier !== identifier3)) {
            if (reference.isWrite()) {
              context.report({
                node: identifier3,
                messageId: "assignmentToFunctionParam",
                data: { name: identifier3.name }
              });
            } else if (props && isModifyingProp(reference) && !isIgnoredPropertyAssignment(identifier3.name)) {
              context.report({
                node: identifier3,
                messageId: "assignmentToFunctionParamProp",
                data: { name: identifier3.name }
              });
            }
          }
        }
        function checkVariable(variable) {
          if (variable.defs[0].type === "Parameter") {
            variable.references.forEach(checkReference);
          }
        }
        function checkForFunction(node) {
          context.getDeclaredVariables(node).forEach(checkVariable);
        }
        return {
          // `:exit` is needed for the `node.parent` property of identifier nodes.
          "FunctionDeclaration:exit": checkForFunction,
          "FunctionExpression:exit": checkForFunction,
          "ArrowFunctionExpression:exit": checkForFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-path-concat.js
var require_no_path_concat = __commonJS({
  "node_modules/eslint/lib/rules/no-path-concat.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow string concatenation with `__dirname` and `__filename`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-path-concat"
        },
        schema: [],
        messages: {
          usePathFunctions: "Use path.join() or path.resolve() instead of + to create paths."
        }
      },
      create(context) {
        const MATCHER = /^__(?:dir|file)name$/u;
        return {
          BinaryExpression(node) {
            const left = node.left, right = node.right;
            if (node.operator === "+" && (left.type === "Identifier" && MATCHER.test(left.name) || right.type === "Identifier" && MATCHER.test(right.name))) {
              context.report({
                node,
                messageId: "usePathFunctions"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-plusplus.js
var require_no_plusplus = __commonJS({
  "node_modules/eslint/lib/rules/no-plusplus.js"(exports, module2) {
    "use strict";
    function isForStatementUpdate(node) {
      const parent = node.parent;
      return parent.type === "ForStatement" && parent.update === node;
    }
    function isForLoopAfterthought(node) {
      const parent = node.parent;
      if (parent.type === "SequenceExpression") {
        return isForLoopAfterthought(parent);
      }
      return isForStatementUpdate(node);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the unary operators `++` and `--`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-plusplus"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowForLoopAfterthoughts: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedUnaryOp: "Unary operator '{{operator}}' used."
        }
      },
      create(context) {
        const config = context.options[0];
        let allowForLoopAfterthoughts = false;
        if (typeof config === "object") {
          allowForLoopAfterthoughts = config.allowForLoopAfterthoughts === true;
        }
        return {
          UpdateExpression(node) {
            if (allowForLoopAfterthoughts && isForLoopAfterthought(node)) {
              return;
            }
            context.report({
              node,
              messageId: "unexpectedUnaryOp",
              data: {
                operator: node.operator
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-process-env.js
var require_no_process_env = __commonJS({
  "node_modules/eslint/lib/rules/no-process-env.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow the use of `process.env`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-process-env"
        },
        schema: [],
        messages: {
          unexpectedProcessEnv: "Unexpected use of process.env."
        }
      },
      create(context) {
        return {
          MemberExpression(node) {
            const objectName = node.object.name, propertyName = node.property.name;
            if (objectName === "process" && !node.computed && propertyName && propertyName === "env") {
              context.report({ node, messageId: "unexpectedProcessEnv" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-process-exit.js
var require_no_process_exit = __commonJS({
  "node_modules/eslint/lib/rules/no-process-exit.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow the use of `process.exit()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-process-exit"
        },
        schema: [],
        messages: {
          noProcessExit: "Don't use process.exit(); throw an error instead."
        }
      },
      create(context) {
        return {
          "CallExpression > MemberExpression.callee[object.name = 'process'][property.name = 'exit']"(node) {
            context.report({ node: node.parent, messageId: "noProcessExit" });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-promise-executor-return.js
var require_no_promise_executor_return = __commonJS({
  "node_modules/eslint/lib/rules/no-promise-executor-return.js"(exports, module2) {
    "use strict";
    var { findVariable } = require_eslint_utils();
    var functionTypesToCheck = /* @__PURE__ */ new Set(["ArrowFunctionExpression", "FunctionExpression"]);
    function isGlobalReference(node, scope) {
      const variable = findVariable(scope, node);
      return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
    }
    function getOuterScope(scope) {
      const upper = scope.upper;
      if (upper.type === "function-expression-name") {
        return upper.upper;
      }
      return upper;
    }
    function isPromiseExecutor(node, scope) {
      const parent = node.parent;
      return parent.type === "NewExpression" && parent.arguments[0] === node && parent.callee.type === "Identifier" && parent.callee.name === "Promise" && isGlobalReference(parent.callee, getOuterScope(scope));
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow returning values from Promise executor functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-promise-executor-return"
        },
        schema: [],
        messages: {
          returnsValue: "Return values from promise executor functions cannot be read."
        }
      },
      create(context) {
        let funcInfo = null;
        function report(node) {
          context.report({ node, messageId: "returnsValue" });
        }
        return {
          onCodePathStart(_, node) {
            funcInfo = {
              upper: funcInfo,
              shouldCheck: functionTypesToCheck.has(node.type) && isPromiseExecutor(node, context.getScope())
            };
            if (funcInfo.shouldCheck && node.type === "ArrowFunctionExpression" && node.expression) {
              report(node.body);
            }
          },
          onCodePathEnd() {
            funcInfo = funcInfo.upper;
          },
          ReturnStatement(node) {
            if (funcInfo.shouldCheck && node.argument) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-proto.js
var require_no_proto = __commonJS({
  "node_modules/eslint/lib/rules/no-proto.js"(exports, module2) {
    "use strict";
    var { getStaticPropertyName } = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of the `__proto__` property",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-proto"
        },
        schema: [],
        messages: {
          unexpectedProto: "The '__proto__' property is deprecated."
        }
      },
      create(context) {
        return {
          MemberExpression(node) {
            if (getStaticPropertyName(node) === "__proto__") {
              context.report({ node, messageId: "unexpectedProto" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-prototype-builtins.js
var require_no_prototype_builtins = __commonJS({
  "node_modules/eslint/lib/rules/no-prototype-builtins.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow calling some `Object.prototype` methods directly on objects",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-prototype-builtins"
        },
        schema: [],
        messages: {
          prototypeBuildIn: "Do not access Object.prototype method '{{prop}}' from target object."
        }
      },
      create(context) {
        const DISALLOWED_PROPS = /* @__PURE__ */ new Set([
          "hasOwnProperty",
          "isPrototypeOf",
          "propertyIsEnumerable"
        ]);
        function disallowBuiltIns(node) {
          const callee = astUtils.skipChainExpression(node.callee);
          if (callee.type !== "MemberExpression") {
            return;
          }
          const propName = astUtils.getStaticPropertyName(callee);
          if (propName !== null && DISALLOWED_PROPS.has(propName)) {
            context.report({
              messageId: "prototypeBuildIn",
              loc: callee.property.loc,
              data: { prop: propName },
              node
            });
          }
        }
        return {
          CallExpression: disallowBuiltIns
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-redeclare.js
var require_no_redeclare = __commonJS({
  "node_modules/eslint/lib/rules/no-redeclare.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow variable redeclaration",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-redeclare"
        },
        messages: {
          redeclared: "'{{id}}' is already defined.",
          redeclaredAsBuiltin: "'{{id}}' is already defined as a built-in global variable.",
          redeclaredBySyntax: "'{{id}}' is already defined by a variable declaration."
        },
        schema: [
          {
            type: "object",
            properties: {
              builtinGlobals: { type: "boolean", default: true }
            },
            additionalProperties: false
          }
        ]
      },
      create(context) {
        const options = {
          builtinGlobals: Boolean(
            context.options.length === 0 || context.options[0].builtinGlobals
          )
        };
        const sourceCode = context.getSourceCode();
        function* iterateDeclarations(variable) {
          if (options.builtinGlobals && (variable.eslintImplicitGlobalSetting === "readonly" || variable.eslintImplicitGlobalSetting === "writable")) {
            yield { type: "builtin" };
          }
          for (const id of variable.identifiers) {
            yield { type: "syntax", node: id, loc: id.loc };
          }
          if (variable.eslintExplicitGlobalComments) {
            for (const comment of variable.eslintExplicitGlobalComments) {
              yield {
                type: "comment",
                node: comment,
                loc: astUtils.getNameLocationInGlobalDirectiveComment(
                  sourceCode,
                  comment,
                  variable.name
                )
              };
            }
          }
        }
        function findVariablesInScope(scope) {
          for (const variable of scope.variables) {
            const [
              declaration,
              ...extraDeclarations
            ] = iterateDeclarations(variable);
            if (extraDeclarations.length === 0) {
              continue;
            }
            const detailMessageId = declaration.type === "builtin" ? "redeclaredAsBuiltin" : "redeclaredBySyntax";
            const data = { id: variable.name };
            for (const { type, node, loc } of extraDeclarations) {
              const messageId = type === declaration.type ? "redeclared" : detailMessageId;
              context.report({ node, loc, messageId, data });
            }
          }
        }
        function checkForBlock(node) {
          const scope = context.getScope();
          if (scope.block === node) {
            findVariablesInScope(scope);
          }
        }
        return {
          Program() {
            const scope = context.getScope();
            findVariablesInScope(scope);
            if (scope.type === "global" && scope.childScopes[0] && // The special scope's block is the Program node.
            scope.block === scope.childScopes[0].block) {
              findVariablesInScope(scope.childScopes[0]);
            }
          },
          FunctionDeclaration: checkForBlock,
          FunctionExpression: checkForBlock,
          ArrowFunctionExpression: checkForBlock,
          StaticBlock: checkForBlock,
          BlockStatement: checkForBlock,
          ForStatement: checkForBlock,
          ForInStatement: checkForBlock,
          ForOfStatement: checkForBlock,
          SwitchStatement: checkForBlock
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-regex-spaces.js
var require_no_regex_spaces = __commonJS({
  "node_modules/eslint/lib/rules/no-regex-spaces.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var regexpp = require_regexpp();
    var regExpParser = new regexpp.RegExpParser();
    var DOUBLE_SPACE = / {2}/u;
    function isString(node) {
      return node && node.type === "Literal" && typeof node.value === "string";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow multiple spaces in regular expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-regex-spaces"
        },
        schema: [],
        fixable: "code",
        messages: {
          multipleSpaces: "Spaces are hard to count. Use {{{length}}}."
        }
      },
      create(context) {
        function checkRegex(nodeToReport, pattern, rawPattern, rawPatternStartRange, flags) {
          if (!DOUBLE_SPACE.test(rawPattern)) {
            return;
          }
          const characterClassNodes = [];
          let regExpAST;
          try {
            regExpAST = regExpParser.parsePattern(pattern, 0, pattern.length, flags.includes("u"));
          } catch {
            return;
          }
          regexpp.visitRegExpAST(regExpAST, {
            onCharacterClassEnter(ccNode) {
              characterClassNodes.push(ccNode);
            }
          });
          const spacesPattern = /( {2,})(?: [+*{?]|[^+*{?]|$)/gu;
          let match;
          while (match = spacesPattern.exec(pattern)) {
            const { 1: { length }, index } = match;
            if (characterClassNodes.every(({ start, end }) => index < start || end <= index)) {
              context.report({
                node: nodeToReport,
                messageId: "multipleSpaces",
                data: { length },
                fix(fixer) {
                  if (pattern !== rawPattern) {
                    return null;
                  }
                  return fixer.replaceTextRange(
                    [rawPatternStartRange + index, rawPatternStartRange + index + length],
                    ` {${length}}`
                  );
                }
              });
              return;
            }
          }
        }
        function checkLiteral(node) {
          if (node.regex) {
            const pattern = node.regex.pattern;
            const rawPattern = node.raw.slice(1, node.raw.lastIndexOf("/"));
            const rawPatternStartRange = node.range[0] + 1;
            const flags = node.regex.flags;
            checkRegex(
              node,
              pattern,
              rawPattern,
              rawPatternStartRange,
              flags
            );
          }
        }
        function checkFunction(node) {
          const scope = context.getScope();
          const regExpVar = astUtils.getVariableByName(scope, "RegExp");
          const shadowed = regExpVar && regExpVar.defs.length > 0;
          const patternNode = node.arguments[0];
          const flagsNode = node.arguments[1];
          if (node.callee.type === "Identifier" && node.callee.name === "RegExp" && isString(patternNode) && !shadowed) {
            const pattern = patternNode.value;
            const rawPattern = patternNode.raw.slice(1, -1);
            const rawPatternStartRange = patternNode.range[0] + 1;
            const flags = isString(flagsNode) ? flagsNode.value : "";
            checkRegex(
              node,
              pattern,
              rawPattern,
              rawPatternStartRange,
              flags
            );
          }
        }
        return {
          Literal: checkLiteral,
          CallExpression: checkFunction,
          NewExpression: checkFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-exports.js
var require_no_restricted_exports = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-exports.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified names in exports",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-exports"
        },
        schema: [{
          type: "object",
          properties: {
            restrictedNamedExports: {
              type: "array",
              items: {
                type: "string"
              },
              uniqueItems: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          restrictedNamed: "'{{name}}' is restricted from being used as an exported name."
        }
      },
      create(context) {
        const restrictedNames = new Set(context.options[0] && context.options[0].restrictedNamedExports);
        function checkExportedName(node) {
          const name = astUtils.getModuleExportName(node);
          if (restrictedNames.has(name)) {
            context.report({
              node,
              messageId: "restrictedNamed",
              data: { name }
            });
          }
        }
        return {
          ExportAllDeclaration(node) {
            if (node.exported) {
              checkExportedName(node.exported);
            }
          },
          ExportNamedDeclaration(node) {
            const declaration = node.declaration;
            if (declaration) {
              if (declaration.type === "FunctionDeclaration" || declaration.type === "ClassDeclaration") {
                checkExportedName(declaration.id);
              } else if (declaration.type === "VariableDeclaration") {
                context.getDeclaredVariables(declaration).map((v) => v.defs.find((d) => d.parent === declaration)).map((d) => d.name).forEach(checkExportedName);
              }
            } else {
              node.specifiers.map((s) => s.exported).forEach(checkExportedName);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-globals.js
var require_no_restricted_globals = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-globals.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified global variables",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-globals"
        },
        schema: {
          type: "array",
          items: {
            oneOf: [
              {
                type: "string"
              },
              {
                type: "object",
                properties: {
                  name: { type: "string" },
                  message: { type: "string" }
                },
                required: ["name"],
                additionalProperties: false
              }
            ]
          },
          uniqueItems: true,
          minItems: 0
        },
        messages: {
          defaultMessage: "Unexpected use of '{{name}}'.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          customMessage: "Unexpected use of '{{name}}'. {{customMessage}}"
        }
      },
      create(context) {
        if (context.options.length === 0) {
          return {};
        }
        const restrictedGlobalMessages = context.options.reduce((memo, option) => {
          if (typeof option === "string") {
            memo[option] = null;
          } else {
            memo[option.name] = option.message;
          }
          return memo;
        }, {});
        function reportReference(reference) {
          const name = reference.identifier.name, customMessage = restrictedGlobalMessages[name], messageId = customMessage ? "customMessage" : "defaultMessage";
          context.report({
            node: reference.identifier,
            messageId,
            data: {
              name,
              customMessage
            }
          });
        }
        function isRestricted(name) {
          return Object.prototype.hasOwnProperty.call(restrictedGlobalMessages, name);
        }
        return {
          Program() {
            const scope = context.getScope();
            scope.variables.forEach((variable) => {
              if (!variable.defs.length && isRestricted(variable.name)) {
                variable.references.forEach(reportReference);
              }
            });
            scope.through.forEach((reference) => {
              if (isRestricted(reference.identifier.name)) {
                reportReference(reference);
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-imports.js
var require_no_restricted_imports = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-imports.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var ignore = require_ignore();
    var arrayOfStringsOrObjects = {
      type: "array",
      items: {
        anyOf: [
          { type: "string" },
          {
            type: "object",
            properties: {
              name: { type: "string" },
              message: {
                type: "string",
                minLength: 1
              },
              importNames: {
                type: "array",
                items: {
                  type: "string"
                }
              }
            },
            additionalProperties: false,
            required: ["name"]
          }
        ]
      },
      uniqueItems: true
    };
    var arrayOfStringsOrObjectPatterns = {
      anyOf: [
        {
          type: "array",
          items: {
            type: "string"
          },
          uniqueItems: true
        },
        {
          type: "array",
          items: {
            type: "object",
            properties: {
              importNames: {
                type: "array",
                items: {
                  type: "string"
                },
                minItems: 1,
                uniqueItems: true
              },
              group: {
                type: "array",
                items: {
                  type: "string"
                },
                minItems: 1,
                uniqueItems: true
              },
              message: {
                type: "string",
                minLength: 1
              },
              caseSensitive: {
                type: "boolean"
              }
            },
            additionalProperties: false,
            required: ["group"]
          },
          uniqueItems: true
        }
      ]
    };
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified modules when loaded by `import`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-imports"
        },
        messages: {
          path: "'{{importSource}}' import is restricted from being used.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          pathWithCustomMessage: "'{{importSource}}' import is restricted from being used. {{customMessage}}",
          patterns: "'{{importSource}}' import is restricted from being used by a pattern.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          patternWithCustomMessage: "'{{importSource}}' import is restricted from being used by a pattern. {{customMessage}}",
          patternAndImportName: "'{{importName}}' import from '{{importSource}}' is restricted from being used by a pattern.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          patternAndImportNameWithCustomMessage: "'{{importName}}' import from '{{importSource}}' is restricted from being used by a pattern. {{customMessage}}",
          patternAndEverything: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted from being used by a pattern.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          patternAndEverythingWithCustomMessage: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted from being used by a pattern. {{customMessage}}",
          everything: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          everythingWithCustomMessage: "* import is invalid because '{{importNames}}' from '{{importSource}}' is restricted. {{customMessage}}",
          importName: "'{{importName}}' import from '{{importSource}}' is restricted.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          importNameWithCustomMessage: "'{{importName}}' import from '{{importSource}}' is restricted. {{customMessage}}"
        },
        schema: {
          anyOf: [
            arrayOfStringsOrObjects,
            {
              type: "array",
              items: [{
                type: "object",
                properties: {
                  paths: arrayOfStringsOrObjects,
                  patterns: arrayOfStringsOrObjectPatterns
                },
                additionalProperties: false
              }],
              additionalItems: false
            }
          ]
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = Array.isArray(context.options) ? context.options : [];
        const isPathAndPatternsObject = typeof options[0] === "object" && (Object.prototype.hasOwnProperty.call(options[0], "paths") || Object.prototype.hasOwnProperty.call(options[0], "patterns"));
        const restrictedPaths = (isPathAndPatternsObject ? options[0].paths : context.options) || [];
        const restrictedPathMessages = restrictedPaths.reduce((memo, importSource) => {
          if (typeof importSource === "string") {
            memo[importSource] = { message: null };
          } else {
            memo[importSource.name] = {
              message: importSource.message,
              importNames: importSource.importNames
            };
          }
          return memo;
        }, {});
        let restrictedPatterns = (isPathAndPatternsObject ? options[0].patterns : []) || [];
        if (restrictedPatterns.length > 0 && typeof restrictedPatterns[0] === "string") {
          restrictedPatterns = [{ group: restrictedPatterns }];
        }
        const restrictedPatternGroups = restrictedPatterns.map(({ group, message, caseSensitive, importNames }) => ({
          matcher: ignore({ allowRelativePaths: true, ignorecase: !caseSensitive }).add(group),
          customMessage: message,
          importNames
        }));
        if (Object.keys(restrictedPaths).length === 0 && restrictedPatternGroups.length === 0) {
          return {};
        }
        function checkRestrictedPathAndReport(importSource, importNames, node) {
          if (!Object.prototype.hasOwnProperty.call(restrictedPathMessages, importSource)) {
            return;
          }
          const customMessage = restrictedPathMessages[importSource].message;
          const restrictedImportNames = restrictedPathMessages[importSource].importNames;
          if (restrictedImportNames) {
            if (importNames.has("*")) {
              const specifierData = importNames.get("*")[0];
              context.report({
                node,
                messageId: customMessage ? "everythingWithCustomMessage" : "everything",
                loc: specifierData.loc,
                data: {
                  importSource,
                  importNames: restrictedImportNames,
                  customMessage
                }
              });
            }
            restrictedImportNames.forEach((importName) => {
              if (importNames.has(importName)) {
                const specifiers = importNames.get(importName);
                specifiers.forEach((specifier) => {
                  context.report({
                    node,
                    messageId: customMessage ? "importNameWithCustomMessage" : "importName",
                    loc: specifier.loc,
                    data: {
                      importSource,
                      customMessage,
                      importName
                    }
                  });
                });
              }
            });
          } else {
            context.report({
              node,
              messageId: customMessage ? "pathWithCustomMessage" : "path",
              data: {
                importSource,
                customMessage
              }
            });
          }
        }
        function reportPathForPatterns(node, group, importNames) {
          const importSource = node.source.value.trim();
          const customMessage = group.customMessage;
          const restrictedImportNames = group.importNames;
          if (!restrictedImportNames) {
            context.report({
              node,
              messageId: customMessage ? "patternWithCustomMessage" : "patterns",
              data: {
                importSource,
                customMessage
              }
            });
            return;
          }
          if (importNames.has("*")) {
            const specifierData = importNames.get("*")[0];
            context.report({
              node,
              messageId: customMessage ? "patternAndEverythingWithCustomMessage" : "patternAndEverything",
              loc: specifierData.loc,
              data: {
                importSource,
                importNames: restrictedImportNames,
                customMessage
              }
            });
          }
          restrictedImportNames.forEach((importName) => {
            if (!importNames.has(importName)) {
              return;
            }
            const specifiers = importNames.get(importName);
            specifiers.forEach((specifier) => {
              context.report({
                node,
                messageId: customMessage ? "patternAndImportNameWithCustomMessage" : "patternAndImportName",
                loc: specifier.loc,
                data: {
                  importSource,
                  customMessage,
                  importName
                }
              });
            });
          });
        }
        function isRestrictedPattern(importSource, group) {
          return group.matcher.ignores(importSource);
        }
        function checkNode(node) {
          const importSource = node.source.value.trim();
          const importNames = /* @__PURE__ */ new Map();
          if (node.type === "ExportAllDeclaration") {
            const starToken = sourceCode.getFirstToken(node, 1);
            importNames.set("*", [{ loc: starToken.loc }]);
          } else if (node.specifiers) {
            for (const specifier of node.specifiers) {
              let name;
              const specifierData = { loc: specifier.loc };
              if (specifier.type === "ImportDefaultSpecifier") {
                name = "default";
              } else if (specifier.type === "ImportNamespaceSpecifier") {
                name = "*";
              } else if (specifier.imported) {
                name = astUtils.getModuleExportName(specifier.imported);
              } else if (specifier.local) {
                name = astUtils.getModuleExportName(specifier.local);
              }
              if (typeof name === "string") {
                if (importNames.has(name)) {
                  importNames.get(name).push(specifierData);
                } else {
                  importNames.set(name, [specifierData]);
                }
              }
            }
          }
          checkRestrictedPathAndReport(importSource, importNames, node);
          restrictedPatternGroups.forEach((group) => {
            if (isRestrictedPattern(importSource, group)) {
              reportPathForPatterns(node, group, importNames);
            }
          });
        }
        return {
          ImportDeclaration: checkNode,
          ExportNamedDeclaration(node) {
            if (node.source) {
              checkNode(node);
            }
          },
          ExportAllDeclaration: checkNode
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-modules.js
var require_no_restricted_modules = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-modules.js"(exports, module2) {
    "use strict";
    var ignore = require_ignore();
    var arrayOfStrings = {
      type: "array",
      items: { type: "string" },
      uniqueItems: true
    };
    var arrayOfStringsOrObjects = {
      type: "array",
      items: {
        anyOf: [
          { type: "string" },
          {
            type: "object",
            properties: {
              name: { type: "string" },
              message: {
                type: "string",
                minLength: 1
              }
            },
            additionalProperties: false,
            required: ["name"]
          }
        ]
      },
      uniqueItems: true
    };
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow specified modules when loaded by `require`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-modules"
        },
        schema: {
          anyOf: [
            arrayOfStringsOrObjects,
            {
              type: "array",
              items: {
                type: "object",
                properties: {
                  paths: arrayOfStringsOrObjects,
                  patterns: arrayOfStrings
                },
                additionalProperties: false
              },
              additionalItems: false
            }
          ]
        },
        messages: {
          defaultMessage: "'{{name}}' module is restricted from being used.",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          customMessage: "'{{name}}' module is restricted from being used. {{customMessage}}",
          patternMessage: "'{{name}}' module is restricted from being used by a pattern."
        }
      },
      create(context) {
        const options = Array.isArray(context.options) ? context.options : [];
        const isPathAndPatternsObject = typeof options[0] === "object" && (Object.prototype.hasOwnProperty.call(options[0], "paths") || Object.prototype.hasOwnProperty.call(options[0], "patterns"));
        const restrictedPaths = (isPathAndPatternsObject ? options[0].paths : context.options) || [];
        const restrictedPatterns = (isPathAndPatternsObject ? options[0].patterns : []) || [];
        const restrictedPathMessages = restrictedPaths.reduce((memo, importName) => {
          if (typeof importName === "string") {
            memo[importName] = null;
          } else {
            memo[importName.name] = importName.message;
          }
          return memo;
        }, {});
        if (Object.keys(restrictedPaths).length === 0 && restrictedPatterns.length === 0) {
          return {};
        }
        const ig = ignore({ allowRelativePaths: true }).add(restrictedPatterns);
        function isStringLiteral3(node) {
          return node && node.type === "Literal" && typeof node.value === "string";
        }
        function isStaticTemplateLiteral(node) {
          return node && node.type === "TemplateLiteral" && node.expressions.length === 0;
        }
        function isRequireCall(node) {
          return node.callee.type === "Identifier" && node.callee.name === "require";
        }
        function getFirstArgumentString(node) {
          if (isStringLiteral3(node)) {
            return node.value.trim();
          }
          if (isStaticTemplateLiteral(node)) {
            return node.quasis[0].value.cooked.trim();
          }
          return null;
        }
        function reportPath(node, name) {
          const customMessage = restrictedPathMessages[name];
          const messageId = customMessage ? "customMessage" : "defaultMessage";
          context.report({
            node,
            messageId,
            data: {
              name,
              customMessage
            }
          });
        }
        function isRestrictedPath(name) {
          return Object.prototype.hasOwnProperty.call(restrictedPathMessages, name);
        }
        return {
          CallExpression(node) {
            if (isRequireCall(node)) {
              if (node.arguments.length) {
                const name = getFirstArgumentString(node.arguments[0]);
                if (name) {
                  if (isRestrictedPath(name)) {
                    reportPath(node, name);
                  }
                  if (restrictedPatterns.length > 0 && ig.ignores(name)) {
                    context.report({
                      node,
                      messageId: "patternMessage",
                      data: { name }
                    });
                  }
                }
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-properties.js
var require_no_restricted_properties = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-properties.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow certain properties on certain objects",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-properties"
        },
        schema: {
          type: "array",
          items: {
            anyOf: [
              // `object` and `property` are both optional, but at least one of them must be provided.
              {
                type: "object",
                properties: {
                  object: {
                    type: "string"
                  },
                  property: {
                    type: "string"
                  },
                  message: {
                    type: "string"
                  }
                },
                additionalProperties: false,
                required: ["object"]
              },
              {
                type: "object",
                properties: {
                  object: {
                    type: "string"
                  },
                  property: {
                    type: "string"
                  },
                  message: {
                    type: "string"
                  }
                },
                additionalProperties: false,
                required: ["property"]
              }
            ]
          },
          uniqueItems: true
        },
        messages: {
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          restrictedObjectProperty: "'{{objectName}}.{{propertyName}}' is restricted from being used.{{message}}",
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          restrictedProperty: "'{{propertyName}}' is restricted from being used.{{message}}"
        }
      },
      create(context) {
        const restrictedCalls = context.options;
        if (restrictedCalls.length === 0) {
          return {};
        }
        const restrictedProperties = /* @__PURE__ */ new Map();
        const globallyRestrictedObjects = /* @__PURE__ */ new Map();
        const globallyRestrictedProperties = /* @__PURE__ */ new Map();
        restrictedCalls.forEach((option) => {
          const objectName = option.object;
          const propertyName = option.property;
          if (typeof objectName === "undefined") {
            globallyRestrictedProperties.set(propertyName, { message: option.message });
          } else if (typeof propertyName === "undefined") {
            globallyRestrictedObjects.set(objectName, { message: option.message });
          } else {
            if (!restrictedProperties.has(objectName)) {
              restrictedProperties.set(objectName, /* @__PURE__ */ new Map());
            }
            restrictedProperties.get(objectName).set(propertyName, {
              message: option.message
            });
          }
        });
        function checkPropertyAccess(node, objectName, propertyName) {
          if (propertyName === null) {
            return;
          }
          const matchedObject = restrictedProperties.get(objectName);
          const matchedObjectProperty = matchedObject ? matchedObject.get(propertyName) : globallyRestrictedObjects.get(objectName);
          const globalMatchedProperty = globallyRestrictedProperties.get(propertyName);
          if (matchedObjectProperty) {
            const message = matchedObjectProperty.message ? ` ${matchedObjectProperty.message}` : "";
            context.report({
              node,
              messageId: "restrictedObjectProperty",
              data: {
                objectName,
                propertyName,
                message
              }
            });
          } else if (globalMatchedProperty) {
            const message = globalMatchedProperty.message ? ` ${globalMatchedProperty.message}` : "";
            context.report({
              node,
              messageId: "restrictedProperty",
              data: {
                propertyName,
                message
              }
            });
          }
        }
        function checkDestructuringAssignment(node) {
          if (node.right.type === "Identifier") {
            const objectName = node.right.name;
            if (node.left.type === "ObjectPattern") {
              node.left.properties.forEach((property) => {
                checkPropertyAccess(node.left, objectName, astUtils.getStaticPropertyName(property));
              });
            }
          }
        }
        return {
          MemberExpression(node) {
            checkPropertyAccess(node, node.object && node.object.name, astUtils.getStaticPropertyName(node));
          },
          VariableDeclarator(node) {
            if (node.init && node.init.type === "Identifier") {
              const objectName = node.init.name;
              if (node.id.type === "ObjectPattern") {
                node.id.properties.forEach((property) => {
                  checkPropertyAccess(node.id, objectName, astUtils.getStaticPropertyName(property));
                });
              }
            }
          },
          AssignmentExpression: checkDestructuringAssignment,
          AssignmentPattern: checkDestructuringAssignment
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-restricted-syntax.js
var require_no_restricted_syntax = __commonJS({
  "node_modules/eslint/lib/rules/no-restricted-syntax.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified syntax",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-restricted-syntax"
        },
        schema: {
          type: "array",
          items: {
            oneOf: [
              {
                type: "string"
              },
              {
                type: "object",
                properties: {
                  selector: { type: "string" },
                  message: { type: "string" }
                },
                required: ["selector"],
                additionalProperties: false
              }
            ]
          },
          uniqueItems: true,
          minItems: 0
        },
        messages: {
          // eslint-disable-next-line eslint-plugin/report-message-format -- Custom message might not end in a period
          restrictedSyntax: "{{message}}"
        }
      },
      create(context) {
        return context.options.reduce((result, selectorOrObject) => {
          const isStringFormat = typeof selectorOrObject === "string";
          const hasCustomMessage = !isStringFormat && Boolean(selectorOrObject.message);
          const selector = isStringFormat ? selectorOrObject : selectorOrObject.selector;
          const message = hasCustomMessage ? selectorOrObject.message : `Using '${selector}' is not allowed.`;
          return Object.assign(result, {
            [selector](node) {
              context.report({
                node,
                messageId: "restrictedSyntax",
                data: { message }
              });
            }
          });
        }, {});
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-return-assign.js
var require_no_return_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-return-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var SENTINEL_TYPE = /^(?:[a-zA-Z]+?Statement|ArrowFunctionExpression|FunctionExpression|ClassExpression)$/u;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow assignment operators in `return` statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-return-assign"
        },
        schema: [
          {
            enum: ["except-parens", "always"]
          }
        ],
        messages: {
          returnAssignment: "Return statement should not contain assignment.",
          arrowAssignment: "Arrow function should not return assignment."
        }
      },
      create(context) {
        const always = (context.options[0] || "except-parens") !== "except-parens";
        const sourceCode = context.getSourceCode();
        return {
          AssignmentExpression(node) {
            if (!always && astUtils.isParenthesised(sourceCode, node)) {
              return;
            }
            let currentChild = node;
            let parent = currentChild.parent;
            while (parent && !SENTINEL_TYPE.test(parent.type)) {
              currentChild = parent;
              parent = parent.parent;
            }
            if (parent && parent.type === "ReturnStatement") {
              context.report({
                node: parent,
                messageId: "returnAssignment"
              });
            } else if (parent && parent.type === "ArrowFunctionExpression" && parent.body === currentChild) {
              context.report({
                node: parent,
                messageId: "arrowAssignment"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-return-await.js
var require_no_return_await = __commonJS({
  "node_modules/eslint/lib/rules/no-return-await.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        hasSuggestions: true,
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary `return await`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-return-await"
        },
        fixable: null,
        schema: [],
        messages: {
          removeAwait: "Remove redundant `await`.",
          redundantUseOfAwait: "Redundant use of `await` on a return value."
        }
      },
      create(context) {
        function reportUnnecessaryAwait(node) {
          context.report({
            node: context.getSourceCode().getFirstToken(node),
            loc: node.loc,
            messageId: "redundantUseOfAwait",
            suggest: [
              {
                messageId: "removeAwait",
                fix(fixer) {
                  const sourceCode = context.getSourceCode();
                  const [awaitToken, tokenAfterAwait] = sourceCode.getFirstTokens(node, 2);
                  const areAwaitAndAwaitedExpressionOnTheSameLine = awaitToken.loc.start.line === tokenAfterAwait.loc.start.line;
                  if (!areAwaitAndAwaitedExpressionOnTheSameLine) {
                    return null;
                  }
                  const [startOfAwait, endOfAwait] = awaitToken.range;
                  const characterAfterAwait = sourceCode.text[endOfAwait];
                  const trimLength = characterAfterAwait === " " ? 1 : 0;
                  const range = [startOfAwait, endOfAwait + trimLength];
                  return fixer.removeRange(range);
                }
              }
            ]
          });
        }
        function hasErrorHandler(node) {
          let ancestor = node;
          while (!astUtils.isFunction(ancestor) && ancestor.type !== "Program") {
            if (ancestor.parent.type === "TryStatement" && (ancestor === ancestor.parent.block || ancestor === ancestor.parent.handler && ancestor.parent.finalizer)) {
              return true;
            }
            ancestor = ancestor.parent;
          }
          return false;
        }
        function isInTailCallPosition(node) {
          if (node.parent.type === "ArrowFunctionExpression") {
            return true;
          }
          if (node.parent.type === "ReturnStatement") {
            return !hasErrorHandler(node.parent);
          }
          if (node.parent.type === "ConditionalExpression" && (node === node.parent.consequent || node === node.parent.alternate)) {
            return isInTailCallPosition(node.parent);
          }
          if (node.parent.type === "LogicalExpression" && node === node.parent.right) {
            return isInTailCallPosition(node.parent);
          }
          if (node.parent.type === "SequenceExpression" && node === node.parent.expressions[node.parent.expressions.length - 1]) {
            return isInTailCallPosition(node.parent);
          }
          return false;
        }
        return {
          AwaitExpression(node) {
            if (isInTailCallPosition(node) && !hasErrorHandler(node)) {
              reportUnnecessaryAwait(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-script-url.js
var require_no_script_url = __commonJS({
  "node_modules/eslint/lib/rules/no-script-url.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `javascript:` urls",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-script-url"
        },
        schema: [],
        messages: {
          unexpectedScriptURL: "Script URL is a form of eval."
        }
      },
      create(context) {
        function check(node) {
          const value2 = astUtils.getStaticStringValue(node);
          if (typeof value2 === "string" && value2.toLowerCase().indexOf("javascript:") === 0) {
            context.report({ node, messageId: "unexpectedScriptURL" });
          }
        }
        return {
          Literal(node) {
            if (node.value && typeof node.value === "string") {
              check(node);
            }
          },
          TemplateLiteral(node) {
            if (!(node.parent && node.parent.type === "TaggedTemplateExpression")) {
              check(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-self-assign.js
var require_no_self_assign = __commonJS({
  "node_modules/eslint/lib/rules/no-self-assign.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var SPACES = /\s+/gu;
    function eachSelfAssignment(left, right, props, report) {
      if (!left || !right) {
      } else if (left.type === "Identifier" && right.type === "Identifier" && left.name === right.name) {
        report(right);
      } else if (left.type === "ArrayPattern" && right.type === "ArrayExpression") {
        const end = Math.min(left.elements.length, right.elements.length);
        for (let i = 0; i < end; ++i) {
          const leftElement = left.elements[i];
          const rightElement = right.elements[i];
          if (leftElement && leftElement.type === "RestElement" && i < right.elements.length - 1) {
            break;
          }
          eachSelfAssignment(leftElement, rightElement, props, report);
          if (rightElement && rightElement.type === "SpreadElement") {
            break;
          }
        }
      } else if (left.type === "RestElement" && right.type === "SpreadElement") {
        eachSelfAssignment(left.argument, right.argument, props, report);
      } else if (left.type === "ObjectPattern" && right.type === "ObjectExpression" && right.properties.length >= 1) {
        let startJ = 0;
        for (let i = right.properties.length - 1; i >= 0; --i) {
          const propType = right.properties[i].type;
          if (propType === "SpreadElement" || propType === "ExperimentalSpreadProperty") {
            startJ = i + 1;
            break;
          }
        }
        for (let i = 0; i < left.properties.length; ++i) {
          for (let j = startJ; j < right.properties.length; ++j) {
            eachSelfAssignment(
              left.properties[i],
              right.properties[j],
              props,
              report
            );
          }
        }
      } else if (left.type === "Property" && right.type === "Property" && right.kind === "init" && !right.method) {
        const leftName = astUtils.getStaticPropertyName(left);
        if (leftName !== null && leftName === astUtils.getStaticPropertyName(right)) {
          eachSelfAssignment(left.value, right.value, props, report);
        }
      } else if (props && astUtils.skipChainExpression(left).type === "MemberExpression" && astUtils.skipChainExpression(right).type === "MemberExpression" && astUtils.isSameReference(left, right)) {
        report(right);
      }
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow assignments where both sides are exactly the same",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-self-assign"
        },
        schema: [
          {
            type: "object",
            properties: {
              props: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          selfAssignment: "'{{name}}' is assigned to itself."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const [{ props = true } = {}] = context.options;
        function report(node) {
          context.report({
            node,
            messageId: "selfAssignment",
            data: {
              name: sourceCode.getText(node).replace(SPACES, "")
            }
          });
        }
        return {
          AssignmentExpression(node) {
            if (["=", "&&=", "||=", "??="].includes(node.operator)) {
              eachSelfAssignment(node.left, node.right, props, report);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-self-compare.js
var require_no_self_compare = __commonJS({
  "node_modules/eslint/lib/rules/no-self-compare.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow comparisons where both sides are exactly the same",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-self-compare"
        },
        schema: [],
        messages: {
          comparingToSelf: "Comparing to itself is potentially pointless."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function hasSameTokens(nodeA, nodeB) {
          const tokensA = sourceCode.getTokens(nodeA);
          const tokensB = sourceCode.getTokens(nodeB);
          return tokensA.length === tokensB.length && tokensA.every((token, index) => token.type === tokensB[index].type && token.value === tokensB[index].value);
        }
        return {
          BinaryExpression(node) {
            const operators = /* @__PURE__ */ new Set(["===", "==", "!==", "!=", ">", "<", ">=", "<="]);
            if (operators.has(node.operator) && hasSameTokens(node.left, node.right)) {
              context.report({ node, messageId: "comparingToSelf" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-sequences.js
var require_no_sequences = __commonJS({
  "node_modules/eslint/lib/rules/no-sequences.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var DEFAULT_OPTIONS = {
      allowInParentheses: true
    };
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow comma operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-sequences"
        },
        schema: [{
          properties: {
            allowInParentheses: {
              type: "boolean",
              default: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          unexpectedCommaExpression: "Unexpected use of comma operator."
        }
      },
      create(context) {
        const options = Object.assign({}, DEFAULT_OPTIONS, context.options[0]);
        const sourceCode = context.getSourceCode();
        const parenthesized = {
          DoWhileStatement: "test",
          IfStatement: "test",
          SwitchStatement: "discriminant",
          WhileStatement: "test",
          WithStatement: "object",
          ArrowFunctionExpression: "body"
          /*
           * Omitting CallExpression - commas are parsed as argument separators
           * Omitting NewExpression - commas are parsed as argument separators
           * Omitting ForInStatement - parts aren't individually parenthesised
           * Omitting ForStatement - parts aren't individually parenthesised
           */
        };
        function requiresExtraParens(node) {
          return node.parent && parenthesized[node.parent.type] && node === node.parent[parenthesized[node.parent.type]];
        }
        function isParenthesised(node) {
          return astUtils.isParenthesised(sourceCode, node);
        }
        function isParenthesisedTwice(node) {
          const previousToken = sourceCode.getTokenBefore(node, 1), nextToken = sourceCode.getTokenAfter(node, 1);
          return isParenthesised(node) && previousToken && nextToken && astUtils.isOpeningParenToken(previousToken) && previousToken.range[1] <= node.range[0] && astUtils.isClosingParenToken(nextToken) && nextToken.range[0] >= node.range[1];
        }
        return {
          SequenceExpression(node) {
            if (node.parent.type === "ForStatement" && (node === node.parent.init || node === node.parent.update)) {
              return;
            }
            if (options.allowInParentheses) {
              if (requiresExtraParens(node)) {
                if (isParenthesisedTwice(node)) {
                  return;
                }
              } else {
                if (isParenthesised(node)) {
                  return;
                }
              }
            }
            const firstCommaToken = sourceCode.getTokenAfter(node.expressions[0], astUtils.isCommaToken);
            context.report({ node, loc: firstCommaToken.loc, messageId: "unexpectedCommaExpression" });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-setter-return.js
var require_no_setter_return = __commonJS({
  "node_modules/eslint/lib/rules/no-setter-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { findVariable } = require_eslint_utils();
    function isGlobalReference(node, scope) {
      const variable = findVariable(scope, node);
      return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
    }
    function isArgumentOfGlobalMethodCall(node, scope, objectName, methodName, index) {
      const callNode = node.parent;
      return callNode.type === "CallExpression" && callNode.arguments[index] === node && astUtils.isSpecificMemberAccess(callNode.callee, objectName, methodName) && isGlobalReference(astUtils.skipChainExpression(callNode.callee).object, scope);
    }
    function isPropertyDescriptor(node, scope) {
      if (isArgumentOfGlobalMethodCall(node, scope, "Object", "defineProperty", 2) || isArgumentOfGlobalMethodCall(node, scope, "Reflect", "defineProperty", 2)) {
        return true;
      }
      const parent = node.parent;
      if (parent.type === "Property" && parent.value === node) {
        const grandparent = parent.parent;
        if (grandparent.type === "ObjectExpression" && (isArgumentOfGlobalMethodCall(grandparent, scope, "Object", "create", 1) || isArgumentOfGlobalMethodCall(grandparent, scope, "Object", "defineProperties", 1))) {
          return true;
        }
      }
      return false;
    }
    function isSetter(node, scope) {
      const parent = node.parent;
      if ((parent.type === "Property" || parent.type === "MethodDefinition") && parent.kind === "set" && parent.value === node) {
        return true;
      }
      if (parent.type === "Property" && parent.value === node && astUtils.getStaticPropertyName(parent) === "set" && parent.parent.type === "ObjectExpression" && isPropertyDescriptor(parent.parent, scope)) {
        return true;
      }
      return false;
    }
    function getOuterScope(scope) {
      const upper = scope.upper;
      if (upper.type === "function-expression-name") {
        return upper.upper;
      }
      return upper;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow returning values from setters",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-setter-return"
        },
        schema: [],
        messages: {
          returnsValue: "Setter cannot return a value."
        }
      },
      create(context) {
        let funcInfo = null;
        function enterFunction(node) {
          const outerScope = getOuterScope(context.getScope());
          funcInfo = {
            upper: funcInfo,
            isSetter: isSetter(node, outerScope)
          };
        }
        function exitFunction() {
          funcInfo = funcInfo.upper;
        }
        function report(node) {
          context.report({ node, messageId: "returnsValue" });
        }
        return {
          /*
           * Function declarations cannot be setters, but we still have to track them in the `funcInfo` stack to avoid
           * false positives, because a ReturnStatement node can belong to a function declaration inside a setter.
           *
           * Note: A previously declared function can be referenced and actually used as a setter in a property descriptor,
           * but that's out of scope for this rule.
           */
          FunctionDeclaration: enterFunction,
          FunctionExpression: enterFunction,
          ArrowFunctionExpression(node) {
            enterFunction(node);
            if (funcInfo.isSetter && node.expression) {
              report(node.body);
            }
          },
          "FunctionDeclaration:exit": exitFunction,
          "FunctionExpression:exit": exitFunction,
          "ArrowFunctionExpression:exit": exitFunction,
          ReturnStatement(node) {
            if (funcInfo && funcInfo.isSetter && node.argument) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-shadow.js
var require_no_shadow = __commonJS({
  "node_modules/eslint/lib/rules/no-shadow.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var FUNC_EXPR_NODE_TYPES = /* @__PURE__ */ new Set(["ArrowFunctionExpression", "FunctionExpression"]);
    var CALL_EXPR_NODE_TYPE = /* @__PURE__ */ new Set(["CallExpression"]);
    var FOR_IN_OF_TYPE = /^For(?:In|Of)Statement$/u;
    var SENTINEL_TYPE = /^(?:(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|CatchClause|ImportDeclaration|ExportNamedDeclaration)$/u;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow variable declarations from shadowing variables declared in the outer scope",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-shadow"
        },
        schema: [
          {
            type: "object",
            properties: {
              builtinGlobals: { type: "boolean", default: false },
              hoist: { enum: ["all", "functions", "never"], default: "functions" },
              allow: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              ignoreOnInitialization: { type: "boolean", default: false }
            },
            additionalProperties: false
          }
        ],
        messages: {
          noShadow: "'{{name}}' is already declared in the upper scope on line {{shadowedLine}} column {{shadowedColumn}}.",
          noShadowGlobal: "'{{name}}' is already a global variable."
        }
      },
      create(context) {
        const options = {
          builtinGlobals: context.options[0] && context.options[0].builtinGlobals,
          hoist: context.options[0] && context.options[0].hoist || "functions",
          allow: context.options[0] && context.options[0].allow || [],
          ignoreOnInitialization: context.options[0] && context.options[0].ignoreOnInitialization
        };
        function isInRange(node, location) {
          return node && node.range[0] <= location && location <= node.range[1];
        }
        function findSelfOrAncestor(node, match) {
          let currentNode = node;
          while (currentNode && !match(currentNode)) {
            currentNode = currentNode.parent;
          }
          return currentNode;
        }
        function getOuterScope(scope) {
          const upper = scope.upper;
          if (upper.type === "function-expression-name") {
            return upper.upper;
          }
          return upper;
        }
        function isInitPatternNode(variable, shadowedVariable) {
          const outerDef = shadowedVariable.defs[0];
          if (!outerDef) {
            return false;
          }
          const { variableScope } = variable.scope;
          if (!(FUNC_EXPR_NODE_TYPES.has(variableScope.block.type) && getOuterScope(variableScope) === shadowedVariable.scope)) {
            return false;
          }
          const fun = variableScope.block;
          const { parent } = fun;
          const callExpression3 = findSelfOrAncestor(
            parent,
            (node2) => CALL_EXPR_NODE_TYPE.has(node2.type)
          );
          if (!callExpression3) {
            return false;
          }
          let node = outerDef.name;
          const location = callExpression3.range[1];
          while (node) {
            if (node.type === "VariableDeclarator") {
              if (isInRange(node.init, location)) {
                return true;
              }
              if (FOR_IN_OF_TYPE.test(node.parent.parent.type) && isInRange(node.parent.parent.right, location)) {
                return true;
              }
              break;
            } else if (node.type === "AssignmentPattern") {
              if (isInRange(node.right, location)) {
                return true;
              }
            } else if (SENTINEL_TYPE.test(node.type)) {
              break;
            }
            node = node.parent;
          }
          return false;
        }
        function isAllowed(variable) {
          return options.allow.includes(variable.name);
        }
        function isDuplicatedClassNameVariable(variable) {
          const block = variable.scope.block;
          return block.type === "ClassDeclaration" && block.id === variable.identifiers[0];
        }
        function isOnInitializer(variable, scopeVar) {
          const outerScope = scopeVar.scope;
          const outerDef = scopeVar.defs[0];
          const outer = outerDef && outerDef.parent && outerDef.parent.range;
          const innerScope = variable.scope;
          const innerDef = variable.defs[0];
          const inner = innerDef && innerDef.name.range;
          return outer && inner && outer[0] < inner[0] && inner[1] < outer[1] && (innerDef.type === "FunctionName" && innerDef.node.type === "FunctionExpression" || innerDef.node.type === "ClassExpression") && outerScope === innerScope.upper;
        }
        function getNameRange(variable) {
          const def = variable.defs[0];
          return def && def.name.range;
        }
        function getDeclaredLocation(variable) {
          const identifier3 = variable.identifiers[0];
          let obj;
          if (identifier3) {
            obj = {
              global: false,
              line: identifier3.loc.start.line,
              column: identifier3.loc.start.column + 1
            };
          } else {
            obj = {
              global: true
            };
          }
          return obj;
        }
        function isInTdz(variable, scopeVar) {
          const outerDef = scopeVar.defs[0];
          const inner = getNameRange(variable);
          const outer = getNameRange(scopeVar);
          return inner && outer && inner[1] < outer[0] && // Excepts FunctionDeclaration if is {"hoist":"function"}.
          (options.hoist !== "functions" || !outerDef || outerDef.node.type !== "FunctionDeclaration");
        }
        function checkForShadows(scope) {
          const variables = scope.variables;
          for (let i = 0; i < variables.length; ++i) {
            const variable = variables[i];
            if (variable.identifiers.length === 0 || isDuplicatedClassNameVariable(variable) || isAllowed(variable)) {
              continue;
            }
            const shadowed = astUtils.getVariableByName(scope.upper, variable.name);
            if (shadowed && (shadowed.identifiers.length > 0 || options.builtinGlobals && "writeable" in shadowed) && !isOnInitializer(variable, shadowed) && !(options.ignoreOnInitialization && isInitPatternNode(variable, shadowed)) && !(options.hoist !== "all" && isInTdz(variable, shadowed))) {
              const location = getDeclaredLocation(shadowed);
              const messageId = location.global ? "noShadowGlobal" : "noShadow";
              const data = { name: variable.name };
              if (!location.global) {
                data.shadowedLine = location.line;
                data.shadowedColumn = location.column;
              }
              context.report({
                node: variable.identifiers[0],
                messageId,
                data
              });
            }
          }
        }
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            const stack = globalScope.childScopes.slice();
            while (stack.length) {
              const scope = stack.pop();
              stack.push(...scope.childScopes);
              checkForShadows(scope);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-shadow-restricted-names.js
var require_no_shadow_restricted_names = __commonJS({
  "node_modules/eslint/lib/rules/no-shadow-restricted-names.js"(exports, module2) {
    "use strict";
    function safelyShadowsUndefined(variable) {
      return variable.name === "undefined" && variable.references.every((ref) => !ref.isWrite()) && variable.defs.every((def) => def.node.type === "VariableDeclarator" && def.node.init === null);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow identifiers from shadowing restricted names",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-shadow-restricted-names"
        },
        schema: [],
        messages: {
          shadowingRestrictedName: "Shadowing of global property '{{name}}'."
        }
      },
      create(context) {
        const RESTRICTED = /* @__PURE__ */ new Set(["undefined", "NaN", "Infinity", "arguments", "eval"]);
        return {
          "VariableDeclaration, :function, CatchClause"(node) {
            for (const variable of context.getDeclaredVariables(node)) {
              if (variable.defs.length > 0 && RESTRICTED.has(variable.name) && !safelyShadowsUndefined(variable)) {
                context.report({
                  node: variable.defs[0].name,
                  messageId: "shadowingRestrictedName",
                  data: {
                    name: variable.name
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-spaced-func.js
var require_no_spaced_func = __commonJS({
  "node_modules/eslint/lib/rules/no-spaced-func.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow spacing between function identifiers and their applications (deprecated)",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-spaced-func"
        },
        deprecated: true,
        replacedBy: ["func-call-spacing"],
        fixable: "whitespace",
        schema: [],
        messages: {
          noSpacedFunction: "Unexpected space between function name and paren."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function detectOpenSpaces(node) {
          const lastCalleeToken = sourceCode.getLastToken(node.callee);
          let prevToken = lastCalleeToken, parenToken = sourceCode.getTokenAfter(lastCalleeToken);
          while (parenToken && parenToken.range[1] < node.range[1] && parenToken.value !== "(") {
            prevToken = parenToken;
            parenToken = sourceCode.getTokenAfter(parenToken);
          }
          if (parenToken && parenToken.range[1] < node.range[1] && sourceCode.isSpaceBetweenTokens(prevToken, parenToken)) {
            context.report({
              node,
              loc: lastCalleeToken.loc.start,
              messageId: "noSpacedFunction",
              fix(fixer) {
                return fixer.removeRange([prevToken.range[1], parenToken.range[0]]);
              }
            });
          }
        }
        return {
          CallExpression: detectOpenSpaces,
          NewExpression: detectOpenSpaces
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-sparse-arrays.js
var require_no_sparse_arrays = __commonJS({
  "node_modules/eslint/lib/rules/no-sparse-arrays.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow sparse arrays",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-sparse-arrays"
        },
        schema: [],
        messages: {
          unexpectedSparseArray: "Unexpected comma in middle of array."
        }
      },
      create(context) {
        return {
          ArrayExpression(node) {
            const emptySpot = node.elements.includes(null);
            if (emptySpot) {
              context.report({ node, messageId: "unexpectedSparseArray" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-sync.js
var require_no_sync = __commonJS({
  "node_modules/eslint/lib/rules/no-sync.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        deprecated: true,
        replacedBy: [],
        type: "suggestion",
        docs: {
          description: "Disallow synchronous methods",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-sync"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowAtRootLevel: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          noSync: "Unexpected sync method: '{{propertyName}}'."
        }
      },
      create(context) {
        const selector = context.options[0] && context.options[0].allowAtRootLevel ? ":function MemberExpression[property.name=/.*Sync$/]" : "MemberExpression[property.name=/.*Sync$/]";
        return {
          [selector](node) {
            context.report({
              node,
              messageId: "noSync",
              data: {
                propertyName: node.property.name
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-tabs.js
var require_no_tabs = __commonJS({
  "node_modules/eslint/lib/rules/no-tabs.js"(exports, module2) {
    "use strict";
    var tabRegex = /\t+/gu;
    var anyNonWhitespaceRegex = /\S/u;
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow all tabs",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-tabs"
        },
        schema: [{
          type: "object",
          properties: {
            allowIndentationTabs: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          unexpectedTab: "Unexpected tab character."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const allowIndentationTabs = context.options && context.options[0] && context.options[0].allowIndentationTabs;
        return {
          Program(node) {
            sourceCode.getLines().forEach((line, index) => {
              let match;
              while ((match = tabRegex.exec(line)) !== null) {
                if (allowIndentationTabs && !anyNonWhitespaceRegex.test(line.slice(0, match.index))) {
                  continue;
                }
                context.report({
                  node,
                  loc: {
                    start: {
                      line: index + 1,
                      column: match.index
                    },
                    end: {
                      line: index + 1,
                      column: match.index + match[0].length
                    }
                  },
                  messageId: "unexpectedTab"
                });
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-template-curly-in-string.js
var require_no_template_curly_in_string = __commonJS({
  "node_modules/eslint/lib/rules/no-template-curly-in-string.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow template literal placeholder syntax in regular strings",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-template-curly-in-string"
        },
        schema: [],
        messages: {
          unexpectedTemplateExpression: "Unexpected template string expression."
        }
      },
      create(context) {
        const regex = /\$\{[^}]+\}/u;
        return {
          Literal(node) {
            if (typeof node.value === "string" && regex.test(node.value)) {
              context.report({
                node,
                messageId: "unexpectedTemplateExpression"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-ternary.js
var require_no_ternary = __commonJS({
  "node_modules/eslint/lib/rules/no-ternary.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow ternary operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-ternary"
        },
        schema: [],
        messages: {
          noTernaryOperator: "Ternary operator used."
        }
      },
      create(context) {
        return {
          ConditionalExpression(node) {
            context.report({ node, messageId: "noTernaryOperator" });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-this-before-super.js
var require_no_this_before_super = __commonJS({
  "node_modules/eslint/lib/rules/no-this-before-super.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isConstructorFunction(node) {
      return node.type === "FunctionExpression" && node.parent.type === "MethodDefinition" && node.parent.kind === "constructor";
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow `this`/`super` before calling `super()` in constructors",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-this-before-super"
        },
        schema: [],
        messages: {
          noBeforeSuper: "'{{kind}}' is not allowed before 'super()'."
        }
      },
      create(context) {
        let funcInfo = null;
        let segInfoMap = /* @__PURE__ */ Object.create(null);
        function isCalled(segment) {
          return !segment.reachable || segInfoMap[segment.id].superCalled;
        }
        function isInConstructorOfDerivedClass() {
          return Boolean(funcInfo && funcInfo.isConstructor && funcInfo.hasExtends);
        }
        function isBeforeCallOfSuper() {
          return isInConstructorOfDerivedClass() && !funcInfo.codePath.currentSegments.every(isCalled);
        }
        function setInvalid(node) {
          const segments = funcInfo.codePath.currentSegments;
          for (let i = 0; i < segments.length; ++i) {
            const segment = segments[i];
            if (segment.reachable) {
              segInfoMap[segment.id].invalidNodes.push(node);
            }
          }
        }
        function setSuperCalled() {
          const segments = funcInfo.codePath.currentSegments;
          for (let i = 0; i < segments.length; ++i) {
            const segment = segments[i];
            if (segment.reachable) {
              segInfoMap[segment.id].superCalled = true;
            }
          }
        }
        return {
          /**
           * Adds information of a constructor into the stack.
           * @param {CodePath} codePath A code path which was started.
           * @param {ASTNode} node The current node.
           * @returns {void}
           */
          onCodePathStart(codePath, node) {
            if (isConstructorFunction(node)) {
              const classNode = node.parent.parent.parent;
              funcInfo = {
                upper: funcInfo,
                isConstructor: true,
                hasExtends: Boolean(
                  classNode.superClass && !astUtils.isNullOrUndefined(classNode.superClass)
                ),
                codePath
              };
            } else {
              funcInfo = {
                upper: funcInfo,
                isConstructor: false,
                hasExtends: false,
                codePath
              };
            }
          },
          /**
           * Removes the top of stack item.
           *
           * And this traverses all segments of this code path then reports every
           * invalid node.
           * @param {CodePath} codePath A code path which was ended.
           * @returns {void}
           */
          onCodePathEnd(codePath) {
            const isDerivedClass = funcInfo.hasExtends;
            funcInfo = funcInfo.upper;
            if (!isDerivedClass) {
              return;
            }
            codePath.traverseSegments((segment, controller) => {
              const info = segInfoMap[segment.id];
              for (let i = 0; i < info.invalidNodes.length; ++i) {
                const invalidNode = info.invalidNodes[i];
                context.report({
                  messageId: "noBeforeSuper",
                  node: invalidNode,
                  data: {
                    kind: invalidNode.type === "Super" ? "super" : "this"
                  }
                });
              }
              if (info.superCalled) {
                controller.skip();
              }
            });
          },
          /**
           * Initialize information of a given code path segment.
           * @param {CodePathSegment} segment A code path segment to initialize.
           * @returns {void}
           */
          onCodePathSegmentStart(segment) {
            if (!isInConstructorOfDerivedClass()) {
              return;
            }
            segInfoMap[segment.id] = {
              superCalled: segment.prevSegments.length > 0 && segment.prevSegments.every(isCalled),
              invalidNodes: []
            };
          },
          /**
           * Update information of the code path segment when a code path was
           * looped.
           * @param {CodePathSegment} fromSegment The code path segment of the
           *      end of a loop.
           * @param {CodePathSegment} toSegment A code path segment of the head
           *      of a loop.
           * @returns {void}
           */
          onCodePathSegmentLoop(fromSegment, toSegment) {
            if (!isInConstructorOfDerivedClass()) {
              return;
            }
            funcInfo.codePath.traverseSegments(
              { first: toSegment, last: fromSegment },
              (segment, controller) => {
                const info = segInfoMap[segment.id];
                if (info.superCalled) {
                  info.invalidNodes = [];
                  controller.skip();
                } else if (segment.prevSegments.length > 0 && segment.prevSegments.every(isCalled)) {
                  info.superCalled = true;
                  info.invalidNodes = [];
                }
              }
            );
          },
          /**
           * Reports if this is before `super()`.
           * @param {ASTNode} node A target node.
           * @returns {void}
           */
          ThisExpression(node) {
            if (isBeforeCallOfSuper()) {
              setInvalid(node);
            }
          },
          /**
           * Reports if this is before `super()`.
           * @param {ASTNode} node A target node.
           * @returns {void}
           */
          Super(node) {
            if (!astUtils.isCallee(node) && isBeforeCallOfSuper()) {
              setInvalid(node);
            }
          },
          /**
           * Marks `super()` called.
           * @param {ASTNode} node A target node.
           * @returns {void}
           */
          "CallExpression:exit"(node) {
            if (node.callee.type === "Super" && isBeforeCallOfSuper()) {
              setSuperCalled();
            }
          },
          /**
           * Resets state.
           * @returns {void}
           */
          "Program:exit"() {
            segInfoMap = /* @__PURE__ */ Object.create(null);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-throw-literal.js
var require_no_throw_literal = __commonJS({
  "node_modules/eslint/lib/rules/no-throw-literal.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow throwing literals as exceptions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-throw-literal"
        },
        schema: [],
        messages: {
          object: "Expected an error object to be thrown.",
          undef: "Do not throw undefined."
        }
      },
      create(context) {
        return {
          ThrowStatement(node) {
            if (!astUtils.couldBeError(node.argument)) {
              context.report({ node, messageId: "object" });
            } else if (node.argument.type === "Identifier") {
              if (node.argument.name === "undefined") {
                context.report({ node, messageId: "undef" });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-trailing-spaces.js
var require_no_trailing_spaces = __commonJS({
  "node_modules/eslint/lib/rules/no-trailing-spaces.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow trailing whitespace at the end of lines",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-trailing-spaces"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              skipBlankLines: {
                type: "boolean",
                default: false
              },
              ignoreComments: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          trailingSpace: "Trailing spaces not allowed."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const BLANK_CLASS = "[ 	\xA0\u2000-\u200B\u3000]", SKIP_BLANK = `^${BLANK_CLASS}*$`, NONBLANK = `${BLANK_CLASS}+$`;
        const options = context.options[0] || {}, skipBlankLines = options.skipBlankLines || false, ignoreComments = options.ignoreComments || false;
        function report(node, location, fixRange) {
          context.report({
            node,
            loc: location,
            messageId: "trailingSpace",
            fix(fixer) {
              return fixer.removeRange(fixRange);
            }
          });
        }
        function getCommentLineNumbers(comments) {
          const lines = /* @__PURE__ */ new Set();
          comments.forEach((comment) => {
            const endLine = comment.type === "Block" ? comment.loc.end.line - 1 : comment.loc.end.line;
            for (let i = comment.loc.start.line; i <= endLine; i++) {
              lines.add(i);
            }
          });
          return lines;
        }
        return {
          Program: function checkTrailingSpaces(node) {
            const re = new RegExp(NONBLANK, "u"), skipMatch = new RegExp(SKIP_BLANK, "u"), lines = sourceCode.lines, linebreaks = sourceCode.getText().match(astUtils.createGlobalLinebreakMatcher()), comments = sourceCode.getAllComments(), commentLineNumbers = getCommentLineNumbers(comments);
            let totalLength = 0, fixRange = [];
            for (let i = 0, ii = lines.length; i < ii; i++) {
              const lineNumber = i + 1;
              const linebreakLength = linebreaks && linebreaks[i] ? linebreaks[i].length : 1;
              const lineLength = lines[i].length + linebreakLength;
              const matches = re.exec(lines[i]);
              if (matches) {
                const location = {
                  start: {
                    line: lineNumber,
                    column: matches.index
                  },
                  end: {
                    line: lineNumber,
                    column: lineLength - linebreakLength
                  }
                };
                const rangeStart = totalLength + location.start.column;
                const rangeEnd = totalLength + location.end.column;
                const containingNode = sourceCode.getNodeByRangeIndex(rangeStart);
                if (containingNode && containingNode.type === "TemplateElement" && rangeStart > containingNode.parent.range[0] && rangeEnd < containingNode.parent.range[1]) {
                  totalLength += lineLength;
                  continue;
                }
                if (skipBlankLines && skipMatch.test(lines[i])) {
                  totalLength += lineLength;
                  continue;
                }
                fixRange = [rangeStart, rangeEnd];
                if (!ignoreComments || !commentLineNumbers.has(lineNumber)) {
                  report(node, location, fixRange);
                }
              }
              totalLength += lineLength;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-undef.js
var require_no_undef = __commonJS({
  "node_modules/eslint/lib/rules/no-undef.js"(exports, module2) {
    "use strict";
    function hasTypeOfOperator(node) {
      const parent = node.parent;
      return parent.type === "UnaryExpression" && parent.operator === "typeof";
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow the use of undeclared variables unless mentioned in `/*global */` comments",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-undef"
        },
        schema: [
          {
            type: "object",
            properties: {
              typeof: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          undef: "'{{name}}' is not defined."
        }
      },
      create(context) {
        const options = context.options[0];
        const considerTypeOf = options && options.typeof === true || false;
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            globalScope.through.forEach((ref) => {
              const identifier3 = ref.identifier;
              if (!considerTypeOf && hasTypeOfOperator(identifier3)) {
                return;
              }
              context.report({
                node: identifier3,
                messageId: "undef",
                data: identifier3
              });
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-undef-init.js
var require_no_undef_init = __commonJS({
  "node_modules/eslint/lib/rules/no-undef-init.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow initializing variables to `undefined`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-undef-init"
        },
        schema: [],
        fixable: "code",
        messages: {
          unnecessaryUndefinedInit: "It's not necessary to initialize '{{name}}' to undefined."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          VariableDeclarator(node) {
            const name = sourceCode.getText(node.id), init = node.init && node.init.name, scope = context.getScope(), undefinedVar = astUtils.getVariableByName(scope, "undefined"), shadowed = undefinedVar && undefinedVar.defs.length > 0, lastToken = sourceCode.getLastToken(node);
            if (init === "undefined" && node.parent.kind !== "const" && !shadowed) {
              context.report({
                node,
                messageId: "unnecessaryUndefinedInit",
                data: { name },
                fix(fixer) {
                  if (node.parent.kind === "var") {
                    return null;
                  }
                  if (node.id.type === "ArrayPattern" || node.id.type === "ObjectPattern") {
                    return null;
                  }
                  if (sourceCode.commentsExistBetween(node.id, lastToken)) {
                    return null;
                  }
                  return fixer.removeRange([node.id.range[1], node.range[1]]);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-undefined.js
var require_no_undefined = __commonJS({
  "node_modules/eslint/lib/rules/no-undefined.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `undefined` as an identifier",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-undefined"
        },
        schema: [],
        messages: {
          unexpectedUndefined: "Unexpected use of undefined."
        }
      },
      create(context) {
        function report(node) {
          context.report({
            node,
            messageId: "unexpectedUndefined"
          });
        }
        function checkScope(scope) {
          const undefinedVar = scope.set.get("undefined");
          if (!undefinedVar) {
            return;
          }
          const references = undefinedVar.references;
          const defs = undefinedVar.defs;
          references.filter((ref) => !ref.init).forEach((ref) => report(ref.identifier));
          defs.forEach((def) => report(def.name));
        }
        return {
          "Program:exit"() {
            const globalScope = context.getScope();
            const stack = [globalScope];
            while (stack.length) {
              const scope = stack.pop();
              stack.push(...scope.childScopes);
              checkScope(scope);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-underscore-dangle.js
var require_no_underscore_dangle = __commonJS({
  "node_modules/eslint/lib/rules/no-underscore-dangle.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow dangling underscores in identifiers",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-underscore-dangle"
        },
        schema: [
          {
            type: "object",
            properties: {
              allow: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              allowAfterThis: {
                type: "boolean",
                default: false
              },
              allowAfterSuper: {
                type: "boolean",
                default: false
              },
              allowAfterThisConstructor: {
                type: "boolean",
                default: false
              },
              enforceInMethodNames: {
                type: "boolean",
                default: false
              },
              allowFunctionParams: {
                type: "boolean",
                default: true
              },
              enforceInClassFields: {
                type: "boolean",
                default: false
              },
              allowInArrayDestructuring: {
                type: "boolean",
                default: true
              },
              allowInObjectDestructuring: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedUnderscore: "Unexpected dangling '_' in '{{identifier}}'."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const ALLOWED_VARIABLES = options.allow ? options.allow : [];
        const allowAfterThis = typeof options.allowAfterThis !== "undefined" ? options.allowAfterThis : false;
        const allowAfterSuper = typeof options.allowAfterSuper !== "undefined" ? options.allowAfterSuper : false;
        const allowAfterThisConstructor = typeof options.allowAfterThisConstructor !== "undefined" ? options.allowAfterThisConstructor : false;
        const enforceInMethodNames = typeof options.enforceInMethodNames !== "undefined" ? options.enforceInMethodNames : false;
        const enforceInClassFields = typeof options.enforceInClassFields !== "undefined" ? options.enforceInClassFields : false;
        const allowFunctionParams = typeof options.allowFunctionParams !== "undefined" ? options.allowFunctionParams : true;
        const allowInArrayDestructuring = typeof options.allowInArrayDestructuring !== "undefined" ? options.allowInArrayDestructuring : true;
        const allowInObjectDestructuring = typeof options.allowInObjectDestructuring !== "undefined" ? options.allowInObjectDestructuring : true;
        function isAllowed(identifier3) {
          return ALLOWED_VARIABLES.includes(identifier3);
        }
        function hasDanglingUnderscore(identifier3) {
          const len = identifier3.length;
          return identifier3 !== "_" && (identifier3[0] === "_" || identifier3[len - 1] === "_");
        }
        function isSpecialCaseIdentifierForMemberExpression(identifier3) {
          return identifier3 === "__proto__";
        }
        function isSpecialCaseIdentifierInVariableExpression(identifier3) {
          return identifier3 === "_";
        }
        function isThisConstructorReference(node) {
          return node.object.type === "MemberExpression" && node.object.property.name === "constructor" && node.object.object.type === "ThisExpression";
        }
        function checkForDanglingUnderscoreInFunctionParameters(node) {
          if (!allowFunctionParams) {
            node.params.forEach((param) => {
              const { type } = param;
              let nodeToCheck;
              if (type === "RestElement") {
                nodeToCheck = param.argument;
              } else if (type === "AssignmentPattern") {
                nodeToCheck = param.left;
              } else {
                nodeToCheck = param;
              }
              if (nodeToCheck.type === "Identifier") {
                const identifier3 = nodeToCheck.name;
                if (hasDanglingUnderscore(identifier3) && !isAllowed(identifier3)) {
                  context.report({
                    node: param,
                    messageId: "unexpectedUnderscore",
                    data: {
                      identifier: identifier3
                    }
                  });
                }
              }
            });
          }
        }
        function checkForDanglingUnderscoreInFunction(node) {
          if (node.type === "FunctionDeclaration" && node.id) {
            const identifier3 = node.id.name;
            if (typeof identifier3 !== "undefined" && hasDanglingUnderscore(identifier3) && !isAllowed(identifier3)) {
              context.report({
                node,
                messageId: "unexpectedUnderscore",
                data: {
                  identifier: identifier3
                }
              });
            }
          }
          checkForDanglingUnderscoreInFunctionParameters(node);
        }
        function checkForDanglingUnderscoreInVariableExpression(node) {
          context.getDeclaredVariables(node).forEach((variable) => {
            const definition = variable.defs.find((def) => def.node === node);
            const identifierNode = definition.name;
            const identifier3 = identifierNode.name;
            let parent = identifierNode.parent;
            while (!["VariableDeclarator", "ArrayPattern", "ObjectPattern"].includes(parent.type)) {
              parent = parent.parent;
            }
            if (hasDanglingUnderscore(identifier3) && !isSpecialCaseIdentifierInVariableExpression(identifier3) && !isAllowed(identifier3) && !(allowInArrayDestructuring && parent.type === "ArrayPattern") && !(allowInObjectDestructuring && parent.type === "ObjectPattern")) {
              context.report({
                node,
                messageId: "unexpectedUnderscore",
                data: {
                  identifier: identifier3
                }
              });
            }
          });
        }
        function checkForDanglingUnderscoreInMemberExpression(node) {
          const identifier3 = node.property.name, isMemberOfThis = node.object.type === "ThisExpression", isMemberOfSuper = node.object.type === "Super", isMemberOfThisConstructor = isThisConstructorReference(node);
          if (typeof identifier3 !== "undefined" && hasDanglingUnderscore(identifier3) && !(isMemberOfThis && allowAfterThis) && !(isMemberOfSuper && allowAfterSuper) && !(isMemberOfThisConstructor && allowAfterThisConstructor) && !isSpecialCaseIdentifierForMemberExpression(identifier3) && !isAllowed(identifier3)) {
            context.report({
              node,
              messageId: "unexpectedUnderscore",
              data: {
                identifier: identifier3
              }
            });
          }
        }
        function checkForDanglingUnderscoreInMethod(node) {
          const identifier3 = node.key.name;
          const isMethod = node.type === "MethodDefinition" || node.type === "Property" && node.method;
          if (typeof identifier3 !== "undefined" && enforceInMethodNames && isMethod && hasDanglingUnderscore(identifier3) && !isAllowed(identifier3)) {
            context.report({
              node,
              messageId: "unexpectedUnderscore",
              data: {
                identifier: node.key.type === "PrivateIdentifier" ? `#${identifier3}` : identifier3
              }
            });
          }
        }
        function checkForDanglingUnderscoreInClassField(node) {
          const identifier3 = node.key.name;
          if (typeof identifier3 !== "undefined" && hasDanglingUnderscore(identifier3) && enforceInClassFields && !isAllowed(identifier3)) {
            context.report({
              node,
              messageId: "unexpectedUnderscore",
              data: {
                identifier: node.key.type === "PrivateIdentifier" ? `#${identifier3}` : identifier3
              }
            });
          }
        }
        return {
          FunctionDeclaration: checkForDanglingUnderscoreInFunction,
          VariableDeclarator: checkForDanglingUnderscoreInVariableExpression,
          MemberExpression: checkForDanglingUnderscoreInMemberExpression,
          MethodDefinition: checkForDanglingUnderscoreInMethod,
          PropertyDefinition: checkForDanglingUnderscoreInClassField,
          Property: checkForDanglingUnderscoreInMethod,
          FunctionExpression: checkForDanglingUnderscoreInFunction,
          ArrowFunctionExpression: checkForDanglingUnderscoreInFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unexpected-multiline.js
var require_no_unexpected_multiline = __commonJS({
  "node_modules/eslint/lib/rules/no-unexpected-multiline.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow confusing multiline expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unexpected-multiline"
        },
        schema: [],
        messages: {
          function: "Unexpected newline between function and ( of function call.",
          property: "Unexpected newline between object and [ of property access.",
          taggedTemplate: "Unexpected newline between template tag and template literal.",
          division: "Unexpected newline between numerator and division operator."
        }
      },
      create(context) {
        const REGEX_FLAG_MATCHER = /^[gimsuy]+$/u;
        const sourceCode = context.getSourceCode();
        function checkForBreakAfter(node, messageId) {
          const openParen = sourceCode.getTokenAfter(node, astUtils.isNotClosingParenToken);
          const nodeExpressionEnd = sourceCode.getTokenBefore(openParen);
          if (openParen.loc.start.line !== nodeExpressionEnd.loc.end.line) {
            context.report({
              node,
              loc: openParen.loc,
              messageId
            });
          }
        }
        return {
          MemberExpression(node) {
            if (!node.computed || node.optional) {
              return;
            }
            checkForBreakAfter(node.object, "property");
          },
          TaggedTemplateExpression(node) {
            const { quasi } = node;
            const tokenBefore = sourceCode.getTokenBefore(quasi);
            if (tokenBefore.loc.end.line !== quasi.loc.start.line) {
              context.report({
                node,
                loc: {
                  start: quasi.loc.start,
                  end: {
                    line: quasi.loc.start.line,
                    column: quasi.loc.start.column + 1
                  }
                },
                messageId: "taggedTemplate"
              });
            }
          },
          CallExpression(node) {
            if (node.arguments.length === 0 || node.optional) {
              return;
            }
            checkForBreakAfter(node.callee, "function");
          },
          "BinaryExpression[operator='/'] > BinaryExpression[operator='/'].left"(node) {
            const secondSlash = sourceCode.getTokenAfter(node, (token) => token.value === "/");
            const tokenAfterOperator = sourceCode.getTokenAfter(secondSlash);
            if (tokenAfterOperator.type === "Identifier" && REGEX_FLAG_MATCHER.test(tokenAfterOperator.value) && secondSlash.range[1] === tokenAfterOperator.range[0]) {
              checkForBreakAfter(node.left, "division");
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint-visitor-keys/dist/eslint-visitor-keys.cjs
var require_eslint_visitor_keys = __commonJS({
  "node_modules/eslint-visitor-keys/dist/eslint-visitor-keys.cjs"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var KEYS = {
      AssignmentExpression: [
        "left",
        "right"
      ],
      AssignmentPattern: [
        "left",
        "right"
      ],
      ArrayExpression: [
        "elements"
      ],
      ArrayPattern: [
        "elements"
      ],
      ArrowFunctionExpression: [
        "params",
        "body"
      ],
      AwaitExpression: [
        "argument"
      ],
      BlockStatement: [
        "body"
      ],
      BinaryExpression: [
        "left",
        "right"
      ],
      BreakStatement: [
        "label"
      ],
      CallExpression: [
        "callee",
        "arguments"
      ],
      CatchClause: [
        "param",
        "body"
      ],
      ChainExpression: [
        "expression"
      ],
      ClassBody: [
        "body"
      ],
      ClassDeclaration: [
        "id",
        "superClass",
        "body"
      ],
      ClassExpression: [
        "id",
        "superClass",
        "body"
      ],
      ConditionalExpression: [
        "test",
        "consequent",
        "alternate"
      ],
      ContinueStatement: [
        "label"
      ],
      DebuggerStatement: [],
      DoWhileStatement: [
        "body",
        "test"
      ],
      EmptyStatement: [],
      ExportAllDeclaration: [
        "exported",
        "source"
      ],
      ExportDefaultDeclaration: [
        "declaration"
      ],
      ExportNamedDeclaration: [
        "declaration",
        "specifiers",
        "source"
      ],
      ExportSpecifier: [
        "exported",
        "local"
      ],
      ExpressionStatement: [
        "expression"
      ],
      ExperimentalRestProperty: [
        "argument"
      ],
      ExperimentalSpreadProperty: [
        "argument"
      ],
      ForStatement: [
        "init",
        "test",
        "update",
        "body"
      ],
      ForInStatement: [
        "left",
        "right",
        "body"
      ],
      ForOfStatement: [
        "left",
        "right",
        "body"
      ],
      FunctionDeclaration: [
        "id",
        "params",
        "body"
      ],
      FunctionExpression: [
        "id",
        "params",
        "body"
      ],
      Identifier: [],
      IfStatement: [
        "test",
        "consequent",
        "alternate"
      ],
      ImportDeclaration: [
        "specifiers",
        "source"
      ],
      ImportDefaultSpecifier: [
        "local"
      ],
      ImportExpression: [
        "source"
      ],
      ImportNamespaceSpecifier: [
        "local"
      ],
      ImportSpecifier: [
        "imported",
        "local"
      ],
      JSXAttribute: [
        "name",
        "value"
      ],
      JSXClosingElement: [
        "name"
      ],
      JSXElement: [
        "openingElement",
        "children",
        "closingElement"
      ],
      JSXEmptyExpression: [],
      JSXExpressionContainer: [
        "expression"
      ],
      JSXIdentifier: [],
      JSXMemberExpression: [
        "object",
        "property"
      ],
      JSXNamespacedName: [
        "namespace",
        "name"
      ],
      JSXOpeningElement: [
        "name",
        "attributes"
      ],
      JSXSpreadAttribute: [
        "argument"
      ],
      JSXText: [],
      JSXFragment: [
        "openingFragment",
        "children",
        "closingFragment"
      ],
      JSXClosingFragment: [],
      JSXOpeningFragment: [],
      Literal: [],
      LabeledStatement: [
        "label",
        "body"
      ],
      LogicalExpression: [
        "left",
        "right"
      ],
      MemberExpression: [
        "object",
        "property"
      ],
      MetaProperty: [
        "meta",
        "property"
      ],
      MethodDefinition: [
        "key",
        "value"
      ],
      NewExpression: [
        "callee",
        "arguments"
      ],
      ObjectExpression: [
        "properties"
      ],
      ObjectPattern: [
        "properties"
      ],
      PrivateIdentifier: [],
      Program: [
        "body"
      ],
      Property: [
        "key",
        "value"
      ],
      PropertyDefinition: [
        "key",
        "value"
      ],
      RestElement: [
        "argument"
      ],
      ReturnStatement: [
        "argument"
      ],
      SequenceExpression: [
        "expressions"
      ],
      SpreadElement: [
        "argument"
      ],
      StaticBlock: [
        "body"
      ],
      Super: [],
      SwitchStatement: [
        "discriminant",
        "cases"
      ],
      SwitchCase: [
        "test",
        "consequent"
      ],
      TaggedTemplateExpression: [
        "tag",
        "quasi"
      ],
      TemplateElement: [],
      TemplateLiteral: [
        "quasis",
        "expressions"
      ],
      ThisExpression: [],
      ThrowStatement: [
        "argument"
      ],
      TryStatement: [
        "block",
        "handler",
        "finalizer"
      ],
      UnaryExpression: [
        "argument"
      ],
      UpdateExpression: [
        "argument"
      ],
      VariableDeclaration: [
        "declarations"
      ],
      VariableDeclarator: [
        "id",
        "init"
      ],
      WhileStatement: [
        "test",
        "body"
      ],
      WithStatement: [
        "object",
        "body"
      ],
      YieldExpression: [
        "argument"
      ]
    };
    var NODE_TYPES = Object.keys(KEYS);
    for (const type of NODE_TYPES) {
      Object.freeze(KEYS[type]);
    }
    Object.freeze(KEYS);
    var KEY_BLACKLIST = /* @__PURE__ */ new Set([
      "parent",
      "leadingComments",
      "trailingComments"
    ]);
    function filterKey(key) {
      return !KEY_BLACKLIST.has(key) && key[0] !== "_";
    }
    function getKeys(node) {
      return Object.keys(node).filter(filterKey);
    }
    function unionWith(additionalKeys) {
      const retv = (
        /** @type {{
            [type: string]: ReadonlyArray<string>
        }} */
        Object.assign({}, KEYS)
      );
      for (const type of Object.keys(additionalKeys)) {
        if (Object.prototype.hasOwnProperty.call(retv, type)) {
          const keys3 = new Set(additionalKeys[type]);
          for (const key of retv[type]) {
            keys3.add(key);
          }
          retv[type] = Object.freeze(Array.from(keys3));
        } else {
          retv[type] = Object.freeze(Array.from(additionalKeys[type]));
        }
      }
      return Object.freeze(retv);
    }
    exports.KEYS = KEYS;
    exports.getKeys = getKeys;
    exports.unionWith = unionWith;
  }
});

// node_modules/eslint/lib/shared/traverser.js
var require_traverser = __commonJS({
  "node_modules/eslint/lib/shared/traverser.js"(exports, module2) {
    "use strict";
    var vk = require_eslint_visitor_keys();
    var debug = require_src()("eslint:traverser");
    function noop() {
    }
    function isNode(x) {
      return x !== null && typeof x === "object" && typeof x.type === "string";
    }
    function getVisitorKeys(visitorKeys, node) {
      let keys3 = visitorKeys[node.type];
      if (!keys3) {
        keys3 = vk.getKeys(node);
        debug('Unknown node type "%s": Estimated visitor keys %j', node.type, keys3);
      }
      return keys3;
    }
    var Traverser = class _Traverser {
      constructor() {
        this._current = null;
        this._parents = [];
        this._skipped = false;
        this._broken = false;
        this._visitorKeys = null;
        this._enter = null;
        this._leave = null;
      }
      /**
       * Gives current node.
       * @returns {ASTNode} The current node.
       */
      current() {
        return this._current;
      }
      /**
       * Gives a copy of the ancestor nodes.
       * @returns {ASTNode[]} The ancestor nodes.
       */
      parents() {
        return this._parents.slice(0);
      }
      /**
       * Break the current traversal.
       * @returns {void}
       */
      break() {
        this._broken = true;
      }
      /**
       * Skip child nodes for the current traversal.
       * @returns {void}
       */
      skip() {
        this._skipped = true;
      }
      /**
       * Traverse the given AST tree.
       * @param {ASTNode} node The root node to traverse.
       * @param {Object} options The option object.
       * @param {Object} [options.visitorKeys=DEFAULT_VISITOR_KEYS] The keys of each node types to traverse child nodes. Default is `./default-visitor-keys.json`.
       * @param {Function} [options.enter=noop] The callback function which is called on entering each node.
       * @param {Function} [options.leave=noop] The callback function which is called on leaving each node.
       * @returns {void}
       */
      traverse(node, options) {
        this._current = null;
        this._parents = [];
        this._skipped = false;
        this._broken = false;
        this._visitorKeys = options.visitorKeys || vk.KEYS;
        this._enter = options.enter || noop;
        this._leave = options.leave || noop;
        this._traverse(node, null);
      }
      /**
       * Traverse the given AST tree recursively.
       * @param {ASTNode} node The current node.
       * @param {ASTNode|null} parent The parent node.
       * @returns {void}
       * @private
       */
      _traverse(node, parent) {
        if (!isNode(node)) {
          return;
        }
        this._current = node;
        this._skipped = false;
        this._enter(node, parent);
        if (!this._skipped && !this._broken) {
          const keys3 = getVisitorKeys(this._visitorKeys, node);
          if (keys3.length >= 1) {
            this._parents.push(node);
            for (let i = 0; i < keys3.length && !this._broken; ++i) {
              const child = node[keys3[i]];
              if (Array.isArray(child)) {
                for (let j = 0; j < child.length && !this._broken; ++j) {
                  this._traverse(child[j], node);
                }
              } else {
                this._traverse(child, node);
              }
            }
            this._parents.pop();
          }
        }
        if (!this._broken) {
          this._leave(node, parent);
        }
        this._current = parent;
      }
      /**
       * Calculates the keys to use for traversal.
       * @param {ASTNode} node The node to read keys from.
       * @returns {string[]} An array of keys to visit on the node.
       * @private
       */
      static getKeys(node) {
        return vk.getKeys(node);
      }
      /**
       * Traverse the given AST tree.
       * @param {ASTNode} node The root node to traverse.
       * @param {Object} options The option object.
       * @param {Object} [options.visitorKeys=DEFAULT_VISITOR_KEYS] The keys of each node types to traverse child nodes. Default is `./default-visitor-keys.json`.
       * @param {Function} [options.enter=noop] The callback function which is called on entering each node.
       * @param {Function} [options.leave=noop] The callback function which is called on leaving each node.
       * @returns {void}
       */
      static traverse(node, options) {
        new _Traverser().traverse(node, options);
      }
      /**
       * The default visitor keys.
       * @type {Object}
       */
      static get DEFAULT_VISITOR_KEYS() {
        return vk.KEYS;
      }
    };
    module2.exports = Traverser;
  }
});

// node_modules/eslint/lib/rules/no-unmodified-loop-condition.js
var require_no_unmodified_loop_condition = __commonJS({
  "node_modules/eslint/lib/rules/no-unmodified-loop-condition.js"(exports, module2) {
    "use strict";
    var Traverser = require_traverser();
    var astUtils = require_ast_utils2();
    var SENTINEL_PATTERN = /(?:(?:Call|Class|Function|Member|New|Yield)Expression|Statement|Declaration)$/u;
    var LOOP_PATTERN = /^(?:DoWhile|For|While)Statement$/u;
    var GROUP_PATTERN = /^(?:BinaryExpression|ConditionalExpression)$/u;
    var SKIP_PATTERN = /^(?:ArrowFunction|Class|Function)Expression$/u;
    var DYNAMIC_PATTERN = /^(?:Call|Member|New|TaggedTemplate|Yield)Expression$/u;
    function isWriteReference(reference) {
      if (reference.init) {
        const def = reference.resolved && reference.resolved.defs[0];
        if (!def || def.type !== "Variable" || def.parent.kind !== "var") {
          return false;
        }
      }
      return reference.isWrite();
    }
    function isUnmodified(condition) {
      return !condition.modified;
    }
    function isUnmodifiedAndNotBelongToGroup(condition) {
      return !(condition.modified || condition.group);
    }
    function isInRange(node, reference) {
      const or = node.range;
      const ir = reference.identifier.range;
      return or[0] <= ir[0] && ir[1] <= or[1];
    }
    var isInLoop = {
      WhileStatement: isInRange,
      DoWhileStatement: isInRange,
      ForStatement(node, reference) {
        return isInRange(node, reference) && !(node.init && isInRange(node.init, reference));
      }
    };
    function getEncloseFunctionDeclaration(reference) {
      let node = reference.identifier;
      while (node) {
        if (node.type === "FunctionDeclaration") {
          return node.id ? node : null;
        }
        node = node.parent;
      }
      return null;
    }
    function updateModifiedFlag(conditions, modifiers) {
      for (let i = 0; i < conditions.length; ++i) {
        const condition = conditions[i];
        for (let j = 0; !condition.modified && j < modifiers.length; ++j) {
          const modifier = modifiers[j];
          let funcNode, funcVar;
          const inLoop = condition.isInLoop(modifier) || Boolean(
            (funcNode = getEncloseFunctionDeclaration(modifier)) && (funcVar = astUtils.getVariableByName(modifier.from.upper, funcNode.id.name)) && funcVar.references.some(condition.isInLoop)
          );
          condition.modified = inLoop;
        }
      }
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow unmodified loop conditions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-unmodified-loop-condition"
        },
        schema: [],
        messages: {
          loopConditionNotModified: "'{{name}}' is not modified in this loop."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let groupMap = null;
        function report(condition) {
          const node = condition.reference.identifier;
          context.report({
            node,
            messageId: "loopConditionNotModified",
            data: node
          });
        }
        function registerConditionsToGroup(conditions) {
          for (let i = 0; i < conditions.length; ++i) {
            const condition = conditions[i];
            if (condition.group) {
              let group = groupMap.get(condition.group);
              if (!group) {
                group = [];
                groupMap.set(condition.group, group);
              }
              group.push(condition);
            }
          }
        }
        function checkConditionsInGroup(conditions) {
          if (conditions.every(isUnmodified)) {
            conditions.forEach(report);
          }
        }
        function hasDynamicExpressions(root2) {
          let retv = false;
          Traverser.traverse(root2, {
            visitorKeys: sourceCode.visitorKeys,
            enter(node) {
              if (DYNAMIC_PATTERN.test(node.type)) {
                retv = true;
                this.break();
              } else if (SKIP_PATTERN.test(node.type)) {
                this.skip();
              }
            }
          });
          return retv;
        }
        function toLoopCondition(reference) {
          if (reference.init) {
            return null;
          }
          let group = null;
          let child = reference.identifier;
          let node = child.parent;
          while (node) {
            if (SENTINEL_PATTERN.test(node.type)) {
              if (LOOP_PATTERN.test(node.type) && node.test === child) {
                return {
                  reference,
                  group,
                  isInLoop: isInLoop[node.type].bind(null, node),
                  modified: false
                };
              }
              break;
            }
            if (GROUP_PATTERN.test(node.type)) {
              if (hasDynamicExpressions(node)) {
                break;
              } else {
                group = node;
              }
            }
            child = node;
            node = node.parent;
          }
          return null;
        }
        function checkReferences(variable) {
          const conditions = variable.references.map(toLoopCondition).filter(Boolean);
          if (conditions.length === 0) {
            return;
          }
          registerConditionsToGroup(conditions);
          const modifiers = variable.references.filter(isWriteReference);
          if (modifiers.length > 0) {
            updateModifiedFlag(conditions, modifiers);
          }
          conditions.filter(isUnmodifiedAndNotBelongToGroup).forEach(report);
        }
        return {
          "Program:exit"() {
            const queue = [context.getScope()];
            groupMap = /* @__PURE__ */ new Map();
            let scope;
            while (scope = queue.pop()) {
              queue.push(...scope.childScopes);
              scope.variables.forEach(checkReferences);
            }
            groupMap.forEach(checkConditionsInGroup);
            groupMap = null;
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unneeded-ternary.js
var require_no_unneeded_ternary = __commonJS({
  "node_modules/eslint/lib/rules/no-unneeded-ternary.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var BOOLEAN_OPERATORS = /* @__PURE__ */ new Set(["==", "===", "!=", "!==", ">", ">=", "<", "<=", "in", "instanceof"]);
    var OPERATOR_INVERSES = {
      "==": "!=",
      "!=": "==",
      "===": "!==",
      "!==": "==="
      // Operators like < and >= are not true inverses, since both will return false with NaN.
    };
    var OR_PRECEDENCE = astUtils.getPrecedence({ type: "LogicalExpression", operator: "||" });
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow ternary operators when simpler alternatives exist",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-unneeded-ternary"
        },
        schema: [
          {
            type: "object",
            properties: {
              defaultAssignment: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          unnecessaryConditionalExpression: "Unnecessary use of boolean literals in conditional expression.",
          unnecessaryConditionalAssignment: "Unnecessary use of conditional expression for default assignment."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const defaultAssignment = options.defaultAssignment !== false;
        const sourceCode = context.getSourceCode();
        function isBooleanLiteral(node) {
          return node.type === "Literal" && typeof node.value === "boolean";
        }
        function invertExpression(node) {
          if (node.type === "BinaryExpression" && Object.prototype.hasOwnProperty.call(OPERATOR_INVERSES, node.operator)) {
            const operatorToken = sourceCode.getFirstTokenBetween(
              node.left,
              node.right,
              (token) => token.value === node.operator
            );
            const text = sourceCode.getText();
            return text.slice(
              node.range[0],
              operatorToken.range[0]
            ) + OPERATOR_INVERSES[node.operator] + text.slice(operatorToken.range[1], node.range[1]);
          }
          if (astUtils.getPrecedence(node) < astUtils.getPrecedence({ type: "UnaryExpression" })) {
            return `!(${astUtils.getParenthesisedText(sourceCode, node)})`;
          }
          return `!${astUtils.getParenthesisedText(sourceCode, node)}`;
        }
        function isBooleanExpression(node) {
          return node.type === "BinaryExpression" && BOOLEAN_OPERATORS.has(node.operator) || node.type === "UnaryExpression" && node.operator === "!";
        }
        function matchesDefaultAssignment(node) {
          return node.test.type === "Identifier" && node.consequent.type === "Identifier" && node.test.name === node.consequent.name;
        }
        return {
          ConditionalExpression(node) {
            if (isBooleanLiteral(node.alternate) && isBooleanLiteral(node.consequent)) {
              context.report({
                node,
                messageId: "unnecessaryConditionalExpression",
                fix(fixer) {
                  if (node.consequent.value === node.alternate.value) {
                    return node.test.type === "Identifier" ? fixer.replaceText(node, node.consequent.value.toString()) : null;
                  }
                  if (node.alternate.value) {
                    return fixer.replaceText(node, invertExpression(node.test));
                  }
                  return fixer.replaceText(node, isBooleanExpression(node.test) ? astUtils.getParenthesisedText(sourceCode, node.test) : `!${invertExpression(node.test)}`);
                }
              });
            } else if (!defaultAssignment && matchesDefaultAssignment(node)) {
              context.report({
                node,
                messageId: "unnecessaryConditionalAssignment",
                fix(fixer) {
                  const shouldParenthesizeAlternate = (astUtils.getPrecedence(node.alternate) < OR_PRECEDENCE || astUtils.isCoalesceExpression(node.alternate)) && !astUtils.isParenthesised(sourceCode, node.alternate);
                  const alternateText = shouldParenthesizeAlternate ? `(${sourceCode.getText(node.alternate)})` : astUtils.getParenthesisedText(sourceCode, node.alternate);
                  const testText = astUtils.getParenthesisedText(sourceCode, node.test);
                  return fixer.replaceText(node, `${testText} || ${alternateText}`);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unreachable.js
var require_no_unreachable = __commonJS({
  "node_modules/eslint/lib/rules/no-unreachable.js"(exports, module2) {
    "use strict";
    function isInitialized(node) {
      return Boolean(node.init);
    }
    function isUnreachable(segment) {
      return !segment.reachable;
    }
    var ConsecutiveRange = class {
      constructor(sourceCode) {
        this.sourceCode = sourceCode;
        this.startNode = null;
        this.endNode = null;
      }
      /**
       * The location object of this range.
       * @type {Object}
       */
      get location() {
        return {
          start: this.startNode.loc.start,
          end: this.endNode.loc.end
        };
      }
      /**
       * `true` if this range is empty.
       * @type {boolean}
       */
      get isEmpty() {
        return !(this.startNode && this.endNode);
      }
      /**
       * Checks whether the given node is inside of this range.
       * @param {ASTNode|Token} node The node to check.
       * @returns {boolean} `true` if the node is inside of this range.
       */
      contains(node) {
        return node.range[0] >= this.startNode.range[0] && node.range[1] <= this.endNode.range[1];
      }
      /**
       * Checks whether the given node is consecutive to this range.
       * @param {ASTNode} node The node to check.
       * @returns {boolean} `true` if the node is consecutive to this range.
       */
      isConsecutive(node) {
        return this.contains(this.sourceCode.getTokenBefore(node));
      }
      /**
       * Merges the given node to this range.
       * @param {ASTNode} node The node to merge.
       * @returns {void}
       */
      merge(node) {
        this.endNode = node;
      }
      /**
       * Resets this range by the given node or null.
       * @param {ASTNode|null} node The node to reset, or null.
       * @returns {void}
       */
      reset(node) {
        this.startNode = this.endNode = node;
      }
    };
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow unreachable code after `return`, `throw`, `continue`, and `break` statements",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unreachable"
        },
        schema: [],
        messages: {
          unreachableCode: "Unreachable code."
        }
      },
      create(context) {
        let currentCodePath = null;
        let constructorInfo = null;
        const range = new ConsecutiveRange(context.getSourceCode());
        function reportIfUnreachable(node) {
          let nextNode = null;
          if (node && (node.type === "PropertyDefinition" || currentCodePath.currentSegments.every(isUnreachable))) {
            if (range.isEmpty) {
              range.reset(node);
              return;
            }
            if (range.contains(node)) {
              return;
            }
            if (range.isConsecutive(node)) {
              range.merge(node);
              return;
            }
            nextNode = node;
          }
          if (!range.isEmpty) {
            context.report({
              messageId: "unreachableCode",
              loc: range.location,
              node: range.startNode
            });
          }
          range.reset(nextNode);
        }
        return {
          // Manages the current code path.
          onCodePathStart(codePath) {
            currentCodePath = codePath;
          },
          onCodePathEnd() {
            currentCodePath = currentCodePath.upper;
          },
          // Registers for all statement nodes (excludes FunctionDeclaration).
          BlockStatement: reportIfUnreachable,
          BreakStatement: reportIfUnreachable,
          ClassDeclaration: reportIfUnreachable,
          ContinueStatement: reportIfUnreachable,
          DebuggerStatement: reportIfUnreachable,
          DoWhileStatement: reportIfUnreachable,
          ExpressionStatement: reportIfUnreachable,
          ForInStatement: reportIfUnreachable,
          ForOfStatement: reportIfUnreachable,
          ForStatement: reportIfUnreachable,
          IfStatement: reportIfUnreachable,
          ImportDeclaration: reportIfUnreachable,
          LabeledStatement: reportIfUnreachable,
          ReturnStatement: reportIfUnreachable,
          SwitchStatement: reportIfUnreachable,
          ThrowStatement: reportIfUnreachable,
          TryStatement: reportIfUnreachable,
          VariableDeclaration(node) {
            if (node.kind !== "var" || node.declarations.some(isInitialized)) {
              reportIfUnreachable(node);
            }
          },
          WhileStatement: reportIfUnreachable,
          WithStatement: reportIfUnreachable,
          ExportNamedDeclaration: reportIfUnreachable,
          ExportDefaultDeclaration: reportIfUnreachable,
          ExportAllDeclaration: reportIfUnreachable,
          "Program:exit"() {
            reportIfUnreachable();
          },
          /*
           * Instance fields defined in a subclass are never created if the constructor of the subclass
           * doesn't call `super()`, so their definitions are unreachable code.
           */
          "MethodDefinition[kind='constructor']"() {
            constructorInfo = {
              upper: constructorInfo,
              hasSuperCall: false
            };
          },
          "MethodDefinition[kind='constructor']:exit"(node) {
            const { hasSuperCall } = constructorInfo;
            constructorInfo = constructorInfo.upper;
            if (!node.value.body) {
              return;
            }
            const classDefinition = node.parent.parent;
            if (classDefinition.superClass && !hasSuperCall) {
              for (const element of classDefinition.body.body) {
                if (element.type === "PropertyDefinition" && !element.static) {
                  reportIfUnreachable(element);
                }
              }
            }
          },
          "CallExpression > Super.callee"() {
            if (constructorInfo) {
              constructorInfo.hasSuperCall = true;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unreachable-loop.js
var require_no_unreachable_loop = __commonJS({
  "node_modules/eslint/lib/rules/no-unreachable-loop.js"(exports, module2) {
    "use strict";
    var allLoopTypes = ["WhileStatement", "DoWhileStatement", "ForStatement", "ForInStatement", "ForOfStatement"];
    function isLoopingTarget(node) {
      const parent = node.parent;
      if (parent) {
        switch (parent.type) {
          case "WhileStatement":
            return node === parent.test;
          case "DoWhileStatement":
            return node === parent.body;
          case "ForStatement":
            return node === (parent.update || parent.test || parent.body);
          case "ForInStatement":
          case "ForOfStatement":
            return node === parent.left;
        }
      }
      return false;
    }
    function getDifference(arrA, arrB) {
      return arrA.filter((a) => !arrB.includes(a));
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow loops with a body that allows only one iteration",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-unreachable-loop"
        },
        schema: [{
          type: "object",
          properties: {
            ignore: {
              type: "array",
              items: {
                enum: allLoopTypes
              },
              uniqueItems: true
            }
          },
          additionalProperties: false
        }],
        messages: {
          invalid: "Invalid loop. Its body allows only one iteration."
        }
      },
      create(context) {
        const ignoredLoopTypes = context.options[0] && context.options[0].ignore || [], loopTypesToCheck = getDifference(allLoopTypes, ignoredLoopTypes), loopSelector = loopTypesToCheck.join(","), loopsByTargetSegments = /* @__PURE__ */ new Map(), loopsToReport = /* @__PURE__ */ new Set();
        let currentCodePath = null;
        return {
          onCodePathStart(codePath) {
            currentCodePath = codePath;
          },
          onCodePathEnd() {
            currentCodePath = currentCodePath.upper;
          },
          [loopSelector](node) {
            if (currentCodePath.currentSegments.some((segment) => segment.reachable)) {
              loopsToReport.add(node);
            }
          },
          onCodePathSegmentStart(segment, node) {
            if (isLoopingTarget(node)) {
              const loop = node.parent;
              loopsByTargetSegments.set(segment, loop);
            }
          },
          onCodePathSegmentLoop(_, toSegment, node) {
            const loop = loopsByTargetSegments.get(toSegment);
            if (node === loop || node.type === "ContinueStatement") {
              loopsToReport.delete(loop);
            }
          },
          "Program:exit"() {
            loopsToReport.forEach(
              (node) => context.report({ node, messageId: "invalid" })
            );
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unsafe-finally.js
var require_no_unsafe_finally = __commonJS({
  "node_modules/eslint/lib/rules/no-unsafe-finally.js"(exports, module2) {
    "use strict";
    var SENTINEL_NODE_TYPE_RETURN_THROW = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression)$/u;
    var SENTINEL_NODE_TYPE_BREAK = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|DoWhileStatement|WhileStatement|ForOfStatement|ForInStatement|ForStatement|SwitchStatement)$/u;
    var SENTINEL_NODE_TYPE_CONTINUE = /^(?:Program|(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|DoWhileStatement|WhileStatement|ForOfStatement|ForInStatement|ForStatement)$/u;
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow control flow statements in `finally` blocks",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unsafe-finally"
        },
        schema: [],
        messages: {
          unsafeUsage: "Unsafe usage of {{nodeType}}."
        }
      },
      create(context) {
        function isFinallyBlock(node) {
          return node.parent.type === "TryStatement" && node.parent.finalizer === node;
        }
        function isInFinallyBlock(node, label) {
          let labelInside = false;
          let sentinelNodeType;
          if (node.type === "BreakStatement" && !node.label) {
            sentinelNodeType = SENTINEL_NODE_TYPE_BREAK;
          } else if (node.type === "ContinueStatement") {
            sentinelNodeType = SENTINEL_NODE_TYPE_CONTINUE;
          } else {
            sentinelNodeType = SENTINEL_NODE_TYPE_RETURN_THROW;
          }
          for (let currentNode = node; currentNode && !sentinelNodeType.test(currentNode.type); currentNode = currentNode.parent) {
            if (currentNode.parent.label && label && currentNode.parent.label.name === label.name) {
              labelInside = true;
            }
            if (isFinallyBlock(currentNode)) {
              if (label && labelInside) {
                return false;
              }
              return true;
            }
          }
          return false;
        }
        function check(node) {
          if (isInFinallyBlock(node, node.label)) {
            context.report({
              messageId: "unsafeUsage",
              data: {
                nodeType: node.type
              },
              node,
              line: node.loc.line,
              column: node.loc.column
            });
          }
        }
        return {
          ReturnStatement: check,
          ThrowStatement: check,
          BreakStatement: check,
          ContinueStatement: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unsafe-negation.js
var require_no_unsafe_negation = __commonJS({
  "node_modules/eslint/lib/rules/no-unsafe-negation.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isInOrInstanceOfOperator(op) {
      return op === "in" || op === "instanceof";
    }
    function isOrderingRelationalOperator(op) {
      return op === "<" || op === ">" || op === ">=" || op === "<=";
    }
    function isNegation(node) {
      return node.type === "UnaryExpression" && node.operator === "!";
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow negating the left operand of relational operators",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unsafe-negation"
        },
        hasSuggestions: true,
        schema: [
          {
            type: "object",
            properties: {
              enforceForOrderingRelations: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: null,
        messages: {
          unexpected: "Unexpected negating the left operand of '{{operator}}' operator.",
          suggestNegatedExpression: "Negate '{{operator}}' expression instead of its left operand. This changes the current behavior.",
          suggestParenthesisedNegation: "Wrap negation in '()' to make the intention explicit. This preserves the current behavior."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = context.options[0] || {};
        const enforceForOrderingRelations = options.enforceForOrderingRelations === true;
        return {
          BinaryExpression(node) {
            const operator = node.operator;
            const orderingRelationRuleApplies = enforceForOrderingRelations && isOrderingRelationalOperator(operator);
            if ((isInOrInstanceOfOperator(operator) || orderingRelationRuleApplies) && isNegation(node.left) && !astUtils.isParenthesised(sourceCode, node.left)) {
              context.report({
                node,
                loc: node.left.loc,
                messageId: "unexpected",
                data: { operator },
                suggest: [
                  {
                    messageId: "suggestNegatedExpression",
                    data: { operator },
                    fix(fixer) {
                      const negationToken = sourceCode.getFirstToken(node.left);
                      const fixRange = [negationToken.range[1], node.range[1]];
                      const text = sourceCode.text.slice(fixRange[0], fixRange[1]);
                      return fixer.replaceTextRange(fixRange, `(${text})`);
                    }
                  },
                  {
                    messageId: "suggestParenthesisedNegation",
                    fix(fixer) {
                      return fixer.replaceText(node.left, `(${sourceCode.getText(node.left)})`);
                    }
                  }
                ]
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unsafe-optional-chaining.js
var require_no_unsafe_optional_chaining = __commonJS({
  "node_modules/eslint/lib/rules/no-unsafe-optional-chaining.js"(exports, module2) {
    "use strict";
    var UNSAFE_ARITHMETIC_OPERATORS = /* @__PURE__ */ new Set(["+", "-", "/", "*", "%", "**"]);
    var UNSAFE_ASSIGNMENT_OPERATORS = /* @__PURE__ */ new Set(["+=", "-=", "/=", "*=", "%=", "**="]);
    var UNSAFE_RELATIONAL_OPERATORS = /* @__PURE__ */ new Set(["in", "instanceof"]);
    function isDestructuringPattern(node) {
      return node.type === "ObjectPattern" || node.type === "ArrayPattern";
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow use of optional chaining in contexts where the `undefined` value is not allowed",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unsafe-optional-chaining"
        },
        schema: [{
          type: "object",
          properties: {
            disallowArithmeticOperators: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        fixable: null,
        messages: {
          unsafeOptionalChain: "Unsafe usage of optional chaining. If it short-circuits with 'undefined' the evaluation will throw TypeError.",
          unsafeArithmetic: "Unsafe arithmetic operation on optional chaining. It can result in NaN."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const disallowArithmeticOperators = options.disallowArithmeticOperators || false;
        function reportUnsafeUsage(node) {
          context.report({
            messageId: "unsafeOptionalChain",
            node
          });
        }
        function reportUnsafeArithmetic(node) {
          context.report({
            messageId: "unsafeArithmetic",
            node
          });
        }
        function checkUndefinedShortCircuit(node, reportFunc) {
          if (!node) {
            return;
          }
          switch (node.type) {
            case "LogicalExpression":
              if (node.operator === "||" || node.operator === "??") {
                checkUndefinedShortCircuit(node.right, reportFunc);
              } else if (node.operator === "&&") {
                checkUndefinedShortCircuit(node.left, reportFunc);
                checkUndefinedShortCircuit(node.right, reportFunc);
              }
              break;
            case "SequenceExpression":
              checkUndefinedShortCircuit(
                node.expressions[node.expressions.length - 1],
                reportFunc
              );
              break;
            case "ConditionalExpression":
              checkUndefinedShortCircuit(node.consequent, reportFunc);
              checkUndefinedShortCircuit(node.alternate, reportFunc);
              break;
            case "AwaitExpression":
              checkUndefinedShortCircuit(node.argument, reportFunc);
              break;
            case "ChainExpression":
              reportFunc(node);
              break;
            default:
              break;
          }
        }
        function checkUnsafeUsage(node) {
          checkUndefinedShortCircuit(node, reportUnsafeUsage);
        }
        function checkUnsafeArithmetic(node) {
          checkUndefinedShortCircuit(node, reportUnsafeArithmetic);
        }
        return {
          "AssignmentExpression, AssignmentPattern"(node) {
            if (isDestructuringPattern(node.left)) {
              checkUnsafeUsage(node.right);
            }
          },
          "ClassDeclaration, ClassExpression"(node) {
            checkUnsafeUsage(node.superClass);
          },
          CallExpression(node) {
            if (!node.optional) {
              checkUnsafeUsage(node.callee);
            }
          },
          NewExpression(node) {
            checkUnsafeUsage(node.callee);
          },
          VariableDeclarator(node) {
            if (isDestructuringPattern(node.id)) {
              checkUnsafeUsage(node.init);
            }
          },
          MemberExpression(node) {
            if (!node.optional) {
              checkUnsafeUsage(node.object);
            }
          },
          TaggedTemplateExpression(node) {
            checkUnsafeUsage(node.tag);
          },
          ForOfStatement(node) {
            checkUnsafeUsage(node.right);
          },
          SpreadElement(node) {
            if (node.parent && node.parent.type !== "ObjectExpression") {
              checkUnsafeUsage(node.argument);
            }
          },
          BinaryExpression(node) {
            if (UNSAFE_RELATIONAL_OPERATORS.has(node.operator)) {
              checkUnsafeUsage(node.right);
            }
            if (disallowArithmeticOperators && UNSAFE_ARITHMETIC_OPERATORS.has(node.operator)) {
              checkUnsafeArithmetic(node.right);
              checkUnsafeArithmetic(node.left);
            }
          },
          WithStatement(node) {
            checkUnsafeUsage(node.object);
          },
          UnaryExpression(node) {
            if (disallowArithmeticOperators && UNSAFE_ARITHMETIC_OPERATORS.has(node.operator)) {
              checkUnsafeArithmetic(node.argument);
            }
          },
          AssignmentExpression(node) {
            if (disallowArithmeticOperators && UNSAFE_ASSIGNMENT_OPERATORS.has(node.operator)) {
              checkUnsafeArithmetic(node.right);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unused-expressions.js
var require_no_unused_expressions = __commonJS({
  "node_modules/eslint/lib/rules/no-unused-expressions.js"(exports, module2) {
    "use strict";
    function alwaysTrue() {
      return true;
    }
    function alwaysFalse() {
      return false;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unused expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-unused-expressions"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowShortCircuit: {
                type: "boolean",
                default: false
              },
              allowTernary: {
                type: "boolean",
                default: false
              },
              allowTaggedTemplates: {
                type: "boolean",
                default: false
              },
              enforceForJSX: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unusedExpression: "Expected an assignment or function call and instead saw an expression."
        }
      },
      create(context) {
        const config = context.options[0] || {}, allowShortCircuit = config.allowShortCircuit || false, allowTernary = config.allowTernary || false, allowTaggedTemplates = config.allowTaggedTemplates || false, enforceForJSX = config.enforceForJSX || false;
        function looksLikeDirective(node) {
          return node.type === "ExpressionStatement" && node.expression.type === "Literal" && typeof node.expression.value === "string";
        }
        function takeWhile(predicate, list) {
          for (let i = 0; i < list.length; ++i) {
            if (!predicate(list[i])) {
              return list.slice(0, i);
            }
          }
          return list.slice();
        }
        function directives(node) {
          return takeWhile(looksLikeDirective, node.body);
        }
        function isDirective(node, ancestors) {
          const parent = ancestors[ancestors.length - 1], grandparent = ancestors[ancestors.length - 2];
          return (parent.type === "Program" || parent.type === "BlockStatement" && /Function/u.test(grandparent.type)) && directives(parent).includes(node);
        }
        const Checker = Object.assign(/* @__PURE__ */ Object.create(null), {
          isDisallowed(node) {
            return (Checker[node.type] || alwaysFalse)(node);
          },
          ArrayExpression: alwaysTrue,
          ArrowFunctionExpression: alwaysTrue,
          BinaryExpression: alwaysTrue,
          ChainExpression(node) {
            return Checker.isDisallowed(node.expression);
          },
          ClassExpression: alwaysTrue,
          ConditionalExpression(node) {
            if (allowTernary) {
              return Checker.isDisallowed(node.consequent) || Checker.isDisallowed(node.alternate);
            }
            return true;
          },
          FunctionExpression: alwaysTrue,
          Identifier: alwaysTrue,
          JSXElement() {
            return enforceForJSX;
          },
          JSXFragment() {
            return enforceForJSX;
          },
          Literal: alwaysTrue,
          LogicalExpression(node) {
            if (allowShortCircuit) {
              return Checker.isDisallowed(node.right);
            }
            return true;
          },
          MemberExpression: alwaysTrue,
          MetaProperty: alwaysTrue,
          ObjectExpression: alwaysTrue,
          SequenceExpression: alwaysTrue,
          TaggedTemplateExpression() {
            return !allowTaggedTemplates;
          },
          TemplateLiteral: alwaysTrue,
          ThisExpression: alwaysTrue,
          UnaryExpression(node) {
            return node.operator !== "void" && node.operator !== "delete";
          }
        });
        return {
          ExpressionStatement(node) {
            if (Checker.isDisallowed(node.expression) && !isDirective(node, context.getAncestors())) {
              context.report({ node, messageId: "unusedExpression" });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unused-labels.js
var require_no_unused_labels = __commonJS({
  "node_modules/eslint/lib/rules/no-unused-labels.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unused labels",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unused-labels"
        },
        schema: [],
        fixable: "code",
        messages: {
          unused: "'{{name}}:' is defined but never used."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let scopeInfo = null;
        function enterLabeledScope(node) {
          scopeInfo = {
            label: node.label.name,
            used: false,
            upper: scopeInfo
          };
        }
        function exitLabeledScope(node) {
          if (!scopeInfo.used) {
            context.report({
              node: node.label,
              messageId: "unused",
              data: node.label,
              fix(fixer) {
                if (sourceCode.getTokenAfter(node.label, { includeComments: true }) === sourceCode.getTokenBefore(node.body, { includeComments: true })) {
                  return fixer.removeRange([node.range[0], node.body.range[0]]);
                }
                return null;
              }
            });
          }
          scopeInfo = scopeInfo.upper;
        }
        function markAsUsed(node) {
          if (!node.label) {
            return;
          }
          const label = node.label.name;
          let info = scopeInfo;
          while (info) {
            if (info.label === label) {
              info.used = true;
              break;
            }
            info = info.upper;
          }
        }
        return {
          LabeledStatement: enterLabeledScope,
          "LabeledStatement:exit": exitLabeledScope,
          BreakStatement: markAsUsed,
          ContinueStatement: markAsUsed
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unused-private-class-members.js
var require_no_unused_private_class_members = __commonJS({
  "node_modules/eslint/lib/rules/no-unused-private-class-members.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow unused private class members",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-unused-private-class-members"
        },
        schema: [],
        messages: {
          unusedPrivateClassMember: "'{{classMemberName}}' is defined but never used."
        }
      },
      create(context) {
        const trackedClasses = [];
        function isWriteOnlyAssignment(privateIdentifierNode) {
          const parentStatement = privateIdentifierNode.parent.parent;
          const isAssignmentExpression = parentStatement.type === "AssignmentExpression";
          if (!isAssignmentExpression && parentStatement.type !== "ForInStatement" && parentStatement.type !== "ForOfStatement" && parentStatement.type !== "AssignmentPattern") {
            return false;
          }
          if (parentStatement.left !== privateIdentifierNode.parent) {
            return false;
          }
          if (isAssignmentExpression && parentStatement.operator !== "=") {
            return parentStatement.parent.type === "ExpressionStatement";
          }
          return true;
        }
        return {
          // Collect all declared members up front and assume they are all unused
          ClassBody(classBodyNode) {
            const privateMembers = /* @__PURE__ */ new Map();
            trackedClasses.unshift(privateMembers);
            for (const bodyMember of classBodyNode.body) {
              if (bodyMember.type === "PropertyDefinition" || bodyMember.type === "MethodDefinition") {
                if (bodyMember.key.type === "PrivateIdentifier") {
                  privateMembers.set(bodyMember.key.name, {
                    declaredNode: bodyMember,
                    isAccessor: bodyMember.type === "MethodDefinition" && (bodyMember.kind === "set" || bodyMember.kind === "get")
                  });
                }
              }
            }
          },
          /*
           * Process all usages of the private identifier and remove a member from
           * `declaredAndUnusedPrivateMembers` if we deem it used.
           */
          PrivateIdentifier(privateIdentifierNode) {
            const classBody = trackedClasses.find((classProperties) => classProperties.has(privateIdentifierNode.name));
            if (!classBody) {
              return;
            }
            const memberDefinition = classBody.get(privateIdentifierNode.name);
            if (memberDefinition.isUsed) {
              return;
            }
            if (privateIdentifierNode.parent.type === "PropertyDefinition" || privateIdentifierNode.parent.type === "MethodDefinition") {
              return;
            }
            if (memberDefinition.isAccessor) {
              memberDefinition.isUsed = true;
              return;
            }
            if (isWriteOnlyAssignment(privateIdentifierNode)) {
              return;
            }
            const wrappingExpressionType = privateIdentifierNode.parent.parent.type;
            const parentOfWrappingExpressionType = privateIdentifierNode.parent.parent.parent.type;
            if (wrappingExpressionType === "UpdateExpression" && parentOfWrappingExpressionType === "ExpressionStatement") {
              return;
            }
            if (wrappingExpressionType === "Property" && parentOfWrappingExpressionType === "ObjectPattern" && privateIdentifierNode.parent.parent.value === privateIdentifierNode.parent) {
              return;
            }
            if (wrappingExpressionType === "RestElement") {
              return;
            }
            if (wrappingExpressionType === "ArrayPattern") {
              return;
            }
            memberDefinition.isUsed = true;
          },
          /*
           * Post-process the class members and report any remaining members.
           * Since private members can only be accessed in the current class context,
           * we can safely assume that all usages are within the current class body.
           */
          "ClassBody:exit"() {
            const unusedPrivateMembers = trackedClasses.shift();
            for (const [classMemberName, { declaredNode, isUsed }] of unusedPrivateMembers.entries()) {
              if (isUsed) {
                continue;
              }
              context.report({
                node: declaredNode,
                loc: declaredNode.key.loc,
                messageId: "unusedPrivateClassMember",
                data: {
                  classMemberName: `#${classMemberName}`
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-unused-vars.js
var require_no_unused_vars = __commonJS({
  "node_modules/eslint/lib/rules/no-unused-vars.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow unused variables",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-unused-vars"
        },
        schema: [
          {
            oneOf: [
              {
                enum: ["all", "local"]
              },
              {
                type: "object",
                properties: {
                  vars: {
                    enum: ["all", "local"]
                  },
                  varsIgnorePattern: {
                    type: "string"
                  },
                  args: {
                    enum: ["all", "after-used", "none"]
                  },
                  ignoreRestSiblings: {
                    type: "boolean"
                  },
                  argsIgnorePattern: {
                    type: "string"
                  },
                  caughtErrors: {
                    enum: ["all", "none"]
                  },
                  caughtErrorsIgnorePattern: {
                    type: "string"
                  },
                  destructuredArrayIgnorePattern: {
                    type: "string"
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          unusedVar: "'{{varName}}' is {{action}} but never used{{additional}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const REST_PROPERTY_TYPE = /^(?:RestElement|(?:Experimental)?RestProperty)$/u;
        const config = {
          vars: "all",
          args: "after-used",
          ignoreRestSiblings: false,
          caughtErrors: "none"
        };
        const firstOption = context.options[0];
        if (firstOption) {
          if (typeof firstOption === "string") {
            config.vars = firstOption;
          } else {
            config.vars = firstOption.vars || config.vars;
            config.args = firstOption.args || config.args;
            config.ignoreRestSiblings = firstOption.ignoreRestSiblings || config.ignoreRestSiblings;
            config.caughtErrors = firstOption.caughtErrors || config.caughtErrors;
            if (firstOption.varsIgnorePattern) {
              config.varsIgnorePattern = new RegExp(firstOption.varsIgnorePattern, "u");
            }
            if (firstOption.argsIgnorePattern) {
              config.argsIgnorePattern = new RegExp(firstOption.argsIgnorePattern, "u");
            }
            if (firstOption.caughtErrorsIgnorePattern) {
              config.caughtErrorsIgnorePattern = new RegExp(firstOption.caughtErrorsIgnorePattern, "u");
            }
            if (firstOption.destructuredArrayIgnorePattern) {
              config.destructuredArrayIgnorePattern = new RegExp(firstOption.destructuredArrayIgnorePattern, "u");
            }
          }
        }
        function getDefinedMessageData(unusedVar) {
          const defType = unusedVar.defs && unusedVar.defs[0] && unusedVar.defs[0].type;
          let type;
          let pattern;
          if (defType === "CatchClause" && config.caughtErrorsIgnorePattern) {
            type = "args";
            pattern = config.caughtErrorsIgnorePattern.toString();
          } else if (defType === "Parameter" && config.argsIgnorePattern) {
            type = "args";
            pattern = config.argsIgnorePattern.toString();
          } else if (defType !== "Parameter" && config.varsIgnorePattern) {
            type = "vars";
            pattern = config.varsIgnorePattern.toString();
          }
          const additional = type ? `. Allowed unused ${type} must match ${pattern}` : "";
          return {
            varName: unusedVar.name,
            action: "defined",
            additional
          };
        }
        function getAssignedMessageData(unusedVar) {
          const def = unusedVar.defs[0];
          let additional = "";
          if (config.destructuredArrayIgnorePattern && def && def.name.parent.type === "ArrayPattern") {
            additional = `. Allowed unused elements of array destructuring patterns must match ${config.destructuredArrayIgnorePattern.toString()}`;
          } else if (config.varsIgnorePattern) {
            additional = `. Allowed unused vars must match ${config.varsIgnorePattern.toString()}`;
          }
          return {
            varName: unusedVar.name,
            action: "assigned a value",
            additional
          };
        }
        const STATEMENT_TYPE = /(?:Statement|Declaration)$/u;
        function isExported(variable) {
          const definition = variable.defs[0];
          if (definition) {
            let node = definition.node;
            if (node.type === "VariableDeclarator") {
              node = node.parent;
            } else if (definition.type === "Parameter") {
              return false;
            }
            return node.parent.type.indexOf("Export") === 0;
          }
          return false;
        }
        function hasRestSibling(node) {
          return node.type === "Property" && node.parent.type === "ObjectPattern" && REST_PROPERTY_TYPE.test(node.parent.properties[node.parent.properties.length - 1].type);
        }
        function hasRestSpreadSibling(variable) {
          if (config.ignoreRestSiblings) {
            const hasRestSiblingDefinition = variable.defs.some((def) => hasRestSibling(def.name.parent));
            const hasRestSiblingReference = variable.references.some((ref) => hasRestSibling(ref.identifier.parent));
            return hasRestSiblingDefinition || hasRestSiblingReference;
          }
          return false;
        }
        function isReadRef(ref) {
          return ref.isRead();
        }
        function isSelfReference(ref, nodes) {
          let scope = ref.from;
          while (scope) {
            if (nodes.includes(scope.block)) {
              return true;
            }
            scope = scope.upper;
          }
          return false;
        }
        function getFunctionDefinitions(variable) {
          const functionDefinitions = [];
          variable.defs.forEach((def) => {
            const { type, node } = def;
            if (type === "FunctionName") {
              functionDefinitions.push(node);
            }
            if (type === "Variable" && node.init && (node.init.type === "FunctionExpression" || node.init.type === "ArrowFunctionExpression")) {
              functionDefinitions.push(node.init);
            }
          });
          return functionDefinitions;
        }
        function isInside(inner, outer) {
          return inner.range[0] >= outer.range[0] && inner.range[1] <= outer.range[1];
        }
        function isUnusedExpression(node) {
          const parent = node.parent;
          if (parent.type === "ExpressionStatement") {
            return true;
          }
          if (parent.type === "SequenceExpression") {
            const isLastExpression = parent.expressions[parent.expressions.length - 1] === node;
            if (!isLastExpression) {
              return true;
            }
            return isUnusedExpression(parent);
          }
          return false;
        }
        function getRhsNode(ref, prevRhsNode) {
          const id = ref.identifier;
          const parent = id.parent;
          const refScope = ref.from.variableScope;
          const varScope = ref.resolved.scope.variableScope;
          const canBeUsedLater = refScope !== varScope || astUtils.isInLoop(id);
          if (prevRhsNode && isInside(id, prevRhsNode)) {
            return prevRhsNode;
          }
          if (parent.type === "AssignmentExpression" && isUnusedExpression(parent) && id === parent.left && !canBeUsedLater) {
            return parent.right;
          }
          return null;
        }
        function isStorableFunction(funcNode, rhsNode) {
          let node = funcNode;
          let parent = funcNode.parent;
          while (parent && isInside(parent, rhsNode)) {
            switch (parent.type) {
              case "SequenceExpression":
                if (parent.expressions[parent.expressions.length - 1] !== node) {
                  return false;
                }
                break;
              case "CallExpression":
              case "NewExpression":
                return parent.callee !== node;
              case "AssignmentExpression":
              case "TaggedTemplateExpression":
              case "YieldExpression":
                return true;
              default:
                if (STATEMENT_TYPE.test(parent.type)) {
                  return true;
                }
            }
            node = parent;
            parent = parent.parent;
          }
          return false;
        }
        function isInsideOfStorableFunction(id, rhsNode) {
          const funcNode = astUtils.getUpperFunction(id);
          return funcNode && isInside(funcNode, rhsNode) && isStorableFunction(funcNode, rhsNode);
        }
        function isReadForItself(ref, rhsNode) {
          const id = ref.identifier;
          const parent = id.parent;
          return ref.isRead() && // self update. e.g. `a += 1`, `a++`
          (parent.type === "AssignmentExpression" && parent.left === id && isUnusedExpression(parent) || parent.type === "UpdateExpression" && isUnusedExpression(parent) || // in RHS of an assignment for itself. e.g. `a = a + 1`
          rhsNode && isInside(id, rhsNode) && !isInsideOfStorableFunction(id, rhsNode));
        }
        function isForInOfRef(ref) {
          let target = ref.identifier.parent;
          if (target.type === "VariableDeclarator") {
            target = target.parent.parent;
          }
          if (target.type !== "ForInStatement" && target.type !== "ForOfStatement") {
            return false;
          }
          if (target.body.type === "BlockStatement") {
            target = target.body.body[0];
          } else {
            target = target.body;
          }
          if (!target) {
            return false;
          }
          return target.type === "ReturnStatement";
        }
        function isUsedVariable(variable) {
          const functionNodes = getFunctionDefinitions(variable), isFunctionDefinition = functionNodes.length > 0;
          let rhsNode = null;
          return variable.references.some((ref) => {
            if (isForInOfRef(ref)) {
              return true;
            }
            const forItself = isReadForItself(ref, rhsNode);
            rhsNode = getRhsNode(ref, rhsNode);
            return isReadRef(ref) && !forItself && !(isFunctionDefinition && isSelfReference(ref, functionNodes));
          });
        }
        function isAfterLastUsedArg(variable) {
          const def = variable.defs[0];
          const params = context.getDeclaredVariables(def.node);
          const posteriorParams = params.slice(params.indexOf(variable) + 1);
          return !posteriorParams.some((v) => v.references.length > 0 || v.eslintUsed);
        }
        function collectUnusedVariables(scope, unusedVars) {
          const variables = scope.variables;
          const childScopes = scope.childScopes;
          let i, l;
          if (scope.type !== "global" || config.vars === "all") {
            for (i = 0, l = variables.length; i < l; ++i) {
              const variable = variables[i];
              if (scope.type === "class" && scope.block.id === variable.identifiers[0]) {
                continue;
              }
              if (scope.functionExpressionScope || variable.eslintUsed) {
                continue;
              }
              if (scope.type === "function" && variable.name === "arguments" && variable.identifiers.length === 0) {
                continue;
              }
              const def = variable.defs[0];
              if (def) {
                const type = def.type;
                const refUsedInArrayPatterns = variable.references.some((ref) => ref.identifier.parent.type === "ArrayPattern");
                if ((def.name.parent.type === "ArrayPattern" || refUsedInArrayPatterns) && config.destructuredArrayIgnorePattern && config.destructuredArrayIgnorePattern.test(def.name.name)) {
                  continue;
                }
                if (type === "CatchClause") {
                  if (config.caughtErrors === "none") {
                    continue;
                  }
                  if (config.caughtErrorsIgnorePattern && config.caughtErrorsIgnorePattern.test(def.name.name)) {
                    continue;
                  }
                }
                if (type === "Parameter") {
                  if ((def.node.parent.type === "Property" || def.node.parent.type === "MethodDefinition") && def.node.parent.kind === "set") {
                    continue;
                  }
                  if (config.args === "none") {
                    continue;
                  }
                  if (config.argsIgnorePattern && config.argsIgnorePattern.test(def.name.name)) {
                    continue;
                  }
                  if (config.args === "after-used" && astUtils.isFunction(def.name.parent) && !isAfterLastUsedArg(variable)) {
                    continue;
                  }
                } else {
                  if (config.varsIgnorePattern && config.varsIgnorePattern.test(def.name.name)) {
                    continue;
                  }
                }
              }
              if (!isUsedVariable(variable) && !isExported(variable) && !hasRestSpreadSibling(variable)) {
                unusedVars.push(variable);
              }
            }
          }
          for (i = 0, l = childScopes.length; i < l; ++i) {
            collectUnusedVariables(childScopes[i], unusedVars);
          }
          return unusedVars;
        }
        return {
          "Program:exit"(programNode) {
            const unusedVars = collectUnusedVariables(context.getScope(), []);
            for (let i = 0, l = unusedVars.length; i < l; ++i) {
              const unusedVar = unusedVars[i];
              if (unusedVar.defs.length > 0) {
                const writeReferences = unusedVar.references.filter((ref) => ref.isWrite() && ref.from.variableScope === unusedVar.scope.variableScope);
                let referenceToReport;
                if (writeReferences.length > 0) {
                  referenceToReport = writeReferences[writeReferences.length - 1];
                }
                context.report({
                  node: referenceToReport ? referenceToReport.identifier : unusedVar.identifiers[0],
                  messageId: "unusedVar",
                  data: unusedVar.references.some((ref) => ref.isWrite()) ? getAssignedMessageData(unusedVar) : getDefinedMessageData(unusedVar)
                });
              } else if (unusedVar.eslintExplicitGlobalComments) {
                const directiveComment = unusedVar.eslintExplicitGlobalComments[0];
                context.report({
                  node: programNode,
                  loc: astUtils.getNameLocationInGlobalDirectiveComment(sourceCode, directiveComment, unusedVar.name),
                  messageId: "unusedVar",
                  data: getDefinedMessageData(unusedVar)
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-use-before-define.js
var require_no_use_before_define = __commonJS({
  "node_modules/eslint/lib/rules/no-use-before-define.js"(exports, module2) {
    "use strict";
    var SENTINEL_TYPE = /^(?:(?:Function|Class)(?:Declaration|Expression)|ArrowFunctionExpression|CatchClause|ImportDeclaration|ExportNamedDeclaration)$/u;
    var FOR_IN_OF_TYPE = /^For(?:In|Of)Statement$/u;
    function parseOptions(options) {
      let functions = true;
      let classes = true;
      let variables = true;
      let allowNamedExports = false;
      if (typeof options === "string") {
        functions = options !== "nofunc";
      } else if (typeof options === "object" && options !== null) {
        functions = options.functions !== false;
        classes = options.classes !== false;
        variables = options.variables !== false;
        allowNamedExports = !!options.allowNamedExports;
      }
      return { functions, classes, variables, allowNamedExports };
    }
    function isInRange(node, location) {
      return node && node.range[0] <= location && location <= node.range[1];
    }
    function isInClassStaticInitializerRange(node, location) {
      return node.body.some((classMember) => classMember.type === "StaticBlock" && isInRange(classMember, location) || classMember.type === "PropertyDefinition" && classMember.static && classMember.value && isInRange(classMember.value, location));
    }
    function isClassStaticInitializerScope(scope) {
      if (scope.type === "class-static-block") {
        return true;
      }
      if (scope.type === "class-field-initializer") {
        const propertyDefinition = scope.block.parent;
        return propertyDefinition.static;
      }
      return false;
    }
    function isFromSeparateExecutionContext(reference) {
      const variable = reference.resolved;
      let scope = reference.from;
      while (variable.scope.variableScope !== scope.variableScope) {
        if (isClassStaticInitializerScope(scope.variableScope)) {
          scope = scope.variableScope.upper;
        } else {
          return true;
        }
      }
      return false;
    }
    function isEvaluatedDuringInitialization(reference) {
      if (isFromSeparateExecutionContext(reference)) {
        return false;
      }
      const location = reference.identifier.range[1];
      const definition = reference.resolved.defs[0];
      if (definition.type === "ClassName") {
        const classDefinition = definition.node;
        return isInRange(classDefinition, location) && /*
         * Class binding is initialized before running static initializers.
         * For example, `class C { static foo = C; static { bar = C; } }` is valid.
         */
        !isInClassStaticInitializerRange(classDefinition.body, location);
      }
      let node = definition.name.parent;
      while (node) {
        if (node.type === "VariableDeclarator") {
          if (isInRange(node.init, location)) {
            return true;
          }
          if (FOR_IN_OF_TYPE.test(node.parent.parent.type) && isInRange(node.parent.parent.right, location)) {
            return true;
          }
          break;
        } else if (node.type === "AssignmentPattern") {
          if (isInRange(node.right, location)) {
            return true;
          }
        } else if (SENTINEL_TYPE.test(node.type)) {
          break;
        }
        node = node.parent;
      }
      return false;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow the use of variables before they are defined",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-use-before-define"
        },
        schema: [
          {
            oneOf: [
              {
                enum: ["nofunc"]
              },
              {
                type: "object",
                properties: {
                  functions: { type: "boolean" },
                  classes: { type: "boolean" },
                  variables: { type: "boolean" },
                  allowNamedExports: { type: "boolean" }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          usedBeforeDefined: "'{{name}}' was used before it was defined."
        }
      },
      create(context) {
        const options = parseOptions(context.options[0]);
        function shouldCheck(reference) {
          if (reference.init) {
            return false;
          }
          const { identifier: identifier3 } = reference;
          if (options.allowNamedExports && identifier3.parent.type === "ExportSpecifier" && identifier3.parent.local === identifier3) {
            return false;
          }
          const variable = reference.resolved;
          if (!variable || variable.defs.length === 0) {
            return false;
          }
          const definitionType = variable.defs[0].type;
          if (!options.functions && definitionType === "FunctionName") {
            return false;
          }
          if ((!options.variables && definitionType === "Variable" || !options.classes && definitionType === "ClassName") && // don't skip checking the reference if it's in the same execution context, because of TDZ
          isFromSeparateExecutionContext(reference)) {
            return false;
          }
          return true;
        }
        function checkReferencesInScope(scope) {
          scope.references.filter(shouldCheck).forEach((reference) => {
            const variable = reference.resolved;
            const definitionIdentifier = variable.defs[0].name;
            if (reference.identifier.range[1] < definitionIdentifier.range[1] || isEvaluatedDuringInitialization(reference)) {
              context.report({
                node: reference.identifier,
                messageId: "usedBeforeDefined",
                data: reference.identifier
              });
            }
          });
          scope.childScopes.forEach(checkReferencesInScope);
        }
        return {
          Program() {
            checkReferencesInScope(context.getScope());
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-backreference.js
var require_no_useless_backreference = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-backreference.js"(exports, module2) {
    "use strict";
    var { CALL, CONSTRUCT, ReferenceTracker, getStringIfConstant } = require_eslint_utils();
    var { RegExpParser, visitRegExpAST } = require_regexpp();
    var parser = new RegExpParser();
    function getPathToRoot(node) {
      const path2 = [];
      let current = node;
      do {
        path2.push(current);
        current = current.parent;
      } while (current);
      return path2;
    }
    function isLookaround(node) {
      return node.type === "Assertion" && (node.kind === "lookahead" || node.kind === "lookbehind");
    }
    function isNegativeLookaround(node) {
      return isLookaround(node) && node.negate;
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow useless backreferences in regular expressions",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-useless-backreference"
        },
        schema: [],
        messages: {
          nested: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' from within that group.",
          forward: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which appears later in the pattern.",
          backward: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which appears before in the same lookbehind.",
          disjunctive: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which is in another alternative.",
          intoNegativeLookaround: "Backreference '{{ bref }}' will be ignored. It references group '{{ group }}' which is in a negative lookaround."
        }
      },
      create(context) {
        function checkRegex(node, pattern, flags) {
          let regExpAST;
          try {
            regExpAST = parser.parsePattern(pattern, 0, pattern.length, flags.includes("u"));
          } catch {
            return;
          }
          visitRegExpAST(regExpAST, {
            onBackreferenceEnter(bref) {
              const group = bref.resolved, brefPath = getPathToRoot(bref), groupPath = getPathToRoot(group);
              let messageId = null;
              if (brefPath.includes(group)) {
                messageId = "nested";
              } else {
                let i = brefPath.length - 1, j = groupPath.length - 1;
                do {
                  i--;
                  j--;
                } while (brefPath[i] === groupPath[j]);
                const indexOfLowestCommonAncestor = j + 1, groupCut = groupPath.slice(0, indexOfLowestCommonAncestor), commonPath = groupPath.slice(indexOfLowestCommonAncestor), lowestCommonLookaround = commonPath.find(isLookaround), isMatchingBackward = lowestCommonLookaround && lowestCommonLookaround.kind === "lookbehind";
                if (!isMatchingBackward && bref.end <= group.start) {
                  messageId = "forward";
                } else if (isMatchingBackward && group.end <= bref.start) {
                  messageId = "backward";
                } else if (groupCut[groupCut.length - 1].type === "Alternative") {
                  messageId = "disjunctive";
                } else if (groupCut.some(isNegativeLookaround)) {
                  messageId = "intoNegativeLookaround";
                }
              }
              if (messageId) {
                context.report({
                  node,
                  messageId,
                  data: {
                    bref: bref.raw,
                    group: group.raw
                  }
                });
              }
            }
          });
        }
        return {
          "Literal[regex]"(node) {
            const { pattern, flags } = node.regex;
            checkRegex(node, pattern, flags);
          },
          Program() {
            const scope = context.getScope(), tracker = new ReferenceTracker(scope), traceMap = {
              RegExp: {
                [CALL]: true,
                [CONSTRUCT]: true
              }
            };
            for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
              const [patternNode, flagsNode] = node.arguments, pattern = getStringIfConstant(patternNode, scope), flags = getStringIfConstant(flagsNode, scope);
              if (typeof pattern === "string") {
                checkRegex(node, pattern, flags || "");
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-call.js
var require_no_useless_call = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-call.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isCallOrNonVariadicApply(node) {
      const callee = astUtils.skipChainExpression(node.callee);
      return callee.type === "MemberExpression" && callee.property.type === "Identifier" && callee.computed === false && (callee.property.name === "call" && node.arguments.length >= 1 || callee.property.name === "apply" && node.arguments.length === 2 && node.arguments[1].type === "ArrayExpression");
    }
    function isValidThisArg(expectedThis, thisArg, sourceCode) {
      if (!expectedThis) {
        return astUtils.isNullOrUndefined(thisArg);
      }
      return astUtils.equalTokens(expectedThis, thisArg, sourceCode);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary calls to `.call()` and `.apply()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-call"
        },
        schema: [],
        messages: {
          unnecessaryCall: "Unnecessary '.{{name}}()'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          CallExpression(node) {
            if (!isCallOrNonVariadicApply(node)) {
              return;
            }
            const callee = astUtils.skipChainExpression(node.callee);
            const applied = astUtils.skipChainExpression(callee.object);
            const expectedThis = applied.type === "MemberExpression" ? applied.object : null;
            const thisArg = node.arguments[0];
            if (isValidThisArg(expectedThis, thisArg, sourceCode)) {
              context.report({ node, messageId: "unnecessaryCall", data: { name: callee.property.name } });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-catch.js
var require_no_useless_catch = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-catch.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary `catch` clauses",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-useless-catch"
        },
        schema: [],
        messages: {
          unnecessaryCatchClause: "Unnecessary catch clause.",
          unnecessaryCatch: "Unnecessary try/catch wrapper."
        }
      },
      create(context) {
        return {
          CatchClause(node) {
            if (node.param && node.param.type === "Identifier" && node.body.body.length && node.body.body[0].type === "ThrowStatement" && node.body.body[0].argument.type === "Identifier" && node.body.body[0].argument.name === node.param.name) {
              if (node.parent.finalizer) {
                context.report({
                  node,
                  messageId: "unnecessaryCatchClause"
                });
              } else {
                context.report({
                  node: node.parent,
                  messageId: "unnecessaryCatch"
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-computed-key.js
var require_no_useless_computed_key = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-computed-key.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function hasUselessComputedKey(node) {
      if (!node.computed) {
        return false;
      }
      const { key } = node;
      if (key.type !== "Literal") {
        return false;
      }
      const { value: value2 } = key;
      if (typeof value2 !== "number" && typeof value2 !== "string") {
        return false;
      }
      switch (node.type) {
        case "Property":
          return value2 !== "__proto__";
        case "PropertyDefinition":
          if (node.static) {
            return value2 !== "constructor" && value2 !== "prototype";
          }
          return value2 !== "constructor";
        case "MethodDefinition":
          if (node.static) {
            return value2 !== "prototype";
          }
          return value2 !== "constructor";
        default:
          throw new Error(`Unexpected node type: ${node.type}`);
      }
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary computed property keys in objects and classes",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-computed-key"
        },
        schema: [{
          type: "object",
          properties: {
            enforceForClassMembers: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        fixable: "code",
        messages: {
          unnecessarilyComputedProperty: "Unnecessarily computed property [{{property}}] found."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const enforceForClassMembers = context.options[0] && context.options[0].enforceForClassMembers;
        function check(node) {
          if (hasUselessComputedKey(node)) {
            const { key } = node;
            context.report({
              node,
              messageId: "unnecessarilyComputedProperty",
              data: { property: sourceCode.getText(key) },
              fix(fixer) {
                const leftSquareBracket = sourceCode.getTokenBefore(key, astUtils.isOpeningBracketToken);
                const rightSquareBracket = sourceCode.getTokenAfter(key, astUtils.isClosingBracketToken);
                if (sourceCode.commentsExistBetween(leftSquareBracket, rightSquareBracket)) {
                  return null;
                }
                const tokenBeforeLeftBracket = sourceCode.getTokenBefore(leftSquareBracket);
                const needsSpaceBeforeKey = tokenBeforeLeftBracket.range[1] === leftSquareBracket.range[0] && !astUtils.canTokensBeAdjacent(tokenBeforeLeftBracket, sourceCode.getFirstToken(key));
                const replacementKey = (needsSpaceBeforeKey ? " " : "") + key.raw;
                return fixer.replaceTextRange([leftSquareBracket.range[0], rightSquareBracket.range[1]], replacementKey);
              }
            });
          }
        }
        function noop() {
        }
        return {
          Property: check,
          MethodDefinition: enforceForClassMembers ? check : noop,
          PropertyDefinition: enforceForClassMembers ? check : noop
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-concat.js
var require_no_useless_concat = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-concat.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isConcatenation(node) {
      return node.type === "BinaryExpression" && node.operator === "+";
    }
    function isConcatOperatorToken(token) {
      return token.value === "+" && token.type === "Punctuator";
    }
    function getLeft(node) {
      let left = node.left;
      while (isConcatenation(left)) {
        left = left.right;
      }
      return left;
    }
    function getRight(node) {
      let right = node.right;
      while (isConcatenation(right)) {
        right = right.left;
      }
      return right;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary concatenation of literals or template literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-concat"
        },
        schema: [],
        messages: {
          unexpectedConcat: "Unexpected string concatenation of literals."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          BinaryExpression(node) {
            if (node.operator !== "+") {
              return;
            }
            const left = getLeft(node);
            const right = getRight(node);
            if (astUtils.isStringLiteral(left) && astUtils.isStringLiteral(right) && astUtils.isTokenOnSameLine(left, right)) {
              const operatorToken = sourceCode.getFirstTokenBetween(left, right, isConcatOperatorToken);
              context.report({
                node,
                loc: operatorToken.loc,
                messageId: "unexpectedConcat"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-constructor.js
var require_no_useless_constructor = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-constructor.js"(exports, module2) {
    "use strict";
    function isSingleSuperCall(body) {
      return body.length === 1 && body[0].type === "ExpressionStatement" && body[0].expression.type === "CallExpression" && body[0].expression.callee.type === "Super";
    }
    function isSimple(node) {
      return node.type === "Identifier" || node.type === "RestElement";
    }
    function isSpreadArguments(superArgs) {
      return superArgs.length === 1 && superArgs[0].type === "SpreadElement" && superArgs[0].argument.type === "Identifier" && superArgs[0].argument.name === "arguments";
    }
    function isValidIdentifierPair(ctorParam, superArg) {
      return ctorParam.type === "Identifier" && superArg.type === "Identifier" && ctorParam.name === superArg.name;
    }
    function isValidRestSpreadPair(ctorParam, superArg) {
      return ctorParam.type === "RestElement" && superArg.type === "SpreadElement" && isValidIdentifierPair(ctorParam.argument, superArg.argument);
    }
    function isValidPair(ctorParam, superArg) {
      return isValidIdentifierPair(ctorParam, superArg) || isValidRestSpreadPair(ctorParam, superArg);
    }
    function isPassingThrough(ctorParams, superArgs) {
      if (ctorParams.length !== superArgs.length) {
        return false;
      }
      for (let i = 0; i < ctorParams.length; ++i) {
        if (!isValidPair(ctorParams[i], superArgs[i])) {
          return false;
        }
      }
      return true;
    }
    function isRedundantSuperCall(body, ctorParams) {
      return isSingleSuperCall(body) && ctorParams.every(isSimple) && (isSpreadArguments(body[0].expression.arguments) || isPassingThrough(ctorParams, body[0].expression.arguments));
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary constructors",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-constructor"
        },
        schema: [],
        messages: {
          noUselessConstructor: "Useless constructor."
        }
      },
      create(context) {
        function checkForConstructor(node) {
          if (node.kind !== "constructor") {
            return;
          }
          if (!node.value.body) {
            return;
          }
          const body = node.value.body.body;
          const ctorParams = node.value.params;
          const superClass = node.parent.parent.superClass;
          if (superClass ? isRedundantSuperCall(body, ctorParams) : body.length === 0) {
            context.report({
              node,
              messageId: "noUselessConstructor"
            });
          }
        }
        return {
          MethodDefinition: checkForConstructor
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-escape.js
var require_no_useless_escape = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-escape.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function union(setA, setB) {
      return new Set(function* () {
        yield* setA;
        yield* setB;
      }());
    }
    var VALID_STRING_ESCAPES = union(new Set("\\nrvtbfux"), astUtils.LINEBREAKS);
    var REGEX_GENERAL_ESCAPES = new Set("\\bcdDfnpPrsStvwWxu0123456789]");
    var REGEX_NON_CHARCLASS_ESCAPES = union(REGEX_GENERAL_ESCAPES, new Set("^/.$*+?[{}|()Bk"));
    function parseRegExp(regExpText) {
      const charList = [];
      regExpText.split("").reduce((state, char, index) => {
        if (!state.escapeNextChar) {
          if (char === "\\") {
            return Object.assign(state, { escapeNextChar: true });
          }
          if (char === "[" && !state.inCharClass) {
            return Object.assign(state, { inCharClass: true, startingCharClass: true });
          }
          if (char === "]" && state.inCharClass) {
            if (charList.length && charList[charList.length - 1].inCharClass) {
              charList[charList.length - 1].endsCharClass = true;
            }
            return Object.assign(state, { inCharClass: false, startingCharClass: false });
          }
        }
        charList.push({
          text: char,
          index,
          escaped: state.escapeNextChar,
          inCharClass: state.inCharClass,
          startsCharClass: state.startingCharClass,
          endsCharClass: false
        });
        return Object.assign(state, { escapeNextChar: false, startingCharClass: false });
      }, { escapeNextChar: false, inCharClass: false, startingCharClass: false });
      return charList;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow unnecessary escape characters",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-useless-escape"
        },
        hasSuggestions: true,
        messages: {
          unnecessaryEscape: "Unnecessary escape character: \\{{character}}.",
          removeEscape: "Remove the `\\`. This maintains the current functionality.",
          escapeBackslash: "Replace the `\\` with `\\\\` to include the actual backslash character."
        },
        schema: []
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function report(node, startOffset, character) {
          const rangeStart = node.range[0] + startOffset;
          const range = [rangeStart, rangeStart + 1];
          const start = sourceCode.getLocFromIndex(rangeStart);
          context.report({
            node,
            loc: {
              start,
              end: { line: start.line, column: start.column + 1 }
            },
            messageId: "unnecessaryEscape",
            data: { character },
            suggest: [
              {
                messageId: "removeEscape",
                fix(fixer) {
                  return fixer.removeRange(range);
                }
              },
              {
                messageId: "escapeBackslash",
                fix(fixer) {
                  return fixer.insertTextBeforeRange(range, "\\");
                }
              }
            ]
          });
        }
        function validateString(node, match) {
          const isTemplateElement2 = node.type === "TemplateElement";
          const escapedChar = match[0][1];
          let isUnnecessaryEscape = !VALID_STRING_ESCAPES.has(escapedChar);
          let isQuoteEscape;
          if (isTemplateElement2) {
            isQuoteEscape = escapedChar === "`";
            if (escapedChar === "$") {
              isUnnecessaryEscape = match.input[match.index + 2] !== "{";
            } else if (escapedChar === "{") {
              isUnnecessaryEscape = match.input[match.index - 1] !== "$";
            }
          } else {
            isQuoteEscape = escapedChar === node.raw[0];
          }
          if (isUnnecessaryEscape && !isQuoteEscape) {
            report(node, match.index, match[0].slice(1));
          }
        }
        function check(node) {
          const isTemplateElement2 = node.type === "TemplateElement";
          if (isTemplateElement2 && node.parent && node.parent.parent && node.parent.parent.type === "TaggedTemplateExpression" && node.parent === node.parent.parent.quasi) {
            return;
          }
          if (typeof node.value === "string" || isTemplateElement2) {
            if (node.parent.type === "JSXAttribute" || node.parent.type === "JSXElement" || node.parent.type === "JSXFragment") {
              return;
            }
            const value2 = isTemplateElement2 ? sourceCode.getText(node) : node.raw;
            const pattern = /\\[^\d]/gu;
            let match;
            while (match = pattern.exec(value2)) {
              validateString(node, match);
            }
          } else if (node.regex) {
            parseRegExp(node.regex.pattern).filter((charInfo) => !(charInfo.text === "-" && charInfo.inCharClass && !charInfo.startsCharClass && !charInfo.endsCharClass)).filter((charInfo) => !(charInfo.text === "^" && charInfo.startsCharClass)).filter((charInfo) => charInfo.escaped).filter((charInfo) => !(charInfo.inCharClass ? REGEX_GENERAL_ESCAPES : REGEX_NON_CHARCLASS_ESCAPES).has(charInfo.text)).forEach((charInfo) => report(node, charInfo.index, charInfo.text));
          }
        }
        return {
          Literal: check,
          TemplateElement: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-rename.js
var require_no_useless_rename = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-rename.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow renaming import, export, and destructured assignments to the same name",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-rename"
        },
        fixable: "code",
        schema: [
          {
            type: "object",
            properties: {
              ignoreDestructuring: { type: "boolean", default: false },
              ignoreImport: { type: "boolean", default: false },
              ignoreExport: { type: "boolean", default: false }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unnecessarilyRenamed: "{{type}} {{name}} unnecessarily renamed."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode(), options = context.options[0] || {}, ignoreDestructuring = options.ignoreDestructuring === true, ignoreImport = options.ignoreImport === true, ignoreExport = options.ignoreExport === true;
        function reportError(node, initial, type) {
          const name = initial.type === "Identifier" ? initial.name : initial.value;
          return context.report({
            node,
            messageId: "unnecessarilyRenamed",
            data: {
              name,
              type
            },
            fix(fixer) {
              const replacementNode = node.type === "Property" ? node.value : node.local;
              if (sourceCode.getCommentsInside(node).length > sourceCode.getCommentsInside(replacementNode).length) {
                return null;
              }
              if (replacementNode.type === "AssignmentPattern" && astUtils.isParenthesised(sourceCode, replacementNode.left)) {
                return null;
              }
              return fixer.replaceText(node, sourceCode.getText(replacementNode));
            }
          });
        }
        function checkDestructured(node) {
          if (ignoreDestructuring) {
            return;
          }
          for (const property of node.properties) {
            if (property.type !== "Property" || property.shorthand || property.computed) {
              continue;
            }
            const key = property.key.type === "Identifier" && property.key.name || property.key.type === "Literal" && property.key.value;
            const renamedKey = property.value.type === "AssignmentPattern" ? property.value.left.name : property.value.name;
            if (key === renamedKey) {
              reportError(property, property.key, "Destructuring assignment");
            }
          }
        }
        function checkImport(node) {
          if (ignoreImport) {
            return;
          }
          if (node.imported.range[0] !== node.local.range[0] && astUtils.getModuleExportName(node.imported) === node.local.name) {
            reportError(node, node.imported, "Import");
          }
        }
        function checkExport(node) {
          if (ignoreExport) {
            return;
          }
          if (node.local.range[0] !== node.exported.range[0] && astUtils.getModuleExportName(node.local) === astUtils.getModuleExportName(node.exported)) {
            reportError(node, node.local, "Export");
          }
        }
        return {
          ObjectPattern: checkDestructured,
          ImportSpecifier: checkImport,
          ExportSpecifier: checkExport
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-useless-return.js
var require_no_useless_return = __commonJS({
  "node_modules/eslint/lib/rules/no-useless-return.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var FixTracker = require_fix_tracker();
    function remove(array, element) {
      const index = array.indexOf(element);
      if (index !== -1) {
        array.splice(index, 1);
      }
    }
    function isRemovable(node) {
      return astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type);
    }
    function isInFinally(node) {
      for (let currentNode = node; currentNode && currentNode.parent && !astUtils.isFunction(currentNode); currentNode = currentNode.parent) {
        if (currentNode.parent.type === "TryStatement" && currentNode.parent.finalizer === currentNode) {
          return true;
        }
      }
      return false;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow redundant return statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-useless-return"
        },
        fixable: "code",
        schema: [],
        messages: {
          unnecessaryReturn: "Unnecessary return statement."
        }
      },
      create(context) {
        const segmentInfoMap = /* @__PURE__ */ new WeakMap();
        const usedUnreachableSegments = /* @__PURE__ */ new WeakSet();
        const sourceCode = context.getSourceCode();
        let scopeInfo = null;
        function isReturned(segment) {
          const info = segmentInfoMap.get(segment);
          return !info || info.returned;
        }
        function getUselessReturns(uselessReturns, prevSegments, providedTraversedSegments) {
          const traversedSegments = providedTraversedSegments || /* @__PURE__ */ new WeakSet();
          for (const segment of prevSegments) {
            if (!segment.reachable) {
              if (!traversedSegments.has(segment)) {
                traversedSegments.add(segment);
                getUselessReturns(
                  uselessReturns,
                  segment.allPrevSegments.filter(isReturned),
                  traversedSegments
                );
              }
              continue;
            }
            uselessReturns.push(...segmentInfoMap.get(segment).uselessReturns);
          }
          return uselessReturns;
        }
        function markReturnStatementsOnSegmentAsUsed(segment) {
          if (!segment.reachable) {
            usedUnreachableSegments.add(segment);
            segment.allPrevSegments.filter(isReturned).filter((prevSegment) => !usedUnreachableSegments.has(prevSegment)).forEach(markReturnStatementsOnSegmentAsUsed);
            return;
          }
          const info = segmentInfoMap.get(segment);
          for (const node of info.uselessReturns) {
            remove(scopeInfo.uselessReturns, node);
          }
          info.uselessReturns = [];
        }
        function markReturnStatementsOnCurrentSegmentsAsUsed() {
          scopeInfo.codePath.currentSegments.forEach(markReturnStatementsOnSegmentAsUsed);
        }
        return {
          // Makes and pushs a new scope information.
          onCodePathStart(codePath) {
            scopeInfo = {
              upper: scopeInfo,
              uselessReturns: [],
              codePath
            };
          },
          // Reports useless return statements if exist.
          onCodePathEnd() {
            for (const node of scopeInfo.uselessReturns) {
              context.report({
                node,
                loc: node.loc,
                messageId: "unnecessaryReturn",
                fix(fixer) {
                  if (isRemovable(node) && !sourceCode.getCommentsInside(node).length) {
                    return new FixTracker(fixer, sourceCode).retainEnclosingFunction(node).remove(node);
                  }
                  return null;
                }
              });
            }
            scopeInfo = scopeInfo.upper;
          },
          /*
           * Initializes segments.
           * NOTE: This event is notified for only reachable segments.
           */
          onCodePathSegmentStart(segment) {
            const info = {
              uselessReturns: getUselessReturns([], segment.allPrevSegments),
              returned: false
            };
            segmentInfoMap.set(segment, info);
          },
          // Adds ReturnStatement node to check whether it's useless or not.
          ReturnStatement(node) {
            if (node.argument) {
              markReturnStatementsOnCurrentSegmentsAsUsed();
            }
            if (node.argument || astUtils.isInLoop(node) || isInFinally(node) || // Ignore `return` statements in unreachable places (https://github.com/eslint/eslint/issues/11647).
            !scopeInfo.codePath.currentSegments.some((s) => s.reachable)) {
              return;
            }
            for (const segment of scopeInfo.codePath.currentSegments) {
              const info = segmentInfoMap.get(segment);
              if (info) {
                info.uselessReturns.push(node);
                info.returned = true;
              }
            }
            scopeInfo.uselessReturns.push(node);
          },
          /*
           * Registers for all statement nodes except FunctionDeclaration, BlockStatement, BreakStatement.
           * Removes return statements of the current segments from the useless return statement list.
           */
          ClassDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
          ContinueStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          DebuggerStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          DoWhileStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          EmptyStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ExpressionStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ForInStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ForOfStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ForStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          IfStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ImportDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
          LabeledStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          SwitchStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ThrowStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          TryStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          VariableDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
          WhileStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          WithStatement: markReturnStatementsOnCurrentSegmentsAsUsed,
          ExportNamedDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
          ExportDefaultDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed,
          ExportAllDeclaration: markReturnStatementsOnCurrentSegmentsAsUsed
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-var.js
var require_no_var = __commonJS({
  "node_modules/eslint/lib/rules/no-var.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isGlobal(variable) {
      return Boolean(variable.scope) && variable.scope.type === "global";
    }
    function getEnclosingFunctionScope(scope) {
      let currentScope = scope;
      while (currentScope.type !== "function" && currentScope.type !== "global") {
        currentScope = currentScope.upper;
      }
      return currentScope;
    }
    function isReferencedInClosure(variable) {
      const enclosingFunctionScope = getEnclosingFunctionScope(variable.scope);
      return variable.references.some((reference) => getEnclosingFunctionScope(reference.from) !== enclosingFunctionScope);
    }
    function isLoopAssignee(node) {
      return (node.parent.type === "ForOfStatement" || node.parent.type === "ForInStatement") && node === node.parent.left;
    }
    function isDeclarationInitialized(node) {
      return node.declarations.every((declarator) => declarator.init !== null);
    }
    var SCOPE_NODE_TYPE = /^(?:Program|BlockStatement|SwitchStatement|ForStatement|ForInStatement|ForOfStatement)$/u;
    function getScopeNode(node) {
      for (let currentNode = node; currentNode; currentNode = currentNode.parent) {
        if (SCOPE_NODE_TYPE.test(currentNode.type)) {
          return currentNode;
        }
      }
      return null;
    }
    function isRedeclared(variable) {
      return variable.defs.length >= 2;
    }
    function isUsedFromOutsideOf(scopeNode) {
      function isOutsideOfScope(reference) {
        const scope = scopeNode.range;
        const id = reference.identifier.range;
        return id[0] < scope[0] || id[1] > scope[1];
      }
      return function(variable) {
        return variable.references.some(isOutsideOfScope);
      };
    }
    function hasReferenceInTDZ(node) {
      const initStart = node.range[0];
      const initEnd = node.range[1];
      return (variable) => {
        const id = variable.defs[0].name;
        const idStart = id.range[0];
        const defaultValue = id.parent.type === "AssignmentPattern" ? id.parent.right : null;
        const defaultStart = defaultValue && defaultValue.range[0];
        const defaultEnd = defaultValue && defaultValue.range[1];
        return variable.references.some((reference) => {
          const start = reference.identifier.range[0];
          const end = reference.identifier.range[1];
          return !reference.init && (start < idStart || defaultValue !== null && start >= defaultStart && end <= defaultEnd || !astUtils.isFunction(node) && start >= initStart && end <= initEnd);
        });
      };
    }
    function hasNameDisallowedForLetDeclarations(variable) {
      return variable.name === "let";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `let` or `const` instead of `var`",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-var"
        },
        schema: [],
        fixable: "code",
        messages: {
          unexpectedVar: "Unexpected var, use let or const instead."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function hasSelfReferenceInTDZ(declarator) {
          if (!declarator.init) {
            return false;
          }
          const variables = context.getDeclaredVariables(declarator);
          return variables.some(hasReferenceInTDZ(declarator.init));
        }
        function canFix(node) {
          const variables = context.getDeclaredVariables(node);
          const scopeNode = getScopeNode(node);
          if (node.parent.type === "SwitchCase" || node.declarations.some(hasSelfReferenceInTDZ) || variables.some(isGlobal) || variables.some(isRedeclared) || variables.some(isUsedFromOutsideOf(scopeNode)) || variables.some(hasNameDisallowedForLetDeclarations)) {
            return false;
          }
          if (astUtils.isInLoop(node)) {
            if (variables.some(isReferencedInClosure)) {
              return false;
            }
            if (!isLoopAssignee(node) && !isDeclarationInitialized(node)) {
              return false;
            }
          }
          if (!isLoopAssignee(node) && !(node.parent.type === "ForStatement" && node.parent.init === node) && !astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type)) {
            return false;
          }
          return true;
        }
        function report(node) {
          context.report({
            node,
            messageId: "unexpectedVar",
            fix(fixer) {
              const varToken = sourceCode.getFirstToken(node, { filter: (t3) => t3.value === "var" });
              return canFix(node) ? fixer.replaceText(varToken, "let") : null;
            }
          });
        }
        return {
          "VariableDeclaration:exit"(node) {
            if (node.kind === "var") {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-void.js
var require_no_void = __commonJS({
  "node_modules/eslint/lib/rules/no-void.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `void` operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-void"
        },
        messages: {
          noVoid: "Expected 'undefined' and instead saw 'void'."
        },
        schema: [
          {
            type: "object",
            properties: {
              allowAsStatement: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ]
      },
      create(context) {
        const allowAsStatement = context.options[0] && context.options[0].allowAsStatement;
        return {
          'UnaryExpression[operator="void"]'(node) {
            if (allowAsStatement && node.parent && node.parent.type === "ExpressionStatement") {
              return;
            }
            context.report({
              node,
              messageId: "noVoid"
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-warning-comments.js
var require_no_warning_comments = __commonJS({
  "node_modules/eslint/lib/rules/no-warning-comments.js"(exports, module2) {
    "use strict";
    var escapeRegExp = require_escape_string_regexp2();
    var astUtils = require_ast_utils2();
    var CHAR_LIMIT = 40;
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow specified warning terms in comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-warning-comments"
        },
        schema: [
          {
            type: "object",
            properties: {
              terms: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              location: {
                enum: ["start", "anywhere"]
              },
              decoration: {
                type: "array",
                items: {
                  type: "string",
                  pattern: "^\\S$"
                },
                minItems: 1,
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedComment: "Unexpected '{{matchedTerm}}' comment: '{{comment}}'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode(), configuration = context.options[0] || {}, warningTerms = configuration.terms || ["todo", "fixme", "xxx"], location = configuration.location || "start", decoration = [...configuration.decoration || []].join(""), selfConfigRegEx = /\bno-warning-comments\b/u;
        function convertToRegExp(term) {
          const escaped = escapeRegExp(term);
          const escapedDecoration = escapeRegExp(decoration);
          const wordBoundary = "\\b";
          let prefix = "";
          if (location === "start") {
            prefix = `^[\\s${escapedDecoration}]*`;
          } else if (/^\w/u.test(term)) {
            prefix = wordBoundary;
          }
          const suffix = /\w$/u.test(term) ? wordBoundary : "";
          const flags = "iu";
          return new RegExp(`${prefix}${escaped}${suffix}`, flags);
        }
        const warningRegExps = warningTerms.map(convertToRegExp);
        function commentContainsWarningTerm(comment) {
          const matches = [];
          warningRegExps.forEach((regex, index) => {
            if (regex.test(comment)) {
              matches.push(warningTerms[index]);
            }
          });
          return matches;
        }
        function checkComment(node) {
          const comment = node.value;
          if (astUtils.isDirectiveComment(node) && selfConfigRegEx.test(comment)) {
            return;
          }
          const matches = commentContainsWarningTerm(comment);
          matches.forEach((matchedTerm) => {
            let commentToDisplay = "";
            let truncated = false;
            for (const c of comment.trim().split(/\s+/u)) {
              const tmp = commentToDisplay ? `${commentToDisplay} ${c}` : c;
              if (tmp.length <= CHAR_LIMIT) {
                commentToDisplay = tmp;
              } else {
                truncated = true;
                break;
              }
            }
            context.report({
              node,
              messageId: "unexpectedComment",
              data: {
                matchedTerm,
                comment: `${commentToDisplay}${truncated ? "..." : ""}`
              }
            });
          });
        }
        return {
          Program() {
            const comments = sourceCode.getAllComments();
            comments.filter((token) => token.type !== "Shebang").forEach(checkComment);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-whitespace-before-property.js
var require_no_whitespace_before_property = __commonJS({
  "node_modules/eslint/lib/rules/no-whitespace-before-property.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Disallow whitespace before properties",
          recommended: false,
          url: "https://eslint.org/docs/rules/no-whitespace-before-property"
        },
        fixable: "whitespace",
        schema: [],
        messages: {
          unexpectedWhitespace: "Unexpected whitespace before property {{propName}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function reportError(node, leftToken, rightToken) {
          context.report({
            node,
            messageId: "unexpectedWhitespace",
            data: {
              propName: sourceCode.getText(node.property)
            },
            fix(fixer) {
              let replacementText = "";
              if (!node.computed && !node.optional && astUtils.isDecimalInteger(node.object)) {
                return null;
              }
              if (sourceCode.commentsExistBetween(leftToken, rightToken)) {
                return null;
              }
              if (node.optional) {
                replacementText = "?.";
              } else if (!node.computed) {
                replacementText = ".";
              }
              return fixer.replaceTextRange([leftToken.range[1], rightToken.range[0]], replacementText);
            }
          });
        }
        return {
          MemberExpression(node) {
            let rightToken;
            let leftToken;
            if (!astUtils.isTokenOnSameLine(node.object, node.property)) {
              return;
            }
            if (node.computed) {
              rightToken = sourceCode.getTokenBefore(node.property, astUtils.isOpeningBracketToken);
              leftToken = sourceCode.getTokenBefore(rightToken, node.optional ? 1 : 0);
            } else {
              rightToken = sourceCode.getFirstToken(node.property);
              leftToken = sourceCode.getTokenBefore(rightToken, 1);
            }
            if (sourceCode.isSpaceBetweenTokens(leftToken, rightToken)) {
              reportError(node, leftToken, rightToken);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/no-with.js
var require_no_with = __commonJS({
  "node_modules/eslint/lib/rules/no-with.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `with` statements",
          recommended: true,
          url: "https://eslint.org/docs/rules/no-with"
        },
        schema: [],
        messages: {
          unexpectedWith: "Unexpected use of 'with' statement."
        }
      },
      create(context) {
        return {
          WithStatement(node) {
            context.report({ node, messageId: "unexpectedWith" });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/nonblock-statement-body-position.js
var require_nonblock_statement_body_position = __commonJS({
  "node_modules/eslint/lib/rules/nonblock-statement-body-position.js"(exports, module2) {
    "use strict";
    var POSITION_SCHEMA = { enum: ["beside", "below", "any"] };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce the location of single-line statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/nonblock-statement-body-position"
        },
        fixable: "whitespace",
        schema: [
          POSITION_SCHEMA,
          {
            properties: {
              overrides: {
                properties: {
                  if: POSITION_SCHEMA,
                  else: POSITION_SCHEMA,
                  while: POSITION_SCHEMA,
                  do: POSITION_SCHEMA,
                  for: POSITION_SCHEMA
                },
                additionalProperties: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          expectNoLinebreak: "Expected no linebreak before this statement.",
          expectLinebreak: "Expected a linebreak before this statement."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function getOption(keywordName) {
          return context.options[1] && context.options[1].overrides && context.options[1].overrides[keywordName] || context.options[0] || "beside";
        }
        function validateStatement(node, keywordName) {
          const option = getOption(keywordName);
          if (node.type === "BlockStatement" || option === "any") {
            return;
          }
          const tokenBefore = sourceCode.getTokenBefore(node);
          if (tokenBefore.loc.end.line === node.loc.start.line && option === "below") {
            context.report({
              node,
              messageId: "expectLinebreak",
              fix: (fixer) => fixer.insertTextBefore(node, "\n")
            });
          } else if (tokenBefore.loc.end.line !== node.loc.start.line && option === "beside") {
            context.report({
              node,
              messageId: "expectNoLinebreak",
              fix(fixer) {
                if (sourceCode.getText().slice(tokenBefore.range[1], node.range[0]).trim()) {
                  return null;
                }
                return fixer.replaceTextRange([tokenBefore.range[1], node.range[0]], " ");
              }
            });
          }
        }
        return {
          IfStatement(node) {
            validateStatement(node.consequent, "if");
            if (node.alternate && node.alternate.type !== "IfStatement") {
              validateStatement(node.alternate, "else");
            }
          },
          WhileStatement: (node) => validateStatement(node.body, "while"),
          DoWhileStatement: (node) => validateStatement(node.body, "do"),
          ForStatement: (node) => validateStatement(node.body, "for"),
          ForInStatement: (node) => validateStatement(node.body, "for"),
          ForOfStatement: (node) => validateStatement(node.body, "for")
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/object-curly-newline.js
var require_object_curly_newline = __commonJS({
  "node_modules/eslint/lib/rules/object-curly-newline.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var OPTION_VALUE = {
      oneOf: [
        {
          enum: ["always", "never"]
        },
        {
          type: "object",
          properties: {
            multiline: {
              type: "boolean"
            },
            minProperties: {
              type: "integer",
              minimum: 0
            },
            consistent: {
              type: "boolean"
            }
          },
          additionalProperties: false,
          minProperties: 1
        }
      ]
    };
    function normalizeOptionValue(value2) {
      let multiline = false;
      let minProperties = Number.POSITIVE_INFINITY;
      let consistent = false;
      if (value2) {
        if (value2 === "always") {
          minProperties = 0;
        } else if (value2 === "never") {
          minProperties = Number.POSITIVE_INFINITY;
        } else {
          multiline = Boolean(value2.multiline);
          minProperties = value2.minProperties || Number.POSITIVE_INFINITY;
          consistent = Boolean(value2.consistent);
        }
      } else {
        consistent = true;
      }
      return { multiline, minProperties, consistent };
    }
    function isObject(value2) {
      return typeof value2 === "object" && value2 !== null;
    }
    function isNodeSpecificOption(option) {
      return isObject(option) || typeof option === "string";
    }
    function normalizeOptions(options) {
      if (isObject(options) && Object.values(options).some(isNodeSpecificOption)) {
        return {
          ObjectExpression: normalizeOptionValue(options.ObjectExpression),
          ObjectPattern: normalizeOptionValue(options.ObjectPattern),
          ImportDeclaration: normalizeOptionValue(options.ImportDeclaration),
          ExportNamedDeclaration: normalizeOptionValue(options.ExportDeclaration)
        };
      }
      const value2 = normalizeOptionValue(options);
      return { ObjectExpression: value2, ObjectPattern: value2, ImportDeclaration: value2, ExportNamedDeclaration: value2 };
    }
    function areLineBreaksRequired(node, options, first2, last2) {
      let objectProperties;
      if (node.type === "ObjectExpression" || node.type === "ObjectPattern") {
        objectProperties = node.properties;
      } else {
        objectProperties = node.specifiers.filter((s) => s.type === "ImportSpecifier" || s.type === "ExportSpecifier");
      }
      return objectProperties.length >= options.minProperties || options.multiline && objectProperties.length > 0 && first2.loc.start.line !== last2.loc.end.line;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent line breaks after opening and before closing braces",
          recommended: false,
          url: "https://eslint.org/docs/rules/object-curly-newline"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              OPTION_VALUE,
              {
                type: "object",
                properties: {
                  ObjectExpression: OPTION_VALUE,
                  ObjectPattern: OPTION_VALUE,
                  ImportDeclaration: OPTION_VALUE,
                  ExportDeclaration: OPTION_VALUE
                },
                additionalProperties: false,
                minProperties: 1
              }
            ]
          }
        ],
        messages: {
          unexpectedLinebreakBeforeClosingBrace: "Unexpected line break before this closing brace.",
          unexpectedLinebreakAfterOpeningBrace: "Unexpected line break after this opening brace.",
          expectedLinebreakBeforeClosingBrace: "Expected a line break before this closing brace.",
          expectedLinebreakAfterOpeningBrace: "Expected a line break after this opening brace."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const normalizedOptions = normalizeOptions(context.options[0]);
        function check(node) {
          const options = normalizedOptions[node.type];
          if (node.type === "ImportDeclaration" && !node.specifiers.some((specifier) => specifier.type === "ImportSpecifier") || node.type === "ExportNamedDeclaration" && !node.specifiers.some((specifier) => specifier.type === "ExportSpecifier")) {
            return;
          }
          const openBrace = sourceCode.getFirstToken(node, (token) => token.value === "{");
          let closeBrace;
          if (node.typeAnnotation) {
            closeBrace = sourceCode.getTokenBefore(node.typeAnnotation);
          } else {
            closeBrace = sourceCode.getLastToken(node, (token) => token.value === "}");
          }
          let first2 = sourceCode.getTokenAfter(openBrace, { includeComments: true });
          let last2 = sourceCode.getTokenBefore(closeBrace, { includeComments: true });
          const needsLineBreaks = areLineBreaksRequired(node, options, first2, last2);
          const hasCommentsFirstToken = astUtils.isCommentToken(first2);
          const hasCommentsLastToken = astUtils.isCommentToken(last2);
          first2 = sourceCode.getTokenAfter(openBrace);
          last2 = sourceCode.getTokenBefore(closeBrace);
          if (needsLineBreaks) {
            if (astUtils.isTokenOnSameLine(openBrace, first2)) {
              context.report({
                messageId: "expectedLinebreakAfterOpeningBrace",
                node,
                loc: openBrace.loc,
                fix(fixer) {
                  if (hasCommentsFirstToken) {
                    return null;
                  }
                  return fixer.insertTextAfter(openBrace, "\n");
                }
              });
            }
            if (astUtils.isTokenOnSameLine(last2, closeBrace)) {
              context.report({
                messageId: "expectedLinebreakBeforeClosingBrace",
                node,
                loc: closeBrace.loc,
                fix(fixer) {
                  if (hasCommentsLastToken) {
                    return null;
                  }
                  return fixer.insertTextBefore(closeBrace, "\n");
                }
              });
            }
          } else {
            const consistent = options.consistent;
            const hasLineBreakBetweenOpenBraceAndFirst = !astUtils.isTokenOnSameLine(openBrace, first2);
            const hasLineBreakBetweenCloseBraceAndLast = !astUtils.isTokenOnSameLine(last2, closeBrace);
            if (!consistent && hasLineBreakBetweenOpenBraceAndFirst || consistent && hasLineBreakBetweenOpenBraceAndFirst && !hasLineBreakBetweenCloseBraceAndLast) {
              context.report({
                messageId: "unexpectedLinebreakAfterOpeningBrace",
                node,
                loc: openBrace.loc,
                fix(fixer) {
                  if (hasCommentsFirstToken) {
                    return null;
                  }
                  return fixer.removeRange([
                    openBrace.range[1],
                    first2.range[0]
                  ]);
                }
              });
            }
            if (!consistent && hasLineBreakBetweenCloseBraceAndLast || consistent && !hasLineBreakBetweenOpenBraceAndFirst && hasLineBreakBetweenCloseBraceAndLast) {
              context.report({
                messageId: "unexpectedLinebreakBeforeClosingBrace",
                node,
                loc: closeBrace.loc,
                fix(fixer) {
                  if (hasCommentsLastToken) {
                    return null;
                  }
                  return fixer.removeRange([
                    last2.range[1],
                    closeBrace.range[0]
                  ]);
                }
              });
            }
          }
        }
        return {
          ObjectExpression: check,
          ObjectPattern: check,
          ImportDeclaration: check,
          ExportNamedDeclaration: check
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/object-curly-spacing.js
var require_object_curly_spacing = __commonJS({
  "node_modules/eslint/lib/rules/object-curly-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing inside braces",
          recommended: false,
          url: "https://eslint.org/docs/rules/object-curly-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              arraysInObjects: {
                type: "boolean"
              },
              objectsInObjects: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          requireSpaceBefore: "A space is required before '{{token}}'.",
          requireSpaceAfter: "A space is required after '{{token}}'.",
          unexpectedSpaceBefore: "There should be no space before '{{token}}'.",
          unexpectedSpaceAfter: "There should be no space after '{{token}}'."
        }
      },
      create(context) {
        const spaced = context.options[0] === "always", sourceCode = context.getSourceCode();
        function isOptionSet(option) {
          return context.options[1] ? context.options[1][option] === !spaced : false;
        }
        const options = {
          spaced,
          arraysInObjectsException: isOptionSet("arraysInObjects"),
          objectsInObjectsException: isOptionSet("objectsInObjects")
        };
        function reportNoBeginningSpace(node, token) {
          const nextToken = context.getSourceCode().getTokenAfter(token, { includeComments: true });
          context.report({
            node,
            loc: { start: token.loc.end, end: nextToken.loc.start },
            messageId: "unexpectedSpaceAfter",
            data: {
              token: token.value
            },
            fix(fixer) {
              return fixer.removeRange([token.range[1], nextToken.range[0]]);
            }
          });
        }
        function reportNoEndingSpace(node, token) {
          const previousToken = context.getSourceCode().getTokenBefore(token, { includeComments: true });
          context.report({
            node,
            loc: { start: previousToken.loc.end, end: token.loc.start },
            messageId: "unexpectedSpaceBefore",
            data: {
              token: token.value
            },
            fix(fixer) {
              return fixer.removeRange([previousToken.range[1], token.range[0]]);
            }
          });
        }
        function reportRequiredBeginningSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "requireSpaceAfter",
            data: {
              token: token.value
            },
            fix(fixer) {
              return fixer.insertTextAfter(token, " ");
            }
          });
        }
        function reportRequiredEndingSpace(node, token) {
          context.report({
            node,
            loc: token.loc,
            messageId: "requireSpaceBefore",
            data: {
              token: token.value
            },
            fix(fixer) {
              return fixer.insertTextBefore(token, " ");
            }
          });
        }
        function validateBraceSpacing(node, first2, second, penultimate, last2) {
          if (astUtils.isTokenOnSameLine(first2, second)) {
            const firstSpaced = sourceCode.isSpaceBetweenTokens(first2, second);
            if (options.spaced && !firstSpaced) {
              reportRequiredBeginningSpace(node, first2);
            }
            if (!options.spaced && firstSpaced && second.type !== "Line") {
              reportNoBeginningSpace(node, first2);
            }
          }
          if (astUtils.isTokenOnSameLine(penultimate, last2)) {
            const shouldCheckPenultimate = options.arraysInObjectsException && astUtils.isClosingBracketToken(penultimate) || options.objectsInObjectsException && astUtils.isClosingBraceToken(penultimate);
            const penultimateType = shouldCheckPenultimate && sourceCode.getNodeByRangeIndex(penultimate.range[0]).type;
            const closingCurlyBraceMustBeSpaced = options.arraysInObjectsException && penultimateType === "ArrayExpression" || options.objectsInObjectsException && (penultimateType === "ObjectExpression" || penultimateType === "ObjectPattern") ? !options.spaced : options.spaced;
            const lastSpaced = sourceCode.isSpaceBetweenTokens(penultimate, last2);
            if (closingCurlyBraceMustBeSpaced && !lastSpaced) {
              reportRequiredEndingSpace(node, last2);
            }
            if (!closingCurlyBraceMustBeSpaced && lastSpaced) {
              reportNoEndingSpace(node, last2);
            }
          }
        }
        function getClosingBraceOfObject(node) {
          const lastProperty = node.properties[node.properties.length - 1];
          return sourceCode.getTokenAfter(lastProperty, astUtils.isClosingBraceToken);
        }
        function checkForObject(node) {
          if (node.properties.length === 0) {
            return;
          }
          const first2 = sourceCode.getFirstToken(node), last2 = getClosingBraceOfObject(node), second = sourceCode.getTokenAfter(first2, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last2, { includeComments: true });
          validateBraceSpacing(node, first2, second, penultimate, last2);
        }
        function checkForImport(node) {
          if (node.specifiers.length === 0) {
            return;
          }
          let firstSpecifier = node.specifiers[0];
          const lastSpecifier = node.specifiers[node.specifiers.length - 1];
          if (lastSpecifier.type !== "ImportSpecifier") {
            return;
          }
          if (firstSpecifier.type !== "ImportSpecifier") {
            firstSpecifier = node.specifiers[1];
          }
          const first2 = sourceCode.getTokenBefore(firstSpecifier), last2 = sourceCode.getTokenAfter(lastSpecifier, astUtils.isNotCommaToken), second = sourceCode.getTokenAfter(first2, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last2, { includeComments: true });
          validateBraceSpacing(node, first2, second, penultimate, last2);
        }
        function checkForExport(node) {
          if (node.specifiers.length === 0) {
            return;
          }
          const firstSpecifier = node.specifiers[0], lastSpecifier = node.specifiers[node.specifiers.length - 1], first2 = sourceCode.getTokenBefore(firstSpecifier), last2 = sourceCode.getTokenAfter(lastSpecifier, astUtils.isNotCommaToken), second = sourceCode.getTokenAfter(first2, { includeComments: true }), penultimate = sourceCode.getTokenBefore(last2, { includeComments: true });
          validateBraceSpacing(node, first2, second, penultimate, last2);
        }
        return {
          // var {x} = y;
          ObjectPattern: checkForObject,
          // var y = {x: 'y'}
          ObjectExpression: checkForObject,
          // import {y} from 'x';
          ImportDeclaration: checkForImport,
          // export {name} from 'yo';
          ExportNamedDeclaration: checkForExport
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/object-property-newline.js
var require_object_property_newline = __commonJS({
  "node_modules/eslint/lib/rules/object-property-newline.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce placing object properties on separate lines",
          recommended: false,
          url: "https://eslint.org/docs/rules/object-property-newline"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowAllPropertiesOnSameLine: {
                type: "boolean",
                default: false
              },
              allowMultiplePropertiesPerLine: {
                // Deprecated
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "whitespace",
        messages: {
          propertiesOnNewlineAll: "Object properties must go on a new line if they aren't all on the same line.",
          propertiesOnNewline: "Object properties must go on a new line."
        }
      },
      create(context) {
        const allowSameLine = context.options[0] && (context.options[0].allowAllPropertiesOnSameLine || context.options[0].allowMultiplePropertiesPerLine);
        const messageId = allowSameLine ? "propertiesOnNewlineAll" : "propertiesOnNewline";
        const sourceCode = context.getSourceCode();
        return {
          ObjectExpression(node) {
            if (allowSameLine) {
              if (node.properties.length > 1) {
                const firstTokenOfFirstProperty = sourceCode.getFirstToken(node.properties[0]);
                const lastTokenOfLastProperty = sourceCode.getLastToken(node.properties[node.properties.length - 1]);
                if (firstTokenOfFirstProperty.loc.end.line === lastTokenOfLastProperty.loc.start.line) {
                  return;
                }
              }
            }
            for (let i = 1; i < node.properties.length; i++) {
              const lastTokenOfPreviousProperty = sourceCode.getLastToken(node.properties[i - 1]);
              const firstTokenOfCurrentProperty = sourceCode.getFirstToken(node.properties[i]);
              if (lastTokenOfPreviousProperty.loc.end.line === firstTokenOfCurrentProperty.loc.start.line) {
                context.report({
                  node,
                  loc: firstTokenOfCurrentProperty.loc,
                  messageId,
                  fix(fixer) {
                    const comma = sourceCode.getTokenBefore(firstTokenOfCurrentProperty);
                    const rangeAfterComma = [comma.range[1], firstTokenOfCurrentProperty.range[0]];
                    if (sourceCode.text.slice(rangeAfterComma[0], rangeAfterComma[1]).trim()) {
                      return null;
                    }
                    return fixer.replaceTextRange(rangeAfterComma, "\n");
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/object-shorthand.js
var require_object_shorthand = __commonJS({
  "node_modules/eslint/lib/rules/object-shorthand.js"(exports, module2) {
    "use strict";
    var OPTIONS = {
      always: "always",
      never: "never",
      methods: "methods",
      properties: "properties",
      consistent: "consistent",
      consistentAsNeeded: "consistent-as-needed"
    };
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow method and property shorthand syntax for object literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/object-shorthand"
        },
        fixable: "code",
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always", "methods", "properties", "never", "consistent", "consistent-as-needed"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["always", "methods", "properties"]
                },
                {
                  type: "object",
                  properties: {
                    avoidQuotes: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            },
            {
              type: "array",
              items: [
                {
                  enum: ["always", "methods"]
                },
                {
                  type: "object",
                  properties: {
                    ignoreConstructors: {
                      type: "boolean"
                    },
                    methodsIgnorePattern: {
                      type: "string"
                    },
                    avoidQuotes: {
                      type: "boolean"
                    },
                    avoidExplicitReturnArrows: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        messages: {
          expectedAllPropertiesShorthanded: "Expected shorthand for all properties.",
          expectedLiteralMethodLongform: "Expected longform method syntax for string literal keys.",
          expectedPropertyShorthand: "Expected property shorthand.",
          expectedPropertyLongform: "Expected longform property syntax.",
          expectedMethodShorthand: "Expected method shorthand.",
          expectedMethodLongform: "Expected longform method syntax.",
          unexpectedMix: "Unexpected mix of shorthand and non-shorthand properties."
        }
      },
      create(context) {
        const APPLY = context.options[0] || OPTIONS.always;
        const APPLY_TO_METHODS = APPLY === OPTIONS.methods || APPLY === OPTIONS.always;
        const APPLY_TO_PROPS = APPLY === OPTIONS.properties || APPLY === OPTIONS.always;
        const APPLY_NEVER = APPLY === OPTIONS.never;
        const APPLY_CONSISTENT = APPLY === OPTIONS.consistent;
        const APPLY_CONSISTENT_AS_NEEDED = APPLY === OPTIONS.consistentAsNeeded;
        const PARAMS = context.options[1] || {};
        const IGNORE_CONSTRUCTORS = PARAMS.ignoreConstructors;
        const METHODS_IGNORE_PATTERN = PARAMS.methodsIgnorePattern ? new RegExp(PARAMS.methodsIgnorePattern, "u") : null;
        const AVOID_QUOTES = PARAMS.avoidQuotes;
        const AVOID_EXPLICIT_RETURN_ARROWS = !!PARAMS.avoidExplicitReturnArrows;
        const sourceCode = context.getSourceCode();
        const CTOR_PREFIX_REGEX = /[^_$0-9]/u;
        function isConstructor(name) {
          const match = CTOR_PREFIX_REGEX.exec(name);
          if (!match) {
            return false;
          }
          const firstChar = name.charAt(match.index);
          return firstChar === firstChar.toUpperCase();
        }
        function canHaveShorthand(property) {
          return property.kind !== "set" && property.kind !== "get" && property.type !== "SpreadElement" && property.type !== "SpreadProperty" && property.type !== "ExperimentalSpreadProperty";
        }
        function isStringLiteral3(node) {
          return node.type === "Literal" && typeof node.value === "string";
        }
        function isShorthand(property) {
          return property.shorthand || property.method;
        }
        function isRedundant(property) {
          const value2 = property.value;
          if (value2.type === "FunctionExpression") {
            return !value2.id;
          }
          if (value2.type === "Identifier") {
            return astUtils.getStaticPropertyName(property) === value2.name;
          }
          return false;
        }
        function checkConsistency(node, checkRedundancy) {
          const properties = node.properties.filter(canHaveShorthand);
          if (properties.length > 0) {
            const shorthandProperties = properties.filter(isShorthand);
            if (shorthandProperties.length !== properties.length) {
              if (shorthandProperties.length > 0) {
                context.report({ node, messageId: "unexpectedMix" });
              } else if (checkRedundancy) {
                const canAlwaysUseShorthand = properties.every(isRedundant);
                if (canAlwaysUseShorthand) {
                  context.report({ node, messageId: "expectedAllPropertiesShorthanded" });
                }
              }
            }
          }
        }
        function makeFunctionShorthand(fixer, node) {
          const firstKeyToken = node.computed ? sourceCode.getFirstToken(node, astUtils.isOpeningBracketToken) : sourceCode.getFirstToken(node.key);
          const lastKeyToken = node.computed ? sourceCode.getFirstTokenBetween(node.key, node.value, astUtils.isClosingBracketToken) : sourceCode.getLastToken(node.key);
          const keyText = sourceCode.text.slice(firstKeyToken.range[0], lastKeyToken.range[1]);
          let keyPrefix = "";
          if (sourceCode.commentsExistBetween(lastKeyToken, node.value)) {
            return null;
          }
          if (node.value.async) {
            keyPrefix += "async ";
          }
          if (node.value.generator) {
            keyPrefix += "*";
          }
          const fixRange = [firstKeyToken.range[0], node.range[1]];
          const methodPrefix = keyPrefix + keyText;
          if (node.value.type === "FunctionExpression") {
            const functionToken = sourceCode.getTokens(node.value).find((token) => token.type === "Keyword" && token.value === "function");
            const tokenBeforeParams2 = node.value.generator ? sourceCode.getTokenAfter(functionToken) : functionToken;
            return fixer.replaceTextRange(
              fixRange,
              methodPrefix + sourceCode.text.slice(tokenBeforeParams2.range[1], node.value.range[1])
            );
          }
          const arrowToken = sourceCode.getTokenBefore(node.value.body, astUtils.isArrowToken);
          const fnBody = sourceCode.text.slice(arrowToken.range[1], node.value.range[1]);
          let shouldAddParensAroundParameters = false;
          let tokenBeforeParams;
          if (node.value.params.length === 0) {
            tokenBeforeParams = sourceCode.getFirstToken(node.value, astUtils.isOpeningParenToken);
          } else {
            tokenBeforeParams = sourceCode.getTokenBefore(node.value.params[0]);
          }
          if (node.value.params.length === 1) {
            const hasParen = astUtils.isOpeningParenToken(tokenBeforeParams);
            const isTokenOutsideNode = tokenBeforeParams.range[0] < node.range[0];
            shouldAddParensAroundParameters = !hasParen || isTokenOutsideNode;
          }
          const sliceStart = shouldAddParensAroundParameters ? node.value.params[0].range[0] : tokenBeforeParams.range[0];
          const sliceEnd = sourceCode.getTokenBefore(arrowToken).range[1];
          const oldParamText = sourceCode.text.slice(sliceStart, sliceEnd);
          const newParamText = shouldAddParensAroundParameters ? `(${oldParamText})` : oldParamText;
          return fixer.replaceTextRange(
            fixRange,
            methodPrefix + newParamText + fnBody
          );
        }
        function makeFunctionLongform(fixer, node) {
          const firstKeyToken = node.computed ? sourceCode.getTokens(node).find((token) => token.value === "[") : sourceCode.getFirstToken(node.key);
          const lastKeyToken = node.computed ? sourceCode.getTokensBetween(node.key, node.value).find((token) => token.value === "]") : sourceCode.getLastToken(node.key);
          const keyText = sourceCode.text.slice(firstKeyToken.range[0], lastKeyToken.range[1]);
          let functionHeader = "function";
          if (node.value.async) {
            functionHeader = `async ${functionHeader}`;
          }
          if (node.value.generator) {
            functionHeader = `${functionHeader}*`;
          }
          return fixer.replaceTextRange([node.range[0], lastKeyToken.range[1]], `${keyText}: ${functionHeader}`);
        }
        const lexicalScopeStack = [];
        const arrowsWithLexicalIdentifiers = /* @__PURE__ */ new WeakSet();
        const argumentsIdentifiers = /* @__PURE__ */ new WeakSet();
        function enterFunction() {
          lexicalScopeStack.unshift(/* @__PURE__ */ new Set());
          context.getScope().variables.filter((variable) => variable.name === "arguments").forEach((variable) => {
            variable.references.map((ref) => ref.identifier).forEach((identifier3) => argumentsIdentifiers.add(identifier3));
          });
        }
        function exitFunction() {
          lexicalScopeStack.shift();
        }
        function reportLexicalIdentifier() {
          lexicalScopeStack[0].forEach((arrowFunction) => arrowsWithLexicalIdentifiers.add(arrowFunction));
        }
        return {
          Program: enterFunction,
          FunctionDeclaration: enterFunction,
          FunctionExpression: enterFunction,
          "Program:exit": exitFunction,
          "FunctionDeclaration:exit": exitFunction,
          "FunctionExpression:exit": exitFunction,
          ArrowFunctionExpression(node) {
            lexicalScopeStack[0].add(node);
          },
          "ArrowFunctionExpression:exit"(node) {
            lexicalScopeStack[0].delete(node);
          },
          ThisExpression: reportLexicalIdentifier,
          Super: reportLexicalIdentifier,
          MetaProperty(node) {
            if (node.meta.name === "new" && node.property.name === "target") {
              reportLexicalIdentifier();
            }
          },
          Identifier(node) {
            if (argumentsIdentifiers.has(node)) {
              reportLexicalIdentifier();
            }
          },
          ObjectExpression(node) {
            if (APPLY_CONSISTENT) {
              checkConsistency(node, false);
            } else if (APPLY_CONSISTENT_AS_NEEDED) {
              checkConsistency(node, true);
            }
          },
          "Property:exit"(node) {
            const isConciseProperty = node.method || node.shorthand;
            if (node.parent.type === "ObjectPattern") {
              return;
            }
            if (node.kind === "get" || node.kind === "set") {
              return;
            }
            if (node.computed && node.value.type !== "FunctionExpression" && node.value.type !== "ArrowFunctionExpression") {
              return;
            }
            if (isConciseProperty) {
              if (node.method && (APPLY_NEVER || AVOID_QUOTES && isStringLiteral3(node.key))) {
                const messageId = APPLY_NEVER ? "expectedMethodLongform" : "expectedLiteralMethodLongform";
                context.report({
                  node,
                  messageId,
                  fix: (fixer) => makeFunctionLongform(fixer, node)
                });
              } else if (APPLY_NEVER) {
                context.report({
                  node,
                  messageId: "expectedPropertyLongform",
                  fix: (fixer) => fixer.insertTextAfter(node.key, `: ${node.key.name}`)
                });
              }
            } else if (APPLY_TO_METHODS && !node.value.id && (node.value.type === "FunctionExpression" || node.value.type === "ArrowFunctionExpression")) {
              if (IGNORE_CONSTRUCTORS && node.key.type === "Identifier" && isConstructor(node.key.name)) {
                return;
              }
              if (METHODS_IGNORE_PATTERN) {
                const propertyName = astUtils.getStaticPropertyName(node);
                if (propertyName !== null && METHODS_IGNORE_PATTERN.test(propertyName)) {
                  return;
                }
              }
              if (AVOID_QUOTES && isStringLiteral3(node.key)) {
                return;
              }
              if (node.value.type === "FunctionExpression" || node.value.type === "ArrowFunctionExpression" && node.value.body.type === "BlockStatement" && AVOID_EXPLICIT_RETURN_ARROWS && !arrowsWithLexicalIdentifiers.has(node.value)) {
                context.report({
                  node,
                  messageId: "expectedMethodShorthand",
                  fix: (fixer) => makeFunctionShorthand(fixer, node)
                });
              }
            } else if (node.value.type === "Identifier" && node.key.name === node.value.name && APPLY_TO_PROPS) {
              context.report({
                node,
                messageId: "expectedPropertyShorthand",
                fix(fixer) {
                  return fixer.replaceText(node, node.value.name);
                }
              });
            } else if (node.value.type === "Identifier" && node.key.type === "Literal" && node.key.value === node.value.name && APPLY_TO_PROPS) {
              if (AVOID_QUOTES) {
                return;
              }
              context.report({
                node,
                messageId: "expectedPropertyShorthand",
                fix(fixer) {
                  return fixer.replaceText(node, node.value.name);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/one-var.js
var require_one_var = __commonJS({
  "node_modules/eslint/lib/rules/one-var.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isInStatementList(node) {
      return astUtils.STATEMENT_LIST_PARENTS.has(node.parent.type);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce variables to be declared either together or separately in functions",
          recommended: false,
          url: "https://eslint.org/docs/rules/one-var"
        },
        fixable: "code",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never", "consecutive"]
              },
              {
                type: "object",
                properties: {
                  separateRequires: {
                    type: "boolean"
                  },
                  var: {
                    enum: ["always", "never", "consecutive"]
                  },
                  let: {
                    enum: ["always", "never", "consecutive"]
                  },
                  const: {
                    enum: ["always", "never", "consecutive"]
                  }
                },
                additionalProperties: false
              },
              {
                type: "object",
                properties: {
                  initialized: {
                    enum: ["always", "never", "consecutive"]
                  },
                  uninitialized: {
                    enum: ["always", "never", "consecutive"]
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          combineUninitialized: "Combine this with the previous '{{type}}' statement with uninitialized variables.",
          combineInitialized: "Combine this with the previous '{{type}}' statement with initialized variables.",
          splitUninitialized: "Split uninitialized '{{type}}' declarations into multiple statements.",
          splitInitialized: "Split initialized '{{type}}' declarations into multiple statements.",
          splitRequires: "Split requires to be separated into a single block.",
          combine: "Combine this with the previous '{{type}}' statement.",
          split: "Split '{{type}}' declarations into multiple statements."
        }
      },
      create(context) {
        const MODE_ALWAYS = "always";
        const MODE_NEVER = "never";
        const MODE_CONSECUTIVE = "consecutive";
        const mode = context.options[0] || MODE_ALWAYS;
        const options = {};
        if (typeof mode === "string") {
          options.var = { uninitialized: mode, initialized: mode };
          options.let = { uninitialized: mode, initialized: mode };
          options.const = { uninitialized: mode, initialized: mode };
        } else if (typeof mode === "object") {
          options.separateRequires = !!mode.separateRequires;
          options.var = { uninitialized: mode.var, initialized: mode.var };
          options.let = { uninitialized: mode.let, initialized: mode.let };
          options.const = { uninitialized: mode.const, initialized: mode.const };
          if (Object.prototype.hasOwnProperty.call(mode, "uninitialized")) {
            options.var.uninitialized = mode.uninitialized;
            options.let.uninitialized = mode.uninitialized;
            options.const.uninitialized = mode.uninitialized;
          }
          if (Object.prototype.hasOwnProperty.call(mode, "initialized")) {
            options.var.initialized = mode.initialized;
            options.let.initialized = mode.initialized;
            options.const.initialized = mode.initialized;
          }
        }
        const sourceCode = context.getSourceCode();
        const functionStack = [];
        const blockStack = [];
        function startBlock() {
          blockStack.push({
            let: { initialized: false, uninitialized: false },
            const: { initialized: false, uninitialized: false }
          });
        }
        function startFunction() {
          functionStack.push({ initialized: false, uninitialized: false });
          startBlock();
        }
        function endBlock() {
          blockStack.pop();
        }
        function endFunction() {
          functionStack.pop();
          endBlock();
        }
        function isRequire(decl) {
          return decl.init && decl.init.type === "CallExpression" && decl.init.callee.name === "require";
        }
        function recordTypes(statementType, declarations, currentScope) {
          for (let i = 0; i < declarations.length; i++) {
            if (declarations[i].init === null) {
              if (options[statementType] && options[statementType].uninitialized === MODE_ALWAYS) {
                currentScope.uninitialized = true;
              }
            } else {
              if (options[statementType] && options[statementType].initialized === MODE_ALWAYS) {
                if (options.separateRequires && isRequire(declarations[i])) {
                  currentScope.required = true;
                } else {
                  currentScope.initialized = true;
                }
              }
            }
          }
        }
        function getCurrentScope(statementType) {
          let currentScope;
          if (statementType === "var") {
            currentScope = functionStack[functionStack.length - 1];
          } else if (statementType === "let") {
            currentScope = blockStack[blockStack.length - 1].let;
          } else if (statementType === "const") {
            currentScope = blockStack[blockStack.length - 1].const;
          }
          return currentScope;
        }
        function countDeclarations(declarations) {
          const counts = { uninitialized: 0, initialized: 0 };
          for (let i = 0; i < declarations.length; i++) {
            if (declarations[i].init === null) {
              counts.uninitialized++;
            } else {
              counts.initialized++;
            }
          }
          return counts;
        }
        function hasOnlyOneStatement(statementType, declarations) {
          const declarationCounts = countDeclarations(declarations);
          const currentOptions = options[statementType] || {};
          const currentScope = getCurrentScope(statementType);
          const hasRequires = declarations.some(isRequire);
          if (currentOptions.uninitialized === MODE_ALWAYS && currentOptions.initialized === MODE_ALWAYS) {
            if (currentScope.uninitialized || currentScope.initialized) {
              if (!hasRequires) {
                return false;
              }
            }
          }
          if (declarationCounts.uninitialized > 0) {
            if (currentOptions.uninitialized === MODE_ALWAYS && currentScope.uninitialized) {
              return false;
            }
          }
          if (declarationCounts.initialized > 0) {
            if (currentOptions.initialized === MODE_ALWAYS && currentScope.initialized) {
              if (!hasRequires) {
                return false;
              }
            }
          }
          if (currentScope.required && hasRequires) {
            return false;
          }
          recordTypes(statementType, declarations, currentScope);
          return true;
        }
        function joinDeclarations(declarations) {
          const declaration = declarations[0];
          const body = Array.isArray(declaration.parent.parent.body) ? declaration.parent.parent.body : [];
          const currentIndex = body.findIndex((node) => node.range[0] === declaration.parent.range[0]);
          const previousNode = body[currentIndex - 1];
          return (fixer) => {
            const type = sourceCode.getTokenBefore(declaration);
            const prevSemi = sourceCode.getTokenBefore(type);
            const res = [];
            if (previousNode && previousNode.kind === sourceCode.getText(type)) {
              if (prevSemi.value === ";") {
                res.push(fixer.replaceText(prevSemi, ","));
              } else {
                res.push(fixer.insertTextAfter(prevSemi, ","));
              }
              res.push(fixer.replaceText(type, ""));
            }
            return res;
          };
        }
        function splitDeclarations(declaration) {
          const { parent } = declaration;
          if (!isInStatementList(parent.type === "ExportNamedDeclaration" ? parent : declaration)) {
            return null;
          }
          return (fixer) => declaration.declarations.map((declarator) => {
            const tokenAfterDeclarator = sourceCode.getTokenAfter(declarator);
            if (tokenAfterDeclarator === null) {
              return null;
            }
            const afterComma = sourceCode.getTokenAfter(tokenAfterDeclarator, { includeComments: true });
            if (tokenAfterDeclarator.value !== ",") {
              return null;
            }
            const exportPlacement = declaration.parent.type === "ExportNamedDeclaration" ? "export " : "";
            if (afterComma.range[0] === tokenAfterDeclarator.range[1]) {
              return fixer.replaceText(tokenAfterDeclarator, `; ${exportPlacement}${declaration.kind} `);
            }
            if (afterComma.loc.start.line > tokenAfterDeclarator.loc.end.line || afterComma.type === "Line" || afterComma.type === "Block") {
              let lastComment = afterComma;
              while (lastComment.type === "Line" || lastComment.type === "Block") {
                lastComment = sourceCode.getTokenAfter(lastComment, { includeComments: true });
              }
              return fixer.replaceTextRange(
                [tokenAfterDeclarator.range[0], lastComment.range[0]],
                `;${sourceCode.text.slice(tokenAfterDeclarator.range[1], lastComment.range[0])}${exportPlacement}${declaration.kind} `
              );
            }
            return fixer.replaceText(tokenAfterDeclarator, `; ${exportPlacement}${declaration.kind}`);
          }).filter((x) => x);
        }
        function checkVariableDeclaration(node) {
          const parent = node.parent;
          const type = node.kind;
          if (!options[type]) {
            return;
          }
          const declarations = node.declarations;
          const declarationCounts = countDeclarations(declarations);
          const mixedRequires = declarations.some(isRequire) && !declarations.every(isRequire);
          if (options[type].initialized === MODE_ALWAYS) {
            if (options.separateRequires && mixedRequires) {
              context.report({
                node,
                messageId: "splitRequires"
              });
            }
          }
          const nodeIndex = parent.body && parent.body.length > 0 && parent.body.indexOf(node) || 0;
          if (nodeIndex > 0) {
            const previousNode = parent.body[nodeIndex - 1];
            const isPreviousNodeDeclaration = previousNode.type === "VariableDeclaration";
            const declarationsWithPrevious = declarations.concat(previousNode.declarations || []);
            if (isPreviousNodeDeclaration && previousNode.kind === type && !(declarationsWithPrevious.some(isRequire) && !declarationsWithPrevious.every(isRequire))) {
              const previousDeclCounts = countDeclarations(previousNode.declarations);
              if (options[type].initialized === MODE_CONSECUTIVE && options[type].uninitialized === MODE_CONSECUTIVE) {
                context.report({
                  node,
                  messageId: "combine",
                  data: {
                    type
                  },
                  fix: joinDeclarations(declarations)
                });
              } else if (options[type].initialized === MODE_CONSECUTIVE && declarationCounts.initialized > 0 && previousDeclCounts.initialized > 0) {
                context.report({
                  node,
                  messageId: "combineInitialized",
                  data: {
                    type
                  },
                  fix: joinDeclarations(declarations)
                });
              } else if (options[type].uninitialized === MODE_CONSECUTIVE && declarationCounts.uninitialized > 0 && previousDeclCounts.uninitialized > 0) {
                context.report({
                  node,
                  messageId: "combineUninitialized",
                  data: {
                    type
                  },
                  fix: joinDeclarations(declarations)
                });
              }
            }
          }
          if (!hasOnlyOneStatement(type, declarations)) {
            if (options[type].initialized === MODE_ALWAYS && options[type].uninitialized === MODE_ALWAYS) {
              context.report({
                node,
                messageId: "combine",
                data: {
                  type
                },
                fix: joinDeclarations(declarations)
              });
            } else {
              if (options[type].initialized === MODE_ALWAYS && declarationCounts.initialized > 0) {
                context.report({
                  node,
                  messageId: "combineInitialized",
                  data: {
                    type
                  },
                  fix: joinDeclarations(declarations)
                });
              }
              if (options[type].uninitialized === MODE_ALWAYS && declarationCounts.uninitialized > 0) {
                if (node.parent.left === node && (node.parent.type === "ForInStatement" || node.parent.type === "ForOfStatement")) {
                  return;
                }
                context.report({
                  node,
                  messageId: "combineUninitialized",
                  data: {
                    type
                  },
                  fix: joinDeclarations(declarations)
                });
              }
            }
          }
          if (parent.type !== "ForStatement" || parent.init !== node) {
            const totalDeclarations = declarationCounts.uninitialized + declarationCounts.initialized;
            if (totalDeclarations > 1) {
              if (options[type].initialized === MODE_NEVER && options[type].uninitialized === MODE_NEVER) {
                context.report({
                  node,
                  messageId: "split",
                  data: {
                    type
                  },
                  fix: splitDeclarations(node)
                });
              } else if (options[type].initialized === MODE_NEVER && declarationCounts.initialized > 0) {
                context.report({
                  node,
                  messageId: "splitInitialized",
                  data: {
                    type
                  },
                  fix: splitDeclarations(node)
                });
              } else if (options[type].uninitialized === MODE_NEVER && declarationCounts.uninitialized > 0) {
                context.report({
                  node,
                  messageId: "splitUninitialized",
                  data: {
                    type
                  },
                  fix: splitDeclarations(node)
                });
              }
            }
          }
        }
        return {
          Program: startFunction,
          FunctionDeclaration: startFunction,
          FunctionExpression: startFunction,
          ArrowFunctionExpression: startFunction,
          StaticBlock: startFunction,
          // StaticBlock creates a new scope for `var` variables
          BlockStatement: startBlock,
          ForStatement: startBlock,
          ForInStatement: startBlock,
          ForOfStatement: startBlock,
          SwitchStatement: startBlock,
          VariableDeclaration: checkVariableDeclaration,
          "ForStatement:exit": endBlock,
          "ForOfStatement:exit": endBlock,
          "ForInStatement:exit": endBlock,
          "SwitchStatement:exit": endBlock,
          "BlockStatement:exit": endBlock,
          "Program:exit": endFunction,
          "FunctionDeclaration:exit": endFunction,
          "FunctionExpression:exit": endFunction,
          "ArrowFunctionExpression:exit": endFunction,
          "StaticBlock:exit": endFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/one-var-declaration-per-line.js
var require_one_var_declaration_per_line = __commonJS({
  "node_modules/eslint/lib/rules/one-var-declaration-per-line.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow newlines around variable declarations",
          recommended: false,
          url: "https://eslint.org/docs/rules/one-var-declaration-per-line"
        },
        schema: [
          {
            enum: ["always", "initializations"]
          }
        ],
        fixable: "whitespace",
        messages: {
          expectVarOnNewline: "Expected variable declaration to be on a new line."
        }
      },
      create(context) {
        const always = context.options[0] === "always";
        function isForTypeSpecifier(keyword) {
          return keyword === "ForStatement" || keyword === "ForInStatement" || keyword === "ForOfStatement";
        }
        function checkForNewLine(node) {
          if (isForTypeSpecifier(node.parent.type)) {
            return;
          }
          const declarations = node.declarations;
          let prev;
          declarations.forEach((current) => {
            if (prev && prev.loc.end.line === current.loc.start.line) {
              if (always || prev.init || current.init) {
                context.report({
                  node,
                  messageId: "expectVarOnNewline",
                  loc: current.loc,
                  fix: (fixer) => fixer.insertTextBefore(current, "\n")
                });
              }
            }
            prev = current;
          });
        }
        return {
          VariableDeclaration: checkForNewLine
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/operator-assignment.js
var require_operator_assignment = __commonJS({
  "node_modules/eslint/lib/rules/operator-assignment.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isCommutativeOperatorWithShorthand(operator) {
      return ["*", "&", "^", "|"].includes(operator);
    }
    function isNonCommutativeOperatorWithShorthand(operator) {
      return ["+", "-", "/", "%", "<<", ">>", ">>>", "**"].includes(operator);
    }
    function canBeFixed(node) {
      return node.type === "Identifier" || node.type === "MemberExpression" && (node.object.type === "Identifier" || node.object.type === "ThisExpression") && (!node.computed || node.property.type === "Literal");
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow assignment operator shorthand where possible",
          recommended: false,
          url: "https://eslint.org/docs/rules/operator-assignment"
        },
        schema: [
          {
            enum: ["always", "never"]
          }
        ],
        fixable: "code",
        messages: {
          replaced: "Assignment (=) can be replaced with operator assignment ({{operator}}).",
          unexpected: "Unexpected operator assignment ({{operator}}) shorthand."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function getOperatorToken(node) {
          return sourceCode.getFirstTokenBetween(node.left, node.right, (token) => token.value === node.operator);
        }
        function verify(node) {
          if (node.operator !== "=" || node.right.type !== "BinaryExpression") {
            return;
          }
          const left = node.left;
          const expr = node.right;
          const operator = expr.operator;
          if (isCommutativeOperatorWithShorthand(operator) || isNonCommutativeOperatorWithShorthand(operator)) {
            const replacementOperator = `${operator}=`;
            if (astUtils.isSameReference(left, expr.left, true)) {
              context.report({
                node,
                messageId: "replaced",
                data: { operator: replacementOperator },
                fix(fixer) {
                  if (canBeFixed(left) && canBeFixed(expr.left)) {
                    const equalsToken = getOperatorToken(node);
                    const operatorToken = getOperatorToken(expr);
                    const leftText = sourceCode.getText().slice(node.range[0], equalsToken.range[0]);
                    const rightText = sourceCode.getText().slice(operatorToken.range[1], node.right.range[1]);
                    if (sourceCode.commentsExistBetween(equalsToken, operatorToken)) {
                      return null;
                    }
                    return fixer.replaceText(node, `${leftText}${replacementOperator}${rightText}`);
                  }
                  return null;
                }
              });
            } else if (astUtils.isSameReference(left, expr.right, true) && isCommutativeOperatorWithShorthand(operator)) {
              context.report({
                node,
                messageId: "replaced",
                data: { operator: replacementOperator }
              });
            }
          }
        }
        function prohibit(node) {
          if (node.operator !== "=" && !astUtils.isLogicalAssignmentOperator(node.operator)) {
            context.report({
              node,
              messageId: "unexpected",
              data: { operator: node.operator },
              fix(fixer) {
                if (canBeFixed(node.left)) {
                  const firstToken = sourceCode.getFirstToken(node);
                  const operatorToken = getOperatorToken(node);
                  const leftText = sourceCode.getText().slice(node.range[0], operatorToken.range[0]);
                  const newOperator = node.operator.slice(0, -1);
                  let rightText;
                  if (sourceCode.commentsExistBetween(firstToken, operatorToken)) {
                    return null;
                  }
                  if (astUtils.getPrecedence(node.right) <= astUtils.getPrecedence({ type: "BinaryExpression", operator: newOperator }) && !astUtils.isParenthesised(sourceCode, node.right)) {
                    rightText = `${sourceCode.text.slice(operatorToken.range[1], node.right.range[0])}(${sourceCode.getText(node.right)})`;
                  } else {
                    const tokenAfterOperator = sourceCode.getTokenAfter(operatorToken, { includeComments: true });
                    let rightTextPrefix = "";
                    if (operatorToken.range[1] === tokenAfterOperator.range[0] && !astUtils.canTokensBeAdjacent({ type: "Punctuator", value: newOperator }, tokenAfterOperator)) {
                      rightTextPrefix = " ";
                    }
                    rightText = `${rightTextPrefix}${sourceCode.text.slice(operatorToken.range[1], node.range[1])}`;
                  }
                  return fixer.replaceText(node, `${leftText}= ${leftText}${newOperator}${rightText}`);
                }
                return null;
              }
            });
          }
        }
        return {
          AssignmentExpression: context.options[0] !== "never" ? verify : prohibit
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/operator-linebreak.js
var require_operator_linebreak = __commonJS({
  "node_modules/eslint/lib/rules/operator-linebreak.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent linebreak style for operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/operator-linebreak"
        },
        schema: [
          {
            enum: ["after", "before", "none", null]
          },
          {
            type: "object",
            properties: {
              overrides: {
                type: "object",
                additionalProperties: {
                  enum: ["after", "before", "none", "ignore"]
                }
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          operatorAtBeginning: "'{{operator}}' should be placed at the beginning of the line.",
          operatorAtEnd: "'{{operator}}' should be placed at the end of the line.",
          badLinebreak: "Bad line breaking before and after '{{operator}}'.",
          noLinebreak: "There should be no line break before or after '{{operator}}'."
        }
      },
      create(context) {
        const usedDefaultGlobal = !context.options[0];
        const globalStyle = context.options[0] || "after";
        const options = context.options[1] || {};
        const styleOverrides = options.overrides ? Object.assign({}, options.overrides) : {};
        if (usedDefaultGlobal && !styleOverrides["?"]) {
          styleOverrides["?"] = "before";
        }
        if (usedDefaultGlobal && !styleOverrides[":"]) {
          styleOverrides[":"] = "before";
        }
        const sourceCode = context.getSourceCode();
        function getFixer(operatorToken, desiredStyle) {
          return (fixer) => {
            const tokenBefore = sourceCode.getTokenBefore(operatorToken);
            const tokenAfter = sourceCode.getTokenAfter(operatorToken);
            const textBefore = sourceCode.text.slice(tokenBefore.range[1], operatorToken.range[0]);
            const textAfter = sourceCode.text.slice(operatorToken.range[1], tokenAfter.range[0]);
            const hasLinebreakBefore = !astUtils.isTokenOnSameLine(tokenBefore, operatorToken);
            const hasLinebreakAfter = !astUtils.isTokenOnSameLine(operatorToken, tokenAfter);
            let newTextBefore, newTextAfter;
            if (hasLinebreakBefore !== hasLinebreakAfter && desiredStyle !== "none") {
              if (sourceCode.getTokenBefore(operatorToken, { includeComments: true }) !== tokenBefore && sourceCode.getTokenAfter(operatorToken, { includeComments: true }) !== tokenAfter) {
                return null;
              }
              newTextBefore = textAfter;
              newTextAfter = textBefore;
            } else {
              const LINEBREAK_REGEX = astUtils.createGlobalLinebreakMatcher();
              newTextBefore = desiredStyle === "before" || textBefore.trim() ? textBefore : textBefore.replace(LINEBREAK_REGEX, "");
              newTextAfter = desiredStyle === "after" || textAfter.trim() ? textAfter : textAfter.replace(LINEBREAK_REGEX, "");
              if (newTextBefore === textBefore && newTextAfter === textAfter) {
                return null;
              }
            }
            if (newTextAfter === "" && tokenAfter.type === "Punctuator" && "+-".includes(operatorToken.value) && tokenAfter.value === operatorToken.value) {
              newTextAfter += " ";
            }
            return fixer.replaceTextRange([tokenBefore.range[1], tokenAfter.range[0]], newTextBefore + operatorToken.value + newTextAfter);
          };
        }
        function validateNode(node, rightSide, operator) {
          const operatorToken = sourceCode.getTokenBefore(rightSide, (token) => token.value === operator);
          const leftToken = sourceCode.getTokenBefore(operatorToken);
          const rightToken = sourceCode.getTokenAfter(operatorToken);
          const operatorStyleOverride = styleOverrides[operator];
          const style = operatorStyleOverride || globalStyle;
          const fix = getFixer(operatorToken, style);
          if (astUtils.isTokenOnSameLine(leftToken, operatorToken) && astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
          } else if (operatorStyleOverride !== "ignore" && !astUtils.isTokenOnSameLine(leftToken, operatorToken) && !astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
            context.report({
              node,
              loc: operatorToken.loc,
              messageId: "badLinebreak",
              data: {
                operator
              },
              fix
            });
          } else if (style === "before" && astUtils.isTokenOnSameLine(leftToken, operatorToken)) {
            context.report({
              node,
              loc: operatorToken.loc,
              messageId: "operatorAtBeginning",
              data: {
                operator
              },
              fix
            });
          } else if (style === "after" && astUtils.isTokenOnSameLine(operatorToken, rightToken)) {
            context.report({
              node,
              loc: operatorToken.loc,
              messageId: "operatorAtEnd",
              data: {
                operator
              },
              fix
            });
          } else if (style === "none") {
            context.report({
              node,
              loc: operatorToken.loc,
              messageId: "noLinebreak",
              data: {
                operator
              },
              fix
            });
          }
        }
        function validateBinaryExpression(node) {
          validateNode(node, node.right, node.operator);
        }
        return {
          BinaryExpression: validateBinaryExpression,
          LogicalExpression: validateBinaryExpression,
          AssignmentExpression: validateBinaryExpression,
          VariableDeclarator(node) {
            if (node.init) {
              validateNode(node, node.init, "=");
            }
          },
          PropertyDefinition(node) {
            if (node.value) {
              validateNode(node, node.value, "=");
            }
          },
          ConditionalExpression(node) {
            validateNode(node, node.consequent, "?");
            validateNode(node, node.alternate, ":");
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/padded-blocks.js
var require_padded_blocks = __commonJS({
  "node_modules/eslint/lib/rules/padded-blocks.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow padding within blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/padded-blocks"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never"]
              },
              {
                type: "object",
                properties: {
                  blocks: {
                    enum: ["always", "never"]
                  },
                  switches: {
                    enum: ["always", "never"]
                  },
                  classes: {
                    enum: ["always", "never"]
                  }
                },
                additionalProperties: false,
                minProperties: 1
              }
            ]
          },
          {
            type: "object",
            properties: {
              allowSingleLineBlocks: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          alwaysPadBlock: "Block must be padded by blank lines.",
          neverPadBlock: "Block must not be padded by blank lines."
        }
      },
      create(context) {
        const options = {};
        const typeOptions = context.options[0] || "always";
        const exceptOptions = context.options[1] || {};
        if (typeof typeOptions === "string") {
          const shouldHavePadding = typeOptions === "always";
          options.blocks = shouldHavePadding;
          options.switches = shouldHavePadding;
          options.classes = shouldHavePadding;
        } else {
          if (Object.prototype.hasOwnProperty.call(typeOptions, "blocks")) {
            options.blocks = typeOptions.blocks === "always";
          }
          if (Object.prototype.hasOwnProperty.call(typeOptions, "switches")) {
            options.switches = typeOptions.switches === "always";
          }
          if (Object.prototype.hasOwnProperty.call(typeOptions, "classes")) {
            options.classes = typeOptions.classes === "always";
          }
        }
        if (Object.prototype.hasOwnProperty.call(exceptOptions, "allowSingleLineBlocks")) {
          options.allowSingleLineBlocks = exceptOptions.allowSingleLineBlocks === true;
        }
        const sourceCode = context.getSourceCode();
        function getOpenBrace(node) {
          if (node.type === "SwitchStatement") {
            return sourceCode.getTokenBefore(node.cases[0]);
          }
          if (node.type === "StaticBlock") {
            return sourceCode.getFirstToken(node, { skip: 1 });
          }
          return sourceCode.getFirstToken(node);
        }
        function isComment(node) {
          return node.type === "Line" || node.type === "Block";
        }
        function isPaddingBetweenTokens(first2, second) {
          return second.loc.start.line - first2.loc.end.line >= 2;
        }
        function getFirstBlockToken(token) {
          let prev, first2 = token;
          do {
            prev = first2;
            first2 = sourceCode.getTokenAfter(first2, { includeComments: true });
          } while (isComment(first2) && first2.loc.start.line === prev.loc.end.line);
          return first2;
        }
        function getLastBlockToken(token) {
          let last2 = token, next;
          do {
            next = last2;
            last2 = sourceCode.getTokenBefore(last2, { includeComments: true });
          } while (isComment(last2) && last2.loc.end.line === next.loc.start.line);
          return last2;
        }
        function requirePaddingFor(node) {
          switch (node.type) {
            case "BlockStatement":
            case "StaticBlock":
              return options.blocks;
            case "SwitchStatement":
              return options.switches;
            case "ClassBody":
              return options.classes;
            default:
              throw new Error("unreachable");
          }
        }
        function checkPadding(node) {
          const openBrace = getOpenBrace(node), firstBlockToken = getFirstBlockToken(openBrace), tokenBeforeFirst = sourceCode.getTokenBefore(firstBlockToken, { includeComments: true }), closeBrace = sourceCode.getLastToken(node), lastBlockToken = getLastBlockToken(closeBrace), tokenAfterLast = sourceCode.getTokenAfter(lastBlockToken, { includeComments: true }), blockHasTopPadding = isPaddingBetweenTokens(tokenBeforeFirst, firstBlockToken), blockHasBottomPadding = isPaddingBetweenTokens(lastBlockToken, tokenAfterLast);
          if (options.allowSingleLineBlocks && astUtils.isTokenOnSameLine(tokenBeforeFirst, tokenAfterLast)) {
            return;
          }
          if (requirePaddingFor(node)) {
            if (!blockHasTopPadding) {
              context.report({
                node,
                loc: {
                  start: tokenBeforeFirst.loc.start,
                  end: firstBlockToken.loc.start
                },
                fix(fixer) {
                  return fixer.insertTextAfter(tokenBeforeFirst, "\n");
                },
                messageId: "alwaysPadBlock"
              });
            }
            if (!blockHasBottomPadding) {
              context.report({
                node,
                loc: {
                  end: tokenAfterLast.loc.start,
                  start: lastBlockToken.loc.end
                },
                fix(fixer) {
                  return fixer.insertTextBefore(tokenAfterLast, "\n");
                },
                messageId: "alwaysPadBlock"
              });
            }
          } else {
            if (blockHasTopPadding) {
              context.report({
                node,
                loc: {
                  start: tokenBeforeFirst.loc.start,
                  end: firstBlockToken.loc.start
                },
                fix(fixer) {
                  return fixer.replaceTextRange([tokenBeforeFirst.range[1], firstBlockToken.range[0] - firstBlockToken.loc.start.column], "\n");
                },
                messageId: "neverPadBlock"
              });
            }
            if (blockHasBottomPadding) {
              context.report({
                node,
                loc: {
                  end: tokenAfterLast.loc.start,
                  start: lastBlockToken.loc.end
                },
                messageId: "neverPadBlock",
                fix(fixer) {
                  return fixer.replaceTextRange([lastBlockToken.range[1], tokenAfterLast.range[0] - tokenAfterLast.loc.start.column], "\n");
                }
              });
            }
          }
        }
        const rule = {};
        if (Object.prototype.hasOwnProperty.call(options, "switches")) {
          rule.SwitchStatement = function(node) {
            if (node.cases.length === 0) {
              return;
            }
            checkPadding(node);
          };
        }
        if (Object.prototype.hasOwnProperty.call(options, "blocks")) {
          rule.BlockStatement = function(node) {
            if (node.body.length === 0) {
              return;
            }
            checkPadding(node);
          };
          rule.StaticBlock = rule.BlockStatement;
        }
        if (Object.prototype.hasOwnProperty.call(options, "classes")) {
          rule.ClassBody = function(node) {
            if (node.body.length === 0) {
              return;
            }
            checkPadding(node);
          };
        }
        return rule;
      }
    };
  }
});

// node_modules/eslint/lib/rules/padding-line-between-statements.js
var require_padding_line_between_statements = __commonJS({
  "node_modules/eslint/lib/rules/padding-line-between-statements.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var LT = `[${Array.from(astUtils.LINEBREAKS).join("")}]`;
    var PADDING_LINE_SEQUENCE = new RegExp(
      String.raw`^(\s*?${LT})\s*${LT}(\s*;?)$`,
      "u"
    );
    var CJS_EXPORT = /^(?:module\s*\.\s*)?exports(?:\s*\.|\s*\[|$)/u;
    var CJS_IMPORT = /^require\(/u;
    function newKeywordTester(keyword) {
      return {
        test: (node, sourceCode) => sourceCode.getFirstToken(node).value === keyword
      };
    }
    function newSinglelineKeywordTester(keyword) {
      return {
        test: (node, sourceCode) => node.loc.start.line === node.loc.end.line && sourceCode.getFirstToken(node).value === keyword
      };
    }
    function newMultilineKeywordTester(keyword) {
      return {
        test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line && sourceCode.getFirstToken(node).value === keyword
      };
    }
    function newNodeTypeTester(type) {
      return {
        test: (node) => node.type === type
      };
    }
    function isIIFEStatement(node) {
      if (node.type === "ExpressionStatement") {
        let call = astUtils.skipChainExpression(node.expression);
        if (call.type === "UnaryExpression") {
          call = astUtils.skipChainExpression(call.argument);
        }
        return call.type === "CallExpression" && astUtils.isFunction(call.callee);
      }
      return false;
    }
    function isBlockLikeStatement(sourceCode, node) {
      if (node.type === "DoWhileStatement" && node.body.type === "BlockStatement") {
        return true;
      }
      if (isIIFEStatement(node)) {
        return true;
      }
      const lastToken = sourceCode.getLastToken(node, astUtils.isNotSemicolonToken);
      const belongingNode = lastToken && astUtils.isClosingBraceToken(lastToken) ? sourceCode.getNodeByRangeIndex(lastToken.range[0]) : null;
      return Boolean(belongingNode) && (belongingNode.type === "BlockStatement" || belongingNode.type === "SwitchStatement");
    }
    function isDirective(node, sourceCode) {
      return node.type === "ExpressionStatement" && (node.parent.type === "Program" || node.parent.type === "BlockStatement" && astUtils.isFunction(node.parent.parent)) && node.expression.type === "Literal" && typeof node.expression.value === "string" && !astUtils.isParenthesised(sourceCode, node.expression);
    }
    function isDirectivePrologue(node, sourceCode) {
      if (isDirective(node, sourceCode)) {
        for (const sibling of node.parent.body) {
          if (sibling === node) {
            break;
          }
          if (!isDirective(sibling, sourceCode)) {
            return false;
          }
        }
        return true;
      }
      return false;
    }
    function getActualLastToken(sourceCode, node) {
      const semiToken = sourceCode.getLastToken(node);
      const prevToken = sourceCode.getTokenBefore(semiToken);
      const nextToken = sourceCode.getTokenAfter(semiToken);
      const isSemicolonLessStyle = Boolean(
        prevToken && nextToken && prevToken.range[0] >= node.range[0] && astUtils.isSemicolonToken(semiToken) && semiToken.loc.start.line !== prevToken.loc.end.line && semiToken.loc.end.line === nextToken.loc.start.line
      );
      return isSemicolonLessStyle ? prevToken : semiToken;
    }
    function replacerToRemovePaddingLines(_, trailingSpaces, indentSpaces) {
      return trailingSpaces + indentSpaces;
    }
    function verifyForAny() {
    }
    function verifyForNever(context, _, nextNode, paddingLines) {
      if (paddingLines.length === 0) {
        return;
      }
      context.report({
        node: nextNode,
        messageId: "unexpectedBlankLine",
        fix(fixer) {
          if (paddingLines.length >= 2) {
            return null;
          }
          const prevToken = paddingLines[0][0];
          const nextToken = paddingLines[0][1];
          const start = prevToken.range[1];
          const end = nextToken.range[0];
          const text = context.getSourceCode().text.slice(start, end).replace(PADDING_LINE_SEQUENCE, replacerToRemovePaddingLines);
          return fixer.replaceTextRange([start, end], text);
        }
      });
    }
    function verifyForAlways(context, prevNode, nextNode, paddingLines) {
      if (paddingLines.length > 0) {
        return;
      }
      context.report({
        node: nextNode,
        messageId: "expectedBlankLine",
        fix(fixer) {
          const sourceCode = context.getSourceCode();
          let prevToken = getActualLastToken(sourceCode, prevNode);
          const nextToken = sourceCode.getFirstTokenBetween(
            prevToken,
            nextNode,
            {
              includeComments: true,
              /**
               * Skip the trailing comments of the previous node.
               * This inserts a blank line after the last trailing comment.
               *
               * For example:
               *
               *     foo(); // trailing comment.
               *     // comment.
               *     bar();
               *
               * Get fixed to:
               *
               *     foo(); // trailing comment.
               *
               *     // comment.
               *     bar();
               * @param {Token} token The token to check.
               * @returns {boolean} `true` if the token is not a trailing comment.
               * @private
               */
              filter(token) {
                if (astUtils.isTokenOnSameLine(prevToken, token)) {
                  prevToken = token;
                  return false;
                }
                return true;
              }
            }
          ) || nextNode;
          const insertText = astUtils.isTokenOnSameLine(prevToken, nextToken) ? "\n\n" : "\n";
          return fixer.insertTextAfter(prevToken, insertText);
        }
      });
    }
    var PaddingTypes = {
      any: { verify: verifyForAny },
      never: { verify: verifyForNever },
      always: { verify: verifyForAlways }
    };
    var StatementTypes = {
      "*": { test: () => true },
      "block-like": {
        test: (node, sourceCode) => isBlockLikeStatement(sourceCode, node)
      },
      "cjs-export": {
        test: (node, sourceCode) => node.type === "ExpressionStatement" && node.expression.type === "AssignmentExpression" && CJS_EXPORT.test(sourceCode.getText(node.expression.left))
      },
      "cjs-import": {
        test: (node, sourceCode) => node.type === "VariableDeclaration" && node.declarations.length > 0 && Boolean(node.declarations[0].init) && CJS_IMPORT.test(sourceCode.getText(node.declarations[0].init))
      },
      directive: {
        test: isDirectivePrologue
      },
      expression: {
        test: (node, sourceCode) => node.type === "ExpressionStatement" && !isDirectivePrologue(node, sourceCode)
      },
      iife: {
        test: isIIFEStatement
      },
      "multiline-block-like": {
        test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line && isBlockLikeStatement(sourceCode, node)
      },
      "multiline-expression": {
        test: (node, sourceCode) => node.loc.start.line !== node.loc.end.line && node.type === "ExpressionStatement" && !isDirectivePrologue(node, sourceCode)
      },
      "multiline-const": newMultilineKeywordTester("const"),
      "multiline-let": newMultilineKeywordTester("let"),
      "multiline-var": newMultilineKeywordTester("var"),
      "singleline-const": newSinglelineKeywordTester("const"),
      "singleline-let": newSinglelineKeywordTester("let"),
      "singleline-var": newSinglelineKeywordTester("var"),
      block: newNodeTypeTester("BlockStatement"),
      empty: newNodeTypeTester("EmptyStatement"),
      function: newNodeTypeTester("FunctionDeclaration"),
      break: newKeywordTester("break"),
      case: newKeywordTester("case"),
      class: newKeywordTester("class"),
      const: newKeywordTester("const"),
      continue: newKeywordTester("continue"),
      debugger: newKeywordTester("debugger"),
      default: newKeywordTester("default"),
      do: newKeywordTester("do"),
      export: newKeywordTester("export"),
      for: newKeywordTester("for"),
      if: newKeywordTester("if"),
      import: newKeywordTester("import"),
      let: newKeywordTester("let"),
      return: newKeywordTester("return"),
      switch: newKeywordTester("switch"),
      throw: newKeywordTester("throw"),
      try: newKeywordTester("try"),
      var: newKeywordTester("var"),
      while: newKeywordTester("while"),
      with: newKeywordTester("with")
    };
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow padding lines between statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/padding-line-between-statements"
        },
        fixable: "whitespace",
        schema: {
          definitions: {
            paddingType: {
              enum: Object.keys(PaddingTypes)
            },
            statementType: {
              anyOf: [
                { enum: Object.keys(StatementTypes) },
                {
                  type: "array",
                  items: { enum: Object.keys(StatementTypes) },
                  minItems: 1,
                  uniqueItems: true
                }
              ]
            }
          },
          type: "array",
          items: {
            type: "object",
            properties: {
              blankLine: { $ref: "#/definitions/paddingType" },
              prev: { $ref: "#/definitions/statementType" },
              next: { $ref: "#/definitions/statementType" }
            },
            additionalProperties: false,
            required: ["blankLine", "prev", "next"]
          }
        },
        messages: {
          unexpectedBlankLine: "Unexpected blank line before this statement.",
          expectedBlankLine: "Expected blank line before this statement."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const configureList = context.options || [];
        let scopeInfo = null;
        function enterScope() {
          scopeInfo = {
            upper: scopeInfo,
            prevNode: null
          };
        }
        function exitScope() {
          scopeInfo = scopeInfo.upper;
        }
        function match(node, type) {
          let innerStatementNode = node;
          while (innerStatementNode.type === "LabeledStatement") {
            innerStatementNode = innerStatementNode.body;
          }
          if (Array.isArray(type)) {
            return type.some(match.bind(null, innerStatementNode));
          }
          return StatementTypes[type].test(innerStatementNode, sourceCode);
        }
        function getPaddingType(prevNode, nextNode) {
          for (let i = configureList.length - 1; i >= 0; --i) {
            const configure = configureList[i];
            const matched = match(prevNode, configure.prev) && match(nextNode, configure.next);
            if (matched) {
              return PaddingTypes[configure.blankLine];
            }
          }
          return PaddingTypes.any;
        }
        function getPaddingLineSequences(prevNode, nextNode) {
          const pairs = [];
          let prevToken = getActualLastToken(sourceCode, prevNode);
          if (nextNode.loc.start.line - prevToken.loc.end.line >= 2) {
            do {
              const token = sourceCode.getTokenAfter(
                prevToken,
                { includeComments: true }
              );
              if (token.loc.start.line - prevToken.loc.end.line >= 2) {
                pairs.push([prevToken, token]);
              }
              prevToken = token;
            } while (prevToken.range[0] < nextNode.range[0]);
          }
          return pairs;
        }
        function verify(node) {
          const parentType = node.parent.type;
          const validParent = astUtils.STATEMENT_LIST_PARENTS.has(parentType) || parentType === "SwitchStatement";
          if (!validParent) {
            return;
          }
          const prevNode = scopeInfo.prevNode;
          if (prevNode) {
            const type = getPaddingType(prevNode, node);
            const paddingLines = getPaddingLineSequences(prevNode, node);
            type.verify(context, prevNode, node, paddingLines);
          }
          scopeInfo.prevNode = node;
        }
        function verifyThenEnterScope(node) {
          verify(node);
          enterScope();
        }
        return {
          Program: enterScope,
          BlockStatement: enterScope,
          SwitchStatement: enterScope,
          StaticBlock: enterScope,
          "Program:exit": exitScope,
          "BlockStatement:exit": exitScope,
          "SwitchStatement:exit": exitScope,
          "StaticBlock:exit": exitScope,
          ":statement": verify,
          SwitchCase: verifyThenEnterScope,
          "SwitchCase:exit": exitScope
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-arrow-callback.js
var require_prefer_arrow_callback = __commonJS({
  "node_modules/eslint/lib/rules/prefer-arrow-callback.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isFunctionName(variable) {
      return variable && variable.defs[0].type === "FunctionName";
    }
    function checkMetaProperty(node, metaName, propertyName) {
      return node.meta.name === metaName && node.property.name === propertyName;
    }
    function getVariableOfArguments(scope) {
      const variables = scope.variables;
      for (let i = 0; i < variables.length; ++i) {
        const variable = variables[i];
        if (variable.name === "arguments") {
          return variable.identifiers.length === 0 ? variable : null;
        }
      }
      return null;
    }
    function getCallbackInfo(node) {
      const retv = { isCallback: false, isLexicalThis: false };
      let currentNode = node;
      let parent = node.parent;
      let bound = false;
      while (currentNode) {
        switch (parent.type) {
          case "LogicalExpression":
          case "ChainExpression":
          case "ConditionalExpression":
            break;
          case "MemberExpression":
            if (parent.object === currentNode && !parent.property.computed && parent.property.type === "Identifier" && parent.property.name === "bind") {
              const maybeCallee = parent.parent.type === "ChainExpression" ? parent.parent : parent;
              if (astUtils.isCallee(maybeCallee)) {
                if (!bound) {
                  bound = true;
                  retv.isLexicalThis = maybeCallee.parent.arguments.length === 1 && maybeCallee.parent.arguments[0].type === "ThisExpression";
                }
                parent = maybeCallee.parent;
              } else {
                return retv;
              }
            } else {
              return retv;
            }
            break;
          case "CallExpression":
          case "NewExpression":
            if (parent.callee !== currentNode) {
              retv.isCallback = true;
            }
            return retv;
          default:
            return retv;
        }
        currentNode = parent;
        parent = parent.parent;
      }
      throw new Error("unreachable");
    }
    function hasDuplicateParams(paramsList) {
      return paramsList.every((param) => param.type === "Identifier") && paramsList.length !== new Set(paramsList.map((param) => param.name)).size;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require using arrow functions for callbacks",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-arrow-callback"
        },
        schema: [
          {
            type: "object",
            properties: {
              allowNamedFunctions: {
                type: "boolean",
                default: false
              },
              allowUnboundThis: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          preferArrowCallback: "Unexpected function expression."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const allowUnboundThis = options.allowUnboundThis !== false;
        const allowNamedFunctions = options.allowNamedFunctions;
        const sourceCode = context.getSourceCode();
        let stack = [];
        function enterScope() {
          stack.push({ this: false, super: false, meta: false });
        }
        function exitScope() {
          return stack.pop();
        }
        return {
          // Reset internal state.
          Program() {
            stack = [];
          },
          // If there are below, it cannot replace with arrow functions merely.
          ThisExpression() {
            const info = stack[stack.length - 1];
            if (info) {
              info.this = true;
            }
          },
          Super() {
            const info = stack[stack.length - 1];
            if (info) {
              info.super = true;
            }
          },
          MetaProperty(node) {
            const info = stack[stack.length - 1];
            if (info && checkMetaProperty(node, "new", "target")) {
              info.meta = true;
            }
          },
          // To skip nested scopes.
          FunctionDeclaration: enterScope,
          "FunctionDeclaration:exit": exitScope,
          // Main.
          FunctionExpression: enterScope,
          "FunctionExpression:exit"(node) {
            const scopeInfo = exitScope();
            if (allowNamedFunctions && node.id && node.id.name) {
              return;
            }
            if (node.generator) {
              return;
            }
            const nameVar = context.getDeclaredVariables(node)[0];
            if (isFunctionName(nameVar) && nameVar.references.length > 0) {
              return;
            }
            const variable = getVariableOfArguments(context.getScope());
            if (variable && variable.references.length > 0) {
              return;
            }
            const callbackInfo = getCallbackInfo(node);
            if (callbackInfo.isCallback && (!allowUnboundThis || !scopeInfo.this || callbackInfo.isLexicalThis) && !scopeInfo.super && !scopeInfo.meta) {
              context.report({
                node,
                messageId: "preferArrowCallback",
                *fix(fixer) {
                  if (!callbackInfo.isLexicalThis && scopeInfo.this || hasDuplicateParams(node.params)) {
                    return;
                  }
                  if (callbackInfo.isLexicalThis) {
                    const memberNode = node.parent;
                    if (memberNode.type !== "MemberExpression") {
                      return;
                    }
                    const callNode = memberNode.parent;
                    const firstTokenToRemove = sourceCode.getTokenAfter(memberNode.object, astUtils.isNotClosingParenToken);
                    const lastTokenToRemove = sourceCode.getLastToken(callNode);
                    if (astUtils.isParenthesised(sourceCode, memberNode)) {
                      return;
                    }
                    if (sourceCode.commentsExistBetween(firstTokenToRemove, lastTokenToRemove)) {
                      return;
                    }
                    yield fixer.removeRange([firstTokenToRemove.range[0], lastTokenToRemove.range[1]]);
                  }
                  const functionToken = sourceCode.getFirstToken(node, node.async ? 1 : 0);
                  const leftParenToken = sourceCode.getTokenAfter(functionToken, astUtils.isOpeningParenToken);
                  const tokenBeforeBody = sourceCode.getTokenBefore(node.body);
                  if (sourceCode.commentsExistBetween(functionToken, leftParenToken)) {
                    yield fixer.remove(functionToken);
                    if (node.id) {
                      yield fixer.remove(node.id);
                    }
                  } else {
                    yield fixer.removeRange([functionToken.range[0], leftParenToken.range[0]]);
                  }
                  yield fixer.insertTextAfter(tokenBeforeBody, " =>");
                  let replacedNode = callbackInfo.isLexicalThis ? node.parent.parent : node;
                  if (replacedNode.type === "ChainExpression") {
                    replacedNode = replacedNode.parent;
                  }
                  if (replacedNode.parent.type !== "CallExpression" && replacedNode.parent.type !== "ConditionalExpression" && !astUtils.isParenthesised(sourceCode, replacedNode) && !astUtils.isParenthesised(sourceCode, node)) {
                    yield fixer.insertTextBefore(replacedNode, "(");
                    yield fixer.insertTextAfter(replacedNode, ")");
                  }
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-const.js
var require_prefer_const = __commonJS({
  "node_modules/eslint/lib/rules/prefer-const.js"(exports, module2) {
    "use strict";
    var FixTracker = require_fix_tracker();
    var astUtils = require_ast_utils2();
    var PATTERN_TYPE = /^(?:.+?Pattern|RestElement|SpreadProperty|ExperimentalRestProperty|Property)$/u;
    var DECLARATION_HOST_TYPE = /^(?:Program|BlockStatement|StaticBlock|SwitchCase)$/u;
    var DESTRUCTURING_HOST_TYPE = /^(?:VariableDeclarator|AssignmentExpression)$/u;
    function isInitOfForStatement(node) {
      return node.parent.type === "ForStatement" && node.parent.init === node;
    }
    function canBecomeVariableDeclaration(identifier3) {
      let node = identifier3.parent;
      while (PATTERN_TYPE.test(node.type)) {
        node = node.parent;
      }
      return node.type === "VariableDeclarator" || node.type === "AssignmentExpression" && node.parent.type === "ExpressionStatement" && DECLARATION_HOST_TYPE.test(node.parent.parent.type);
    }
    function isOuterVariableInDestructing(name, initScope) {
      if (initScope.through.some((ref) => ref.resolved && ref.resolved.name === name)) {
        return true;
      }
      const variable = astUtils.getVariableByName(initScope, name);
      if (variable !== null) {
        return variable.defs.some((def) => def.type === "Parameter");
      }
      return false;
    }
    function getDestructuringHost(reference) {
      if (!reference.isWrite()) {
        return null;
      }
      let node = reference.identifier.parent;
      while (PATTERN_TYPE.test(node.type)) {
        node = node.parent;
      }
      if (!DESTRUCTURING_HOST_TYPE.test(node.type)) {
        return null;
      }
      return node;
    }
    function hasMemberExpressionAssignment(node) {
      switch (node.type) {
        case "ObjectPattern":
          return node.properties.some((prop) => {
            if (prop) {
              return hasMemberExpressionAssignment(prop.argument || prop.value);
            }
            return false;
          });
        case "ArrayPattern":
          return node.elements.some((element) => {
            if (element) {
              return hasMemberExpressionAssignment(element);
            }
            return false;
          });
        case "AssignmentPattern":
          return hasMemberExpressionAssignment(node.left);
        case "MemberExpression":
          return true;
      }
      return false;
    }
    function getIdentifierIfShouldBeConst(variable, ignoreReadBeforeAssign) {
      if (variable.eslintUsed && variable.scope.type === "global") {
        return null;
      }
      let writer = null;
      let isReadBeforeInit = false;
      const references = variable.references;
      for (let i = 0; i < references.length; ++i) {
        const reference = references[i];
        if (reference.isWrite()) {
          const isReassigned = writer !== null && writer.identifier !== reference.identifier;
          if (isReassigned) {
            return null;
          }
          const destructuringHost = getDestructuringHost(reference);
          if (destructuringHost !== null && destructuringHost.left !== void 0) {
            const leftNode = destructuringHost.left;
            let hasOuterVariables = false, hasNonIdentifiers = false;
            if (leftNode.type === "ObjectPattern") {
              const properties = leftNode.properties;
              hasOuterVariables = properties.filter((prop) => prop.value).map((prop) => prop.value.name).some((name) => isOuterVariableInDestructing(name, variable.scope));
              hasNonIdentifiers = hasMemberExpressionAssignment(leftNode);
            } else if (leftNode.type === "ArrayPattern") {
              const elements = leftNode.elements;
              hasOuterVariables = elements.map((element) => element && element.name).some((name) => isOuterVariableInDestructing(name, variable.scope));
              hasNonIdentifiers = hasMemberExpressionAssignment(leftNode);
            }
            if (hasOuterVariables || hasNonIdentifiers) {
              return null;
            }
          }
          writer = reference;
        } else if (reference.isRead() && writer === null) {
          if (ignoreReadBeforeAssign) {
            return null;
          }
          isReadBeforeInit = true;
        }
      }
      const shouldBeConst = writer !== null && writer.from === variable.scope && canBecomeVariableDeclaration(writer.identifier);
      if (!shouldBeConst) {
        return null;
      }
      if (isReadBeforeInit) {
        return variable.defs[0].name;
      }
      return writer.identifier;
    }
    function groupByDestructuring(variables, ignoreReadBeforeAssign) {
      const identifierMap = /* @__PURE__ */ new Map();
      for (let i = 0; i < variables.length; ++i) {
        const variable = variables[i];
        const references = variable.references;
        const identifier3 = getIdentifierIfShouldBeConst(variable, ignoreReadBeforeAssign);
        let prevId = null;
        for (let j = 0; j < references.length; ++j) {
          const reference = references[j];
          const id = reference.identifier;
          if (id === prevId) {
            continue;
          }
          prevId = id;
          const group = getDestructuringHost(reference);
          if (group) {
            if (identifierMap.has(group)) {
              identifierMap.get(group).push(identifier3);
            } else {
              identifierMap.set(group, [identifier3]);
            }
          }
        }
      }
      return identifierMap;
    }
    function findUp(node, type, shouldStop) {
      if (!node || shouldStop(node)) {
        return null;
      }
      if (node.type === type) {
        return node;
      }
      return findUp(node.parent, type, shouldStop);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `const` declarations for variables that are never reassigned after declared",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-const"
        },
        fixable: "code",
        schema: [
          {
            type: "object",
            properties: {
              destructuring: { enum: ["any", "all"], default: "any" },
              ignoreReadBeforeAssign: { type: "boolean", default: false }
            },
            additionalProperties: false
          }
        ],
        messages: {
          useConst: "'{{name}}' is never reassigned. Use 'const' instead."
        }
      },
      create(context) {
        const options = context.options[0] || {};
        const sourceCode = context.getSourceCode();
        const shouldMatchAnyDestructuredVariable = options.destructuring !== "all";
        const ignoreReadBeforeAssign = options.ignoreReadBeforeAssign === true;
        const variables = [];
        let reportCount = 0;
        let checkedId = null;
        let checkedName = "";
        function checkGroup(nodes) {
          const nodesToReport = nodes.filter(Boolean);
          if (nodes.length && (shouldMatchAnyDestructuredVariable || nodesToReport.length === nodes.length)) {
            const varDeclParent = findUp(nodes[0], "VariableDeclaration", (parentNode) => parentNode.type.endsWith("Statement"));
            const isVarDecParentNull = varDeclParent === null;
            if (!isVarDecParentNull && varDeclParent.declarations.length > 0) {
              const firstDeclaration = varDeclParent.declarations[0];
              if (firstDeclaration.init) {
                const firstDecParent = firstDeclaration.init.parent;
                if (firstDecParent.type === "VariableDeclarator") {
                  if (firstDecParent.id.name !== checkedName) {
                    checkedName = firstDecParent.id.name;
                    reportCount = 0;
                  }
                  if (firstDecParent.id.type === "ObjectPattern") {
                    if (firstDecParent.init.name !== checkedName) {
                      checkedName = firstDecParent.init.name;
                      reportCount = 0;
                    }
                  }
                  if (firstDecParent.id !== checkedId) {
                    checkedId = firstDecParent.id;
                    reportCount = 0;
                  }
                }
              }
            }
            let shouldFix = varDeclParent && // Don't do a fix unless all variables in the declarations are initialized (or it's in a for-in or for-of loop)
            (varDeclParent.parent.type === "ForInStatement" || varDeclParent.parent.type === "ForOfStatement" || varDeclParent.declarations.every((declaration) => declaration.init)) && /*
             * If options.destructuring is "all", then this warning will not occur unless
             * every assignment in the destructuring should be const. In that case, it's safe
             * to apply the fix.
             */
            nodesToReport.length === nodes.length;
            if (!isVarDecParentNull && varDeclParent.declarations && varDeclParent.declarations.length !== 1) {
              if (varDeclParent && varDeclParent.declarations && varDeclParent.declarations.length >= 1) {
                reportCount += nodesToReport.length;
                let totalDeclarationsCount = 0;
                varDeclParent.declarations.forEach((declaration) => {
                  if (declaration.id.type === "ObjectPattern") {
                    totalDeclarationsCount += declaration.id.properties.length;
                  } else if (declaration.id.type === "ArrayPattern") {
                    totalDeclarationsCount += declaration.id.elements.length;
                  } else {
                    totalDeclarationsCount += 1;
                  }
                });
                shouldFix = shouldFix && reportCount === totalDeclarationsCount;
              }
            }
            nodesToReport.forEach((node) => {
              context.report({
                node,
                messageId: "useConst",
                data: node,
                fix: shouldFix ? (fixer) => {
                  const letKeywordToken = sourceCode.getFirstToken(varDeclParent, (t3) => t3.value === varDeclParent.kind);
                  return new FixTracker(fixer, sourceCode).retainRange(varDeclParent.range).replaceTextRange(letKeywordToken.range, "const");
                } : null
              });
            });
          }
        }
        return {
          "Program:exit"() {
            groupByDestructuring(variables, ignoreReadBeforeAssign).forEach(checkGroup);
          },
          VariableDeclaration(node) {
            if (node.kind === "let" && !isInitOfForStatement(node)) {
              variables.push(...context.getDeclaredVariables(node));
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-destructuring.js
var require_prefer_destructuring = __commonJS({
  "node_modules/eslint/lib/rules/prefer-destructuring.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var PRECEDENCE_OF_ASSIGNMENT_EXPR = astUtils.getPrecedence({ type: "AssignmentExpression" });
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require destructuring from arrays and/or objects",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-destructuring"
        },
        fixable: "code",
        schema: [
          {
            /*
             * old support {array: Boolean, object: Boolean}
             * new support {VariableDeclarator: {}, AssignmentExpression: {}}
             */
            oneOf: [
              {
                type: "object",
                properties: {
                  VariableDeclarator: {
                    type: "object",
                    properties: {
                      array: {
                        type: "boolean"
                      },
                      object: {
                        type: "boolean"
                      }
                    },
                    additionalProperties: false
                  },
                  AssignmentExpression: {
                    type: "object",
                    properties: {
                      array: {
                        type: "boolean"
                      },
                      object: {
                        type: "boolean"
                      }
                    },
                    additionalProperties: false
                  }
                },
                additionalProperties: false
              },
              {
                type: "object",
                properties: {
                  array: {
                    type: "boolean"
                  },
                  object: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ]
          },
          {
            type: "object",
            properties: {
              enforceForRenamedProperties: {
                type: "boolean"
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          preferDestructuring: "Use {{type}} destructuring."
        }
      },
      create(context) {
        const enabledTypes = context.options[0];
        const enforceForRenamedProperties = context.options[1] && context.options[1].enforceForRenamedProperties;
        let normalizedOptions = {
          VariableDeclarator: { array: true, object: true },
          AssignmentExpression: { array: true, object: true }
        };
        if (enabledTypes) {
          normalizedOptions = typeof enabledTypes.array !== "undefined" || typeof enabledTypes.object !== "undefined" ? { VariableDeclarator: enabledTypes, AssignmentExpression: enabledTypes } : enabledTypes;
        }
        function shouldCheck(nodeType, destructuringType) {
          return normalizedOptions && normalizedOptions[nodeType] && normalizedOptions[nodeType][destructuringType];
        }
        function isArrayIndexAccess(node) {
          return Number.isInteger(node.property.value);
        }
        function report(reportNode, type, fix) {
          context.report({
            node: reportNode,
            messageId: "preferDestructuring",
            data: { type },
            fix
          });
        }
        function shouldFix(node) {
          return node.type === "VariableDeclarator" && node.id.type === "Identifier" && node.init.type === "MemberExpression" && !node.init.computed && node.init.property.type === "Identifier" && node.id.name === node.init.property.name;
        }
        function fixIntoObjectDestructuring(fixer, node) {
          const rightNode = node.init;
          const sourceCode = context.getSourceCode();
          if (sourceCode.getCommentsInside(node).length > sourceCode.getCommentsInside(rightNode.object).length) {
            return null;
          }
          let objectText = sourceCode.getText(rightNode.object);
          if (astUtils.getPrecedence(rightNode.object) < PRECEDENCE_OF_ASSIGNMENT_EXPR) {
            objectText = `(${objectText})`;
          }
          return fixer.replaceText(
            node,
            `{${rightNode.property.name}} = ${objectText}`
          );
        }
        function performCheck(leftNode, rightNode, reportNode) {
          if (rightNode.type !== "MemberExpression" || rightNode.object.type === "Super" || rightNode.property.type === "PrivateIdentifier") {
            return;
          }
          if (isArrayIndexAccess(rightNode)) {
            if (shouldCheck(reportNode.type, "array")) {
              report(reportNode, "array", null);
            }
            return;
          }
          const fix = shouldFix(reportNode) ? (fixer) => fixIntoObjectDestructuring(fixer, reportNode) : null;
          if (shouldCheck(reportNode.type, "object") && enforceForRenamedProperties) {
            report(reportNode, "object", fix);
            return;
          }
          if (shouldCheck(reportNode.type, "object")) {
            const property = rightNode.property;
            if (property.type === "Literal" && leftNode.name === property.value || property.type === "Identifier" && leftNode.name === property.name && !rightNode.computed) {
              report(reportNode, "object", fix);
            }
          }
        }
        function checkVariableDeclarator(node) {
          if (!node.init) {
            return;
          }
          if (node.init.type !== "MemberExpression") {
            return;
          }
          performCheck(node.id, node.init, node);
        }
        function checkAssignmentExpression(node) {
          if (node.operator === "=") {
            performCheck(node.left, node.right, node);
          }
        }
        return {
          VariableDeclarator: checkVariableDeclarator,
          AssignmentExpression: checkAssignmentExpression
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-exponentiation-operator.js
var require_prefer_exponentiation_operator = __commonJS({
  "node_modules/eslint/lib/rules/prefer-exponentiation-operator.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { CALL, ReferenceTracker } = require_eslint_utils();
    var PRECEDENCE_OF_EXPONENTIATION_EXPR = astUtils.getPrecedence({ type: "BinaryExpression", operator: "**" });
    function doesBaseNeedParens(base) {
      return (
        // '**' is right-associative, parens are needed when Math.pow(a ** b, c) is converted to (a ** b) ** c
        astUtils.getPrecedence(base) <= PRECEDENCE_OF_EXPONENTIATION_EXPR || // An unary operator cannot be used immediately before an exponentiation expression
        base.type === "AwaitExpression" || base.type === "UnaryExpression"
      );
    }
    function doesExponentNeedParens(exponent) {
      return astUtils.getPrecedence(exponent) < PRECEDENCE_OF_EXPONENTIATION_EXPR;
    }
    function doesExponentiationExpressionNeedParens(node, sourceCode) {
      const parent = node.parent.type === "ChainExpression" ? node.parent.parent : node.parent;
      const needsParens = parent.type === "ClassDeclaration" || parent.type.endsWith("Expression") && astUtils.getPrecedence(parent) >= PRECEDENCE_OF_EXPONENTIATION_EXPR && !(parent.type === "BinaryExpression" && parent.operator === "**" && parent.right === node) && !((parent.type === "CallExpression" || parent.type === "NewExpression") && parent.arguments.includes(node)) && !(parent.type === "MemberExpression" && parent.computed && parent.property === node) && !(parent.type === "ArrayExpression");
      return needsParens && !astUtils.isParenthesised(sourceCode, node);
    }
    function parenthesizeIfShould(text, shouldParenthesize) {
      return shouldParenthesize ? `(${text})` : text;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow the use of `Math.pow` in favor of the `**` operator",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-exponentiation-operator"
        },
        schema: [],
        fixable: "code",
        messages: {
          useExponentiation: "Use the '**' operator instead of 'Math.pow'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function report(node) {
          context.report({
            node,
            messageId: "useExponentiation",
            fix(fixer) {
              if (node.arguments.length !== 2 || node.arguments.some((arg) => arg.type === "SpreadElement") || sourceCode.getCommentsInside(node).length > 0) {
                return null;
              }
              const base = node.arguments[0], exponent = node.arguments[1], baseText = sourceCode.getText(base), exponentText = sourceCode.getText(exponent), shouldParenthesizeBase = doesBaseNeedParens(base), shouldParenthesizeExponent = doesExponentNeedParens(exponent), shouldParenthesizeAll = doesExponentiationExpressionNeedParens(node, sourceCode);
              let prefix = "", suffix = "";
              if (!shouldParenthesizeAll) {
                if (!shouldParenthesizeBase) {
                  const firstReplacementToken = sourceCode.getFirstToken(base), tokenBefore = sourceCode.getTokenBefore(node);
                  if (tokenBefore && tokenBefore.range[1] === node.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, firstReplacementToken)) {
                    prefix = " ";
                  }
                }
                if (!shouldParenthesizeExponent) {
                  const lastReplacementToken = sourceCode.getLastToken(exponent), tokenAfter = sourceCode.getTokenAfter(node);
                  if (tokenAfter && node.range[1] === tokenAfter.range[0] && !astUtils.canTokensBeAdjacent(lastReplacementToken, tokenAfter)) {
                    suffix = " ";
                  }
                }
              }
              const baseReplacement = parenthesizeIfShould(baseText, shouldParenthesizeBase), exponentReplacement = parenthesizeIfShould(exponentText, shouldParenthesizeExponent), replacement = parenthesizeIfShould(`${baseReplacement}**${exponentReplacement}`, shouldParenthesizeAll);
              return fixer.replaceText(node, `${prefix}${replacement}${suffix}`);
            }
          });
        }
        return {
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const trackMap = {
              Math: {
                pow: { [CALL]: true }
              }
            };
            for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
              report(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-named-capture-group.js
var require_prefer_named_capture_group = __commonJS({
  "node_modules/eslint/lib/rules/prefer-named-capture-group.js"(exports, module2) {
    "use strict";
    var {
      CALL,
      CONSTRUCT,
      ReferenceTracker,
      getStringIfConstant
    } = require_eslint_utils();
    var regexpp = require_regexpp();
    var parser = new regexpp.RegExpParser();
    function suggestIfPossible(groupStart, pattern, rawText, regexNode) {
      switch (regexNode.type) {
        case "Literal":
          if (typeof regexNode.value === "string" && rawText.includes("\\")) {
            return null;
          }
          break;
        case "TemplateLiteral":
          if (regexNode.expressions.length || rawText.slice(1, -1) !== pattern) {
            return null;
          }
          break;
        default:
          return null;
      }
      const start = regexNode.range[0] + groupStart + 2;
      return [
        {
          fix(fixer) {
            const existingTemps = pattern.match(/temp\d+/gu) || [];
            const highestTempCount = existingTemps.reduce(
              (previous, next) => Math.max(previous, Number(next.slice("temp".length))),
              0
            );
            return fixer.insertTextBeforeRange(
              [start, start],
              `?<temp${highestTempCount + 1}>`
            );
          },
          messageId: "addGroupName"
        },
        {
          fix(fixer) {
            return fixer.insertTextBeforeRange(
              [start, start],
              "?:"
            );
          },
          messageId: "addNonCapture"
        }
      ];
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce using named capture group in regular expression",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-named-capture-group"
        },
        hasSuggestions: true,
        schema: [],
        messages: {
          addGroupName: "Add name to capture group.",
          addNonCapture: "Convert group to non-capturing.",
          required: "Capture group '{{group}}' should be converted to a named or non-capturing group."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        function checkRegex(pattern, node, regexNode, uFlag) {
          let ast;
          try {
            ast = parser.parsePattern(pattern, 0, pattern.length, uFlag);
          } catch {
            return;
          }
          regexpp.visitRegExpAST(ast, {
            onCapturingGroupEnter(group) {
              if (!group.name) {
                const rawText = sourceCode.getText(regexNode);
                const suggest = suggestIfPossible(group.start, pattern, rawText, regexNode);
                context.report({
                  node,
                  messageId: "required",
                  data: {
                    group: group.raw
                  },
                  suggest
                });
              }
            }
          });
        }
        return {
          Literal(node) {
            if (node.regex) {
              checkRegex(node.regex.pattern, node, node, node.regex.flags.includes("u"));
            }
          },
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const traceMap = {
              RegExp: {
                [CALL]: true,
                [CONSTRUCT]: true
              }
            };
            for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
              const regex = getStringIfConstant(node.arguments[0]);
              const flags = getStringIfConstant(node.arguments[1]);
              if (regex) {
                checkRegex(regex, node, node.arguments[0], flags && flags.includes("u"));
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-numeric-literals.js
var require_prefer_numeric_literals = __commonJS({
  "node_modules/eslint/lib/rules/prefer-numeric-literals.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var radixMap = /* @__PURE__ */ new Map([
      [2, { system: "binary", literalPrefix: "0b" }],
      [8, { system: "octal", literalPrefix: "0o" }],
      [16, { system: "hexadecimal", literalPrefix: "0x" }]
    ]);
    function isParseInt(calleeNode) {
      return astUtils.isSpecificId(calleeNode, "parseInt") || astUtils.isSpecificMemberAccess(calleeNode, "Number", "parseInt");
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow `parseInt()` and `Number.parseInt()` in favor of binary, octal, and hexadecimal literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-numeric-literals"
        },
        schema: [],
        messages: {
          useLiteral: "Use {{system}} literals instead of {{functionName}}()."
        },
        fixable: "code"
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          "CallExpression[arguments.length=2]"(node) {
            const [strNode, radixNode] = node.arguments, str = astUtils.getStaticStringValue(strNode), radix = radixNode.value;
            if (str !== null && astUtils.isStringLiteral(strNode) && radixNode.type === "Literal" && typeof radix === "number" && radixMap.has(radix) && isParseInt(node.callee)) {
              const { system, literalPrefix } = radixMap.get(radix);
              context.report({
                node,
                messageId: "useLiteral",
                data: {
                  system,
                  functionName: sourceCode.getText(node.callee)
                },
                fix(fixer) {
                  if (sourceCode.getCommentsInside(node).length) {
                    return null;
                  }
                  const replacement = `${literalPrefix}${str}`;
                  if (+replacement !== parseInt(str, radix)) {
                    return null;
                  }
                  const tokenBefore = sourceCode.getTokenBefore(node), tokenAfter = sourceCode.getTokenAfter(node);
                  let prefix = "", suffix = "";
                  if (tokenBefore && tokenBefore.range[1] === node.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, replacement)) {
                    prefix = " ";
                  }
                  if (tokenAfter && node.range[1] === tokenAfter.range[0] && !astUtils.canTokensBeAdjacent(replacement, tokenAfter)) {
                    suffix = " ";
                  }
                  return fixer.replaceText(node, `${prefix}${replacement}${suffix}`);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-object-has-own.js
var require_prefer_object_has_own = __commonJS({
  "node_modules/eslint/lib/rules/prefer-object-has-own.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function hasLeftHandObject(node) {
      if (node.object.type === "ObjectExpression" && node.object.properties.length === 0) {
        return true;
      }
      const objectNodeToCheck = node.object.type === "MemberExpression" && astUtils.getStaticPropertyName(node.object) === "prototype" ? node.object.object : node.object;
      if (objectNodeToCheck.type === "Identifier" && objectNodeToCheck.name === "Object") {
        return true;
      }
      return false;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow use of `Object.prototype.hasOwnProperty.call()` and prefer use of `Object.hasOwn()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-object-has-own"
        },
        schema: [],
        messages: {
          useHasOwn: "Use 'Object.hasOwn()' instead of 'Object.prototype.hasOwnProperty.call()'."
        },
        fixable: "code"
      },
      create(context) {
        return {
          CallExpression(node) {
            if (!(node.callee.type === "MemberExpression" && node.callee.object.type === "MemberExpression")) {
              return;
            }
            const calleePropertyName = astUtils.getStaticPropertyName(node.callee);
            const objectPropertyName = astUtils.getStaticPropertyName(node.callee.object);
            const isObject = hasLeftHandObject(node.callee.object);
            const scope = context.getScope();
            const variable = astUtils.getVariableByName(scope, "Object");
            if (calleePropertyName === "call" && objectPropertyName === "hasOwnProperty" && isObject && variable && variable.scope.type === "global") {
              context.report({
                node,
                messageId: "useHasOwn",
                fix(fixer) {
                  const sourceCode = context.getSourceCode();
                  if (sourceCode.getCommentsInside(node.callee).length > 0) {
                    return null;
                  }
                  const tokenJustBeforeNode = sourceCode.getTokenBefore(node.callee, { includeComments: true });
                  if (tokenJustBeforeNode && tokenJustBeforeNode.range[1] === node.callee.range[0] && !astUtils.canTokensBeAdjacent(tokenJustBeforeNode, "Object.hasOwn")) {
                    return fixer.replaceText(node.callee, " Object.hasOwn");
                  }
                  return fixer.replaceText(node.callee, "Object.hasOwn");
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-object-spread.js
var require_prefer_object_spread = __commonJS({
  "node_modules/eslint/lib/rules/prefer-object-spread.js"(exports, module2) {
    "use strict";
    var { CALL, ReferenceTracker } = require_eslint_utils();
    var {
      isCommaToken,
      isOpeningParenToken,
      isClosingParenToken,
      isParenthesised
    } = require_ast_utils2();
    var ANY_SPACE = /\s/u;
    function hasArraySpread(node) {
      return node.arguments.some((arg) => arg.type === "SpreadElement");
    }
    function isAccessorProperty(node) {
      return node.type === "Property" && (node.kind === "get" || node.kind === "set");
    }
    function hasAccessors(node) {
      return node.properties.some(isAccessorProperty);
    }
    function hasArgumentsWithAccessors(node) {
      return node.arguments.filter((arg) => arg.type === "ObjectExpression").some(hasAccessors);
    }
    function needsParens(node, sourceCode) {
      const parent = node.parent;
      switch (parent.type) {
        case "VariableDeclarator":
        case "ArrayExpression":
        case "ReturnStatement":
        case "CallExpression":
        case "Property":
          return false;
        case "AssignmentExpression":
          return parent.left === node && !isParenthesised(sourceCode, node);
        default:
          return !isParenthesised(sourceCode, node);
      }
    }
    function argNeedsParens(node, sourceCode) {
      switch (node.type) {
        case "AssignmentExpression":
        case "ArrowFunctionExpression":
        case "ConditionalExpression":
          return !isParenthesised(sourceCode, node);
        default:
          return false;
      }
    }
    function getParenTokens(node, leftArgumentListParen, sourceCode) {
      const parens = [sourceCode.getFirstToken(node), sourceCode.getLastToken(node)];
      let leftNext = sourceCode.getTokenBefore(node);
      let rightNext = sourceCode.getTokenAfter(node);
      while (leftNext && rightNext && leftNext.range[0] > leftArgumentListParen.range[0] && isOpeningParenToken(leftNext) && isClosingParenToken(rightNext)) {
        parens.push(leftNext, rightNext);
        leftNext = sourceCode.getTokenBefore(leftNext);
        rightNext = sourceCode.getTokenAfter(rightNext);
      }
      return parens.sort((a, b) => a.range[0] - b.range[0]);
    }
    function getStartWithSpaces(token, sourceCode) {
      const text = sourceCode.text;
      let start = token.range[0];
      {
        const prevToken = sourceCode.getTokenBefore(token, { includeComments: true });
        if (prevToken && prevToken.type === "Line") {
          return start;
        }
      }
      while (ANY_SPACE.test(text[start - 1] || "")) {
        start -= 1;
      }
      return start;
    }
    function getEndWithSpaces(token, sourceCode) {
      const text = sourceCode.text;
      let end = token.range[1];
      while (ANY_SPACE.test(text[end] || "")) {
        end += 1;
      }
      return end;
    }
    function defineFixer(node, sourceCode) {
      return function* (fixer) {
        const leftParen = sourceCode.getTokenAfter(node.callee, isOpeningParenToken);
        const rightParen = sourceCode.getLastToken(node);
        yield fixer.removeRange([node.range[0], leftParen.range[0]]);
        if (needsParens(node, sourceCode)) {
          yield fixer.replaceText(leftParen, "({");
          yield fixer.replaceText(rightParen, "})");
        } else {
          yield fixer.replaceText(leftParen, "{");
          yield fixer.replaceText(rightParen, "}");
        }
        for (const argNode of node.arguments) {
          const innerParens = getParenTokens(argNode, leftParen, sourceCode);
          const left = innerParens.shift();
          const right = innerParens.pop();
          if (argNode.type === "ObjectExpression") {
            const maybeTrailingComma = sourceCode.getLastToken(argNode, 1);
            const maybeArgumentComma = sourceCode.getTokenAfter(right);
            for (const innerParen of innerParens) {
              yield fixer.remove(innerParen);
            }
            const leftRange = [left.range[0], getEndWithSpaces(left, sourceCode)];
            const rightRange = [
              Math.max(getStartWithSpaces(right, sourceCode), leftRange[1]),
              // Ensure ranges don't overlap
              right.range[1]
            ];
            yield fixer.removeRange(leftRange);
            yield fixer.removeRange(rightRange);
            if ((argNode.properties.length === 0 || isCommaToken(maybeTrailingComma)) && isCommaToken(maybeArgumentComma)) {
              yield fixer.remove(maybeArgumentComma);
            }
          } else {
            if (argNeedsParens(argNode, sourceCode)) {
              yield fixer.insertTextBefore(left, "...(");
              yield fixer.insertTextAfter(right, ")");
            } else {
              yield fixer.insertTextBefore(left, "...");
            }
          }
        }
      };
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow using Object.assign with an object literal as the first argument and prefer the use of object spread instead",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-object-spread"
        },
        schema: [],
        fixable: "code",
        messages: {
          useSpreadMessage: "Use an object spread instead of `Object.assign` eg: `{ ...foo }`.",
          useLiteralMessage: "Use an object literal instead of `Object.assign`. eg: `{ foo: bar }`."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const trackMap = {
              Object: {
                assign: { [CALL]: true }
              }
            };
            for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
              if (node.arguments.length >= 1 && node.arguments[0].type === "ObjectExpression" && !hasArraySpread(node) && !(node.arguments.length > 1 && hasArgumentsWithAccessors(node))) {
                const messageId = node.arguments.length === 1 ? "useLiteralMessage" : "useSpreadMessage";
                const fix = defineFixer(node, sourceCode);
                context.report({ node, messageId, fix });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-promise-reject-errors.js
var require_prefer_promise_reject_errors = __commonJS({
  "node_modules/eslint/lib/rules/prefer-promise-reject-errors.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require using Error objects as Promise rejection reasons",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-promise-reject-errors"
        },
        fixable: null,
        schema: [
          {
            type: "object",
            properties: {
              allowEmptyReject: { type: "boolean", default: false }
            },
            additionalProperties: false
          }
        ],
        messages: {
          rejectAnError: "Expected the Promise rejection reason to be an Error."
        }
      },
      create(context) {
        const ALLOW_EMPTY_REJECT = context.options.length && context.options[0].allowEmptyReject;
        function checkRejectCall(callExpression3) {
          if (!callExpression3.arguments.length && ALLOW_EMPTY_REJECT) {
            return;
          }
          if (!callExpression3.arguments.length || !astUtils.couldBeError(callExpression3.arguments[0]) || callExpression3.arguments[0].type === "Identifier" && callExpression3.arguments[0].name === "undefined") {
            context.report({
              node: callExpression3,
              messageId: "rejectAnError"
            });
          }
        }
        function isPromiseRejectCall(node) {
          return astUtils.isSpecificMemberAccess(node.callee, "Promise", "reject");
        }
        return {
          // Check `Promise.reject(value)` calls.
          CallExpression(node) {
            if (isPromiseRejectCall(node)) {
              checkRejectCall(node);
            }
          },
          /*
           * Check for `new Promise((resolve, reject) => {})`, and check for reject() calls.
           * This function is run on "NewExpression:exit" instead of "NewExpression" to ensure that
           * the nodes in the expression already have the `parent` property.
           */
          "NewExpression:exit"(node) {
            if (node.callee.type === "Identifier" && node.callee.name === "Promise" && node.arguments.length && astUtils.isFunction(node.arguments[0]) && node.arguments[0].params.length > 1 && node.arguments[0].params[1].type === "Identifier") {
              context.getDeclaredVariables(node.arguments[0]).find((variable) => variable.name === node.arguments[0].params[1].name).references.filter((ref) => ref.isRead()).filter((ref) => ref.identifier.parent.type === "CallExpression" && ref.identifier === ref.identifier.parent.callee).forEach((ref) => checkRejectCall(ref.identifier.parent));
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-reflect.js
var require_prefer_reflect = __commonJS({
  "node_modules/eslint/lib/rules/prefer-reflect.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `Reflect` methods where applicable",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-reflect"
        },
        deprecated: true,
        replacedBy: [],
        schema: [
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: {
                  enum: [
                    "apply",
                    "call",
                    "delete",
                    "defineProperty",
                    "getOwnPropertyDescriptor",
                    "getPrototypeOf",
                    "setPrototypeOf",
                    "isExtensible",
                    "getOwnPropertyNames",
                    "preventExtensions"
                  ]
                },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          preferReflect: "Avoid using {{existing}}, instead use {{substitute}}."
        }
      },
      create(context) {
        const existingNames = {
          apply: "Function.prototype.apply",
          call: "Function.prototype.call",
          defineProperty: "Object.defineProperty",
          getOwnPropertyDescriptor: "Object.getOwnPropertyDescriptor",
          getPrototypeOf: "Object.getPrototypeOf",
          setPrototypeOf: "Object.setPrototypeOf",
          isExtensible: "Object.isExtensible",
          getOwnPropertyNames: "Object.getOwnPropertyNames",
          preventExtensions: "Object.preventExtensions"
        };
        const reflectSubstitutes = {
          apply: "Reflect.apply",
          call: "Reflect.apply",
          defineProperty: "Reflect.defineProperty",
          getOwnPropertyDescriptor: "Reflect.getOwnPropertyDescriptor",
          getPrototypeOf: "Reflect.getPrototypeOf",
          setPrototypeOf: "Reflect.setPrototypeOf",
          isExtensible: "Reflect.isExtensible",
          getOwnPropertyNames: "Reflect.getOwnPropertyNames",
          preventExtensions: "Reflect.preventExtensions"
        };
        const exceptions = (context.options[0] || {}).exceptions || [];
        function report(node, existing, substitute) {
          context.report({
            node,
            messageId: "preferReflect",
            data: {
              existing,
              substitute
            }
          });
        }
        return {
          CallExpression(node) {
            const methodName = (node.callee.property || {}).name;
            const isReflectCall = (node.callee.object || {}).name === "Reflect";
            const hasReflectSubstitute = Object.prototype.hasOwnProperty.call(reflectSubstitutes, methodName);
            const userConfiguredException = exceptions.includes(methodName);
            if (hasReflectSubstitute && !isReflectCall && !userConfiguredException) {
              report(node, existingNames[methodName], reflectSubstitutes[methodName]);
            }
          },
          UnaryExpression(node) {
            const isDeleteOperator = node.operator === "delete";
            const targetsIdentifier = node.argument.type === "Identifier";
            const userConfiguredException = exceptions.includes("delete");
            if (isDeleteOperator && !targetsIdentifier && !userConfiguredException) {
              report(node, "the delete keyword", "Reflect.deleteProperty");
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-regex-literals.js
var require_prefer_regex_literals = __commonJS({
  "node_modules/eslint/lib/rules/prefer-regex-literals.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var { CALL, CONSTRUCT, ReferenceTracker, findVariable } = require_eslint_utils();
    var { RegExpValidator, visitRegExpAST, RegExpParser } = require_regexpp();
    var { canTokensBeAdjacent } = require_ast_utils2();
    var REGEXPP_LATEST_ECMA_VERSION = 2022;
    function isStringLiteral3(node) {
      return node.type === "Literal" && typeof node.value === "string";
    }
    function isRegexLiteral(node) {
      return node.type === "Literal" && Object.prototype.hasOwnProperty.call(node, "regex");
    }
    function isStaticTemplateLiteral(node) {
      return node.type === "TemplateLiteral" && node.expressions.length === 0;
    }
    var validPrecedingTokens = /* @__PURE__ */ new Set([
      "(",
      ";",
      "[",
      ",",
      "=",
      "+",
      "*",
      "-",
      "?",
      "~",
      "%",
      "**",
      "!",
      "typeof",
      "instanceof",
      "&&",
      "||",
      "??",
      "return",
      "...",
      "delete",
      "void",
      "in",
      "<",
      ">",
      "<=",
      ">=",
      "==",
      "===",
      "!=",
      "!==",
      "<<",
      ">>",
      ">>>",
      "&",
      "|",
      "^",
      ":",
      "{",
      "=>",
      "*=",
      "<<=",
      ">>=",
      ">>>=",
      "^=",
      "|=",
      "&=",
      "??=",
      "||=",
      "&&=",
      "**=",
      "+=",
      "-=",
      "/=",
      "%=",
      "/",
      "do",
      "break",
      "continue",
      "debugger",
      "case",
      "throw"
    ]);
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow use of the `RegExp` constructor in favor of regular expression literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-regex-literals"
        },
        hasSuggestions: true,
        schema: [
          {
            type: "object",
            properties: {
              disallowRedundantWrapping: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedRegExp: "Use a regular expression literal instead of the 'RegExp' constructor.",
          replaceWithLiteral: "Replace with an equivalent regular expression literal.",
          unexpectedRedundantRegExp: "Regular expression literal is unnecessarily wrapped within a 'RegExp' constructor.",
          unexpectedRedundantRegExpWithFlags: "Use regular expression literal with flags instead of the 'RegExp' constructor."
        }
      },
      create(context) {
        const [{ disallowRedundantWrapping = false } = {}] = context.options;
        const sourceCode = context.getSourceCode();
        function isGlobalReference(node) {
          const scope = context.getScope();
          const variable = findVariable(scope, node);
          return variable !== null && variable.scope.type === "global" && variable.defs.length === 0;
        }
        function isStringRawTaggedStaticTemplateLiteral(node) {
          return node.type === "TaggedTemplateExpression" && astUtils.isSpecificMemberAccess(node.tag, "String", "raw") && isGlobalReference(astUtils.skipChainExpression(node.tag).object) && isStaticTemplateLiteral(node.quasi);
        }
        function getStringValue(node) {
          if (isStringLiteral3(node)) {
            return node.value;
          }
          if (isStaticTemplateLiteral(node)) {
            return node.quasis[0].value.cooked;
          }
          if (isStringRawTaggedStaticTemplateLiteral(node)) {
            return node.quasi.quasis[0].value.raw;
          }
          return null;
        }
        function isStaticString(node) {
          return isStringLiteral3(node) || isStaticTemplateLiteral(node) || isStringRawTaggedStaticTemplateLiteral(node);
        }
        function hasOnlyStaticStringArguments(node) {
          const args = node.arguments;
          if ((args.length === 1 || args.length === 2) && args.every(isStaticString)) {
            return true;
          }
          return false;
        }
        function isUnnecessarilyWrappedRegexLiteral(node) {
          const args = node.arguments;
          if (args.length === 1 && isRegexLiteral(args[0])) {
            return true;
          }
          if (args.length === 2 && isRegexLiteral(args[0]) && isStaticString(args[1])) {
            return true;
          }
          return false;
        }
        function getRegexppEcmaVersion(ecmaVersion) {
          if (ecmaVersion <= 5) {
            return 5;
          }
          return Math.min(ecmaVersion, REGEXPP_LATEST_ECMA_VERSION);
        }
        function resolveEscapes(character) {
          switch (character) {
            case "\n":
            case "\\\n":
              return "\\n";
            case "\r":
            case "\\\r":
              return "\\r";
            case "	":
            case "\\	":
              return "\\t";
            case "\v":
            case "\\\v":
              return "\\v";
            case "\f":
            case "\\\f":
              return "\\f";
            case "/":
              return "\\/";
            default:
              return null;
          }
        }
        return {
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const traceMap = {
              RegExp: {
                [CALL]: true,
                [CONSTRUCT]: true
              }
            };
            for (const { node } of tracker.iterateGlobalReferences(traceMap)) {
              if (disallowRedundantWrapping && isUnnecessarilyWrappedRegexLiteral(node)) {
                if (node.arguments.length === 2) {
                  context.report({ node, messageId: "unexpectedRedundantRegExpWithFlags" });
                } else {
                  context.report({ node, messageId: "unexpectedRedundantRegExp" });
                }
              } else if (hasOnlyStaticStringArguments(node)) {
                let regexContent = getStringValue(node.arguments[0]);
                let noFix = false;
                let flags;
                if (node.arguments[1]) {
                  flags = getStringValue(node.arguments[1]);
                }
                const regexppEcmaVersion = getRegexppEcmaVersion(context.languageOptions.ecmaVersion);
                const RegExpValidatorInstance = new RegExpValidator({ ecmaVersion: regexppEcmaVersion });
                try {
                  RegExpValidatorInstance.validatePattern(regexContent, 0, regexContent.length, flags ? flags.includes("u") : false);
                  if (flags) {
                    RegExpValidatorInstance.validateFlags(flags);
                  }
                } catch {
                  noFix = true;
                }
                const tokenBefore = sourceCode.getTokenBefore(node);
                if (tokenBefore && !validPrecedingTokens.has(tokenBefore.value)) {
                  noFix = true;
                }
                if (!/^[-a-zA-Z0-9\\[\](){} \t\r\n\v\f!@#$%^&*+^_=/~`.><?,'"|:;]*$/u.test(regexContent)) {
                  noFix = true;
                }
                if (sourceCode.getCommentsInside(node).length > 0) {
                  noFix = true;
                }
                if (regexContent && !noFix) {
                  let charIncrease = 0;
                  const ast = new RegExpParser({ ecmaVersion: regexppEcmaVersion }).parsePattern(regexContent, 0, regexContent.length, flags ? flags.includes("u") : false);
                  visitRegExpAST(ast, {
                    onCharacterEnter(characterNode) {
                      const escaped = resolveEscapes(characterNode.raw);
                      if (escaped) {
                        regexContent = regexContent.slice(0, characterNode.start + charIncrease) + escaped + regexContent.slice(characterNode.end + charIncrease);
                        if (characterNode.raw.length === 1) {
                          charIncrease += 1;
                        }
                      }
                    }
                  });
                }
                const newRegExpValue = `/${regexContent || "(?:)"}/${flags || ""}`;
                context.report({
                  node,
                  messageId: "unexpectedRegExp",
                  suggest: noFix ? [] : [{
                    messageId: "replaceWithLiteral",
                    fix(fixer) {
                      const tokenAfter = sourceCode.getTokenAfter(node);
                      return fixer.replaceText(
                        node,
                        (tokenBefore && !canTokensBeAdjacent(tokenBefore, newRegExpValue) && tokenBefore.range[1] === node.range[0] ? " " : "") + newRegExpValue + (tokenAfter && !canTokensBeAdjacent(newRegExpValue, tokenAfter) && node.range[1] === tokenAfter.range[0] ? " " : "")
                      );
                    }
                  }]
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-rest-params.js
var require_prefer_rest_params = __commonJS({
  "node_modules/eslint/lib/rules/prefer-rest-params.js"(exports, module2) {
    "use strict";
    function getVariableOfArguments(scope) {
      const variables = scope.variables;
      for (let i = 0; i < variables.length; ++i) {
        const variable = variables[i];
        if (variable.name === "arguments") {
          return variable.identifiers.length === 0 ? variable : null;
        }
      }
      return null;
    }
    function isNotNormalMemberAccess(reference) {
      const id = reference.identifier;
      const parent = id.parent;
      return !(parent.type === "MemberExpression" && parent.object === id && !parent.computed);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require rest parameters instead of `arguments`",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-rest-params"
        },
        schema: [],
        messages: {
          preferRestParams: "Use the rest parameters instead of 'arguments'."
        }
      },
      create(context) {
        function report(reference) {
          context.report({
            node: reference.identifier,
            loc: reference.identifier.loc,
            messageId: "preferRestParams"
          });
        }
        function checkForArguments() {
          const argumentsVar = getVariableOfArguments(context.getScope());
          if (argumentsVar) {
            argumentsVar.references.filter(isNotNormalMemberAccess).forEach(report);
          }
        }
        return {
          "FunctionDeclaration:exit": checkForArguments,
          "FunctionExpression:exit": checkForArguments
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-spread.js
var require_prefer_spread = __commonJS({
  "node_modules/eslint/lib/rules/prefer-spread.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isVariadicApplyCalling(node) {
      return astUtils.isSpecificMemberAccess(node.callee, null, "apply") && node.arguments.length === 2 && node.arguments[1].type !== "ArrayExpression" && node.arguments[1].type !== "SpreadElement";
    }
    function isValidThisArg(expectedThis, thisArg, context) {
      if (!expectedThis) {
        return astUtils.isNullOrUndefined(thisArg);
      }
      return astUtils.equalTokens(expectedThis, thisArg, context);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require spread operators instead of `.apply()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-spread"
        },
        schema: [],
        fixable: null,
        messages: {
          preferSpread: "Use the spread operator instead of '.apply()'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          CallExpression(node) {
            if (!isVariadicApplyCalling(node)) {
              return;
            }
            const applied = astUtils.skipChainExpression(astUtils.skipChainExpression(node.callee).object);
            const expectedThis = applied.type === "MemberExpression" ? applied.object : null;
            const thisArg = node.arguments[0];
            if (isValidThisArg(expectedThis, thisArg, sourceCode)) {
              context.report({
                node,
                messageId: "preferSpread"
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/prefer-template.js
var require_prefer_template = __commonJS({
  "node_modules/eslint/lib/rules/prefer-template.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isConcatenation(node) {
      return node.type === "BinaryExpression" && node.operator === "+";
    }
    function getTopConcatBinaryExpression(node) {
      let currentNode = node;
      while (isConcatenation(currentNode.parent)) {
        currentNode = currentNode.parent;
      }
      return currentNode;
    }
    function hasOctalOrNonOctalDecimalEscapeSequence(node) {
      if (isConcatenation(node)) {
        return hasOctalOrNonOctalDecimalEscapeSequence(node.left) || hasOctalOrNonOctalDecimalEscapeSequence(node.right);
      }
      if (node.type === "Literal" && typeof node.value === "string") {
        return astUtils.hasOctalOrNonOctalDecimalEscapeSequence(node.raw);
      }
      return false;
    }
    function hasStringLiteral(node) {
      if (isConcatenation(node)) {
        return hasStringLiteral(node.right) || hasStringLiteral(node.left);
      }
      return astUtils.isStringLiteral(node);
    }
    function hasNonStringLiteral(node) {
      if (isConcatenation(node)) {
        return hasNonStringLiteral(node.right) || hasNonStringLiteral(node.left);
      }
      return !astUtils.isStringLiteral(node);
    }
    function startsWithTemplateCurly(node) {
      if (node.type === "BinaryExpression") {
        return startsWithTemplateCurly(node.left);
      }
      if (node.type === "TemplateLiteral") {
        return node.expressions.length && node.quasis.length && node.quasis[0].range[0] === node.quasis[0].range[1];
      }
      return node.type !== "Literal" || typeof node.value !== "string";
    }
    function endsWithTemplateCurly(node) {
      if (node.type === "BinaryExpression") {
        return startsWithTemplateCurly(node.right);
      }
      if (node.type === "TemplateLiteral") {
        return node.expressions.length && node.quasis.length && node.quasis[node.quasis.length - 1].range[0] === node.quasis[node.quasis.length - 1].range[1];
      }
      return node.type !== "Literal" || typeof node.value !== "string";
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require template literals instead of string concatenation",
          recommended: false,
          url: "https://eslint.org/docs/rules/prefer-template"
        },
        schema: [],
        fixable: "code",
        messages: {
          unexpectedStringConcatenation: "Unexpected string concatenation."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let done = /* @__PURE__ */ Object.create(null);
        function getTextBetween(node1, node2) {
          const allTokens = [node1].concat(sourceCode.getTokensBetween(node1, node2)).concat(node2);
          const sourceText = sourceCode.getText();
          return allTokens.slice(0, -1).reduce((accumulator, token, index) => accumulator + sourceText.slice(token.range[1], allTokens[index + 1].range[0]), "");
        }
        function getTemplateLiteral(currentNode, textBeforeNode, textAfterNode) {
          if (currentNode.type === "Literal" && typeof currentNode.value === "string") {
            return `\`${currentNode.raw.slice(1, -1).replace(/\\*(\$\{|`)/gu, (matched) => {
              if (matched.lastIndexOf("\\") % 2) {
                return `\\${matched}`;
              }
              return matched;
            }).replace(new RegExp(`\\\\${currentNode.raw[0]}`, "gu"), currentNode.raw[0])}\``;
          }
          if (currentNode.type === "TemplateLiteral") {
            return sourceCode.getText(currentNode);
          }
          if (isConcatenation(currentNode) && hasStringLiteral(currentNode)) {
            const plusSign = sourceCode.getFirstTokenBetween(currentNode.left, currentNode.right, (token) => token.value === "+");
            const textBeforePlus = getTextBetween(currentNode.left, plusSign);
            const textAfterPlus = getTextBetween(plusSign, currentNode.right);
            const leftEndsWithCurly = endsWithTemplateCurly(currentNode.left);
            const rightStartsWithCurly = startsWithTemplateCurly(currentNode.right);
            if (leftEndsWithCurly) {
              return getTemplateLiteral(currentNode.left, textBeforeNode, textBeforePlus + textAfterPlus).slice(0, -1) + getTemplateLiteral(currentNode.right, null, textAfterNode).slice(1);
            }
            if (rightStartsWithCurly) {
              return getTemplateLiteral(currentNode.left, textBeforeNode, null).slice(0, -1) + getTemplateLiteral(currentNode.right, textBeforePlus + textAfterPlus, textAfterNode).slice(1);
            }
            return `${getTemplateLiteral(currentNode.left, textBeforeNode, null)}${textBeforePlus}+${textAfterPlus}${getTemplateLiteral(currentNode.right, textAfterNode, null)}`;
          }
          return `\`\${${textBeforeNode || ""}${sourceCode.getText(currentNode)}${textAfterNode || ""}}\``;
        }
        function fixNonStringBinaryExpression(fixer, node) {
          const topBinaryExpr = getTopConcatBinaryExpression(node.parent);
          if (hasOctalOrNonOctalDecimalEscapeSequence(topBinaryExpr)) {
            return null;
          }
          return fixer.replaceText(topBinaryExpr, getTemplateLiteral(topBinaryExpr, null, null));
        }
        function checkForStringConcat(node) {
          if (!astUtils.isStringLiteral(node) || !isConcatenation(node.parent)) {
            return;
          }
          const topBinaryExpr = getTopConcatBinaryExpression(node.parent);
          if (done[topBinaryExpr.range[0]]) {
            return;
          }
          done[topBinaryExpr.range[0]] = true;
          if (hasNonStringLiteral(topBinaryExpr)) {
            context.report({
              node: topBinaryExpr,
              messageId: "unexpectedStringConcatenation",
              fix: (fixer) => fixNonStringBinaryExpression(fixer, node)
            });
          }
        }
        return {
          Program() {
            done = /* @__PURE__ */ Object.create(null);
          },
          Literal: checkForStringConcat,
          TemplateLiteral: checkForStringConcat
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/quote-props.js
var require_quote_props = __commonJS({
  "node_modules/eslint/lib/rules/quote-props.js"(exports, module2) {
    "use strict";
    var espree = require("espree");
    var astUtils = require_ast_utils2();
    var keywords = require_keywords();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require quotes around object literal property names",
          recommended: false,
          url: "https://eslint.org/docs/rules/quote-props"
        },
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["always", "as-needed", "consistent", "consistent-as-needed"]
                }
              ],
              minItems: 0,
              maxItems: 1
            },
            {
              type: "array",
              items: [
                {
                  enum: ["always", "as-needed", "consistent", "consistent-as-needed"]
                },
                {
                  type: "object",
                  properties: {
                    keywords: {
                      type: "boolean"
                    },
                    unnecessary: {
                      type: "boolean"
                    },
                    numbers: {
                      type: "boolean"
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        fixable: "code",
        messages: {
          requireQuotesDueToReservedWord: "Properties should be quoted as '{{property}}' is a reserved word.",
          inconsistentlyQuotedProperty: "Inconsistently quoted property '{{key}}' found.",
          unnecessarilyQuotedProperty: "Unnecessarily quoted property '{{property}}' found.",
          unquotedReservedProperty: "Unquoted reserved word '{{property}}' used as key.",
          unquotedNumericProperty: "Unquoted number literal '{{property}}' used as key.",
          unquotedPropertyFound: "Unquoted property '{{property}}' found.",
          redundantQuoting: "Properties shouldn't be quoted as all quotes are redundant."
        }
      },
      create(context) {
        const MODE = context.options[0], KEYWORDS = context.options[1] && context.options[1].keywords, CHECK_UNNECESSARY = !context.options[1] || context.options[1].unnecessary !== false, NUMBERS = context.options[1] && context.options[1].numbers, sourceCode = context.getSourceCode();
        function isKeyword(tokenStr) {
          return keywords.includes(tokenStr);
        }
        function areQuotesRedundant(rawKey, tokens, skipNumberLiterals) {
          return tokens.length === 1 && tokens[0].start === 0 && tokens[0].end === rawKey.length && (["Identifier", "Keyword", "Null", "Boolean"].includes(tokens[0].type) || tokens[0].type === "Numeric" && !skipNumberLiterals && String(+tokens[0].value) === tokens[0].value);
        }
        function getUnquotedKey(key) {
          return key.type === "Identifier" ? key.name : key.value;
        }
        function getQuotedKey(key) {
          if (key.type === "Literal" && typeof key.value === "string") {
            return sourceCode.getText(key);
          }
          return `"${key.type === "Identifier" ? key.name : key.value}"`;
        }
        function checkUnnecessaryQuotes(node) {
          const key = node.key;
          if (node.method || node.computed || node.shorthand) {
            return;
          }
          if (key.type === "Literal" && typeof key.value === "string") {
            let tokens;
            try {
              tokens = espree.tokenize(key.value);
            } catch {
              return;
            }
            if (tokens.length !== 1) {
              return;
            }
            const isKeywordToken = isKeyword(tokens[0].value);
            if (isKeywordToken && KEYWORDS) {
              return;
            }
            if (CHECK_UNNECESSARY && areQuotesRedundant(key.value, tokens, NUMBERS)) {
              context.report({
                node,
                messageId: "unnecessarilyQuotedProperty",
                data: { property: key.value },
                fix: (fixer) => fixer.replaceText(key, getUnquotedKey(key))
              });
            }
          } else if (KEYWORDS && key.type === "Identifier" && isKeyword(key.name)) {
            context.report({
              node,
              messageId: "unquotedReservedProperty",
              data: { property: key.name },
              fix: (fixer) => fixer.replaceText(key, getQuotedKey(key))
            });
          } else if (NUMBERS && key.type === "Literal" && astUtils.isNumericLiteral(key)) {
            context.report({
              node,
              messageId: "unquotedNumericProperty",
              data: { property: key.value },
              fix: (fixer) => fixer.replaceText(key, getQuotedKey(key))
            });
          }
        }
        function checkOmittedQuotes(node) {
          const key = node.key;
          if (!node.method && !node.computed && !node.shorthand && !(key.type === "Literal" && typeof key.value === "string")) {
            context.report({
              node,
              messageId: "unquotedPropertyFound",
              data: { property: key.name || key.value },
              fix: (fixer) => fixer.replaceText(key, getQuotedKey(key))
            });
          }
        }
        function checkConsistency(node, checkQuotesRedundancy) {
          const quotedProps = [], unquotedProps = [];
          let keywordKeyName = null, necessaryQuotes = false;
          node.properties.forEach((property) => {
            const key = property.key;
            if (!key || property.method || property.computed || property.shorthand) {
              return;
            }
            if (key.type === "Literal" && typeof key.value === "string") {
              quotedProps.push(property);
              if (checkQuotesRedundancy) {
                let tokens;
                try {
                  tokens = espree.tokenize(key.value);
                } catch {
                  necessaryQuotes = true;
                  return;
                }
                necessaryQuotes = necessaryQuotes || !areQuotesRedundant(key.value, tokens) || KEYWORDS && isKeyword(tokens[0].value);
              }
            } else if (KEYWORDS && checkQuotesRedundancy && key.type === "Identifier" && isKeyword(key.name)) {
              unquotedProps.push(property);
              necessaryQuotes = true;
              keywordKeyName = key.name;
            } else {
              unquotedProps.push(property);
            }
          });
          if (checkQuotesRedundancy && quotedProps.length && !necessaryQuotes) {
            quotedProps.forEach((property) => {
              context.report({
                node: property,
                messageId: "redundantQuoting",
                fix: (fixer) => fixer.replaceText(property.key, getUnquotedKey(property.key))
              });
            });
          } else if (unquotedProps.length && keywordKeyName) {
            unquotedProps.forEach((property) => {
              context.report({
                node: property,
                messageId: "requireQuotesDueToReservedWord",
                data: { property: keywordKeyName },
                fix: (fixer) => fixer.replaceText(property.key, getQuotedKey(property.key))
              });
            });
          } else if (quotedProps.length && unquotedProps.length) {
            unquotedProps.forEach((property) => {
              context.report({
                node: property,
                messageId: "inconsistentlyQuotedProperty",
                data: { key: property.key.name || property.key.value },
                fix: (fixer) => fixer.replaceText(property.key, getQuotedKey(property.key))
              });
            });
          }
        }
        return {
          Property(node) {
            if (MODE === "always" || !MODE) {
              checkOmittedQuotes(node);
            }
            if (MODE === "as-needed") {
              checkUnnecessaryQuotes(node);
            }
          },
          ObjectExpression(node) {
            if (MODE === "consistent") {
              checkConsistency(node, false);
            }
            if (MODE === "consistent-as-needed") {
              checkConsistency(node, true);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/quotes.js
var require_quotes = __commonJS({
  "node_modules/eslint/lib/rules/quotes.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var QUOTE_SETTINGS = {
      double: {
        quote: '"',
        alternateQuote: "'",
        description: "doublequote"
      },
      single: {
        quote: "'",
        alternateQuote: '"',
        description: "singlequote"
      },
      backtick: {
        quote: "`",
        alternateQuote: '"',
        description: "backtick"
      }
    };
    var UNESCAPED_LINEBREAK_PATTERN = new RegExp(String.raw`(^|[^\\])(\\\\)*[${Array.from(astUtils.LINEBREAKS).join("")}]`, "u");
    QUOTE_SETTINGS.double.convert = QUOTE_SETTINGS.single.convert = QUOTE_SETTINGS.backtick.convert = function(str) {
      const newQuote = this.quote;
      const oldQuote = str[0];
      if (newQuote === oldQuote) {
        return str;
      }
      return newQuote + str.slice(1, -1).replace(/\\(\$\{|\r\n?|\n|.)|["'`]|\$\{|(\r\n?|\n)/gu, (match, escaped, newline) => {
        if (escaped === oldQuote || oldQuote === "`" && escaped === "${") {
          return escaped;
        }
        if (match === newQuote || newQuote === "`" && match === "${") {
          return `\\${match}`;
        }
        if (newline && oldQuote === "`") {
          return "\\n";
        }
        return match;
      }) + newQuote;
    };
    var AVOID_ESCAPE = "avoid-escape";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce the consistent use of either backticks, double, or single quotes",
          recommended: false,
          url: "https://eslint.org/docs/rules/quotes"
        },
        fixable: "code",
        schema: [
          {
            enum: ["single", "double", "backtick"]
          },
          {
            anyOf: [
              {
                enum: ["avoid-escape"]
              },
              {
                type: "object",
                properties: {
                  avoidEscape: {
                    type: "boolean"
                  },
                  allowTemplateLiterals: {
                    type: "boolean"
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          wrongQuotes: "Strings must use {{description}}."
        }
      },
      create(context) {
        const quoteOption = context.options[0], settings = QUOTE_SETTINGS[quoteOption || "double"], options = context.options[1], allowTemplateLiterals = options && options.allowTemplateLiterals === true, sourceCode = context.getSourceCode();
        let avoidEscape = options && options.avoidEscape === true;
        if (options === AVOID_ESCAPE) {
          avoidEscape = true;
        }
        function isJSXLiteral(node) {
          return node.parent.type === "JSXAttribute" || node.parent.type === "JSXElement" || node.parent.type === "JSXFragment";
        }
        function isDirective(node) {
          return node.type === "ExpressionStatement" && node.expression.type === "Literal" && typeof node.expression.value === "string";
        }
        function isPartOfDirectivePrologue(node) {
          const block = node.parent.parent;
          if (block.type !== "Program" && (block.type !== "BlockStatement" || !astUtils.isFunction(block.parent))) {
            return false;
          }
          for (let i = 0; i < block.body.length; ++i) {
            const statement = block.body[i];
            if (statement === node.parent) {
              return true;
            }
            if (!isDirective(statement)) {
              break;
            }
          }
          return false;
        }
        function isAllowedAsNonBacktick(node) {
          const parent = node.parent;
          switch (parent.type) {
            case "ExpressionStatement":
              return isPartOfDirectivePrologue(node);
            case "Property":
            case "PropertyDefinition":
            case "MethodDefinition":
              return parent.key === node && !parent.computed;
            case "ImportDeclaration":
            case "ExportNamedDeclaration":
              return parent.source === node;
            case "ExportAllDeclaration":
              return parent.exported === node || parent.source === node;
            case "ImportSpecifier":
              return parent.imported === node;
            case "ExportSpecifier":
              return parent.local === node || parent.exported === node;
            default:
              return false;
          }
        }
        function isUsingFeatureOfTemplateLiteral(node) {
          const hasTag = node.parent.type === "TaggedTemplateExpression" && node === node.parent.quasi;
          if (hasTag) {
            return true;
          }
          const hasStringInterpolation = node.expressions.length > 0;
          if (hasStringInterpolation) {
            return true;
          }
          const isMultilineString = node.quasis.length >= 1 && UNESCAPED_LINEBREAK_PATTERN.test(node.quasis[0].value.raw);
          if (isMultilineString) {
            return true;
          }
          return false;
        }
        return {
          Literal(node) {
            const val = node.value, rawVal = node.raw;
            if (settings && typeof val === "string") {
              let isValid = quoteOption === "backtick" && isAllowedAsNonBacktick(node) || isJSXLiteral(node) || astUtils.isSurroundedBy(rawVal, settings.quote);
              if (!isValid && avoidEscape) {
                isValid = astUtils.isSurroundedBy(rawVal, settings.alternateQuote) && rawVal.includes(settings.quote);
              }
              if (!isValid) {
                context.report({
                  node,
                  messageId: "wrongQuotes",
                  data: {
                    description: settings.description
                  },
                  fix(fixer) {
                    if (quoteOption === "backtick" && astUtils.hasOctalOrNonOctalDecimalEscapeSequence(rawVal)) {
                      return null;
                    }
                    return fixer.replaceText(node, settings.convert(node.raw));
                  }
                });
              }
            }
          },
          TemplateLiteral(node) {
            if (allowTemplateLiterals || quoteOption === "backtick" || isUsingFeatureOfTemplateLiteral(node)) {
              return;
            }
            context.report({
              node,
              messageId: "wrongQuotes",
              data: {
                description: settings.description
              },
              fix(fixer) {
                if (isPartOfDirectivePrologue(node)) {
                  return null;
                }
                return fixer.replaceText(node, settings.convert(sourceCode.getText(node)));
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/radix.js
var require_radix = __commonJS({
  "node_modules/eslint/lib/rules/radix.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var MODE_ALWAYS = "always";
    var MODE_AS_NEEDED = "as-needed";
    var validRadixValues = new Set(Array.from({ length: 37 - 2 }, (_, index) => index + 2));
    function isShadowed(variable) {
      return variable.defs.length >= 1;
    }
    function isParseIntMethod(node) {
      return node.type === "MemberExpression" && !node.computed && node.property.type === "Identifier" && node.property.name === "parseInt";
    }
    function isValidRadix(radix) {
      return !(radix.type === "Literal" && !validRadixValues.has(radix.value) || radix.type === "Identifier" && radix.name === "undefined");
    }
    function isDefaultRadix(radix) {
      return radix.type === "Literal" && radix.value === 10;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce the consistent use of the radix argument when using `parseInt()`",
          recommended: false,
          url: "https://eslint.org/docs/rules/radix"
        },
        hasSuggestions: true,
        schema: [
          {
            enum: ["always", "as-needed"]
          }
        ],
        messages: {
          missingParameters: "Missing parameters.",
          redundantRadix: "Redundant radix parameter.",
          missingRadix: "Missing radix parameter.",
          invalidRadix: "Invalid radix parameter, must be an integer between 2 and 36.",
          addRadixParameter10: "Add radix parameter `10` for parsing decimal numbers."
        }
      },
      create(context) {
        const mode = context.options[0] || MODE_ALWAYS;
        function checkArguments(node) {
          const args = node.arguments;
          switch (args.length) {
            case 0:
              context.report({
                node,
                messageId: "missingParameters"
              });
              break;
            case 1:
              if (mode === MODE_ALWAYS) {
                context.report({
                  node,
                  messageId: "missingRadix",
                  suggest: [
                    {
                      messageId: "addRadixParameter10",
                      fix(fixer) {
                        const sourceCode = context.getSourceCode();
                        const tokens = sourceCode.getTokens(node);
                        const lastToken = tokens[tokens.length - 1];
                        const secondToLastToken = tokens[tokens.length - 2];
                        const hasTrailingComma = secondToLastToken.type === "Punctuator" && secondToLastToken.value === ",";
                        return fixer.insertTextBefore(lastToken, hasTrailingComma ? " 10," : ", 10");
                      }
                    }
                  ]
                });
              }
              break;
            default:
              if (mode === MODE_AS_NEEDED && isDefaultRadix(args[1])) {
                context.report({
                  node,
                  messageId: "redundantRadix"
                });
              } else if (!isValidRadix(args[1])) {
                context.report({
                  node,
                  messageId: "invalidRadix"
                });
              }
              break;
          }
        }
        return {
          "Program:exit"() {
            const scope = context.getScope();
            let variable;
            variable = astUtils.getVariableByName(scope, "parseInt");
            if (variable && !isShadowed(variable)) {
              variable.references.forEach((reference) => {
                const node = reference.identifier;
                if (astUtils.isCallee(node)) {
                  checkArguments(node.parent);
                }
              });
            }
            variable = astUtils.getVariableByName(scope, "Number");
            if (variable && !isShadowed(variable)) {
              variable.references.forEach((reference) => {
                const node = reference.identifier.parent;
                const maybeCallee = node.parent.type === "ChainExpression" ? node.parent : node;
                if (isParseIntMethod(node) && astUtils.isCallee(maybeCallee)) {
                  checkArguments(maybeCallee.parent);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/require-atomic-updates.js
var require_require_atomic_updates = __commonJS({
  "node_modules/eslint/lib/rules/require-atomic-updates.js"(exports, module2) {
    "use strict";
    function createReferenceMap(scope, outReferenceMap = /* @__PURE__ */ new Map()) {
      for (const reference of scope.references) {
        if (reference.resolved === null) {
          continue;
        }
        outReferenceMap.set(reference.identifier, reference);
      }
      for (const childScope of scope.childScopes) {
        if (childScope.type !== "function") {
          createReferenceMap(childScope, outReferenceMap);
        }
      }
      return outReferenceMap;
    }
    function getWriteExpr(reference) {
      if (reference.writeExpr) {
        return reference.writeExpr;
      }
      let node = reference.identifier;
      while (node) {
        const t3 = node.parent.type;
        if (t3 === "AssignmentExpression" && node.parent.left === node) {
          return node.parent.right;
        }
        if (t3 === "MemberExpression" && node.parent.object === node) {
          node = node.parent;
          continue;
        }
        break;
      }
      return null;
    }
    function isLocalVariableWithoutEscape(variable, isMemberAccess) {
      if (!variable) {
        return false;
      }
      if (isMemberAccess && variable.defs.some((d) => d.type === "Parameter")) {
        return false;
      }
      const functionScope = variable.scope.variableScope;
      return variable.references.every((reference) => reference.from.variableScope === functionScope);
    }
    var SegmentInfo = class {
      constructor() {
        this.info = /* @__PURE__ */ new WeakMap();
      }
      /**
       * Initialize the segment information.
       * @param {PathSegment} segment The segment to initialize.
       * @returns {void}
       */
      initialize(segment) {
        const outdatedReadVariables = /* @__PURE__ */ new Set();
        const freshReadVariables = /* @__PURE__ */ new Set();
        for (const prevSegment of segment.prevSegments) {
          const info = this.info.get(prevSegment);
          if (info) {
            info.outdatedReadVariables.forEach(Set.prototype.add, outdatedReadVariables);
            info.freshReadVariables.forEach(Set.prototype.add, freshReadVariables);
          }
        }
        this.info.set(segment, { outdatedReadVariables, freshReadVariables });
      }
      /**
       * Mark a given variable as read on given segments.
       * @param {PathSegment[]} segments The segments that it read the variable on.
       * @param {Variable} variable The variable to be read.
       * @returns {void}
       */
      markAsRead(segments, variable) {
        for (const segment of segments) {
          const info = this.info.get(segment);
          if (info) {
            info.freshReadVariables.add(variable);
            info.outdatedReadVariables.delete(variable);
          }
        }
      }
      /**
       * Move `freshReadVariables` to `outdatedReadVariables`.
       * @param {PathSegment[]} segments The segments to process.
       * @returns {void}
       */
      makeOutdated(segments) {
        for (const segment of segments) {
          const info = this.info.get(segment);
          if (info) {
            info.freshReadVariables.forEach(Set.prototype.add, info.outdatedReadVariables);
            info.freshReadVariables.clear();
          }
        }
      }
      /**
       * Check if a given variable is outdated on the current segments.
       * @param {PathSegment[]} segments The current segments.
       * @param {Variable} variable The variable to check.
       * @returns {boolean} `true` if the variable is outdated on the segments.
       */
      isOutdated(segments, variable) {
        for (const segment of segments) {
          const info = this.info.get(segment);
          if (info && info.outdatedReadVariables.has(variable)) {
            return true;
          }
        }
        return false;
      }
    };
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Disallow assignments that can lead to race conditions due to usage of `await` or `yield`",
          recommended: false,
          url: "https://eslint.org/docs/rules/require-atomic-updates"
        },
        fixable: null,
        schema: [{
          type: "object",
          properties: {
            allowProperties: {
              type: "boolean",
              default: false
            }
          },
          additionalProperties: false
        }],
        messages: {
          nonAtomicUpdate: "Possible race condition: `{{value}}` might be reassigned based on an outdated value of `{{value}}`.",
          nonAtomicObjectUpdate: "Possible race condition: `{{value}}` might be assigned based on an outdated state of `{{object}}`."
        }
      },
      create(context) {
        const allowProperties = !!context.options[0] && context.options[0].allowProperties;
        const sourceCode = context.getSourceCode();
        const assignmentReferences = /* @__PURE__ */ new Map();
        const segmentInfo = new SegmentInfo();
        let stack = null;
        return {
          onCodePathStart(codePath) {
            const scope = context.getScope();
            const shouldVerify = scope.type === "function" && (scope.block.async || scope.block.generator);
            stack = {
              upper: stack,
              codePath,
              referenceMap: shouldVerify ? createReferenceMap(scope) : null
            };
          },
          onCodePathEnd() {
            stack = stack.upper;
          },
          // Initialize the segment information.
          onCodePathSegmentStart(segment) {
            segmentInfo.initialize(segment);
          },
          // Handle references to prepare verification.
          Identifier(node) {
            const { codePath, referenceMap } = stack;
            const reference = referenceMap && referenceMap.get(node);
            if (!reference) {
              return;
            }
            const variable = reference.resolved;
            const writeExpr = getWriteExpr(reference);
            const isMemberAccess = reference.identifier.parent.type === "MemberExpression";
            if (reference.isRead() && !(writeExpr && writeExpr.parent.operator === "=")) {
              segmentInfo.markAsRead(codePath.currentSegments, variable);
            }
            if (writeExpr && writeExpr.parent.right === writeExpr && // ← exclude variable declarations.
            !isLocalVariableWithoutEscape(variable, isMemberAccess)) {
              let refs = assignmentReferences.get(writeExpr);
              if (!refs) {
                refs = [];
                assignmentReferences.set(writeExpr, refs);
              }
              refs.push(reference);
            }
          },
          /*
           * Verify assignments.
           * If the reference exists in `outdatedReadVariables` list, report it.
           */
          ":expression:exit"(node) {
            const { codePath, referenceMap } = stack;
            if (!referenceMap) {
              return;
            }
            if (node.type === "AwaitExpression" || node.type === "YieldExpression") {
              segmentInfo.makeOutdated(codePath.currentSegments);
            }
            const references = assignmentReferences.get(node);
            if (references) {
              assignmentReferences.delete(node);
              for (const reference of references) {
                const variable = reference.resolved;
                if (segmentInfo.isOutdated(codePath.currentSegments, variable)) {
                  if (node.parent.left === reference.identifier) {
                    context.report({
                      node: node.parent,
                      messageId: "nonAtomicUpdate",
                      data: {
                        value: variable.name
                      }
                    });
                  } else if (!allowProperties) {
                    context.report({
                      node: node.parent,
                      messageId: "nonAtomicObjectUpdate",
                      data: {
                        value: sourceCode.getText(node.parent.left),
                        object: variable.name
                      }
                    });
                  }
                }
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/require-await.js
var require_require_await = __commonJS({
  "node_modules/eslint/lib/rules/require-await.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function capitalizeFirstLetter(text) {
      return text[0].toUpperCase() + text.slice(1);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Disallow async functions which have no `await` expression",
          recommended: false,
          url: "https://eslint.org/docs/rules/require-await"
        },
        schema: [],
        messages: {
          missingAwait: "{{name}} has no 'await' expression."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        let scopeInfo = null;
        function enterFunction() {
          scopeInfo = {
            upper: scopeInfo,
            hasAwait: false
          };
        }
        function exitFunction(node) {
          if (!node.generator && node.async && !scopeInfo.hasAwait && !astUtils.isEmptyFunction(node)) {
            context.report({
              node,
              loc: astUtils.getFunctionHeadLoc(node, sourceCode),
              messageId: "missingAwait",
              data: {
                name: capitalizeFirstLetter(
                  astUtils.getFunctionNameWithKind(node)
                )
              }
            });
          }
          scopeInfo = scopeInfo.upper;
        }
        return {
          FunctionDeclaration: enterFunction,
          FunctionExpression: enterFunction,
          ArrowFunctionExpression: enterFunction,
          "FunctionDeclaration:exit": exitFunction,
          "FunctionExpression:exit": exitFunction,
          "ArrowFunctionExpression:exit": exitFunction,
          AwaitExpression() {
            if (!scopeInfo) {
              return;
            }
            scopeInfo.hasAwait = true;
          },
          ForOfStatement(node) {
            if (!scopeInfo) {
              return;
            }
            if (node.await) {
              scopeInfo.hasAwait = true;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/require-jsdoc.js
var require_require_jsdoc = __commonJS({
  "node_modules/eslint/lib/rules/require-jsdoc.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require JSDoc comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/require-jsdoc"
        },
        schema: [
          {
            type: "object",
            properties: {
              require: {
                type: "object",
                properties: {
                  ClassDeclaration: {
                    type: "boolean",
                    default: false
                  },
                  MethodDefinition: {
                    type: "boolean",
                    default: false
                  },
                  FunctionDeclaration: {
                    type: "boolean",
                    default: true
                  },
                  ArrowFunctionExpression: {
                    type: "boolean",
                    default: false
                  },
                  FunctionExpression: {
                    type: "boolean",
                    default: false
                  }
                },
                additionalProperties: false,
                default: {}
              }
            },
            additionalProperties: false
          }
        ],
        deprecated: true,
        replacedBy: [],
        messages: {
          missingJSDocComment: "Missing JSDoc comment."
        }
      },
      create(context) {
        const source = context.getSourceCode();
        const DEFAULT_OPTIONS = {
          FunctionDeclaration: true,
          MethodDefinition: false,
          ClassDeclaration: false,
          ArrowFunctionExpression: false,
          FunctionExpression: false
        };
        const options = Object.assign(DEFAULT_OPTIONS, context.options[0] && context.options[0].require);
        function report(node) {
          context.report({ node, messageId: "missingJSDocComment" });
        }
        function checkJsDoc(node) {
          const jsdocComment = source.getJSDocComment(node);
          if (!jsdocComment) {
            report(node);
          }
        }
        return {
          FunctionDeclaration(node) {
            if (options.FunctionDeclaration) {
              checkJsDoc(node);
            }
          },
          FunctionExpression(node) {
            if (options.MethodDefinition && node.parent.type === "MethodDefinition" || options.FunctionExpression && (node.parent.type === "VariableDeclarator" || node.parent.type === "Property" && node === node.parent.value)) {
              checkJsDoc(node);
            }
          },
          ClassDeclaration(node) {
            if (options.ClassDeclaration) {
              checkJsDoc(node);
            }
          },
          ArrowFunctionExpression(node) {
            if (options.ArrowFunctionExpression && node.parent.type === "VariableDeclarator") {
              checkJsDoc(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/require-unicode-regexp.js
var require_require_unicode_regexp = __commonJS({
  "node_modules/eslint/lib/rules/require-unicode-regexp.js"(exports, module2) {
    "use strict";
    var {
      CALL,
      CONSTRUCT,
      ReferenceTracker,
      getStringIfConstant
    } = require_eslint_utils();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce the use of `u` flag on RegExp",
          recommended: false,
          url: "https://eslint.org/docs/rules/require-unicode-regexp"
        },
        messages: {
          requireUFlag: "Use the 'u' flag."
        },
        schema: []
      },
      create(context) {
        return {
          "Literal[regex]"(node) {
            const flags = node.regex.flags || "";
            if (!flags.includes("u")) {
              context.report({ node, messageId: "requireUFlag" });
            }
          },
          Program() {
            const scope = context.getScope();
            const tracker = new ReferenceTracker(scope);
            const trackMap = {
              RegExp: { [CALL]: true, [CONSTRUCT]: true }
            };
            for (const { node } of tracker.iterateGlobalReferences(trackMap)) {
              const flagsNode = node.arguments[1];
              const flags = getStringIfConstant(flagsNode, scope);
              if (!flagsNode || typeof flags === "string" && !flags.includes("u")) {
                context.report({ node, messageId: "requireUFlag" });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/require-yield.js
var require_require_yield = __commonJS({
  "node_modules/eslint/lib/rules/require-yield.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require generator functions to contain `yield`",
          recommended: true,
          url: "https://eslint.org/docs/rules/require-yield"
        },
        schema: [],
        messages: {
          missingYield: "This generator function does not have 'yield'."
        }
      },
      create(context) {
        const stack = [];
        function beginChecking(node) {
          if (node.generator) {
            stack.push(0);
          }
        }
        function endChecking(node) {
          if (!node.generator) {
            return;
          }
          const countYield = stack.pop();
          if (countYield === 0 && node.body.body.length > 0) {
            context.report({ node, messageId: "missingYield" });
          }
        }
        return {
          FunctionDeclaration: beginChecking,
          "FunctionDeclaration:exit": endChecking,
          FunctionExpression: beginChecking,
          "FunctionExpression:exit": endChecking,
          // Increases the count of `yield` keyword.
          YieldExpression() {
            if (stack.length > 0) {
              stack[stack.length - 1] += 1;
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/rest-spread-spacing.js
var require_rest_spread_spacing = __commonJS({
  "node_modules/eslint/lib/rules/rest-spread-spacing.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce spacing between rest and spread operators and their expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/rest-spread-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          }
        ],
        messages: {
          unexpectedWhitespace: "Unexpected whitespace after {{type}} operator.",
          expectedWhitespace: "Expected whitespace after {{type}} operator."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode(), alwaysSpace = context.options[0] === "always";
        function checkWhiteSpace(node) {
          const operator = sourceCode.getFirstToken(node), nextToken = sourceCode.getTokenAfter(operator), hasWhitespace = sourceCode.isSpaceBetweenTokens(operator, nextToken);
          let type;
          switch (node.type) {
            case "SpreadElement":
              type = "spread";
              if (node.parent.type === "ObjectExpression") {
                type += " property";
              }
              break;
            case "RestElement":
              type = "rest";
              if (node.parent.type === "ObjectPattern") {
                type += " property";
              }
              break;
            case "ExperimentalSpreadProperty":
              type = "spread property";
              break;
            case "ExperimentalRestProperty":
              type = "rest property";
              break;
            default:
              return;
          }
          if (alwaysSpace && !hasWhitespace) {
            context.report({
              node,
              loc: operator.loc,
              messageId: "expectedWhitespace",
              data: {
                type
              },
              fix(fixer) {
                return fixer.replaceTextRange([operator.range[1], nextToken.range[0]], " ");
              }
            });
          } else if (!alwaysSpace && hasWhitespace) {
            context.report({
              node,
              loc: {
                start: operator.loc.end,
                end: nextToken.loc.start
              },
              messageId: "unexpectedWhitespace",
              data: {
                type
              },
              fix(fixer) {
                return fixer.removeRange([operator.range[1], nextToken.range[0]]);
              }
            });
          }
        }
        return {
          SpreadElement: checkWhiteSpace,
          RestElement: checkWhiteSpace,
          ExperimentalSpreadProperty: checkWhiteSpace,
          ExperimentalRestProperty: checkWhiteSpace
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/semi.js
var require_semi = __commonJS({
  "node_modules/eslint/lib/rules/semi.js"(exports, module2) {
    "use strict";
    var FixTracker = require_fix_tracker();
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow semicolons instead of ASI",
          recommended: false,
          url: "https://eslint.org/docs/rules/semi"
        },
        fixable: "code",
        schema: {
          anyOf: [
            {
              type: "array",
              items: [
                {
                  enum: ["never"]
                },
                {
                  type: "object",
                  properties: {
                    beforeStatementContinuationChars: {
                      enum: ["always", "any", "never"]
                    }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            },
            {
              type: "array",
              items: [
                {
                  enum: ["always"]
                },
                {
                  type: "object",
                  properties: {
                    omitLastInOneLineBlock: { type: "boolean" }
                  },
                  additionalProperties: false
                }
              ],
              minItems: 0,
              maxItems: 2
            }
          ]
        },
        messages: {
          missingSemi: "Missing semicolon.",
          extraSemi: "Extra semicolon."
        }
      },
      create(context) {
        const OPT_OUT_PATTERN = /^[-[(/+`]/u;
        const unsafeClassFieldNames = /* @__PURE__ */ new Set(["get", "set", "static"]);
        const unsafeClassFieldFollowers = /* @__PURE__ */ new Set(["*", "in", "instanceof"]);
        const options = context.options[1];
        const never = context.options[0] === "never";
        const exceptOneLine = Boolean(options && options.omitLastInOneLineBlock);
        const beforeStatementContinuationChars = options && options.beforeStatementContinuationChars || "any";
        const sourceCode = context.getSourceCode();
        function report(node, missing) {
          const lastToken = sourceCode.getLastToken(node);
          let messageId, fix, loc;
          if (!missing) {
            messageId = "missingSemi";
            loc = {
              start: lastToken.loc.end,
              end: astUtils.getNextLocation(sourceCode, lastToken.loc.end)
            };
            fix = function(fixer) {
              return fixer.insertTextAfter(lastToken, ";");
            };
          } else {
            messageId = "extraSemi";
            loc = lastToken.loc;
            fix = function(fixer) {
              return new FixTracker(fixer, sourceCode).retainSurroundingTokens(lastToken).remove(lastToken);
            };
          }
          context.report({
            node,
            loc,
            messageId,
            fix
          });
        }
        function isRedundantSemi(semiToken) {
          const nextToken = sourceCode.getTokenAfter(semiToken);
          return !nextToken || astUtils.isClosingBraceToken(nextToken) || astUtils.isSemicolonToken(nextToken);
        }
        function isEndOfArrowBlock(lastToken) {
          if (!astUtils.isClosingBraceToken(lastToken)) {
            return false;
          }
          const node = sourceCode.getNodeByRangeIndex(lastToken.range[0]);
          return node.type === "BlockStatement" && node.parent.type === "ArrowFunctionExpression";
        }
        function maybeClassFieldAsiHazard(node) {
          if (node.type !== "PropertyDefinition") {
            return false;
          }
          const needsNameCheck = !node.computed && node.key.type === "Identifier";
          if (needsNameCheck && unsafeClassFieldNames.has(node.key.name)) {
            const isStaticStatic = node.static && node.key.name === "static";
            if (!isStaticStatic && !node.value) {
              return true;
            }
          }
          const followingToken = sourceCode.getTokenAfter(node);
          return unsafeClassFieldFollowers.has(followingToken.value);
        }
        function isOnSameLineWithNextToken(node) {
          const prevToken = sourceCode.getLastToken(node, 1);
          const nextToken = sourceCode.getTokenAfter(node);
          return !!nextToken && astUtils.isTokenOnSameLine(prevToken, nextToken);
        }
        function maybeAsiHazardAfter(node) {
          const t3 = node.type;
          if (t3 === "DoWhileStatement" || t3 === "BreakStatement" || t3 === "ContinueStatement" || t3 === "DebuggerStatement" || t3 === "ImportDeclaration" || t3 === "ExportAllDeclaration") {
            return false;
          }
          if (t3 === "ReturnStatement") {
            return Boolean(node.argument);
          }
          if (t3 === "ExportNamedDeclaration") {
            return Boolean(node.declaration);
          }
          if (isEndOfArrowBlock(sourceCode.getLastToken(node, 1))) {
            return false;
          }
          return true;
        }
        function maybeAsiHazardBefore(token) {
          return Boolean(token) && OPT_OUT_PATTERN.test(token.value) && token.value !== "++" && token.value !== "--";
        }
        function canRemoveSemicolon(node) {
          if (isRedundantSemi(sourceCode.getLastToken(node))) {
            return true;
          }
          if (maybeClassFieldAsiHazard(node)) {
            return false;
          }
          if (isOnSameLineWithNextToken(node)) {
            return false;
          }
          if (node.type !== "PropertyDefinition" && beforeStatementContinuationChars === "never" && !maybeAsiHazardAfter(node)) {
            return true;
          }
          if (!maybeAsiHazardBefore(sourceCode.getTokenAfter(node))) {
            return true;
          }
          return false;
        }
        function isLastInOneLinerBlock(node) {
          const parent = node.parent;
          const nextToken = sourceCode.getTokenAfter(node);
          if (!nextToken || nextToken.value !== "}") {
            return false;
          }
          if (parent.type === "BlockStatement") {
            return parent.loc.start.line === parent.loc.end.line;
          }
          if (parent.type === "StaticBlock") {
            const openingBrace = sourceCode.getFirstToken(parent, { skip: 1 });
            return openingBrace.loc.start.line === parent.loc.end.line;
          }
          return false;
        }
        function checkForSemicolon(node) {
          const isSemi = astUtils.isSemicolonToken(sourceCode.getLastToken(node));
          if (never) {
            if (isSemi && canRemoveSemicolon(node)) {
              report(node, true);
            } else if (!isSemi && beforeStatementContinuationChars === "always" && node.type !== "PropertyDefinition" && maybeAsiHazardBefore(sourceCode.getTokenAfter(node))) {
              report(node);
            }
          } else {
            const oneLinerBlock = exceptOneLine && isLastInOneLinerBlock(node);
            if (isSemi && oneLinerBlock) {
              report(node, true);
            } else if (!isSemi && !oneLinerBlock) {
              report(node);
            }
          }
        }
        function checkForSemicolonForVariableDeclaration(node) {
          const parent = node.parent;
          if ((parent.type !== "ForStatement" || parent.init !== node) && (!/^For(?:In|Of)Statement/u.test(parent.type) || parent.left !== node)) {
            checkForSemicolon(node);
          }
        }
        return {
          VariableDeclaration: checkForSemicolonForVariableDeclaration,
          ExpressionStatement: checkForSemicolon,
          ReturnStatement: checkForSemicolon,
          ThrowStatement: checkForSemicolon,
          DoWhileStatement: checkForSemicolon,
          DebuggerStatement: checkForSemicolon,
          BreakStatement: checkForSemicolon,
          ContinueStatement: checkForSemicolon,
          ImportDeclaration: checkForSemicolon,
          ExportAllDeclaration: checkForSemicolon,
          ExportNamedDeclaration(node) {
            if (!node.declaration) {
              checkForSemicolon(node);
            }
          },
          ExportDefaultDeclaration(node) {
            if (!/(?:Class|Function)Declaration/u.test(node.declaration.type)) {
              checkForSemicolon(node);
            }
          },
          PropertyDefinition: checkForSemicolon
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/semi-spacing.js
var require_semi_spacing = __commonJS({
  "node_modules/eslint/lib/rules/semi-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before and after semicolons",
          recommended: false,
          url: "https://eslint.org/docs/rules/semi-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              before: {
                type: "boolean",
                default: false
              },
              after: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedWhitespaceBefore: "Unexpected whitespace before semicolon.",
          unexpectedWhitespaceAfter: "Unexpected whitespace after semicolon.",
          missingWhitespaceBefore: "Missing whitespace before semicolon.",
          missingWhitespaceAfter: "Missing whitespace after semicolon."
        }
      },
      create(context) {
        const config = context.options[0], sourceCode = context.getSourceCode();
        let requireSpaceBefore = false, requireSpaceAfter = true;
        if (typeof config === "object") {
          requireSpaceBefore = config.before;
          requireSpaceAfter = config.after;
        }
        function hasLeadingSpace(token) {
          const tokenBefore = sourceCode.getTokenBefore(token);
          return tokenBefore && astUtils.isTokenOnSameLine(tokenBefore, token) && sourceCode.isSpaceBetweenTokens(tokenBefore, token);
        }
        function hasTrailingSpace(token) {
          const tokenAfter = sourceCode.getTokenAfter(token);
          return tokenAfter && astUtils.isTokenOnSameLine(token, tokenAfter) && sourceCode.isSpaceBetweenTokens(token, tokenAfter);
        }
        function isLastTokenInCurrentLine(token) {
          const tokenAfter = sourceCode.getTokenAfter(token);
          return !(tokenAfter && astUtils.isTokenOnSameLine(token, tokenAfter));
        }
        function isFirstTokenInCurrentLine(token) {
          const tokenBefore = sourceCode.getTokenBefore(token);
          return !(tokenBefore && astUtils.isTokenOnSameLine(token, tokenBefore));
        }
        function isBeforeClosingParen(token) {
          const nextToken = sourceCode.getTokenAfter(token);
          return nextToken && astUtils.isClosingBraceToken(nextToken) || astUtils.isClosingParenToken(nextToken);
        }
        function checkSemicolonSpacing(token, node) {
          if (astUtils.isSemicolonToken(token)) {
            if (hasLeadingSpace(token)) {
              if (!requireSpaceBefore) {
                const tokenBefore = sourceCode.getTokenBefore(token);
                const loc = {
                  start: tokenBefore.loc.end,
                  end: token.loc.start
                };
                context.report({
                  node,
                  loc,
                  messageId: "unexpectedWhitespaceBefore",
                  fix(fixer) {
                    return fixer.removeRange([tokenBefore.range[1], token.range[0]]);
                  }
                });
              }
            } else {
              if (requireSpaceBefore) {
                const loc = token.loc;
                context.report({
                  node,
                  loc,
                  messageId: "missingWhitespaceBefore",
                  fix(fixer) {
                    return fixer.insertTextBefore(token, " ");
                  }
                });
              }
            }
            if (!isFirstTokenInCurrentLine(token) && !isLastTokenInCurrentLine(token) && !isBeforeClosingParen(token)) {
              if (hasTrailingSpace(token)) {
                if (!requireSpaceAfter) {
                  const tokenAfter = sourceCode.getTokenAfter(token);
                  const loc = {
                    start: token.loc.end,
                    end: tokenAfter.loc.start
                  };
                  context.report({
                    node,
                    loc,
                    messageId: "unexpectedWhitespaceAfter",
                    fix(fixer) {
                      return fixer.removeRange([token.range[1], tokenAfter.range[0]]);
                    }
                  });
                }
              } else {
                if (requireSpaceAfter) {
                  const loc = token.loc;
                  context.report({
                    node,
                    loc,
                    messageId: "missingWhitespaceAfter",
                    fix(fixer) {
                      return fixer.insertTextAfter(token, " ");
                    }
                  });
                }
              }
            }
          }
        }
        function checkNode(node) {
          const token = sourceCode.getLastToken(node);
          checkSemicolonSpacing(token, node);
        }
        return {
          VariableDeclaration: checkNode,
          ExpressionStatement: checkNode,
          BreakStatement: checkNode,
          ContinueStatement: checkNode,
          DebuggerStatement: checkNode,
          DoWhileStatement: checkNode,
          ReturnStatement: checkNode,
          ThrowStatement: checkNode,
          ImportDeclaration: checkNode,
          ExportNamedDeclaration: checkNode,
          ExportAllDeclaration: checkNode,
          ExportDefaultDeclaration: checkNode,
          ForStatement(node) {
            if (node.init) {
              checkSemicolonSpacing(sourceCode.getTokenAfter(node.init), node);
            }
            if (node.test) {
              checkSemicolonSpacing(sourceCode.getTokenAfter(node.test), node);
            }
          },
          PropertyDefinition: checkNode
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/semi-style.js
var require_semi_style = __commonJS({
  "node_modules/eslint/lib/rules/semi-style.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var SELECTOR = [
      "BreakStatement",
      "ContinueStatement",
      "DebuggerStatement",
      "DoWhileStatement",
      "ExportAllDeclaration",
      "ExportDefaultDeclaration",
      "ExportNamedDeclaration",
      "ExpressionStatement",
      "ImportDeclaration",
      "ReturnStatement",
      "ThrowStatement",
      "VariableDeclaration",
      "PropertyDefinition"
    ].join(",");
    function getChildren(node) {
      const t3 = node.type;
      if (t3 === "BlockStatement" || t3 === "StaticBlock" || t3 === "Program" || t3 === "ClassBody") {
        return node.body;
      }
      if (t3 === "SwitchCase") {
        return node.consequent;
      }
      return null;
    }
    function isLastChild(node) {
      const t3 = node.parent.type;
      if (t3 === "IfStatement" && node.parent.consequent === node && node.parent.alternate) {
        return true;
      }
      if (t3 === "DoWhileStatement") {
        return true;
      }
      const nodeList = getChildren(node.parent);
      return nodeList !== null && nodeList[nodeList.length - 1] === node;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce location of semicolons",
          recommended: false,
          url: "https://eslint.org/docs/rules/semi-style"
        },
        schema: [{ enum: ["last", "first"] }],
        fixable: "whitespace",
        messages: {
          expectedSemiColon: "Expected this semicolon to be at {{pos}}."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const option = context.options[0] || "last";
        function check(semiToken, expected) {
          const prevToken = sourceCode.getTokenBefore(semiToken);
          const nextToken = sourceCode.getTokenAfter(semiToken);
          const prevIsSameLine = !prevToken || astUtils.isTokenOnSameLine(prevToken, semiToken);
          const nextIsSameLine = !nextToken || astUtils.isTokenOnSameLine(semiToken, nextToken);
          if (expected === "last" && !prevIsSameLine || expected === "first" && !nextIsSameLine) {
            context.report({
              loc: semiToken.loc,
              messageId: "expectedSemiColon",
              data: {
                pos: expected === "last" ? "the end of the previous line" : "the beginning of the next line"
              },
              fix(fixer) {
                if (prevToken && nextToken && sourceCode.commentsExistBetween(prevToken, nextToken)) {
                  return null;
                }
                const start = prevToken ? prevToken.range[1] : semiToken.range[0];
                const end = nextToken ? nextToken.range[0] : semiToken.range[1];
                const text = expected === "last" ? ";\n" : "\n;";
                return fixer.replaceTextRange([start, end], text);
              }
            });
          }
        }
        return {
          [SELECTOR](node) {
            if (option === "first" && isLastChild(node)) {
              return;
            }
            const lastToken = sourceCode.getLastToken(node);
            if (astUtils.isSemicolonToken(lastToken)) {
              check(lastToken, option);
            }
          },
          ForStatement(node) {
            const firstSemi = node.init && sourceCode.getTokenAfter(node.init, astUtils.isSemicolonToken);
            const secondSemi = node.test && sourceCode.getTokenAfter(node.test, astUtils.isSemicolonToken);
            if (firstSemi) {
              check(firstSemi, "last");
            }
            if (secondSemi) {
              check(secondSemi, "last");
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/sort-imports.js
var require_sort_imports = __commonJS({
  "node_modules/eslint/lib/rules/sort-imports.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce sorted import declarations within modules",
          recommended: false,
          url: "https://eslint.org/docs/rules/sort-imports"
        },
        schema: [
          {
            type: "object",
            properties: {
              ignoreCase: {
                type: "boolean",
                default: false
              },
              memberSyntaxSortOrder: {
                type: "array",
                items: {
                  enum: ["none", "all", "multiple", "single"]
                },
                uniqueItems: true,
                minItems: 4,
                maxItems: 4
              },
              ignoreDeclarationSort: {
                type: "boolean",
                default: false
              },
              ignoreMemberSort: {
                type: "boolean",
                default: false
              },
              allowSeparatedGroups: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          sortImportsAlphabetically: "Imports should be sorted alphabetically.",
          sortMembersAlphabetically: "Member '{{memberName}}' of the import declaration should be sorted alphabetically.",
          unexpectedSyntaxOrder: "Expected '{{syntaxA}}' syntax before '{{syntaxB}}' syntax."
        }
      },
      create(context) {
        const configuration = context.options[0] || {}, ignoreCase = configuration.ignoreCase || false, ignoreDeclarationSort = configuration.ignoreDeclarationSort || false, ignoreMemberSort = configuration.ignoreMemberSort || false, memberSyntaxSortOrder = configuration.memberSyntaxSortOrder || ["none", "all", "multiple", "single"], allowSeparatedGroups = configuration.allowSeparatedGroups || false, sourceCode = context.getSourceCode();
        let previousDeclaration = null;
        function usedMemberSyntax(node) {
          if (node.specifiers.length === 0) {
            return "none";
          }
          if (node.specifiers[0].type === "ImportNamespaceSpecifier") {
            return "all";
          }
          if (node.specifiers.length === 1) {
            return "single";
          }
          return "multiple";
        }
        function getMemberParameterGroupIndex(node) {
          return memberSyntaxSortOrder.indexOf(usedMemberSyntax(node));
        }
        function getFirstLocalMemberName(node) {
          if (node.specifiers[0]) {
            return node.specifiers[0].local.name;
          }
          return null;
        }
        function getNumberOfLinesBetween(left, right) {
          return Math.max(right.loc.start.line - left.loc.end.line - 1, 0);
        }
        return {
          ImportDeclaration(node) {
            if (!ignoreDeclarationSort) {
              if (previousDeclaration && allowSeparatedGroups && getNumberOfLinesBetween(previousDeclaration, node) > 0) {
                previousDeclaration = null;
              }
              if (previousDeclaration) {
                const currentMemberSyntaxGroupIndex = getMemberParameterGroupIndex(node), previousMemberSyntaxGroupIndex = getMemberParameterGroupIndex(previousDeclaration);
                let currentLocalMemberName = getFirstLocalMemberName(node), previousLocalMemberName = getFirstLocalMemberName(previousDeclaration);
                if (ignoreCase) {
                  previousLocalMemberName = previousLocalMemberName && previousLocalMemberName.toLowerCase();
                  currentLocalMemberName = currentLocalMemberName && currentLocalMemberName.toLowerCase();
                }
                if (currentMemberSyntaxGroupIndex !== previousMemberSyntaxGroupIndex) {
                  if (currentMemberSyntaxGroupIndex < previousMemberSyntaxGroupIndex) {
                    context.report({
                      node,
                      messageId: "unexpectedSyntaxOrder",
                      data: {
                        syntaxA: memberSyntaxSortOrder[currentMemberSyntaxGroupIndex],
                        syntaxB: memberSyntaxSortOrder[previousMemberSyntaxGroupIndex]
                      }
                    });
                  }
                } else {
                  if (previousLocalMemberName && currentLocalMemberName && currentLocalMemberName < previousLocalMemberName) {
                    context.report({
                      node,
                      messageId: "sortImportsAlphabetically"
                    });
                  }
                }
              }
              previousDeclaration = node;
            }
            if (!ignoreMemberSort) {
              const importSpecifiers = node.specifiers.filter((specifier) => specifier.type === "ImportSpecifier");
              const getSortableName = ignoreCase ? (specifier) => specifier.local.name.toLowerCase() : (specifier) => specifier.local.name;
              const firstUnsortedIndex = importSpecifiers.map(getSortableName).findIndex((name, index, array) => array[index - 1] > name);
              if (firstUnsortedIndex !== -1) {
                context.report({
                  node: importSpecifiers[firstUnsortedIndex],
                  messageId: "sortMembersAlphabetically",
                  data: { memberName: importSpecifiers[firstUnsortedIndex].local.name },
                  fix(fixer) {
                    if (importSpecifiers.some((specifier) => sourceCode.getCommentsBefore(specifier).length || sourceCode.getCommentsAfter(specifier).length)) {
                      return null;
                    }
                    return fixer.replaceTextRange(
                      [importSpecifiers[0].range[0], importSpecifiers[importSpecifiers.length - 1].range[1]],
                      importSpecifiers.slice().sort((specifierA, specifierB) => {
                        const aName = getSortableName(specifierA);
                        const bName = getSortableName(specifierB);
                        return aName > bName ? 1 : -1;
                      }).reduce((sourceText, specifier, index) => {
                        const textAfterSpecifier = index === importSpecifiers.length - 1 ? "" : sourceCode.getText().slice(importSpecifiers[index].range[1], importSpecifiers[index + 1].range[0]);
                        return sourceText + sourceCode.getText(specifier) + textAfterSpecifier;
                      }, "")
                    );
                  }
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/natural-compare/index.js
var require_natural_compare = __commonJS({
  "node_modules/natural-compare/index.js"(exports, module2) {
    var naturalCompare = function(a, b) {
      var i, codeA, codeB = 1, posA = 0, posB = 0, alphabet = String.alphabet;
      function getCode(str, pos, code) {
        if (code) {
          for (i = pos; code = getCode(str, i), code < 76 && code > 65; )
            ++i;
          return +str.slice(pos - 1, i);
        }
        code = alphabet && alphabet.indexOf(str.charAt(pos));
        return code > -1 ? code + 76 : (code = str.charCodeAt(pos) || 0, code < 45 || code > 127) ? code : code < 46 ? 65 : code < 48 ? code - 1 : code < 58 ? code + 18 : code < 65 ? code - 11 : code < 91 ? code + 11 : code < 97 ? code - 37 : code < 123 ? code + 5 : code - 63;
      }
      if ((a += "") != (b += ""))
        for (; codeB; ) {
          codeA = getCode(a, posA++);
          codeB = getCode(b, posB++);
          if (codeA < 76 && codeB < 76 && codeA > 66 && codeB > 66) {
            codeA = getCode(a, posA, posA);
            codeB = getCode(b, posB, posA = i);
            posB = i;
          }
          if (codeA != codeB)
            return codeA < codeB ? -1 : 1;
        }
      return 0;
    };
    try {
      module2.exports = naturalCompare;
    } catch (e) {
      String.naturalCompare = naturalCompare;
    }
  }
});

// node_modules/eslint/lib/rules/sort-keys.js
var require_sort_keys = __commonJS({
  "node_modules/eslint/lib/rules/sort-keys.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var naturalCompare = require_natural_compare();
    function getPropertyName(node) {
      const staticName = astUtils.getStaticPropertyName(node);
      if (staticName !== null) {
        return staticName;
      }
      return node.key.name || null;
    }
    var isValidOrders = {
      asc(a, b) {
        return a <= b;
      },
      ascI(a, b) {
        return a.toLowerCase() <= b.toLowerCase();
      },
      ascN(a, b) {
        return naturalCompare(a, b) <= 0;
      },
      ascIN(a, b) {
        return naturalCompare(a.toLowerCase(), b.toLowerCase()) <= 0;
      },
      desc(a, b) {
        return isValidOrders.asc(b, a);
      },
      descI(a, b) {
        return isValidOrders.ascI(b, a);
      },
      descN(a, b) {
        return isValidOrders.ascN(b, a);
      },
      descIN(a, b) {
        return isValidOrders.ascIN(b, a);
      }
    };
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require object keys to be sorted",
          recommended: false,
          url: "https://eslint.org/docs/rules/sort-keys"
        },
        schema: [
          {
            enum: ["asc", "desc"]
          },
          {
            type: "object",
            properties: {
              caseSensitive: {
                type: "boolean",
                default: true
              },
              natural: {
                type: "boolean",
                default: false
              },
              minKeys: {
                type: "integer",
                minimum: 2,
                default: 2
              },
              allowLineSeparatedGroups: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          sortKeys: "Expected object keys to be in {{natural}}{{insensitive}}{{order}}ending order. '{{thisName}}' should be before '{{prevName}}'."
        }
      },
      create(context) {
        const order = context.options[0] || "asc";
        const options = context.options[1];
        const insensitive = options && options.caseSensitive === false;
        const natural = options && options.natural;
        const minKeys = options && options.minKeys;
        const allowLineSeparatedGroups = options && options.allowLineSeparatedGroups || false;
        const isValidOrder = isValidOrders[order + (insensitive ? "I" : "") + (natural ? "N" : "")];
        let stack = null;
        const sourceCode = context.getSourceCode();
        return {
          ObjectExpression(node) {
            stack = {
              upper: stack,
              prevNode: null,
              prevBlankLine: false,
              prevName: null,
              numKeys: node.properties.length
            };
          },
          "ObjectExpression:exit"() {
            stack = stack.upper;
          },
          SpreadElement(node) {
            if (node.parent.type === "ObjectExpression") {
              stack.prevName = null;
            }
          },
          Property(node) {
            if (node.parent.type === "ObjectPattern") {
              return;
            }
            const prevName = stack.prevName;
            const numKeys = stack.numKeys;
            const thisName = getPropertyName(node);
            const tokens = stack.prevNode && sourceCode.getTokensBetween(stack.prevNode, node, { includeComments: true });
            let isBlankLineBetweenNodes = stack.prevBlankLine;
            if (tokens) {
              tokens.forEach((token, index) => {
                const previousToken = tokens[index - 1];
                if (previousToken && token.loc.start.line - previousToken.loc.end.line > 1) {
                  isBlankLineBetweenNodes = true;
                }
              });
              if (!isBlankLineBetweenNodes && node.loc.start.line - tokens[tokens.length - 1].loc.end.line > 1) {
                isBlankLineBetweenNodes = true;
              }
              if (!isBlankLineBetweenNodes && tokens[0].loc.start.line - stack.prevNode.loc.end.line > 1) {
                isBlankLineBetweenNodes = true;
              }
            }
            stack.prevNode = node;
            if (thisName !== null) {
              stack.prevName = thisName;
            }
            if (allowLineSeparatedGroups && isBlankLineBetweenNodes) {
              stack.prevBlankLine = thisName === null;
              return;
            }
            if (prevName === null || thisName === null || numKeys < minKeys) {
              return;
            }
            if (!isValidOrder(prevName, thisName)) {
              context.report({
                node,
                loc: node.key.loc,
                messageId: "sortKeys",
                data: {
                  thisName,
                  prevName,
                  order,
                  insensitive: insensitive ? "insensitive " : "",
                  natural: natural ? "natural " : ""
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/sort-vars.js
var require_sort_vars = __commonJS({
  "node_modules/eslint/lib/rules/sort-vars.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require variables within the same declaration block to be sorted",
          recommended: false,
          url: "https://eslint.org/docs/rules/sort-vars"
        },
        schema: [
          {
            type: "object",
            properties: {
              ignoreCase: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          sortVars: "Variables within the same declaration block should be sorted alphabetically."
        }
      },
      create(context) {
        const configuration = context.options[0] || {}, ignoreCase = configuration.ignoreCase || false, sourceCode = context.getSourceCode();
        return {
          VariableDeclaration(node) {
            const idDeclarations = node.declarations.filter((decl) => decl.id.type === "Identifier");
            const getSortableName = ignoreCase ? (decl) => decl.id.name.toLowerCase() : (decl) => decl.id.name;
            const unfixable = idDeclarations.some((decl) => decl.init !== null && decl.init.type !== "Literal");
            let fixed = false;
            idDeclarations.slice(1).reduce((memo, decl) => {
              const lastVariableName = getSortableName(memo), currentVariableName = getSortableName(decl);
              if (currentVariableName < lastVariableName) {
                context.report({
                  node: decl,
                  messageId: "sortVars",
                  fix(fixer) {
                    if (unfixable || fixed) {
                      return null;
                    }
                    return fixer.replaceTextRange(
                      [idDeclarations[0].range[0], idDeclarations[idDeclarations.length - 1].range[1]],
                      idDeclarations.slice().sort((declA, declB) => {
                        const aName = getSortableName(declA);
                        const bName = getSortableName(declB);
                        return aName > bName ? 1 : -1;
                      }).reduce((sourceText, identifier3, index) => {
                        const textAfterIdentifier = index === idDeclarations.length - 1 ? "" : sourceCode.getText().slice(idDeclarations[index].range[1], idDeclarations[index + 1].range[0]);
                        return sourceText + sourceCode.getText(identifier3) + textAfterIdentifier;
                      }, "")
                    );
                  }
                });
                fixed = true;
                return memo;
              }
              return decl;
            }, idDeclarations[0]);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/space-before-blocks.js
var require_space_before_blocks = __commonJS({
  "node_modules/eslint/lib/rules/space-before-blocks.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isFunctionBody(node) {
      const parent = node.parent;
      return node.type === "BlockStatement" && astUtils.isFunction(parent) && parent.body === node;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before blocks",
          recommended: false,
          url: "https://eslint.org/docs/rules/space-before-blocks"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never"]
              },
              {
                type: "object",
                properties: {
                  keywords: {
                    enum: ["always", "never", "off"]
                  },
                  functions: {
                    enum: ["always", "never", "off"]
                  },
                  classes: {
                    enum: ["always", "never", "off"]
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          unexpectedSpace: "Unexpected space before opening brace.",
          missingSpace: "Missing space before opening brace."
        }
      },
      create(context) {
        const config = context.options[0], sourceCode = context.getSourceCode();
        let alwaysFunctions = true, alwaysKeywords = true, alwaysClasses = true, neverFunctions = false, neverKeywords = false, neverClasses = false;
        if (typeof config === "object") {
          alwaysFunctions = config.functions === "always";
          alwaysKeywords = config.keywords === "always";
          alwaysClasses = config.classes === "always";
          neverFunctions = config.functions === "never";
          neverKeywords = config.keywords === "never";
          neverClasses = config.classes === "never";
        } else if (config === "never") {
          alwaysFunctions = false;
          alwaysKeywords = false;
          alwaysClasses = false;
          neverFunctions = true;
          neverKeywords = true;
          neverClasses = true;
        }
        function isConflicted(precedingToken, node) {
          return astUtils.isArrowToken(precedingToken) || astUtils.isKeywordToken(precedingToken) && !isFunctionBody(node) || astUtils.isColonToken(precedingToken) && node.parent && node.parent.type === "SwitchCase" && precedingToken === astUtils.getSwitchCaseColonToken(node.parent, sourceCode);
        }
        function checkPrecedingSpace(node) {
          const precedingToken = sourceCode.getTokenBefore(node);
          if (precedingToken && !isConflicted(precedingToken, node) && astUtils.isTokenOnSameLine(precedingToken, node)) {
            const hasSpace = sourceCode.isSpaceBetweenTokens(precedingToken, node);
            let requireSpace;
            let requireNoSpace;
            if (isFunctionBody(node)) {
              requireSpace = alwaysFunctions;
              requireNoSpace = neverFunctions;
            } else if (node.type === "ClassBody") {
              requireSpace = alwaysClasses;
              requireNoSpace = neverClasses;
            } else {
              requireSpace = alwaysKeywords;
              requireNoSpace = neverKeywords;
            }
            if (requireSpace && !hasSpace) {
              context.report({
                node,
                messageId: "missingSpace",
                fix(fixer) {
                  return fixer.insertTextBefore(node, " ");
                }
              });
            } else if (requireNoSpace && hasSpace) {
              context.report({
                node,
                messageId: "unexpectedSpace",
                fix(fixer) {
                  return fixer.removeRange([precedingToken.range[1], node.range[0]]);
                }
              });
            }
          }
        }
        function checkSpaceBeforeCaseBlock(node) {
          const cases = node.cases;
          let openingBrace;
          if (cases.length > 0) {
            openingBrace = sourceCode.getTokenBefore(cases[0]);
          } else {
            openingBrace = sourceCode.getLastToken(node, 1);
          }
          checkPrecedingSpace(openingBrace);
        }
        return {
          BlockStatement: checkPrecedingSpace,
          ClassBody: checkPrecedingSpace,
          SwitchStatement: checkSpaceBeforeCaseBlock
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/space-before-function-paren.js
var require_space_before_function_paren = __commonJS({
  "node_modules/eslint/lib/rules/space-before-function-paren.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before `function` definition opening parenthesis",
          recommended: false,
          url: "https://eslint.org/docs/rules/space-before-function-paren"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["always", "never"]
              },
              {
                type: "object",
                properties: {
                  anonymous: {
                    enum: ["always", "never", "ignore"]
                  },
                  named: {
                    enum: ["always", "never", "ignore"]
                  },
                  asyncArrow: {
                    enum: ["always", "never", "ignore"]
                  }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          unexpectedSpace: "Unexpected space before function parentheses.",
          missingSpace: "Missing space before function parentheses."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const baseConfig = typeof context.options[0] === "string" ? context.options[0] : "always";
        const overrideConfig = typeof context.options[0] === "object" ? context.options[0] : {};
        function isNamedFunction(node) {
          if (node.id) {
            return true;
          }
          const parent = node.parent;
          return parent.type === "MethodDefinition" || parent.type === "Property" && (parent.kind === "get" || parent.kind === "set" || parent.method);
        }
        function getConfigForFunction(node) {
          if (node.type === "ArrowFunctionExpression") {
            if (node.async && astUtils.isOpeningParenToken(sourceCode.getFirstToken(node, { skip: 1 }))) {
              return overrideConfig.asyncArrow || baseConfig;
            }
          } else if (isNamedFunction(node)) {
            return overrideConfig.named || baseConfig;
          } else if (!node.generator) {
            return overrideConfig.anonymous || baseConfig;
          }
          return "ignore";
        }
        function checkFunction(node) {
          const functionConfig = getConfigForFunction(node);
          if (functionConfig === "ignore") {
            return;
          }
          const rightToken = sourceCode.getFirstToken(node, astUtils.isOpeningParenToken);
          const leftToken = sourceCode.getTokenBefore(rightToken);
          const hasSpacing = sourceCode.isSpaceBetweenTokens(leftToken, rightToken);
          if (hasSpacing && functionConfig === "never") {
            context.report({
              node,
              loc: {
                start: leftToken.loc.end,
                end: rightToken.loc.start
              },
              messageId: "unexpectedSpace",
              fix(fixer) {
                const comments = sourceCode.getCommentsBefore(rightToken);
                if (comments.some((comment) => comment.type === "Line")) {
                  return null;
                }
                return fixer.replaceTextRange(
                  [leftToken.range[1], rightToken.range[0]],
                  comments.reduce((text, comment) => text + sourceCode.getText(comment), "")
                );
              }
            });
          } else if (!hasSpacing && functionConfig === "always") {
            context.report({
              node,
              loc: rightToken.loc,
              messageId: "missingSpace",
              fix: (fixer) => fixer.insertTextAfter(leftToken, " ")
            });
          }
        }
        return {
          ArrowFunctionExpression: checkFunction,
          FunctionDeclaration: checkFunction,
          FunctionExpression: checkFunction
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/space-in-parens.js
var require_space_in_parens = __commonJS({
  "node_modules/eslint/lib/rules/space-in-parens.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing inside parentheses",
          recommended: false,
          url: "https://eslint.org/docs/rules/space-in-parens"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: {
                  enum: ["{}", "[]", "()", "empty"]
                },
                uniqueItems: true
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          missingOpeningSpace: "There must be a space after this paren.",
          missingClosingSpace: "There must be a space before this paren.",
          rejectedOpeningSpace: "There should be no space after this paren.",
          rejectedClosingSpace: "There should be no space before this paren."
        }
      },
      create(context) {
        const ALWAYS = context.options[0] === "always", exceptionsArrayOptions = context.options[1] && context.options[1].exceptions || [], options = {};
        let exceptions;
        if (exceptionsArrayOptions.length) {
          options.braceException = exceptionsArrayOptions.includes("{}");
          options.bracketException = exceptionsArrayOptions.includes("[]");
          options.parenException = exceptionsArrayOptions.includes("()");
          options.empty = exceptionsArrayOptions.includes("empty");
        }
        function getExceptions() {
          const openers = [], closers = [];
          if (options.braceException) {
            openers.push("{");
            closers.push("}");
          }
          if (options.bracketException) {
            openers.push("[");
            closers.push("]");
          }
          if (options.parenException) {
            openers.push("(");
            closers.push(")");
          }
          if (options.empty) {
            openers.push(")");
            closers.push("(");
          }
          return {
            openers,
            closers
          };
        }
        const sourceCode = context.getSourceCode();
        function isOpenerException(token) {
          return exceptions.openers.includes(token.value);
        }
        function isCloserException(token) {
          return exceptions.closers.includes(token.value);
        }
        function openerMissingSpace(openingParenToken, tokenAfterOpeningParen) {
          if (sourceCode.isSpaceBetweenTokens(openingParenToken, tokenAfterOpeningParen)) {
            return false;
          }
          if (!options.empty && astUtils.isClosingParenToken(tokenAfterOpeningParen)) {
            return false;
          }
          if (ALWAYS) {
            return !isOpenerException(tokenAfterOpeningParen);
          }
          return isOpenerException(tokenAfterOpeningParen);
        }
        function openerRejectsSpace(openingParenToken, tokenAfterOpeningParen) {
          if (!astUtils.isTokenOnSameLine(openingParenToken, tokenAfterOpeningParen)) {
            return false;
          }
          if (tokenAfterOpeningParen.type === "Line") {
            return false;
          }
          if (!sourceCode.isSpaceBetweenTokens(openingParenToken, tokenAfterOpeningParen)) {
            return false;
          }
          if (ALWAYS) {
            return isOpenerException(tokenAfterOpeningParen);
          }
          return !isOpenerException(tokenAfterOpeningParen);
        }
        function closerMissingSpace(tokenBeforeClosingParen, closingParenToken) {
          if (sourceCode.isSpaceBetweenTokens(tokenBeforeClosingParen, closingParenToken)) {
            return false;
          }
          if (!options.empty && astUtils.isOpeningParenToken(tokenBeforeClosingParen)) {
            return false;
          }
          if (ALWAYS) {
            return !isCloserException(tokenBeforeClosingParen);
          }
          return isCloserException(tokenBeforeClosingParen);
        }
        function closerRejectsSpace(tokenBeforeClosingParen, closingParenToken) {
          if (!astUtils.isTokenOnSameLine(tokenBeforeClosingParen, closingParenToken)) {
            return false;
          }
          if (!sourceCode.isSpaceBetweenTokens(tokenBeforeClosingParen, closingParenToken)) {
            return false;
          }
          if (ALWAYS) {
            return isCloserException(tokenBeforeClosingParen);
          }
          return !isCloserException(tokenBeforeClosingParen);
        }
        return {
          Program: function checkParenSpaces(node) {
            exceptions = getExceptions();
            const tokens = sourceCode.tokensAndComments;
            tokens.forEach((token, i) => {
              const prevToken = tokens[i - 1];
              const nextToken = tokens[i + 1];
              if (!astUtils.isOpeningParenToken(token) && !astUtils.isClosingParenToken(token)) {
                return;
              }
              if (token.value === "(" && openerMissingSpace(token, nextToken)) {
                context.report({
                  node,
                  loc: token.loc,
                  messageId: "missingOpeningSpace",
                  fix(fixer) {
                    return fixer.insertTextAfter(token, " ");
                  }
                });
              }
              if (token.value === "(" && openerRejectsSpace(token, nextToken)) {
                context.report({
                  node,
                  loc: { start: token.loc.end, end: nextToken.loc.start },
                  messageId: "rejectedOpeningSpace",
                  fix(fixer) {
                    return fixer.removeRange([token.range[1], nextToken.range[0]]);
                  }
                });
              }
              if (token.value === ")" && closerMissingSpace(prevToken, token)) {
                context.report({
                  node,
                  loc: token.loc,
                  messageId: "missingClosingSpace",
                  fix(fixer) {
                    return fixer.insertTextBefore(token, " ");
                  }
                });
              }
              if (token.value === ")" && closerRejectsSpace(prevToken, token)) {
                context.report({
                  node,
                  loc: { start: prevToken.loc.end, end: token.loc.start },
                  messageId: "rejectedClosingSpace",
                  fix(fixer) {
                    return fixer.removeRange([prevToken.range[1], token.range[0]]);
                  }
                });
              }
            });
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/space-infix-ops.js
var require_space_infix_ops = __commonJS({
  "node_modules/eslint/lib/rules/space-infix-ops.js"(exports, module2) {
    "use strict";
    var { isEqToken } = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require spacing around infix operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/space-infix-ops"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              int32Hint: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          missingSpace: "Operator '{{operator}}' must be spaced."
        }
      },
      create(context) {
        const int32Hint = context.options[0] ? context.options[0].int32Hint === true : false;
        const sourceCode = context.getSourceCode();
        function getFirstNonSpacedToken(left, right, op) {
          const operator = sourceCode.getFirstTokenBetween(left, right, (token) => token.value === op);
          const prev = sourceCode.getTokenBefore(operator);
          const next = sourceCode.getTokenAfter(operator);
          if (!sourceCode.isSpaceBetweenTokens(prev, operator) || !sourceCode.isSpaceBetweenTokens(operator, next)) {
            return operator;
          }
          return null;
        }
        function report(mainNode, culpritToken) {
          context.report({
            node: mainNode,
            loc: culpritToken.loc,
            messageId: "missingSpace",
            data: {
              operator: culpritToken.value
            },
            fix(fixer) {
              const previousToken = sourceCode.getTokenBefore(culpritToken);
              const afterToken = sourceCode.getTokenAfter(culpritToken);
              let fixString = "";
              if (culpritToken.range[0] - previousToken.range[1] === 0) {
                fixString = " ";
              }
              fixString += culpritToken.value;
              if (afterToken.range[0] - culpritToken.range[1] === 0) {
                fixString += " ";
              }
              return fixer.replaceText(culpritToken, fixString);
            }
          });
        }
        function checkBinary(node) {
          const leftNode = node.left.typeAnnotation ? node.left.typeAnnotation : node.left;
          const rightNode = node.right;
          const operator = node.operator || "=";
          const nonSpacedNode = getFirstNonSpacedToken(leftNode, rightNode, operator);
          if (nonSpacedNode) {
            if (!(int32Hint && sourceCode.getText(node).endsWith("|0"))) {
              report(node, nonSpacedNode);
            }
          }
        }
        function checkConditional(node) {
          const nonSpacedConsequentNode = getFirstNonSpacedToken(node.test, node.consequent, "?");
          const nonSpacedAlternateNode = getFirstNonSpacedToken(node.consequent, node.alternate, ":");
          if (nonSpacedConsequentNode) {
            report(node, nonSpacedConsequentNode);
          }
          if (nonSpacedAlternateNode) {
            report(node, nonSpacedAlternateNode);
          }
        }
        function checkVar(node) {
          const leftNode = node.id.typeAnnotation ? node.id.typeAnnotation : node.id;
          const rightNode = node.init;
          if (rightNode) {
            const nonSpacedNode = getFirstNonSpacedToken(leftNode, rightNode, "=");
            if (nonSpacedNode) {
              report(node, nonSpacedNode);
            }
          }
        }
        return {
          AssignmentExpression: checkBinary,
          AssignmentPattern: checkBinary,
          BinaryExpression: checkBinary,
          LogicalExpression: checkBinary,
          ConditionalExpression: checkConditional,
          VariableDeclarator: checkVar,
          PropertyDefinition(node) {
            if (!node.value) {
              return;
            }
            const operatorToken = sourceCode.getTokenBefore(node.value, isEqToken);
            const leftToken = sourceCode.getTokenBefore(operatorToken);
            const rightToken = sourceCode.getTokenAfter(operatorToken);
            if (!sourceCode.isSpaceBetweenTokens(leftToken, operatorToken) || !sourceCode.isSpaceBetweenTokens(operatorToken, rightToken)) {
              report(node, operatorToken);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/space-unary-ops.js
var require_space_unary_ops = __commonJS({
  "node_modules/eslint/lib/rules/space-unary-ops.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce consistent spacing before or after unary operators",
          recommended: false,
          url: "https://eslint.org/docs/rules/space-unary-ops"
        },
        fixable: "whitespace",
        schema: [
          {
            type: "object",
            properties: {
              words: {
                type: "boolean",
                default: true
              },
              nonwords: {
                type: "boolean",
                default: false
              },
              overrides: {
                type: "object",
                additionalProperties: {
                  type: "boolean"
                }
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedBefore: "Unexpected space before unary operator '{{operator}}'.",
          unexpectedAfter: "Unexpected space after unary operator '{{operator}}'.",
          unexpectedAfterWord: "Unexpected space after unary word operator '{{word}}'.",
          wordOperator: "Unary word operator '{{word}}' must be followed by whitespace.",
          operator: "Unary operator '{{operator}}' must be followed by whitespace.",
          beforeUnaryExpressions: "Space is required before unary expressions '{{token}}'."
        }
      },
      create(context) {
        const options = context.options[0] || { words: true, nonwords: false };
        const sourceCode = context.getSourceCode();
        function isFirstBangInBangBangExpression(node) {
          return node && node.type === "UnaryExpression" && node.argument.operator === "!" && node.argument && node.argument.type === "UnaryExpression" && node.argument.operator === "!";
        }
        function overrideExistsForOperator(operator) {
          return options.overrides && Object.prototype.hasOwnProperty.call(options.overrides, operator);
        }
        function overrideEnforcesSpaces(operator) {
          return options.overrides[operator];
        }
        function verifyWordHasSpaces(node, firstToken, secondToken, word) {
          if (secondToken.range[0] === firstToken.range[1]) {
            context.report({
              node,
              messageId: "wordOperator",
              data: {
                word
              },
              fix(fixer) {
                return fixer.insertTextAfter(firstToken, " ");
              }
            });
          }
        }
        function verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word) {
          if (astUtils.canTokensBeAdjacent(firstToken, secondToken)) {
            if (secondToken.range[0] > firstToken.range[1]) {
              context.report({
                node,
                messageId: "unexpectedAfterWord",
                data: {
                  word
                },
                fix(fixer) {
                  return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                }
              });
            }
          }
        }
        function checkUnaryWordOperatorForSpaces(node, firstToken, secondToken, word) {
          if (overrideExistsForOperator(word)) {
            if (overrideEnforcesSpaces(word)) {
              verifyWordHasSpaces(node, firstToken, secondToken, word);
            } else {
              verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word);
            }
          } else if (options.words) {
            verifyWordHasSpaces(node, firstToken, secondToken, word);
          } else {
            verifyWordDoesntHaveSpaces(node, firstToken, secondToken, word);
          }
        }
        function checkForSpacesAfterYield(node) {
          const tokens = sourceCode.getFirstTokens(node, 3), word = "yield";
          if (!node.argument || node.delegate) {
            return;
          }
          checkUnaryWordOperatorForSpaces(node, tokens[0], tokens[1], word);
        }
        function checkForSpacesAfterAwait(node) {
          const tokens = sourceCode.getFirstTokens(node, 3);
          checkUnaryWordOperatorForSpaces(node, tokens[0], tokens[1], "await");
        }
        function verifyNonWordsHaveSpaces(node, firstToken, secondToken) {
          if (node.prefix) {
            if (isFirstBangInBangBangExpression(node)) {
              return;
            }
            if (firstToken.range[1] === secondToken.range[0]) {
              context.report({
                node,
                messageId: "operator",
                data: {
                  operator: firstToken.value
                },
                fix(fixer) {
                  return fixer.insertTextAfter(firstToken, " ");
                }
              });
            }
          } else {
            if (firstToken.range[1] === secondToken.range[0]) {
              context.report({
                node,
                messageId: "beforeUnaryExpressions",
                data: {
                  token: secondToken.value
                },
                fix(fixer) {
                  return fixer.insertTextBefore(secondToken, " ");
                }
              });
            }
          }
        }
        function verifyNonWordsDontHaveSpaces(node, firstToken, secondToken) {
          if (node.prefix) {
            if (secondToken.range[0] > firstToken.range[1]) {
              context.report({
                node,
                messageId: "unexpectedAfter",
                data: {
                  operator: firstToken.value
                },
                fix(fixer) {
                  if (astUtils.canTokensBeAdjacent(firstToken, secondToken)) {
                    return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                  }
                  return null;
                }
              });
            }
          } else {
            if (secondToken.range[0] > firstToken.range[1]) {
              context.report({
                node,
                messageId: "unexpectedBefore",
                data: {
                  operator: secondToken.value
                },
                fix(fixer) {
                  return fixer.removeRange([firstToken.range[1], secondToken.range[0]]);
                }
              });
            }
          }
        }
        function checkForSpaces(node) {
          const tokens = node.type === "UpdateExpression" && !node.prefix ? sourceCode.getLastTokens(node, 2) : sourceCode.getFirstTokens(node, 2);
          const firstToken = tokens[0];
          const secondToken = tokens[1];
          if ((node.type === "NewExpression" || node.prefix) && firstToken.type === "Keyword") {
            checkUnaryWordOperatorForSpaces(node, firstToken, secondToken, firstToken.value);
            return;
          }
          const operator = node.prefix ? tokens[0].value : tokens[1].value;
          if (overrideExistsForOperator(operator)) {
            if (overrideEnforcesSpaces(operator)) {
              verifyNonWordsHaveSpaces(node, firstToken, secondToken);
            } else {
              verifyNonWordsDontHaveSpaces(node, firstToken, secondToken);
            }
          } else if (options.nonwords) {
            verifyNonWordsHaveSpaces(node, firstToken, secondToken);
          } else {
            verifyNonWordsDontHaveSpaces(node, firstToken, secondToken);
          }
        }
        return {
          UnaryExpression: checkForSpaces,
          UpdateExpression: checkForSpaces,
          NewExpression: checkForSpaces,
          YieldExpression: checkForSpacesAfterYield,
          AwaitExpression: checkForSpacesAfterAwait
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/spaced-comment.js
var require_spaced_comment = __commonJS({
  "node_modules/eslint/lib/rules/spaced-comment.js"(exports, module2) {
    "use strict";
    var escapeRegExp = require_escape_string_regexp2();
    var astUtils = require_ast_utils2();
    function escape2(s) {
      return `(?:${escapeRegExp(s)})`;
    }
    function escapeAndRepeat(s) {
      return `${escape2(s)}+`;
    }
    function parseMarkersOption(markers) {
      if (!markers.includes("*")) {
        return markers.concat("*");
      }
      return markers;
    }
    function createExceptionsPattern(exceptions) {
      let pattern = "";
      if (exceptions.length === 0) {
        pattern += "\\s";
      } else {
        pattern += "(?:\\s|";
        if (exceptions.length === 1) {
          pattern += escapeAndRepeat(exceptions[0]);
        } else {
          pattern += "(?:";
          pattern += exceptions.map(escapeAndRepeat).join("|");
          pattern += ")";
        }
        pattern += `(?:$|[${Array.from(astUtils.LINEBREAKS).join("")}]))`;
      }
      return pattern;
    }
    function createAlwaysStylePattern(markers, exceptions) {
      let pattern = "^";
      if (markers.length === 1) {
        pattern += escape2(markers[0]);
      } else {
        pattern += "(?:";
        pattern += markers.map(escape2).join("|");
        pattern += ")";
      }
      pattern += "?";
      pattern += createExceptionsPattern(exceptions);
      return new RegExp(pattern, "u");
    }
    function createNeverStylePattern(markers) {
      const pattern = `^(${markers.map(escape2).join("|")})?[ 	]+`;
      return new RegExp(pattern, "u");
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce consistent spacing after the `//` or `/*` in a comment",
          recommended: false,
          url: "https://eslint.org/docs/rules/spaced-comment"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              exceptions: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              markers: {
                type: "array",
                items: {
                  type: "string"
                }
              },
              line: {
                type: "object",
                properties: {
                  exceptions: {
                    type: "array",
                    items: {
                      type: "string"
                    }
                  },
                  markers: {
                    type: "array",
                    items: {
                      type: "string"
                    }
                  }
                },
                additionalProperties: false
              },
              block: {
                type: "object",
                properties: {
                  exceptions: {
                    type: "array",
                    items: {
                      type: "string"
                    }
                  },
                  markers: {
                    type: "array",
                    items: {
                      type: "string"
                    }
                  },
                  balanced: {
                    type: "boolean",
                    default: false
                  }
                },
                additionalProperties: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          unexpectedSpaceAfterMarker: "Unexpected space or tab after marker ({{refChar}}) in comment.",
          expectedExceptionAfter: "Expected exception block, space or tab after '{{refChar}}' in comment.",
          unexpectedSpaceBefore: "Unexpected space or tab before '*/' in comment.",
          unexpectedSpaceAfter: "Unexpected space or tab after '{{refChar}}' in comment.",
          expectedSpaceBefore: "Expected space or tab before '*/' in comment.",
          expectedSpaceAfter: "Expected space or tab after '{{refChar}}' in comment."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const requireSpace = context.options[0] !== "never";
        const config = context.options[1] || {};
        const balanced = config.block && config.block.balanced;
        const styleRules = ["block", "line"].reduce((rule, type) => {
          const markers = parseMarkersOption(config[type] && config[type].markers || config.markers || []);
          const exceptions = config[type] && config[type].exceptions || config.exceptions || [];
          const endNeverPattern = "[ 	]+$";
          rule[type] = {
            beginRegex: requireSpace ? createAlwaysStylePattern(markers, exceptions) : createNeverStylePattern(markers),
            endRegex: balanced && requireSpace ? new RegExp(`${createExceptionsPattern(exceptions)}$`, "u") : new RegExp(endNeverPattern, "u"),
            hasExceptions: exceptions.length > 0,
            captureMarker: new RegExp(`^(${markers.map(escape2).join("|")})`, "u"),
            markers: new Set(markers)
          };
          return rule;
        }, {});
        function reportBegin(node, messageId, match, refChar) {
          const type = node.type.toLowerCase(), commentIdentifier = type === "block" ? "/*" : "//";
          context.report({
            node,
            fix(fixer) {
              const start = node.range[0];
              let end = start + 2;
              if (requireSpace) {
                if (match) {
                  end += match[0].length;
                }
                return fixer.insertTextAfterRange([start, end], " ");
              }
              end += match[0].length;
              return fixer.replaceTextRange([start, end], commentIdentifier + (match[1] ? match[1] : ""));
            },
            messageId,
            data: { refChar }
          });
        }
        function reportEnd(node, messageId, match) {
          context.report({
            node,
            fix(fixer) {
              if (requireSpace) {
                return fixer.insertTextAfterRange([node.range[0], node.range[1] - 2], " ");
              }
              const end = node.range[1] - 2, start = end - match[0].length;
              return fixer.replaceTextRange([start, end], "");
            },
            messageId
          });
        }
        function checkCommentForSpace(node) {
          const type = node.type.toLowerCase(), rule = styleRules[type], commentIdentifier = type === "block" ? "/*" : "//";
          if (node.value.length === 0 || rule.markers.has(node.value)) {
            return;
          }
          const beginMatch = rule.beginRegex.exec(node.value);
          const endMatch = rule.endRegex.exec(node.value);
          if (requireSpace) {
            if (!beginMatch) {
              const hasMarker = rule.captureMarker.exec(node.value);
              const marker = hasMarker ? commentIdentifier + hasMarker[0] : commentIdentifier;
              if (rule.hasExceptions) {
                reportBegin(node, "expectedExceptionAfter", hasMarker, marker);
              } else {
                reportBegin(node, "expectedSpaceAfter", hasMarker, marker);
              }
            }
            if (balanced && type === "block" && !endMatch) {
              reportEnd(node, "expectedSpaceBefore");
            }
          } else {
            if (beginMatch) {
              if (!beginMatch[1]) {
                reportBegin(node, "unexpectedSpaceAfter", beginMatch, commentIdentifier);
              } else {
                reportBegin(node, "unexpectedSpaceAfterMarker", beginMatch, beginMatch[1]);
              }
            }
            if (balanced && type === "block" && endMatch) {
              reportEnd(node, "unexpectedSpaceBefore", endMatch);
            }
          }
        }
        return {
          Program() {
            const comments = sourceCode.getAllComments();
            comments.filter((token) => token.type !== "Shebang").forEach(checkCommentForSpace);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/strict.js
var require_strict = __commonJS({
  "node_modules/eslint/lib/rules/strict.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function getUseStrictDirectives(statements) {
      const directives = [];
      for (let i = 0; i < statements.length; i++) {
        const statement = statements[i];
        if (statement.type === "ExpressionStatement" && statement.expression.type === "Literal" && statement.expression.value === "use strict") {
          directives[i] = statement;
        } else {
          break;
        }
      }
      return directives;
    }
    function isSimpleParameter(node) {
      return node.type === "Identifier";
    }
    function isSimpleParameterList(params) {
      return params.every(isSimpleParameter);
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require or disallow strict mode directives",
          recommended: false,
          url: "https://eslint.org/docs/rules/strict"
        },
        schema: [
          {
            enum: ["never", "global", "function", "safe"]
          }
        ],
        fixable: "code",
        messages: {
          function: "Use the function form of 'use strict'.",
          global: "Use the global form of 'use strict'.",
          multiple: "Multiple 'use strict' directives.",
          never: "Strict mode is not permitted.",
          unnecessary: "Unnecessary 'use strict' directive.",
          module: "'use strict' is unnecessary inside of modules.",
          implied: "'use strict' is unnecessary when implied strict mode is enabled.",
          unnecessaryInClasses: "'use strict' is unnecessary inside of classes.",
          nonSimpleParameterList: "'use strict' directive inside a function with non-simple parameter list throws a syntax error since ES2016.",
          wrap: "Wrap {{name}} in a function with 'use strict' directive."
        }
      },
      create(context) {
        const ecmaFeatures = context.parserOptions.ecmaFeatures || {}, scopes = [], classScopes = [];
        let mode = context.options[0] || "safe";
        if (ecmaFeatures.impliedStrict) {
          mode = "implied";
        } else if (mode === "safe") {
          mode = ecmaFeatures.globalReturn || context.languageOptions.sourceType === "commonjs" ? "global" : "function";
        }
        function shouldFix(errorType) {
          return errorType === "multiple" || errorType === "unnecessary" || errorType === "module" || errorType === "implied" || errorType === "unnecessaryInClasses";
        }
        function getFixFunction(node) {
          return (fixer) => fixer.remove(node);
        }
        function reportSlice(nodes, start, end, messageId, fix) {
          nodes.slice(start, end).forEach((node) => {
            context.report({ node, messageId, fix: fix ? getFixFunction(node) : null });
          });
        }
        function reportAll(nodes, messageId, fix) {
          reportSlice(nodes, 0, nodes.length, messageId, fix);
        }
        function reportAllExceptFirst(nodes, messageId, fix) {
          reportSlice(nodes, 1, nodes.length, messageId, fix);
        }
        function enterFunctionInFunctionMode(node, useStrictDirectives) {
          const isInClass = classScopes.length > 0, isParentGlobal = scopes.length === 0 && classScopes.length === 0, isParentStrict = scopes.length > 0 && scopes[scopes.length - 1], isStrict = useStrictDirectives.length > 0;
          if (isStrict) {
            if (!isSimpleParameterList(node.params)) {
              context.report({ node: useStrictDirectives[0], messageId: "nonSimpleParameterList" });
            } else if (isParentStrict) {
              context.report({ node: useStrictDirectives[0], messageId: "unnecessary", fix: getFixFunction(useStrictDirectives[0]) });
            } else if (isInClass) {
              context.report({ node: useStrictDirectives[0], messageId: "unnecessaryInClasses", fix: getFixFunction(useStrictDirectives[0]) });
            }
            reportAllExceptFirst(useStrictDirectives, "multiple", true);
          } else if (isParentGlobal) {
            if (isSimpleParameterList(node.params)) {
              context.report({ node, messageId: "function" });
            } else {
              context.report({
                node,
                messageId: "wrap",
                data: { name: astUtils.getFunctionNameWithKind(node) }
              });
            }
          }
          scopes.push(isParentStrict || isStrict);
        }
        function exitFunctionInFunctionMode() {
          scopes.pop();
        }
        function enterFunction(node) {
          const isBlock = node.body.type === "BlockStatement", useStrictDirectives = isBlock ? getUseStrictDirectives(node.body.body) : [];
          if (mode === "function") {
            enterFunctionInFunctionMode(node, useStrictDirectives);
          } else if (useStrictDirectives.length > 0) {
            if (isSimpleParameterList(node.params)) {
              reportAll(useStrictDirectives, mode, shouldFix(mode));
            } else {
              context.report({ node: useStrictDirectives[0], messageId: "nonSimpleParameterList" });
              reportAllExceptFirst(useStrictDirectives, "multiple", true);
            }
          }
        }
        const rule = {
          Program(node) {
            const useStrictDirectives = getUseStrictDirectives(node.body);
            if (node.sourceType === "module") {
              mode = "module";
            }
            if (mode === "global") {
              if (node.body.length > 0 && useStrictDirectives.length === 0) {
                context.report({ node, messageId: "global" });
              }
              reportAllExceptFirst(useStrictDirectives, "multiple", true);
            } else {
              reportAll(useStrictDirectives, mode, shouldFix(mode));
            }
          },
          FunctionDeclaration: enterFunction,
          FunctionExpression: enterFunction,
          ArrowFunctionExpression: enterFunction
        };
        if (mode === "function") {
          Object.assign(rule, {
            // Inside of class bodies are always strict mode.
            ClassBody() {
              classScopes.push(true);
            },
            "ClassBody:exit"() {
              classScopes.pop();
            },
            "FunctionDeclaration:exit": exitFunctionInFunctionMode,
            "FunctionExpression:exit": exitFunctionInFunctionMode,
            "ArrowFunctionExpression:exit": exitFunctionInFunctionMode
          });
        }
        return rule;
      }
    };
  }
});

// node_modules/eslint/lib/rules/switch-colon-spacing.js
var require_switch_colon_spacing = __commonJS({
  "node_modules/eslint/lib/rules/switch-colon-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Enforce spacing around colons of switch statements",
          recommended: false,
          url: "https://eslint.org/docs/rules/switch-colon-spacing"
        },
        schema: [
          {
            type: "object",
            properties: {
              before: { type: "boolean", default: false },
              after: { type: "boolean", default: true }
            },
            additionalProperties: false
          }
        ],
        fixable: "whitespace",
        messages: {
          expectedBefore: "Expected space(s) before this colon.",
          expectedAfter: "Expected space(s) after this colon.",
          unexpectedBefore: "Unexpected space(s) before this colon.",
          unexpectedAfter: "Unexpected space(s) after this colon."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const options = context.options[0] || {};
        const beforeSpacing = options.before === true;
        const afterSpacing = options.after !== false;
        function isValidSpacing(left, right, expected) {
          return astUtils.isClosingBraceToken(right) || !astUtils.isTokenOnSameLine(left, right) || sourceCode.isSpaceBetweenTokens(left, right) === expected;
        }
        function commentsExistBetween(left, right) {
          return sourceCode.getFirstTokenBetween(
            left,
            right,
            {
              includeComments: true,
              filter: astUtils.isCommentToken
            }
          ) !== null;
        }
        function fix(fixer, left, right, spacing) {
          if (commentsExistBetween(left, right)) {
            return null;
          }
          if (spacing) {
            return fixer.insertTextAfter(left, " ");
          }
          return fixer.removeRange([left.range[1], right.range[0]]);
        }
        return {
          SwitchCase(node) {
            const colonToken = astUtils.getSwitchCaseColonToken(node, sourceCode);
            const beforeToken = sourceCode.getTokenBefore(colonToken);
            const afterToken = sourceCode.getTokenAfter(colonToken);
            if (!isValidSpacing(beforeToken, colonToken, beforeSpacing)) {
              context.report({
                node,
                loc: colonToken.loc,
                messageId: beforeSpacing ? "expectedBefore" : "unexpectedBefore",
                fix: (fixer) => fix(fixer, beforeToken, colonToken, beforeSpacing)
              });
            }
            if (!isValidSpacing(colonToken, afterToken, afterSpacing)) {
              context.report({
                node,
                loc: colonToken.loc,
                messageId: afterSpacing ? "expectedAfter" : "unexpectedAfter",
                fix: (fixer) => fix(fixer, colonToken, afterToken, afterSpacing)
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/symbol-description.js
var require_symbol_description = __commonJS({
  "node_modules/eslint/lib/rules/symbol-description.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require symbol descriptions",
          recommended: false,
          url: "https://eslint.org/docs/rules/symbol-description"
        },
        fixable: null,
        schema: [],
        messages: {
          expected: "Expected Symbol to have a description."
        }
      },
      create(context) {
        function checkArgument(node) {
          if (node.arguments.length === 0) {
            context.report({
              node,
              messageId: "expected"
            });
          }
        }
        return {
          "Program:exit"() {
            const scope = context.getScope();
            const variable = astUtils.getVariableByName(scope, "Symbol");
            if (variable && variable.defs.length === 0) {
              variable.references.forEach((reference) => {
                const node = reference.identifier;
                if (astUtils.isCallee(node)) {
                  checkArgument(node.parent);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/template-curly-spacing.js
var require_template_curly_spacing = __commonJS({
  "node_modules/eslint/lib/rules/template-curly-spacing.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow spacing around embedded expressions of template strings",
          recommended: false,
          url: "https://eslint.org/docs/rules/template-curly-spacing"
        },
        fixable: "whitespace",
        schema: [
          { enum: ["always", "never"] }
        ],
        messages: {
          expectedBefore: "Expected space(s) before '}'.",
          expectedAfter: "Expected space(s) after '${'.",
          unexpectedBefore: "Unexpected space(s) before '}'.",
          unexpectedAfter: "Unexpected space(s) after '${'."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const always = context.options[0] === "always";
        function checkSpacingBefore(token) {
          if (!token.value.startsWith("}")) {
            return;
          }
          const prevToken = sourceCode.getTokenBefore(token, { includeComments: true }), hasSpace = sourceCode.isSpaceBetween(prevToken, token);
          if (!astUtils.isTokenOnSameLine(prevToken, token)) {
            return;
          }
          if (always && !hasSpace) {
            context.report({
              loc: {
                start: token.loc.start,
                end: {
                  line: token.loc.start.line,
                  column: token.loc.start.column + 1
                }
              },
              messageId: "expectedBefore",
              fix: (fixer) => fixer.insertTextBefore(token, " ")
            });
          }
          if (!always && hasSpace) {
            context.report({
              loc: {
                start: prevToken.loc.end,
                end: token.loc.start
              },
              messageId: "unexpectedBefore",
              fix: (fixer) => fixer.removeRange([prevToken.range[1], token.range[0]])
            });
          }
        }
        function checkSpacingAfter(token) {
          if (!token.value.endsWith("${")) {
            return;
          }
          const nextToken = sourceCode.getTokenAfter(token, { includeComments: true }), hasSpace = sourceCode.isSpaceBetween(token, nextToken);
          if (!astUtils.isTokenOnSameLine(token, nextToken)) {
            return;
          }
          if (always && !hasSpace) {
            context.report({
              loc: {
                start: {
                  line: token.loc.end.line,
                  column: token.loc.end.column - 2
                },
                end: token.loc.end
              },
              messageId: "expectedAfter",
              fix: (fixer) => fixer.insertTextAfter(token, " ")
            });
          }
          if (!always && hasSpace) {
            context.report({
              loc: {
                start: token.loc.end,
                end: nextToken.loc.start
              },
              messageId: "unexpectedAfter",
              fix: (fixer) => fixer.removeRange([token.range[1], nextToken.range[0]])
            });
          }
        }
        return {
          TemplateElement(node) {
            const token = sourceCode.getFirstToken(node);
            checkSpacingBefore(token);
            checkSpacingAfter(token);
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/template-tag-spacing.js
var require_template_tag_spacing = __commonJS({
  "node_modules/eslint/lib/rules/template-tag-spacing.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow spacing between template tags and their literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/template-tag-spacing"
        },
        fixable: "whitespace",
        schema: [
          { enum: ["always", "never"] }
        ],
        messages: {
          unexpected: "Unexpected space between template tag and template literal.",
          missing: "Missing space between template tag and template literal."
        }
      },
      create(context) {
        const never = context.options[0] !== "always";
        const sourceCode = context.getSourceCode();
        function checkSpacing(node) {
          const tagToken = sourceCode.getTokenBefore(node.quasi);
          const literalToken = sourceCode.getFirstToken(node.quasi);
          const hasWhitespace = sourceCode.isSpaceBetweenTokens(tagToken, literalToken);
          if (never && hasWhitespace) {
            context.report({
              node,
              loc: {
                start: tagToken.loc.end,
                end: literalToken.loc.start
              },
              messageId: "unexpected",
              fix(fixer) {
                const comments = sourceCode.getCommentsBefore(node.quasi);
                if (comments.some((comment) => comment.type === "Line")) {
                  return null;
                }
                return fixer.replaceTextRange(
                  [tagToken.range[1], literalToken.range[0]],
                  comments.reduce((text, comment) => text + sourceCode.getText(comment), "")
                );
              }
            });
          } else if (!never && !hasWhitespace) {
            context.report({
              node,
              loc: {
                start: node.loc.start,
                end: literalToken.loc.start
              },
              messageId: "missing",
              fix(fixer) {
                return fixer.insertTextAfter(tagToken, " ");
              }
            });
          }
        }
        return {
          TaggedTemplateExpression: checkSpacing
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/unicode-bom.js
var require_unicode_bom = __commonJS({
  "node_modules/eslint/lib/rules/unicode-bom.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow Unicode byte order mark (BOM)",
          recommended: false,
          url: "https://eslint.org/docs/rules/unicode-bom"
        },
        fixable: "whitespace",
        schema: [
          {
            enum: ["always", "never"]
          }
        ],
        messages: {
          expected: "Expected Unicode BOM (Byte Order Mark).",
          unexpected: "Unexpected Unicode BOM (Byte Order Mark)."
        }
      },
      create(context) {
        return {
          Program: function checkUnicodeBOM(node) {
            const sourceCode = context.getSourceCode(), location = { column: 0, line: 1 }, requireBOM = context.options[0] || "never";
            if (!sourceCode.hasBOM && requireBOM === "always") {
              context.report({
                node,
                loc: location,
                messageId: "expected",
                fix(fixer) {
                  return fixer.insertTextBeforeRange([0, 1], "\uFEFF");
                }
              });
            } else if (sourceCode.hasBOM && requireBOM === "never") {
              context.report({
                node,
                loc: location,
                messageId: "unexpected",
                fix(fixer) {
                  return fixer.removeRange([-1, 0]);
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/use-isnan.js
var require_use_isnan = __commonJS({
  "node_modules/eslint/lib/rules/use-isnan.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isNaNIdentifier(node) {
      return Boolean(node) && (astUtils.isSpecificId(node, "NaN") || astUtils.isSpecificMemberAccess(node, "Number", "NaN"));
    }
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Require calls to `isNaN()` when checking for `NaN`",
          recommended: true,
          url: "https://eslint.org/docs/rules/use-isnan"
        },
        schema: [
          {
            type: "object",
            properties: {
              enforceForSwitchCase: {
                type: "boolean",
                default: true
              },
              enforceForIndexOf: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          comparisonWithNaN: "Use the isNaN function to compare with NaN.",
          switchNaN: "'switch(NaN)' can never match a case clause. Use Number.isNaN instead of the switch.",
          caseNaN: "'case NaN' can never match. Use Number.isNaN before the switch.",
          indexOfNaN: "Array prototype method '{{ methodName }}' cannot find NaN."
        }
      },
      create(context) {
        const enforceForSwitchCase = !context.options[0] || context.options[0].enforceForSwitchCase;
        const enforceForIndexOf = context.options[0] && context.options[0].enforceForIndexOf;
        function checkBinaryExpression(node) {
          if (/^(?:[<>]|[!=]=)=?$/u.test(node.operator) && (isNaNIdentifier(node.left) || isNaNIdentifier(node.right))) {
            context.report({ node, messageId: "comparisonWithNaN" });
          }
        }
        function checkSwitchStatement(node) {
          if (isNaNIdentifier(node.discriminant)) {
            context.report({ node, messageId: "switchNaN" });
          }
          for (const switchCase of node.cases) {
            if (isNaNIdentifier(switchCase.test)) {
              context.report({ node: switchCase, messageId: "caseNaN" });
            }
          }
        }
        function checkCallExpression(node) {
          const callee = astUtils.skipChainExpression(node.callee);
          if (callee.type === "MemberExpression") {
            const methodName = astUtils.getStaticPropertyName(callee);
            if ((methodName === "indexOf" || methodName === "lastIndexOf") && node.arguments.length === 1 && isNaNIdentifier(node.arguments[0])) {
              context.report({ node, messageId: "indexOfNaN", data: { methodName } });
            }
          }
        }
        const listeners = {
          BinaryExpression: checkBinaryExpression
        };
        if (enforceForSwitchCase) {
          listeners.SwitchStatement = checkSwitchStatement;
        }
        if (enforceForIndexOf) {
          listeners.CallExpression = checkCallExpression;
        }
        return listeners;
      }
    };
  }
});

// node_modules/doctrine/package.json
var require_package5 = __commonJS({
  "node_modules/doctrine/package.json"(exports, module2) {
    module2.exports = {
      name: "doctrine",
      description: "JSDoc parser",
      homepage: "https://github.com/eslint/doctrine",
      main: "lib/doctrine.js",
      version: "3.0.0",
      engines: {
        node: ">=6.0.0"
      },
      directories: {
        lib: "./lib"
      },
      files: [
        "lib"
      ],
      maintainers: [
        {
          name: "Nicholas C. Zakas",
          email: "nicholas+npm@nczconsulting.com",
          web: "https://www.nczonline.net"
        },
        {
          name: "Yusuke Suzuki",
          email: "utatane.tea@gmail.com",
          web: "https://github.com/Constellation"
        }
      ],
      repository: "eslint/doctrine",
      devDependencies: {
        coveralls: "^3.0.1",
        dateformat: "^1.0.11",
        eslint: "^1.10.3",
        "eslint-release": "^1.0.0",
        linefix: "^0.1.1",
        mocha: "^3.4.2",
        "npm-license": "^0.3.1",
        nyc: "^10.3.2",
        semver: "^5.0.3",
        shelljs: "^0.5.3",
        "shelljs-nodecli": "^0.1.1",
        should: "^5.0.1"
      },
      license: "Apache-2.0",
      scripts: {
        pretest: "npm run lint",
        test: "nyc mocha",
        coveralls: "nyc report --reporter=text-lcov | coveralls",
        lint: "eslint lib/",
        "generate-release": "eslint-generate-release",
        "generate-alpharelease": "eslint-generate-prerelease alpha",
        "generate-betarelease": "eslint-generate-prerelease beta",
        "generate-rcrelease": "eslint-generate-prerelease rc",
        "publish-release": "eslint-publish-release"
      },
      dependencies: {
        esutils: "^2.0.2"
      }
    };
  }
});

// node_modules/doctrine/lib/utility.js
var require_utility = __commonJS({
  "node_modules/doctrine/lib/utility.js"(exports) {
    (function() {
      "use strict";
      var VERSION;
      VERSION = require_package5().version;
      exports.VERSION = VERSION;
      function DoctrineError(message) {
        this.name = "DoctrineError";
        this.message = message;
      }
      DoctrineError.prototype = function() {
        var Middle = function() {
        };
        Middle.prototype = Error.prototype;
        return new Middle();
      }();
      DoctrineError.prototype.constructor = DoctrineError;
      exports.DoctrineError = DoctrineError;
      function throwError(message) {
        throw new DoctrineError(message);
      }
      exports.throwError = throwError;
      exports.assert = require("assert");
    })();
  }
});

// node_modules/doctrine/lib/typed.js
var require_typed = __commonJS({
  "node_modules/doctrine/lib/typed.js"(exports) {
    (function() {
      "use strict";
      var Syntax, Token, source, length, index, previous, token, value2, esutils, utility, rangeOffset, addRange;
      esutils = require_utils2();
      utility = require_utility();
      Syntax = {
        NullableLiteral: "NullableLiteral",
        AllLiteral: "AllLiteral",
        NullLiteral: "NullLiteral",
        UndefinedLiteral: "UndefinedLiteral",
        VoidLiteral: "VoidLiteral",
        UnionType: "UnionType",
        ArrayType: "ArrayType",
        RecordType: "RecordType",
        FieldType: "FieldType",
        FunctionType: "FunctionType",
        ParameterType: "ParameterType",
        RestType: "RestType",
        NonNullableType: "NonNullableType",
        OptionalType: "OptionalType",
        NullableType: "NullableType",
        NameExpression: "NameExpression",
        TypeApplication: "TypeApplication",
        StringLiteralType: "StringLiteralType",
        NumericLiteralType: "NumericLiteralType",
        BooleanLiteralType: "BooleanLiteralType"
      };
      Token = {
        ILLEGAL: 0,
        // ILLEGAL
        DOT_LT: 1,
        // .<
        REST: 2,
        // ...
        LT: 3,
        // <
        GT: 4,
        // >
        LPAREN: 5,
        // (
        RPAREN: 6,
        // )
        LBRACE: 7,
        // {
        RBRACE: 8,
        // }
        LBRACK: 9,
        // [
        RBRACK: 10,
        // ]
        COMMA: 11,
        // ,
        COLON: 12,
        // :
        STAR: 13,
        // *
        PIPE: 14,
        // |
        QUESTION: 15,
        // ?
        BANG: 16,
        // !
        EQUAL: 17,
        // =
        NAME: 18,
        // name token
        STRING: 19,
        // string
        NUMBER: 20,
        // number
        EOF: 21
      };
      function isTypeName(ch) {
        return "><(){}[],:*|?!=".indexOf(String.fromCharCode(ch)) === -1 && !esutils.code.isWhiteSpace(ch) && !esutils.code.isLineTerminator(ch);
      }
      function Context(previous2, index2, token2, value3) {
        this._previous = previous2;
        this._index = index2;
        this._token = token2;
        this._value = value3;
      }
      Context.prototype.restore = function() {
        previous = this._previous;
        index = this._index;
        token = this._token;
        value2 = this._value;
      };
      Context.save = function() {
        return new Context(previous, index, token, value2);
      };
      function maybeAddRange(node, range) {
        if (addRange) {
          node.range = [range[0] + rangeOffset, range[1] + rangeOffset];
        }
        return node;
      }
      function advance() {
        var ch = source.charAt(index);
        index += 1;
        return ch;
      }
      function scanHexEscape(prefix) {
        var i, len, ch, code = 0;
        len = prefix === "u" ? 4 : 2;
        for (i = 0; i < len; ++i) {
          if (index < length && esutils.code.isHexDigit(source.charCodeAt(index))) {
            ch = advance();
            code = code * 16 + "0123456789abcdef".indexOf(ch.toLowerCase());
          } else {
            return "";
          }
        }
        return String.fromCharCode(code);
      }
      function scanString() {
        var str = "", quote, ch, code, unescaped, restore;
        quote = source.charAt(index);
        ++index;
        while (index < length) {
          ch = advance();
          if (ch === quote) {
            quote = "";
            break;
          } else if (ch === "\\") {
            ch = advance();
            if (!esutils.code.isLineTerminator(ch.charCodeAt(0))) {
              switch (ch) {
                case "n":
                  str += "\n";
                  break;
                case "r":
                  str += "\r";
                  break;
                case "t":
                  str += "	";
                  break;
                case "u":
                case "x":
                  restore = index;
                  unescaped = scanHexEscape(ch);
                  if (unescaped) {
                    str += unescaped;
                  } else {
                    index = restore;
                    str += ch;
                  }
                  break;
                case "b":
                  str += "\b";
                  break;
                case "f":
                  str += "\f";
                  break;
                case "v":
                  str += "\v";
                  break;
                default:
                  if (esutils.code.isOctalDigit(ch.charCodeAt(0))) {
                    code = "01234567".indexOf(ch);
                    if (index < length && esutils.code.isOctalDigit(source.charCodeAt(index))) {
                      code = code * 8 + "01234567".indexOf(advance());
                      if ("0123".indexOf(ch) >= 0 && index < length && esutils.code.isOctalDigit(source.charCodeAt(index))) {
                        code = code * 8 + "01234567".indexOf(advance());
                      }
                    }
                    str += String.fromCharCode(code);
                  } else {
                    str += ch;
                  }
                  break;
              }
            } else {
              if (ch === "\r" && source.charCodeAt(index) === 10) {
                ++index;
              }
            }
          } else if (esutils.code.isLineTerminator(ch.charCodeAt(0))) {
            break;
          } else {
            str += ch;
          }
        }
        if (quote !== "") {
          utility.throwError("unexpected quote");
        }
        value2 = str;
        return Token.STRING;
      }
      function scanNumber() {
        var number, ch;
        number = "";
        ch = source.charCodeAt(index);
        if (ch !== 46) {
          number = advance();
          ch = source.charCodeAt(index);
          if (number === "0") {
            if (ch === 120 || ch === 88) {
              number += advance();
              while (index < length) {
                ch = source.charCodeAt(index);
                if (!esutils.code.isHexDigit(ch)) {
                  break;
                }
                number += advance();
              }
              if (number.length <= 2) {
                utility.throwError("unexpected token");
              }
              if (index < length) {
                ch = source.charCodeAt(index);
                if (esutils.code.isIdentifierStartES5(ch)) {
                  utility.throwError("unexpected token");
                }
              }
              value2 = parseInt(number, 16);
              return Token.NUMBER;
            }
            if (esutils.code.isOctalDigit(ch)) {
              number += advance();
              while (index < length) {
                ch = source.charCodeAt(index);
                if (!esutils.code.isOctalDigit(ch)) {
                  break;
                }
                number += advance();
              }
              if (index < length) {
                ch = source.charCodeAt(index);
                if (esutils.code.isIdentifierStartES5(ch) || esutils.code.isDecimalDigit(ch)) {
                  utility.throwError("unexpected token");
                }
              }
              value2 = parseInt(number, 8);
              return Token.NUMBER;
            }
            if (esutils.code.isDecimalDigit(ch)) {
              utility.throwError("unexpected token");
            }
          }
          while (index < length) {
            ch = source.charCodeAt(index);
            if (!esutils.code.isDecimalDigit(ch)) {
              break;
            }
            number += advance();
          }
        }
        if (ch === 46) {
          number += advance();
          while (index < length) {
            ch = source.charCodeAt(index);
            if (!esutils.code.isDecimalDigit(ch)) {
              break;
            }
            number += advance();
          }
        }
        if (ch === 101 || ch === 69) {
          number += advance();
          ch = source.charCodeAt(index);
          if (ch === 43 || ch === 45) {
            number += advance();
          }
          ch = source.charCodeAt(index);
          if (esutils.code.isDecimalDigit(ch)) {
            number += advance();
            while (index < length) {
              ch = source.charCodeAt(index);
              if (!esutils.code.isDecimalDigit(ch)) {
                break;
              }
              number += advance();
            }
          } else {
            utility.throwError("unexpected token");
          }
        }
        if (index < length) {
          ch = source.charCodeAt(index);
          if (esutils.code.isIdentifierStartES5(ch)) {
            utility.throwError("unexpected token");
          }
        }
        value2 = parseFloat(number);
        return Token.NUMBER;
      }
      function scanTypeName() {
        var ch, ch2;
        value2 = advance();
        while (index < length && isTypeName(source.charCodeAt(index))) {
          ch = source.charCodeAt(index);
          if (ch === 46) {
            if (index + 1 >= length) {
              return Token.ILLEGAL;
            }
            ch2 = source.charCodeAt(index + 1);
            if (ch2 === 60) {
              break;
            }
          }
          value2 += advance();
        }
        return Token.NAME;
      }
      function next() {
        var ch;
        previous = index;
        while (index < length && esutils.code.isWhiteSpace(source.charCodeAt(index))) {
          advance();
        }
        if (index >= length) {
          token = Token.EOF;
          return token;
        }
        ch = source.charCodeAt(index);
        switch (ch) {
          case 39:
          case 34:
            token = scanString();
            return token;
          case 58:
            advance();
            token = Token.COLON;
            return token;
          case 44:
            advance();
            token = Token.COMMA;
            return token;
          case 40:
            advance();
            token = Token.LPAREN;
            return token;
          case 41:
            advance();
            token = Token.RPAREN;
            return token;
          case 91:
            advance();
            token = Token.LBRACK;
            return token;
          case 93:
            advance();
            token = Token.RBRACK;
            return token;
          case 123:
            advance();
            token = Token.LBRACE;
            return token;
          case 125:
            advance();
            token = Token.RBRACE;
            return token;
          case 46:
            if (index + 1 < length) {
              ch = source.charCodeAt(index + 1);
              if (ch === 60) {
                advance();
                advance();
                token = Token.DOT_LT;
                return token;
              }
              if (ch === 46 && index + 2 < length && source.charCodeAt(index + 2) === 46) {
                advance();
                advance();
                advance();
                token = Token.REST;
                return token;
              }
              if (esutils.code.isDecimalDigit(ch)) {
                token = scanNumber();
                return token;
              }
            }
            token = Token.ILLEGAL;
            return token;
          case 60:
            advance();
            token = Token.LT;
            return token;
          case 62:
            advance();
            token = Token.GT;
            return token;
          case 42:
            advance();
            token = Token.STAR;
            return token;
          case 124:
            advance();
            token = Token.PIPE;
            return token;
          case 63:
            advance();
            token = Token.QUESTION;
            return token;
          case 33:
            advance();
            token = Token.BANG;
            return token;
          case 61:
            advance();
            token = Token.EQUAL;
            return token;
          case 45:
            token = scanNumber();
            return token;
          default:
            if (esutils.code.isDecimalDigit(ch)) {
              token = scanNumber();
              return token;
            }
            utility.assert(isTypeName(ch));
            token = scanTypeName();
            return token;
        }
      }
      function consume(target, text) {
        utility.assert(token === target, text || "consumed token not matched");
        next();
      }
      function expect(target, message) {
        if (token !== target) {
          utility.throwError(message || "unexpected token");
        }
        next();
      }
      function parseUnionType() {
        var elements, startIndex = index - 1;
        consume(Token.LPAREN, "UnionType should start with (");
        elements = [];
        if (token !== Token.RPAREN) {
          while (true) {
            elements.push(parseTypeExpression());
            if (token === Token.RPAREN) {
              break;
            }
            expect(Token.PIPE);
          }
        }
        consume(Token.RPAREN, "UnionType should end with )");
        return maybeAddRange({
          type: Syntax.UnionType,
          elements
        }, [startIndex, previous]);
      }
      function parseArrayType() {
        var elements, startIndex = index - 1, restStartIndex;
        consume(Token.LBRACK, "ArrayType should start with [");
        elements = [];
        while (token !== Token.RBRACK) {
          if (token === Token.REST) {
            restStartIndex = index - 3;
            consume(Token.REST);
            elements.push(maybeAddRange({
              type: Syntax.RestType,
              expression: parseTypeExpression()
            }, [restStartIndex, previous]));
            break;
          } else {
            elements.push(parseTypeExpression());
          }
          if (token !== Token.RBRACK) {
            expect(Token.COMMA);
          }
        }
        expect(Token.RBRACK);
        return maybeAddRange({
          type: Syntax.ArrayType,
          elements
        }, [startIndex, previous]);
      }
      function parseFieldName() {
        var v = value2;
        if (token === Token.NAME || token === Token.STRING) {
          next();
          return v;
        }
        if (token === Token.NUMBER) {
          consume(Token.NUMBER);
          return String(v);
        }
        utility.throwError("unexpected token");
      }
      function parseFieldType() {
        var key, rangeStart = previous;
        key = parseFieldName();
        if (token === Token.COLON) {
          consume(Token.COLON);
          return maybeAddRange({
            type: Syntax.FieldType,
            key,
            value: parseTypeExpression()
          }, [rangeStart, previous]);
        }
        return maybeAddRange({
          type: Syntax.FieldType,
          key,
          value: null
        }, [rangeStart, previous]);
      }
      function parseRecordType() {
        var fields, rangeStart = index - 1, rangeEnd;
        consume(Token.LBRACE, "RecordType should start with {");
        fields = [];
        if (token === Token.COMMA) {
          consume(Token.COMMA);
        } else {
          while (token !== Token.RBRACE) {
            fields.push(parseFieldType());
            if (token !== Token.RBRACE) {
              expect(Token.COMMA);
            }
          }
        }
        rangeEnd = index;
        expect(Token.RBRACE);
        return maybeAddRange({
          type: Syntax.RecordType,
          fields
        }, [rangeStart, rangeEnd]);
      }
      function parseNameExpression() {
        var name = value2, rangeStart = index - name.length;
        expect(Token.NAME);
        if (token === Token.COLON && (name === "module" || name === "external" || name === "event")) {
          consume(Token.COLON);
          name += ":" + value2;
          expect(Token.NAME);
        }
        return maybeAddRange({
          type: Syntax.NameExpression,
          name
        }, [rangeStart, previous]);
      }
      function parseTypeExpressionList() {
        var elements = [];
        elements.push(parseTop());
        while (token === Token.COMMA) {
          consume(Token.COMMA);
          elements.push(parseTop());
        }
        return elements;
      }
      function parseTypeName() {
        var expr, applications, startIndex = index - value2.length;
        expr = parseNameExpression();
        if (token === Token.DOT_LT || token === Token.LT) {
          next();
          applications = parseTypeExpressionList();
          expect(Token.GT);
          return maybeAddRange({
            type: Syntax.TypeApplication,
            expression: expr,
            applications
          }, [startIndex, previous]);
        }
        return expr;
      }
      function parseResultType() {
        consume(Token.COLON, "ResultType should start with :");
        if (token === Token.NAME && value2 === "void") {
          consume(Token.NAME);
          return {
            type: Syntax.VoidLiteral
          };
        }
        return parseTypeExpression();
      }
      function parseParametersType() {
        var params = [], optionalSequence = false, expr, rest = false, startIndex, restStartIndex = index - 3, nameStartIndex;
        while (token !== Token.RPAREN) {
          if (token === Token.REST) {
            consume(Token.REST);
            rest = true;
          }
          startIndex = previous;
          expr = parseTypeExpression();
          if (expr.type === Syntax.NameExpression && token === Token.COLON) {
            nameStartIndex = previous - expr.name.length;
            consume(Token.COLON);
            expr = maybeAddRange({
              type: Syntax.ParameterType,
              name: expr.name,
              expression: parseTypeExpression()
            }, [nameStartIndex, previous]);
          }
          if (token === Token.EQUAL) {
            consume(Token.EQUAL);
            expr = maybeAddRange({
              type: Syntax.OptionalType,
              expression: expr
            }, [startIndex, previous]);
            optionalSequence = true;
          } else {
            if (optionalSequence) {
              utility.throwError("unexpected token");
            }
          }
          if (rest) {
            expr = maybeAddRange({
              type: Syntax.RestType,
              expression: expr
            }, [restStartIndex, previous]);
          }
          params.push(expr);
          if (token !== Token.RPAREN) {
            expect(Token.COMMA);
          }
        }
        return params;
      }
      function parseFunctionType() {
        var isNew, thisBinding, params, result, fnType, startIndex = index - value2.length;
        utility.assert(token === Token.NAME && value2 === "function", "FunctionType should start with 'function'");
        consume(Token.NAME);
        expect(Token.LPAREN);
        isNew = false;
        params = [];
        thisBinding = null;
        if (token !== Token.RPAREN) {
          if (token === Token.NAME && (value2 === "this" || value2 === "new")) {
            isNew = value2 === "new";
            consume(Token.NAME);
            expect(Token.COLON);
            thisBinding = parseTypeName();
            if (token === Token.COMMA) {
              consume(Token.COMMA);
              params = parseParametersType();
            }
          } else {
            params = parseParametersType();
          }
        }
        expect(Token.RPAREN);
        result = null;
        if (token === Token.COLON) {
          result = parseResultType();
        }
        fnType = maybeAddRange({
          type: Syntax.FunctionType,
          params,
          result
        }, [startIndex, previous]);
        if (thisBinding) {
          fnType["this"] = thisBinding;
          if (isNew) {
            fnType["new"] = true;
          }
        }
        return fnType;
      }
      function parseBasicTypeExpression() {
        var context, startIndex;
        switch (token) {
          case Token.STAR:
            consume(Token.STAR);
            return maybeAddRange({
              type: Syntax.AllLiteral
            }, [previous - 1, previous]);
          case Token.LPAREN:
            return parseUnionType();
          case Token.LBRACK:
            return parseArrayType();
          case Token.LBRACE:
            return parseRecordType();
          case Token.NAME:
            startIndex = index - value2.length;
            if (value2 === "null") {
              consume(Token.NAME);
              return maybeAddRange({
                type: Syntax.NullLiteral
              }, [startIndex, previous]);
            }
            if (value2 === "undefined") {
              consume(Token.NAME);
              return maybeAddRange({
                type: Syntax.UndefinedLiteral
              }, [startIndex, previous]);
            }
            if (value2 === "true" || value2 === "false") {
              consume(Token.NAME);
              return maybeAddRange({
                type: Syntax.BooleanLiteralType,
                value: value2 === "true"
              }, [startIndex, previous]);
            }
            context = Context.save();
            if (value2 === "function") {
              try {
                return parseFunctionType();
              } catch (e) {
                context.restore();
              }
            }
            return parseTypeName();
          case Token.STRING:
            next();
            return maybeAddRange({
              type: Syntax.StringLiteralType,
              value: value2
            }, [previous - value2.length - 2, previous]);
          case Token.NUMBER:
            next();
            return maybeAddRange({
              type: Syntax.NumericLiteralType,
              value: value2
            }, [previous - String(value2).length, previous]);
          default:
            utility.throwError("unexpected token");
        }
      }
      function parseTypeExpression() {
        var expr, rangeStart;
        if (token === Token.QUESTION) {
          rangeStart = index - 1;
          consume(Token.QUESTION);
          if (token === Token.COMMA || token === Token.EQUAL || token === Token.RBRACE || token === Token.RPAREN || token === Token.PIPE || token === Token.EOF || token === Token.RBRACK || token === Token.GT) {
            return maybeAddRange({
              type: Syntax.NullableLiteral
            }, [rangeStart, previous]);
          }
          return maybeAddRange({
            type: Syntax.NullableType,
            expression: parseBasicTypeExpression(),
            prefix: true
          }, [rangeStart, previous]);
        } else if (token === Token.BANG) {
          rangeStart = index - 1;
          consume(Token.BANG);
          return maybeAddRange({
            type: Syntax.NonNullableType,
            expression: parseBasicTypeExpression(),
            prefix: true
          }, [rangeStart, previous]);
        } else {
          rangeStart = previous;
        }
        expr = parseBasicTypeExpression();
        if (token === Token.BANG) {
          consume(Token.BANG);
          return maybeAddRange({
            type: Syntax.NonNullableType,
            expression: expr,
            prefix: false
          }, [rangeStart, previous]);
        }
        if (token === Token.QUESTION) {
          consume(Token.QUESTION);
          return maybeAddRange({
            type: Syntax.NullableType,
            expression: expr,
            prefix: false
          }, [rangeStart, previous]);
        }
        if (token === Token.LBRACK) {
          consume(Token.LBRACK);
          expect(Token.RBRACK, "expected an array-style type declaration (" + value2 + "[])");
          return maybeAddRange({
            type: Syntax.TypeApplication,
            expression: maybeAddRange({
              type: Syntax.NameExpression,
              name: "Array"
            }, [rangeStart, previous]),
            applications: [expr]
          }, [rangeStart, previous]);
        }
        return expr;
      }
      function parseTop() {
        var expr, elements;
        expr = parseTypeExpression();
        if (token !== Token.PIPE) {
          return expr;
        }
        elements = [expr];
        consume(Token.PIPE);
        while (true) {
          elements.push(parseTypeExpression());
          if (token !== Token.PIPE) {
            break;
          }
          consume(Token.PIPE);
        }
        return maybeAddRange({
          type: Syntax.UnionType,
          elements
        }, [0, index]);
      }
      function parseTopParamType() {
        var expr;
        if (token === Token.REST) {
          consume(Token.REST);
          return maybeAddRange({
            type: Syntax.RestType,
            expression: parseTop()
          }, [0, index]);
        }
        expr = parseTop();
        if (token === Token.EQUAL) {
          consume(Token.EQUAL);
          return maybeAddRange({
            type: Syntax.OptionalType,
            expression: expr
          }, [0, index]);
        }
        return expr;
      }
      function parseType(src, opt) {
        var expr;
        source = src;
        length = source.length;
        index = 0;
        previous = 0;
        addRange = opt && opt.range;
        rangeOffset = opt && opt.startIndex || 0;
        next();
        expr = parseTop();
        if (opt && opt.midstream) {
          return {
            expression: expr,
            index: previous
          };
        }
        if (token !== Token.EOF) {
          utility.throwError("not reach to EOF");
        }
        return expr;
      }
      function parseParamType(src, opt) {
        var expr;
        source = src;
        length = source.length;
        index = 0;
        previous = 0;
        addRange = opt && opt.range;
        rangeOffset = opt && opt.startIndex || 0;
        next();
        expr = parseTopParamType();
        if (opt && opt.midstream) {
          return {
            expression: expr,
            index: previous
          };
        }
        if (token !== Token.EOF) {
          utility.throwError("not reach to EOF");
        }
        return expr;
      }
      function stringifyImpl(node, compact, topLevel) {
        var result, i, iz;
        switch (node.type) {
          case Syntax.NullableLiteral:
            result = "?";
            break;
          case Syntax.AllLiteral:
            result = "*";
            break;
          case Syntax.NullLiteral:
            result = "null";
            break;
          case Syntax.UndefinedLiteral:
            result = "undefined";
            break;
          case Syntax.VoidLiteral:
            result = "void";
            break;
          case Syntax.UnionType:
            if (!topLevel) {
              result = "(";
            } else {
              result = "";
            }
            for (i = 0, iz = node.elements.length; i < iz; ++i) {
              result += stringifyImpl(node.elements[i], compact);
              if (i + 1 !== iz) {
                result += compact ? "|" : " | ";
              }
            }
            if (!topLevel) {
              result += ")";
            }
            break;
          case Syntax.ArrayType:
            result = "[";
            for (i = 0, iz = node.elements.length; i < iz; ++i) {
              result += stringifyImpl(node.elements[i], compact);
              if (i + 1 !== iz) {
                result += compact ? "," : ", ";
              }
            }
            result += "]";
            break;
          case Syntax.RecordType:
            result = "{";
            for (i = 0, iz = node.fields.length; i < iz; ++i) {
              result += stringifyImpl(node.fields[i], compact);
              if (i + 1 !== iz) {
                result += compact ? "," : ", ";
              }
            }
            result += "}";
            break;
          case Syntax.FieldType:
            if (node.value) {
              result = node.key + (compact ? ":" : ": ") + stringifyImpl(node.value, compact);
            } else {
              result = node.key;
            }
            break;
          case Syntax.FunctionType:
            result = compact ? "function(" : "function (";
            if (node["this"]) {
              if (node["new"]) {
                result += compact ? "new:" : "new: ";
              } else {
                result += compact ? "this:" : "this: ";
              }
              result += stringifyImpl(node["this"], compact);
              if (node.params.length !== 0) {
                result += compact ? "," : ", ";
              }
            }
            for (i = 0, iz = node.params.length; i < iz; ++i) {
              result += stringifyImpl(node.params[i], compact);
              if (i + 1 !== iz) {
                result += compact ? "," : ", ";
              }
            }
            result += ")";
            if (node.result) {
              result += (compact ? ":" : ": ") + stringifyImpl(node.result, compact);
            }
            break;
          case Syntax.ParameterType:
            result = node.name + (compact ? ":" : ": ") + stringifyImpl(node.expression, compact);
            break;
          case Syntax.RestType:
            result = "...";
            if (node.expression) {
              result += stringifyImpl(node.expression, compact);
            }
            break;
          case Syntax.NonNullableType:
            if (node.prefix) {
              result = "!" + stringifyImpl(node.expression, compact);
            } else {
              result = stringifyImpl(node.expression, compact) + "!";
            }
            break;
          case Syntax.OptionalType:
            result = stringifyImpl(node.expression, compact) + "=";
            break;
          case Syntax.NullableType:
            if (node.prefix) {
              result = "?" + stringifyImpl(node.expression, compact);
            } else {
              result = stringifyImpl(node.expression, compact) + "?";
            }
            break;
          case Syntax.NameExpression:
            result = node.name;
            break;
          case Syntax.TypeApplication:
            result = stringifyImpl(node.expression, compact) + ".<";
            for (i = 0, iz = node.applications.length; i < iz; ++i) {
              result += stringifyImpl(node.applications[i], compact);
              if (i + 1 !== iz) {
                result += compact ? "," : ", ";
              }
            }
            result += ">";
            break;
          case Syntax.StringLiteralType:
            result = '"' + node.value + '"';
            break;
          case Syntax.NumericLiteralType:
            result = String(node.value);
            break;
          case Syntax.BooleanLiteralType:
            result = String(node.value);
            break;
          default:
            utility.throwError("Unknown type " + node.type);
        }
        return result;
      }
      function stringify(node, options) {
        if (options == null) {
          options = {};
        }
        return stringifyImpl(node, options.compact, options.topLevel);
      }
      exports.parseType = parseType;
      exports.parseParamType = parseParamType;
      exports.stringify = stringify;
      exports.Syntax = Syntax;
    })();
  }
});

// node_modules/doctrine/lib/doctrine.js
var require_doctrine = __commonJS({
  "node_modules/doctrine/lib/doctrine.js"(exports) {
    (function() {
      "use strict";
      var typed, utility, jsdoc, esutils, hasOwnProperty;
      esutils = require_utils2();
      typed = require_typed();
      utility = require_utility();
      function sliceSource(source, index, last2) {
        return source.slice(index, last2);
      }
      hasOwnProperty = function() {
        var func = Object.prototype.hasOwnProperty;
        return function hasOwnProperty2(obj, name) {
          return func.call(obj, name);
        };
      }();
      function shallowCopy(obj) {
        var ret = {}, key;
        for (key in obj) {
          if (obj.hasOwnProperty(key)) {
            ret[key] = obj[key];
          }
        }
        return ret;
      }
      function isASCIIAlphanumeric(ch) {
        return ch >= 97 && ch <= 122 || ch >= 65 && ch <= 90 || ch >= 48 && ch <= 57;
      }
      function isParamTitle(title) {
        return title === "param" || title === "argument" || title === "arg";
      }
      function isReturnTitle(title) {
        return title === "return" || title === "returns";
      }
      function isProperty(title) {
        return title === "property" || title === "prop";
      }
      function isNameParameterRequired(title) {
        return isParamTitle(title) || isProperty(title) || title === "alias" || title === "this" || title === "mixes" || title === "requires";
      }
      function isAllowedName(title) {
        return isNameParameterRequired(title) || title === "const" || title === "constant";
      }
      function isAllowedNested(title) {
        return isProperty(title) || isParamTitle(title);
      }
      function isAllowedOptional(title) {
        return isProperty(title) || isParamTitle(title);
      }
      function isTypeParameterRequired(title) {
        return isParamTitle(title) || isReturnTitle(title) || title === "define" || title === "enum" || title === "implements" || title === "this" || title === "type" || title === "typedef" || isProperty(title);
      }
      function isAllowedType(title) {
        return isTypeParameterRequired(title) || title === "throws" || title === "const" || title === "constant" || title === "namespace" || title === "member" || title === "var" || title === "module" || title === "constructor" || title === "class" || title === "extends" || title === "augments" || title === "public" || title === "private" || title === "protected";
      }
      var WHITESPACE = "[ \\f\\t\\v\\u00a0\\u1680\\u180e\\u2000-\\u200a\\u202f\\u205f\\u3000\\ufeff]";
      var STAR_MATCHER = "(" + WHITESPACE + "*(?:\\*" + WHITESPACE + "?)?)(.+|[\r\n\u2028\u2029])";
      function unwrapComment(doc) {
        return doc.replace(/^\/\*\*?/, "").replace(/\*\/$/, "").replace(new RegExp(STAR_MATCHER, "g"), "$2").replace(/\s*$/, "");
      }
      function convertUnwrappedCommentIndex(originalSource, unwrappedIndex) {
        var replacedSource = originalSource.replace(/^\/\*\*?/, "");
        var numSkippedChars = 0;
        var matcher = new RegExp(STAR_MATCHER, "g");
        var match;
        while (match = matcher.exec(replacedSource)) {
          numSkippedChars += match[1].length;
          if (match.index + match[0].length > unwrappedIndex + numSkippedChars) {
            return unwrappedIndex + numSkippedChars + originalSource.length - replacedSource.length;
          }
        }
        return originalSource.replace(/\*\/$/, "").replace(/\s*$/, "").length;
      }
      (function(exports2) {
        var Rules, index, lineNumber, length, source, originalSource, recoverable, sloppy, strict;
        function advance() {
          var ch = source.charCodeAt(index);
          index += 1;
          if (esutils.code.isLineTerminator(ch) && !(ch === 13 && source.charCodeAt(index) === 10)) {
            lineNumber += 1;
          }
          return String.fromCharCode(ch);
        }
        function scanTitle() {
          var title = "";
          advance();
          while (index < length && isASCIIAlphanumeric(source.charCodeAt(index))) {
            title += advance();
          }
          return title;
        }
        function seekContent() {
          var ch, waiting, last2 = index;
          waiting = false;
          while (last2 < length) {
            ch = source.charCodeAt(last2);
            if (esutils.code.isLineTerminator(ch) && !(ch === 13 && source.charCodeAt(last2 + 1) === 10)) {
              waiting = true;
            } else if (waiting) {
              if (ch === 64) {
                break;
              }
              if (!esutils.code.isWhiteSpace(ch)) {
                waiting = false;
              }
            }
            last2 += 1;
          }
          return last2;
        }
        function parseType(title, last2, addRange) {
          var ch, brace, type, startIndex, direct = false;
          while (index < last2) {
            ch = source.charCodeAt(index);
            if (esutils.code.isWhiteSpace(ch)) {
              advance();
            } else if (ch === 123) {
              advance();
              break;
            } else {
              direct = true;
              break;
            }
          }
          if (direct) {
            return null;
          }
          brace = 1;
          type = "";
          while (index < last2) {
            ch = source.charCodeAt(index);
            if (esutils.code.isLineTerminator(ch)) {
              advance();
            } else {
              if (ch === 125) {
                brace -= 1;
                if (brace === 0) {
                  advance();
                  break;
                }
              } else if (ch === 123) {
                brace += 1;
              }
              if (type === "") {
                startIndex = index;
              }
              type += advance();
            }
          }
          if (brace !== 0) {
            return utility.throwError("Braces are not balanced");
          }
          if (isAllowedOptional(title)) {
            return typed.parseParamType(type, { startIndex: convertIndex(startIndex), range: addRange });
          }
          return typed.parseType(type, { startIndex: convertIndex(startIndex), range: addRange });
        }
        function scanIdentifier(last2) {
          var identifier3;
          if (!esutils.code.isIdentifierStartES5(source.charCodeAt(index)) && !source[index].match(/[0-9]/)) {
            return null;
          }
          identifier3 = advance();
          while (index < last2 && esutils.code.isIdentifierPartES5(source.charCodeAt(index))) {
            identifier3 += advance();
          }
          return identifier3;
        }
        function skipWhiteSpace(last2) {
          while (index < last2 && (esutils.code.isWhiteSpace(source.charCodeAt(index)) || esutils.code.isLineTerminator(source.charCodeAt(index)))) {
            advance();
          }
        }
        function parseName(last2, allowBrackets, allowNestedParams) {
          var name = "", useBrackets, insideString;
          skipWhiteSpace(last2);
          if (index >= last2) {
            return null;
          }
          if (source.charCodeAt(index) === 91) {
            if (allowBrackets) {
              useBrackets = true;
              name = advance();
            } else {
              return null;
            }
          }
          name += scanIdentifier(last2);
          if (allowNestedParams) {
            if (source.charCodeAt(index) === 58 && (name === "module" || name === "external" || name === "event")) {
              name += advance();
              name += scanIdentifier(last2);
            }
            if (source.charCodeAt(index) === 91 && source.charCodeAt(index + 1) === 93) {
              name += advance();
              name += advance();
            }
            while (source.charCodeAt(index) === 46 || source.charCodeAt(index) === 47 || source.charCodeAt(index) === 35 || source.charCodeAt(index) === 45 || source.charCodeAt(index) === 126) {
              name += advance();
              name += scanIdentifier(last2);
            }
          }
          if (useBrackets) {
            skipWhiteSpace(last2);
            if (source.charCodeAt(index) === 61) {
              name += advance();
              skipWhiteSpace(last2);
              var ch;
              var bracketDepth = 1;
              while (index < last2) {
                ch = source.charCodeAt(index);
                if (esutils.code.isWhiteSpace(ch)) {
                  if (!insideString) {
                    skipWhiteSpace(last2);
                    ch = source.charCodeAt(index);
                  }
                }
                if (ch === 39) {
                  if (!insideString) {
                    insideString = "'";
                  } else {
                    if (insideString === "'") {
                      insideString = "";
                    }
                  }
                }
                if (ch === 34) {
                  if (!insideString) {
                    insideString = '"';
                  } else {
                    if (insideString === '"') {
                      insideString = "";
                    }
                  }
                }
                if (ch === 91) {
                  bracketDepth++;
                } else if (ch === 93 && --bracketDepth === 0) {
                  break;
                }
                name += advance();
              }
            }
            skipWhiteSpace(last2);
            if (index >= last2 || source.charCodeAt(index) !== 93) {
              return null;
            }
            name += advance();
          }
          return name;
        }
        function skipToTag() {
          while (index < length && source.charCodeAt(index) !== 64) {
            advance();
          }
          if (index >= length) {
            return false;
          }
          utility.assert(
            source.charCodeAt(index) === 64
            /* '@' */
          );
          return true;
        }
        function convertIndex(rangeIndex) {
          if (source === originalSource) {
            return rangeIndex;
          }
          return convertUnwrappedCommentIndex(originalSource, rangeIndex);
        }
        function TagParser(options, title) {
          this._options = options;
          this._title = title.toLowerCase();
          this._tag = {
            title,
            description: null
          };
          if (this._options.lineNumbers) {
            this._tag.lineNumber = lineNumber;
          }
          this._first = index - title.length - 1;
          this._last = 0;
          this._extra = {};
        }
        TagParser.prototype.addError = function addError(errorText) {
          var args = Array.prototype.slice.call(arguments, 1), msg = errorText.replace(
            /%(\d)/g,
            function(whole, index2) {
              utility.assert(index2 < args.length, "Message reference must be in range");
              return args[index2];
            }
          );
          if (!this._tag.errors) {
            this._tag.errors = [];
          }
          if (strict) {
            utility.throwError(msg);
          }
          this._tag.errors.push(msg);
          return recoverable;
        };
        TagParser.prototype.parseType = function() {
          if (isTypeParameterRequired(this._title)) {
            try {
              this._tag.type = parseType(this._title, this._last, this._options.range);
              if (!this._tag.type) {
                if (!isParamTitle(this._title) && !isReturnTitle(this._title)) {
                  if (!this.addError("Missing or invalid tag type")) {
                    return false;
                  }
                }
              }
            } catch (error) {
              this._tag.type = null;
              if (!this.addError(error.message)) {
                return false;
              }
            }
          } else if (isAllowedType(this._title)) {
            try {
              this._tag.type = parseType(this._title, this._last, this._options.range);
            } catch (e) {
            }
          }
          return true;
        };
        TagParser.prototype._parseNamePath = function(optional) {
          var name;
          name = parseName(this._last, sloppy && isAllowedOptional(this._title), true);
          if (!name) {
            if (!optional) {
              if (!this.addError("Missing or invalid tag name")) {
                return false;
              }
            }
          }
          this._tag.name = name;
          return true;
        };
        TagParser.prototype.parseNamePath = function() {
          return this._parseNamePath(false);
        };
        TagParser.prototype.parseNamePathOptional = function() {
          return this._parseNamePath(true);
        };
        TagParser.prototype.parseName = function() {
          var assign, name;
          if (isAllowedName(this._title)) {
            this._tag.name = parseName(this._last, sloppy && isAllowedOptional(this._title), isAllowedNested(this._title));
            if (!this._tag.name) {
              if (!isNameParameterRequired(this._title)) {
                return true;
              }
              if (isParamTitle(this._title) && this._tag.type && this._tag.type.name) {
                this._extra.name = this._tag.type;
                this._tag.name = this._tag.type.name;
                this._tag.type = null;
              } else {
                if (!this.addError("Missing or invalid tag name")) {
                  return false;
                }
              }
            } else {
              name = this._tag.name;
              if (name.charAt(0) === "[" && name.charAt(name.length - 1) === "]") {
                assign = name.substring(1, name.length - 1).split("=");
                if (assign.length > 1) {
                  this._tag["default"] = assign.slice(1).join("=");
                }
                this._tag.name = assign[0];
                if (this._tag.type && this._tag.type.type !== "OptionalType") {
                  this._tag.type = {
                    type: "OptionalType",
                    expression: this._tag.type
                  };
                }
              }
            }
          }
          return true;
        };
        TagParser.prototype.parseDescription = function parseDescription() {
          var description = sliceSource(source, index, this._last).trim();
          if (description) {
            if (/^-\s+/.test(description)) {
              description = description.substring(2);
            }
            this._tag.description = description;
          }
          return true;
        };
        TagParser.prototype.parseCaption = function parseDescription() {
          var description = sliceSource(source, index, this._last).trim();
          var captionStartTag = "<caption>";
          var captionEndTag = "</caption>";
          var captionStart = description.indexOf(captionStartTag);
          var captionEnd = description.indexOf(captionEndTag);
          if (captionStart >= 0 && captionEnd >= 0) {
            this._tag.caption = description.substring(
              captionStart + captionStartTag.length,
              captionEnd
            ).trim();
            this._tag.description = description.substring(captionEnd + captionEndTag.length).trim();
          } else {
            this._tag.description = description;
          }
          return true;
        };
        TagParser.prototype.parseKind = function parseKind() {
          var kind, kinds;
          kinds = {
            "class": true,
            "constant": true,
            "event": true,
            "external": true,
            "file": true,
            "function": true,
            "member": true,
            "mixin": true,
            "module": true,
            "namespace": true,
            "typedef": true
          };
          kind = sliceSource(source, index, this._last).trim();
          this._tag.kind = kind;
          if (!hasOwnProperty(kinds, kind)) {
            if (!this.addError("Invalid kind name '%0'", kind)) {
              return false;
            }
          }
          return true;
        };
        TagParser.prototype.parseAccess = function parseAccess() {
          var access;
          access = sliceSource(source, index, this._last).trim();
          this._tag.access = access;
          if (access !== "private" && access !== "protected" && access !== "public") {
            if (!this.addError("Invalid access name '%0'", access)) {
              return false;
            }
          }
          return true;
        };
        TagParser.prototype.parseThis = function parseThis() {
          var value2 = sliceSource(source, index, this._last).trim();
          if (value2 && value2.charAt(0) === "{") {
            var gotType = this.parseType();
            if (gotType && this._tag.type.type === "NameExpression" || this._tag.type.type === "UnionType") {
              this._tag.name = this._tag.type.name;
              return true;
            } else {
              return this.addError("Invalid name for this");
            }
          } else {
            return this.parseNamePath();
          }
        };
        TagParser.prototype.parseVariation = function parseVariation() {
          var variation, text;
          text = sliceSource(source, index, this._last).trim();
          variation = parseFloat(text, 10);
          this._tag.variation = variation;
          if (isNaN(variation)) {
            if (!this.addError("Invalid variation '%0'", text)) {
              return false;
            }
          }
          return true;
        };
        TagParser.prototype.ensureEnd = function() {
          var shouldBeEmpty = sliceSource(source, index, this._last).trim();
          if (shouldBeEmpty) {
            if (!this.addError("Unknown content '%0'", shouldBeEmpty)) {
              return false;
            }
          }
          return true;
        };
        TagParser.prototype.epilogue = function epilogue() {
          var description;
          description = this._tag.description;
          if (isAllowedOptional(this._title) && !this._tag.type && description && description.charAt(0) === "[") {
            this._tag.type = this._extra.name;
            if (!this._tag.name) {
              this._tag.name = void 0;
            }
            if (!sloppy) {
              if (!this.addError("Missing or invalid tag name")) {
                return false;
              }
            }
          }
          return true;
        };
        Rules = {
          // http://usejsdoc.org/tags-access.html
          "access": ["parseAccess"],
          // http://usejsdoc.org/tags-alias.html
          "alias": ["parseNamePath", "ensureEnd"],
          // http://usejsdoc.org/tags-augments.html
          "augments": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-constructor.html
          "constructor": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // Synonym: http://usejsdoc.org/tags-constructor.html
          "class": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // Synonym: http://usejsdoc.org/tags-extends.html
          "extends": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-example.html
          "example": ["parseCaption"],
          // http://usejsdoc.org/tags-deprecated.html
          "deprecated": ["parseDescription"],
          // http://usejsdoc.org/tags-global.html
          "global": ["ensureEnd"],
          // http://usejsdoc.org/tags-inner.html
          "inner": ["ensureEnd"],
          // http://usejsdoc.org/tags-instance.html
          "instance": ["ensureEnd"],
          // http://usejsdoc.org/tags-kind.html
          "kind": ["parseKind"],
          // http://usejsdoc.org/tags-mixes.html
          "mixes": ["parseNamePath", "ensureEnd"],
          // http://usejsdoc.org/tags-mixin.html
          "mixin": ["parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-member.html
          "member": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-method.html
          "method": ["parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-module.html
          "module": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // Synonym: http://usejsdoc.org/tags-method.html
          "func": ["parseNamePathOptional", "ensureEnd"],
          // Synonym: http://usejsdoc.org/tags-method.html
          "function": ["parseNamePathOptional", "ensureEnd"],
          // Synonym: http://usejsdoc.org/tags-member.html
          "var": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-name.html
          "name": ["parseNamePath", "ensureEnd"],
          // http://usejsdoc.org/tags-namespace.html
          "namespace": ["parseType", "parseNamePathOptional", "ensureEnd"],
          // http://usejsdoc.org/tags-private.html
          "private": ["parseType", "parseDescription"],
          // http://usejsdoc.org/tags-protected.html
          "protected": ["parseType", "parseDescription"],
          // http://usejsdoc.org/tags-public.html
          "public": ["parseType", "parseDescription"],
          // http://usejsdoc.org/tags-readonly.html
          "readonly": ["ensureEnd"],
          // http://usejsdoc.org/tags-requires.html
          "requires": ["parseNamePath", "ensureEnd"],
          // http://usejsdoc.org/tags-since.html
          "since": ["parseDescription"],
          // http://usejsdoc.org/tags-static.html
          "static": ["ensureEnd"],
          // http://usejsdoc.org/tags-summary.html
          "summary": ["parseDescription"],
          // http://usejsdoc.org/tags-this.html
          "this": ["parseThis", "ensureEnd"],
          // http://usejsdoc.org/tags-todo.html
          "todo": ["parseDescription"],
          // http://usejsdoc.org/tags-typedef.html
          "typedef": ["parseType", "parseNamePathOptional"],
          // http://usejsdoc.org/tags-variation.html
          "variation": ["parseVariation"],
          // http://usejsdoc.org/tags-version.html
          "version": ["parseDescription"]
        };
        TagParser.prototype.parse = function parse4() {
          var i, iz, sequences, method;
          if (!this._title) {
            if (!this.addError("Missing or invalid title")) {
              return null;
            }
          }
          this._last = seekContent(this._title);
          if (this._options.range) {
            this._tag.range = [this._first, source.slice(0, this._last).replace(/\s*$/, "").length].map(convertIndex);
          }
          if (hasOwnProperty(Rules, this._title)) {
            sequences = Rules[this._title];
          } else {
            sequences = ["parseType", "parseName", "parseDescription", "epilogue"];
          }
          for (i = 0, iz = sequences.length; i < iz; ++i) {
            method = sequences[i];
            if (!this[method]()) {
              return null;
            }
          }
          return this._tag;
        };
        function parseTag(options) {
          var title, parser, tag;
          if (!skipToTag()) {
            return null;
          }
          title = scanTitle();
          parser = new TagParser(options, title);
          tag = parser.parse();
          while (index < parser._last) {
            advance();
          }
          return tag;
        }
        function scanJSDocDescription(preserveWhitespace) {
          var description = "", ch, atAllowed;
          atAllowed = true;
          while (index < length) {
            ch = source.charCodeAt(index);
            if (atAllowed && ch === 64) {
              break;
            }
            if (esutils.code.isLineTerminator(ch)) {
              atAllowed = true;
            } else if (atAllowed && !esutils.code.isWhiteSpace(ch)) {
              atAllowed = false;
            }
            description += advance();
          }
          return preserveWhitespace ? description : description.trim();
        }
        function parse3(comment, options) {
          var tags = [], tag, description, interestingTags, i, iz;
          if (options === void 0) {
            options = {};
          }
          if (typeof options.unwrap === "boolean" && options.unwrap) {
            source = unwrapComment(comment);
          } else {
            source = comment;
          }
          originalSource = comment;
          if (options.tags) {
            if (Array.isArray(options.tags)) {
              interestingTags = {};
              for (i = 0, iz = options.tags.length; i < iz; i++) {
                if (typeof options.tags[i] === "string") {
                  interestingTags[options.tags[i]] = true;
                } else {
                  utility.throwError('Invalid "tags" parameter: ' + options.tags);
                }
              }
            } else {
              utility.throwError('Invalid "tags" parameter: ' + options.tags);
            }
          }
          length = source.length;
          index = 0;
          lineNumber = 0;
          recoverable = options.recoverable;
          sloppy = options.sloppy;
          strict = options.strict;
          description = scanJSDocDescription(options.preserveWhitespace);
          while (true) {
            tag = parseTag(options);
            if (!tag) {
              break;
            }
            if (!interestingTags || interestingTags.hasOwnProperty(tag.title)) {
              tags.push(tag);
            }
          }
          return {
            description,
            tags
          };
        }
        exports2.parse = parse3;
      })(jsdoc = {});
      exports.version = utility.VERSION;
      exports.parse = jsdoc.parse;
      exports.parseType = typed.parseType;
      exports.parseParamType = typed.parseParamType;
      exports.unwrapComment = unwrapComment;
      exports.Syntax = shallowCopy(typed.Syntax);
      exports.Error = utility.DoctrineError;
      exports.type = {
        Syntax: exports.Syntax,
        parseType: typed.parseType,
        parseParamType: typed.parseParamType,
        stringify: typed.stringify
      };
    })();
  }
});

// node_modules/eslint/lib/rules/valid-jsdoc.js
var require_valid_jsdoc = __commonJS({
  "node_modules/eslint/lib/rules/valid-jsdoc.js"(exports, module2) {
    "use strict";
    var doctrine = require_doctrine();
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Enforce valid JSDoc comments",
          recommended: false,
          url: "https://eslint.org/docs/rules/valid-jsdoc"
        },
        schema: [
          {
            type: "object",
            properties: {
              prefer: {
                type: "object",
                additionalProperties: {
                  type: "string"
                }
              },
              preferType: {
                type: "object",
                additionalProperties: {
                  type: "string"
                }
              },
              requireReturn: {
                type: "boolean",
                default: true
              },
              requireParamDescription: {
                type: "boolean",
                default: true
              },
              requireReturnDescription: {
                type: "boolean",
                default: true
              },
              matchDescription: {
                type: "string"
              },
              requireReturnType: {
                type: "boolean",
                default: true
              },
              requireParamType: {
                type: "boolean",
                default: true
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          unexpectedTag: "Unexpected @{{title}} tag; function has no return statement.",
          expected: "Expected JSDoc for '{{name}}' but found '{{jsdocName}}'.",
          use: "Use @{{name}} instead.",
          useType: "Use '{{expectedTypeName}}' instead of '{{currentTypeName}}'.",
          syntaxError: "JSDoc syntax error.",
          missingBrace: "JSDoc type missing brace.",
          missingParamDesc: "Missing JSDoc parameter description for '{{name}}'.",
          missingParamType: "Missing JSDoc parameter type for '{{name}}'.",
          missingReturnType: "Missing JSDoc return type.",
          missingReturnDesc: "Missing JSDoc return description.",
          missingReturn: "Missing JSDoc @{{returns}} for function.",
          missingParam: "Missing JSDoc for parameter '{{name}}'.",
          duplicateParam: "Duplicate JSDoc parameter '{{name}}'.",
          unsatisfiedDesc: "JSDoc description does not satisfy the regex pattern."
        },
        deprecated: true,
        replacedBy: []
      },
      create(context) {
        const options = context.options[0] || {}, prefer = options.prefer || {}, sourceCode = context.getSourceCode(), requireReturn = options.requireReturn !== false, requireParamDescription = options.requireParamDescription !== false, requireReturnDescription = options.requireReturnDescription !== false, requireReturnType = options.requireReturnType !== false, requireParamType = options.requireParamType !== false, preferType = options.preferType || {}, checkPreferType = Object.keys(preferType).length !== 0;
        const fns = [];
        function isTypeClass(node) {
          return node.type === "ClassExpression" || node.type === "ClassDeclaration";
        }
        function startFunction(node) {
          fns.push({
            returnPresent: node.type === "ArrowFunctionExpression" && node.body.type !== "BlockStatement" || isTypeClass(node) || node.async
          });
        }
        function addReturn(node) {
          const functionState = fns[fns.length - 1];
          if (functionState && node.argument !== null) {
            functionState.returnPresent = true;
          }
        }
        function isValidReturnType(tag) {
          return tag.type === null || tag.type.name === "void" || tag.type.type === "UndefinedLiteral";
        }
        function canTypeBeValidated(type) {
          return type !== "UndefinedLiteral" && // {undefined} as there is no name property available.
          type !== "NullLiteral" && // {null}
          type !== "NullableLiteral" && // {?}
          type !== "FunctionType" && // {function(a)}
          type !== "AllLiteral";
        }
        function getCurrentExpectedTypes(type) {
          let currentType;
          if (type.name) {
            currentType = type;
          } else if (type.expression) {
            currentType = type.expression;
          }
          return {
            currentType,
            expectedTypeName: currentType && preferType[currentType.name]
          };
        }
        function getAbsoluteRange(jsdocComment, parsedJsdocNode) {
          return {
            start: sourceCode.getLocFromIndex(jsdocComment.range[0] + 2 + parsedJsdocNode.range[0]),
            end: sourceCode.getLocFromIndex(jsdocComment.range[0] + 2 + parsedJsdocNode.range[1])
          };
        }
        function validateType(jsdocNode, type) {
          if (!type || !canTypeBeValidated(type.type)) {
            return;
          }
          const typesToCheck = [];
          let elements = [];
          switch (type.type) {
            case "TypeApplication":
              elements = type.applications[0].type === "UnionType" ? type.applications[0].elements : type.applications;
              typesToCheck.push(getCurrentExpectedTypes(type));
              break;
            case "RecordType":
              elements = type.fields;
              break;
            case "UnionType":
            case "ArrayType":
              elements = type.elements;
              break;
            case "FieldType":
              if (type.value) {
                typesToCheck.push(getCurrentExpectedTypes(type.value));
              }
              break;
            default:
              typesToCheck.push(getCurrentExpectedTypes(type));
          }
          elements.forEach(validateType.bind(null, jsdocNode));
          typesToCheck.forEach((typeToCheck) => {
            if (typeToCheck.expectedTypeName && typeToCheck.expectedTypeName !== typeToCheck.currentType.name) {
              context.report({
                node: jsdocNode,
                messageId: "useType",
                loc: getAbsoluteRange(jsdocNode, typeToCheck.currentType),
                data: {
                  currentTypeName: typeToCheck.currentType.name,
                  expectedTypeName: typeToCheck.expectedTypeName
                },
                fix(fixer) {
                  return fixer.replaceTextRange(
                    typeToCheck.currentType.range.map((indexInComment) => jsdocNode.range[0] + 2 + indexInComment),
                    typeToCheck.expectedTypeName
                  );
                }
              });
            }
          });
        }
        function checkJSDoc(node) {
          const jsdocNode = sourceCode.getJSDocComment(node), functionData = fns.pop(), paramTagsByName = /* @__PURE__ */ Object.create(null), paramTags = [];
          let hasReturns = false, returnsTag, hasConstructor = false, isInterface = false, isOverride = false, isAbstract = false;
          if (jsdocNode) {
            let jsdoc;
            try {
              jsdoc = doctrine.parse(jsdocNode.value, {
                strict: true,
                unwrap: true,
                sloppy: true,
                range: true
              });
            } catch (ex) {
              if (/braces/iu.test(ex.message)) {
                context.report({ node: jsdocNode, messageId: "missingBrace" });
              } else {
                context.report({ node: jsdocNode, messageId: "syntaxError" });
              }
              return;
            }
            jsdoc.tags.forEach((tag) => {
              switch (tag.title.toLowerCase()) {
                case "param":
                case "arg":
                case "argument":
                  paramTags.push(tag);
                  break;
                case "return":
                case "returns":
                  hasReturns = true;
                  returnsTag = tag;
                  break;
                case "constructor":
                case "class":
                  hasConstructor = true;
                  break;
                case "override":
                case "inheritdoc":
                  isOverride = true;
                  break;
                case "abstract":
                case "virtual":
                  isAbstract = true;
                  break;
                case "interface":
                  isInterface = true;
                  break;
              }
              if (Object.prototype.hasOwnProperty.call(prefer, tag.title) && tag.title !== prefer[tag.title]) {
                const entireTagRange = getAbsoluteRange(jsdocNode, tag);
                context.report({
                  node: jsdocNode,
                  messageId: "use",
                  loc: {
                    start: entireTagRange.start,
                    end: {
                      line: entireTagRange.start.line,
                      column: entireTagRange.start.column + `@${tag.title}`.length
                    }
                  },
                  data: { name: prefer[tag.title] },
                  fix(fixer) {
                    return fixer.replaceTextRange(
                      [
                        jsdocNode.range[0] + tag.range[0] + 3,
                        jsdocNode.range[0] + tag.range[0] + tag.title.length + 3
                      ],
                      prefer[tag.title]
                    );
                  }
                });
              }
              if (checkPreferType && tag.type) {
                validateType(jsdocNode, tag.type);
              }
            });
            paramTags.forEach((param) => {
              if (requireParamType && !param.type) {
                context.report({
                  node: jsdocNode,
                  messageId: "missingParamType",
                  loc: getAbsoluteRange(jsdocNode, param),
                  data: { name: param.name }
                });
              }
              if (!param.description && requireParamDescription) {
                context.report({
                  node: jsdocNode,
                  messageId: "missingParamDesc",
                  loc: getAbsoluteRange(jsdocNode, param),
                  data: { name: param.name }
                });
              }
              if (paramTagsByName[param.name]) {
                context.report({
                  node: jsdocNode,
                  messageId: "duplicateParam",
                  loc: getAbsoluteRange(jsdocNode, param),
                  data: { name: param.name }
                });
              } else if (!param.name.includes(".")) {
                paramTagsByName[param.name] = param;
              }
            });
            if (hasReturns) {
              if (!requireReturn && !functionData.returnPresent && (returnsTag.type === null || !isValidReturnType(returnsTag)) && !isAbstract) {
                context.report({
                  node: jsdocNode,
                  messageId: "unexpectedTag",
                  loc: getAbsoluteRange(jsdocNode, returnsTag),
                  data: {
                    title: returnsTag.title
                  }
                });
              } else {
                if (requireReturnType && !returnsTag.type) {
                  context.report({ node: jsdocNode, messageId: "missingReturnType" });
                }
                if (!isValidReturnType(returnsTag) && !returnsTag.description && requireReturnDescription) {
                  context.report({ node: jsdocNode, messageId: "missingReturnDesc" });
                }
              }
            }
            if (!isOverride && !hasReturns && !hasConstructor && !isInterface && node.parent.kind !== "get" && node.parent.kind !== "constructor" && node.parent.kind !== "set" && !isTypeClass(node)) {
              if (requireReturn || functionData.returnPresent && !node.async) {
                context.report({
                  node: jsdocNode,
                  messageId: "missingReturn",
                  data: {
                    returns: prefer.returns || "returns"
                  }
                });
              }
            }
            const jsdocParamNames = Object.keys(paramTagsByName);
            if (node.params) {
              node.params.forEach((param, paramsIndex) => {
                const bindingParam = param.type === "AssignmentPattern" ? param.left : param;
                if (bindingParam.type === "Identifier") {
                  const name = bindingParam.name;
                  if (jsdocParamNames[paramsIndex] && name !== jsdocParamNames[paramsIndex]) {
                    context.report({
                      node: jsdocNode,
                      messageId: "expected",
                      loc: getAbsoluteRange(jsdocNode, paramTagsByName[jsdocParamNames[paramsIndex]]),
                      data: {
                        name,
                        jsdocName: jsdocParamNames[paramsIndex]
                      }
                    });
                  } else if (!paramTagsByName[name] && !isOverride) {
                    context.report({
                      node: jsdocNode,
                      messageId: "missingParam",
                      data: {
                        name
                      }
                    });
                  }
                }
              });
            }
            if (options.matchDescription) {
              const regex = new RegExp(options.matchDescription, "u");
              if (!regex.test(jsdoc.description)) {
                context.report({ node: jsdocNode, messageId: "unsatisfiedDesc" });
              }
            }
          }
        }
        return {
          ArrowFunctionExpression: startFunction,
          FunctionExpression: startFunction,
          FunctionDeclaration: startFunction,
          ClassExpression: startFunction,
          ClassDeclaration: startFunction,
          "ArrowFunctionExpression:exit": checkJSDoc,
          "FunctionExpression:exit": checkJSDoc,
          "FunctionDeclaration:exit": checkJSDoc,
          "ClassExpression:exit": checkJSDoc,
          "ClassDeclaration:exit": checkJSDoc,
          ReturnStatement: addReturn
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/valid-typeof.js
var require_valid_typeof = __commonJS({
  "node_modules/eslint/lib/rules/valid-typeof.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "problem",
        docs: {
          description: "Enforce comparing `typeof` expressions against valid strings",
          recommended: true,
          url: "https://eslint.org/docs/rules/valid-typeof"
        },
        hasSuggestions: true,
        schema: [
          {
            type: "object",
            properties: {
              requireStringLiterals: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        messages: {
          invalidValue: "Invalid typeof comparison value.",
          notString: "Typeof comparisons should be to string literals.",
          suggestString: 'Use `"{{type}}"` instead of `{{type}}`.'
        }
      },
      create(context) {
        const VALID_TYPES = /* @__PURE__ */ new Set(["symbol", "undefined", "object", "boolean", "number", "string", "function", "bigint"]), OPERATORS = /* @__PURE__ */ new Set(["==", "===", "!=", "!=="]);
        const requireStringLiterals = context.options[0] && context.options[0].requireStringLiterals;
        let globalScope;
        function isReferenceToGlobalVariable(node) {
          const variable = globalScope.set.get(node.name);
          return variable && variable.defs.length === 0 && variable.references.some((ref) => ref.identifier === node);
        }
        function isTypeofExpression(node) {
          return node.type === "UnaryExpression" && node.operator === "typeof";
        }
        return {
          Program() {
            globalScope = context.getScope();
          },
          UnaryExpression(node) {
            if (isTypeofExpression(node)) {
              const parent = context.getAncestors().pop();
              if (parent.type === "BinaryExpression" && OPERATORS.has(parent.operator)) {
                const sibling = parent.left === node ? parent.right : parent.left;
                if (sibling.type === "Literal" || sibling.type === "TemplateLiteral" && !sibling.expressions.length) {
                  const value2 = sibling.type === "Literal" ? sibling.value : sibling.quasis[0].value.cooked;
                  if (!VALID_TYPES.has(value2)) {
                    context.report({ node: sibling, messageId: "invalidValue" });
                  }
                } else if (sibling.type === "Identifier" && sibling.name === "undefined" && isReferenceToGlobalVariable(sibling)) {
                  context.report({
                    node: sibling,
                    messageId: requireStringLiterals ? "notString" : "invalidValue",
                    suggest: [
                      {
                        messageId: "suggestString",
                        data: { type: "undefined" },
                        fix(fixer) {
                          return fixer.replaceText(sibling, '"undefined"');
                        }
                      }
                    ]
                  });
                } else if (requireStringLiterals && !isTypeofExpression(sibling)) {
                  context.report({ node: sibling, messageId: "notString" });
                }
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/vars-on-top.js
var require_vars_on_top = __commonJS({
  "node_modules/eslint/lib/rules/vars-on-top.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: "Require `var` declarations be placed at the top of their containing scope",
          recommended: false,
          url: "https://eslint.org/docs/rules/vars-on-top"
        },
        schema: [],
        messages: {
          top: "All 'var' declarations must be at the top of the function scope."
        }
      },
      create(context) {
        function looksLikeDirective(node) {
          return node.type === "ExpressionStatement" && node.expression.type === "Literal" && typeof node.expression.value === "string";
        }
        function looksLikeImport(node) {
          return node.type === "ImportDeclaration" || node.type === "ImportSpecifier" || node.type === "ImportDefaultSpecifier" || node.type === "ImportNamespaceSpecifier";
        }
        function isVariableDeclaration(node) {
          return node.type === "VariableDeclaration" || node.type === "ExportNamedDeclaration" && node.declaration && node.declaration.type === "VariableDeclaration";
        }
        function isVarOnTop(node, statements) {
          const l = statements.length;
          let i = 0;
          if (node.parent.type !== "StaticBlock") {
            for (; i < l; ++i) {
              if (!looksLikeDirective(statements[i]) && !looksLikeImport(statements[i])) {
                break;
              }
            }
          }
          for (; i < l; ++i) {
            if (!isVariableDeclaration(statements[i])) {
              return false;
            }
            if (statements[i] === node) {
              return true;
            }
          }
          return false;
        }
        function globalVarCheck(node, parent) {
          if (!isVarOnTop(node, parent.body)) {
            context.report({ node, messageId: "top" });
          }
        }
        function blockScopeVarCheck(node) {
          const { parent } = node;
          if (parent.type === "BlockStatement" && /Function/u.test(parent.parent.type) && isVarOnTop(node, parent.body)) {
            return;
          }
          if (parent.type === "StaticBlock" && isVarOnTop(node, parent.body)) {
            return;
          }
          context.report({ node, messageId: "top" });
        }
        return {
          "VariableDeclaration[kind='var']"(node) {
            if (node.parent.type === "ExportNamedDeclaration") {
              globalVarCheck(node.parent, node.parent.parent);
            } else if (node.parent.type === "Program") {
              globalVarCheck(node, node.parent);
            } else {
              blockScopeVarCheck(node);
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/wrap-iife.js
var require_wrap_iife = __commonJS({
  "node_modules/eslint/lib/rules/wrap-iife.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    var eslintUtils = require_eslint_utils();
    function isCalleeOfNewExpression(node) {
      const maybeCallee = node.parent.type === "ChainExpression" ? node.parent : node;
      return maybeCallee.parent.type === "NewExpression" && maybeCallee.parent.callee === maybeCallee;
    }
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require parentheses around immediate `function` invocations",
          recommended: false,
          url: "https://eslint.org/docs/rules/wrap-iife"
        },
        schema: [
          {
            enum: ["outside", "inside", "any"]
          },
          {
            type: "object",
            properties: {
              functionPrototypeMethods: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          wrapInvocation: "Wrap an immediate function invocation in parentheses.",
          wrapExpression: "Wrap only the function expression in parens.",
          moveInvocation: "Move the invocation into the parens that contain the function."
        }
      },
      create(context) {
        const style = context.options[0] || "outside";
        const includeFunctionPrototypeMethods = context.options[1] && context.options[1].functionPrototypeMethods;
        const sourceCode = context.getSourceCode();
        function isWrappedInAnyParens(node) {
          return astUtils.isParenthesised(sourceCode, node);
        }
        function isWrappedInGroupingParens(node) {
          return eslintUtils.isParenthesized(1, node, sourceCode);
        }
        function getFunctionNodeFromIIFE(node) {
          const callee = astUtils.skipChainExpression(node.callee);
          if (callee.type === "FunctionExpression") {
            return callee;
          }
          if (includeFunctionPrototypeMethods && callee.type === "MemberExpression" && callee.object.type === "FunctionExpression" && (astUtils.getStaticPropertyName(callee) === "call" || astUtils.getStaticPropertyName(callee) === "apply")) {
            return callee.object;
          }
          return null;
        }
        return {
          CallExpression(node) {
            const innerNode = getFunctionNodeFromIIFE(node);
            if (!innerNode) {
              return;
            }
            const isCallExpressionWrapped = isWrappedInAnyParens(node), isFunctionExpressionWrapped = isWrappedInAnyParens(innerNode);
            if (!isCallExpressionWrapped && !isFunctionExpressionWrapped) {
              context.report({
                node,
                messageId: "wrapInvocation",
                fix(fixer) {
                  const nodeToSurround = style === "inside" ? innerNode : node;
                  return fixer.replaceText(nodeToSurround, `(${sourceCode.getText(nodeToSurround)})`);
                }
              });
            } else if (style === "inside" && !isFunctionExpressionWrapped) {
              context.report({
                node,
                messageId: "wrapExpression",
                fix(fixer) {
                  if (isWrappedInGroupingParens(node) && !isCalleeOfNewExpression(node)) {
                    const parenAfter = sourceCode.getTokenAfter(node);
                    return fixer.replaceTextRange(
                      [innerNode.range[1], parenAfter.range[1]],
                      `)${sourceCode.getText().slice(innerNode.range[1], parenAfter.range[0])}`
                    );
                  }
                  return fixer.replaceText(innerNode, `(${sourceCode.getText(innerNode)})`);
                }
              });
            } else if (style === "outside" && !isCallExpressionWrapped) {
              context.report({
                node,
                messageId: "moveInvocation",
                fix(fixer) {
                  const parenAfter = sourceCode.getTokenAfter(innerNode);
                  return fixer.replaceTextRange(
                    [parenAfter.range[0], node.range[1]],
                    `${sourceCode.getText().slice(parenAfter.range[1], node.range[1])})`
                  );
                }
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/wrap-regex.js
var require_wrap_regex = __commonJS({
  "node_modules/eslint/lib/rules/wrap-regex.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require parenthesis around regex literals",
          recommended: false,
          url: "https://eslint.org/docs/rules/wrap-regex"
        },
        schema: [],
        fixable: "code",
        messages: {
          requireParens: "Wrap the regexp literal in parens to disambiguate the slash."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        return {
          Literal(node) {
            const token = sourceCode.getFirstToken(node), nodeType = token.type;
            if (nodeType === "RegularExpression") {
              const beforeToken = sourceCode.getTokenBefore(node);
              const afterToken = sourceCode.getTokenAfter(node);
              const ancestors = context.getAncestors();
              const grandparent = ancestors[ancestors.length - 1];
              if (grandparent.type === "MemberExpression" && grandparent.object === node && !(beforeToken && beforeToken.value === "(" && afterToken && afterToken.value === ")")) {
                context.report({
                  node,
                  messageId: "requireParens",
                  fix: (fixer) => fixer.replaceText(node, `(${sourceCode.getText(node)})`)
                });
              }
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/yield-star-spacing.js
var require_yield_star_spacing = __commonJS({
  "node_modules/eslint/lib/rules/yield-star-spacing.js"(exports, module2) {
    "use strict";
    module2.exports = {
      meta: {
        type: "layout",
        docs: {
          description: "Require or disallow spacing around the `*` in `yield*` expressions",
          recommended: false,
          url: "https://eslint.org/docs/rules/yield-star-spacing"
        },
        fixable: "whitespace",
        schema: [
          {
            oneOf: [
              {
                enum: ["before", "after", "both", "neither"]
              },
              {
                type: "object",
                properties: {
                  before: { type: "boolean" },
                  after: { type: "boolean" }
                },
                additionalProperties: false
              }
            ]
          }
        ],
        messages: {
          missingBefore: "Missing space before *.",
          missingAfter: "Missing space after *.",
          unexpectedBefore: "Unexpected space before *.",
          unexpectedAfter: "Unexpected space after *."
        }
      },
      create(context) {
        const sourceCode = context.getSourceCode();
        const mode = function(option) {
          if (!option || typeof option === "string") {
            return {
              before: { before: true, after: false },
              after: { before: false, after: true },
              both: { before: true, after: true },
              neither: { before: false, after: false }
            }[option || "after"];
          }
          return option;
        }(context.options[0]);
        function checkSpacing(side, leftToken, rightToken) {
          if (sourceCode.isSpaceBetweenTokens(leftToken, rightToken) !== mode[side]) {
            const after = leftToken.value === "*";
            const spaceRequired = mode[side];
            const node = after ? leftToken : rightToken;
            let messageId = "";
            if (spaceRequired) {
              messageId = side === "before" ? "missingBefore" : "missingAfter";
            } else {
              messageId = side === "before" ? "unexpectedBefore" : "unexpectedAfter";
            }
            context.report({
              node,
              messageId,
              fix(fixer) {
                if (spaceRequired) {
                  if (after) {
                    return fixer.insertTextAfter(node, " ");
                  }
                  return fixer.insertTextBefore(node, " ");
                }
                return fixer.removeRange([leftToken.range[1], rightToken.range[0]]);
              }
            });
          }
        }
        function checkExpression(node) {
          if (!node.delegate) {
            return;
          }
          const tokens = sourceCode.getFirstTokens(node, 3);
          const yieldToken = tokens[0];
          const starToken = tokens[1];
          const nextToken = tokens[2];
          checkSpacing("before", yieldToken, starToken);
          checkSpacing("after", starToken, nextToken);
        }
        return {
          YieldExpression: checkExpression
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/yoda.js
var require_yoda = __commonJS({
  "node_modules/eslint/lib/rules/yoda.js"(exports, module2) {
    "use strict";
    var astUtils = require_ast_utils2();
    function isComparisonOperator(operator) {
      return /^(==|===|!=|!==|<|>|<=|>=)$/u.test(operator);
    }
    function isEqualityOperator(operator) {
      return /^(==|===)$/u.test(operator);
    }
    function isRangeTestOperator(operator) {
      return ["<", "<="].includes(operator);
    }
    function isNegativeNumericLiteral(node) {
      return node.type === "UnaryExpression" && node.operator === "-" && node.prefix && astUtils.isNumericLiteral(node.argument);
    }
    function isStaticTemplateLiteral(node) {
      return node.type === "TemplateLiteral" && node.expressions.length === 0;
    }
    function looksLikeLiteral(node) {
      return isNegativeNumericLiteral(node) || isStaticTemplateLiteral(node);
    }
    function getNormalizedLiteral(node) {
      if (node.type === "Literal") {
        return node;
      }
      if (isNegativeNumericLiteral(node)) {
        return {
          type: "Literal",
          value: -node.argument.value,
          raw: `-${node.argument.value}`
        };
      }
      if (isStaticTemplateLiteral(node)) {
        return {
          type: "Literal",
          value: node.quasis[0].value.cooked,
          raw: node.quasis[0].value.raw
        };
      }
      return null;
    }
    module2.exports = {
      meta: {
        type: "suggestion",
        docs: {
          description: 'Require or disallow "Yoda" conditions',
          recommended: false,
          url: "https://eslint.org/docs/rules/yoda"
        },
        schema: [
          {
            enum: ["always", "never"]
          },
          {
            type: "object",
            properties: {
              exceptRange: {
                type: "boolean",
                default: false
              },
              onlyEquality: {
                type: "boolean",
                default: false
              }
            },
            additionalProperties: false
          }
        ],
        fixable: "code",
        messages: {
          expected: "Expected literal to be on the {{expectedSide}} side of {{operator}}."
        }
      },
      create(context) {
        const always = context.options[0] === "always";
        const exceptRange = context.options[1] && context.options[1].exceptRange;
        const onlyEquality = context.options[1] && context.options[1].onlyEquality;
        const sourceCode = context.getSourceCode();
        function isRangeTest(node) {
          const left = node.left, right = node.right;
          function isBetweenTest() {
            if (node.operator === "&&" && astUtils.isSameReference(left.right, right.left)) {
              const leftLiteral = getNormalizedLiteral(left.left);
              const rightLiteral = getNormalizedLiteral(right.right);
              if (leftLiteral === null && rightLiteral === null) {
                return false;
              }
              if (rightLiteral === null || leftLiteral === null) {
                return true;
              }
              if (leftLiteral.value <= rightLiteral.value) {
                return true;
              }
            }
            return false;
          }
          function isOutsideTest() {
            if (node.operator === "||" && astUtils.isSameReference(left.left, right.right)) {
              const leftLiteral = getNormalizedLiteral(left.right);
              const rightLiteral = getNormalizedLiteral(right.left);
              if (leftLiteral === null && rightLiteral === null) {
                return false;
              }
              if (rightLiteral === null || leftLiteral === null) {
                return true;
              }
              if (leftLiteral.value <= rightLiteral.value) {
                return true;
              }
            }
            return false;
          }
          function isParenWrapped() {
            return astUtils.isParenthesised(sourceCode, node);
          }
          return node.type === "LogicalExpression" && left.type === "BinaryExpression" && right.type === "BinaryExpression" && isRangeTestOperator(left.operator) && isRangeTestOperator(right.operator) && (isBetweenTest() || isOutsideTest()) && isParenWrapped();
        }
        const OPERATOR_FLIP_MAP = {
          "===": "===",
          "!==": "!==",
          "==": "==",
          "!=": "!=",
          "<": ">",
          ">": "<",
          "<=": ">=",
          ">=": "<="
        };
        function getFlippedString(node) {
          const operatorToken = sourceCode.getFirstTokenBetween(
            node.left,
            node.right,
            (token) => token.value === node.operator
          );
          const lastLeftToken = sourceCode.getTokenBefore(operatorToken);
          const firstRightToken = sourceCode.getTokenAfter(operatorToken);
          const source = sourceCode.getText();
          const leftText = source.slice(
            node.range[0],
            lastLeftToken.range[1]
          );
          const textBeforeOperator = source.slice(
            lastLeftToken.range[1],
            operatorToken.range[0]
          );
          const textAfterOperator = source.slice(
            operatorToken.range[1],
            firstRightToken.range[0]
          );
          const rightText = source.slice(
            firstRightToken.range[0],
            node.range[1]
          );
          const tokenBefore = sourceCode.getTokenBefore(node);
          const tokenAfter = sourceCode.getTokenAfter(node);
          let prefix = "";
          let suffix = "";
          if (tokenBefore && tokenBefore.range[1] === node.range[0] && !astUtils.canTokensBeAdjacent(tokenBefore, firstRightToken)) {
            prefix = " ";
          }
          if (tokenAfter && node.range[1] === tokenAfter.range[0] && !astUtils.canTokensBeAdjacent(lastLeftToken, tokenAfter)) {
            suffix = " ";
          }
          return prefix + rightText + textBeforeOperator + OPERATOR_FLIP_MAP[operatorToken.value] + textAfterOperator + leftText + suffix;
        }
        return {
          BinaryExpression(node) {
            const expectedLiteral = always ? node.left : node.right;
            const expectedNonLiteral = always ? node.right : node.left;
            if ((expectedNonLiteral.type === "Literal" || looksLikeLiteral(expectedNonLiteral)) && !(expectedLiteral.type === "Literal" || looksLikeLiteral(expectedLiteral)) && !(!isEqualityOperator(node.operator) && onlyEquality) && isComparisonOperator(node.operator) && !(exceptRange && isRangeTest(context.getAncestors().pop()))) {
              context.report({
                node,
                messageId: "expected",
                data: {
                  operator: node.operator,
                  expectedSide: always ? "left" : "right"
                },
                fix: (fixer) => fixer.replaceText(node, getFlippedString(node))
              });
            }
          }
        };
      }
    };
  }
});

// node_modules/eslint/lib/rules/index.js
var require_rules2 = __commonJS({
  "node_modules/eslint/lib/rules/index.js"(exports, module2) {
    "use strict";
    var { LazyLoadingRuleMap } = require_lazy_loading_rule_map();
    module2.exports = new LazyLoadingRuleMap(Object.entries({
      "accessor-pairs": () => require_accessor_pairs(),
      "array-bracket-newline": () => require_array_bracket_newline(),
      "array-bracket-spacing": () => require_array_bracket_spacing(),
      "array-callback-return": () => require_array_callback_return(),
      "array-element-newline": () => require_array_element_newline(),
      "arrow-body-style": () => require_arrow_body_style(),
      "arrow-parens": () => require_arrow_parens(),
      "arrow-spacing": () => require_arrow_spacing(),
      "block-scoped-var": () => require_block_scoped_var(),
      "block-spacing": () => require_block_spacing(),
      "brace-style": () => require_brace_style(),
      "callback-return": () => require_callback_return(),
      camelcase: () => require_camelcase(),
      "capitalized-comments": () => require_capitalized_comments(),
      "class-methods-use-this": () => require_class_methods_use_this(),
      "comma-dangle": () => require_comma_dangle(),
      "comma-spacing": () => require_comma_spacing(),
      "comma-style": () => require_comma_style(),
      complexity: () => require_complexity(),
      "computed-property-spacing": () => require_computed_property_spacing(),
      "consistent-return": () => require_consistent_return(),
      "consistent-this": () => require_consistent_this(),
      "constructor-super": () => require_constructor_super(),
      curly: () => require_curly(),
      "default-case": () => require_default_case(),
      "default-case-last": () => require_default_case_last(),
      "default-param-last": () => require_default_param_last(),
      "dot-location": () => require_dot_location(),
      "dot-notation": () => require_dot_notation(),
      "eol-last": () => require_eol_last(),
      eqeqeq: () => require_eqeqeq(),
      "for-direction": () => require_for_direction(),
      "func-call-spacing": () => require_func_call_spacing(),
      "func-name-matching": () => require_func_name_matching(),
      "func-names": () => require_func_names(),
      "func-style": () => require_func_style(),
      "function-call-argument-newline": () => require_function_call_argument_newline(),
      "function-paren-newline": () => require_function_paren_newline(),
      "generator-star-spacing": () => require_generator_star_spacing(),
      "getter-return": () => require_getter_return(),
      "global-require": () => require_global_require(),
      "grouped-accessor-pairs": () => require_grouped_accessor_pairs(),
      "guard-for-in": () => require_guard_for_in(),
      "handle-callback-err": () => require_handle_callback_err(),
      "id-blacklist": () => require_id_blacklist(),
      "id-denylist": () => require_id_denylist(),
      "id-length": () => require_id_length(),
      "id-match": () => require_id_match(),
      "implicit-arrow-linebreak": () => require_implicit_arrow_linebreak(),
      indent: () => require_indent(),
      "indent-legacy": () => require_indent_legacy(),
      "init-declarations": () => require_init_declarations(),
      "jsx-quotes": () => require_jsx_quotes(),
      "key-spacing": () => require_key_spacing(),
      "keyword-spacing": () => require_keyword_spacing(),
      "line-comment-position": () => require_line_comment_position(),
      "linebreak-style": () => require_linebreak_style(),
      "lines-around-comment": () => require_lines_around_comment(),
      "lines-around-directive": () => require_lines_around_directive(),
      "lines-between-class-members": () => require_lines_between_class_members(),
      "logical-assignment-operators": () => require_logical_assignment_operators(),
      "max-classes-per-file": () => require_max_classes_per_file(),
      "max-depth": () => require_max_depth(),
      "max-len": () => require_max_len(),
      "max-lines": () => require_max_lines(),
      "max-lines-per-function": () => require_max_lines_per_function(),
      "max-nested-callbacks": () => require_max_nested_callbacks(),
      "max-params": () => require_max_params(),
      "max-statements": () => require_max_statements(),
      "max-statements-per-line": () => require_max_statements_per_line(),
      "multiline-comment-style": () => require_multiline_comment_style(),
      "multiline-ternary": () => require_multiline_ternary(),
      "new-cap": () => require_new_cap(),
      "new-parens": () => require_new_parens(),
      "newline-after-var": () => require_newline_after_var(),
      "newline-before-return": () => require_newline_before_return(),
      "newline-per-chained-call": () => require_newline_per_chained_call(),
      "no-alert": () => require_no_alert(),
      "no-array-constructor": () => require_no_array_constructor(),
      "no-async-promise-executor": () => require_no_async_promise_executor(),
      "no-await-in-loop": () => require_no_await_in_loop(),
      "no-bitwise": () => require_no_bitwise(),
      "no-buffer-constructor": () => require_no_buffer_constructor(),
      "no-caller": () => require_no_caller(),
      "no-case-declarations": () => require_no_case_declarations(),
      "no-catch-shadow": () => require_no_catch_shadow(),
      "no-class-assign": () => require_no_class_assign(),
      "no-compare-neg-zero": () => require_no_compare_neg_zero(),
      "no-cond-assign": () => require_no_cond_assign(),
      "no-confusing-arrow": () => require_no_confusing_arrow(),
      "no-console": () => require_no_console(),
      "no-const-assign": () => require_no_const_assign(),
      "no-constant-binary-expression": () => require_no_constant_binary_expression(),
      "no-constant-condition": () => require_no_constant_condition(),
      "no-constructor-return": () => require_no_constructor_return(),
      "no-continue": () => require_no_continue(),
      "no-control-regex": () => require_no_control_regex(),
      "no-debugger": () => require_no_debugger(),
      "no-delete-var": () => require_no_delete_var(),
      "no-div-regex": () => require_no_div_regex(),
      "no-dupe-args": () => require_no_dupe_args(),
      "no-dupe-class-members": () => require_no_dupe_class_members(),
      "no-dupe-else-if": () => require_no_dupe_else_if(),
      "no-dupe-keys": () => require_no_dupe_keys(),
      "no-duplicate-case": () => require_no_duplicate_case(),
      "no-duplicate-imports": () => require_no_duplicate_imports(),
      "no-else-return": () => require_no_else_return(),
      "no-empty": () => require_no_empty(),
      "no-empty-character-class": () => require_no_empty_character_class(),
      "no-empty-function": () => require_no_empty_function(),
      "no-empty-pattern": () => require_no_empty_pattern(),
      "no-empty-static-block": () => require_no_empty_static_block(),
      "no-eq-null": () => require_no_eq_null(),
      "no-eval": () => require_no_eval(),
      "no-ex-assign": () => require_no_ex_assign(),
      "no-extend-native": () => require_no_extend_native(),
      "no-extra-bind": () => require_no_extra_bind(),
      "no-extra-boolean-cast": () => require_no_extra_boolean_cast(),
      "no-extra-label": () => require_no_extra_label(),
      "no-extra-parens": () => require_no_extra_parens(),
      "no-extra-semi": () => require_no_extra_semi(),
      "no-fallthrough": () => require_no_fallthrough(),
      "no-floating-decimal": () => require_no_floating_decimal(),
      "no-func-assign": () => require_no_func_assign(),
      "no-global-assign": () => require_no_global_assign(),
      "no-implicit-coercion": () => require_no_implicit_coercion(),
      "no-implicit-globals": () => require_no_implicit_globals(),
      "no-implied-eval": () => require_no_implied_eval(),
      "no-import-assign": () => require_no_import_assign(),
      "no-inline-comments": () => require_no_inline_comments(),
      "no-inner-declarations": () => require_no_inner_declarations(),
      "no-invalid-regexp": () => require_no_invalid_regexp(),
      "no-invalid-this": () => require_no_invalid_this(),
      "no-irregular-whitespace": () => require_no_irregular_whitespace(),
      "no-iterator": () => require_no_iterator(),
      "no-label-var": () => require_no_label_var(),
      "no-labels": () => require_no_labels(),
      "no-lone-blocks": () => require_no_lone_blocks(),
      "no-lonely-if": () => require_no_lonely_if(),
      "no-loop-func": () => require_no_loop_func(),
      "no-loss-of-precision": () => require_no_loss_of_precision(),
      "no-magic-numbers": () => require_no_magic_numbers(),
      "no-misleading-character-class": () => require_no_misleading_character_class(),
      "no-mixed-operators": () => require_no_mixed_operators(),
      "no-mixed-requires": () => require_no_mixed_requires(),
      "no-mixed-spaces-and-tabs": () => require_no_mixed_spaces_and_tabs(),
      "no-multi-assign": () => require_no_multi_assign(),
      "no-multi-spaces": () => require_no_multi_spaces(),
      "no-multi-str": () => require_no_multi_str(),
      "no-multiple-empty-lines": () => require_no_multiple_empty_lines(),
      "no-native-reassign": () => require_no_native_reassign(),
      "no-negated-condition": () => require_no_negated_condition(),
      "no-negated-in-lhs": () => require_no_negated_in_lhs(),
      "no-nested-ternary": () => require_no_nested_ternary(),
      "no-new": () => require_no_new(),
      "no-new-func": () => require_no_new_func(),
      "no-new-native-nonconstructor": () => require_no_new_native_nonconstructor(),
      "no-new-object": () => require_no_new_object(),
      "no-new-require": () => require_no_new_require(),
      "no-new-symbol": () => require_no_new_symbol(),
      "no-new-wrappers": () => require_no_new_wrappers(),
      "no-nonoctal-decimal-escape": () => require_no_nonoctal_decimal_escape(),
      "no-obj-calls": () => require_no_obj_calls(),
      "no-octal": () => require_no_octal(),
      "no-octal-escape": () => require_no_octal_escape(),
      "no-param-reassign": () => require_no_param_reassign(),
      "no-path-concat": () => require_no_path_concat(),
      "no-plusplus": () => require_no_plusplus(),
      "no-process-env": () => require_no_process_env(),
      "no-process-exit": () => require_no_process_exit(),
      "no-promise-executor-return": () => require_no_promise_executor_return(),
      "no-proto": () => require_no_proto(),
      "no-prototype-builtins": () => require_no_prototype_builtins(),
      "no-redeclare": () => require_no_redeclare(),
      "no-regex-spaces": () => require_no_regex_spaces(),
      "no-restricted-exports": () => require_no_restricted_exports(),
      "no-restricted-globals": () => require_no_restricted_globals(),
      "no-restricted-imports": () => require_no_restricted_imports(),
      "no-restricted-modules": () => require_no_restricted_modules(),
      "no-restricted-properties": () => require_no_restricted_properties(),
      "no-restricted-syntax": () => require_no_restricted_syntax(),
      "no-return-assign": () => require_no_return_assign(),
      "no-return-await": () => require_no_return_await(),
      "no-script-url": () => require_no_script_url(),
      "no-self-assign": () => require_no_self_assign(),
      "no-self-compare": () => require_no_self_compare(),
      "no-sequences": () => require_no_sequences(),
      "no-setter-return": () => require_no_setter_return(),
      "no-shadow": () => require_no_shadow(),
      "no-shadow-restricted-names": () => require_no_shadow_restricted_names(),
      "no-spaced-func": () => require_no_spaced_func(),
      "no-sparse-arrays": () => require_no_sparse_arrays(),
      "no-sync": () => require_no_sync(),
      "no-tabs": () => require_no_tabs(),
      "no-template-curly-in-string": () => require_no_template_curly_in_string(),
      "no-ternary": () => require_no_ternary(),
      "no-this-before-super": () => require_no_this_before_super(),
      "no-throw-literal": () => require_no_throw_literal(),
      "no-trailing-spaces": () => require_no_trailing_spaces(),
      "no-undef": () => require_no_undef(),
      "no-undef-init": () => require_no_undef_init(),
      "no-undefined": () => require_no_undefined(),
      "no-underscore-dangle": () => require_no_underscore_dangle(),
      "no-unexpected-multiline": () => require_no_unexpected_multiline(),
      "no-unmodified-loop-condition": () => require_no_unmodified_loop_condition(),
      "no-unneeded-ternary": () => require_no_unneeded_ternary(),
      "no-unreachable": () => require_no_unreachable(),
      "no-unreachable-loop": () => require_no_unreachable_loop(),
      "no-unsafe-finally": () => require_no_unsafe_finally(),
      "no-unsafe-negation": () => require_no_unsafe_negation(),
      "no-unsafe-optional-chaining": () => require_no_unsafe_optional_chaining(),
      "no-unused-expressions": () => require_no_unused_expressions(),
      "no-unused-labels": () => require_no_unused_labels(),
      "no-unused-private-class-members": () => require_no_unused_private_class_members(),
      "no-unused-vars": () => require_no_unused_vars(),
      "no-use-before-define": () => require_no_use_before_define(),
      "no-useless-backreference": () => require_no_useless_backreference(),
      "no-useless-call": () => require_no_useless_call(),
      "no-useless-catch": () => require_no_useless_catch(),
      "no-useless-computed-key": () => require_no_useless_computed_key(),
      "no-useless-concat": () => require_no_useless_concat(),
      "no-useless-constructor": () => require_no_useless_constructor(),
      "no-useless-escape": () => require_no_useless_escape(),
      "no-useless-rename": () => require_no_useless_rename(),
      "no-useless-return": () => require_no_useless_return(),
      "no-var": () => require_no_var(),
      "no-void": () => require_no_void(),
      "no-warning-comments": () => require_no_warning_comments(),
      "no-whitespace-before-property": () => require_no_whitespace_before_property(),
      "no-with": () => require_no_with(),
      "nonblock-statement-body-position": () => require_nonblock_statement_body_position(),
      "object-curly-newline": () => require_object_curly_newline(),
      "object-curly-spacing": () => require_object_curly_spacing(),
      "object-property-newline": () => require_object_property_newline(),
      "object-shorthand": () => require_object_shorthand(),
      "one-var": () => require_one_var(),
      "one-var-declaration-per-line": () => require_one_var_declaration_per_line(),
      "operator-assignment": () => require_operator_assignment(),
      "operator-linebreak": () => require_operator_linebreak(),
      "padded-blocks": () => require_padded_blocks(),
      "padding-line-between-statements": () => require_padding_line_between_statements(),
      "prefer-arrow-callback": () => require_prefer_arrow_callback(),
      "prefer-const": () => require_prefer_const(),
      "prefer-destructuring": () => require_prefer_destructuring(),
      "prefer-exponentiation-operator": () => require_prefer_exponentiation_operator(),
      "prefer-named-capture-group": () => require_prefer_named_capture_group(),
      "prefer-numeric-literals": () => require_prefer_numeric_literals(),
      "prefer-object-has-own": () => require_prefer_object_has_own(),
      "prefer-object-spread": () => require_prefer_object_spread(),
      "prefer-promise-reject-errors": () => require_prefer_promise_reject_errors(),
      "prefer-reflect": () => require_prefer_reflect(),
      "prefer-regex-literals": () => require_prefer_regex_literals(),
      "prefer-rest-params": () => require_prefer_rest_params(),
      "prefer-spread": () => require_prefer_spread(),
      "prefer-template": () => require_prefer_template(),
      "quote-props": () => require_quote_props(),
      quotes: () => require_quotes(),
      radix: () => require_radix(),
      "require-atomic-updates": () => require_require_atomic_updates(),
      "require-await": () => require_require_await(),
      "require-jsdoc": () => require_require_jsdoc(),
      "require-unicode-regexp": () => require_require_unicode_regexp(),
      "require-yield": () => require_require_yield(),
      "rest-spread-spacing": () => require_rest_spread_spacing(),
      semi: () => require_semi(),
      "semi-spacing": () => require_semi_spacing(),
      "semi-style": () => require_semi_style(),
      "sort-imports": () => require_sort_imports(),
      "sort-keys": () => require_sort_keys(),
      "sort-vars": () => require_sort_vars(),
      "space-before-blocks": () => require_space_before_blocks(),
      "space-before-function-paren": () => require_space_before_function_paren(),
      "space-in-parens": () => require_space_in_parens(),
      "space-infix-ops": () => require_space_infix_ops(),
      "space-unary-ops": () => require_space_unary_ops(),
      "spaced-comment": () => require_spaced_comment(),
      strict: () => require_strict(),
      "switch-colon-spacing": () => require_switch_colon_spacing(),
      "symbol-description": () => require_symbol_description(),
      "template-curly-spacing": () => require_template_curly_spacing(),
      "template-tag-spacing": () => require_template_tag_spacing(),
      "unicode-bom": () => require_unicode_bom(),
      "use-isnan": () => require_use_isnan(),
      "valid-jsdoc": () => require_valid_jsdoc(),
      "valid-typeof": () => require_valid_typeof(),
      "vars-on-top": () => require_vars_on_top(),
      "wrap-iife": () => require_wrap_iife(),
      "wrap-regex": () => require_wrap_regex(),
      "yield-star-spacing": () => require_yield_star_spacing(),
      yoda: () => require_yoda()
    }));
  }
});

// node_modules/eslint/conf/eslint-all.js
var require_eslint_all = __commonJS({
  "node_modules/eslint/conf/eslint-all.js"(exports, module2) {
    "use strict";
    var builtInRules = require_rules2();
    var allRules = {};
    for (const [ruleId, rule] of builtInRules) {
      if (!rule.meta.deprecated) {
        allRules[ruleId] = "error";
      }
    }
    module2.exports = { rules: allRules };
  }
});

// node_modules/eslint/lib/cli-engine/file-enumerator.js
var require_file_enumerator = __commonJS({
  "node_modules/eslint/lib/cli-engine/file-enumerator.js"(exports, module2) {
    "use strict";
    var fs2 = require("fs");
    var path2 = require("path");
    var getGlobParent = require_glob_parent();
    var isGlob = require_is_glob();
    var escapeRegExp = require_escape_string_regexp2();
    var { Minimatch } = require_minimatch();
    var {
      Legacy: {
        IgnorePattern,
        CascadingConfigArrayFactory
      }
    } = require_eslintrc();
    var debug = require_src()("eslint:file-enumerator");
    var minimatchOpts = { dot: true, matchBase: true };
    var dotfilesPattern = /(?:(?:^\.)|(?:[/\\]\.))[^/\\.].*/u;
    var NONE = 0;
    var IGNORED_SILENTLY = 1;
    var IGNORED = 2;
    var internalSlotsMap = /* @__PURE__ */ new WeakMap();
    function isGlobPattern(pattern) {
      return isGlob(path2.sep === "\\" ? pattern.replace(/\\/gu, "/") : pattern);
    }
    function statSafeSync(filePath) {
      try {
        return fs2.statSync(filePath);
      } catch (error) {
        if (error.code !== "ENOENT") {
          throw error;
        }
        return null;
      }
    }
    function readdirSafeSync(directoryPath) {
      try {
        return fs2.readdirSync(directoryPath, { withFileTypes: true });
      } catch (error) {
        if (error.code !== "ENOENT") {
          throw error;
        }
        return [];
      }
    }
    function createExtensionRegExp(extensions) {
      if (extensions) {
        const normalizedExts = extensions.map((ext) => escapeRegExp(
          ext.startsWith(".") ? ext.slice(1) : ext
        ));
        return new RegExp(
          `.\\.(?:${normalizedExts.join("|")})$`,
          "u"
        );
      }
      return null;
    }
    var NoFilesFoundError = class extends Error {
      /**
       * @param {string} pattern The glob pattern which was not found.
       * @param {boolean} globDisabled If `true` then the pattern was a glob pattern, but glob was disabled.
       */
      constructor(pattern, globDisabled) {
        super(`No files matching '${pattern}' were found${globDisabled ? " (glob was disabled)" : ""}.`);
        this.messageTemplate = "file-not-found";
        this.messageData = { pattern, globDisabled };
      }
    };
    var AllFilesIgnoredError = class extends Error {
      /**
       * @param {string} pattern The glob pattern which was not found.
       */
      constructor(pattern) {
        super(`All files matched by '${pattern}' are ignored.`);
        this.messageTemplate = "all-files-ignored";
        this.messageData = { pattern };
      }
    };
    var FileEnumerator = class {
      /**
       * Initialize this enumerator.
       * @param {FileEnumeratorOptions} options The options.
       */
      constructor({
        cwd = process.cwd(),
        configArrayFactory = new CascadingConfigArrayFactory({
          cwd,
          getEslintRecommendedConfig: () => require_eslint_recommended(),
          getEslintAllConfig: () => require_eslint_all()
        }),
        extensions = null,
        globInputPaths = true,
        errorOnUnmatchedPattern = true,
        ignore = true
      } = {}) {
        internalSlotsMap.set(this, {
          configArrayFactory,
          cwd,
          defaultIgnores: IgnorePattern.createDefaultIgnore(cwd),
          extensionRegExp: createExtensionRegExp(extensions),
          globInputPaths,
          errorOnUnmatchedPattern,
          ignoreFlag: ignore
        });
      }
      /**
       * Check if a given file is target or not.
       * @param {string} filePath The path to a candidate file.
       * @param {ConfigArray} [providedConfig] Optional. The configuration for the file.
       * @returns {boolean} `true` if the file is a target.
       */
      isTargetPath(filePath, providedConfig) {
        const {
          configArrayFactory,
          extensionRegExp
        } = internalSlotsMap.get(this);
        if (extensionRegExp) {
          return extensionRegExp.test(filePath);
        }
        if (filePath.endsWith(".js")) {
          return true;
        }
        const config = providedConfig || configArrayFactory.getConfigArrayForFile(
          filePath,
          { ignoreNotFoundError: true }
        );
        return config.isAdditionalTargetPath(filePath);
      }
      /**
       * Iterate files which are matched by given glob patterns.
       * @param {string|string[]} patternOrPatterns The glob patterns to iterate files.
       * @throws {NoFilesFoundError|AllFilesIgnoredError} On an unmatched pattern.
       * @returns {IterableIterator<FileAndConfig>} The found files.
       */
      *iterateFiles(patternOrPatterns) {
        const { globInputPaths, errorOnUnmatchedPattern } = internalSlotsMap.get(this);
        const patterns = Array.isArray(patternOrPatterns) ? patternOrPatterns : [patternOrPatterns];
        debug("Start to iterate files: %o", patterns);
        const set = /* @__PURE__ */ new Set();
        for (const pattern of patterns) {
          let foundRegardlessOfIgnored = false;
          let found = false;
          if (!pattern) {
            continue;
          }
          for (const { config, filePath, flag } of this._iterateFiles(pattern)) {
            foundRegardlessOfIgnored = true;
            if (flag === IGNORED_SILENTLY) {
              continue;
            }
            found = true;
            if (!set.has(filePath)) {
              set.add(filePath);
              yield {
                config,
                filePath,
                ignored: flag === IGNORED
              };
            }
          }
          if (errorOnUnmatchedPattern) {
            if (!foundRegardlessOfIgnored) {
              throw new NoFilesFoundError(
                pattern,
                !globInputPaths && isGlob(pattern)
              );
            }
            if (!found) {
              throw new AllFilesIgnoredError(pattern);
            }
          }
        }
        debug(`Complete iterating files: ${JSON.stringify(patterns)}`);
      }
      /**
       * Iterate files which are matched by a given glob pattern.
       * @param {string} pattern The glob pattern to iterate files.
       * @returns {IterableIterator<FileEntry>} The found files.
       */
      _iterateFiles(pattern) {
        const { cwd, globInputPaths } = internalSlotsMap.get(this);
        const absolutePath = path2.resolve(cwd, pattern);
        const isDot = dotfilesPattern.test(pattern);
        const stat = statSafeSync(absolutePath);
        if (stat && stat.isDirectory()) {
          return this._iterateFilesWithDirectory(absolutePath, isDot);
        }
        if (stat && stat.isFile()) {
          return this._iterateFilesWithFile(absolutePath);
        }
        if (globInputPaths && isGlobPattern(pattern)) {
          return this._iterateFilesWithGlob(absolutePath, isDot);
        }
        return [];
      }
      /**
       * Iterate a file which is matched by a given path.
       * @param {string} filePath The path to the target file.
       * @returns {IterableIterator<FileEntry>} The found files.
       * @private
       */
      _iterateFilesWithFile(filePath) {
        debug(`File: ${filePath}`);
        const { configArrayFactory } = internalSlotsMap.get(this);
        const config = configArrayFactory.getConfigArrayForFile(filePath);
        const ignored = this._isIgnoredFile(filePath, { config, direct: true });
        const flag = ignored ? IGNORED : NONE;
        return [{ config, filePath, flag }];
      }
      /**
       * Iterate files in a given path.
       * @param {string} directoryPath The path to the target directory.
       * @param {boolean} dotfiles If `true` then it doesn't skip dot files by default.
       * @returns {IterableIterator<FileEntry>} The found files.
       * @private
       */
      _iterateFilesWithDirectory(directoryPath, dotfiles) {
        debug(`Directory: ${directoryPath}`);
        return this._iterateFilesRecursive(
          directoryPath,
          { dotfiles, recursive: true, selector: null }
        );
      }
      /**
       * Iterate files which are matched by a given glob pattern.
       * @param {string} pattern The glob pattern to iterate files.
       * @param {boolean} dotfiles If `true` then it doesn't skip dot files by default.
       * @returns {IterableIterator<FileEntry>} The found files.
       * @private
       */
      _iterateFilesWithGlob(pattern, dotfiles) {
        debug(`Glob: ${pattern}`);
        const directoryPath = path2.resolve(getGlobParent(pattern));
        const globPart = pattern.slice(directoryPath.length + 1);
        const recursive = /\*\*|\/|\\/u.test(globPart);
        const selector = new Minimatch(pattern, minimatchOpts);
        debug(`recursive? ${recursive}`);
        return this._iterateFilesRecursive(
          directoryPath,
          { dotfiles, recursive, selector }
        );
      }
      /**
       * Iterate files in a given path.
       * @param {string} directoryPath The path to the target directory.
       * @param {Object} options The options to iterate files.
       * @param {boolean} [options.dotfiles] If `true` then it doesn't skip dot files by default.
       * @param {boolean} [options.recursive] If `true` then it dives into sub directories.
       * @param {InstanceType<Minimatch>} [options.selector] The matcher to choose files.
       * @returns {IterableIterator<FileEntry>} The found files.
       * @private
       */
      *_iterateFilesRecursive(directoryPath, options) {
        debug(`Enter the directory: ${directoryPath}`);
        const { configArrayFactory } = internalSlotsMap.get(this);
        let config = null;
        for (const entry of readdirSafeSync(directoryPath)) {
          const filePath = path2.join(directoryPath, entry.name);
          const fileInfo = entry.isSymbolicLink() ? statSafeSync(filePath) : entry;
          if (!fileInfo) {
            continue;
          }
          if (fileInfo.isFile()) {
            if (!config) {
              config = configArrayFactory.getConfigArrayForFile(
                filePath,
                /*
                 * We must ignore `ConfigurationNotFoundError` at this
                 * point because we don't know if target files exist in
                 * this directory.
                 */
                { ignoreNotFoundError: true }
              );
            }
            const matched = options.selector ? options.selector.match(filePath) : this.isTargetPath(filePath, config);
            if (matched) {
              const ignored = this._isIgnoredFile(filePath, { ...options, config });
              const flag = ignored ? IGNORED_SILENTLY : NONE;
              debug(`Yield: ${entry.name}${ignored ? " but ignored" : ""}`);
              yield {
                config: configArrayFactory.getConfigArrayForFile(filePath),
                filePath,
                flag
              };
            } else {
              debug(`Didn't match: ${entry.name}`);
            }
          } else if (options.recursive && fileInfo.isDirectory()) {
            if (!config) {
              config = configArrayFactory.getConfigArrayForFile(
                filePath,
                { ignoreNotFoundError: true }
              );
            }
            const ignored = this._isIgnoredFile(
              filePath + path2.sep,
              { ...options, config }
            );
            if (!ignored) {
              yield* this._iterateFilesRecursive(filePath, options);
            }
          }
        }
        debug(`Leave the directory: ${directoryPath}`);
      }
      /**
       * Check if a given file should be ignored.
       * @param {string} filePath The path to a file to check.
       * @param {Object} options Options
       * @param {ConfigArray} [options.config] The config for this file.
       * @param {boolean} [options.dotfiles] If `true` then this is not ignore dot files by default.
       * @param {boolean} [options.direct] If `true` then this is a direct specified file.
       * @returns {boolean} `true` if the file should be ignored.
       * @private
       */
      _isIgnoredFile(filePath, {
        config: providedConfig,
        dotfiles = false,
        direct = false
      }) {
        const {
          configArrayFactory,
          defaultIgnores,
          ignoreFlag
        } = internalSlotsMap.get(this);
        if (ignoreFlag) {
          const config = providedConfig || configArrayFactory.getConfigArrayForFile(
            filePath,
            { ignoreNotFoundError: true }
          );
          const ignores = config.extractConfig(filePath).ignores || defaultIgnores;
          return ignores(filePath, dotfiles);
        }
        return !direct && defaultIgnores(filePath, dotfiles);
      }
    };
    module2.exports = { FileEnumerator };
  }
});

// node_modules/eslint/node_modules/eslint-scope/dist/eslint-scope.cjs
var require_eslint_scope = __commonJS({
  "node_modules/eslint/node_modules/eslint-scope/dist/eslint-scope.cjs"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var assert = require("assert");
    var estraverse = require_estraverse2();
    var esrecurse = require_esrecurse();
    function _interopDefaultLegacy(e) {
      return e && typeof e === "object" && "default" in e ? e : { "default": e };
    }
    var assert__default = /* @__PURE__ */ _interopDefaultLegacy(assert);
    var estraverse__default = /* @__PURE__ */ _interopDefaultLegacy(estraverse);
    var esrecurse__default = /* @__PURE__ */ _interopDefaultLegacy(esrecurse);
    var READ = 1;
    var WRITE = 2;
    var RW = READ | WRITE;
    var Reference = class _Reference {
      constructor(ident, scope, flag, writeExpr, maybeImplicitGlobal, partial, init) {
        this.identifier = ident;
        this.from = scope;
        this.tainted = false;
        this.resolved = null;
        this.flag = flag;
        if (this.isWrite()) {
          this.writeExpr = writeExpr;
          this.partial = partial;
          this.init = init;
        }
        this.__maybeImplicitGlobal = maybeImplicitGlobal;
      }
      /**
       * Whether the reference is static.
       * @function Reference#isStatic
       * @returns {boolean} static
       */
      isStatic() {
        return !this.tainted && this.resolved && this.resolved.scope.isStatic();
      }
      /**
       * Whether the reference is writeable.
       * @function Reference#isWrite
       * @returns {boolean} write
       */
      isWrite() {
        return !!(this.flag & _Reference.WRITE);
      }
      /**
       * Whether the reference is readable.
       * @function Reference#isRead
       * @returns {boolean} read
       */
      isRead() {
        return !!(this.flag & _Reference.READ);
      }
      /**
       * Whether the reference is read-only.
       * @function Reference#isReadOnly
       * @returns {boolean} read only
       */
      isReadOnly() {
        return this.flag === _Reference.READ;
      }
      /**
       * Whether the reference is write-only.
       * @function Reference#isWriteOnly
       * @returns {boolean} write only
       */
      isWriteOnly() {
        return this.flag === _Reference.WRITE;
      }
      /**
       * Whether the reference is read-write.
       * @function Reference#isReadWrite
       * @returns {boolean} read write
       */
      isReadWrite() {
        return this.flag === _Reference.RW;
      }
    };
    Reference.READ = READ;
    Reference.WRITE = WRITE;
    Reference.RW = RW;
    var Variable = class {
      constructor(name, scope) {
        this.name = name;
        this.identifiers = [];
        this.references = [];
        this.defs = [];
        this.tainted = false;
        this.stack = true;
        this.scope = scope;
      }
    };
    Variable.CatchClause = "CatchClause";
    Variable.Parameter = "Parameter";
    Variable.FunctionName = "FunctionName";
    Variable.ClassName = "ClassName";
    Variable.Variable = "Variable";
    Variable.ImportBinding = "ImportBinding";
    Variable.ImplicitGlobalVariable = "ImplicitGlobalVariable";
    var Definition = class {
      constructor(type, name, node, parent, index, kind) {
        this.type = type;
        this.name = name;
        this.node = node;
        this.parent = parent;
        this.index = index;
        this.kind = kind;
      }
    };
    var ParameterDefinition = class extends Definition {
      constructor(name, node, index, rest) {
        super(Variable.Parameter, name, node, null, index, null);
        this.rest = rest;
      }
    };
    var { Syntax: Syntax$2 } = estraverse__default["default"];
    function isStrictScope(scope, block, isMethodDefinition, useDirective) {
      let body;
      if (scope.upper && scope.upper.isStrict) {
        return true;
      }
      if (isMethodDefinition) {
        return true;
      }
      if (scope.type === "class" || scope.type === "module") {
        return true;
      }
      if (scope.type === "block" || scope.type === "switch") {
        return false;
      }
      if (scope.type === "function") {
        if (block.type === Syntax$2.ArrowFunctionExpression && block.body.type !== Syntax$2.BlockStatement) {
          return false;
        }
        if (block.type === Syntax$2.Program) {
          body = block;
        } else {
          body = block.body;
        }
        if (!body) {
          return false;
        }
      } else if (scope.type === "global") {
        body = block;
      } else {
        return false;
      }
      if (useDirective) {
        for (let i = 0, iz = body.body.length; i < iz; ++i) {
          const stmt = body.body[i];
          if (stmt.type !== Syntax$2.DirectiveStatement) {
            break;
          }
          if (stmt.raw === '"use strict"' || stmt.raw === "'use strict'") {
            return true;
          }
        }
      } else {
        for (let i = 0, iz = body.body.length; i < iz; ++i) {
          const stmt = body.body[i];
          if (stmt.type !== Syntax$2.ExpressionStatement) {
            break;
          }
          const expr = stmt.expression;
          if (expr.type !== Syntax$2.Literal || typeof expr.value !== "string") {
            break;
          }
          if (expr.raw !== null && expr.raw !== void 0) {
            if (expr.raw === '"use strict"' || expr.raw === "'use strict'") {
              return true;
            }
          } else {
            if (expr.value === "use strict") {
              return true;
            }
          }
        }
      }
      return false;
    }
    function registerScope(scopeManager, scope) {
      scopeManager.scopes.push(scope);
      const scopes = scopeManager.__nodeToScope.get(scope.block);
      if (scopes) {
        scopes.push(scope);
      } else {
        scopeManager.__nodeToScope.set(scope.block, [scope]);
      }
    }
    function shouldBeStatically(def) {
      return def.type === Variable.ClassName || def.type === Variable.Variable && def.parent.kind !== "var";
    }
    var Scope = class {
      constructor(scopeManager, type, upperScope, block, isMethodDefinition) {
        this.type = type;
        this.set = /* @__PURE__ */ new Map();
        this.taints = /* @__PURE__ */ new Map();
        this.dynamic = this.type === "global" || this.type === "with";
        this.block = block;
        this.through = [];
        this.variables = [];
        this.references = [];
        this.variableScope = this.type === "global" || this.type === "module" || this.type === "function" || this.type === "class-field-initializer" || this.type === "class-static-block" ? this : upperScope.variableScope;
        this.functionExpressionScope = false;
        this.directCallToEvalScope = false;
        this.thisFound = false;
        this.__left = [];
        this.upper = upperScope;
        this.isStrict = scopeManager.isStrictModeSupported() ? isStrictScope(this, block, isMethodDefinition, scopeManager.__useDirective()) : false;
        this.childScopes = [];
        if (this.upper) {
          this.upper.childScopes.push(this);
        }
        this.__declaredVariables = scopeManager.__declaredVariables;
        registerScope(scopeManager, this);
      }
      __shouldStaticallyClose(scopeManager) {
        return !this.dynamic || scopeManager.__isOptimistic();
      }
      __shouldStaticallyCloseForGlobal(ref) {
        const name = ref.identifier.name;
        if (!this.set.has(name)) {
          return false;
        }
        const variable = this.set.get(name);
        const defs = variable.defs;
        return defs.length > 0 && defs.every(shouldBeStatically);
      }
      __staticCloseRef(ref) {
        if (!this.__resolve(ref)) {
          this.__delegateToUpperScope(ref);
        }
      }
      __dynamicCloseRef(ref) {
        let current = this;
        do {
          current.through.push(ref);
          current = current.upper;
        } while (current);
      }
      __globalCloseRef(ref) {
        if (this.__shouldStaticallyCloseForGlobal(ref)) {
          this.__staticCloseRef(ref);
        } else {
          this.__dynamicCloseRef(ref);
        }
      }
      __close(scopeManager) {
        let closeRef;
        if (this.__shouldStaticallyClose(scopeManager)) {
          closeRef = this.__staticCloseRef;
        } else if (this.type !== "global") {
          closeRef = this.__dynamicCloseRef;
        } else {
          closeRef = this.__globalCloseRef;
        }
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          closeRef.call(this, ref);
        }
        this.__left = null;
        return this.upper;
      }
      // To override by function scopes.
      // References in default parameters isn't resolved to variables which are in their function body.
      __isValidResolution(ref, variable) {
        return true;
      }
      __resolve(ref) {
        const name = ref.identifier.name;
        if (!this.set.has(name)) {
          return false;
        }
        const variable = this.set.get(name);
        if (!this.__isValidResolution(ref, variable)) {
          return false;
        }
        variable.references.push(ref);
        variable.stack = variable.stack && ref.from.variableScope === this.variableScope;
        if (ref.tainted) {
          variable.tainted = true;
          this.taints.set(variable.name, true);
        }
        ref.resolved = variable;
        return true;
      }
      __delegateToUpperScope(ref) {
        if (this.upper) {
          this.upper.__left.push(ref);
        }
        this.through.push(ref);
      }
      __addDeclaredVariablesOfNode(variable, node) {
        if (node === null || node === void 0) {
          return;
        }
        let variables = this.__declaredVariables.get(node);
        if (variables === null || variables === void 0) {
          variables = [];
          this.__declaredVariables.set(node, variables);
        }
        if (variables.indexOf(variable) === -1) {
          variables.push(variable);
        }
      }
      __defineGeneric(name, set, variables, node, def) {
        let variable;
        variable = set.get(name);
        if (!variable) {
          variable = new Variable(name, this);
          set.set(name, variable);
          variables.push(variable);
        }
        if (def) {
          variable.defs.push(def);
          this.__addDeclaredVariablesOfNode(variable, def.node);
          this.__addDeclaredVariablesOfNode(variable, def.parent);
        }
        if (node) {
          variable.identifiers.push(node);
        }
      }
      __define(node, def) {
        if (node && node.type === Syntax$2.Identifier) {
          this.__defineGeneric(
            node.name,
            this.set,
            this.variables,
            node,
            def
          );
        }
      }
      __referencing(node, assign, writeExpr, maybeImplicitGlobal, partial, init) {
        if (!node || node.type !== Syntax$2.Identifier) {
          return;
        }
        if (node.name === "super") {
          return;
        }
        const ref = new Reference(node, this, assign || Reference.READ, writeExpr, maybeImplicitGlobal, !!partial, !!init);
        this.references.push(ref);
        this.__left.push(ref);
      }
      __detectEval() {
        let current = this;
        this.directCallToEvalScope = true;
        do {
          current.dynamic = true;
          current = current.upper;
        } while (current);
      }
      __detectThis() {
        this.thisFound = true;
      }
      __isClosed() {
        return this.__left === null;
      }
      /**
       * returns resolved {Reference}
       * @function Scope#resolve
       * @param {Espree.Identifier} ident identifier to be resolved.
       * @returns {Reference} reference
       */
      resolve(ident) {
        let ref, i, iz;
        assert__default["default"](this.__isClosed(), "Scope should be closed.");
        assert__default["default"](ident.type === Syntax$2.Identifier, "Target should be identifier.");
        for (i = 0, iz = this.references.length; i < iz; ++i) {
          ref = this.references[i];
          if (ref.identifier === ident) {
            return ref;
          }
        }
        return null;
      }
      /**
       * returns this scope is static
       * @function Scope#isStatic
       * @returns {boolean} static
       */
      isStatic() {
        return !this.dynamic;
      }
      /**
       * returns this scope has materialized arguments
       * @function Scope#isArgumentsMaterialized
       * @returns {boolean} arguemnts materialized
       */
      isArgumentsMaterialized() {
        return true;
      }
      /**
       * returns this scope has materialized `this` reference
       * @function Scope#isThisMaterialized
       * @returns {boolean} this materialized
       */
      isThisMaterialized() {
        return true;
      }
      isUsedName(name) {
        if (this.set.has(name)) {
          return true;
        }
        for (let i = 0, iz = this.through.length; i < iz; ++i) {
          if (this.through[i].identifier.name === name) {
            return true;
          }
        }
        return false;
      }
    };
    var GlobalScope = class extends Scope {
      constructor(scopeManager, block) {
        super(scopeManager, "global", null, block, false);
        this.implicit = {
          set: /* @__PURE__ */ new Map(),
          variables: [],
          /**
           * List of {@link Reference}s that are left to be resolved (i.e. which
           * need to be linked to the variable they refer to).
           * @member {Reference[]} Scope#implicit#left
           */
          left: []
        };
      }
      __close(scopeManager) {
        const implicit = [];
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          if (ref.__maybeImplicitGlobal && !this.set.has(ref.identifier.name)) {
            implicit.push(ref.__maybeImplicitGlobal);
          }
        }
        for (let i = 0, iz = implicit.length; i < iz; ++i) {
          const info = implicit[i];
          this.__defineImplicit(
            info.pattern,
            new Definition(
              Variable.ImplicitGlobalVariable,
              info.pattern,
              info.node,
              null,
              null,
              null
            )
          );
        }
        this.implicit.left = this.__left;
        return super.__close(scopeManager);
      }
      __defineImplicit(node, def) {
        if (node && node.type === Syntax$2.Identifier) {
          this.__defineGeneric(
            node.name,
            this.implicit.set,
            this.implicit.variables,
            node,
            def
          );
        }
      }
    };
    var ModuleScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "module", upperScope, block, false);
      }
    };
    var FunctionExpressionNameScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "function-expression-name", upperScope, block, false);
        this.__define(
          block.id,
          new Definition(
            Variable.FunctionName,
            block.id,
            block,
            null,
            null,
            null
          )
        );
        this.functionExpressionScope = true;
      }
    };
    var CatchScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "catch", upperScope, block, false);
      }
    };
    var WithScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "with", upperScope, block, false);
      }
      __close(scopeManager) {
        if (this.__shouldStaticallyClose(scopeManager)) {
          return super.__close(scopeManager);
        }
        for (let i = 0, iz = this.__left.length; i < iz; ++i) {
          const ref = this.__left[i];
          ref.tainted = true;
          this.__delegateToUpperScope(ref);
        }
        this.__left = null;
        return this.upper;
      }
    };
    var BlockScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "block", upperScope, block, false);
      }
    };
    var SwitchScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "switch", upperScope, block, false);
      }
    };
    var FunctionScope = class extends Scope {
      constructor(scopeManager, upperScope, block, isMethodDefinition) {
        super(scopeManager, "function", upperScope, block, isMethodDefinition);
        if (this.block.type !== Syntax$2.ArrowFunctionExpression) {
          this.__defineArguments();
        }
      }
      isArgumentsMaterialized() {
        if (this.block.type === Syntax$2.ArrowFunctionExpression) {
          return false;
        }
        if (!this.isStatic()) {
          return true;
        }
        const variable = this.set.get("arguments");
        assert__default["default"](variable, "Always have arguments variable.");
        return variable.tainted || variable.references.length !== 0;
      }
      isThisMaterialized() {
        if (!this.isStatic()) {
          return true;
        }
        return this.thisFound;
      }
      __defineArguments() {
        this.__defineGeneric(
          "arguments",
          this.set,
          this.variables,
          null,
          null
        );
        this.taints.set("arguments", true);
      }
      // References in default parameters isn't resolved to variables which are in their function body.
      //     const x = 1
      //     function f(a = x) { // This `x` is resolved to the `x` in the outer scope.
      //         const x = 2
      //         console.log(a)
      //     }
      __isValidResolution(ref, variable) {
        if (this.block.type === "Program") {
          return true;
        }
        const bodyStart = this.block.body.range[0];
        return !(variable.scope === this && ref.identifier.range[0] < bodyStart && // the reference is in the parameter part.
        variable.defs.every((d) => d.name.range[0] >= bodyStart));
      }
    };
    var ForScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "for", upperScope, block, false);
      }
    };
    var ClassScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "class", upperScope, block, false);
      }
    };
    var ClassFieldInitializerScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "class-field-initializer", upperScope, block, true);
      }
    };
    var ClassStaticBlockScope = class extends Scope {
      constructor(scopeManager, upperScope, block) {
        super(scopeManager, "class-static-block", upperScope, block, true);
      }
    };
    var ScopeManager = class {
      constructor(options) {
        this.scopes = [];
        this.globalScope = null;
        this.__nodeToScope = /* @__PURE__ */ new WeakMap();
        this.__currentScope = null;
        this.__options = options;
        this.__declaredVariables = /* @__PURE__ */ new WeakMap();
      }
      __useDirective() {
        return this.__options.directive;
      }
      __isOptimistic() {
        return this.__options.optimistic;
      }
      __ignoreEval() {
        return this.__options.ignoreEval;
      }
      __isNodejsScope() {
        return this.__options.nodejsScope || this.__options.sourceType === "commonjs";
      }
      isModule() {
        return this.__options.sourceType === "module";
      }
      isImpliedStrict() {
        return this.__options.impliedStrict;
      }
      isStrictModeSupported() {
        return this.__options.ecmaVersion >= 5;
      }
      // Returns appropriate scope for this node.
      __get(node) {
        return this.__nodeToScope.get(node);
      }
      /**
       * Get variables that are declared by the node.
       *
       * "are declared by the node" means the node is same as `Variable.defs[].node` or `Variable.defs[].parent`.
       * If the node declares nothing, this method returns an empty array.
       * CAUTION: This API is experimental. See https://github.com/estools/escope/pull/69 for more details.
       * @param {Espree.Node} node a node to get.
       * @returns {Variable[]} variables that declared by the node.
       */
      getDeclaredVariables(node) {
        return this.__declaredVariables.get(node) || [];
      }
      /**
       * acquire scope from node.
       * @function ScopeManager#acquire
       * @param {Espree.Node} node node for the acquired scope.
       * @param {?boolean} [inner=false] look up the most inner scope, default value is false.
       * @returns {Scope?} Scope from node
       */
      acquire(node, inner) {
        function predicate(testScope) {
          if (testScope.type === "function" && testScope.functionExpressionScope) {
            return false;
          }
          return true;
        }
        const scopes = this.__get(node);
        if (!scopes || scopes.length === 0) {
          return null;
        }
        if (scopes.length === 1) {
          return scopes[0];
        }
        if (inner) {
          for (let i = scopes.length - 1; i >= 0; --i) {
            const scope = scopes[i];
            if (predicate(scope)) {
              return scope;
            }
          }
        } else {
          for (let i = 0, iz = scopes.length; i < iz; ++i) {
            const scope = scopes[i];
            if (predicate(scope)) {
              return scope;
            }
          }
        }
        return null;
      }
      /**
       * acquire all scopes from node.
       * @function ScopeManager#acquireAll
       * @param {Espree.Node} node node for the acquired scope.
       * @returns {Scopes?} Scope array
       */
      acquireAll(node) {
        return this.__get(node);
      }
      /**
       * release the node.
       * @function ScopeManager#release
       * @param {Espree.Node} node releasing node.
       * @param {?boolean} [inner=false] look up the most inner scope, default value is false.
       * @returns {Scope?} upper scope for the node.
       */
      release(node, inner) {
        const scopes = this.__get(node);
        if (scopes && scopes.length) {
          const scope = scopes[0].upper;
          if (!scope) {
            return null;
          }
          return this.acquire(scope.block, inner);
        }
        return null;
      }
      attach() {
      }
      // eslint-disable-line class-methods-use-this
      detach() {
      }
      // eslint-disable-line class-methods-use-this
      __nestScope(scope) {
        if (scope instanceof GlobalScope) {
          assert__default["default"](this.__currentScope === null);
          this.globalScope = scope;
        }
        this.__currentScope = scope;
        return scope;
      }
      __nestGlobalScope(node) {
        return this.__nestScope(new GlobalScope(this, node));
      }
      __nestBlockScope(node) {
        return this.__nestScope(new BlockScope(this, this.__currentScope, node));
      }
      __nestFunctionScope(node, isMethodDefinition) {
        return this.__nestScope(new FunctionScope(this, this.__currentScope, node, isMethodDefinition));
      }
      __nestForScope(node) {
        return this.__nestScope(new ForScope(this, this.__currentScope, node));
      }
      __nestCatchScope(node) {
        return this.__nestScope(new CatchScope(this, this.__currentScope, node));
      }
      __nestWithScope(node) {
        return this.__nestScope(new WithScope(this, this.__currentScope, node));
      }
      __nestClassScope(node) {
        return this.__nestScope(new ClassScope(this, this.__currentScope, node));
      }
      __nestClassFieldInitializerScope(node) {
        return this.__nestScope(new ClassFieldInitializerScope(this, this.__currentScope, node));
      }
      __nestClassStaticBlockScope(node) {
        return this.__nestScope(new ClassStaticBlockScope(this, this.__currentScope, node));
      }
      __nestSwitchScope(node) {
        return this.__nestScope(new SwitchScope(this, this.__currentScope, node));
      }
      __nestModuleScope(node) {
        return this.__nestScope(new ModuleScope(this, this.__currentScope, node));
      }
      __nestFunctionExpressionNameScope(node) {
        return this.__nestScope(new FunctionExpressionNameScope(this, this.__currentScope, node));
      }
      __isES6() {
        return this.__options.ecmaVersion >= 6;
      }
    };
    var { Syntax: Syntax$1 } = estraverse__default["default"];
    function getLast(xs) {
      return xs[xs.length - 1] || null;
    }
    var PatternVisitor = class extends esrecurse__default["default"].Visitor {
      static isPattern(node) {
        const nodeType = node.type;
        return nodeType === Syntax$1.Identifier || nodeType === Syntax$1.ObjectPattern || nodeType === Syntax$1.ArrayPattern || nodeType === Syntax$1.SpreadElement || nodeType === Syntax$1.RestElement || nodeType === Syntax$1.AssignmentPattern;
      }
      constructor(options, rootPattern, callback) {
        super(null, options);
        this.rootPattern = rootPattern;
        this.callback = callback;
        this.assignments = [];
        this.rightHandNodes = [];
        this.restElements = [];
      }
      Identifier(pattern) {
        const lastRestElement = getLast(this.restElements);
        this.callback(pattern, {
          topLevel: pattern === this.rootPattern,
          rest: lastRestElement !== null && lastRestElement !== void 0 && lastRestElement.argument === pattern,
          assignments: this.assignments
        });
      }
      Property(property) {
        if (property.computed) {
          this.rightHandNodes.push(property.key);
        }
        this.visit(property.value);
      }
      ArrayPattern(pattern) {
        for (let i = 0, iz = pattern.elements.length; i < iz; ++i) {
          const element = pattern.elements[i];
          this.visit(element);
        }
      }
      AssignmentPattern(pattern) {
        this.assignments.push(pattern);
        this.visit(pattern.left);
        this.rightHandNodes.push(pattern.right);
        this.assignments.pop();
      }
      RestElement(pattern) {
        this.restElements.push(pattern);
        this.visit(pattern.argument);
        this.restElements.pop();
      }
      MemberExpression(node) {
        if (node.computed) {
          this.rightHandNodes.push(node.property);
        }
        this.rightHandNodes.push(node.object);
      }
      //
      // ForInStatement.left and AssignmentExpression.left are LeftHandSideExpression.
      // By spec, LeftHandSideExpression is Pattern or MemberExpression.
      //   (see also: https://github.com/estree/estree/pull/20#issuecomment-74584758)
      // But espree 2.0 parses to ArrayExpression, ObjectExpression, etc...
      //
      SpreadElement(node) {
        this.visit(node.argument);
      }
      ArrayExpression(node) {
        node.elements.forEach(this.visit, this);
      }
      AssignmentExpression(node) {
        this.assignments.push(node);
        this.visit(node.left);
        this.rightHandNodes.push(node.right);
        this.assignments.pop();
      }
      CallExpression(node) {
        node.arguments.forEach((a) => {
          this.rightHandNodes.push(a);
        });
        this.visit(node.callee);
      }
    };
    var { Syntax } = estraverse__default["default"];
    function traverseIdentifierInPattern(options, rootPattern, referencer, callback) {
      const visitor = new PatternVisitor(options, rootPattern, callback);
      visitor.visit(rootPattern);
      if (referencer !== null && referencer !== void 0) {
        visitor.rightHandNodes.forEach(referencer.visit, referencer);
      }
    }
    var Importer = class extends esrecurse__default["default"].Visitor {
      constructor(declaration, referencer) {
        super(null, referencer.options);
        this.declaration = declaration;
        this.referencer = referencer;
      }
      visitImport(id, specifier) {
        this.referencer.visitPattern(id, (pattern) => {
          this.referencer.currentScope().__define(
            pattern,
            new Definition(
              Variable.ImportBinding,
              pattern,
              specifier,
              this.declaration,
              null,
              null
            )
          );
        });
      }
      ImportNamespaceSpecifier(node) {
        const local = node.local || node.id;
        if (local) {
          this.visitImport(local, node);
        }
      }
      ImportDefaultSpecifier(node) {
        const local = node.local || node.id;
        this.visitImport(local, node);
      }
      ImportSpecifier(node) {
        const local = node.local || node.id;
        if (node.name) {
          this.visitImport(node.name, node);
        } else {
          this.visitImport(local, node);
        }
      }
    };
    var Referencer = class extends esrecurse__default["default"].Visitor {
      constructor(options, scopeManager) {
        super(null, options);
        this.options = options;
        this.scopeManager = scopeManager;
        this.parent = null;
        this.isInnerMethodDefinition = false;
      }
      currentScope() {
        return this.scopeManager.__currentScope;
      }
      close(node) {
        while (this.currentScope() && node === this.currentScope().block) {
          this.scopeManager.__currentScope = this.currentScope().__close(this.scopeManager);
        }
      }
      pushInnerMethodDefinition(isInnerMethodDefinition) {
        const previous = this.isInnerMethodDefinition;
        this.isInnerMethodDefinition = isInnerMethodDefinition;
        return previous;
      }
      popInnerMethodDefinition(isInnerMethodDefinition) {
        this.isInnerMethodDefinition = isInnerMethodDefinition;
      }
      referencingDefaultValue(pattern, assignments, maybeImplicitGlobal, init) {
        const scope = this.currentScope();
        assignments.forEach((assignment) => {
          scope.__referencing(
            pattern,
            Reference.WRITE,
            assignment.right,
            maybeImplicitGlobal,
            pattern !== assignment.left,
            init
          );
        });
      }
      visitPattern(node, options, callback) {
        let visitPatternOptions = options;
        let visitPatternCallback = callback;
        if (typeof options === "function") {
          visitPatternCallback = options;
          visitPatternOptions = { processRightHandNodes: false };
        }
        traverseIdentifierInPattern(
          this.options,
          node,
          visitPatternOptions.processRightHandNodes ? this : null,
          visitPatternCallback
        );
      }
      visitFunction(node) {
        let i, iz;
        if (node.type === Syntax.FunctionDeclaration) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.FunctionName,
              node.id,
              node,
              null,
              null,
              null
            )
          );
        }
        if (node.type === Syntax.FunctionExpression && node.id) {
          this.scopeManager.__nestFunctionExpressionNameScope(node);
        }
        this.scopeManager.__nestFunctionScope(node, this.isInnerMethodDefinition);
        const that = this;
        function visitPatternCallback(pattern, info) {
          that.currentScope().__define(
            pattern,
            new ParameterDefinition(
              pattern,
              node,
              i,
              info.rest
            )
          );
          that.referencingDefaultValue(pattern, info.assignments, null, true);
        }
        for (i = 0, iz = node.params.length; i < iz; ++i) {
          this.visitPattern(node.params[i], { processRightHandNodes: true }, visitPatternCallback);
        }
        if (node.rest) {
          this.visitPattern({
            type: "RestElement",
            argument: node.rest
          }, (pattern) => {
            this.currentScope().__define(
              pattern,
              new ParameterDefinition(
                pattern,
                node,
                node.params.length,
                true
              )
            );
          });
        }
        if (node.body) {
          if (node.body.type === Syntax.BlockStatement) {
            this.visitChildren(node.body);
          } else {
            this.visit(node.body);
          }
        }
        this.close(node);
      }
      visitClass(node) {
        if (node.type === Syntax.ClassDeclaration) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.ClassName,
              node.id,
              node,
              null,
              null,
              null
            )
          );
        }
        this.visit(node.superClass);
        this.scopeManager.__nestClassScope(node);
        if (node.id) {
          this.currentScope().__define(
            node.id,
            new Definition(
              Variable.ClassName,
              node.id,
              node
            )
          );
        }
        this.visit(node.body);
        this.close(node);
      }
      visitProperty(node) {
        let previous;
        if (node.computed) {
          this.visit(node.key);
        }
        const isMethodDefinition = node.type === Syntax.MethodDefinition;
        if (isMethodDefinition) {
          previous = this.pushInnerMethodDefinition(true);
        }
        this.visit(node.value);
        if (isMethodDefinition) {
          this.popInnerMethodDefinition(previous);
        }
      }
      visitForIn(node) {
        if (node.left.type === Syntax.VariableDeclaration && node.left.kind !== "var") {
          this.scopeManager.__nestForScope(node);
        }
        if (node.left.type === Syntax.VariableDeclaration) {
          this.visit(node.left);
          this.visitPattern(node.left.declarations[0].id, (pattern) => {
            this.currentScope().__referencing(pattern, Reference.WRITE, node.right, null, true, true);
          });
        } else {
          this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
            let maybeImplicitGlobal = null;
            if (!this.currentScope().isStrict) {
              maybeImplicitGlobal = {
                pattern,
                node
              };
            }
            this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
            this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, true, false);
          });
        }
        this.visit(node.right);
        this.visit(node.body);
        this.close(node);
      }
      visitVariableDeclaration(variableTargetScope, type, node, index) {
        const decl = node.declarations[index];
        const init = decl.init;
        this.visitPattern(decl.id, { processRightHandNodes: true }, (pattern, info) => {
          variableTargetScope.__define(
            pattern,
            new Definition(
              type,
              pattern,
              decl,
              node,
              index,
              node.kind
            )
          );
          this.referencingDefaultValue(pattern, info.assignments, null, true);
          if (init) {
            this.currentScope().__referencing(pattern, Reference.WRITE, init, null, !info.topLevel, true);
          }
        });
      }
      AssignmentExpression(node) {
        if (PatternVisitor.isPattern(node.left)) {
          if (node.operator === "=") {
            this.visitPattern(node.left, { processRightHandNodes: true }, (pattern, info) => {
              let maybeImplicitGlobal = null;
              if (!this.currentScope().isStrict) {
                maybeImplicitGlobal = {
                  pattern,
                  node
                };
              }
              this.referencingDefaultValue(pattern, info.assignments, maybeImplicitGlobal, false);
              this.currentScope().__referencing(pattern, Reference.WRITE, node.right, maybeImplicitGlobal, !info.topLevel, false);
            });
          } else {
            this.currentScope().__referencing(node.left, Reference.RW, node.right);
          }
        } else {
          this.visit(node.left);
        }
        this.visit(node.right);
      }
      CatchClause(node) {
        this.scopeManager.__nestCatchScope(node);
        this.visitPattern(node.param, { processRightHandNodes: true }, (pattern, info) => {
          this.currentScope().__define(
            pattern,
            new Definition(
              Variable.CatchClause,
              node.param,
              node,
              null,
              null,
              null
            )
          );
          this.referencingDefaultValue(pattern, info.assignments, null, true);
        });
        this.visit(node.body);
        this.close(node);
      }
      Program(node) {
        this.scopeManager.__nestGlobalScope(node);
        if (this.scopeManager.__isNodejsScope()) {
          this.currentScope().isStrict = false;
          this.scopeManager.__nestFunctionScope(node, false);
        }
        if (this.scopeManager.__isES6() && this.scopeManager.isModule()) {
          this.scopeManager.__nestModuleScope(node);
        }
        if (this.scopeManager.isStrictModeSupported() && this.scopeManager.isImpliedStrict()) {
          this.currentScope().isStrict = true;
        }
        this.visitChildren(node);
        this.close(node);
      }
      Identifier(node) {
        this.currentScope().__referencing(node);
      }
      // eslint-disable-next-line class-methods-use-this
      PrivateIdentifier() {
      }
      UpdateExpression(node) {
        if (PatternVisitor.isPattern(node.argument)) {
          this.currentScope().__referencing(node.argument, Reference.RW, null);
        } else {
          this.visitChildren(node);
        }
      }
      MemberExpression(node) {
        this.visit(node.object);
        if (node.computed) {
          this.visit(node.property);
        }
      }
      Property(node) {
        this.visitProperty(node);
      }
      PropertyDefinition(node) {
        const { computed, key, value: value2 } = node;
        if (computed) {
          this.visit(key);
        }
        if (value2) {
          this.scopeManager.__nestClassFieldInitializerScope(value2);
          this.visit(value2);
          this.close(value2);
        }
      }
      StaticBlock(node) {
        this.scopeManager.__nestClassStaticBlockScope(node);
        this.visitChildren(node);
        this.close(node);
      }
      MethodDefinition(node) {
        this.visitProperty(node);
      }
      BreakStatement() {
      }
      // eslint-disable-line class-methods-use-this
      ContinueStatement() {
      }
      // eslint-disable-line class-methods-use-this
      LabeledStatement(node) {
        this.visit(node.body);
      }
      ForStatement(node) {
        if (node.init && node.init.type === Syntax.VariableDeclaration && node.init.kind !== "var") {
          this.scopeManager.__nestForScope(node);
        }
        this.visitChildren(node);
        this.close(node);
      }
      ClassExpression(node) {
        this.visitClass(node);
      }
      ClassDeclaration(node) {
        this.visitClass(node);
      }
      CallExpression(node) {
        if (!this.scopeManager.__ignoreEval() && node.callee.type === Syntax.Identifier && node.callee.name === "eval") {
          this.currentScope().variableScope.__detectEval();
        }
        this.visitChildren(node);
      }
      BlockStatement(node) {
        if (this.scopeManager.__isES6()) {
          this.scopeManager.__nestBlockScope(node);
        }
        this.visitChildren(node);
        this.close(node);
      }
      ThisExpression() {
        this.currentScope().variableScope.__detectThis();
      }
      WithStatement(node) {
        this.visit(node.object);
        this.scopeManager.__nestWithScope(node);
        this.visit(node.body);
        this.close(node);
      }
      VariableDeclaration(node) {
        const variableTargetScope = node.kind === "var" ? this.currentScope().variableScope : this.currentScope();
        for (let i = 0, iz = node.declarations.length; i < iz; ++i) {
          const decl = node.declarations[i];
          this.visitVariableDeclaration(variableTargetScope, Variable.Variable, node, i);
          if (decl.init) {
            this.visit(decl.init);
          }
        }
      }
      // sec 13.11.8
      SwitchStatement(node) {
        this.visit(node.discriminant);
        if (this.scopeManager.__isES6()) {
          this.scopeManager.__nestSwitchScope(node);
        }
        for (let i = 0, iz = node.cases.length; i < iz; ++i) {
          this.visit(node.cases[i]);
        }
        this.close(node);
      }
      FunctionDeclaration(node) {
        this.visitFunction(node);
      }
      FunctionExpression(node) {
        this.visitFunction(node);
      }
      ForOfStatement(node) {
        this.visitForIn(node);
      }
      ForInStatement(node) {
        this.visitForIn(node);
      }
      ArrowFunctionExpression(node) {
        this.visitFunction(node);
      }
      ImportDeclaration(node) {
        assert__default["default"](this.scopeManager.__isES6() && this.scopeManager.isModule(), "ImportDeclaration should appear when the mode is ES6 and in the module context.");
        const importer = new Importer(node, this);
        importer.visit(node);
      }
      visitExportDeclaration(node) {
        if (node.source) {
          return;
        }
        if (node.declaration) {
          this.visit(node.declaration);
          return;
        }
        this.visitChildren(node);
      }
      // TODO: ExportDeclaration doesn't exist. for bc?
      ExportDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportAllDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportDefaultDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportNamedDeclaration(node) {
        this.visitExportDeclaration(node);
      }
      ExportSpecifier(node) {
        const local = node.id || node.local;
        this.visit(local);
      }
      MetaProperty() {
      }
    };
    var version2 = "7.1.1";
    function defaultOptions2() {
      return {
        optimistic: false,
        directive: false,
        nodejsScope: false,
        impliedStrict: false,
        sourceType: "script",
        // one of ['script', 'module', 'commonjs']
        ecmaVersion: 5,
        childVisitorKeys: null,
        fallback: "iteration"
      };
    }
    function updateDeeply(target, override) {
      function isHashObject(value2) {
        return typeof value2 === "object" && value2 instanceof Object && !(value2 instanceof Array) && !(value2 instanceof RegExp);
      }
      for (const key in override) {
        if (Object.prototype.hasOwnProperty.call(override, key)) {
          const val = override[key];
          if (isHashObject(val)) {
            if (isHashObject(target[key])) {
              updateDeeply(target[key], val);
            } else {
              target[key] = updateDeeply({}, val);
            }
          } else {
            target[key] = val;
          }
        }
      }
      return target;
    }
    function analyze(tree, providedOptions) {
      const options = updateDeeply(defaultOptions2(), providedOptions);
      const scopeManager = new ScopeManager(options);
      const referencer = new Referencer(options, scopeManager);
      referencer.visit(tree);
      assert__default["default"](scopeManager.__currentScope === null, "currentScope should be null.");
      return scopeManager;
    }
    exports.Definition = Definition;
    exports.PatternVisitor = PatternVisitor;
    exports.Reference = Reference;
    exports.Referencer = Referencer;
    exports.Scope = Scope;
    exports.ScopeManager = ScopeManager;
    exports.Variable = Variable;
    exports.analyze = analyze;
    exports.version = version2;
  }
});

// node_modules/lodash.merge/index.js
var require_lodash2 = __commonJS({
  "node_modules/lodash.merge/index.js"(exports, module2) {
    var LARGE_ARRAY_SIZE = 200;
    var HASH_UNDEFINED = "__lodash_hash_undefined__";
    var HOT_COUNT = 800;
    var HOT_SPAN = 16;
    var MAX_SAFE_INTEGER = 9007199254740991;
    var argsTag = "[object Arguments]";
    var arrayTag = "[object Array]";
    var asyncTag = "[object AsyncFunction]";
    var boolTag = "[object Boolean]";
    var dateTag = "[object Date]";
    var errorTag = "[object Error]";
    var funcTag = "[object Function]";
    var genTag = "[object GeneratorFunction]";
    var mapTag = "[object Map]";
    var numberTag = "[object Number]";
    var nullTag = "[object Null]";
    var objectTag = "[object Object]";
    var proxyTag = "[object Proxy]";
    var regexpTag = "[object RegExp]";
    var setTag = "[object Set]";
    var stringTag = "[object String]";
    var undefinedTag = "[object Undefined]";
    var weakMapTag = "[object WeakMap]";
    var arrayBufferTag = "[object ArrayBuffer]";
    var dataViewTag = "[object DataView]";
    var float32Tag = "[object Float32Array]";
    var float64Tag = "[object Float64Array]";
    var int8Tag = "[object Int8Array]";
    var int16Tag = "[object Int16Array]";
    var int32Tag = "[object Int32Array]";
    var uint8Tag = "[object Uint8Array]";
    var uint8ClampedTag = "[object Uint8ClampedArray]";
    var uint16Tag = "[object Uint16Array]";
    var uint32Tag = "[object Uint32Array]";
    var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
    var reIsHostCtor = /^\[object .+?Constructor\]$/;
    var reIsUint = /^(?:0|[1-9]\d*)$/;
    var typedArrayTags = {};
    typedArrayTags[float32Tag] = typedArrayTags[float64Tag] = typedArrayTags[int8Tag] = typedArrayTags[int16Tag] = typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] = typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] = typedArrayTags[uint32Tag] = true;
    typedArrayTags[argsTag] = typedArrayTags[arrayTag] = typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] = typedArrayTags[dataViewTag] = typedArrayTags[dateTag] = typedArrayTags[errorTag] = typedArrayTags[funcTag] = typedArrayTags[mapTag] = typedArrayTags[numberTag] = typedArrayTags[objectTag] = typedArrayTags[regexpTag] = typedArrayTags[setTag] = typedArrayTags[stringTag] = typedArrayTags[weakMapTag] = false;
    var freeGlobal = typeof global == "object" && global && global.Object === Object && global;
    var freeSelf = typeof self == "object" && self && self.Object === Object && self;
    var root2 = freeGlobal || freeSelf || Function("return this")();
    var freeExports = typeof exports == "object" && exports && !exports.nodeType && exports;
    var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var freeProcess = moduleExports && freeGlobal.process;
    var nodeUtil = function() {
      try {
        var types = freeModule && freeModule.require && freeModule.require("util").types;
        if (types) {
          return types;
        }
        return freeProcess && freeProcess.binding && freeProcess.binding("util");
      } catch (e) {
      }
    }();
    var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;
    function apply(func, thisArg, args) {
      switch (args.length) {
        case 0:
          return func.call(thisArg);
        case 1:
          return func.call(thisArg, args[0]);
        case 2:
          return func.call(thisArg, args[0], args[1]);
        case 3:
          return func.call(thisArg, args[0], args[1], args[2]);
      }
      return func.apply(thisArg, args);
    }
    function baseTimes(n, iteratee) {
      var index = -1, result = Array(n);
      while (++index < n) {
        result[index] = iteratee(index);
      }
      return result;
    }
    function baseUnary(func) {
      return function(value2) {
        return func(value2);
      };
    }
    function getValue(object, key) {
      return object == null ? void 0 : object[key];
    }
    function overArg(func, transform) {
      return function(arg) {
        return func(transform(arg));
      };
    }
    var arrayProto = Array.prototype;
    var funcProto = Function.prototype;
    var objectProto = Object.prototype;
    var coreJsData = root2["__core-js_shared__"];
    var funcToString = funcProto.toString;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var maskSrcKey = function() {
      var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
      return uid ? "Symbol(src)_1." + uid : "";
    }();
    var nativeObjectToString = objectProto.toString;
    var objectCtorString = funcToString.call(Object);
    var reIsNative = RegExp(
      "^" + funcToString.call(hasOwnProperty).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
    );
    var Buffer2 = moduleExports ? root2.Buffer : void 0;
    var Symbol2 = root2.Symbol;
    var Uint8Array2 = root2.Uint8Array;
    var allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : void 0;
    var getPrototype = overArg(Object.getPrototypeOf, Object);
    var objectCreate = Object.create;
    var propertyIsEnumerable = objectProto.propertyIsEnumerable;
    var splice = arrayProto.splice;
    var symToStringTag = Symbol2 ? Symbol2.toStringTag : void 0;
    var defineProperty = function() {
      try {
        var func = getNative(Object, "defineProperty");
        func({}, "", {});
        return func;
      } catch (e) {
      }
    }();
    var nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0;
    var nativeMax = Math.max;
    var nativeNow = Date.now;
    var Map2 = getNative(root2, "Map");
    var nativeCreate = getNative(Object, "create");
    var baseCreate = function() {
      function object() {
      }
      return function(proto) {
        if (!isObject(proto)) {
          return {};
        }
        if (objectCreate) {
          return objectCreate(proto);
        }
        object.prototype = proto;
        var result = new object();
        object.prototype = void 0;
        return result;
      };
    }();
    function Hash(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    function hashClear() {
      this.__data__ = nativeCreate ? nativeCreate(null) : {};
      this.size = 0;
    }
    function hashDelete(key) {
      var result = this.has(key) && delete this.__data__[key];
      this.size -= result ? 1 : 0;
      return result;
    }
    function hashGet(key) {
      var data = this.__data__;
      if (nativeCreate) {
        var result = data[key];
        return result === HASH_UNDEFINED ? void 0 : result;
      }
      return hasOwnProperty.call(data, key) ? data[key] : void 0;
    }
    function hashHas(key) {
      var data = this.__data__;
      return nativeCreate ? data[key] !== void 0 : hasOwnProperty.call(data, key);
    }
    function hashSet(key, value2) {
      var data = this.__data__;
      this.size += this.has(key) ? 0 : 1;
      data[key] = nativeCreate && value2 === void 0 ? HASH_UNDEFINED : value2;
      return this;
    }
    Hash.prototype.clear = hashClear;
    Hash.prototype["delete"] = hashDelete;
    Hash.prototype.get = hashGet;
    Hash.prototype.has = hashHas;
    Hash.prototype.set = hashSet;
    function ListCache(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    function listCacheClear() {
      this.__data__ = [];
      this.size = 0;
    }
    function listCacheDelete(key) {
      var data = this.__data__, index = assocIndexOf(data, key);
      if (index < 0) {
        return false;
      }
      var lastIndex = data.length - 1;
      if (index == lastIndex) {
        data.pop();
      } else {
        splice.call(data, index, 1);
      }
      --this.size;
      return true;
    }
    function listCacheGet(key) {
      var data = this.__data__, index = assocIndexOf(data, key);
      return index < 0 ? void 0 : data[index][1];
    }
    function listCacheHas(key) {
      return assocIndexOf(this.__data__, key) > -1;
    }
    function listCacheSet(key, value2) {
      var data = this.__data__, index = assocIndexOf(data, key);
      if (index < 0) {
        ++this.size;
        data.push([key, value2]);
      } else {
        data[index][1] = value2;
      }
      return this;
    }
    ListCache.prototype.clear = listCacheClear;
    ListCache.prototype["delete"] = listCacheDelete;
    ListCache.prototype.get = listCacheGet;
    ListCache.prototype.has = listCacheHas;
    ListCache.prototype.set = listCacheSet;
    function MapCache(entries) {
      var index = -1, length = entries == null ? 0 : entries.length;
      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }
    function mapCacheClear() {
      this.size = 0;
      this.__data__ = {
        "hash": new Hash(),
        "map": new (Map2 || ListCache)(),
        "string": new Hash()
      };
    }
    function mapCacheDelete(key) {
      var result = getMapData(this, key)["delete"](key);
      this.size -= result ? 1 : 0;
      return result;
    }
    function mapCacheGet(key) {
      return getMapData(this, key).get(key);
    }
    function mapCacheHas(key) {
      return getMapData(this, key).has(key);
    }
    function mapCacheSet(key, value2) {
      var data = getMapData(this, key), size = data.size;
      data.set(key, value2);
      this.size += data.size == size ? 0 : 1;
      return this;
    }
    MapCache.prototype.clear = mapCacheClear;
    MapCache.prototype["delete"] = mapCacheDelete;
    MapCache.prototype.get = mapCacheGet;
    MapCache.prototype.has = mapCacheHas;
    MapCache.prototype.set = mapCacheSet;
    function Stack(entries) {
      var data = this.__data__ = new ListCache(entries);
      this.size = data.size;
    }
    function stackClear() {
      this.__data__ = new ListCache();
      this.size = 0;
    }
    function stackDelete(key) {
      var data = this.__data__, result = data["delete"](key);
      this.size = data.size;
      return result;
    }
    function stackGet(key) {
      return this.__data__.get(key);
    }
    function stackHas(key) {
      return this.__data__.has(key);
    }
    function stackSet(key, value2) {
      var data = this.__data__;
      if (data instanceof ListCache) {
        var pairs = data.__data__;
        if (!Map2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
          pairs.push([key, value2]);
          this.size = ++data.size;
          return this;
        }
        data = this.__data__ = new MapCache(pairs);
      }
      data.set(key, value2);
      this.size = data.size;
      return this;
    }
    Stack.prototype.clear = stackClear;
    Stack.prototype["delete"] = stackDelete;
    Stack.prototype.get = stackGet;
    Stack.prototype.has = stackHas;
    Stack.prototype.set = stackSet;
    function arrayLikeKeys(value2, inherited) {
      var isArr = isArray2(value2), isArg = !isArr && isArguments(value2), isBuff = !isArr && !isArg && isBuffer(value2), isType = !isArr && !isArg && !isBuff && isTypedArray(value2), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value2.length, String) : [], length = result.length;
      for (var key in value2) {
        if ((inherited || hasOwnProperty.call(value2, key)) && !(skipIndexes && // Safari 9 has enumerable `arguments.length` in strict mode.
        (key == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
        isBuff && (key == "offset" || key == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
        isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || // Skip index properties.
        isIndex(key, length)))) {
          result.push(key);
        }
      }
      return result;
    }
    function assignMergeValue(object, key, value2) {
      if (value2 !== void 0 && !eq(object[key], value2) || value2 === void 0 && !(key in object)) {
        baseAssignValue(object, key, value2);
      }
    }
    function assignValue(object, key, value2) {
      var objValue = object[key];
      if (!(hasOwnProperty.call(object, key) && eq(objValue, value2)) || value2 === void 0 && !(key in object)) {
        baseAssignValue(object, key, value2);
      }
    }
    function assocIndexOf(array, key) {
      var length = array.length;
      while (length--) {
        if (eq(array[length][0], key)) {
          return length;
        }
      }
      return -1;
    }
    function baseAssignValue(object, key, value2) {
      if (key == "__proto__" && defineProperty) {
        defineProperty(object, key, {
          "configurable": true,
          "enumerable": true,
          "value": value2,
          "writable": true
        });
      } else {
        object[key] = value2;
      }
    }
    var baseFor = createBaseFor();
    function baseGetTag(value2) {
      if (value2 == null) {
        return value2 === void 0 ? undefinedTag : nullTag;
      }
      return symToStringTag && symToStringTag in Object(value2) ? getRawTag(value2) : objectToString(value2);
    }
    function baseIsArguments(value2) {
      return isObjectLike(value2) && baseGetTag(value2) == argsTag;
    }
    function baseIsNative(value2) {
      if (!isObject(value2) || isMasked(value2)) {
        return false;
      }
      var pattern = isFunction(value2) ? reIsNative : reIsHostCtor;
      return pattern.test(toSource(value2));
    }
    function baseIsTypedArray(value2) {
      return isObjectLike(value2) && isLength(value2.length) && !!typedArrayTags[baseGetTag(value2)];
    }
    function baseKeysIn(object) {
      if (!isObject(object)) {
        return nativeKeysIn(object);
      }
      var isProto = isPrototype(object), result = [];
      for (var key in object) {
        if (!(key == "constructor" && (isProto || !hasOwnProperty.call(object, key)))) {
          result.push(key);
        }
      }
      return result;
    }
    function baseMerge(object, source, srcIndex, customizer, stack) {
      if (object === source) {
        return;
      }
      baseFor(source, function(srcValue, key) {
        stack || (stack = new Stack());
        if (isObject(srcValue)) {
          baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack);
        } else {
          var newValue = customizer ? customizer(safeGet(object, key), srcValue, key + "", object, source, stack) : void 0;
          if (newValue === void 0) {
            newValue = srcValue;
          }
          assignMergeValue(object, key, newValue);
        }
      }, keysIn);
    }
    function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack) {
      var objValue = safeGet(object, key), srcValue = safeGet(source, key), stacked = stack.get(srcValue);
      if (stacked) {
        assignMergeValue(object, key, stacked);
        return;
      }
      var newValue = customizer ? customizer(objValue, srcValue, key + "", object, source, stack) : void 0;
      var isCommon = newValue === void 0;
      if (isCommon) {
        var isArr = isArray2(srcValue), isBuff = !isArr && isBuffer(srcValue), isTyped = !isArr && !isBuff && isTypedArray(srcValue);
        newValue = srcValue;
        if (isArr || isBuff || isTyped) {
          if (isArray2(objValue)) {
            newValue = objValue;
          } else if (isArrayLikeObject(objValue)) {
            newValue = copyArray(objValue);
          } else if (isBuff) {
            isCommon = false;
            newValue = cloneBuffer(srcValue, true);
          } else if (isTyped) {
            isCommon = false;
            newValue = cloneTypedArray(srcValue, true);
          } else {
            newValue = [];
          }
        } else if (isPlainObject(srcValue) || isArguments(srcValue)) {
          newValue = objValue;
          if (isArguments(objValue)) {
            newValue = toPlainObject(objValue);
          } else if (!isObject(objValue) || isFunction(objValue)) {
            newValue = initCloneObject(srcValue);
          }
        } else {
          isCommon = false;
        }
      }
      if (isCommon) {
        stack.set(srcValue, newValue);
        mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
        stack["delete"](srcValue);
      }
      assignMergeValue(object, key, newValue);
    }
    function baseRest(func, start) {
      return setToString(overRest(func, start, identity), func + "");
    }
    var baseSetToString = !defineProperty ? identity : function(func, string) {
      return defineProperty(func, "toString", {
        "configurable": true,
        "enumerable": false,
        "value": constant(string),
        "writable": true
      });
    };
    function cloneBuffer(buffer, isDeep) {
      if (isDeep) {
        return buffer.slice();
      }
      var length = buffer.length, result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
      buffer.copy(result);
      return result;
    }
    function cloneArrayBuffer(arrayBuffer) {
      var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
      new Uint8Array2(result).set(new Uint8Array2(arrayBuffer));
      return result;
    }
    function cloneTypedArray(typedArray, isDeep) {
      var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
      return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
    }
    function copyArray(source, array) {
      var index = -1, length = source.length;
      array || (array = Array(length));
      while (++index < length) {
        array[index] = source[index];
      }
      return array;
    }
    function copyObject(source, props, object, customizer) {
      var isNew = !object;
      object || (object = {});
      var index = -1, length = props.length;
      while (++index < length) {
        var key = props[index];
        var newValue = customizer ? customizer(object[key], source[key], key, object, source) : void 0;
        if (newValue === void 0) {
          newValue = source[key];
        }
        if (isNew) {
          baseAssignValue(object, key, newValue);
        } else {
          assignValue(object, key, newValue);
        }
      }
      return object;
    }
    function createAssigner(assigner) {
      return baseRest(function(object, sources) {
        var index = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : void 0, guard = length > 2 ? sources[2] : void 0;
        customizer = assigner.length > 3 && typeof customizer == "function" ? (length--, customizer) : void 0;
        if (guard && isIterateeCall(sources[0], sources[1], guard)) {
          customizer = length < 3 ? void 0 : customizer;
          length = 1;
        }
        object = Object(object);
        while (++index < length) {
          var source = sources[index];
          if (source) {
            assigner(object, source, index, customizer);
          }
        }
        return object;
      });
    }
    function createBaseFor(fromRight) {
      return function(object, iteratee, keysFunc) {
        var index = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
        while (length--) {
          var key = props[fromRight ? length : ++index];
          if (iteratee(iterable[key], key, iterable) === false) {
            break;
          }
        }
        return object;
      };
    }
    function getMapData(map, key) {
      var data = map.__data__;
      return isKeyable(key) ? data[typeof key == "string" ? "string" : "hash"] : data.map;
    }
    function getNative(object, key) {
      var value2 = getValue(object, key);
      return baseIsNative(value2) ? value2 : void 0;
    }
    function getRawTag(value2) {
      var isOwn = hasOwnProperty.call(value2, symToStringTag), tag = value2[symToStringTag];
      try {
        value2[symToStringTag] = void 0;
        var unmasked = true;
      } catch (e) {
      }
      var result = nativeObjectToString.call(value2);
      if (unmasked) {
        if (isOwn) {
          value2[symToStringTag] = tag;
        } else {
          delete value2[symToStringTag];
        }
      }
      return result;
    }
    function initCloneObject(object) {
      return typeof object.constructor == "function" && !isPrototype(object) ? baseCreate(getPrototype(object)) : {};
    }
    function isIndex(value2, length) {
      var type = typeof value2;
      length = length == null ? MAX_SAFE_INTEGER : length;
      return !!length && (type == "number" || type != "symbol" && reIsUint.test(value2)) && (value2 > -1 && value2 % 1 == 0 && value2 < length);
    }
    function isIterateeCall(value2, index, object) {
      if (!isObject(object)) {
        return false;
      }
      var type = typeof index;
      if (type == "number" ? isArrayLike(object) && isIndex(index, object.length) : type == "string" && index in object) {
        return eq(object[index], value2);
      }
      return false;
    }
    function isKeyable(value2) {
      var type = typeof value2;
      return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value2 !== "__proto__" : value2 === null;
    }
    function isMasked(func) {
      return !!maskSrcKey && maskSrcKey in func;
    }
    function isPrototype(value2) {
      var Ctor = value2 && value2.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto;
      return value2 === proto;
    }
    function nativeKeysIn(object) {
      var result = [];
      if (object != null) {
        for (var key in Object(object)) {
          result.push(key);
        }
      }
      return result;
    }
    function objectToString(value2) {
      return nativeObjectToString.call(value2);
    }
    function overRest(func, start, transform) {
      start = nativeMax(start === void 0 ? func.length - 1 : start, 0);
      return function() {
        var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array(length);
        while (++index < length) {
          array[index] = args[start + index];
        }
        index = -1;
        var otherArgs = Array(start + 1);
        while (++index < start) {
          otherArgs[index] = args[index];
        }
        otherArgs[start] = transform(array);
        return apply(func, this, otherArgs);
      };
    }
    function safeGet(object, key) {
      if (key === "constructor" && typeof object[key] === "function") {
        return;
      }
      if (key == "__proto__") {
        return;
      }
      return object[key];
    }
    var setToString = shortOut(baseSetToString);
    function shortOut(func) {
      var count = 0, lastCalled = 0;
      return function() {
        var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
        lastCalled = stamp;
        if (remaining > 0) {
          if (++count >= HOT_COUNT) {
            return arguments[0];
          }
        } else {
          count = 0;
        }
        return func.apply(void 0, arguments);
      };
    }
    function toSource(func) {
      if (func != null) {
        try {
          return funcToString.call(func);
        } catch (e) {
        }
        try {
          return func + "";
        } catch (e) {
        }
      }
      return "";
    }
    function eq(value2, other) {
      return value2 === other || value2 !== value2 && other !== other;
    }
    var isArguments = baseIsArguments(function() {
      return arguments;
    }()) ? baseIsArguments : function(value2) {
      return isObjectLike(value2) && hasOwnProperty.call(value2, "callee") && !propertyIsEnumerable.call(value2, "callee");
    };
    var isArray2 = Array.isArray;
    function isArrayLike(value2) {
      return value2 != null && isLength(value2.length) && !isFunction(value2);
    }
    function isArrayLikeObject(value2) {
      return isObjectLike(value2) && isArrayLike(value2);
    }
    var isBuffer = nativeIsBuffer || stubFalse;
    function isFunction(value2) {
      if (!isObject(value2)) {
        return false;
      }
      var tag = baseGetTag(value2);
      return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
    }
    function isLength(value2) {
      return typeof value2 == "number" && value2 > -1 && value2 % 1 == 0 && value2 <= MAX_SAFE_INTEGER;
    }
    function isObject(value2) {
      var type = typeof value2;
      return value2 != null && (type == "object" || type == "function");
    }
    function isObjectLike(value2) {
      return value2 != null && typeof value2 == "object";
    }
    function isPlainObject(value2) {
      if (!isObjectLike(value2) || baseGetTag(value2) != objectTag) {
        return false;
      }
      var proto = getPrototype(value2);
      if (proto === null) {
        return true;
      }
      var Ctor = hasOwnProperty.call(proto, "constructor") && proto.constructor;
      return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString.call(Ctor) == objectCtorString;
    }
    var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;
    function toPlainObject(value2) {
      return copyObject(value2, keysIn(value2));
    }
    function keysIn(object) {
      return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
    }
    var merge4 = createAssigner(function(object, source, srcIndex) {
      baseMerge(object, source, srcIndex);
    });
    function constant(value2) {
      return function() {
        return value2;
      };
    }
    function identity(value2) {
      return value2;
    }
    function stubFalse() {
      return false;
    }
    module2.exports = merge4;
  }
});

// node_modules/@eslint/eslintrc/dist/eslintrc-universal.cjs
var require_eslintrc_universal = __commonJS({
  "node_modules/@eslint/eslintrc/dist/eslintrc-universal.cjs"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var util = require("util");
    var path2 = require("path");
    var Ajv = require_ajv();
    var globals = require_globals2();
    function _interopDefaultLegacy(e) {
      return e && typeof e === "object" && "default" in e ? e : { "default": e };
    }
    var util__default = /* @__PURE__ */ _interopDefaultLegacy(util);
    var path__default = /* @__PURE__ */ _interopDefaultLegacy(path2);
    var Ajv__default = /* @__PURE__ */ _interopDefaultLegacy(Ajv);
    var globals__default = /* @__PURE__ */ _interopDefaultLegacy(globals);
    var RULE_SEVERITY_STRINGS = ["off", "warn", "error"];
    var RULE_SEVERITY = RULE_SEVERITY_STRINGS.reduce((map, value2, index) => {
      map[value2] = index;
      return map;
    }, {});
    var VALID_SEVERITIES = [0, 1, 2, "off", "warn", "error"];
    function getRuleSeverity(ruleConfig) {
      const severityValue = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
      if (severityValue === 0 || severityValue === 1 || severityValue === 2) {
        return severityValue;
      }
      if (typeof severityValue === "string") {
        return RULE_SEVERITY[severityValue.toLowerCase()] || 0;
      }
      return 0;
    }
    function normalizeToStrings(config) {
      if (config.rules) {
        Object.keys(config.rules).forEach((ruleId) => {
          const ruleConfig = config.rules[ruleId];
          if (typeof ruleConfig === "number") {
            config.rules[ruleId] = RULE_SEVERITY_STRINGS[ruleConfig] || RULE_SEVERITY_STRINGS[0];
          } else if (Array.isArray(ruleConfig) && typeof ruleConfig[0] === "number") {
            ruleConfig[0] = RULE_SEVERITY_STRINGS[ruleConfig[0]] || RULE_SEVERITY_STRINGS[0];
          }
        });
      }
    }
    function isErrorSeverity(ruleConfig) {
      return getRuleSeverity(ruleConfig) === 2;
    }
    function isValidSeverity(ruleConfig) {
      let severity = Array.isArray(ruleConfig) ? ruleConfig[0] : ruleConfig;
      if (typeof severity === "string") {
        severity = severity.toLowerCase();
      }
      return VALID_SEVERITIES.indexOf(severity) !== -1;
    }
    function isEverySeverityValid(config) {
      return Object.keys(config).every((ruleId) => isValidSeverity(config[ruleId]));
    }
    function normalizeConfigGlobal(configuredValue) {
      switch (configuredValue) {
        case "off":
          return "off";
        case true:
        case "true":
        case "writeable":
        case "writable":
          return "writable";
        case null:
        case false:
        case "false":
        case "readable":
        case "readonly":
          return "readonly";
        default:
          throw new Error(`'${configuredValue}' is not a valid configuration for a global (use 'readonly', 'writable', or 'off')`);
      }
    }
    var ConfigOps = {
      __proto__: null,
      getRuleSeverity,
      normalizeToStrings,
      isErrorSeverity,
      isValidSeverity,
      isEverySeverityValid,
      normalizeConfigGlobal
    };
    var deprecationWarningMessages = {
      ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect.",
      ESLINT_PERSONAL_CONFIG_LOAD: "'~/.eslintrc.*' config files have been deprecated. Please use a config file per project or the '--config' option.",
      ESLINT_PERSONAL_CONFIG_SUPPRESS: "'~/.eslintrc.*' config files have been deprecated. Please remove it or add 'root:true' to the config files in your projects in order to avoid loading '~/.eslintrc.*' accidentally."
    };
    var sourceFileErrorCache = /* @__PURE__ */ new Set();
    function emitDeprecationWarning(source, errorCode) {
      const cacheKey = JSON.stringify({ source, errorCode });
      if (sourceFileErrorCache.has(cacheKey)) {
        return;
      }
      sourceFileErrorCache.add(cacheKey);
      const rel = path__default["default"].relative(process.cwd(), source);
      const message = deprecationWarningMessages[errorCode];
      process.emitWarning(
        `${message} (found in "${rel}")`,
        "DeprecationWarning",
        errorCode
      );
    }
    var metaSchema = {
      id: "http://json-schema.org/draft-04/schema#",
      $schema: "http://json-schema.org/draft-04/schema#",
      description: "Core schema meta-schema",
      definitions: {
        schemaArray: {
          type: "array",
          minItems: 1,
          items: { $ref: "#" }
        },
        positiveInteger: {
          type: "integer",
          minimum: 0
        },
        positiveIntegerDefault0: {
          allOf: [{ $ref: "#/definitions/positiveInteger" }, { default: 0 }]
        },
        simpleTypes: {
          enum: ["array", "boolean", "integer", "null", "number", "object", "string"]
        },
        stringArray: {
          type: "array",
          items: { type: "string" },
          minItems: 1,
          uniqueItems: true
        }
      },
      type: "object",
      properties: {
        id: {
          type: "string"
        },
        $schema: {
          type: "string"
        },
        title: {
          type: "string"
        },
        description: {
          type: "string"
        },
        default: {},
        multipleOf: {
          type: "number",
          minimum: 0,
          exclusiveMinimum: true
        },
        maximum: {
          type: "number"
        },
        exclusiveMaximum: {
          type: "boolean",
          default: false
        },
        minimum: {
          type: "number"
        },
        exclusiveMinimum: {
          type: "boolean",
          default: false
        },
        maxLength: { $ref: "#/definitions/positiveInteger" },
        minLength: { $ref: "#/definitions/positiveIntegerDefault0" },
        pattern: {
          type: "string",
          format: "regex"
        },
        additionalItems: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        items: {
          anyOf: [
            { $ref: "#" },
            { $ref: "#/definitions/schemaArray" }
          ],
          default: {}
        },
        maxItems: { $ref: "#/definitions/positiveInteger" },
        minItems: { $ref: "#/definitions/positiveIntegerDefault0" },
        uniqueItems: {
          type: "boolean",
          default: false
        },
        maxProperties: { $ref: "#/definitions/positiveInteger" },
        minProperties: { $ref: "#/definitions/positiveIntegerDefault0" },
        required: { $ref: "#/definitions/stringArray" },
        additionalProperties: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        definitions: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        properties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        patternProperties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        dependencies: {
          type: "object",
          additionalProperties: {
            anyOf: [
              { $ref: "#" },
              { $ref: "#/definitions/stringArray" }
            ]
          }
        },
        enum: {
          type: "array",
          minItems: 1,
          uniqueItems: true
        },
        type: {
          anyOf: [
            { $ref: "#/definitions/simpleTypes" },
            {
              type: "array",
              items: { $ref: "#/definitions/simpleTypes" },
              minItems: 1,
              uniqueItems: true
            }
          ]
        },
        format: { type: "string" },
        allOf: { $ref: "#/definitions/schemaArray" },
        anyOf: { $ref: "#/definitions/schemaArray" },
        oneOf: { $ref: "#/definitions/schemaArray" },
        not: { $ref: "#" }
      },
      dependencies: {
        exclusiveMaximum: ["maximum"],
        exclusiveMinimum: ["minimum"]
      },
      default: {}
    };
    var ajvOrig = (additionalOptions = {}) => {
      const ajv2 = new Ajv__default["default"]({
        meta: false,
        useDefaults: true,
        validateSchema: false,
        missingRefs: "ignore",
        verbose: true,
        schemaId: "auto",
        ...additionalOptions
      });
      ajv2.addMetaSchema(metaSchema);
      ajv2._opts.defaultMeta = metaSchema.id;
      return ajv2;
    };
    var baseConfigProperties = {
      $schema: { type: "string" },
      env: { type: "object" },
      extends: { $ref: "#/definitions/stringOrStrings" },
      globals: { type: "object" },
      overrides: {
        type: "array",
        items: { $ref: "#/definitions/overrideConfig" },
        additionalItems: false
      },
      parser: { type: ["string", "null"] },
      parserOptions: { type: "object" },
      plugins: { type: "array" },
      processor: { type: "string" },
      rules: { type: "object" },
      settings: { type: "object" },
      noInlineConfig: { type: "boolean" },
      reportUnusedDisableDirectives: { type: "boolean" },
      ecmaFeatures: { type: "object" }
      // deprecated; logs a warning when used
    };
    var configSchema = {
      definitions: {
        stringOrStrings: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false
            }
          ]
        },
        stringOrStringsRequired: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false,
              minItems: 1
            }
          ]
        },
        // Config at top-level.
        objectConfig: {
          type: "object",
          properties: {
            root: { type: "boolean" },
            ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
            ...baseConfigProperties
          },
          additionalProperties: false
        },
        // Config in `overrides`.
        overrideConfig: {
          type: "object",
          properties: {
            excludedFiles: { $ref: "#/definitions/stringOrStrings" },
            files: { $ref: "#/definitions/stringOrStringsRequired" },
            ...baseConfigProperties
          },
          required: ["files"],
          additionalProperties: false
        }
      },
      $ref: "#/definitions/objectConfig"
    };
    function getDiff(current, prev) {
      const retv = {};
      for (const [key, value2] of Object.entries(current)) {
        if (!Object.hasOwnProperty.call(prev, key)) {
          retv[key] = value2;
        }
      }
      return retv;
    }
    var newGlobals2015 = getDiff(globals__default["default"].es2015, globals__default["default"].es5);
    var newGlobals2017 = {
      Atomics: false,
      SharedArrayBuffer: false
    };
    var newGlobals2020 = {
      BigInt: false,
      BigInt64Array: false,
      BigUint64Array: false,
      globalThis: false
    };
    var newGlobals2021 = {
      AggregateError: false,
      FinalizationRegistry: false,
      WeakRef: false
    };
    var environments = new Map(Object.entries({
      // Language
      builtin: {
        globals: globals__default["default"].es5
      },
      es6: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 6
        }
      },
      es2015: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 6
        }
      },
      es2016: {
        globals: newGlobals2015,
        parserOptions: {
          ecmaVersion: 7
        }
      },
      es2017: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 8
        }
      },
      es2018: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 9
        }
      },
      es2019: {
        globals: { ...newGlobals2015, ...newGlobals2017 },
        parserOptions: {
          ecmaVersion: 10
        }
      },
      es2020: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020 },
        parserOptions: {
          ecmaVersion: 11
        }
      },
      es2021: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
        parserOptions: {
          ecmaVersion: 12
        }
      },
      es2022: {
        globals: { ...newGlobals2015, ...newGlobals2017, ...newGlobals2020, ...newGlobals2021 },
        parserOptions: {
          ecmaVersion: 13
        }
      },
      // Platforms
      browser: {
        globals: globals__default["default"].browser
      },
      node: {
        globals: globals__default["default"].node,
        parserOptions: {
          ecmaFeatures: {
            globalReturn: true
          }
        }
      },
      "shared-node-browser": {
        globals: globals__default["default"]["shared-node-browser"]
      },
      worker: {
        globals: globals__default["default"].worker
      },
      serviceworker: {
        globals: globals__default["default"].serviceworker
      },
      // Frameworks
      commonjs: {
        globals: globals__default["default"].commonjs,
        parserOptions: {
          ecmaFeatures: {
            globalReturn: true
          }
        }
      },
      amd: {
        globals: globals__default["default"].amd
      },
      mocha: {
        globals: globals__default["default"].mocha
      },
      jasmine: {
        globals: globals__default["default"].jasmine
      },
      jest: {
        globals: globals__default["default"].jest
      },
      phantomjs: {
        globals: globals__default["default"].phantomjs
      },
      jquery: {
        globals: globals__default["default"].jquery
      },
      qunit: {
        globals: globals__default["default"].qunit
      },
      prototypejs: {
        globals: globals__default["default"].prototypejs
      },
      shelljs: {
        globals: globals__default["default"].shelljs
      },
      meteor: {
        globals: globals__default["default"].meteor
      },
      mongo: {
        globals: globals__default["default"].mongo
      },
      protractor: {
        globals: globals__default["default"].protractor
      },
      applescript: {
        globals: globals__default["default"].applescript
      },
      nashorn: {
        globals: globals__default["default"].nashorn
      },
      atomtest: {
        globals: globals__default["default"].atomtest
      },
      embertest: {
        globals: globals__default["default"].embertest
      },
      webextensions: {
        globals: globals__default["default"].webextensions
      },
      greasemonkey: {
        globals: globals__default["default"].greasemonkey
      }
    }));
    var ajv = ajvOrig();
    var ruleValidators = /* @__PURE__ */ new WeakMap();
    var noop = Function.prototype;
    var validateSchema;
    var severityMap = {
      error: 2,
      warn: 1,
      off: 0
    };
    var validated = /* @__PURE__ */ new WeakSet();
    var ConfigValidator = class {
      constructor({ builtInRules = /* @__PURE__ */ new Map() } = {}) {
        this.builtInRules = builtInRules;
      }
      /**
       * Gets a complete options schema for a rule.
       * @param {{create: Function, schema: (Array|null)}} rule A new-style rule object
       * @returns {Object} JSON Schema for the rule's options.
       */
      getRuleOptionsSchema(rule) {
        if (!rule) {
          return null;
        }
        const schema = rule.schema || rule.meta && rule.meta.schema;
        if (Array.isArray(schema)) {
          if (schema.length) {
            return {
              type: "array",
              items: schema,
              minItems: 0,
              maxItems: schema.length
            };
          }
          return {
            type: "array",
            minItems: 0,
            maxItems: 0
          };
        }
        return schema || null;
      }
      /**
       * Validates a rule's severity and returns the severity value. Throws an error if the severity is invalid.
       * @param {options} options The given options for the rule.
       * @returns {number|string} The rule's severity value
       */
      validateRuleSeverity(options) {
        const severity = Array.isArray(options) ? options[0] : options;
        const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
        if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
          return normSeverity;
        }
        throw new Error(`	Severity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util__default["default"].inspect(severity).replace(/'/gu, '"').replace(/\n/gu, "")}').
`);
      }
      /**
       * Validates the non-severity options passed to a rule, based on its schema.
       * @param {{create: Function}} rule The rule to validate
       * @param {Array} localOptions The options for the rule, excluding severity
       * @returns {void}
       */
      validateRuleSchema(rule, localOptions) {
        if (!ruleValidators.has(rule)) {
          const schema = this.getRuleOptionsSchema(rule);
          if (schema) {
            ruleValidators.set(rule, ajv.compile(schema));
          }
        }
        const validateRule = ruleValidators.get(rule);
        if (validateRule) {
          validateRule(localOptions);
          if (validateRule.errors) {
            throw new Error(validateRule.errors.map(
              (error) => `	Value ${JSON.stringify(error.data)} ${error.message}.
`
            ).join(""));
          }
        }
      }
      /**
       * Validates a rule's options against its schema.
       * @param {{create: Function}|null} rule The rule that the config is being validated for
       * @param {string} ruleId The rule's unique name.
       * @param {Array|number} options The given options for the rule.
       * @param {string|null} source The name of the configuration source to report in any errors. If null or undefined,
       * no source is prepended to the message.
       * @returns {void}
       */
      validateRuleOptions(rule, ruleId, options, source = null) {
        try {
          const severity = this.validateRuleSeverity(options);
          if (severity !== 0) {
            this.validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
          }
        } catch (err) {
          const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:
${err.message}`;
          if (typeof source === "string") {
            throw new Error(`${source}:
	${enhancedMessage}`);
          } else {
            throw new Error(enhancedMessage);
          }
        }
      }
      /**
       * Validates an environment object
       * @param {Object} environment The environment config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded environments.
       * @returns {void}
       */
      validateEnvironment(environment, source, getAdditionalEnv = noop) {
        if (!environment) {
          return;
        }
        Object.keys(environment).forEach((id) => {
          const env = getAdditionalEnv(id) || environments.get(id) || null;
          if (!env) {
            const message = `${source}:
	Environment key "${id}" is unknown
`;
            throw new Error(message);
          }
        });
      }
      /**
       * Validates a rules config object
       * @param {Object} rulesConfig The rules config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(ruleId:string): Object} getAdditionalRule A map from strings to loaded rules
       * @returns {void}
       */
      validateRules(rulesConfig, source, getAdditionalRule = noop) {
        if (!rulesConfig) {
          return;
        }
        Object.keys(rulesConfig).forEach((id) => {
          const rule = getAdditionalRule(id) || this.builtInRules.get(id) || null;
          this.validateRuleOptions(rule, id, rulesConfig[id], source);
        });
      }
      /**
       * Validates a `globals` section of a config file
       * @param {Object} globalsConfig The `globals` section
       * @param {string|null} source The name of the configuration source to report in the event of an error.
       * @returns {void}
       */
      validateGlobals(globalsConfig, source = null) {
        if (!globalsConfig) {
          return;
        }
        Object.entries(globalsConfig).forEach(([configuredGlobal, configuredValue]) => {
          try {
            normalizeConfigGlobal(configuredValue);
          } catch (err) {
            throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:
${err.message}`);
          }
        });
      }
      /**
       * Validate `processor` configuration.
       * @param {string|undefined} processorName The processor name.
       * @param {string} source The name of config file.
       * @param {function(id:string): Processor} getProcessor The getter of defined processors.
       * @returns {void}
       */
      validateProcessor(processorName, source, getProcessor) {
        if (processorName && !getProcessor(processorName)) {
          throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
        }
      }
      /**
       * Formats an array of schema validation errors.
       * @param {Array} errors An array of error messages to format.
       * @returns {string} Formatted error message
       */
      formatErrors(errors) {
        return errors.map((error) => {
          if (error.keyword === "additionalProperties") {
            const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
            return `Unexpected top-level property "${formattedPropertyPath}"`;
          }
          if (error.keyword === "type") {
            const formattedField = error.dataPath.slice(1);
            const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
            const formattedValue = JSON.stringify(error.data);
            return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
          }
          const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
          return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
        }).map((message) => `	- ${message}.
`).join("");
      }
      /**
       * Validates the top level properties of the config object.
       * @param {Object} config The config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @returns {void}
       */
      validateConfigSchema(config, source = null) {
        validateSchema = validateSchema || ajv.compile(configSchema);
        if (!validateSchema(config)) {
          throw new Error(`ESLint configuration in ${source} is invalid:
${this.formatErrors(validateSchema.errors)}`);
        }
        if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
          emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
        }
      }
      /**
       * Validates an entire config object.
       * @param {Object} config The config object to validate.
       * @param {string} source The name of the configuration source to report in any errors.
       * @param {function(ruleId:string): Object} [getAdditionalRule] A map from strings to loaded rules.
       * @param {function(envId:string): Object} [getAdditionalEnv] A map from strings to loaded envs.
       * @returns {void}
       */
      validate(config, source, getAdditionalRule, getAdditionalEnv) {
        this.validateConfigSchema(config, source);
        this.validateRules(config.rules, source, getAdditionalRule);
        this.validateEnvironment(config.env, source, getAdditionalEnv);
        this.validateGlobals(config.globals, source);
        for (const override of config.overrides || []) {
          this.validateRules(override.rules, source, getAdditionalRule);
          this.validateEnvironment(override.env, source, getAdditionalEnv);
          this.validateGlobals(config.globals, source);
        }
      }
      /**
       * Validate config array object.
       * @param {ConfigArray} configArray The config array to validate.
       * @returns {void}
       */
      validateConfigArray(configArray) {
        const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
        const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
        const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
        for (const element of configArray) {
          if (validated.has(element)) {
            continue;
          }
          validated.add(element);
          this.validateEnvironment(element.env, element.name, getPluginEnv);
          this.validateGlobals(element.globals, element.name);
          this.validateProcessor(element.processor, element.name, getPluginProcessor);
          this.validateRules(element.rules, element.name, getPluginRule);
        }
      }
    };
    var NAMESPACE_REGEX = /^@.*\//iu;
    function normalizePackageName(name, prefix) {
      let normalizedName = name;
      if (normalizedName.includes("\\")) {
        normalizedName = normalizedName.replace(/\\/gu, "/");
      }
      if (normalizedName.charAt(0) === "@") {
        const scopedPackageShortcutRegex = new RegExp(`^(@[^/]+)(?:/(?:${prefix})?)?$`, "u"), scopedPackageNameRegex = new RegExp(`^${prefix}(-|$)`, "u");
        if (scopedPackageShortcutRegex.test(normalizedName)) {
          normalizedName = normalizedName.replace(scopedPackageShortcutRegex, `$1/${prefix}`);
        } else if (!scopedPackageNameRegex.test(normalizedName.split("/")[1])) {
          normalizedName = normalizedName.replace(/^@([^/]+)\/(.*)$/u, `@$1/${prefix}-$2`);
        }
      } else if (!normalizedName.startsWith(`${prefix}-`)) {
        normalizedName = `${prefix}-${normalizedName}`;
      }
      return normalizedName;
    }
    function getShorthandName(fullname, prefix) {
      if (fullname[0] === "@") {
        let matchResult = new RegExp(`^(@[^/]+)/${prefix}$`, "u").exec(fullname);
        if (matchResult) {
          return matchResult[1];
        }
        matchResult = new RegExp(`^(@[^/]+)/${prefix}-(.+)$`, "u").exec(fullname);
        if (matchResult) {
          return `${matchResult[1]}/${matchResult[2]}`;
        }
      } else if (fullname.startsWith(`${prefix}-`)) {
        return fullname.slice(prefix.length + 1);
      }
      return fullname;
    }
    function getNamespaceFromTerm(term) {
      const match = term.match(NAMESPACE_REGEX);
      return match ? match[0] : "";
    }
    var naming = {
      __proto__: null,
      normalizePackageName,
      getShorthandName,
      getNamespaceFromTerm
    };
    var Legacy = {
      environments,
      // shared
      ConfigOps,
      ConfigValidator,
      naming
    };
    exports.Legacy = Legacy;
  }
});

// node_modules/eslint/lib/source-code/token-store/cursor.js
var require_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/cursor.js"(exports, module2) {
    "use strict";
    module2.exports = class Cursor {
      /**
       * Initializes this cursor.
       */
      constructor() {
        this.current = null;
      }
      /**
       * Gets the first token.
       * This consumes this cursor.
       * @returns {Token|Comment} The first token or null.
       */
      getOneToken() {
        return this.moveNext() ? this.current : null;
      }
      /**
       * Gets the first tokens.
       * This consumes this cursor.
       * @returns {(Token|Comment)[]} All tokens.
       */
      getAllTokens() {
        const tokens = [];
        while (this.moveNext()) {
          tokens.push(this.current);
        }
        return tokens;
      }
      /**
       * Moves this cursor to the next token.
       * @returns {boolean} `true` if the next token exists.
       * @abstract
       */
      /* c8 ignore next */
      moveNext() {
        throw new Error("Not implemented.");
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/utils.js
var require_utils3 = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/utils.js"(exports) {
    "use strict";
    function getStartLocation(token) {
      return token.range[0];
    }
    exports.search = function search(tokens, location) {
      const index = tokens.findIndex((el) => location <= getStartLocation(el));
      return index === -1 ? tokens.length : index;
    };
    exports.getFirstIndex = function getFirstIndex(tokens, indexMap, startLoc) {
      if (startLoc in indexMap) {
        return indexMap[startLoc];
      }
      if (startLoc - 1 in indexMap) {
        const index = indexMap[startLoc - 1];
        const token = index >= 0 && index < tokens.length ? tokens[index] : null;
        if (token && token.range[0] >= startLoc) {
          return index;
        }
        return index + 1;
      }
      return 0;
    };
    exports.getLastIndex = function getLastIndex(tokens, indexMap, endLoc) {
      if (endLoc in indexMap) {
        return indexMap[endLoc] - 1;
      }
      if (endLoc - 1 in indexMap) {
        const index = indexMap[endLoc - 1];
        const token = index >= 0 && index < tokens.length ? tokens[index] : null;
        if (token && token.range[1] > endLoc) {
          return index - 1;
        }
        return index;
      }
      return tokens.length - 1;
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/backward-token-comment-cursor.js
var require_backward_token_comment_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/backward-token-comment-cursor.js"(exports, module2) {
    "use strict";
    var Cursor = require_cursor();
    var utils2 = require_utils3();
    module2.exports = class BackwardTokenCommentCursor extends Cursor {
      /**
       * Initializes this cursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       */
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.comments = comments;
        this.tokenIndex = utils2.getLastIndex(tokens, indexMap, endLoc);
        this.commentIndex = utils2.search(comments, endLoc) - 1;
        this.border = startLoc;
      }
      /** @inheritdoc */
      moveNext() {
        const token = this.tokenIndex >= 0 ? this.tokens[this.tokenIndex] : null;
        const comment = this.commentIndex >= 0 ? this.comments[this.commentIndex] : null;
        if (token && (!comment || token.range[1] > comment.range[1])) {
          this.current = token;
          this.tokenIndex -= 1;
        } else if (comment) {
          this.current = comment;
          this.commentIndex -= 1;
        } else {
          this.current = null;
        }
        return Boolean(this.current) && (this.border === -1 || this.current.range[0] >= this.border);
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/backward-token-cursor.js
var require_backward_token_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/backward-token-cursor.js"(exports, module2) {
    "use strict";
    var Cursor = require_cursor();
    var utils2 = require_utils3();
    module2.exports = class BackwardTokenCursor extends Cursor {
      /**
       * Initializes this cursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       */
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.index = utils2.getLastIndex(tokens, indexMap, endLoc);
        this.indexEnd = utils2.getFirstIndex(tokens, indexMap, startLoc);
      }
      /** @inheritdoc */
      moveNext() {
        if (this.index >= this.indexEnd) {
          this.current = this.tokens[this.index];
          this.index -= 1;
          return true;
        }
        return false;
      }
      /*
       *
       * Shorthand for performance.
       *
       */
      /** @inheritdoc */
      getOneToken() {
        return this.index >= this.indexEnd ? this.tokens[this.index] : null;
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/decorative-cursor.js
var require_decorative_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/decorative-cursor.js"(exports, module2) {
    "use strict";
    var Cursor = require_cursor();
    module2.exports = class DecorativeCursor extends Cursor {
      /**
       * Initializes this cursor.
       * @param {Cursor} cursor The cursor to be decorated.
       */
      constructor(cursor) {
        super();
        this.cursor = cursor;
      }
      /** @inheritdoc */
      moveNext() {
        const retv = this.cursor.moveNext();
        this.current = this.cursor.current;
        return retv;
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/filter-cursor.js
var require_filter_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/filter-cursor.js"(exports, module2) {
    "use strict";
    var DecorativeCursor = require_decorative_cursor();
    module2.exports = class FilterCursor extends DecorativeCursor {
      /**
       * Initializes this cursor.
       * @param {Cursor} cursor The cursor to be decorated.
       * @param {Function} predicate The predicate function to decide tokens this cursor iterates.
       */
      constructor(cursor, predicate) {
        super(cursor);
        this.predicate = predicate;
      }
      /** @inheritdoc */
      moveNext() {
        const predicate = this.predicate;
        while (super.moveNext()) {
          if (predicate(this.current)) {
            return true;
          }
        }
        return false;
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/forward-token-comment-cursor.js
var require_forward_token_comment_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/forward-token-comment-cursor.js"(exports, module2) {
    "use strict";
    var Cursor = require_cursor();
    var utils2 = require_utils3();
    module2.exports = class ForwardTokenCommentCursor extends Cursor {
      /**
       * Initializes this cursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       */
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.comments = comments;
        this.tokenIndex = utils2.getFirstIndex(tokens, indexMap, startLoc);
        this.commentIndex = utils2.search(comments, startLoc);
        this.border = endLoc;
      }
      /** @inheritdoc */
      moveNext() {
        const token = this.tokenIndex < this.tokens.length ? this.tokens[this.tokenIndex] : null;
        const comment = this.commentIndex < this.comments.length ? this.comments[this.commentIndex] : null;
        if (token && (!comment || token.range[0] < comment.range[0])) {
          this.current = token;
          this.tokenIndex += 1;
        } else if (comment) {
          this.current = comment;
          this.commentIndex += 1;
        } else {
          this.current = null;
        }
        return Boolean(this.current) && (this.border === -1 || this.current.range[1] <= this.border);
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/forward-token-cursor.js
var require_forward_token_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/forward-token-cursor.js"(exports, module2) {
    "use strict";
    var Cursor = require_cursor();
    var utils2 = require_utils3();
    module2.exports = class ForwardTokenCursor extends Cursor {
      /**
       * Initializes this cursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       */
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.index = utils2.getFirstIndex(tokens, indexMap, startLoc);
        this.indexEnd = utils2.getLastIndex(tokens, indexMap, endLoc);
      }
      /** @inheritdoc */
      moveNext() {
        if (this.index <= this.indexEnd) {
          this.current = this.tokens[this.index];
          this.index += 1;
          return true;
        }
        return false;
      }
      /*
       *
       * Shorthand for performance.
       *
       */
      /** @inheritdoc */
      getOneToken() {
        return this.index <= this.indexEnd ? this.tokens[this.index] : null;
      }
      /** @inheritdoc */
      getAllTokens() {
        return this.tokens.slice(this.index, this.indexEnd + 1);
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/limit-cursor.js
var require_limit_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/limit-cursor.js"(exports, module2) {
    "use strict";
    var DecorativeCursor = require_decorative_cursor();
    module2.exports = class LimitCursor extends DecorativeCursor {
      /**
       * Initializes this cursor.
       * @param {Cursor} cursor The cursor to be decorated.
       * @param {number} count The count of tokens this cursor iterates.
       */
      constructor(cursor, count) {
        super(cursor);
        this.count = count;
      }
      /** @inheritdoc */
      moveNext() {
        if (this.count > 0) {
          this.count -= 1;
          return super.moveNext();
        }
        return false;
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/skip-cursor.js
var require_skip_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/skip-cursor.js"(exports, module2) {
    "use strict";
    var DecorativeCursor = require_decorative_cursor();
    module2.exports = class SkipCursor extends DecorativeCursor {
      /**
       * Initializes this cursor.
       * @param {Cursor} cursor The cursor to be decorated.
       * @param {number} count The count of tokens this cursor skips.
       */
      constructor(cursor, count) {
        super(cursor);
        this.count = count;
      }
      /** @inheritdoc */
      moveNext() {
        while (this.count > 0) {
          this.count -= 1;
          if (!super.moveNext()) {
            return false;
          }
        }
        return super.moveNext();
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/cursors.js
var require_cursors = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/cursors.js"(exports) {
    "use strict";
    var BackwardTokenCommentCursor = require_backward_token_comment_cursor();
    var BackwardTokenCursor = require_backward_token_cursor();
    var FilterCursor = require_filter_cursor();
    var ForwardTokenCommentCursor = require_forward_token_comment_cursor();
    var ForwardTokenCursor = require_forward_token_cursor();
    var LimitCursor = require_limit_cursor();
    var SkipCursor = require_skip_cursor();
    var CursorFactory = class {
      /**
       * Initializes this cursor.
       * @param {Function} TokenCursor The class of the cursor which iterates tokens only.
       * @param {Function} TokenCommentCursor The class of the cursor which iterates the mix of tokens and comments.
       */
      constructor(TokenCursor, TokenCommentCursor) {
        this.TokenCursor = TokenCursor;
        this.TokenCommentCursor = TokenCommentCursor;
      }
      /**
       * Creates a base cursor instance that can be decorated by createCursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       * @param {boolean} includeComments The flag to iterate comments as well.
       * @returns {Cursor} The created base cursor.
       */
      createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments) {
        const Cursor = includeComments ? this.TokenCommentCursor : this.TokenCursor;
        return new Cursor(tokens, comments, indexMap, startLoc, endLoc);
      }
      /**
       * Creates a cursor that iterates tokens with normalized options.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       * @param {boolean} includeComments The flag to iterate comments as well.
       * @param {Function|null} filter The predicate function to choose tokens.
       * @param {number} skip The count of tokens the cursor skips.
       * @param {number} count The maximum count of tokens the cursor iterates. Zero is no iteration for backward compatibility.
       * @returns {Cursor} The created cursor.
       */
      createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, count) {
        let cursor = this.createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments);
        if (filter) {
          cursor = new FilterCursor(cursor, filter);
        }
        if (skip >= 1) {
          cursor = new SkipCursor(cursor, skip);
        }
        if (count >= 0) {
          cursor = new LimitCursor(cursor, count);
        }
        return cursor;
      }
    };
    exports.forward = new CursorFactory(ForwardTokenCursor, ForwardTokenCommentCursor);
    exports.backward = new CursorFactory(BackwardTokenCursor, BackwardTokenCommentCursor);
  }
});

// node_modules/eslint/lib/source-code/token-store/padded-token-cursor.js
var require_padded_token_cursor = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/padded-token-cursor.js"(exports, module2) {
    "use strict";
    var ForwardTokenCursor = require_forward_token_cursor();
    module2.exports = class PaddedTokenCursor extends ForwardTokenCursor {
      /**
       * Initializes this cursor.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       * @param {Object} indexMap The map from locations to indices in `tokens`.
       * @param {number} startLoc The start location of the iteration range.
       * @param {number} endLoc The end location of the iteration range.
       * @param {number} beforeCount The number of tokens this cursor iterates before start.
       * @param {number} afterCount The number of tokens this cursor iterates after end.
       */
      constructor(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
        super(tokens, comments, indexMap, startLoc, endLoc);
        this.index = Math.max(0, this.index - beforeCount);
        this.indexEnd = Math.min(tokens.length - 1, this.indexEnd + afterCount);
      }
    };
  }
});

// node_modules/eslint/lib/source-code/token-store/index.js
var require_token_store = __commonJS({
  "node_modules/eslint/lib/source-code/token-store/index.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var { isCommentToken } = require_eslint_utils();
    var cursors = require_cursors();
    var ForwardTokenCursor = require_forward_token_cursor();
    var PaddedTokenCursor = require_padded_token_cursor();
    var utils2 = require_utils3();
    var TOKENS = Symbol("tokens");
    var COMMENTS = Symbol("comments");
    var INDEX_MAP = Symbol("indexMap");
    function createIndexMap(tokens, comments) {
      const map = /* @__PURE__ */ Object.create(null);
      let tokenIndex = 0;
      let commentIndex = 0;
      let nextStart = 0;
      let range = null;
      while (tokenIndex < tokens.length || commentIndex < comments.length) {
        nextStart = commentIndex < comments.length ? comments[commentIndex].range[0] : Number.MAX_SAFE_INTEGER;
        while (tokenIndex < tokens.length && (range = tokens[tokenIndex].range)[0] < nextStart) {
          map[range[0]] = tokenIndex;
          map[range[1] - 1] = tokenIndex;
          tokenIndex += 1;
        }
        nextStart = tokenIndex < tokens.length ? tokens[tokenIndex].range[0] : Number.MAX_SAFE_INTEGER;
        while (commentIndex < comments.length && (range = comments[commentIndex].range)[0] < nextStart) {
          map[range[0]] = tokenIndex;
          map[range[1] - 1] = tokenIndex;
          commentIndex += 1;
        }
      }
      return map;
    }
    function createCursorWithSkip(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
      let includeComments = false;
      let skip = 0;
      let filter = null;
      if (typeof opts === "number") {
        skip = opts | 0;
      } else if (typeof opts === "function") {
        filter = opts;
      } else if (opts) {
        includeComments = !!opts.includeComments;
        skip = opts.skip | 0;
        filter = opts.filter || null;
      }
      assert(skip >= 0, "options.skip should be zero or a positive integer.");
      assert(!filter || typeof filter === "function", "options.filter should be a function.");
      return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, -1);
    }
    function createCursorWithCount(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
      let includeComments = false;
      let count = 0;
      let countExists = false;
      let filter = null;
      if (typeof opts === "number") {
        count = opts | 0;
        countExists = true;
      } else if (typeof opts === "function") {
        filter = opts;
      } else if (opts) {
        includeComments = !!opts.includeComments;
        count = opts.count | 0;
        countExists = typeof opts.count === "number";
        filter = opts.filter || null;
      }
      assert(count >= 0, "options.count should be zero or a positive integer.");
      assert(!filter || typeof filter === "function", "options.filter should be a function.");
      return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, 0, countExists ? count : -1);
    }
    function createCursorWithPadding(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
      if (typeof beforeCount === "undefined" && typeof afterCount === "undefined") {
        return new ForwardTokenCursor(tokens, comments, indexMap, startLoc, endLoc);
      }
      if (typeof beforeCount === "number" || typeof beforeCount === "undefined") {
        return new PaddedTokenCursor(tokens, comments, indexMap, startLoc, endLoc, beforeCount | 0, afterCount | 0);
      }
      return createCursorWithCount(cursors.forward, tokens, comments, indexMap, startLoc, endLoc, beforeCount);
    }
    function getAdjacentCommentTokensFromCursor(cursor) {
      const tokens = [];
      let currentToken = cursor.getOneToken();
      while (currentToken && isCommentToken(currentToken)) {
        tokens.push(currentToken);
        currentToken = cursor.getOneToken();
      }
      return tokens;
    }
    module2.exports = class TokenStore {
      /**
       * Initializes this token store.
       * @param {Token[]} tokens The array of tokens.
       * @param {Comment[]} comments The array of comments.
       */
      constructor(tokens, comments) {
        this[TOKENS] = tokens;
        this[COMMENTS] = comments;
        this[INDEX_MAP] = createIndexMap(tokens, comments);
      }
      //--------------------------------------------------------------------------
      // Gets single token.
      //--------------------------------------------------------------------------
      /**
       * Gets the token starting at the specified index.
       * @param {number} offset Index of the start of the token's range.
       * @param {Object} [options=0] The option object.
       * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
       * @returns {Token|null} The token starting at index, or null if no such token.
       */
      getTokenByRangeStart(offset, options) {
        const includeComments = options && options.includeComments;
        const token = cursors.forward.createBaseCursor(
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          offset,
          -1,
          includeComments
        ).getOneToken();
        if (token && token.range[0] === offset) {
          return token;
        }
        return null;
      }
      /**
       * Gets the first token of the given node.
       * @param {ASTNode} node The AST node.
       * @param {number|Function|Object} [options=0] The option object. If this is a number then it's `options.skip`. If this is a function then it's `options.filter`.
       * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
       * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
       * @param {number} [options.skip=0] The count of tokens the cursor skips.
       * @returns {Token|null} An object representing the token.
       */
      getFirstToken(node, options) {
        return createCursorWithSkip(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[0],
          node.range[1],
          options
        ).getOneToken();
      }
      /**
       * Gets the last token of the given node.
       * @param {ASTNode} node The AST node.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
       * @returns {Token|null} An object representing the token.
       */
      getLastToken(node, options) {
        return createCursorWithSkip(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[0],
          node.range[1],
          options
        ).getOneToken();
      }
      /**
       * Gets the token that precedes a given node or token.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
       * @returns {Token|null} An object representing the token.
       */
      getTokenBefore(node, options) {
        return createCursorWithSkip(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          -1,
          node.range[0],
          options
        ).getOneToken();
      }
      /**
       * Gets the token that follows a given node or token.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
       * @returns {Token|null} An object representing the token.
       */
      getTokenAfter(node, options) {
        return createCursorWithSkip(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[1],
          -1,
          options
        ).getOneToken();
      }
      /**
       * Gets the first token between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
       * @returns {Token|null} An object representing the token.
       */
      getFirstTokenBetween(left, right, options) {
        return createCursorWithSkip(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          left.range[1],
          right.range[0],
          options
        ).getOneToken();
      }
      /**
       * Gets the last token between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstToken()
       * @returns {Token|null} An object representing the token.
       */
      getLastTokenBetween(left, right, options) {
        return createCursorWithSkip(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          left.range[1],
          right.range[0],
          options
        ).getOneToken();
      }
      /**
       * Gets the token that precedes a given node or token in the token stream.
       * This is defined for backward compatibility. Use `includeComments` option instead.
       * TODO: We have a plan to remove this in a future major version.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number} [skip=0] A number of tokens to skip.
       * @returns {Token|null} An object representing the token.
       * @deprecated
       */
      getTokenOrCommentBefore(node, skip) {
        return this.getTokenBefore(node, { includeComments: true, skip });
      }
      /**
       * Gets the token that follows a given node or token in the token stream.
       * This is defined for backward compatibility. Use `includeComments` option instead.
       * TODO: We have a plan to remove this in a future major version.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number} [skip=0] A number of tokens to skip.
       * @returns {Token|null} An object representing the token.
       * @deprecated
       */
      getTokenOrCommentAfter(node, skip) {
        return this.getTokenAfter(node, { includeComments: true, skip });
      }
      //--------------------------------------------------------------------------
      // Gets multiple tokens.
      //--------------------------------------------------------------------------
      /**
       * Gets the first `count` tokens of the given node.
       * @param {ASTNode} node The AST node.
       * @param {number|Function|Object} [options=0] The option object. If this is a number then it's `options.count`. If this is a function then it's `options.filter`.
       * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
       * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
       * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
       * @returns {Token[]} Tokens.
       */
      getFirstTokens(node, options) {
        return createCursorWithCount(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[0],
          node.range[1],
          options
        ).getAllTokens();
      }
      /**
       * Gets the last `count` tokens of the given node.
       * @param {ASTNode} node The AST node.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
       * @returns {Token[]} Tokens.
       */
      getLastTokens(node, options) {
        return createCursorWithCount(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[0],
          node.range[1],
          options
        ).getAllTokens().reverse();
      }
      /**
       * Gets the `count` tokens that precedes a given node or token.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
       * @returns {Token[]} Tokens.
       */
      getTokensBefore(node, options) {
        return createCursorWithCount(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          -1,
          node.range[0],
          options
        ).getAllTokens().reverse();
      }
      /**
       * Gets the `count` tokens that follows a given node or token.
       * @param {ASTNode|Token|Comment} node The AST node or token.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
       * @returns {Token[]} Tokens.
       */
      getTokensAfter(node, options) {
        return createCursorWithCount(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[1],
          -1,
          options
        ).getAllTokens();
      }
      /**
       * Gets the first `count` tokens between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
       * @returns {Token[]} Tokens between left and right.
       */
      getFirstTokensBetween(left, right, options) {
        return createCursorWithCount(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          left.range[1],
          right.range[0],
          options
        ).getAllTokens();
      }
      /**
       * Gets the last `count` tokens between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {number|Function|Object} [options=0] The option object. Same options as getFirstTokens()
       * @returns {Token[]} Tokens between left and right.
       */
      getLastTokensBetween(left, right, options) {
        return createCursorWithCount(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          left.range[1],
          right.range[0],
          options
        ).getAllTokens().reverse();
      }
      /**
       * Gets all tokens that are related to the given node.
       * @param {ASTNode} node The AST node.
       * @param {Function|Object} options The option object. If this is a function then it's `options.filter`.
       * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
       * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
       * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
       * @returns {Token[]} Array of objects representing tokens.
       */
      /**
       * Gets all tokens that are related to the given node.
       * @param {ASTNode} node The AST node.
       * @param {int} [beforeCount=0] The number of tokens before the node to retrieve.
       * @param {int} [afterCount=0] The number of tokens after the node to retrieve.
       * @returns {Token[]} Array of objects representing tokens.
       */
      getTokens(node, beforeCount, afterCount) {
        return createCursorWithPadding(
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          node.range[0],
          node.range[1],
          beforeCount,
          afterCount
        ).getAllTokens();
      }
      /**
       * Gets all of the tokens between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {Function|Object} options The option object. If this is a function then it's `options.filter`.
       * @param {boolean} [options.includeComments=false] The flag to iterate comments as well.
       * @param {Function|null} [options.filter=null] The predicate function to choose tokens.
       * @param {number} [options.count=0] The maximum count of tokens the cursor iterates.
       * @returns {Token[]} Tokens between left and right.
       */
      /**
       * Gets all of the tokens between two non-overlapping nodes.
       * @param {ASTNode|Token|Comment} left Node before the desired token range.
       * @param {ASTNode|Token|Comment} right Node after the desired token range.
       * @param {int} [padding=0] Number of extra tokens on either side of center.
       * @returns {Token[]} Tokens between left and right.
       */
      getTokensBetween(left, right, padding) {
        return createCursorWithPadding(
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          left.range[1],
          right.range[0],
          padding,
          padding
        ).getAllTokens();
      }
      //--------------------------------------------------------------------------
      // Others.
      //--------------------------------------------------------------------------
      /**
       * Checks whether any comments exist or not between the given 2 nodes.
       * @param {ASTNode} left The node to check.
       * @param {ASTNode} right The node to check.
       * @returns {boolean} `true` if one or more comments exist.
       */
      commentsExistBetween(left, right) {
        const index = utils2.search(this[COMMENTS], left.range[1]);
        return index < this[COMMENTS].length && this[COMMENTS][index].range[1] <= right.range[0];
      }
      /**
       * Gets all comment tokens directly before the given node or token.
       * @param {ASTNode|token} nodeOrToken The AST node or token to check for adjacent comment tokens.
       * @returns {Array} An array of comments in occurrence order.
       */
      getCommentsBefore(nodeOrToken) {
        const cursor = createCursorWithCount(
          cursors.backward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          -1,
          nodeOrToken.range[0],
          { includeComments: true }
        );
        return getAdjacentCommentTokensFromCursor(cursor).reverse();
      }
      /**
       * Gets all comment tokens directly after the given node or token.
       * @param {ASTNode|token} nodeOrToken The AST node or token to check for adjacent comment tokens.
       * @returns {Array} An array of comments in occurrence order.
       */
      getCommentsAfter(nodeOrToken) {
        const cursor = createCursorWithCount(
          cursors.forward,
          this[TOKENS],
          this[COMMENTS],
          this[INDEX_MAP],
          nodeOrToken.range[1],
          -1,
          { includeComments: true }
        );
        return getAdjacentCommentTokensFromCursor(cursor);
      }
      /**
       * Gets all comment tokens inside the given node.
       * @param {ASTNode} node The AST node to get the comments for.
       * @returns {Array} An array of comments in occurrence order.
       */
      getCommentsInside(node) {
        return this.getTokens(node, {
          includeComments: true,
          filter: isCommentToken
        });
      }
    };
  }
});

// node_modules/eslint/lib/source-code/source-code.js
var require_source_code = __commonJS({
  "node_modules/eslint/lib/source-code/source-code.js"(exports, module2) {
    "use strict";
    var { isCommentToken } = require_eslint_utils();
    var TokenStore = require_token_store();
    var astUtils = require_ast_utils();
    var Traverser = require_traverser();
    function validate(ast) {
      if (!ast.tokens) {
        throw new Error("AST is missing the tokens array.");
      }
      if (!ast.comments) {
        throw new Error("AST is missing the comments array.");
      }
      if (!ast.loc) {
        throw new Error("AST is missing location information.");
      }
      if (!ast.range) {
        throw new Error("AST is missing range information");
      }
    }
    function looksLikeExport(astNode) {
      return astNode.type === "ExportDefaultDeclaration" || astNode.type === "ExportNamedDeclaration" || astNode.type === "ExportAllDeclaration" || astNode.type === "ExportSpecifier";
    }
    function sortedMerge(tokens, comments) {
      const result = [];
      let tokenIndex = 0;
      let commentIndex = 0;
      while (tokenIndex < tokens.length || commentIndex < comments.length) {
        if (commentIndex >= comments.length || tokenIndex < tokens.length && tokens[tokenIndex].range[0] < comments[commentIndex].range[0]) {
          result.push(tokens[tokenIndex++]);
        } else {
          result.push(comments[commentIndex++]);
        }
      }
      return result;
    }
    function nodesOrTokensOverlap(first2, second) {
      return first2.range[0] <= second.range[0] && first2.range[1] >= second.range[0] || second.range[0] <= first2.range[0] && second.range[1] >= first2.range[0];
    }
    function isSpaceBetween(sourceCode, first2, second, checkInsideOfJSXText) {
      if (nodesOrTokensOverlap(first2, second)) {
        return false;
      }
      const [startingNodeOrToken, endingNodeOrToken] = first2.range[1] <= second.range[0] ? [first2, second] : [second, first2];
      const firstToken = sourceCode.getLastToken(startingNodeOrToken) || startingNodeOrToken;
      const finalToken = sourceCode.getFirstToken(endingNodeOrToken) || endingNodeOrToken;
      let currentToken = firstToken;
      while (currentToken !== finalToken) {
        const nextToken = sourceCode.getTokenAfter(currentToken, { includeComments: true });
        if (currentToken.range[1] !== nextToken.range[0] || /*
         * For backward compatibility, check spaces in JSXText.
         * https://github.com/eslint/eslint/issues/12614
         */
        checkInsideOfJSXText && nextToken !== finalToken && nextToken.type === "JSXText" && /\s/u.test(nextToken.value)) {
          return true;
        }
        currentToken = nextToken;
      }
      return false;
    }
    var SourceCode = class extends TokenStore {
      /**
       * @param {string|Object} textOrConfig The source code text or config object.
       * @param {string} textOrConfig.text The source code text.
       * @param {ASTNode} textOrConfig.ast The Program node of the AST representing the code. This AST should be created from the text that BOM was stripped.
       * @param {Object|null} textOrConfig.parserServices The parser services.
       * @param {ScopeManager|null} textOrConfig.scopeManager The scope of this source code.
       * @param {Object|null} textOrConfig.visitorKeys The visitor keys to traverse AST.
       * @param {ASTNode} [astIfNoConfig] The Program node of the AST representing the code. This AST should be created from the text that BOM was stripped.
       */
      constructor(textOrConfig, astIfNoConfig) {
        let text, ast, parserServices, scopeManager, visitorKeys;
        if (typeof textOrConfig === "string") {
          text = textOrConfig;
          ast = astIfNoConfig;
        } else if (typeof textOrConfig === "object" && textOrConfig !== null) {
          text = textOrConfig.text;
          ast = textOrConfig.ast;
          parserServices = textOrConfig.parserServices;
          scopeManager = textOrConfig.scopeManager;
          visitorKeys = textOrConfig.visitorKeys;
        }
        validate(ast);
        super(ast.tokens, ast.comments);
        this.hasBOM = text.charCodeAt(0) === 65279;
        this.text = this.hasBOM ? text.slice(1) : text;
        this.ast = ast;
        this.parserServices = parserServices || {};
        this.scopeManager = scopeManager || null;
        this.visitorKeys = visitorKeys || Traverser.DEFAULT_VISITOR_KEYS;
        const shebangMatched = this.text.match(astUtils.shebangPattern);
        const hasShebang = shebangMatched && ast.comments.length && ast.comments[0].value === shebangMatched[1];
        if (hasShebang) {
          ast.comments[0].type = "Shebang";
        }
        this.tokensAndComments = sortedMerge(ast.tokens, ast.comments);
        this.lines = [];
        this.lineStartIndices = [0];
        const lineEndingPattern = astUtils.createGlobalLinebreakMatcher();
        let match;
        while (match = lineEndingPattern.exec(this.text)) {
          this.lines.push(this.text.slice(this.lineStartIndices[this.lineStartIndices.length - 1], match.index));
          this.lineStartIndices.push(match.index + match[0].length);
        }
        this.lines.push(this.text.slice(this.lineStartIndices[this.lineStartIndices.length - 1]));
        this._commentCache = /* @__PURE__ */ new WeakMap();
        Object.freeze(this);
        Object.freeze(this.lines);
      }
      /**
       * Split the source code into multiple lines based on the line delimiters.
       * @param {string} text Source code as a string.
       * @returns {string[]} Array of source code lines.
       * @public
       */
      static splitLines(text) {
        return text.split(astUtils.createGlobalLinebreakMatcher());
      }
      /**
       * Gets the source code for the given node.
       * @param {ASTNode} [node] The AST node to get the text for.
       * @param {int} [beforeCount] The number of characters before the node to retrieve.
       * @param {int} [afterCount] The number of characters after the node to retrieve.
       * @returns {string} The text representing the AST node.
       * @public
       */
      getText(node, beforeCount, afterCount) {
        if (node) {
          return this.text.slice(
            Math.max(node.range[0] - (beforeCount || 0), 0),
            node.range[1] + (afterCount || 0)
          );
        }
        return this.text;
      }
      /**
       * Gets the entire source text split into an array of lines.
       * @returns {Array} The source text as an array of lines.
       * @public
       */
      getLines() {
        return this.lines;
      }
      /**
       * Retrieves an array containing all comments in the source code.
       * @returns {ASTNode[]} An array of comment nodes.
       * @public
       */
      getAllComments() {
        return this.ast.comments;
      }
      /**
       * Gets all comments for the given node.
       * @param {ASTNode} node The AST node to get the comments for.
       * @returns {Object} An object containing a leading and trailing array
       *      of comments indexed by their position.
       * @public
       * @deprecated replaced by getCommentsBefore(), getCommentsAfter(), and getCommentsInside().
       */
      getComments(node) {
        if (this._commentCache.has(node)) {
          return this._commentCache.get(node);
        }
        const comments = {
          leading: [],
          trailing: []
        };
        if (node.type === "Program") {
          if (node.body.length === 0) {
            comments.leading = node.comments;
          }
        } else {
          if ((node.type === "BlockStatement" || node.type === "ClassBody") && node.body.length === 0 || node.type === "ObjectExpression" && node.properties.length === 0 || node.type === "ArrayExpression" && node.elements.length === 0 || node.type === "SwitchStatement" && node.cases.length === 0) {
            comments.trailing = this.getTokens(node, {
              includeComments: true,
              filter: isCommentToken
            });
          }
          let currentToken = this.getTokenBefore(node, { includeComments: true });
          while (currentToken && isCommentToken(currentToken)) {
            if (node.parent && node.parent.type !== "Program" && currentToken.start < node.parent.start) {
              break;
            }
            comments.leading.push(currentToken);
            currentToken = this.getTokenBefore(currentToken, { includeComments: true });
          }
          comments.leading.reverse();
          currentToken = this.getTokenAfter(node, { includeComments: true });
          while (currentToken && isCommentToken(currentToken)) {
            if (node.parent && node.parent.type !== "Program" && currentToken.end > node.parent.end) {
              break;
            }
            comments.trailing.push(currentToken);
            currentToken = this.getTokenAfter(currentToken, { includeComments: true });
          }
        }
        this._commentCache.set(node, comments);
        return comments;
      }
      /**
       * Retrieves the JSDoc comment for a given node.
       * @param {ASTNode} node The AST node to get the comment for.
       * @returns {Token|null} The Block comment token containing the JSDoc comment
       *      for the given node or null if not found.
       * @public
       * @deprecated
       */
      getJSDocComment(node) {
        const findJSDocComment = (astNode) => {
          const tokenBefore = this.getTokenBefore(astNode, { includeComments: true });
          if (tokenBefore && isCommentToken(tokenBefore) && tokenBefore.type === "Block" && tokenBefore.value.charAt(0) === "*" && astNode.loc.start.line - tokenBefore.loc.end.line <= 1) {
            return tokenBefore;
          }
          return null;
        };
        let parent = node.parent;
        switch (node.type) {
          case "ClassDeclaration":
          case "FunctionDeclaration":
            return findJSDocComment(looksLikeExport(parent) ? parent : node);
          case "ClassExpression":
            return findJSDocComment(parent.parent);
          case "ArrowFunctionExpression":
          case "FunctionExpression":
            if (parent.type !== "CallExpression" && parent.type !== "NewExpression") {
              while (!this.getCommentsBefore(parent).length && !/Function/u.test(parent.type) && parent.type !== "MethodDefinition" && parent.type !== "Property") {
                parent = parent.parent;
                if (!parent) {
                  break;
                }
              }
              if (parent && parent.type !== "FunctionDeclaration" && parent.type !== "Program") {
                return findJSDocComment(parent);
              }
            }
            return findJSDocComment(node);
          default:
            return null;
        }
      }
      /**
       * Gets the deepest node containing a range index.
       * @param {int} index Range index of the desired node.
       * @returns {ASTNode} The node if found or null if not found.
       * @public
       */
      getNodeByRangeIndex(index) {
        let result = null;
        Traverser.traverse(this.ast, {
          visitorKeys: this.visitorKeys,
          enter(node) {
            if (node.range[0] <= index && index < node.range[1]) {
              result = node;
            } else {
              this.skip();
            }
          },
          leave(node) {
            if (node === result) {
              this.break();
            }
          }
        });
        return result;
      }
      /**
       * Determines if two nodes or tokens have at least one whitespace character
       * between them. Order does not matter. Returns false if the given nodes or
       * tokens overlap.
       * @param {ASTNode|Token} first The first node or token to check between.
       * @param {ASTNode|Token} second The second node or token to check between.
       * @returns {boolean} True if there is a whitespace character between
       * any of the tokens found between the two given nodes or tokens.
       * @public
       */
      isSpaceBetween(first2, second) {
        return isSpaceBetween(this, first2, second, false);
      }
      /**
       * Determines if two nodes or tokens have at least one whitespace character
       * between them. Order does not matter. Returns false if the given nodes or
       * tokens overlap.
       * For backward compatibility, this method returns true if there are
       * `JSXText` tokens that contain whitespaces between the two.
       * @param {ASTNode|Token} first The first node or token to check between.
       * @param {ASTNode|Token} second The second node or token to check between.
       * @returns {boolean} True if there is a whitespace character between
       * any of the tokens found between the two given nodes or tokens.
       * @deprecated in favor of isSpaceBetween().
       * @public
       */
      isSpaceBetweenTokens(first2, second) {
        return isSpaceBetween(this, first2, second, true);
      }
      /**
       * Converts a source text index into a (line, column) pair.
       * @param {number} index The index of a character in a file
       * @throws {TypeError} If non-numeric index or index out of range.
       * @returns {Object} A {line, column} location object with a 0-indexed column
       * @public
       */
      getLocFromIndex(index) {
        if (typeof index !== "number") {
          throw new TypeError("Expected `index` to be a number.");
        }
        if (index < 0 || index > this.text.length) {
          throw new RangeError(`Index out of range (requested index ${index}, but source text has length ${this.text.length}).`);
        }
        if (index === this.text.length) {
          return { line: this.lines.length, column: this.lines[this.lines.length - 1].length };
        }
        const lineNumber = index >= this.lineStartIndices[this.lineStartIndices.length - 1] ? this.lineStartIndices.length : this.lineStartIndices.findIndex((el) => index < el);
        return { line: lineNumber, column: index - this.lineStartIndices[lineNumber - 1] };
      }
      /**
       * Converts a (line, column) pair into a range index.
       * @param {Object} loc A line/column location
       * @param {number} loc.line The line number of the location (1-indexed)
       * @param {number} loc.column The column number of the location (0-indexed)
       * @throws {TypeError|RangeError} If `loc` is not an object with a numeric
       *   `line` and `column`, if the `line` is less than or equal to zero or
       *   the line or column is out of the expected range.
       * @returns {number} The range index of the location in the file.
       * @public
       */
      getIndexFromLoc(loc) {
        if (typeof loc !== "object" || typeof loc.line !== "number" || typeof loc.column !== "number") {
          throw new TypeError("Expected `loc` to be an object with numeric `line` and `column` properties.");
        }
        if (loc.line <= 0) {
          throw new RangeError(`Line number out of range (line ${loc.line} requested). Line numbers should be 1-based.`);
        }
        if (loc.line > this.lineStartIndices.length) {
          throw new RangeError(`Line number out of range (line ${loc.line} requested, but only ${this.lineStartIndices.length} lines present).`);
        }
        const lineStartIndex = this.lineStartIndices[loc.line - 1];
        const lineEndIndex = loc.line === this.lineStartIndices.length ? this.text.length : this.lineStartIndices[loc.line];
        const positionIndex = lineStartIndex + loc.column;
        if (loc.line === this.lineStartIndices.length && positionIndex > lineEndIndex || loc.line < this.lineStartIndices.length && positionIndex >= lineEndIndex) {
          throw new RangeError(`Column number out of range (column ${loc.column} requested, but the length of line ${loc.line} is ${lineEndIndex - lineStartIndex}).`);
        }
        return positionIndex;
      }
    };
    module2.exports = SourceCode;
  }
});

// node_modules/eslint/lib/source-code/index.js
var require_source_code2 = __commonJS({
  "node_modules/eslint/lib/source-code/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      SourceCode: require_source_code()
    };
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/debug-helpers.js
var require_debug_helpers = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/debug-helpers.js"(exports, module2) {
    "use strict";
    var debug = require_src()("eslint:code-path");
    function getId(segment) {
      return segment.id + (segment.reachable ? "" : "!");
    }
    function nodeToString(node, label) {
      const suffix = label ? `:${label}` : "";
      switch (node.type) {
        case "Identifier":
          return `${node.type}${suffix} (${node.name})`;
        case "Literal":
          return `${node.type}${suffix} (${node.value})`;
        default:
          return `${node.type}${suffix}`;
      }
    }
    module2.exports = {
      /**
       * A flag that debug dumping is enabled or not.
       * @type {boolean}
       */
      enabled: debug.enabled,
      /**
       * Dumps given objects.
       * @param {...any} args objects to dump.
       * @returns {void}
       */
      dump: debug,
      /**
       * Dumps the current analyzing state.
       * @param {ASTNode} node A node to dump.
       * @param {CodePathState} state A state to dump.
       * @param {boolean} leaving A flag whether or not it's leaving
       * @returns {void}
       */
      dumpState: !debug.enabled ? debug : (
        /* c8 ignore next */
        function(node, state, leaving) {
          for (let i = 0; i < state.currentSegments.length; ++i) {
            const segInternal = state.currentSegments[i].internal;
            if (leaving) {
              const last2 = segInternal.nodes.length - 1;
              if (last2 >= 0 && segInternal.nodes[last2] === nodeToString(node, "enter")) {
                segInternal.nodes[last2] = nodeToString(node, void 0);
              } else {
                segInternal.nodes.push(nodeToString(node, "exit"));
              }
            } else {
              segInternal.nodes.push(nodeToString(node, "enter"));
            }
          }
          debug([
            `${state.currentSegments.map(getId).join(",")})`,
            `${node.type}${leaving ? ":exit" : ""}`
          ].join(" "));
        }
      ),
      /**
       * Dumps a DOT code of a given code path.
       * The DOT code can be visualized with Graphvis.
       * @param {CodePath} codePath A code path to dump.
       * @returns {void}
       * @see http://www.graphviz.org
       * @see http://www.webgraphviz.com
       */
      dumpDot: !debug.enabled ? debug : (
        /* c8 ignore next */
        function(codePath) {
          let text = '\ndigraph {\nnode[shape=box,style="rounded,filled",fillcolor=white];\ninitial[label="",shape=circle,style=filled,fillcolor=black,width=0.25,height=0.25];\n';
          if (codePath.returnedSegments.length > 0) {
            text += 'final[label="",shape=doublecircle,style=filled,fillcolor=black,width=0.25,height=0.25];\n';
          }
          if (codePath.thrownSegments.length > 0) {
            text += 'thrown[label="\u2718",shape=circle,width=0.3,height=0.3,fixedsize];\n';
          }
          const traceMap = /* @__PURE__ */ Object.create(null);
          const arrows = this.makeDotArrows(codePath, traceMap);
          for (const id in traceMap) {
            const segment = traceMap[id];
            text += `${id}[`;
            if (segment.reachable) {
              text += 'label="';
            } else {
              text += 'style="rounded,dashed,filled",fillcolor="#FF9800",label="<<unreachable>>\\n';
            }
            if (segment.internal.nodes.length > 0) {
              text += segment.internal.nodes.join("\\n");
            } else {
              text += "????";
            }
            text += '"];\n';
          }
          text += `${arrows}
`;
          text += "}";
          debug("DOT", text);
        }
      ),
      /**
       * Makes a DOT code of a given code path.
       * The DOT code can be visualized with Graphvis.
       * @param {CodePath} codePath A code path to make DOT.
       * @param {Object} traceMap Optional. A map to check whether or not segments had been done.
       * @returns {string} A DOT code of the code path.
       */
      makeDotArrows(codePath, traceMap) {
        const stack = [[codePath.initialSegment, 0]];
        const done = traceMap || /* @__PURE__ */ Object.create(null);
        let lastId = codePath.initialSegment.id;
        let text = `initial->${codePath.initialSegment.id}`;
        while (stack.length > 0) {
          const item = stack.pop();
          const segment = item[0];
          const index = item[1];
          if (done[segment.id] && index === 0) {
            continue;
          }
          done[segment.id] = segment;
          const nextSegment = segment.allNextSegments[index];
          if (!nextSegment) {
            continue;
          }
          if (lastId === segment.id) {
            text += `->${nextSegment.id}`;
          } else {
            text += `;
${segment.id}->${nextSegment.id}`;
          }
          lastId = nextSegment.id;
          stack.unshift([segment, 1 + index]);
          stack.push([nextSegment, 0]);
        }
        codePath.returnedSegments.forEach((finalSegment) => {
          if (lastId === finalSegment.id) {
            text += "->final";
          } else {
            text += `;
${finalSegment.id}->final`;
          }
          lastId = null;
        });
        codePath.thrownSegments.forEach((finalSegment) => {
          if (lastId === finalSegment.id) {
            text += "->thrown";
          } else {
            text += `;
${finalSegment.id}->thrown`;
          }
          lastId = null;
        });
        return `${text};`;
      }
    };
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/code-path-segment.js
var require_code_path_segment = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/code-path-segment.js"(exports, module2) {
    "use strict";
    var debug = require_debug_helpers();
    function isReachable(segment) {
      return segment.reachable;
    }
    var CodePathSegment = class _CodePathSegment {
      /**
       * @param {string} id An identifier.
       * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
       *   This array includes unreachable segments.
       * @param {boolean} reachable A flag which shows this is reachable.
       */
      constructor(id, allPrevSegments, reachable) {
        this.id = id;
        this.nextSegments = [];
        this.prevSegments = allPrevSegments.filter(isReachable);
        this.allNextSegments = [];
        this.allPrevSegments = allPrevSegments;
        this.reachable = reachable;
        Object.defineProperty(this, "internal", {
          value: {
            used: false,
            loopedPrevSegments: []
          }
        });
        if (debug.enabled) {
          this.internal.nodes = [];
        }
      }
      /**
       * Checks a given previous segment is coming from the end of a loop.
       * @param {CodePathSegment} segment A previous segment to check.
       * @returns {boolean} `true` if the segment is coming from the end of a loop.
       */
      isLoopedPrevSegment(segment) {
        return this.internal.loopedPrevSegments.includes(segment);
      }
      /**
       * Creates the root segment.
       * @param {string} id An identifier.
       * @returns {CodePathSegment} The created segment.
       */
      static newRoot(id) {
        return new _CodePathSegment(id, [], true);
      }
      /**
       * Creates a segment that follows given segments.
       * @param {string} id An identifier.
       * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
       * @returns {CodePathSegment} The created segment.
       */
      static newNext(id, allPrevSegments) {
        return new _CodePathSegment(
          id,
          _CodePathSegment.flattenUnusedSegments(allPrevSegments),
          allPrevSegments.some(isReachable)
        );
      }
      /**
       * Creates an unreachable segment that follows given segments.
       * @param {string} id An identifier.
       * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
       * @returns {CodePathSegment} The created segment.
       */
      static newUnreachable(id, allPrevSegments) {
        const segment = new _CodePathSegment(id, _CodePathSegment.flattenUnusedSegments(allPrevSegments), false);
        _CodePathSegment.markUsed(segment);
        return segment;
      }
      /**
       * Creates a segment that follows given segments.
       * This factory method does not connect with `allPrevSegments`.
       * But this inherits `reachable` flag.
       * @param {string} id An identifier.
       * @param {CodePathSegment[]} allPrevSegments An array of the previous segments.
       * @returns {CodePathSegment} The created segment.
       */
      static newDisconnected(id, allPrevSegments) {
        return new _CodePathSegment(id, [], allPrevSegments.some(isReachable));
      }
      /**
       * Makes a given segment being used.
       *
       * And this function registers the segment into the previous segments as a next.
       * @param {CodePathSegment} segment A segment to mark.
       * @returns {void}
       */
      static markUsed(segment) {
        if (segment.internal.used) {
          return;
        }
        segment.internal.used = true;
        let i;
        if (segment.reachable) {
          for (i = 0; i < segment.allPrevSegments.length; ++i) {
            const prevSegment = segment.allPrevSegments[i];
            prevSegment.allNextSegments.push(segment);
            prevSegment.nextSegments.push(segment);
          }
        } else {
          for (i = 0; i < segment.allPrevSegments.length; ++i) {
            segment.allPrevSegments[i].allNextSegments.push(segment);
          }
        }
      }
      /**
       * Marks a previous segment as looped.
       * @param {CodePathSegment} segment A segment.
       * @param {CodePathSegment} prevSegment A previous segment to mark.
       * @returns {void}
       */
      static markPrevSegmentAsLooped(segment, prevSegment) {
        segment.internal.loopedPrevSegments.push(prevSegment);
      }
      /**
       * Replaces unused segments with the previous segments of each unused segment.
       * @param {CodePathSegment[]} segments An array of segments to replace.
       * @returns {CodePathSegment[]} The replaced array.
       */
      static flattenUnusedSegments(segments) {
        const done = /* @__PURE__ */ Object.create(null);
        const retv = [];
        for (let i = 0; i < segments.length; ++i) {
          const segment = segments[i];
          if (done[segment.id]) {
            continue;
          }
          if (!segment.internal.used) {
            for (let j = 0; j < segment.allPrevSegments.length; ++j) {
              const prevSegment = segment.allPrevSegments[j];
              if (!done[prevSegment.id]) {
                done[prevSegment.id] = true;
                retv.push(prevSegment);
              }
            }
          } else {
            done[segment.id] = true;
            retv.push(segment);
          }
        }
        return retv;
      }
    };
    module2.exports = CodePathSegment;
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/fork-context.js
var require_fork_context = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/fork-context.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var CodePathSegment = require_code_path_segment();
    function isReachable(segment) {
      return segment.reachable;
    }
    function makeSegments(context, begin, end, create) {
      const list = context.segmentsList;
      const normalizedBegin = begin >= 0 ? begin : list.length + begin;
      const normalizedEnd = end >= 0 ? end : list.length + end;
      const segments = [];
      for (let i = 0; i < context.count; ++i) {
        const allPrevSegments = [];
        for (let j = normalizedBegin; j <= normalizedEnd; ++j) {
          allPrevSegments.push(list[j][i]);
        }
        segments.push(create(context.idGenerator.next(), allPrevSegments));
      }
      return segments;
    }
    function mergeExtraSegments(context, segments) {
      let currentSegments = segments;
      while (currentSegments.length > context.count) {
        const merged = [];
        for (let i = 0, length = currentSegments.length / 2 | 0; i < length; ++i) {
          merged.push(CodePathSegment.newNext(
            context.idGenerator.next(),
            [currentSegments[i], currentSegments[i + length]]
          ));
        }
        currentSegments = merged;
      }
      return currentSegments;
    }
    var ForkContext = class _ForkContext {
      /**
       * @param {IdGenerator} idGenerator An identifier generator for segments.
       * @param {ForkContext|null} upper An upper fork context.
       * @param {number} count A number of parallel segments.
       */
      constructor(idGenerator, upper, count) {
        this.idGenerator = idGenerator;
        this.upper = upper;
        this.count = count;
        this.segmentsList = [];
      }
      /**
       * The head segments.
       * @type {CodePathSegment[]}
       */
      get head() {
        const list = this.segmentsList;
        return list.length === 0 ? [] : list[list.length - 1];
      }
      /**
       * A flag which shows empty.
       * @type {boolean}
       */
      get empty() {
        return this.segmentsList.length === 0;
      }
      /**
       * A flag which shows reachable.
       * @type {boolean}
       */
      get reachable() {
        const segments = this.head;
        return segments.length > 0 && segments.some(isReachable);
      }
      /**
       * Creates new segments from this context.
       * @param {number} begin The first index of previous segments.
       * @param {number} end The last index of previous segments.
       * @returns {CodePathSegment[]} New segments.
       */
      makeNext(begin, end) {
        return makeSegments(this, begin, end, CodePathSegment.newNext);
      }
      /**
       * Creates new segments from this context.
       * The new segments is always unreachable.
       * @param {number} begin The first index of previous segments.
       * @param {number} end The last index of previous segments.
       * @returns {CodePathSegment[]} New segments.
       */
      makeUnreachable(begin, end) {
        return makeSegments(this, begin, end, CodePathSegment.newUnreachable);
      }
      /**
       * Creates new segments from this context.
       * The new segments don't have connections for previous segments.
       * But these inherit the reachable flag from this context.
       * @param {number} begin The first index of previous segments.
       * @param {number} end The last index of previous segments.
       * @returns {CodePathSegment[]} New segments.
       */
      makeDisconnected(begin, end) {
        return makeSegments(this, begin, end, CodePathSegment.newDisconnected);
      }
      /**
       * Adds segments into this context.
       * The added segments become the head.
       * @param {CodePathSegment[]} segments Segments to add.
       * @returns {void}
       */
      add(segments) {
        assert(segments.length >= this.count, `${segments.length} >= ${this.count}`);
        this.segmentsList.push(mergeExtraSegments(this, segments));
      }
      /**
       * Replaces the head segments with given segments.
       * The current head segments are removed.
       * @param {CodePathSegment[]} segments Segments to add.
       * @returns {void}
       */
      replaceHead(segments) {
        assert(segments.length >= this.count, `${segments.length} >= ${this.count}`);
        this.segmentsList.splice(-1, 1, mergeExtraSegments(this, segments));
      }
      /**
       * Adds all segments of a given fork context into this context.
       * @param {ForkContext} context A fork context to add.
       * @returns {void}
       */
      addAll(context) {
        assert(context.count === this.count);
        const source = context.segmentsList;
        for (let i = 0; i < source.length; ++i) {
          this.segmentsList.push(source[i]);
        }
      }
      /**
       * Clears all segments in this context.
       * @returns {void}
       */
      clear() {
        this.segmentsList = [];
      }
      /**
       * Creates the root fork context.
       * @param {IdGenerator} idGenerator An identifier generator for segments.
       * @returns {ForkContext} New fork context.
       */
      static newRoot(idGenerator) {
        const context = new _ForkContext(idGenerator, null, 1);
        context.add([CodePathSegment.newRoot(idGenerator.next())]);
        return context;
      }
      /**
       * Creates an empty fork context preceded by a given context.
       * @param {ForkContext} parentContext The parent fork context.
       * @param {boolean} forkLeavingPath A flag which shows inside of `finally` block.
       * @returns {ForkContext} New fork context.
       */
      static newEmpty(parentContext, forkLeavingPath) {
        return new _ForkContext(
          parentContext.idGenerator,
          parentContext,
          (forkLeavingPath ? 2 : 1) * parentContext.count
        );
      }
    };
    module2.exports = ForkContext;
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/code-path-state.js
var require_code_path_state = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/code-path-state.js"(exports, module2) {
    "use strict";
    var CodePathSegment = require_code_path_segment();
    var ForkContext = require_fork_context();
    function addToReturnedOrThrown(dest, others, all, segments) {
      for (let i = 0; i < segments.length; ++i) {
        const segment = segments[i];
        dest.push(segment);
        if (!others.includes(segment)) {
          all.push(segment);
        }
      }
    }
    function getContinueContext(state, label) {
      if (!label) {
        return state.loopContext;
      }
      let context = state.loopContext;
      while (context) {
        if (context.label === label) {
          return context;
        }
        context = context.upper;
      }
      return null;
    }
    function getBreakContext(state, label) {
      let context = state.breakContext;
      while (context) {
        if (label ? context.label === label : context.breakable) {
          return context;
        }
        context = context.upper;
      }
      return null;
    }
    function getReturnContext(state) {
      let context = state.tryContext;
      while (context) {
        if (context.hasFinalizer && context.position !== "finally") {
          return context;
        }
        context = context.upper;
      }
      return state;
    }
    function getThrowContext(state) {
      let context = state.tryContext;
      while (context) {
        if (context.position === "try" || context.hasFinalizer && context.position === "catch") {
          return context;
        }
        context = context.upper;
      }
      return state;
    }
    function remove(xs, x) {
      xs.splice(xs.indexOf(x), 1);
    }
    function removeConnection(prevSegments, nextSegments) {
      for (let i = 0; i < prevSegments.length; ++i) {
        const prevSegment = prevSegments[i];
        const nextSegment = nextSegments[i];
        remove(prevSegment.nextSegments, nextSegment);
        remove(prevSegment.allNextSegments, nextSegment);
        remove(nextSegment.prevSegments, prevSegment);
        remove(nextSegment.allPrevSegments, prevSegment);
      }
    }
    function makeLooped(state, unflattenedFromSegments, unflattenedToSegments) {
      const fromSegments = CodePathSegment.flattenUnusedSegments(unflattenedFromSegments);
      const toSegments = CodePathSegment.flattenUnusedSegments(unflattenedToSegments);
      const end = Math.min(fromSegments.length, toSegments.length);
      for (let i = 0; i < end; ++i) {
        const fromSegment = fromSegments[i];
        const toSegment = toSegments[i];
        if (toSegment.reachable) {
          fromSegment.nextSegments.push(toSegment);
        }
        if (fromSegment.reachable) {
          toSegment.prevSegments.push(fromSegment);
        }
        fromSegment.allNextSegments.push(toSegment);
        toSegment.allPrevSegments.push(fromSegment);
        if (toSegment.allPrevSegments.length >= 2) {
          CodePathSegment.markPrevSegmentAsLooped(toSegment, fromSegment);
        }
        state.notifyLooped(fromSegment, toSegment);
      }
    }
    function finalizeTestSegmentsOfFor(context, choiceContext, head) {
      if (!choiceContext.processed) {
        choiceContext.trueForkContext.add(head);
        choiceContext.falseForkContext.add(head);
        choiceContext.qqForkContext.add(head);
      }
      if (context.test !== true) {
        context.brokenForkContext.addAll(choiceContext.falseForkContext);
      }
      context.endOfTestSegments = choiceContext.trueForkContext.makeNext(0, -1);
    }
    var CodePathState = class {
      /**
       * @param {IdGenerator} idGenerator An id generator to generate id for code
       *   path segments.
       * @param {Function} onLooped A callback function to notify looping.
       */
      constructor(idGenerator, onLooped) {
        this.idGenerator = idGenerator;
        this.notifyLooped = onLooped;
        this.forkContext = ForkContext.newRoot(idGenerator);
        this.choiceContext = null;
        this.switchContext = null;
        this.tryContext = null;
        this.loopContext = null;
        this.breakContext = null;
        this.chainContext = null;
        this.currentSegments = [];
        this.initialSegment = this.forkContext.head[0];
        const final = this.finalSegments = [];
        const returned = this.returnedForkContext = [];
        const thrown = this.thrownForkContext = [];
        returned.add = addToReturnedOrThrown.bind(null, returned, thrown, final);
        thrown.add = addToReturnedOrThrown.bind(null, thrown, returned, final);
      }
      /**
       * The head segments.
       * @type {CodePathSegment[]}
       */
      get headSegments() {
        return this.forkContext.head;
      }
      /**
       * The parent forking context.
       * This is used for the root of new forks.
       * @type {ForkContext}
       */
      get parentForkContext() {
        const current = this.forkContext;
        return current && current.upper;
      }
      /**
       * Creates and stacks new forking context.
       * @param {boolean} forkLeavingPath A flag which shows being in a
       *   "finally" block.
       * @returns {ForkContext} The created context.
       */
      pushForkContext(forkLeavingPath) {
        this.forkContext = ForkContext.newEmpty(
          this.forkContext,
          forkLeavingPath
        );
        return this.forkContext;
      }
      /**
       * Pops and merges the last forking context.
       * @returns {ForkContext} The last context.
       */
      popForkContext() {
        const lastContext = this.forkContext;
        this.forkContext = lastContext.upper;
        this.forkContext.replaceHead(lastContext.makeNext(0, -1));
        return lastContext;
      }
      /**
       * Creates a new path.
       * @returns {void}
       */
      forkPath() {
        this.forkContext.add(this.parentForkContext.makeNext(-1, -1));
      }
      /**
       * Creates a bypass path.
       * This is used for such as IfStatement which does not have "else" chunk.
       * @returns {void}
       */
      forkBypassPath() {
        this.forkContext.add(this.parentForkContext.head);
      }
      //--------------------------------------------------------------------------
      // ConditionalExpression, LogicalExpression, IfStatement
      //--------------------------------------------------------------------------
      /**
       * Creates a context for ConditionalExpression, LogicalExpression, AssignmentExpression (logical assignments only),
       * IfStatement, WhileStatement, DoWhileStatement, or ForStatement.
       *
       * LogicalExpressions have cases that it goes different paths between the
       * `true` case and the `false` case.
       *
       * For Example:
       *
       *     if (a || b) {
       *         foo();
       *     } else {
       *         bar();
       *     }
       *
       * In this case, `b` is evaluated always in the code path of the `else`
       * block, but it's not so in the code path of the `if` block.
       * So there are 3 paths.
       *
       *     a -> foo();
       *     a -> b -> foo();
       *     a -> b -> bar();
       * @param {string} kind A kind string.
       *   If the new context is LogicalExpression's or AssignmentExpression's, this is `"&&"` or `"||"` or `"??"`.
       *   If it's IfStatement's or ConditionalExpression's, this is `"test"`.
       *   Otherwise, this is `"loop"`.
       * @param {boolean} isForkingAsResult A flag that shows that goes different
       *   paths between `true` and `false`.
       * @returns {void}
       */
      pushChoiceContext(kind, isForkingAsResult) {
        this.choiceContext = {
          upper: this.choiceContext,
          kind,
          isForkingAsResult,
          trueForkContext: ForkContext.newEmpty(this.forkContext),
          falseForkContext: ForkContext.newEmpty(this.forkContext),
          qqForkContext: ForkContext.newEmpty(this.forkContext),
          processed: false
        };
      }
      /**
       * Pops the last choice context and finalizes it.
       * @throws {Error} (Unreachable.)
       * @returns {ChoiceContext} The popped context.
       */
      popChoiceContext() {
        const context = this.choiceContext;
        this.choiceContext = context.upper;
        const forkContext = this.forkContext;
        const headSegments = forkContext.head;
        switch (context.kind) {
          case "&&":
          case "||":
          case "??":
            if (!context.processed) {
              context.trueForkContext.add(headSegments);
              context.falseForkContext.add(headSegments);
              context.qqForkContext.add(headSegments);
            }
            if (context.isForkingAsResult) {
              const parentContext = this.choiceContext;
              parentContext.trueForkContext.addAll(context.trueForkContext);
              parentContext.falseForkContext.addAll(context.falseForkContext);
              parentContext.qqForkContext.addAll(context.qqForkContext);
              parentContext.processed = true;
              return context;
            }
            break;
          case "test":
            if (!context.processed) {
              context.trueForkContext.clear();
              context.trueForkContext.add(headSegments);
            } else {
              context.falseForkContext.clear();
              context.falseForkContext.add(headSegments);
            }
            break;
          case "loop":
            return context;
          default:
            throw new Error("unreachable");
        }
        const prevForkContext = context.trueForkContext;
        prevForkContext.addAll(context.falseForkContext);
        forkContext.replaceHead(prevForkContext.makeNext(0, -1));
        return context;
      }
      /**
       * Makes a code path segment of the right-hand operand of a logical
       * expression.
       * @throws {Error} (Unreachable.)
       * @returns {void}
       */
      makeLogicalRight() {
        const context = this.choiceContext;
        const forkContext = this.forkContext;
        if (context.processed) {
          let prevForkContext;
          switch (context.kind) {
            case "&&":
              prevForkContext = context.trueForkContext;
              break;
            case "||":
              prevForkContext = context.falseForkContext;
              break;
            case "??":
              prevForkContext = context.qqForkContext;
              break;
            default:
              throw new Error("unreachable");
          }
          forkContext.replaceHead(prevForkContext.makeNext(0, -1));
          prevForkContext.clear();
          context.processed = false;
        } else {
          switch (context.kind) {
            case "&&":
              context.falseForkContext.add(forkContext.head);
              break;
            case "||":
              context.trueForkContext.add(forkContext.head);
              break;
            case "??":
              context.trueForkContext.add(forkContext.head);
              context.falseForkContext.add(forkContext.head);
              break;
            default:
              throw new Error("unreachable");
          }
          forkContext.replaceHead(forkContext.makeNext(-1, -1));
        }
      }
      /**
       * Makes a code path segment of the `if` block.
       * @returns {void}
       */
      makeIfConsequent() {
        const context = this.choiceContext;
        const forkContext = this.forkContext;
        if (!context.processed) {
          context.trueForkContext.add(forkContext.head);
          context.falseForkContext.add(forkContext.head);
          context.qqForkContext.add(forkContext.head);
        }
        context.processed = false;
        forkContext.replaceHead(
          context.trueForkContext.makeNext(0, -1)
        );
      }
      /**
       * Makes a code path segment of the `else` block.
       * @returns {void}
       */
      makeIfAlternate() {
        const context = this.choiceContext;
        const forkContext = this.forkContext;
        context.trueForkContext.clear();
        context.trueForkContext.add(forkContext.head);
        context.processed = true;
        forkContext.replaceHead(
          context.falseForkContext.makeNext(0, -1)
        );
      }
      //--------------------------------------------------------------------------
      // ChainExpression
      //--------------------------------------------------------------------------
      /**
       * Push a new `ChainExpression` context to the stack.
       * This method is called on entering to each `ChainExpression` node.
       * This context is used to count forking in the optional chain then merge them on the exiting from the `ChainExpression` node.
       * @returns {void}
       */
      pushChainContext() {
        this.chainContext = {
          upper: this.chainContext,
          countChoiceContexts: 0
        };
      }
      /**
       * Pop a `ChainExpression` context from the stack.
       * This method is called on exiting from each `ChainExpression` node.
       * This merges all forks of the last optional chaining.
       * @returns {void}
       */
      popChainContext() {
        const context = this.chainContext;
        this.chainContext = context.upper;
        for (let i = context.countChoiceContexts; i > 0; --i) {
          this.popChoiceContext();
        }
      }
      /**
       * Create a choice context for optional access.
       * This method is called on entering to each `(Call|Member)Expression[optional=true]` node.
       * This creates a choice context as similar to `LogicalExpression[operator="??"]` node.
       * @returns {void}
       */
      makeOptionalNode() {
        if (this.chainContext) {
          this.chainContext.countChoiceContexts += 1;
          this.pushChoiceContext("??", false);
        }
      }
      /**
       * Create a fork.
       * This method is called on entering to the `arguments|property` property of each `(Call|Member)Expression` node.
       * @returns {void}
       */
      makeOptionalRight() {
        if (this.chainContext) {
          this.makeLogicalRight();
        }
      }
      //--------------------------------------------------------------------------
      // SwitchStatement
      //--------------------------------------------------------------------------
      /**
       * Creates a context object of SwitchStatement and stacks it.
       * @param {boolean} hasCase `true` if the switch statement has one or more
       *   case parts.
       * @param {string|null} label The label text.
       * @returns {void}
       */
      pushSwitchContext(hasCase, label) {
        this.switchContext = {
          upper: this.switchContext,
          hasCase,
          defaultSegments: null,
          defaultBodySegments: null,
          foundDefault: false,
          lastIsDefault: false,
          countForks: 0
        };
        this.pushBreakContext(true, label);
      }
      /**
       * Pops the last context of SwitchStatement and finalizes it.
       *
       * - Disposes all forking stack for `case` and `default`.
       * - Creates the next code path segment from `context.brokenForkContext`.
       * - If the last `SwitchCase` node is not a `default` part, creates a path
       *   to the `default` body.
       * @returns {void}
       */
      popSwitchContext() {
        const context = this.switchContext;
        this.switchContext = context.upper;
        const forkContext = this.forkContext;
        const brokenForkContext = this.popBreakContext().brokenForkContext;
        if (context.countForks === 0) {
          if (!brokenForkContext.empty) {
            brokenForkContext.add(forkContext.makeNext(-1, -1));
            forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
          }
          return;
        }
        const lastSegments = forkContext.head;
        this.forkBypassPath();
        const lastCaseSegments = forkContext.head;
        brokenForkContext.add(lastSegments);
        if (!context.lastIsDefault) {
          if (context.defaultBodySegments) {
            removeConnection(context.defaultSegments, context.defaultBodySegments);
            makeLooped(this, lastCaseSegments, context.defaultBodySegments);
          } else {
            brokenForkContext.add(lastCaseSegments);
          }
        }
        for (let i = 0; i < context.countForks; ++i) {
          this.forkContext = this.forkContext.upper;
        }
        this.forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
      }
      /**
       * Makes a code path segment for a `SwitchCase` node.
       * @param {boolean} isEmpty `true` if the body is empty.
       * @param {boolean} isDefault `true` if the body is the default case.
       * @returns {void}
       */
      makeSwitchCaseBody(isEmpty2, isDefault) {
        const context = this.switchContext;
        if (!context.hasCase) {
          return;
        }
        const parentForkContext = this.forkContext;
        const forkContext = this.pushForkContext();
        forkContext.add(parentForkContext.makeNext(0, -1));
        if (isDefault) {
          context.defaultSegments = parentForkContext.head;
          if (isEmpty2) {
            context.foundDefault = true;
          } else {
            context.defaultBodySegments = forkContext.head;
          }
        } else {
          if (!isEmpty2 && context.foundDefault) {
            context.foundDefault = false;
            context.defaultBodySegments = forkContext.head;
          }
        }
        context.lastIsDefault = isDefault;
        context.countForks += 1;
      }
      //--------------------------------------------------------------------------
      // TryStatement
      //--------------------------------------------------------------------------
      /**
       * Creates a context object of TryStatement and stacks it.
       * @param {boolean} hasFinalizer `true` if the try statement has a
       *   `finally` block.
       * @returns {void}
       */
      pushTryContext(hasFinalizer) {
        this.tryContext = {
          upper: this.tryContext,
          position: "try",
          hasFinalizer,
          returnedForkContext: hasFinalizer ? ForkContext.newEmpty(this.forkContext) : null,
          thrownForkContext: ForkContext.newEmpty(this.forkContext),
          lastOfTryIsReachable: false,
          lastOfCatchIsReachable: false
        };
      }
      /**
       * Pops the last context of TryStatement and finalizes it.
       * @returns {void}
       */
      popTryContext() {
        const context = this.tryContext;
        this.tryContext = context.upper;
        if (context.position === "catch") {
          this.popForkContext();
          return;
        }
        const returned = context.returnedForkContext;
        const thrown = context.thrownForkContext;
        if (returned.empty && thrown.empty) {
          return;
        }
        const headSegments = this.forkContext.head;
        this.forkContext = this.forkContext.upper;
        const normalSegments = headSegments.slice(0, headSegments.length / 2 | 0);
        const leavingSegments = headSegments.slice(headSegments.length / 2 | 0);
        if (!returned.empty) {
          getReturnContext(this).returnedForkContext.add(leavingSegments);
        }
        if (!thrown.empty) {
          getThrowContext(this).thrownForkContext.add(leavingSegments);
        }
        this.forkContext.replaceHead(normalSegments);
        if (!context.lastOfTryIsReachable && !context.lastOfCatchIsReachable) {
          this.forkContext.makeUnreachable();
        }
      }
      /**
       * Makes a code path segment for a `catch` block.
       * @returns {void}
       */
      makeCatchBlock() {
        const context = this.tryContext;
        const forkContext = this.forkContext;
        const thrown = context.thrownForkContext;
        context.position = "catch";
        context.thrownForkContext = ForkContext.newEmpty(forkContext);
        context.lastOfTryIsReachable = forkContext.reachable;
        thrown.add(forkContext.head);
        const thrownSegments = thrown.makeNext(0, -1);
        this.pushForkContext();
        this.forkBypassPath();
        this.forkContext.add(thrownSegments);
      }
      /**
       * Makes a code path segment for a `finally` block.
       *
       * In the `finally` block, parallel paths are created. The parallel paths
       * are used as leaving-paths. The leaving-paths are paths from `return`
       * statements and `throw` statements in a `try` block or a `catch` block.
       * @returns {void}
       */
      makeFinallyBlock() {
        const context = this.tryContext;
        let forkContext = this.forkContext;
        const returned = context.returnedForkContext;
        const thrown = context.thrownForkContext;
        const headOfLeavingSegments = forkContext.head;
        if (context.position === "catch") {
          this.popForkContext();
          forkContext = this.forkContext;
          context.lastOfCatchIsReachable = forkContext.reachable;
        } else {
          context.lastOfTryIsReachable = forkContext.reachable;
        }
        context.position = "finally";
        if (returned.empty && thrown.empty) {
          return;
        }
        const segments = forkContext.makeNext(-1, -1);
        for (let i = 0; i < forkContext.count; ++i) {
          const prevSegsOfLeavingSegment = [headOfLeavingSegments[i]];
          for (let j = 0; j < returned.segmentsList.length; ++j) {
            prevSegsOfLeavingSegment.push(returned.segmentsList[j][i]);
          }
          for (let j = 0; j < thrown.segmentsList.length; ++j) {
            prevSegsOfLeavingSegment.push(thrown.segmentsList[j][i]);
          }
          segments.push(
            CodePathSegment.newNext(
              this.idGenerator.next(),
              prevSegsOfLeavingSegment
            )
          );
        }
        this.pushForkContext(true);
        this.forkContext.add(segments);
      }
      /**
       * Makes a code path segment from the first throwable node to the `catch`
       * block or the `finally` block.
       * @returns {void}
       */
      makeFirstThrowablePathInTryBlock() {
        const forkContext = this.forkContext;
        if (!forkContext.reachable) {
          return;
        }
        const context = getThrowContext(this);
        if (context === this || context.position !== "try" || !context.thrownForkContext.empty) {
          return;
        }
        context.thrownForkContext.add(forkContext.head);
        forkContext.replaceHead(forkContext.makeNext(-1, -1));
      }
      //--------------------------------------------------------------------------
      // Loop Statements
      //--------------------------------------------------------------------------
      /**
       * Creates a context object of a loop statement and stacks it.
       * @param {string} type The type of the node which was triggered. One of
       *   `WhileStatement`, `DoWhileStatement`, `ForStatement`, `ForInStatement`,
       *   and `ForStatement`.
       * @param {string|null} label A label of the node which was triggered.
       * @throws {Error} (Unreachable - unknown type.)
       * @returns {void}
       */
      pushLoopContext(type, label) {
        const forkContext = this.forkContext;
        const breakContext = this.pushBreakContext(true, label);
        switch (type) {
          case "WhileStatement":
            this.pushChoiceContext("loop", false);
            this.loopContext = {
              upper: this.loopContext,
              type,
              label,
              test: void 0,
              continueDestSegments: null,
              brokenForkContext: breakContext.brokenForkContext
            };
            break;
          case "DoWhileStatement":
            this.pushChoiceContext("loop", false);
            this.loopContext = {
              upper: this.loopContext,
              type,
              label,
              test: void 0,
              entrySegments: null,
              continueForkContext: ForkContext.newEmpty(forkContext),
              brokenForkContext: breakContext.brokenForkContext
            };
            break;
          case "ForStatement":
            this.pushChoiceContext("loop", false);
            this.loopContext = {
              upper: this.loopContext,
              type,
              label,
              test: void 0,
              endOfInitSegments: null,
              testSegments: null,
              endOfTestSegments: null,
              updateSegments: null,
              endOfUpdateSegments: null,
              continueDestSegments: null,
              brokenForkContext: breakContext.brokenForkContext
            };
            break;
          case "ForInStatement":
          case "ForOfStatement":
            this.loopContext = {
              upper: this.loopContext,
              type,
              label,
              prevSegments: null,
              leftSegments: null,
              endOfLeftSegments: null,
              continueDestSegments: null,
              brokenForkContext: breakContext.brokenForkContext
            };
            break;
          default:
            throw new Error(`unknown type: "${type}"`);
        }
      }
      /**
       * Pops the last context of a loop statement and finalizes it.
       * @throws {Error} (Unreachable - unknown type.)
       * @returns {void}
       */
      popLoopContext() {
        const context = this.loopContext;
        this.loopContext = context.upper;
        const forkContext = this.forkContext;
        const brokenForkContext = this.popBreakContext().brokenForkContext;
        switch (context.type) {
          case "WhileStatement":
          case "ForStatement":
            this.popChoiceContext();
            makeLooped(
              this,
              forkContext.head,
              context.continueDestSegments
            );
            break;
          case "DoWhileStatement": {
            const choiceContext = this.popChoiceContext();
            if (!choiceContext.processed) {
              choiceContext.trueForkContext.add(forkContext.head);
              choiceContext.falseForkContext.add(forkContext.head);
            }
            if (context.test !== true) {
              brokenForkContext.addAll(choiceContext.falseForkContext);
            }
            const segmentsList = choiceContext.trueForkContext.segmentsList;
            for (let i = 0; i < segmentsList.length; ++i) {
              makeLooped(
                this,
                segmentsList[i],
                context.entrySegments
              );
            }
            break;
          }
          case "ForInStatement":
          case "ForOfStatement":
            brokenForkContext.add(forkContext.head);
            makeLooped(
              this,
              forkContext.head,
              context.leftSegments
            );
            break;
          default:
            throw new Error("unreachable");
        }
        if (brokenForkContext.empty) {
          forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
        } else {
          forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
        }
      }
      /**
       * Makes a code path segment for the test part of a WhileStatement.
       * @param {boolean|undefined} test The test value (only when constant).
       * @returns {void}
       */
      makeWhileTest(test) {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const testSegments = forkContext.makeNext(0, -1);
        context.test = test;
        context.continueDestSegments = testSegments;
        forkContext.replaceHead(testSegments);
      }
      /**
       * Makes a code path segment for the body part of a WhileStatement.
       * @returns {void}
       */
      makeWhileBody() {
        const context = this.loopContext;
        const choiceContext = this.choiceContext;
        const forkContext = this.forkContext;
        if (!choiceContext.processed) {
          choiceContext.trueForkContext.add(forkContext.head);
          choiceContext.falseForkContext.add(forkContext.head);
        }
        if (context.test !== true) {
          context.brokenForkContext.addAll(choiceContext.falseForkContext);
        }
        forkContext.replaceHead(choiceContext.trueForkContext.makeNext(0, -1));
      }
      /**
       * Makes a code path segment for the body part of a DoWhileStatement.
       * @returns {void}
       */
      makeDoWhileBody() {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const bodySegments = forkContext.makeNext(-1, -1);
        context.entrySegments = bodySegments;
        forkContext.replaceHead(bodySegments);
      }
      /**
       * Makes a code path segment for the test part of a DoWhileStatement.
       * @param {boolean|undefined} test The test value (only when constant).
       * @returns {void}
       */
      makeDoWhileTest(test) {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        context.test = test;
        if (!context.continueForkContext.empty) {
          context.continueForkContext.add(forkContext.head);
          const testSegments = context.continueForkContext.makeNext(0, -1);
          forkContext.replaceHead(testSegments);
        }
      }
      /**
       * Makes a code path segment for the test part of a ForStatement.
       * @param {boolean|undefined} test The test value (only when constant).
       * @returns {void}
       */
      makeForTest(test) {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const endOfInitSegments = forkContext.head;
        const testSegments = forkContext.makeNext(-1, -1);
        context.test = test;
        context.endOfInitSegments = endOfInitSegments;
        context.continueDestSegments = context.testSegments = testSegments;
        forkContext.replaceHead(testSegments);
      }
      /**
       * Makes a code path segment for the update part of a ForStatement.
       * @returns {void}
       */
      makeForUpdate() {
        const context = this.loopContext;
        const choiceContext = this.choiceContext;
        const forkContext = this.forkContext;
        if (context.testSegments) {
          finalizeTestSegmentsOfFor(
            context,
            choiceContext,
            forkContext.head
          );
        } else {
          context.endOfInitSegments = forkContext.head;
        }
        const updateSegments = forkContext.makeDisconnected(-1, -1);
        context.continueDestSegments = context.updateSegments = updateSegments;
        forkContext.replaceHead(updateSegments);
      }
      /**
       * Makes a code path segment for the body part of a ForStatement.
       * @returns {void}
       */
      makeForBody() {
        const context = this.loopContext;
        const choiceContext = this.choiceContext;
        const forkContext = this.forkContext;
        if (context.updateSegments) {
          context.endOfUpdateSegments = forkContext.head;
          if (context.testSegments) {
            makeLooped(
              this,
              context.endOfUpdateSegments,
              context.testSegments
            );
          }
        } else if (context.testSegments) {
          finalizeTestSegmentsOfFor(
            context,
            choiceContext,
            forkContext.head
          );
        } else {
          context.endOfInitSegments = forkContext.head;
        }
        let bodySegments = context.endOfTestSegments;
        if (!bodySegments) {
          const prevForkContext = ForkContext.newEmpty(forkContext);
          prevForkContext.add(context.endOfInitSegments);
          if (context.endOfUpdateSegments) {
            prevForkContext.add(context.endOfUpdateSegments);
          }
          bodySegments = prevForkContext.makeNext(0, -1);
        }
        context.continueDestSegments = context.continueDestSegments || bodySegments;
        forkContext.replaceHead(bodySegments);
      }
      /**
       * Makes a code path segment for the left part of a ForInStatement and a
       * ForOfStatement.
       * @returns {void}
       */
      makeForInOfLeft() {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const leftSegments = forkContext.makeDisconnected(-1, -1);
        context.prevSegments = forkContext.head;
        context.leftSegments = context.continueDestSegments = leftSegments;
        forkContext.replaceHead(leftSegments);
      }
      /**
       * Makes a code path segment for the right part of a ForInStatement and a
       * ForOfStatement.
       * @returns {void}
       */
      makeForInOfRight() {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const temp = ForkContext.newEmpty(forkContext);
        temp.add(context.prevSegments);
        const rightSegments = temp.makeNext(-1, -1);
        context.endOfLeftSegments = forkContext.head;
        forkContext.replaceHead(rightSegments);
      }
      /**
       * Makes a code path segment for the body part of a ForInStatement and a
       * ForOfStatement.
       * @returns {void}
       */
      makeForInOfBody() {
        const context = this.loopContext;
        const forkContext = this.forkContext;
        const temp = ForkContext.newEmpty(forkContext);
        temp.add(context.endOfLeftSegments);
        const bodySegments = temp.makeNext(-1, -1);
        makeLooped(this, forkContext.head, context.leftSegments);
        context.brokenForkContext.add(forkContext.head);
        forkContext.replaceHead(bodySegments);
      }
      //--------------------------------------------------------------------------
      // Control Statements
      //--------------------------------------------------------------------------
      /**
       * Creates new context for BreakStatement.
       * @param {boolean} breakable The flag to indicate it can break by
       *      an unlabeled BreakStatement.
       * @param {string|null} label The label of this context.
       * @returns {Object} The new context.
       */
      pushBreakContext(breakable, label) {
        this.breakContext = {
          upper: this.breakContext,
          breakable,
          label,
          brokenForkContext: ForkContext.newEmpty(this.forkContext)
        };
        return this.breakContext;
      }
      /**
       * Removes the top item of the break context stack.
       * @returns {Object} The removed context.
       */
      popBreakContext() {
        const context = this.breakContext;
        const forkContext = this.forkContext;
        this.breakContext = context.upper;
        if (!context.breakable) {
          const brokenForkContext = context.brokenForkContext;
          if (!brokenForkContext.empty) {
            brokenForkContext.add(forkContext.head);
            forkContext.replaceHead(brokenForkContext.makeNext(0, -1));
          }
        }
        return context;
      }
      /**
       * Makes a path for a `break` statement.
       *
       * It registers the head segment to a context of `break`.
       * It makes new unreachable segment, then it set the head with the segment.
       * @param {string} label A label of the break statement.
       * @returns {void}
       */
      makeBreak(label) {
        const forkContext = this.forkContext;
        if (!forkContext.reachable) {
          return;
        }
        const context = getBreakContext(this, label);
        if (context) {
          context.brokenForkContext.add(forkContext.head);
        }
        forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
      }
      /**
       * Makes a path for a `continue` statement.
       *
       * It makes a looping path.
       * It makes new unreachable segment, then it set the head with the segment.
       * @param {string} label A label of the continue statement.
       * @returns {void}
       */
      makeContinue(label) {
        const forkContext = this.forkContext;
        if (!forkContext.reachable) {
          return;
        }
        const context = getContinueContext(this, label);
        if (context) {
          if (context.continueDestSegments) {
            makeLooped(this, forkContext.head, context.continueDestSegments);
            if (context.type === "ForInStatement" || context.type === "ForOfStatement") {
              context.brokenForkContext.add(forkContext.head);
            }
          } else {
            context.continueForkContext.add(forkContext.head);
          }
        }
        forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
      }
      /**
       * Makes a path for a `return` statement.
       *
       * It registers the head segment to a context of `return`.
       * It makes new unreachable segment, then it set the head with the segment.
       * @returns {void}
       */
      makeReturn() {
        const forkContext = this.forkContext;
        if (forkContext.reachable) {
          getReturnContext(this).returnedForkContext.add(forkContext.head);
          forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
        }
      }
      /**
       * Makes a path for a `throw` statement.
       *
       * It registers the head segment to a context of `throw`.
       * It makes new unreachable segment, then it set the head with the segment.
       * @returns {void}
       */
      makeThrow() {
        const forkContext = this.forkContext;
        if (forkContext.reachable) {
          getThrowContext(this).thrownForkContext.add(forkContext.head);
          forkContext.replaceHead(forkContext.makeUnreachable(-1, -1));
        }
      }
      /**
       * Makes the final path.
       * @returns {void}
       */
      makeFinal() {
        const segments = this.currentSegments;
        if (segments.length > 0 && segments[0].reachable) {
          this.returnedForkContext.add(segments);
        }
      }
    };
    module2.exports = CodePathState;
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/id-generator.js
var require_id_generator = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/id-generator.js"(exports, module2) {
    "use strict";
    var IdGenerator = class {
      /**
       * @param {string} prefix Optional. A prefix of generated ids.
       */
      constructor(prefix) {
        this.prefix = String(prefix);
        this.n = 0;
      }
      /**
       * Generates id.
       * @returns {string} A generated id.
       */
      next() {
        this.n = 1 + this.n | 0;
        if (this.n < 0) {
          this.n = 1;
        }
        return this.prefix + this.n;
      }
    };
    module2.exports = IdGenerator;
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/code-path.js
var require_code_path = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/code-path.js"(exports, module2) {
    "use strict";
    var CodePathState = require_code_path_state();
    var IdGenerator = require_id_generator();
    var CodePath = class {
      /**
       * Creates a new instance.
       * @param {Object} options Options for the function (see below).
       * @param {string} options.id An identifier.
       * @param {string} options.origin The type of code path origin.
       * @param {CodePath|null} options.upper The code path of the upper function scope.
       * @param {Function} options.onLooped A callback function to notify looping.
       */
      constructor({ id, origin, upper, onLooped }) {
        this.id = id;
        this.origin = origin;
        this.upper = upper;
        this.childCodePaths = [];
        Object.defineProperty(
          this,
          "internal",
          { value: new CodePathState(new IdGenerator(`${id}_`), onLooped) }
        );
        if (upper) {
          upper.childCodePaths.push(this);
        }
      }
      /**
       * Gets the state of a given code path.
       * @param {CodePath} codePath A code path to get.
       * @returns {CodePathState} The state of the code path.
       */
      static getState(codePath) {
        return codePath.internal;
      }
      /**
       * The initial code path segment.
       * @type {CodePathSegment}
       */
      get initialSegment() {
        return this.internal.initialSegment;
      }
      /**
       * Final code path segments.
       * This array is a mix of `returnedSegments` and `thrownSegments`.
       * @type {CodePathSegment[]}
       */
      get finalSegments() {
        return this.internal.finalSegments;
      }
      /**
       * Final code path segments which is with `return` statements.
       * This array contains the last path segment if it's reachable.
       * Since the reachable last path returns `undefined`.
       * @type {CodePathSegment[]}
       */
      get returnedSegments() {
        return this.internal.returnedForkContext;
      }
      /**
       * Final code path segments which is with `throw` statements.
       * @type {CodePathSegment[]}
       */
      get thrownSegments() {
        return this.internal.thrownForkContext;
      }
      /**
       * Current code path segments.
       * @type {CodePathSegment[]}
       */
      get currentSegments() {
        return this.internal.currentSegments;
      }
      /**
       * Traverses all segments in this code path.
       *
       *     codePath.traverseSegments(function(segment, controller) {
       *         // do something.
       *     });
       *
       * This method enumerates segments in order from the head.
       *
       * The `controller` object has two methods.
       *
       * - `controller.skip()` - Skip the following segments in this branch.
       * - `controller.break()` - Skip all following segments.
       * @param {Object} [options] Omittable.
       * @param {CodePathSegment} [options.first] The first segment to traverse.
       * @param {CodePathSegment} [options.last] The last segment to traverse.
       * @param {Function} callback A callback function.
       * @returns {void}
       */
      traverseSegments(options, callback) {
        let resolvedOptions;
        let resolvedCallback;
        if (typeof options === "function") {
          resolvedCallback = options;
          resolvedOptions = {};
        } else {
          resolvedOptions = options || {};
          resolvedCallback = callback;
        }
        const startSegment = resolvedOptions.first || this.internal.initialSegment;
        const lastSegment = resolvedOptions.last;
        let item = null;
        let index = 0;
        let end = 0;
        let segment = null;
        const visited = /* @__PURE__ */ Object.create(null);
        const stack = [[startSegment, 0]];
        let skippedSegment = null;
        let broken = false;
        const controller = {
          skip() {
            if (stack.length <= 1) {
              broken = true;
            } else {
              skippedSegment = stack[stack.length - 2][0];
            }
          },
          break() {
            broken = true;
          }
        };
        function isVisited(prevSegment) {
          return visited[prevSegment.id] || segment.isLoopedPrevSegment(prevSegment);
        }
        while (stack.length > 0) {
          item = stack[stack.length - 1];
          segment = item[0];
          index = item[1];
          if (index === 0) {
            if (visited[segment.id]) {
              stack.pop();
              continue;
            }
            if (segment !== startSegment && segment.prevSegments.length > 0 && !segment.prevSegments.every(isVisited)) {
              stack.pop();
              continue;
            }
            if (skippedSegment && segment.prevSegments.includes(skippedSegment)) {
              skippedSegment = null;
            }
            visited[segment.id] = true;
            if (!skippedSegment) {
              resolvedCallback.call(this, segment, controller);
              if (segment === lastSegment) {
                controller.skip();
              }
              if (broken) {
                break;
              }
            }
          }
          end = segment.nextSegments.length - 1;
          if (index < end) {
            item[1] += 1;
            stack.push([segment.nextSegments[index], 0]);
          } else if (index === end) {
            item[0] = segment.nextSegments[index];
            item[1] = 0;
          } else {
            stack.pop();
          }
        }
      }
    };
    module2.exports = CodePath;
  }
});

// node_modules/eslint/lib/linter/code-path-analysis/code-path-analyzer.js
var require_code_path_analyzer = __commonJS({
  "node_modules/eslint/lib/linter/code-path-analysis/code-path-analyzer.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var { breakableTypePattern } = require_ast_utils();
    var CodePath = require_code_path();
    var CodePathSegment = require_code_path_segment();
    var IdGenerator = require_id_generator();
    var debug = require_debug_helpers();
    function isCaseNode(node) {
      return Boolean(node.test);
    }
    function isPropertyDefinitionValue(node) {
      const parent = node.parent;
      return parent && parent.type === "PropertyDefinition" && parent.value === node;
    }
    function isHandledLogicalOperator(operator) {
      return operator === "&&" || operator === "||" || operator === "??";
    }
    function isLogicalAssignmentOperator(operator) {
      return operator === "&&=" || operator === "||=" || operator === "??=";
    }
    function getLabel(node) {
      if (node.parent.type === "LabeledStatement") {
        return node.parent.label.name;
      }
      return null;
    }
    function isForkingByTrueOrFalse(node) {
      const parent = node.parent;
      switch (parent.type) {
        case "ConditionalExpression":
        case "IfStatement":
        case "WhileStatement":
        case "DoWhileStatement":
        case "ForStatement":
          return parent.test === node;
        case "LogicalExpression":
          return isHandledLogicalOperator(parent.operator);
        case "AssignmentExpression":
          return isLogicalAssignmentOperator(parent.operator);
        default:
          return false;
      }
    }
    function getBooleanValueIfSimpleConstant(node) {
      if (node.type === "Literal") {
        return Boolean(node.value);
      }
      return void 0;
    }
    function isIdentifierReference(node) {
      const parent = node.parent;
      switch (parent.type) {
        case "LabeledStatement":
        case "BreakStatement":
        case "ContinueStatement":
        case "ArrayPattern":
        case "RestElement":
        case "ImportSpecifier":
        case "ImportDefaultSpecifier":
        case "ImportNamespaceSpecifier":
        case "CatchClause":
          return false;
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "ArrowFunctionExpression":
        case "ClassDeclaration":
        case "ClassExpression":
        case "VariableDeclarator":
          return parent.id !== node;
        case "Property":
        case "PropertyDefinition":
        case "MethodDefinition":
          return parent.key !== node || parent.computed || parent.shorthand;
        case "AssignmentPattern":
          return parent.key !== node;
        default:
          return true;
      }
    }
    function forwardCurrentToHead(analyzer, node) {
      const codePath = analyzer.codePath;
      const state = CodePath.getState(codePath);
      const currentSegments = state.currentSegments;
      const headSegments = state.headSegments;
      const end = Math.max(currentSegments.length, headSegments.length);
      let i, currentSegment, headSegment;
      for (i = 0; i < end; ++i) {
        currentSegment = currentSegments[i];
        headSegment = headSegments[i];
        if (currentSegment !== headSegment && currentSegment) {
          debug.dump(`onCodePathSegmentEnd ${currentSegment.id}`);
          if (currentSegment.reachable) {
            analyzer.emitter.emit(
              "onCodePathSegmentEnd",
              currentSegment,
              node
            );
          }
        }
      }
      state.currentSegments = headSegments;
      for (i = 0; i < end; ++i) {
        currentSegment = currentSegments[i];
        headSegment = headSegments[i];
        if (currentSegment !== headSegment && headSegment) {
          debug.dump(`onCodePathSegmentStart ${headSegment.id}`);
          CodePathSegment.markUsed(headSegment);
          if (headSegment.reachable) {
            analyzer.emitter.emit(
              "onCodePathSegmentStart",
              headSegment,
              node
            );
          }
        }
      }
    }
    function leaveFromCurrentSegment(analyzer, node) {
      const state = CodePath.getState(analyzer.codePath);
      const currentSegments = state.currentSegments;
      for (let i = 0; i < currentSegments.length; ++i) {
        const currentSegment = currentSegments[i];
        debug.dump(`onCodePathSegmentEnd ${currentSegment.id}`);
        if (currentSegment.reachable) {
          analyzer.emitter.emit(
            "onCodePathSegmentEnd",
            currentSegment,
            node
          );
        }
      }
      state.currentSegments = [];
    }
    function preprocess(analyzer, node) {
      const codePath = analyzer.codePath;
      const state = CodePath.getState(codePath);
      const parent = node.parent;
      switch (parent.type) {
        case "CallExpression":
          if (parent.optional === true && parent.arguments.length >= 1 && parent.arguments[0] === node) {
            state.makeOptionalRight();
          }
          break;
        case "MemberExpression":
          if (parent.optional === true && parent.property === node) {
            state.makeOptionalRight();
          }
          break;
        case "LogicalExpression":
          if (parent.right === node && isHandledLogicalOperator(parent.operator)) {
            state.makeLogicalRight();
          }
          break;
        case "AssignmentExpression":
          if (parent.right === node && isLogicalAssignmentOperator(parent.operator)) {
            state.makeLogicalRight();
          }
          break;
        case "ConditionalExpression":
        case "IfStatement":
          if (parent.consequent === node) {
            state.makeIfConsequent();
          } else if (parent.alternate === node) {
            state.makeIfAlternate();
          }
          break;
        case "SwitchCase":
          if (parent.consequent[0] === node) {
            state.makeSwitchCaseBody(false, !parent.test);
          }
          break;
        case "TryStatement":
          if (parent.handler === node) {
            state.makeCatchBlock();
          } else if (parent.finalizer === node) {
            state.makeFinallyBlock();
          }
          break;
        case "WhileStatement":
          if (parent.test === node) {
            state.makeWhileTest(getBooleanValueIfSimpleConstant(node));
          } else {
            assert(parent.body === node);
            state.makeWhileBody();
          }
          break;
        case "DoWhileStatement":
          if (parent.body === node) {
            state.makeDoWhileBody();
          } else {
            assert(parent.test === node);
            state.makeDoWhileTest(getBooleanValueIfSimpleConstant(node));
          }
          break;
        case "ForStatement":
          if (parent.test === node) {
            state.makeForTest(getBooleanValueIfSimpleConstant(node));
          } else if (parent.update === node) {
            state.makeForUpdate();
          } else if (parent.body === node) {
            state.makeForBody();
          }
          break;
        case "ForInStatement":
        case "ForOfStatement":
          if (parent.left === node) {
            state.makeForInOfLeft();
          } else if (parent.right === node) {
            state.makeForInOfRight();
          } else {
            assert(parent.body === node);
            state.makeForInOfBody();
          }
          break;
        case "AssignmentPattern":
          if (parent.right === node) {
            state.pushForkContext();
            state.forkBypassPath();
            state.forkPath();
          }
          break;
        default:
          break;
      }
    }
    function processCodePathToEnter(analyzer, node) {
      let codePath = analyzer.codePath;
      let state = codePath && CodePath.getState(codePath);
      const parent = node.parent;
      function startCodePath(origin) {
        if (codePath) {
          forwardCurrentToHead(analyzer, node);
          debug.dumpState(node, state, false);
        }
        codePath = analyzer.codePath = new CodePath({
          id: analyzer.idGenerator.next(),
          origin,
          upper: codePath,
          onLooped: analyzer.onLooped
        });
        state = CodePath.getState(codePath);
        debug.dump(`onCodePathStart ${codePath.id}`);
        analyzer.emitter.emit("onCodePathStart", codePath, node);
      }
      if (isPropertyDefinitionValue(node)) {
        startCodePath("class-field-initializer");
      }
      switch (node.type) {
        case "Program":
          startCodePath("program");
          break;
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "ArrowFunctionExpression":
          startCodePath("function");
          break;
        case "StaticBlock":
          startCodePath("class-static-block");
          break;
        case "ChainExpression":
          state.pushChainContext();
          break;
        case "CallExpression":
          if (node.optional === true) {
            state.makeOptionalNode();
          }
          break;
        case "MemberExpression":
          if (node.optional === true) {
            state.makeOptionalNode();
          }
          break;
        case "LogicalExpression":
          if (isHandledLogicalOperator(node.operator)) {
            state.pushChoiceContext(
              node.operator,
              isForkingByTrueOrFalse(node)
            );
          }
          break;
        case "AssignmentExpression":
          if (isLogicalAssignmentOperator(node.operator)) {
            state.pushChoiceContext(
              node.operator.slice(0, -1),
              // removes `=` from the end
              isForkingByTrueOrFalse(node)
            );
          }
          break;
        case "ConditionalExpression":
        case "IfStatement":
          state.pushChoiceContext("test", false);
          break;
        case "SwitchStatement":
          state.pushSwitchContext(
            node.cases.some(isCaseNode),
            getLabel(node)
          );
          break;
        case "TryStatement":
          state.pushTryContext(Boolean(node.finalizer));
          break;
        case "SwitchCase":
          if (parent.discriminant !== node && parent.cases[0] !== node) {
            state.forkPath();
          }
          break;
        case "WhileStatement":
        case "DoWhileStatement":
        case "ForStatement":
        case "ForInStatement":
        case "ForOfStatement":
          state.pushLoopContext(node.type, getLabel(node));
          break;
        case "LabeledStatement":
          if (!breakableTypePattern.test(node.body.type)) {
            state.pushBreakContext(false, node.label.name);
          }
          break;
        default:
          break;
      }
      forwardCurrentToHead(analyzer, node);
      debug.dumpState(node, state, false);
    }
    function processCodePathToExit(analyzer, node) {
      const codePath = analyzer.codePath;
      const state = CodePath.getState(codePath);
      let dontForward = false;
      switch (node.type) {
        case "ChainExpression":
          state.popChainContext();
          break;
        case "IfStatement":
        case "ConditionalExpression":
          state.popChoiceContext();
          break;
        case "LogicalExpression":
          if (isHandledLogicalOperator(node.operator)) {
            state.popChoiceContext();
          }
          break;
        case "AssignmentExpression":
          if (isLogicalAssignmentOperator(node.operator)) {
            state.popChoiceContext();
          }
          break;
        case "SwitchStatement":
          state.popSwitchContext();
          break;
        case "SwitchCase":
          if (node.consequent.length === 0) {
            state.makeSwitchCaseBody(true, !node.test);
          }
          if (state.forkContext.reachable) {
            dontForward = true;
          }
          break;
        case "TryStatement":
          state.popTryContext();
          break;
        case "BreakStatement":
          forwardCurrentToHead(analyzer, node);
          state.makeBreak(node.label && node.label.name);
          dontForward = true;
          break;
        case "ContinueStatement":
          forwardCurrentToHead(analyzer, node);
          state.makeContinue(node.label && node.label.name);
          dontForward = true;
          break;
        case "ReturnStatement":
          forwardCurrentToHead(analyzer, node);
          state.makeReturn();
          dontForward = true;
          break;
        case "ThrowStatement":
          forwardCurrentToHead(analyzer, node);
          state.makeThrow();
          dontForward = true;
          break;
        case "Identifier":
          if (isIdentifierReference(node)) {
            state.makeFirstThrowablePathInTryBlock();
            dontForward = true;
          }
          break;
        case "CallExpression":
        case "ImportExpression":
        case "MemberExpression":
        case "NewExpression":
        case "YieldExpression":
          state.makeFirstThrowablePathInTryBlock();
          break;
        case "WhileStatement":
        case "DoWhileStatement":
        case "ForStatement":
        case "ForInStatement":
        case "ForOfStatement":
          state.popLoopContext();
          break;
        case "AssignmentPattern":
          state.popForkContext();
          break;
        case "LabeledStatement":
          if (!breakableTypePattern.test(node.body.type)) {
            state.popBreakContext();
          }
          break;
        default:
          break;
      }
      if (!dontForward) {
        forwardCurrentToHead(analyzer, node);
      }
      debug.dumpState(node, state, true);
    }
    function postprocess(analyzer, node) {
      function endCodePath() {
        let codePath = analyzer.codePath;
        CodePath.getState(codePath).makeFinal();
        leaveFromCurrentSegment(analyzer, node);
        debug.dump(`onCodePathEnd ${codePath.id}`);
        analyzer.emitter.emit("onCodePathEnd", codePath, node);
        debug.dumpDot(codePath);
        codePath = analyzer.codePath = analyzer.codePath.upper;
        if (codePath) {
          debug.dumpState(node, CodePath.getState(codePath), true);
        }
      }
      switch (node.type) {
        case "Program":
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "ArrowFunctionExpression":
        case "StaticBlock": {
          endCodePath();
          break;
        }
        case "CallExpression":
          if (node.optional === true && node.arguments.length === 0) {
            CodePath.getState(analyzer.codePath).makeOptionalRight();
          }
          break;
        default:
          break;
      }
      if (isPropertyDefinitionValue(node)) {
        endCodePath();
      }
    }
    var CodePathAnalyzer = class {
      /**
       * @param {EventGenerator} eventGenerator An event generator to wrap.
       */
      constructor(eventGenerator) {
        this.original = eventGenerator;
        this.emitter = eventGenerator.emitter;
        this.codePath = null;
        this.idGenerator = new IdGenerator("s");
        this.currentNode = null;
        this.onLooped = this.onLooped.bind(this);
      }
      /**
       * Does the process to enter a given AST node.
       * This updates state of analysis and calls `enterNode` of the wrapped.
       * @param {ASTNode} node A node which is entering.
       * @returns {void}
       */
      enterNode(node) {
        this.currentNode = node;
        if (node.parent) {
          preprocess(this, node);
        }
        processCodePathToEnter(this, node);
        this.original.enterNode(node);
        this.currentNode = null;
      }
      /**
       * Does the process to leave a given AST node.
       * This updates state of analysis and calls `leaveNode` of the wrapped.
       * @param {ASTNode} node A node which is leaving.
       * @returns {void}
       */
      leaveNode(node) {
        this.currentNode = node;
        processCodePathToExit(this, node);
        this.original.leaveNode(node);
        postprocess(this, node);
        this.currentNode = null;
      }
      /**
       * This is called on a code path looped.
       * Then this raises a looped event.
       * @param {CodePathSegment} fromSegment A segment of prev.
       * @param {CodePathSegment} toSegment A segment of next.
       * @returns {void}
       */
      onLooped(fromSegment, toSegment) {
        if (fromSegment.reachable && toSegment.reachable) {
          debug.dump(`onCodePathSegmentLoop ${fromSegment.id} -> ${toSegment.id}`);
          this.emitter.emit(
            "onCodePathSegmentLoop",
            fromSegment,
            toSegment,
            this.currentNode
          );
        }
      }
    };
    module2.exports = CodePathAnalyzer;
  }
});

// node_modules/eslint/lib/linter/apply-disable-directives.js
var require_apply_disable_directives = __commonJS({
  "node_modules/eslint/lib/linter/apply-disable-directives.js"(exports, module2) {
    "use strict";
    var escapeRegExp = require_escape_string_regexp2();
    function compareLocations(itemA, itemB) {
      return itemA.line - itemB.line || itemA.column - itemB.column;
    }
    function groupByParentComment(directives) {
      const groups = /* @__PURE__ */ new Map();
      for (const directive of directives) {
        const { unprocessedDirective: { parentComment } } = directive;
        if (groups.has(parentComment)) {
          groups.get(parentComment).push(directive);
        } else {
          groups.set(parentComment, [directive]);
        }
      }
      return [...groups.values()];
    }
    function createIndividualDirectivesRemoval(directives, commentToken) {
      const commentValueStart = commentToken.range[0] + "//".length;
      const listStartOffset = /^\s*\S+\s+/u.exec(commentToken.value)[0].length;
      const listText = commentToken.value.slice(listStartOffset).split(/\s-{2,}\s/u)[0].trimEnd();
      return directives.map((directive) => {
        const { ruleId } = directive;
        const regex = new RegExp(String.raw`(?:^|\s*,\s*)${escapeRegExp(ruleId)}(?:\s*,\s*|$)`, "u");
        const match = regex.exec(listText);
        const matchedText = match[0];
        const matchStartOffset = listStartOffset + match.index;
        const matchEndOffset = matchStartOffset + matchedText.length;
        const firstIndexOfComma = matchedText.indexOf(",");
        const lastIndexOfComma = matchedText.lastIndexOf(",");
        let removalStartOffset, removalEndOffset;
        if (firstIndexOfComma !== lastIndexOfComma) {
          removalStartOffset = matchStartOffset + firstIndexOfComma;
          removalEndOffset = matchStartOffset + lastIndexOfComma;
        } else {
          removalStartOffset = matchStartOffset;
          removalEndOffset = matchEndOffset;
        }
        return {
          description: `'${ruleId}'`,
          fix: {
            range: [
              commentValueStart + removalStartOffset,
              commentValueStart + removalEndOffset
            ],
            text: ""
          },
          unprocessedDirective: directive.unprocessedDirective
        };
      });
    }
    function createCommentRemoval(directives, commentToken) {
      const { range } = commentToken;
      const ruleIds = directives.filter((directive) => directive.ruleId).map((directive) => `'${directive.ruleId}'`);
      return {
        description: ruleIds.length <= 2 ? ruleIds.join(" or ") : `${ruleIds.slice(0, ruleIds.length - 1).join(", ")}, or ${ruleIds[ruleIds.length - 1]}`,
        fix: {
          range,
          text: " "
        },
        unprocessedDirective: directives[0].unprocessedDirective
      };
    }
    function processUnusedDisableDirectives(allDirectives) {
      const directiveGroups = groupByParentComment(allDirectives);
      return directiveGroups.flatMap(
        (directives) => {
          const { parentComment } = directives[0].unprocessedDirective;
          const remainingRuleIds = new Set(parentComment.ruleIds);
          for (const directive of directives) {
            remainingRuleIds.delete(directive.ruleId);
          }
          return remainingRuleIds.size ? createIndividualDirectivesRemoval(directives, parentComment.commentToken) : [createCommentRemoval(directives, parentComment.commentToken)];
        }
      );
    }
    function applyDirectives(options) {
      const problems = [];
      const usedDisableDirectives = /* @__PURE__ */ new Set();
      for (const problem of options.problems) {
        let disableDirectivesForProblem = [];
        let nextDirectiveIndex = 0;
        while (nextDirectiveIndex < options.directives.length && compareLocations(options.directives[nextDirectiveIndex], problem) <= 0) {
          const directive = options.directives[nextDirectiveIndex++];
          if (directive.ruleId === null || directive.ruleId === problem.ruleId) {
            switch (directive.type) {
              case "disable":
                disableDirectivesForProblem.push(directive);
                break;
              case "enable":
                disableDirectivesForProblem = [];
                break;
            }
          }
        }
        if (disableDirectivesForProblem.length > 0) {
          const suppressions = disableDirectivesForProblem.map((directive) => ({
            kind: "directive",
            justification: directive.unprocessedDirective.justification
          }));
          if (problem.suppressions) {
            problem.suppressions = problem.suppressions.concat(suppressions);
          } else {
            problem.suppressions = suppressions;
            usedDisableDirectives.add(disableDirectivesForProblem[disableDirectivesForProblem.length - 1]);
          }
        }
        problems.push(problem);
      }
      const unusedDisableDirectivesToReport = options.directives.filter((directive) => directive.type === "disable" && !usedDisableDirectives.has(directive));
      const processed = processUnusedDisableDirectives(unusedDisableDirectivesToReport);
      const unusedDisableDirectives = processed.map(({ description, fix, unprocessedDirective }) => {
        const { parentComment, type, line, column } = unprocessedDirective;
        return {
          ruleId: null,
          message: description ? `Unused eslint-disable directive (no problems were reported from ${description}).` : "Unused eslint-disable directive (no problems were reported).",
          line: type === "disable-next-line" ? parentComment.commentToken.loc.start.line : line,
          column: type === "disable-next-line" ? parentComment.commentToken.loc.start.column + 1 : column,
          severity: options.reportUnusedDisableDirectives === "warn" ? 1 : 2,
          nodeType: null,
          ...options.disableFixes ? {} : { fix }
        };
      });
      return { problems, unusedDisableDirectives };
    }
    module2.exports = ({ directives, disableFixes, problems, reportUnusedDisableDirectives = "off" }) => {
      const blockDirectives = directives.filter((directive) => directive.type === "disable" || directive.type === "enable").map((directive) => Object.assign({}, directive, { unprocessedDirective: directive })).sort(compareLocations);
      const lineDirectives = directives.flatMap((directive) => {
        switch (directive.type) {
          case "disable":
          case "enable":
            return [];
          case "disable-line":
            return [
              { type: "disable", line: directive.line, column: 1, ruleId: directive.ruleId, unprocessedDirective: directive },
              { type: "enable", line: directive.line + 1, column: 0, ruleId: directive.ruleId, unprocessedDirective: directive }
            ];
          case "disable-next-line":
            return [
              { type: "disable", line: directive.line + 1, column: 1, ruleId: directive.ruleId, unprocessedDirective: directive },
              { type: "enable", line: directive.line + 2, column: 0, ruleId: directive.ruleId, unprocessedDirective: directive }
            ];
          default:
            throw new TypeError(`Unrecognized directive type '${directive.type}'`);
        }
      }).sort(compareLocations);
      const blockDirectivesResult = applyDirectives({
        problems,
        directives: blockDirectives,
        disableFixes,
        reportUnusedDisableDirectives
      });
      const lineDirectivesResult = applyDirectives({
        problems: blockDirectivesResult.problems,
        directives: lineDirectives,
        disableFixes,
        reportUnusedDisableDirectives
      });
      return reportUnusedDisableDirectives !== "off" ? lineDirectivesResult.problems.concat(blockDirectivesResult.unusedDisableDirectives).concat(lineDirectivesResult.unusedDisableDirectives).sort(compareLocations) : lineDirectivesResult.problems;
    };
  }
});

// node_modules/prelude-ls/lib/Func.js
var require_Func = __commonJS({
  "node_modules/prelude-ls/lib/Func.js"(exports, module2) {
    var apply;
    var curry;
    var flip;
    var fix;
    var over;
    var memoize;
    var toString$ = {}.toString;
    apply = curry$(function(f, list) {
      return f.apply(null, list);
    });
    curry = function(f) {
      return curry$(f);
    };
    flip = curry$(function(f, x, y) {
      return f(y, x);
    });
    fix = function(f) {
      return function(g) {
        return function() {
          return f(g(g)).apply(null, arguments);
        };
      }(function(g) {
        return function() {
          return f(g(g)).apply(null, arguments);
        };
      });
    };
    over = curry$(function(f, g, x, y) {
      return f(g(x), g(y));
    });
    memoize = function(f) {
      var memo;
      memo = {};
      return function() {
        var args, res$, i$, to$, key, arg;
        res$ = [];
        for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
          res$.push(arguments[i$]);
        }
        args = res$;
        key = function() {
          var i$2, ref$, len$, results$ = [];
          for (i$2 = 0, len$ = (ref$ = args).length; i$2 < len$; ++i$2) {
            arg = ref$[i$2];
            results$.push(arg + toString$.call(arg).slice(8, -1));
          }
          return results$;
        }().join("");
        return memo[key] = key in memo ? memo[key] : f.apply(null, args);
      };
    };
    module2.exports = {
      curry,
      flip,
      fix,
      apply,
      over,
      memoize
    };
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
  }
});

// node_modules/prelude-ls/lib/List.js
var require_List = __commonJS({
  "node_modules/prelude-ls/lib/List.js"(exports, module2) {
    var each;
    var map;
    var compact;
    var filter;
    var reject;
    var remove;
    var partition;
    var find;
    var head;
    var first2;
    var tail;
    var last2;
    var initial;
    var empty;
    var reverse;
    var unique;
    var uniqueBy;
    var fold;
    var foldl;
    var fold1;
    var foldl1;
    var foldr;
    var foldr1;
    var unfoldr;
    var concat;
    var concatMap;
    var flatten;
    var difference;
    var intersection;
    var union;
    var countBy;
    var groupBy;
    var andList;
    var orList;
    var any;
    var all;
    var sort;
    var sortWith;
    var sortBy;
    var sum;
    var product;
    var mean;
    var average;
    var maximum;
    var minimum;
    var maximumBy;
    var minimumBy;
    var scan;
    var scanl;
    var scan1;
    var scanl1;
    var scanr;
    var scanr1;
    var slice;
    var take;
    var drop;
    var splitAt;
    var takeWhile;
    var dropWhile;
    var span;
    var breakList;
    var zip;
    var zipWith;
    var zipAll;
    var zipAllWith;
    var at;
    var elemIndex;
    var elemIndices;
    var findIndex;
    var findIndices;
    var toString$ = {}.toString;
    each = curry$(function(f, xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        f(x);
      }
      return xs;
    });
    map = curry$(function(f, xs) {
      var i$, len$, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        results$.push(f(x));
      }
      return results$;
    });
    compact = function(xs) {
      var i$, len$, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (x) {
          results$.push(x);
        }
      }
      return results$;
    };
    filter = curry$(function(f, xs) {
      var i$, len$, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (f(x)) {
          results$.push(x);
        }
      }
      return results$;
    });
    reject = curry$(function(f, xs) {
      var i$, len$, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (!f(x)) {
          results$.push(x);
        }
      }
      return results$;
    });
    remove = curry$(function(el, xs) {
      var i, x$;
      i = elemIndex(el, xs);
      x$ = xs.slice();
      if (i != null) {
        x$.splice(i, 1);
      }
      return x$;
    });
    partition = curry$(function(f, xs) {
      var passed, failed, i$, len$, x;
      passed = [];
      failed = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        (f(x) ? passed : failed).push(x);
      }
      return [passed, failed];
    });
    find = curry$(function(f, xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (f(x)) {
          return x;
        }
      }
    });
    head = first2 = function(xs) {
      return xs[0];
    };
    tail = function(xs) {
      if (!xs.length) {
        return;
      }
      return xs.slice(1);
    };
    last2 = function(xs) {
      return xs[xs.length - 1];
    };
    initial = function(xs) {
      if (!xs.length) {
        return;
      }
      return xs.slice(0, -1);
    };
    empty = function(xs) {
      return !xs.length;
    };
    reverse = function(xs) {
      return xs.concat().reverse();
    };
    unique = function(xs) {
      var result, i$, len$, x;
      result = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (!in$(x, result)) {
          result.push(x);
        }
      }
      return result;
    };
    uniqueBy = curry$(function(f, xs) {
      var seen, i$, len$, x, val, results$ = [];
      seen = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        val = f(x);
        if (in$(val, seen)) {
          continue;
        }
        seen.push(val);
        results$.push(x);
      }
      return results$;
    });
    fold = foldl = curry$(function(f, memo, xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        memo = f(memo, x);
      }
      return memo;
    });
    fold1 = foldl1 = curry$(function(f, xs) {
      return fold(f, xs[0], xs.slice(1));
    });
    foldr = curry$(function(f, memo, xs) {
      var i$, x;
      for (i$ = xs.length - 1; i$ >= 0; --i$) {
        x = xs[i$];
        memo = f(x, memo);
      }
      return memo;
    });
    foldr1 = curry$(function(f, xs) {
      return foldr(f, xs[xs.length - 1], xs.slice(0, -1));
    });
    unfoldr = curry$(function(f, b) {
      var result, x, that;
      result = [];
      x = b;
      while ((that = f(x)) != null) {
        result.push(that[0]);
        x = that[1];
      }
      return result;
    });
    concat = function(xss) {
      return [].concat.apply([], xss);
    };
    concatMap = curry$(function(f, xs) {
      var x;
      return [].concat.apply([], function() {
        var i$, ref$, len$, results$ = [];
        for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
          x = ref$[i$];
          results$.push(f(x));
        }
        return results$;
      }());
    });
    flatten = function(xs) {
      var x;
      return [].concat.apply([], function() {
        var i$, ref$, len$, results$ = [];
        for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
          x = ref$[i$];
          if (toString$.call(x).slice(8, -1) === "Array") {
            results$.push(flatten(x));
          } else {
            results$.push(x);
          }
        }
        return results$;
      }());
    };
    difference = function(xs) {
      var yss, res$, i$, to$, results, len$, x, j$, len1$, ys;
      res$ = [];
      for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
        res$.push(arguments[i$]);
      }
      yss = res$;
      results = [];
      outer:
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
          x = xs[i$];
          for (j$ = 0, len1$ = yss.length; j$ < len1$; ++j$) {
            ys = yss[j$];
            if (in$(x, ys)) {
              continue outer;
            }
          }
          results.push(x);
        }
      return results;
    };
    intersection = function(xs) {
      var yss, res$, i$, to$, results, len$, x, j$, len1$, ys;
      res$ = [];
      for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
        res$.push(arguments[i$]);
      }
      yss = res$;
      results = [];
      outer:
        for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
          x = xs[i$];
          for (j$ = 0, len1$ = yss.length; j$ < len1$; ++j$) {
            ys = yss[j$];
            if (!in$(x, ys)) {
              continue outer;
            }
          }
          results.push(x);
        }
      return results;
    };
    union = function() {
      var xss, res$, i$, to$, results, len$, xs, j$, len1$, x;
      res$ = [];
      for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
        res$.push(arguments[i$]);
      }
      xss = res$;
      results = [];
      for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
        xs = xss[i$];
        for (j$ = 0, len1$ = xs.length; j$ < len1$; ++j$) {
          x = xs[j$];
          if (!in$(x, results)) {
            results.push(x);
          }
        }
      }
      return results;
    };
    countBy = curry$(function(f, xs) {
      var results, i$, len$, x, key;
      results = {};
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        key = f(x);
        if (key in results) {
          results[key] += 1;
        } else {
          results[key] = 1;
        }
      }
      return results;
    });
    groupBy = curry$(function(f, xs) {
      var results, i$, len$, x, key;
      results = {};
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        key = f(x);
        if (key in results) {
          results[key].push(x);
        } else {
          results[key] = [x];
        }
      }
      return results;
    });
    andList = function(xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (!x) {
          return false;
        }
      }
      return true;
    };
    orList = function(xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (x) {
          return true;
        }
      }
      return false;
    };
    any = curry$(function(f, xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (f(x)) {
          return true;
        }
      }
      return false;
    });
    all = curry$(function(f, xs) {
      var i$, len$, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        if (!f(x)) {
          return false;
        }
      }
      return true;
    });
    sort = function(xs) {
      return xs.concat().sort(function(x, y) {
        if (x > y) {
          return 1;
        } else if (x < y) {
          return -1;
        } else {
          return 0;
        }
      });
    };
    sortWith = curry$(function(f, xs) {
      return xs.concat().sort(f);
    });
    sortBy = curry$(function(f, xs) {
      return xs.concat().sort(function(x, y) {
        if (f(x) > f(y)) {
          return 1;
        } else if (f(x) < f(y)) {
          return -1;
        } else {
          return 0;
        }
      });
    });
    sum = function(xs) {
      var result, i$, len$, x;
      result = 0;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        result += x;
      }
      return result;
    };
    product = function(xs) {
      var result, i$, len$, x;
      result = 1;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        result *= x;
      }
      return result;
    };
    mean = average = function(xs) {
      var sum2, i$, len$, x;
      sum2 = 0;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        x = xs[i$];
        sum2 += x;
      }
      return sum2 / xs.length;
    };
    maximum = function(xs) {
      var max2, i$, ref$, len$, x;
      max2 = xs[0];
      for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
        x = ref$[i$];
        if (x > max2) {
          max2 = x;
        }
      }
      return max2;
    };
    minimum = function(xs) {
      var min2, i$, ref$, len$, x;
      min2 = xs[0];
      for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
        x = ref$[i$];
        if (x < min2) {
          min2 = x;
        }
      }
      return min2;
    };
    maximumBy = curry$(function(f, xs) {
      var max2, i$, ref$, len$, x;
      max2 = xs[0];
      for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
        x = ref$[i$];
        if (f(x) > f(max2)) {
          max2 = x;
        }
      }
      return max2;
    });
    minimumBy = curry$(function(f, xs) {
      var min2, i$, ref$, len$, x;
      min2 = xs[0];
      for (i$ = 0, len$ = (ref$ = xs.slice(1)).length; i$ < len$; ++i$) {
        x = ref$[i$];
        if (f(x) < f(min2)) {
          min2 = x;
        }
      }
      return min2;
    });
    scan = scanl = curry$(function(f, memo, xs) {
      var last3, x;
      last3 = memo;
      return [memo].concat(function() {
        var i$, ref$, len$, results$ = [];
        for (i$ = 0, len$ = (ref$ = xs).length; i$ < len$; ++i$) {
          x = ref$[i$];
          results$.push(last3 = f(last3, x));
        }
        return results$;
      }());
    });
    scan1 = scanl1 = curry$(function(f, xs) {
      if (!xs.length) {
        return;
      }
      return scan(f, xs[0], xs.slice(1));
    });
    scanr = curry$(function(f, memo, xs) {
      xs = xs.concat().reverse();
      return scan(f, memo, xs).reverse();
    });
    scanr1 = curry$(function(f, xs) {
      if (!xs.length) {
        return;
      }
      xs = xs.concat().reverse();
      return scan(f, xs[0], xs.slice(1)).reverse();
    });
    slice = curry$(function(x, y, xs) {
      return xs.slice(x, y);
    });
    take = curry$(function(n, xs) {
      if (n <= 0) {
        return xs.slice(0, 0);
      } else {
        return xs.slice(0, n);
      }
    });
    drop = curry$(function(n, xs) {
      if (n <= 0) {
        return xs;
      } else {
        return xs.slice(n);
      }
    });
    splitAt = curry$(function(n, xs) {
      return [take(n, xs), drop(n, xs)];
    });
    takeWhile = curry$(function(p, xs) {
      var len, i;
      len = xs.length;
      if (!len) {
        return xs;
      }
      i = 0;
      while (i < len && p(xs[i])) {
        i += 1;
      }
      return xs.slice(0, i);
    });
    dropWhile = curry$(function(p, xs) {
      var len, i;
      len = xs.length;
      if (!len) {
        return xs;
      }
      i = 0;
      while (i < len && p(xs[i])) {
        i += 1;
      }
      return xs.slice(i);
    });
    span = curry$(function(p, xs) {
      return [takeWhile(p, xs), dropWhile(p, xs)];
    });
    breakList = curry$(function(p, xs) {
      return span(compose$(p, not$), xs);
    });
    zip = curry$(function(xs, ys) {
      var result, len, i$, len$, i, x;
      result = [];
      len = ys.length;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (i === len) {
          break;
        }
        result.push([x, ys[i]]);
      }
      return result;
    });
    zipWith = curry$(function(f, xs, ys) {
      var result, len, i$, len$, i, x;
      result = [];
      len = ys.length;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (i === len) {
          break;
        }
        result.push(f(x, ys[i]));
      }
      return result;
    });
    zipAll = function() {
      var xss, res$, i$, to$, minLength, len$, xs, ref$, i, lresult$, j$, results$ = [];
      res$ = [];
      for (i$ = 0, to$ = arguments.length; i$ < to$; ++i$) {
        res$.push(arguments[i$]);
      }
      xss = res$;
      minLength = void 0;
      for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
        xs = xss[i$];
        minLength <= (ref$ = xs.length) || (minLength = ref$);
      }
      for (i$ = 0; i$ < minLength; ++i$) {
        i = i$;
        lresult$ = [];
        for (j$ = 0, len$ = xss.length; j$ < len$; ++j$) {
          xs = xss[j$];
          lresult$.push(xs[i]);
        }
        results$.push(lresult$);
      }
      return results$;
    };
    zipAllWith = function(f) {
      var xss, res$, i$, to$, minLength, len$, xs, ref$, i, results$ = [];
      res$ = [];
      for (i$ = 1, to$ = arguments.length; i$ < to$; ++i$) {
        res$.push(arguments[i$]);
      }
      xss = res$;
      minLength = void 0;
      for (i$ = 0, len$ = xss.length; i$ < len$; ++i$) {
        xs = xss[i$];
        minLength <= (ref$ = xs.length) || (minLength = ref$);
      }
      for (i$ = 0; i$ < minLength; ++i$) {
        i = i$;
        results$.push(f.apply(null, fn$()));
      }
      return results$;
      function fn$() {
        var i$2, ref$2, len$2, results$2 = [];
        for (i$2 = 0, len$2 = (ref$2 = xss).length; i$2 < len$2; ++i$2) {
          xs = ref$2[i$2];
          results$2.push(xs[i]);
        }
        return results$2;
      }
    };
    at = curry$(function(n, xs) {
      if (n < 0) {
        return xs[xs.length + n];
      } else {
        return xs[n];
      }
    });
    elemIndex = curry$(function(el, xs) {
      var i$, len$, i, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (x === el) {
          return i;
        }
      }
    });
    elemIndices = curry$(function(el, xs) {
      var i$, len$, i, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (x === el) {
          results$.push(i);
        }
      }
      return results$;
    });
    findIndex = curry$(function(f, xs) {
      var i$, len$, i, x;
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (f(x)) {
          return i;
        }
      }
    });
    findIndices = curry$(function(f, xs) {
      var i$, len$, i, x, results$ = [];
      for (i$ = 0, len$ = xs.length; i$ < len$; ++i$) {
        i = i$;
        x = xs[i$];
        if (f(x)) {
          results$.push(i);
        }
      }
      return results$;
    });
    module2.exports = {
      each,
      map,
      filter,
      compact,
      reject,
      remove,
      partition,
      find,
      head,
      first: first2,
      tail,
      last: last2,
      initial,
      empty,
      reverse,
      difference,
      intersection,
      union,
      countBy,
      groupBy,
      fold,
      fold1,
      foldl,
      foldl1,
      foldr,
      foldr1,
      unfoldr,
      andList,
      orList,
      any,
      all,
      unique,
      uniqueBy,
      sort,
      sortWith,
      sortBy,
      sum,
      product,
      mean,
      average,
      concat,
      concatMap,
      flatten,
      maximum,
      minimum,
      maximumBy,
      minimumBy,
      scan,
      scan1,
      scanl,
      scanl1,
      scanr,
      scanr1,
      slice,
      take,
      drop,
      splitAt,
      takeWhile,
      dropWhile,
      span,
      breakList,
      zip,
      zipWith,
      zipAll,
      zipAllWith,
      at,
      elemIndex,
      elemIndices,
      findIndex,
      findIndices
    };
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
    function in$(x, xs) {
      var i = -1, l = xs.length >>> 0;
      while (++i < l)
        if (x === xs[i])
          return true;
      return false;
    }
    function compose$() {
      var functions = arguments;
      return function() {
        var i, result;
        result = functions[0].apply(this, arguments);
        for (i = 1; i < functions.length; ++i) {
          result = functions[i](result);
        }
        return result;
      };
    }
    function not$(x) {
      return !x;
    }
  }
});

// node_modules/prelude-ls/lib/Obj.js
var require_Obj = __commonJS({
  "node_modules/prelude-ls/lib/Obj.js"(exports, module2) {
    var values2;
    var keys3;
    var pairsToObj;
    var objToPairs;
    var listsToObj;
    var objToLists;
    var empty;
    var each;
    var map;
    var compact;
    var filter;
    var reject;
    var partition;
    var find;
    values2 = function(object) {
      var i$, x, results$ = [];
      for (i$ in object) {
        x = object[i$];
        results$.push(x);
      }
      return results$;
    };
    keys3 = function(object) {
      var x, results$ = [];
      for (x in object) {
        results$.push(x);
      }
      return results$;
    };
    pairsToObj = function(object) {
      var i$, len$, x, resultObj$ = {};
      for (i$ = 0, len$ = object.length; i$ < len$; ++i$) {
        x = object[i$];
        resultObj$[x[0]] = x[1];
      }
      return resultObj$;
    };
    objToPairs = function(object) {
      var key, value2, results$ = [];
      for (key in object) {
        value2 = object[key];
        results$.push([key, value2]);
      }
      return results$;
    };
    listsToObj = curry$(function(keys4, values3) {
      var i$, len$, i, key, resultObj$ = {};
      for (i$ = 0, len$ = keys4.length; i$ < len$; ++i$) {
        i = i$;
        key = keys4[i$];
        resultObj$[key] = values3[i];
      }
      return resultObj$;
    });
    objToLists = function(object) {
      var keys4, values3, key, value2;
      keys4 = [];
      values3 = [];
      for (key in object) {
        value2 = object[key];
        keys4.push(key);
        values3.push(value2);
      }
      return [keys4, values3];
    };
    empty = function(object) {
      var x;
      for (x in object) {
        return false;
      }
      return true;
    };
    each = curry$(function(f, object) {
      var i$, x;
      for (i$ in object) {
        x = object[i$];
        f(x);
      }
      return object;
    });
    map = curry$(function(f, object) {
      var k, x, resultObj$ = {};
      for (k in object) {
        x = object[k];
        resultObj$[k] = f(x);
      }
      return resultObj$;
    });
    compact = function(object) {
      var k, x, resultObj$ = {};
      for (k in object) {
        x = object[k];
        if (x) {
          resultObj$[k] = x;
        }
      }
      return resultObj$;
    };
    filter = curry$(function(f, object) {
      var k, x, resultObj$ = {};
      for (k in object) {
        x = object[k];
        if (f(x)) {
          resultObj$[k] = x;
        }
      }
      return resultObj$;
    });
    reject = curry$(function(f, object) {
      var k, x, resultObj$ = {};
      for (k in object) {
        x = object[k];
        if (!f(x)) {
          resultObj$[k] = x;
        }
      }
      return resultObj$;
    });
    partition = curry$(function(f, object) {
      var passed, failed, k, x;
      passed = {};
      failed = {};
      for (k in object) {
        x = object[k];
        (f(x) ? passed : failed)[k] = x;
      }
      return [passed, failed];
    });
    find = curry$(function(f, object) {
      var i$, x;
      for (i$ in object) {
        x = object[i$];
        if (f(x)) {
          return x;
        }
      }
    });
    module2.exports = {
      values: values2,
      keys: keys3,
      pairsToObj,
      objToPairs,
      listsToObj,
      objToLists,
      empty,
      each,
      map,
      filter,
      compact,
      reject,
      partition,
      find
    };
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
  }
});

// node_modules/prelude-ls/lib/Str.js
var require_Str = __commonJS({
  "node_modules/prelude-ls/lib/Str.js"(exports, module2) {
    var split;
    var join;
    var lines;
    var unlines;
    var words;
    var unwords;
    var chars;
    var unchars;
    var reverse;
    var repeat;
    var capitalize;
    var camelize;
    var dasherize;
    split = curry$(function(sep, str) {
      return str.split(sep);
    });
    join = curry$(function(sep, xs) {
      return xs.join(sep);
    });
    lines = function(str) {
      if (!str.length) {
        return [];
      }
      return str.split("\n");
    };
    unlines = function(it2) {
      return it2.join("\n");
    };
    words = function(str) {
      if (!str.length) {
        return [];
      }
      return str.split(/[ ]+/);
    };
    unwords = function(it2) {
      return it2.join(" ");
    };
    chars = function(it2) {
      return it2.split("");
    };
    unchars = function(it2) {
      return it2.join("");
    };
    reverse = function(str) {
      return str.split("").reverse().join("");
    };
    repeat = curry$(function(n, str) {
      var result, i$;
      result = "";
      for (i$ = 0; i$ < n; ++i$) {
        result += str;
      }
      return result;
    });
    capitalize = function(str) {
      return str.charAt(0).toUpperCase() + str.slice(1);
    };
    camelize = function(it2) {
      return it2.replace(/[-_]+(.)?/g, function(arg$, c) {
        return (c != null ? c : "").toUpperCase();
      });
    };
    dasherize = function(str) {
      return str.replace(/([^-A-Z])([A-Z]+)/g, function(arg$, lower, upper) {
        return lower + "-" + (upper.length > 1 ? upper : upper.toLowerCase());
      }).replace(/^([A-Z]+)/, function(arg$, upper) {
        if (upper.length > 1) {
          return upper + "-";
        } else {
          return upper.toLowerCase();
        }
      });
    };
    module2.exports = {
      split,
      join,
      lines,
      unlines,
      words,
      unwords,
      chars,
      unchars,
      reverse,
      repeat,
      capitalize,
      camelize,
      dasherize
    };
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
  }
});

// node_modules/prelude-ls/lib/Num.js
var require_Num = __commonJS({
  "node_modules/prelude-ls/lib/Num.js"(exports, module2) {
    var max2;
    var min2;
    var negate;
    var abs;
    var signum;
    var quot;
    var rem;
    var div;
    var mod;
    var recip;
    var pi;
    var tau;
    var exp;
    var sqrt;
    var ln;
    var pow;
    var sin;
    var tan;
    var cos;
    var asin;
    var acos;
    var atan;
    var atan2;
    var truncate;
    var round;
    var ceiling;
    var floor;
    var isItNaN;
    var even;
    var odd;
    var gcd;
    var lcm;
    max2 = curry$(function(x$, y$) {
      return x$ > y$ ? x$ : y$;
    });
    min2 = curry$(function(x$, y$) {
      return x$ < y$ ? x$ : y$;
    });
    negate = function(x) {
      return -x;
    };
    abs = Math.abs;
    signum = function(x) {
      if (x < 0) {
        return -1;
      } else if (x > 0) {
        return 1;
      } else {
        return 0;
      }
    };
    quot = curry$(function(x, y) {
      return ~~(x / y);
    });
    rem = curry$(function(x$, y$) {
      return x$ % y$;
    });
    div = curry$(function(x, y) {
      return Math.floor(x / y);
    });
    mod = curry$(function(x$, y$) {
      var ref$;
      return (x$ % (ref$ = y$) + ref$) % ref$;
    });
    recip = function(it2) {
      return 1 / it2;
    };
    pi = Math.PI;
    tau = pi * 2;
    exp = Math.exp;
    sqrt = Math.sqrt;
    ln = Math.log;
    pow = curry$(function(x$, y$) {
      return Math.pow(x$, y$);
    });
    sin = Math.sin;
    tan = Math.tan;
    cos = Math.cos;
    asin = Math.asin;
    acos = Math.acos;
    atan = Math.atan;
    atan2 = curry$(function(x, y) {
      return Math.atan2(x, y);
    });
    truncate = function(x) {
      return ~~x;
    };
    round = Math.round;
    ceiling = Math.ceil;
    floor = Math.floor;
    isItNaN = function(x) {
      return x !== x;
    };
    even = function(x) {
      return x % 2 === 0;
    };
    odd = function(x) {
      return x % 2 !== 0;
    };
    gcd = curry$(function(x, y) {
      var z;
      x = Math.abs(x);
      y = Math.abs(y);
      while (y !== 0) {
        z = x % y;
        x = y;
        y = z;
      }
      return x;
    });
    lcm = curry$(function(x, y) {
      return Math.abs(Math.floor(x / gcd(x, y) * y));
    });
    module2.exports = {
      max: max2,
      min: min2,
      negate,
      abs,
      signum,
      quot,
      rem,
      div,
      mod,
      recip,
      pi,
      tau,
      exp,
      sqrt,
      ln,
      pow,
      sin,
      tan,
      cos,
      acos,
      asin,
      atan,
      atan2,
      truncate,
      round,
      ceiling,
      floor,
      isItNaN,
      even,
      odd,
      gcd,
      lcm
    };
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
  }
});

// node_modules/prelude-ls/lib/index.js
var require_lib6 = __commonJS({
  "node_modules/prelude-ls/lib/index.js"(exports, module2) {
    var Func;
    var List;
    var Obj;
    var Str;
    var Num;
    var id;
    var isType;
    var replicate;
    var prelude;
    var toString$ = {}.toString;
    Func = require_Func();
    List = require_List();
    Obj = require_Obj();
    Str = require_Str();
    Num = require_Num();
    id = function(x) {
      return x;
    };
    isType = curry$(function(type, x) {
      return toString$.call(x).slice(8, -1) === type;
    });
    replicate = curry$(function(n, x) {
      var i$, results$ = [];
      for (i$ = 0; i$ < n; ++i$) {
        results$.push(x);
      }
      return results$;
    });
    Str.empty = List.empty;
    Str.slice = List.slice;
    Str.take = List.take;
    Str.drop = List.drop;
    Str.splitAt = List.splitAt;
    Str.takeWhile = List.takeWhile;
    Str.dropWhile = List.dropWhile;
    Str.span = List.span;
    Str.breakStr = List.breakList;
    prelude = {
      Func,
      List,
      Obj,
      Str,
      Num,
      id,
      isType,
      replicate
    };
    prelude.each = List.each;
    prelude.map = List.map;
    prelude.filter = List.filter;
    prelude.compact = List.compact;
    prelude.reject = List.reject;
    prelude.partition = List.partition;
    prelude.find = List.find;
    prelude.head = List.head;
    prelude.first = List.first;
    prelude.tail = List.tail;
    prelude.last = List.last;
    prelude.initial = List.initial;
    prelude.empty = List.empty;
    prelude.reverse = List.reverse;
    prelude.difference = List.difference;
    prelude.intersection = List.intersection;
    prelude.union = List.union;
    prelude.countBy = List.countBy;
    prelude.groupBy = List.groupBy;
    prelude.fold = List.fold;
    prelude.foldl = List.foldl;
    prelude.fold1 = List.fold1;
    prelude.foldl1 = List.foldl1;
    prelude.foldr = List.foldr;
    prelude.foldr1 = List.foldr1;
    prelude.unfoldr = List.unfoldr;
    prelude.andList = List.andList;
    prelude.orList = List.orList;
    prelude.any = List.any;
    prelude.all = List.all;
    prelude.unique = List.unique;
    prelude.uniqueBy = List.uniqueBy;
    prelude.sort = List.sort;
    prelude.sortWith = List.sortWith;
    prelude.sortBy = List.sortBy;
    prelude.sum = List.sum;
    prelude.product = List.product;
    prelude.mean = List.mean;
    prelude.average = List.average;
    prelude.concat = List.concat;
    prelude.concatMap = List.concatMap;
    prelude.flatten = List.flatten;
    prelude.maximum = List.maximum;
    prelude.minimum = List.minimum;
    prelude.maximumBy = List.maximumBy;
    prelude.minimumBy = List.minimumBy;
    prelude.scan = List.scan;
    prelude.scanl = List.scanl;
    prelude.scan1 = List.scan1;
    prelude.scanl1 = List.scanl1;
    prelude.scanr = List.scanr;
    prelude.scanr1 = List.scanr1;
    prelude.slice = List.slice;
    prelude.take = List.take;
    prelude.drop = List.drop;
    prelude.splitAt = List.splitAt;
    prelude.takeWhile = List.takeWhile;
    prelude.dropWhile = List.dropWhile;
    prelude.span = List.span;
    prelude.breakList = List.breakList;
    prelude.zip = List.zip;
    prelude.zipWith = List.zipWith;
    prelude.zipAll = List.zipAll;
    prelude.zipAllWith = List.zipAllWith;
    prelude.at = List.at;
    prelude.elemIndex = List.elemIndex;
    prelude.elemIndices = List.elemIndices;
    prelude.findIndex = List.findIndex;
    prelude.findIndices = List.findIndices;
    prelude.apply = Func.apply;
    prelude.curry = Func.curry;
    prelude.flip = Func.flip;
    prelude.fix = Func.fix;
    prelude.over = Func.over;
    prelude.split = Str.split;
    prelude.join = Str.join;
    prelude.lines = Str.lines;
    prelude.unlines = Str.unlines;
    prelude.words = Str.words;
    prelude.unwords = Str.unwords;
    prelude.chars = Str.chars;
    prelude.unchars = Str.unchars;
    prelude.repeat = Str.repeat;
    prelude.capitalize = Str.capitalize;
    prelude.camelize = Str.camelize;
    prelude.dasherize = Str.dasherize;
    prelude.values = Obj.values;
    prelude.keys = Obj.keys;
    prelude.pairsToObj = Obj.pairsToObj;
    prelude.objToPairs = Obj.objToPairs;
    prelude.listsToObj = Obj.listsToObj;
    prelude.objToLists = Obj.objToLists;
    prelude.max = Num.max;
    prelude.min = Num.min;
    prelude.negate = Num.negate;
    prelude.abs = Num.abs;
    prelude.signum = Num.signum;
    prelude.quot = Num.quot;
    prelude.rem = Num.rem;
    prelude.div = Num.div;
    prelude.mod = Num.mod;
    prelude.recip = Num.recip;
    prelude.pi = Num.pi;
    prelude.tau = Num.tau;
    prelude.exp = Num.exp;
    prelude.sqrt = Num.sqrt;
    prelude.ln = Num.ln;
    prelude.pow = Num.pow;
    prelude.sin = Num.sin;
    prelude.tan = Num.tan;
    prelude.cos = Num.cos;
    prelude.acos = Num.acos;
    prelude.asin = Num.asin;
    prelude.atan = Num.atan;
    prelude.atan2 = Num.atan2;
    prelude.truncate = Num.truncate;
    prelude.round = Num.round;
    prelude.ceiling = Num.ceiling;
    prelude.floor = Num.floor;
    prelude.isItNaN = Num.isItNaN;
    prelude.even = Num.even;
    prelude.odd = Num.odd;
    prelude.gcd = Num.gcd;
    prelude.lcm = Num.lcm;
    prelude.VERSION = "1.2.1";
    module2.exports = prelude;
    function curry$(f, bound) {
      var context, _curry = function(args) {
        return f.length > 1 ? function() {
          var params = args ? args.concat() : [];
          context = bound ? context || this : this;
          return params.push.apply(params, arguments) < f.length && arguments.length ? _curry.call(context, params) : f.apply(context, params);
        } : f;
      };
      return _curry();
    }
  }
});

// node_modules/levn/lib/parse-string.js
var require_parse_string = __commonJS({
  "node_modules/levn/lib/parse-string.js"(exports, module2) {
    (function() {
      var reject, special, tokenRegex;
      reject = require_lib6().reject;
      function consumeOp(tokens, op) {
        if (tokens[0] === op) {
          return tokens.shift();
        } else {
          throw new Error("Expected '" + op + "', but got '" + tokens[0] + "' instead in " + JSON.stringify(tokens) + ".");
        }
      }
      function maybeConsumeOp(tokens, op) {
        if (tokens[0] === op) {
          return tokens.shift();
        }
      }
      function consumeList(tokens, arg$, hasDelimiters) {
        var open, close, result, untilTest;
        open = arg$[0], close = arg$[1];
        if (hasDelimiters) {
          consumeOp(tokens, open);
        }
        result = [];
        untilTest = "," + (hasDelimiters ? close : "");
        while (tokens.length && (hasDelimiters && tokens[0] !== close)) {
          result.push(consumeElement(tokens, untilTest));
          maybeConsumeOp(tokens, ",");
        }
        if (hasDelimiters) {
          consumeOp(tokens, close);
        }
        return result;
      }
      function consumeArray(tokens, hasDelimiters) {
        return consumeList(tokens, ["[", "]"], hasDelimiters);
      }
      function consumeTuple(tokens, hasDelimiters) {
        return consumeList(tokens, ["(", ")"], hasDelimiters);
      }
      function consumeFields(tokens, hasDelimiters) {
        var result, untilTest, key;
        if (hasDelimiters) {
          consumeOp(tokens, "{");
        }
        result = {};
        untilTest = "," + (hasDelimiters ? "}" : "");
        while (tokens.length && (!hasDelimiters || tokens[0] !== "}")) {
          key = consumeValue(tokens, ":");
          consumeOp(tokens, ":");
          result[key] = consumeElement(tokens, untilTest);
          maybeConsumeOp(tokens, ",");
        }
        if (hasDelimiters) {
          consumeOp(tokens, "}");
        }
        return result;
      }
      function consumeValue(tokens, untilTest) {
        var out;
        untilTest == null && (untilTest = "");
        out = "";
        while (tokens.length && -1 === untilTest.indexOf(tokens[0])) {
          out += tokens.shift();
        }
        return out;
      }
      function consumeElement(tokens, untilTest) {
        switch (tokens[0]) {
          case "[":
            return consumeArray(tokens, true);
          case "(":
            return consumeTuple(tokens, true);
          case "{":
            return consumeFields(tokens, true);
          default:
            return consumeValue(tokens, untilTest);
        }
      }
      function consumeTopLevel(tokens, types, options) {
        var ref$, type, structure, origTokens, result, finalResult, x$, y$;
        ref$ = types[0], type = ref$.type, structure = ref$.structure;
        origTokens = tokens.concat();
        if (!options.explicit && types.length === 1 && (!type && structure || (type === "Array" || type === "Object"))) {
          result = structure === "array" || type === "Array" ? consumeArray(tokens, tokens[0] === "[") : structure === "tuple" ? consumeTuple(tokens, tokens[0] === "(") : consumeFields(tokens, tokens[0] === "{");
          finalResult = tokens.length ? consumeElement(structure === "array" || type === "Array" ? (x$ = origTokens, x$.unshift("["), x$.push("]"), x$) : (y$ = origTokens, y$.unshift("("), y$.push(")"), y$)) : result;
        } else {
          finalResult = consumeElement(tokens);
        }
        return finalResult;
      }
      special = /\[\]\(\)}{:,/.source;
      tokenRegex = RegExp(`("(?:\\\\"|[^"])*")|('(?:\\\\'|[^'])*')|(/(?:\\\\/|[^/])*/[a-zA-Z]*)|(#.*#)|([` + special + "])|([^\\s" + special + "](?:\\s*[^\\s" + special + "]+)*)|\\s*");
      module2.exports = function(types, string, options) {
        var tokens, node;
        options == null && (options = {});
        if (!options.explicit && types.length === 1 && types[0].type === "String") {
          return string;
        }
        tokens = reject(not$, string.split(tokenRegex));
        node = consumeTopLevel(tokens, types, options);
        if (!node) {
          throw new Error("Error parsing '" + string + "'.");
        }
        return node;
      };
      function not$(x) {
        return !x;
      }
    }).call(exports);
  }
});

// node_modules/type-check/lib/parse-type.js
var require_parse_type = __commonJS({
  "node_modules/type-check/lib/parse-type.js"(exports, module2) {
    (function() {
      var identifierRegex, tokenRegex;
      identifierRegex = /[\$\w]+/;
      function peek(tokens) {
        var token;
        token = tokens[0];
        if (token == null) {
          throw new Error("Unexpected end of input.");
        }
        return token;
      }
      function consumeIdent(tokens) {
        var token;
        token = peek(tokens);
        if (!identifierRegex.test(token)) {
          throw new Error("Expected text, got '" + token + "' instead.");
        }
        return tokens.shift();
      }
      function consumeOp(tokens, op) {
        var token;
        token = peek(tokens);
        if (token !== op) {
          throw new Error("Expected '" + op + "', got '" + token + "' instead.");
        }
        return tokens.shift();
      }
      function maybeConsumeOp(tokens, op) {
        var token;
        token = tokens[0];
        if (token === op) {
          return tokens.shift();
        } else {
          return null;
        }
      }
      function consumeArray(tokens) {
        var types;
        consumeOp(tokens, "[");
        if (peek(tokens) === "]") {
          throw new Error("Must specify type of Array - eg. [Type], got [] instead.");
        }
        types = consumeTypes(tokens);
        consumeOp(tokens, "]");
        return {
          structure: "array",
          of: types
        };
      }
      function consumeTuple(tokens) {
        var components;
        components = [];
        consumeOp(tokens, "(");
        if (peek(tokens) === ")") {
          throw new Error("Tuple must be of at least length 1 - eg. (Type), got () instead.");
        }
        for (; ; ) {
          components.push(consumeTypes(tokens));
          maybeConsumeOp(tokens, ",");
          if (")" === peek(tokens)) {
            break;
          }
        }
        consumeOp(tokens, ")");
        return {
          structure: "tuple",
          of: components
        };
      }
      function consumeFields(tokens) {
        var fields, subset, ref$, key, types;
        fields = {};
        consumeOp(tokens, "{");
        subset = false;
        for (; ; ) {
          if (maybeConsumeOp(tokens, "...")) {
            subset = true;
            break;
          }
          ref$ = consumeField(tokens), key = ref$[0], types = ref$[1];
          fields[key] = types;
          maybeConsumeOp(tokens, ",");
          if ("}" === peek(tokens)) {
            break;
          }
        }
        consumeOp(tokens, "}");
        return {
          structure: "fields",
          of: fields,
          subset
        };
      }
      function consumeField(tokens) {
        var key, types;
        key = consumeIdent(tokens);
        consumeOp(tokens, ":");
        types = consumeTypes(tokens);
        return [key, types];
      }
      function maybeConsumeStructure(tokens) {
        switch (tokens[0]) {
          case "[":
            return consumeArray(tokens);
          case "(":
            return consumeTuple(tokens);
          case "{":
            return consumeFields(tokens);
        }
      }
      function consumeType(tokens) {
        var token, wildcard, type, structure;
        token = peek(tokens);
        wildcard = token === "*";
        if (wildcard || identifierRegex.test(token)) {
          type = wildcard ? consumeOp(tokens, "*") : consumeIdent(tokens);
          structure = maybeConsumeStructure(tokens);
          if (structure) {
            return structure.type = type, structure;
          } else {
            return {
              type
            };
          }
        } else {
          structure = maybeConsumeStructure(tokens);
          if (!structure) {
            throw new Error("Unexpected character: " + token);
          }
          return structure;
        }
      }
      function consumeTypes(tokens) {
        var lookahead, types, typesSoFar, typeObj, type, structure;
        if ("::" === peek(tokens)) {
          throw new Error("No comment before comment separator '::' found.");
        }
        lookahead = tokens[1];
        if (lookahead != null && lookahead === "::") {
          tokens.shift();
          tokens.shift();
        }
        types = [];
        typesSoFar = {};
        if ("Maybe" === peek(tokens)) {
          tokens.shift();
          types = [
            {
              type: "Undefined"
            },
            {
              type: "Null"
            }
          ];
          typesSoFar = {
            Undefined: true,
            Null: true
          };
        }
        for (; ; ) {
          typeObj = consumeType(tokens), type = typeObj.type, structure = typeObj.structure;
          if (!typesSoFar[type]) {
            types.push(typeObj);
          }
          if (structure == null) {
            typesSoFar[type] = true;
          }
          if (!maybeConsumeOp(tokens, "|")) {
            break;
          }
        }
        return types;
      }
      tokenRegex = RegExp("\\.\\.\\.|::|->|" + identifierRegex.source + "|\\S", "g");
      module2.exports = function(input) {
        var tokens, e;
        if (!input.length) {
          throw new Error("No type specified.");
        }
        tokens = input.match(tokenRegex) || [];
        if (in$("->", tokens)) {
          throw new Error("Function types are not supported. To validate that something is a function, you may use 'Function'.");
        }
        try {
          return consumeTypes(tokens);
        } catch (e$) {
          e = e$;
          throw new Error(e.message + " - Remaining tokens: " + JSON.stringify(tokens) + " - Initial input: '" + input + "'");
        }
      };
      function in$(x, xs) {
        var i = -1, l = xs.length >>> 0;
        while (++i < l)
          if (x === xs[i])
            return true;
        return false;
      }
    }).call(exports);
  }
});

// node_modules/type-check/lib/check.js
var require_check = __commonJS({
  "node_modules/type-check/lib/check.js"(exports, module2) {
    (function() {
      var ref$, any, all, isItNaN, types, defaultType, toString$ = {}.toString;
      ref$ = require_lib6(), any = ref$.any, all = ref$.all, isItNaN = ref$.isItNaN;
      types = {
        Number: {
          typeOf: "Number",
          validate: function(it2) {
            return !isItNaN(it2);
          }
        },
        NaN: {
          typeOf: "Number",
          validate: isItNaN
        },
        Int: {
          typeOf: "Number",
          validate: function(it2) {
            return !isItNaN(it2) && it2 % 1 === 0;
          }
        },
        Float: {
          typeOf: "Number",
          validate: function(it2) {
            return !isItNaN(it2);
          }
        },
        Date: {
          typeOf: "Date",
          validate: function(it2) {
            return !isItNaN(it2.getTime());
          }
        }
      };
      defaultType = {
        array: "Array",
        tuple: "Array"
      };
      function checkArray(input, type, options) {
        return all(function(it2) {
          return checkMultiple(it2, type.of, options);
        }, input);
      }
      function checkTuple(input, type, options) {
        var i, i$, ref$2, len$, types2;
        i = 0;
        for (i$ = 0, len$ = (ref$2 = type.of).length; i$ < len$; ++i$) {
          types2 = ref$2[i$];
          if (!checkMultiple(input[i], types2, options)) {
            return false;
          }
          i++;
        }
        return input.length <= i;
      }
      function checkFields(input, type, options) {
        var inputKeys, numInputKeys, k, numOfKeys, key, ref$2, types2;
        inputKeys = {};
        numInputKeys = 0;
        for (k in input) {
          inputKeys[k] = true;
          numInputKeys++;
        }
        numOfKeys = 0;
        for (key in ref$2 = type.of) {
          types2 = ref$2[key];
          if (!checkMultiple(input[key], types2, options)) {
            return false;
          }
          if (inputKeys[key]) {
            numOfKeys++;
          }
        }
        return type.subset || numInputKeys === numOfKeys;
      }
      function checkStructure(input, type, options) {
        if (!(input instanceof Object)) {
          return false;
        }
        switch (type.structure) {
          case "fields":
            return checkFields(input, type, options);
          case "array":
            return checkArray(input, type, options);
          case "tuple":
            return checkTuple(input, type, options);
        }
      }
      function check(input, typeObj, options) {
        var type, structure, setting, that;
        type = typeObj.type, structure = typeObj.structure;
        if (type) {
          if (type === "*") {
            return true;
          }
          setting = options.customTypes[type] || types[type];
          if (setting) {
            return (setting.typeOf === void 0 || setting.typeOf === toString$.call(input).slice(8, -1)) && setting.validate(input);
          } else {
            return type === toString$.call(input).slice(8, -1) && (!structure || checkStructure(input, typeObj, options));
          }
        } else if (structure) {
          if (that = defaultType[structure]) {
            if (that !== toString$.call(input).slice(8, -1)) {
              return false;
            }
          }
          return checkStructure(input, typeObj, options);
        } else {
          throw new Error("No type defined. Input: " + input + ".");
        }
      }
      function checkMultiple(input, types2, options) {
        if (toString$.call(types2).slice(8, -1) !== "Array") {
          throw new Error("Types must be in an array. Input: " + input + ".");
        }
        return any(function(it2) {
          return check(input, it2, options);
        }, types2);
      }
      module2.exports = function(parsedType, input, options) {
        options == null && (options = {});
        if (options.customTypes == null) {
          options.customTypes = {};
        }
        return checkMultiple(input, parsedType, options);
      };
    }).call(exports);
  }
});

// node_modules/type-check/lib/index.js
var require_lib7 = __commonJS({
  "node_modules/type-check/lib/index.js"(exports, module2) {
    (function() {
      var VERSION, parseType, parsedTypeCheck, typeCheck;
      VERSION = "0.4.0";
      parseType = require_parse_type();
      parsedTypeCheck = require_check();
      typeCheck = function(type, input, options) {
        return parsedTypeCheck(parseType(type), input, options);
      };
      module2.exports = {
        VERSION,
        typeCheck,
        parsedTypeCheck,
        parseType
      };
    }).call(exports);
  }
});

// node_modules/levn/lib/cast.js
var require_cast = __commonJS({
  "node_modules/levn/lib/cast.js"(exports, module2) {
    (function() {
      var parsedTypeCheck, types, toString$ = {}.toString;
      parsedTypeCheck = require_lib7().parsedTypeCheck;
      types = {
        "*": function(value2, options) {
          switch (toString$.call(value2).slice(8, -1)) {
            case "Array":
              return typeCast(value2, {
                type: "Array"
              }, options);
            case "Object":
              return typeCast(value2, {
                type: "Object"
              }, options);
            default:
              return {
                type: "Just",
                value: typesCast(value2, [
                  {
                    type: "Undefined"
                  },
                  {
                    type: "Null"
                  },
                  {
                    type: "NaN"
                  },
                  {
                    type: "Boolean"
                  },
                  {
                    type: "Number"
                  },
                  {
                    type: "Date"
                  },
                  {
                    type: "RegExp"
                  },
                  {
                    type: "Array"
                  },
                  {
                    type: "Object"
                  },
                  {
                    type: "String"
                  }
                ], (options.explicit = true, options))
              };
          }
        },
        Undefined: function(it2) {
          if (it2 === "undefined" || it2 === void 0) {
            return {
              type: "Just",
              value: void 0
            };
          } else {
            return {
              type: "Nothing"
            };
          }
        },
        Null: function(it2) {
          if (it2 === "null") {
            return {
              type: "Just",
              value: null
            };
          } else {
            return {
              type: "Nothing"
            };
          }
        },
        NaN: function(it2) {
          if (it2 === "NaN") {
            return {
              type: "Just",
              value: NaN
            };
          } else {
            return {
              type: "Nothing"
            };
          }
        },
        Boolean: function(it2) {
          if (it2 === "true") {
            return {
              type: "Just",
              value: true
            };
          } else if (it2 === "false") {
            return {
              type: "Just",
              value: false
            };
          } else {
            return {
              type: "Nothing"
            };
          }
        },
        Number: function(it2) {
          return {
            type: "Just",
            value: +it2
          };
        },
        Int: function(it2) {
          return {
            type: "Just",
            value: +it2
          };
        },
        Float: function(it2) {
          return {
            type: "Just",
            value: +it2
          };
        },
        Date: function(value2, options) {
          var that;
          if (that = /^\#([\s\S]*)\#$/.exec(value2)) {
            return {
              type: "Just",
              value: new Date(+that[1] || that[1])
            };
          } else if (options.explicit) {
            return {
              type: "Nothing"
            };
          } else {
            return {
              type: "Just",
              value: new Date(+value2 || value2)
            };
          }
        },
        RegExp: function(value2, options) {
          var that;
          if (that = /^\/([\s\S]*)\/([gimy]*)$/.exec(value2)) {
            return {
              type: "Just",
              value: new RegExp(that[1], that[2])
            };
          } else if (options.explicit) {
            return {
              type: "Nothing"
            };
          } else {
            return {
              type: "Just",
              value: new RegExp(value2)
            };
          }
        },
        Array: function(value2, options) {
          return castArray(value2, {
            of: [{
              type: "*"
            }]
          }, options);
        },
        Object: function(value2, options) {
          return castFields(value2, {
            of: {}
          }, options);
        },
        String: function(it2) {
          var replace, that;
          if (toString$.call(it2).slice(8, -1) !== "String") {
            return {
              type: "Nothing"
            };
          }
          replace = function(value2, quote) {
            return value2.replace(/\\([^u]|u[0-9a-fA-F]{4})/g, function(all, escaped) {
              switch (escaped[0]) {
                case quote:
                  return quote;
                case "\\":
                  return "\\";
                case "b":
                  return "\b";
                case "f":
                  return "\f";
                case "n":
                  return "\n";
                case "r":
                  return "\r";
                case "t":
                  return "	";
                case "u":
                  return JSON.parse('"' + all + '"');
                default:
                  return escaped;
              }
            });
          };
          if (that = it2.match(/^'([\s\S]*)'$/)) {
            return {
              type: "Just",
              value: replace(that[1], "'")
            };
          } else if (that = it2.match(/^"([\s\S]*)"$/)) {
            return {
              type: "Just",
              value: replace(that[1], '"')
            };
          } else {
            return {
              type: "Just",
              value: it2
            };
          }
        }
      };
      function castArray(node, type, options) {
        var typeOf, element;
        if (toString$.call(node).slice(8, -1) !== "Array") {
          return {
            type: "Nothing"
          };
        }
        typeOf = type.of;
        return {
          type: "Just",
          value: function() {
            var i$, ref$, len$, results$ = [];
            for (i$ = 0, len$ = (ref$ = node).length; i$ < len$; ++i$) {
              element = ref$[i$];
              results$.push(typesCast(element, typeOf, options));
            }
            return results$;
          }()
        };
      }
      function castTuple(node, type, options) {
        var result, i, i$, ref$, len$, types2, cast;
        if (toString$.call(node).slice(8, -1) !== "Array") {
          return {
            type: "Nothing"
          };
        }
        result = [];
        i = 0;
        for (i$ = 0, len$ = (ref$ = type.of).length; i$ < len$; ++i$) {
          types2 = ref$[i$];
          cast = typesCast(node[i], types2, options);
          if (toString$.call(cast).slice(8, -1) !== "Undefined") {
            result.push(cast);
          }
          i++;
        }
        if (node.length <= i) {
          return {
            type: "Just",
            value: result
          };
        } else {
          return {
            type: "Nothing"
          };
        }
      }
      function castFields(node, type, options) {
        var typeOf, key, value2;
        if (toString$.call(node).slice(8, -1) !== "Object") {
          return {
            type: "Nothing"
          };
        }
        typeOf = type.of;
        return {
          type: "Just",
          value: function() {
            var ref$, resultObj$ = {};
            for (key in ref$ = node) {
              value2 = ref$[key];
              resultObj$[typesCast(key, [{
                type: "String"
              }], options)] = typesCast(value2, typeOf[key] || [{
                type: "*"
              }], options);
            }
            return resultObj$;
          }()
        };
      }
      function typeCast(node, typeObj, options) {
        var type, structure, castFunc, ref$;
        type = typeObj.type, structure = typeObj.structure;
        if (type) {
          castFunc = ((ref$ = options.customTypes[type]) != null ? ref$.cast : void 0) || types[type];
          if (!castFunc) {
            throw new Error("Type not defined: " + type + ".");
          }
          return castFunc(node, options, typesCast);
        } else {
          switch (structure) {
            case "array":
              return castArray(node, typeObj, options);
            case "tuple":
              return castTuple(node, typeObj, options);
            case "fields":
              return castFields(node, typeObj, options);
          }
        }
      }
      function typesCast(node, types2, options) {
        var i$, len$, type, ref$, valueType, value2;
        for (i$ = 0, len$ = types2.length; i$ < len$; ++i$) {
          type = types2[i$];
          ref$ = typeCast(node, type, options), valueType = ref$.type, value2 = ref$.value;
          if (valueType === "Nothing") {
            continue;
          }
          if (parsedTypeCheck([type], value2, {
            customTypes: options.customTypes
          })) {
            return value2;
          }
        }
        throw new Error("Value " + JSON.stringify(node) + " does not type check against " + JSON.stringify(types2) + ".");
      }
      module2.exports = function(node, types2, options) {
        if (!options.explicit && types2.length === 1 && types2[0].type === "String") {
          return node;
        }
        return typesCast(node, types2, options);
      };
    }).call(exports);
  }
});

// node_modules/levn/lib/index.js
var require_lib8 = __commonJS({
  "node_modules/levn/lib/index.js"(exports, module2) {
    (function() {
      var parseString, cast, parseType, VERSION, parsedTypeParse, parse3;
      parseString = require_parse_string();
      cast = require_cast();
      parseType = require_lib7().parseType;
      VERSION = "0.4.1";
      parsedTypeParse = function(parsedType, string, options) {
        options == null && (options = {});
        options.explicit == null && (options.explicit = false);
        options.customTypes == null && (options.customTypes = {});
        return cast(parseString(parsedType, string, options), parsedType, options);
      };
      parse3 = function(type, string, options) {
        return parsedTypeParse(parseType(type), string, options);
      };
      module2.exports = {
        VERSION,
        parse: parse3,
        parsedTypeParse
      };
    }).call(exports);
  }
});

// node_modules/eslint/lib/linter/config-comment-parser.js
var require_config_comment_parser = __commonJS({
  "node_modules/eslint/lib/linter/config-comment-parser.js"(exports, module2) {
    "use strict";
    var levn = require_lib8();
    var {
      Legacy: {
        ConfigOps
      }
    } = require_eslintrc_universal();
    var debug = require_src()("eslint:config-comment-parser");
    module2.exports = class ConfigCommentParser {
      /**
       * Parses a list of "name:string_value" or/and "name" options divided by comma or
       * whitespace. Used for "global" and "exported" comments.
       * @param {string} string The string to parse.
       * @param {Comment} comment The comment node which has the string.
       * @returns {Object} Result map object of names and string values, or null values if no value was provided
       */
      parseStringConfig(string, comment) {
        debug("Parsing String config");
        const items = {};
        const trimmedString = string.replace(/\s*([:,])\s*/gu, "$1");
        trimmedString.split(/\s|,+/u).forEach((name) => {
          if (!name) {
            return;
          }
          const [key, value2 = null] = name.split(":");
          items[key] = { value: value2, comment };
        });
        return items;
      }
      /**
       * Parses a JSON-like config.
       * @param {string} string The string to parse.
       * @param {Object} location Start line and column of comments for potential error message.
       * @returns {({success: true, config: Object}|{success: false, error: Problem})} Result map object
       */
      parseJsonConfig(string, location) {
        debug("Parsing JSON config");
        let items = {};
        try {
          items = levn.parse("Object", string) || {};
          if (ConfigOps.isEverySeverityValid(items)) {
            return {
              success: true,
              config: items
            };
          }
        } catch {
          debug("Levn parsing failed; falling back to manual parsing.");
        }
        items = {};
        const normalizedString = string.replace(/([-a-zA-Z0-9/]+):/gu, '"$1":').replace(/(\]|[0-9])\s+(?=")/u, "$1,");
        try {
          items = JSON.parse(`{${normalizedString}}`);
        } catch (ex) {
          debug("Manual parsing failed.");
          return {
            success: false,
            error: {
              ruleId: null,
              fatal: true,
              severity: 2,
              message: `Failed to parse JSON from '${normalizedString}': ${ex.message}`,
              line: location.start.line,
              column: location.start.column + 1
            }
          };
        }
        return {
          success: true,
          config: items
        };
      }
      /**
       * Parses a config of values separated by comma.
       * @param {string} string The string to parse.
       * @returns {Object} Result map of values and true values
       */
      parseListConfig(string) {
        debug("Parsing list config");
        const items = {};
        string.split(",").forEach((name) => {
          const trimmedName = name.trim();
          if (trimmedName) {
            items[trimmedName] = true;
          }
        });
        return items;
      }
    };
  }
});

// node_modules/eslint/lib/linter/node-event-generator.js
var require_node_event_generator = __commonJS({
  "node_modules/eslint/lib/linter/node-event-generator.js"(exports, module2) {
    "use strict";
    var esquery = require_esquery_min();
    function union(...arrays) {
      return [...new Set(arrays.flat())];
    }
    function intersection(...arrays) {
      if (arrays.length === 0) {
        return [];
      }
      let result = [...new Set(arrays[0])];
      for (const array of arrays.slice(1)) {
        result = result.filter((x) => array.includes(x));
      }
      return result;
    }
    function getPossibleTypes(parsedSelector) {
      switch (parsedSelector.type) {
        case "identifier":
          return [parsedSelector.value];
        case "matches": {
          const typesForComponents = parsedSelector.selectors.map(getPossibleTypes);
          if (typesForComponents.every(Boolean)) {
            return union(...typesForComponents);
          }
          return null;
        }
        case "compound": {
          const typesForComponents = parsedSelector.selectors.map(getPossibleTypes).filter((typesForComponent) => typesForComponent);
          if (!typesForComponents.length) {
            return null;
          }
          return intersection(...typesForComponents);
        }
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return getPossibleTypes(parsedSelector.right);
        case "class":
          if (parsedSelector.name === "function") {
            return ["FunctionDeclaration", "FunctionExpression", "ArrowFunctionExpression"];
          }
          return null;
        default:
          return null;
      }
    }
    function countClassAttributes(parsedSelector) {
      switch (parsedSelector.type) {
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return countClassAttributes(parsedSelector.left) + countClassAttributes(parsedSelector.right);
        case "compound":
        case "not":
        case "matches":
          return parsedSelector.selectors.reduce((sum, childSelector) => sum + countClassAttributes(childSelector), 0);
        case "attribute":
        case "field":
        case "nth-child":
        case "nth-last-child":
          return 1;
        default:
          return 0;
      }
    }
    function countIdentifiers(parsedSelector) {
      switch (parsedSelector.type) {
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return countIdentifiers(parsedSelector.left) + countIdentifiers(parsedSelector.right);
        case "compound":
        case "not":
        case "matches":
          return parsedSelector.selectors.reduce((sum, childSelector) => sum + countIdentifiers(childSelector), 0);
        case "identifier":
          return 1;
        default:
          return 0;
      }
    }
    function compareSpecificity(selectorA, selectorB) {
      return selectorA.attributeCount - selectorB.attributeCount || selectorA.identifierCount - selectorB.identifierCount || (selectorA.rawSelector <= selectorB.rawSelector ? -1 : 1);
    }
    function tryParseSelector(rawSelector) {
      try {
        return esquery.parse(rawSelector.replace(/:exit$/u, ""));
      } catch (err) {
        if (err.location && err.location.start && typeof err.location.start.offset === "number") {
          throw new SyntaxError(`Syntax error in selector "${rawSelector}" at position ${err.location.start.offset}: ${err.message}`);
        }
        throw err;
      }
    }
    var selectorCache = /* @__PURE__ */ new Map();
    function parseSelector(rawSelector) {
      if (selectorCache.has(rawSelector)) {
        return selectorCache.get(rawSelector);
      }
      const parsedSelector = tryParseSelector(rawSelector);
      const result = {
        rawSelector,
        isExit: rawSelector.endsWith(":exit"),
        parsedSelector,
        listenerTypes: getPossibleTypes(parsedSelector),
        attributeCount: countClassAttributes(parsedSelector),
        identifierCount: countIdentifiers(parsedSelector)
      };
      selectorCache.set(rawSelector, result);
      return result;
    }
    var NodeEventGenerator = class {
      /**
       * @param {SafeEmitter} emitter
       * An SafeEmitter which is the destination of events. This emitter must already
       * have registered listeners for all of the events that it needs to listen for.
       * (See lib/linter/safe-emitter.js for more details on `SafeEmitter`.)
       * @param {ESQueryOptions} esqueryOptions `esquery` options for traversing custom nodes.
       * @returns {NodeEventGenerator} new instance
       */
      constructor(emitter, esqueryOptions) {
        this.emitter = emitter;
        this.esqueryOptions = esqueryOptions;
        this.currentAncestry = [];
        this.enterSelectorsByNodeType = /* @__PURE__ */ new Map();
        this.exitSelectorsByNodeType = /* @__PURE__ */ new Map();
        this.anyTypeEnterSelectors = [];
        this.anyTypeExitSelectors = [];
        emitter.eventNames().forEach((rawSelector) => {
          const selector = parseSelector(rawSelector);
          if (selector.listenerTypes) {
            const typeMap = selector.isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType;
            selector.listenerTypes.forEach((nodeType) => {
              if (!typeMap.has(nodeType)) {
                typeMap.set(nodeType, []);
              }
              typeMap.get(nodeType).push(selector);
            });
            return;
          }
          const selectors = selector.isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors;
          selectors.push(selector);
        });
        this.anyTypeEnterSelectors.sort(compareSpecificity);
        this.anyTypeExitSelectors.sort(compareSpecificity);
        this.enterSelectorsByNodeType.forEach((selectorList) => selectorList.sort(compareSpecificity));
        this.exitSelectorsByNodeType.forEach((selectorList) => selectorList.sort(compareSpecificity));
      }
      /**
       * Checks a selector against a node, and emits it if it matches
       * @param {ASTNode} node The node to check
       * @param {ASTSelector} selector An AST selector descriptor
       * @returns {void}
       */
      applySelector(node, selector) {
        if (esquery.matches(node, selector.parsedSelector, this.currentAncestry, this.esqueryOptions)) {
          this.emitter.emit(selector.rawSelector, node);
        }
      }
      /**
       * Applies all appropriate selectors to a node, in specificity order
       * @param {ASTNode} node The node to check
       * @param {boolean} isExit `false` if the node is currently being entered, `true` if it's currently being exited
       * @returns {void}
       */
      applySelectors(node, isExit) {
        const selectorsByNodeType = (isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType).get(node.type) || [];
        const anyTypeSelectors = isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors;
        let selectorsByTypeIndex = 0;
        let anyTypeSelectorsIndex = 0;
        while (selectorsByTypeIndex < selectorsByNodeType.length || anyTypeSelectorsIndex < anyTypeSelectors.length) {
          if (selectorsByTypeIndex >= selectorsByNodeType.length || anyTypeSelectorsIndex < anyTypeSelectors.length && compareSpecificity(anyTypeSelectors[anyTypeSelectorsIndex], selectorsByNodeType[selectorsByTypeIndex]) < 0) {
            this.applySelector(node, anyTypeSelectors[anyTypeSelectorsIndex++]);
          } else {
            this.applySelector(node, selectorsByNodeType[selectorsByTypeIndex++]);
          }
        }
      }
      /**
       * Emits an event of entering AST node.
       * @param {ASTNode} node A node which was entered.
       * @returns {void}
       */
      enterNode(node) {
        if (node.parent) {
          this.currentAncestry.unshift(node.parent);
        }
        this.applySelectors(node, false);
      }
      /**
       * Emits an event of leaving AST node.
       * @param {ASTNode} node A node which was left.
       * @returns {void}
       */
      leaveNode(node) {
        this.applySelectors(node, true);
        this.currentAncestry.shift();
      }
    };
    module2.exports = NodeEventGenerator;
  }
});

// node_modules/eslint/lib/linter/rule-fixer.js
var require_rule_fixer = __commonJS({
  "node_modules/eslint/lib/linter/rule-fixer.js"(exports, module2) {
    "use strict";
    function insertTextAt(index, text) {
      return {
        range: [index, index],
        text
      };
    }
    var ruleFixer = Object.freeze({
      /**
       * Creates a fix command that inserts text after the given node or token.
       * The fix is not applied until applyFixes() is called.
       * @param {ASTNode|Token} nodeOrToken The node or token to insert after.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      insertTextAfter(nodeOrToken, text) {
        return this.insertTextAfterRange(nodeOrToken.range, text);
      },
      /**
       * Creates a fix command that inserts text after the specified range in the source text.
       * The fix is not applied until applyFixes() is called.
       * @param {int[]} range The range to replace, first item is start of range, second
       *      is end of range.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      insertTextAfterRange(range, text) {
        return insertTextAt(range[1], text);
      },
      /**
       * Creates a fix command that inserts text before the given node or token.
       * The fix is not applied until applyFixes() is called.
       * @param {ASTNode|Token} nodeOrToken The node or token to insert before.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      insertTextBefore(nodeOrToken, text) {
        return this.insertTextBeforeRange(nodeOrToken.range, text);
      },
      /**
       * Creates a fix command that inserts text before the specified range in the source text.
       * The fix is not applied until applyFixes() is called.
       * @param {int[]} range The range to replace, first item is start of range, second
       *      is end of range.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      insertTextBeforeRange(range, text) {
        return insertTextAt(range[0], text);
      },
      /**
       * Creates a fix command that replaces text at the node or token.
       * The fix is not applied until applyFixes() is called.
       * @param {ASTNode|Token} nodeOrToken The node or token to remove.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      replaceText(nodeOrToken, text) {
        return this.replaceTextRange(nodeOrToken.range, text);
      },
      /**
       * Creates a fix command that replaces text at the specified range in the source text.
       * The fix is not applied until applyFixes() is called.
       * @param {int[]} range The range to replace, first item is start of range, second
       *      is end of range.
       * @param {string} text The text to insert.
       * @returns {Object} The fix command.
       */
      replaceTextRange(range, text) {
        return {
          range,
          text
        };
      },
      /**
       * Creates a fix command that removes the node or token from the source.
       * The fix is not applied until applyFixes() is called.
       * @param {ASTNode|Token} nodeOrToken The node or token to remove.
       * @returns {Object} The fix command.
       */
      remove(nodeOrToken) {
        return this.removeRange(nodeOrToken.range);
      },
      /**
       * Creates a fix command that removes the specified range of text from the source.
       * The fix is not applied until applyFixes() is called.
       * @param {int[]} range The range to remove, first item is start of range, second
       *      is end of range.
       * @returns {Object} The fix command.
       */
      removeRange(range) {
        return {
          range,
          text: ""
        };
      }
    });
    module2.exports = ruleFixer;
  }
});

// node_modules/eslint/lib/linter/interpolate.js
var require_interpolate = __commonJS({
  "node_modules/eslint/lib/linter/interpolate.js"(exports, module2) {
    "use strict";
    module2.exports = (text, data) => {
      if (!data) {
        return text;
      }
      return text.replace(/\{\{([^{}]+?)\}\}/gu, (fullMatch, termWithWhitespace) => {
        const term = termWithWhitespace.trim();
        if (term in data) {
          return data[term];
        }
        return fullMatch;
      });
    };
  }
});

// node_modules/eslint/lib/linter/report-translator.js
var require_report_translator = __commonJS({
  "node_modules/eslint/lib/linter/report-translator.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var ruleFixer = require_rule_fixer();
    var interpolate = require_interpolate();
    function normalizeMultiArgReportCall(...args) {
      if (args.length === 1) {
        return Object.assign({}, args[0]);
      }
      if (typeof args[1] === "string") {
        return {
          node: args[0],
          message: args[1],
          data: args[2],
          fix: args[3]
        };
      }
      return {
        node: args[0],
        loc: args[1],
        message: args[2],
        data: args[3],
        fix: args[4]
      };
    }
    function assertValidNodeInfo(descriptor) {
      if (descriptor.node) {
        assert(typeof descriptor.node === "object", "Node must be an object");
      } else {
        assert(descriptor.loc, "Node must be provided when reporting error if location is not provided");
      }
    }
    function normalizeReportLoc(descriptor) {
      if (descriptor.loc) {
        if (descriptor.loc.start) {
          return descriptor.loc;
        }
        return { start: descriptor.loc, end: null };
      }
      return descriptor.node.loc;
    }
    function assertValidFix(fix) {
      if (fix) {
        assert(fix.range && typeof fix.range[0] === "number" && typeof fix.range[1] === "number", `Fix has invalid range: ${JSON.stringify(fix, null, 2)}`);
      }
    }
    function compareFixesByRange(a, b) {
      return a.range[0] - b.range[0] || a.range[1] - b.range[1];
    }
    function mergeFixes(fixes, sourceCode) {
      for (const fix of fixes) {
        assertValidFix(fix);
      }
      if (fixes.length === 0) {
        return null;
      }
      if (fixes.length === 1) {
        return fixes[0];
      }
      fixes.sort(compareFixesByRange);
      const originalText = sourceCode.text;
      const start = fixes[0].range[0];
      const end = fixes[fixes.length - 1].range[1];
      let text = "";
      let lastPos = Number.MIN_SAFE_INTEGER;
      for (const fix of fixes) {
        assert(fix.range[0] >= lastPos, "Fix objects must not be overlapped in a report.");
        if (fix.range[0] >= 0) {
          text += originalText.slice(Math.max(0, start, lastPos), fix.range[0]);
        }
        text += fix.text;
        lastPos = fix.range[1];
      }
      text += originalText.slice(Math.max(0, start, lastPos), end);
      return { range: [start, end], text };
    }
    function normalizeFixes(descriptor, sourceCode) {
      if (typeof descriptor.fix !== "function") {
        return null;
      }
      const fix = descriptor.fix(ruleFixer);
      if (fix && Symbol.iterator in fix) {
        return mergeFixes(Array.from(fix), sourceCode);
      }
      assertValidFix(fix);
      return fix;
    }
    function mapSuggestions(descriptor, sourceCode, messages) {
      if (!descriptor.suggest || !Array.isArray(descriptor.suggest)) {
        return [];
      }
      return descriptor.suggest.map((suggestInfo) => {
        const computedDesc = suggestInfo.desc || messages[suggestInfo.messageId];
        return {
          ...suggestInfo,
          desc: interpolate(computedDesc, suggestInfo.data),
          fix: normalizeFixes(suggestInfo, sourceCode)
        };
      }).filter(({ fix }) => fix);
    }
    function createProblem(options) {
      const problem = {
        ruleId: options.ruleId,
        severity: options.severity,
        message: options.message,
        line: options.loc.start.line,
        column: options.loc.start.column + 1,
        nodeType: options.node && options.node.type || null
      };
      if (options.messageId) {
        problem.messageId = options.messageId;
      }
      if (options.loc.end) {
        problem.endLine = options.loc.end.line;
        problem.endColumn = options.loc.end.column + 1;
      }
      if (options.fix) {
        problem.fix = options.fix;
      }
      if (options.suggestions && options.suggestions.length > 0) {
        problem.suggestions = options.suggestions;
      }
      return problem;
    }
    function validateSuggestions(suggest, messages) {
      if (suggest && Array.isArray(suggest)) {
        suggest.forEach((suggestion) => {
          if (suggestion.messageId) {
            const { messageId } = suggestion;
            if (!messages) {
              throw new TypeError(`context.report() called with a suggest option with a messageId '${messageId}', but no messages were present in the rule metadata.`);
            }
            if (!messages[messageId]) {
              throw new TypeError(`context.report() called with a suggest option with a messageId '${messageId}' which is not present in the 'messages' config: ${JSON.stringify(messages, null, 2)}`);
            }
            if (suggestion.desc) {
              throw new TypeError("context.report() called with a suggest option that defines both a 'messageId' and an 'desc'. Please only pass one.");
            }
          } else if (!suggestion.desc) {
            throw new TypeError("context.report() called with a suggest option that doesn't have either a `desc` or `messageId`");
          }
          if (typeof suggestion.fix !== "function") {
            throw new TypeError(`context.report() called with a suggest option without a fix function. See: ${suggestion}`);
          }
        });
      }
    }
    module2.exports = function createReportTranslator(metadata) {
      return (...args) => {
        const descriptor = normalizeMultiArgReportCall(...args);
        const messages = metadata.messageIds;
        assertValidNodeInfo(descriptor);
        let computedMessage;
        if (descriptor.messageId) {
          if (!messages) {
            throw new TypeError("context.report() called with a messageId, but no messages were present in the rule metadata.");
          }
          const id = descriptor.messageId;
          if (descriptor.message) {
            throw new TypeError("context.report() called with a message and a messageId. Please only pass one.");
          }
          if (!messages || !Object.prototype.hasOwnProperty.call(messages, id)) {
            throw new TypeError(`context.report() called with a messageId of '${id}' which is not present in the 'messages' config: ${JSON.stringify(messages, null, 2)}`);
          }
          computedMessage = messages[id];
        } else if (descriptor.message) {
          computedMessage = descriptor.message;
        } else {
          throw new TypeError("Missing `message` property in report() call; add a message that describes the linting problem.");
        }
        validateSuggestions(descriptor.suggest, messages);
        return createProblem({
          ruleId: metadata.ruleId,
          severity: metadata.severity,
          node: descriptor.node,
          message: interpolate(computedMessage, descriptor.data),
          messageId: descriptor.messageId,
          loc: normalizeReportLoc(descriptor),
          fix: metadata.disableFixes ? null : normalizeFixes(descriptor, metadata.sourceCode),
          suggestions: metadata.disableFixes ? [] : mapSuggestions(descriptor, metadata.sourceCode, messages)
        });
      };
    };
  }
});

// node_modules/eslint/lib/linter/rules.js
var require_rules3 = __commonJS({
  "node_modules/eslint/lib/linter/rules.js"(exports, module2) {
    "use strict";
    var builtInRules = require_rules2();
    function normalizeRule(rule) {
      return typeof rule === "function" ? Object.assign({ create: rule }, rule) : rule;
    }
    var Rules = class {
      constructor() {
        this._rules = /* @__PURE__ */ Object.create(null);
      }
      /**
       * Registers a rule module for rule id in storage.
       * @param {string} ruleId Rule id (file name).
       * @param {Function} ruleModule Rule handler.
       * @returns {void}
       */
      define(ruleId, ruleModule) {
        this._rules[ruleId] = normalizeRule(ruleModule);
      }
      /**
       * Access rule handler by id (file name).
       * @param {string} ruleId Rule id (file name).
       * @returns {{create: Function, schema: JsonSchema[]}}
       * A rule. This is normalized to always have the new-style shape with a `create` method.
       */
      get(ruleId) {
        if (typeof this._rules[ruleId] === "string") {
          this.define(ruleId, require(this._rules[ruleId]));
        }
        if (this._rules[ruleId]) {
          return this._rules[ruleId];
        }
        if (builtInRules.has(ruleId)) {
          return builtInRules.get(ruleId);
        }
        return null;
      }
      *[Symbol.iterator]() {
        yield* builtInRules;
        for (const ruleId of Object.keys(this._rules)) {
          yield [ruleId, this.get(ruleId)];
        }
      }
    };
    module2.exports = Rules;
  }
});

// node_modules/eslint/lib/linter/safe-emitter.js
var require_safe_emitter = __commonJS({
  "node_modules/eslint/lib/linter/safe-emitter.js"(exports, module2) {
    "use strict";
    module2.exports = () => {
      const listeners = /* @__PURE__ */ Object.create(null);
      return Object.freeze({
        on(eventName, listener) {
          if (eventName in listeners) {
            listeners[eventName].push(listener);
          } else {
            listeners[eventName] = [listener];
          }
        },
        emit(eventName, ...args) {
          if (eventName in listeners) {
            listeners[eventName].forEach((listener) => listener(...args));
          }
        },
        eventNames() {
          return Object.keys(listeners);
        }
      });
    };
  }
});

// node_modules/eslint/lib/linter/source-code-fixer.js
var require_source_code_fixer = __commonJS({
  "node_modules/eslint/lib/linter/source-code-fixer.js"(exports, module2) {
    "use strict";
    var debug = require_src()("eslint:source-code-fixer");
    var BOM = "\uFEFF";
    function compareMessagesByFixRange(a, b) {
      return a.fix.range[0] - b.fix.range[0] || a.fix.range[1] - b.fix.range[1];
    }
    function compareMessagesByLocation(a, b) {
      return a.line - b.line || a.column - b.column;
    }
    function SourceCodeFixer() {
      Object.freeze(this);
    }
    SourceCodeFixer.applyFixes = function(sourceText, messages, shouldFix) {
      debug("Applying fixes");
      if (shouldFix === false) {
        debug("shouldFix parameter was false, not attempting fixes");
        return {
          fixed: false,
          messages,
          output: sourceText
        };
      }
      const remainingMessages = [], fixes = [], bom = sourceText.startsWith(BOM) ? BOM : "", text = bom ? sourceText.slice(1) : sourceText;
      let lastPos = Number.NEGATIVE_INFINITY, output = bom;
      function attemptFix(problem) {
        const fix = problem.fix;
        const start = fix.range[0];
        const end = fix.range[1];
        if (lastPos >= start || start > end) {
          remainingMessages.push(problem);
          return false;
        }
        if (start < 0 && end >= 0 || start === 0 && fix.text.startsWith(BOM)) {
          output = "";
        }
        output += text.slice(Math.max(0, lastPos), Math.max(0, start));
        output += fix.text;
        lastPos = end;
        return true;
      }
      messages.forEach((problem) => {
        if (Object.prototype.hasOwnProperty.call(problem, "fix")) {
          fixes.push(problem);
        } else {
          remainingMessages.push(problem);
        }
      });
      if (fixes.length) {
        debug("Found fixes to apply");
        let fixesWereApplied = false;
        for (const problem of fixes.sort(compareMessagesByFixRange)) {
          if (typeof shouldFix !== "function" || shouldFix(problem)) {
            attemptFix(problem);
            fixesWereApplied = true;
          } else {
            remainingMessages.push(problem);
          }
        }
        output += text.slice(Math.max(0, lastPos));
        return {
          fixed: fixesWereApplied,
          messages: remainingMessages.sort(compareMessagesByLocation),
          output
        };
      }
      debug("No fixes to apply");
      return {
        fixed: false,
        messages,
        output: bom + text
      };
    };
    module2.exports = SourceCodeFixer;
  }
});

// node_modules/eslint/lib/linter/timing.js
var require_timing = __commonJS({
  "node_modules/eslint/lib/linter/timing.js"(exports, module2) {
    "use strict";
    function alignLeft(str, len, ch) {
      return str + new Array(len - str.length + 1).join(ch || " ");
    }
    function alignRight(str, len, ch) {
      return new Array(len - str.length + 1).join(ch || " ") + str;
    }
    var enabled = !!process.env.TIMING;
    var HEADERS = ["Rule", "Time (ms)", "Relative"];
    var ALIGN = [alignLeft, alignRight, alignRight];
    function getListSize() {
      const MINIMUM_SIZE = 10;
      if (typeof process.env.TIMING !== "string") {
        return MINIMUM_SIZE;
      }
      if (process.env.TIMING.toLowerCase() === "all") {
        return Number.POSITIVE_INFINITY;
      }
      const TIMING_ENV_VAR_AS_INTEGER = Number.parseInt(process.env.TIMING, 10);
      return TIMING_ENV_VAR_AS_INTEGER > 10 ? TIMING_ENV_VAR_AS_INTEGER : MINIMUM_SIZE;
    }
    function display(data) {
      let total = 0;
      const rows = Object.keys(data).map((key) => {
        const time = data[key];
        total += time;
        return [key, time];
      }).sort((a, b) => b[1] - a[1]).slice(0, getListSize());
      rows.forEach((row) => {
        row.push(`${(row[1] * 100 / total).toFixed(1)}%`);
        row[1] = row[1].toFixed(3);
      });
      rows.unshift(HEADERS);
      const widths = [];
      rows.forEach((row) => {
        const len = row.length;
        for (let i = 0; i < len; i++) {
          const n = row[i].length;
          if (!widths[i] || n > widths[i]) {
            widths[i] = n;
          }
        }
      });
      const table = rows.map((row) => row.map((cell, index) => ALIGN[index](cell, widths[index])).join(" | "));
      table.splice(1, 0, widths.map((width, index) => {
        const extraAlignment = index !== 0 && index !== widths.length - 1 ? 2 : 1;
        return ALIGN[index](":", width + extraAlignment, "-");
      }).join("|"));
      console.log(table.join("\n"));
    }
    module2.exports = function() {
      const data = /* @__PURE__ */ Object.create(null);
      function time(key, fn) {
        if (typeof data[key] === "undefined") {
          data[key] = 0;
        }
        return function(...args) {
          let t3 = process.hrtime();
          const result = fn(...args);
          t3 = process.hrtime(t3);
          data[key] += t3[0] * 1e3 + t3[1] / 1e6;
          return result;
        };
      }
      if (enabled) {
        process.on("exit", () => {
          display(data);
        });
      }
      return {
        time,
        enabled,
        getListSize
      };
    }();
  }
});

// node_modules/eslint/conf/replacements.json
var require_replacements = __commonJS({
  "node_modules/eslint/conf/replacements.json"(exports, module2) {
    module2.exports = {
      rules: {
        "generator-star": ["generator-star-spacing"],
        "global-strict": ["strict"],
        "no-arrow-condition": ["no-confusing-arrow", "no-constant-condition"],
        "no-comma-dangle": ["comma-dangle"],
        "no-empty-class": ["no-empty-character-class"],
        "no-empty-label": ["no-labels"],
        "no-extra-strict": ["strict"],
        "no-reserved-keys": ["quote-props"],
        "no-space-before-semi": ["semi-spacing"],
        "no-wrap-func": ["no-extra-parens"],
        "space-after-function-name": ["space-before-function-paren"],
        "space-after-keywords": ["keyword-spacing"],
        "space-before-function-parentheses": ["space-before-function-paren"],
        "space-before-keywords": ["keyword-spacing"],
        "space-in-brackets": ["object-curly-spacing", "array-bracket-spacing", "computed-property-spacing"],
        "space-return-throw-case": ["keyword-spacing"],
        "space-unary-word-ops": ["space-unary-ops"],
        "spaced-line-comment": ["spaced-comment"]
      }
    };
  }
});

// node_modules/eslint/lib/config/flat-config-helpers.js
var require_flat_config_helpers = __commonJS({
  "node_modules/eslint/lib/config/flat-config-helpers.js"(exports, module2) {
    "use strict";
    function parseRuleId(ruleId) {
      let pluginName, ruleName;
      if (ruleId.includes("/")) {
        if (ruleId.startsWith("@")) {
          pluginName = ruleId.slice(0, ruleId.lastIndexOf("/"));
        } else {
          pluginName = ruleId.slice(0, ruleId.indexOf("/"));
        }
        ruleName = ruleId.slice(pluginName.length + 1);
      } else {
        pluginName = "@";
        ruleName = ruleId;
      }
      return {
        pluginName,
        ruleName
      };
    }
    function getRuleFromConfig(ruleId, config) {
      const { pluginName, ruleName } = parseRuleId(ruleId);
      const plugin = config.plugins && config.plugins[pluginName];
      let rule = plugin && plugin.rules && plugin.rules[ruleName];
      if (rule && typeof rule === "function") {
        rule = {
          create: rule
        };
      }
      return rule;
    }
    function getRuleOptionsSchema(rule) {
      if (!rule) {
        return null;
      }
      const schema = rule.schema || rule.meta && rule.meta.schema;
      if (Array.isArray(schema)) {
        if (schema.length) {
          return {
            type: "array",
            items: schema,
            minItems: 0,
            maxItems: schema.length
          };
        }
        return {
          type: "array",
          minItems: 0,
          maxItems: 0
        };
      }
      return schema || null;
    }
    module2.exports = {
      parseRuleId,
      getRuleFromConfig,
      getRuleOptionsSchema
    };
  }
});

// node_modules/@humanwhocodes/object-schema/src/merge-strategy.js
var require_merge_strategy = __commonJS({
  "node_modules/@humanwhocodes/object-schema/src/merge-strategy.js"(exports) {
    "use strict";
    var MergeStrategy = class {
      /**
       * Merges two keys by overwriting the first with the second.
       * @param {*} value1 The value from the first object key. 
       * @param {*} value2 The value from the second object key.
       * @returns {*} The second value.
       */
      static overwrite(value1, value2) {
        return value2;
      }
      /**
       * Merges two keys by replacing the first with the second only if the
       * second is defined.
       * @param {*} value1 The value from the first object key. 
       * @param {*} value2 The value from the second object key.
       * @returns {*} The second value if it is defined.
       */
      static replace(value1, value2) {
        if (typeof value2 !== "undefined") {
          return value2;
        }
        return value1;
      }
      /**
       * Merges two properties by assigning properties from the second to the first.
       * @param {*} value1 The value from the first object key.
       * @param {*} value2 The value from the second object key.
       * @returns {*} A new object containing properties from both value1 and
       *      value2.
       */
      static assign(value1, value2) {
        return Object.assign({}, value1, value2);
      }
    };
    exports.MergeStrategy = MergeStrategy;
  }
});

// node_modules/@humanwhocodes/object-schema/src/validation-strategy.js
var require_validation_strategy = __commonJS({
  "node_modules/@humanwhocodes/object-schema/src/validation-strategy.js"(exports) {
    "use strict";
    var ValidationStrategy = class {
      /**
       * Validates that a value is an array.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static array(value2) {
        if (!Array.isArray(value2)) {
          throw new TypeError("Expected an array.");
        }
      }
      /**
       * Validates that a value is a boolean.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static boolean(value2) {
        if (typeof value2 !== "boolean") {
          throw new TypeError("Expected a Boolean.");
        }
      }
      /**
       * Validates that a value is a number.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static number(value2) {
        if (typeof value2 !== "number") {
          throw new TypeError("Expected a number.");
        }
      }
      /**
       * Validates that a value is a object.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static object(value2) {
        if (!value2 || typeof value2 !== "object") {
          throw new TypeError("Expected an object.");
        }
      }
      /**
       * Validates that a value is a object or null.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static "object?"(value2) {
        if (typeof value2 !== "object") {
          throw new TypeError("Expected an object or null.");
        }
      }
      /**
       * Validates that a value is a string.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static string(value2) {
        if (typeof value2 !== "string") {
          throw new TypeError("Expected a string.");
        }
      }
      /**
       * Validates that a value is a non-empty string.
       * @param {*} value The value to validate.
       * @returns {void}
       * @throws {TypeError} If the value is invalid. 
       */
      static "string!"(value2) {
        if (typeof value2 !== "string" || value2.length === 0) {
          throw new TypeError("Expected a non-empty string.");
        }
      }
    };
    exports.ValidationStrategy = ValidationStrategy;
  }
});

// node_modules/@humanwhocodes/object-schema/src/object-schema.js
var require_object_schema = __commonJS({
  "node_modules/@humanwhocodes/object-schema/src/object-schema.js"(exports) {
    "use strict";
    var { MergeStrategy } = require_merge_strategy();
    var { ValidationStrategy } = require_validation_strategy();
    var strategies = Symbol("strategies");
    var requiredKeys = Symbol("requiredKeys");
    function validateDefinition(name, strategy) {
      let hasSchema = false;
      if (strategy.schema) {
        if (typeof strategy.schema === "object") {
          hasSchema = true;
        } else {
          throw new TypeError("Schema must be an object.");
        }
      }
      if (typeof strategy.merge === "string") {
        if (!(strategy.merge in MergeStrategy)) {
          throw new TypeError(`Definition for key "${name}" missing valid merge strategy.`);
        }
      } else if (!hasSchema && typeof strategy.merge !== "function") {
        throw new TypeError(`Definition for key "${name}" must have a merge property.`);
      }
      if (typeof strategy.validate === "string") {
        if (!(strategy.validate in ValidationStrategy)) {
          throw new TypeError(`Definition for key "${name}" missing valid validation strategy.`);
        }
      } else if (!hasSchema && typeof strategy.validate !== "function") {
        throw new TypeError(`Definition for key "${name}" must have a validate() method.`);
      }
    }
    var ObjectSchema = class _ObjectSchema {
      /**
       * Creates a new instance.
       */
      constructor(definitions) {
        if (!definitions) {
          throw new Error("Schema definitions missing.");
        }
        this[strategies] = /* @__PURE__ */ new Map();
        this[requiredKeys] = /* @__PURE__ */ new Map();
        for (const key of Object.keys(definitions)) {
          validateDefinition(key, definitions[key]);
          if (typeof definitions[key].schema === "object") {
            const schema = new _ObjectSchema(definitions[key].schema);
            definitions[key] = {
              ...definitions[key],
              merge(first2 = {}, second = {}) {
                return schema.merge(first2, second);
              },
              validate(value2) {
                ValidationStrategy.object(value2);
                schema.validate(value2);
              }
            };
          }
          if (typeof definitions[key].merge === "string") {
            definitions[key] = {
              ...definitions[key],
              merge: MergeStrategy[definitions[key].merge]
            };
          }
          ;
          if (typeof definitions[key].validate === "string") {
            definitions[key] = {
              ...definitions[key],
              validate: ValidationStrategy[definitions[key].validate]
            };
          }
          ;
          this[strategies].set(key, definitions[key]);
          if (definitions[key].required) {
            this[requiredKeys].set(key, definitions[key]);
          }
        }
      }
      /**
       * Determines if a strategy has been registered for the given object key.
       * @param {string} key The object key to find a strategy for.
       * @returns {boolean} True if the key has a strategy registered, false if not. 
       */
      hasKey(key) {
        return this[strategies].has(key);
      }
      /**
       * Merges objects together to create a new object comprised of the keys
       * of the all objects. Keys are merged based on the each key's merge
       * strategy.
       * @param {...Object} objects The objects to merge.
       * @returns {Object} A new object with a mix of all objects' keys.
       * @throws {Error} If any object is invalid.
       */
      merge(...objects) {
        if (objects.length < 2) {
          throw new Error("merge() requires at least two arguments.");
        }
        if (objects.some((object) => object == null || typeof object !== "object")) {
          throw new Error("All arguments must be objects.");
        }
        return objects.reduce((result, object) => {
          this.validate(object);
          for (const [key, strategy] of this[strategies]) {
            try {
              if (key in result || key in object) {
                const value2 = strategy.merge.call(this, result[key], object[key]);
                if (value2 !== void 0) {
                  result[key] = value2;
                }
              }
            } catch (ex) {
              ex.message = `Key "${key}": ` + ex.message;
              throw ex;
            }
          }
          return result;
        }, {});
      }
      /**
       * Validates an object's keys based on the validate strategy for each key.
       * @param {Object} object The object to validate.
       * @returns {void}
       * @throws {Error} When the object is invalid. 
       */
      validate(object) {
        for (const key of Object.keys(object)) {
          if (!this.hasKey(key)) {
            throw new Error(`Unexpected key "${key}" found.`);
          }
          const strategy = this[strategies].get(key);
          if (Array.isArray(strategy.requires)) {
            if (!strategy.requires.every((otherKey) => otherKey in object)) {
              throw new Error(`Key "${key}" requires keys "${strategy.requires.join('", "')}".`);
            }
          }
          try {
            strategy.validate.call(strategy, object[key]);
          } catch (ex) {
            ex.message = `Key "${key}": ` + ex.message;
            throw ex;
          }
        }
        for (const [key] of this[requiredKeys]) {
          if (!(key in object)) {
            throw new Error(`Missing required key "${key}".`);
          }
        }
      }
    };
    exports.ObjectSchema = ObjectSchema;
  }
});

// node_modules/@humanwhocodes/object-schema/src/index.js
var require_src2 = __commonJS({
  "node_modules/@humanwhocodes/object-schema/src/index.js"(exports) {
    exports.ObjectSchema = require_object_schema().ObjectSchema;
    exports.MergeStrategy = require_merge_strategy().MergeStrategy;
    exports.ValidationStrategy = require_validation_strategy().ValidationStrategy;
  }
});

// node_modules/@humanwhocodes/config-array/api.js
var require_api = __commonJS({
  "node_modules/@humanwhocodes/config-array/api.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function _interopDefault(ex) {
      return ex && typeof ex === "object" && "default" in ex ? ex["default"] : ex;
    }
    var path2 = _interopDefault(require("path"));
    var minimatch = _interopDefault(require_minimatch());
    var createDebug = _interopDefault(require_src());
    var objectSchema = require_src2();
    function assertIsArray(value2) {
      if (!Array.isArray(value2)) {
        throw new TypeError("Expected value to be an array.");
      }
    }
    function assertIsArrayOfStringsAndFunctions(value2, name) {
      assertIsArray(value2);
      if (value2.some((item) => typeof item !== "string" && typeof item !== "function")) {
        throw new TypeError("Expected array to only contain strings.");
      }
    }
    var baseSchema = Object.freeze({
      name: {
        required: false,
        merge() {
          return void 0;
        },
        validate(value2) {
          if (typeof value2 !== "string") {
            throw new TypeError("Property must be a string.");
          }
        }
      },
      files: {
        required: false,
        merge() {
          return void 0;
        },
        validate(value2) {
          assertIsArray(value2);
          value2.forEach((item) => {
            if (Array.isArray(item)) {
              assertIsArrayOfStringsAndFunctions(item);
            } else if (typeof item !== "string" && typeof item !== "function") {
              throw new TypeError("Items must be a string, a function, or an array of strings and functions.");
            }
          });
        }
      },
      ignores: {
        required: false,
        merge() {
          return void 0;
        },
        validate: assertIsArrayOfStringsAndFunctions
      }
    });
    var Minimatch = minimatch.Minimatch;
    var minimatchCache = /* @__PURE__ */ new Map();
    var negatedMinimatchCache = /* @__PURE__ */ new Map();
    var debug = createDebug("@hwc/config-array");
    var MINIMATCH_OPTIONS = {
      // matchBase: true,
      dot: true
    };
    var CONFIG_TYPES = /* @__PURE__ */ new Set(["array", "function"]);
    function isString(value2) {
      return typeof value2 === "string";
    }
    function assertNonEmptyFilesArray(config) {
      if (!Array.isArray(config.files) || config.files.length === 0) {
        throw new TypeError("The files key must be a non-empty array.");
      }
    }
    function doMatch(filepath, pattern, options = {}) {
      let cache = minimatchCache;
      if (options.flipNegate) {
        cache = negatedMinimatchCache;
      }
      let matcher = cache.get(pattern);
      if (!matcher) {
        matcher = new Minimatch(pattern, Object.assign({}, MINIMATCH_OPTIONS, options));
        cache.set(pattern, matcher);
      }
      return matcher.match(filepath);
    }
    async function normalize(items, context, extraConfigTypes) {
      const allowFunctions = extraConfigTypes.includes("function");
      const allowArrays = extraConfigTypes.includes("array");
      async function* flatTraverse(array) {
        for (let item of array) {
          if (typeof item === "function") {
            if (!allowFunctions) {
              throw new TypeError("Unexpected function.");
            }
            item = item(context);
            if (item.then) {
              item = await item;
            }
          }
          if (Array.isArray(item)) {
            if (!allowArrays) {
              throw new TypeError("Unexpected array.");
            }
            yield* flatTraverse(item);
          } else if (typeof item === "function") {
            throw new TypeError("A config function can only return an object or array.");
          } else {
            yield item;
          }
        }
      }
      const asyncIterable = await flatTraverse(items);
      const configs = [];
      for await (const config of asyncIterable) {
        configs.push(config);
      }
      return configs;
    }
    function normalizeSync(items, context, extraConfigTypes) {
      const allowFunctions = extraConfigTypes.includes("function");
      const allowArrays = extraConfigTypes.includes("array");
      function* flatTraverse(array) {
        for (let item of array) {
          if (typeof item === "function") {
            if (!allowFunctions) {
              throw new TypeError("Unexpected function.");
            }
            item = item(context);
            if (item.then) {
              throw new TypeError("Async config functions are not supported.");
            }
          }
          if (Array.isArray(item)) {
            if (!allowArrays) {
              throw new TypeError("Unexpected array.");
            }
            yield* flatTraverse(item);
          } else if (typeof item === "function") {
            throw new TypeError("A config function can only return an object or array.");
          } else {
            yield item;
          }
        }
      }
      return [...flatTraverse(items)];
    }
    function shouldIgnorePath(ignores, filePath, relativeFilePath) {
      if (relativeFilePath.startsWith("..")) {
        return true;
      }
      return ignores.reduce((ignored, matcher) => {
        if (!ignored) {
          if (typeof matcher === "function") {
            return matcher(filePath);
          }
          if (!matcher.startsWith("!")) {
            return doMatch(relativeFilePath, matcher);
          }
          return false;
        }
        if (typeof matcher === "string" && matcher.startsWith("!")) {
          return !doMatch(relativeFilePath, matcher, {
            flipNegate: true
          });
        }
        return ignored;
      }, false);
    }
    function pathMatches(filePath, basePath, config) {
      const relativeFilePath = path2.relative(basePath, filePath);
      assertNonEmptyFilesArray(config);
      const match = (pattern) => {
        if (isString(pattern)) {
          return doMatch(relativeFilePath, pattern);
        }
        if (typeof pattern === "function") {
          return pattern(filePath);
        }
        throw new TypeError(`Unexpected matcher type ${pattern}.`);
      };
      let filePathMatchesPattern = config.files.some((pattern) => {
        if (Array.isArray(pattern)) {
          return pattern.every(match);
        }
        return match(pattern);
      });
      if (filePathMatchesPattern && config.ignores) {
        filePathMatchesPattern = !shouldIgnorePath(config.ignores, filePath, relativeFilePath);
      }
      return filePathMatchesPattern;
    }
    function assertNormalized(configArray) {
      if (!configArray.isNormalized()) {
        throw new Error("ConfigArray must be normalized to perform this operation.");
      }
    }
    function assertExtraConfigTypes(extraConfigTypes) {
      if (extraConfigTypes.length > 2) {
        throw new TypeError("configTypes must be an array with at most two items.");
      }
      for (const configType of extraConfigTypes) {
        if (!CONFIG_TYPES.has(configType)) {
          throw new TypeError(`Unexpected config type "${configType}" found. Expected one of: "object", "array", "function".`);
        }
      }
    }
    var ConfigArraySymbol = {
      isNormalized: Symbol("isNormalized"),
      configCache: Symbol("configCache"),
      schema: Symbol("schema"),
      finalizeConfig: Symbol("finalizeConfig"),
      preprocessConfig: Symbol("preprocessConfig")
    };
    var dataCache = /* @__PURE__ */ new WeakMap();
    var ConfigArray = class extends Array {
      /**
       * Creates a new instance of ConfigArray.
       * @param {Iterable|Function|Object} configs An iterable yielding config
       *      objects, or a config function, or a config object.
       * @param {string} [options.basePath=""] The path of the config file
       * @param {boolean} [options.normalized=false] Flag indicating if the
       *      configs have already been normalized.
       * @param {Object} [options.schema] The additional schema 
       *      definitions to use for the ConfigArray schema.
       * @param {Array<string>} [options.configTypes] List of config types supported.
       */
      constructor(configs, {
        basePath = "",
        normalized = false,
        schema: customSchema,
        extraConfigTypes = []
      } = {}) {
        super();
        this[ConfigArraySymbol.isNormalized] = normalized;
        this[ConfigArraySymbol.schema] = new objectSchema.ObjectSchema(
          Object.assign({}, customSchema, baseSchema)
        );
        this.basePath = basePath;
        assertExtraConfigTypes(extraConfigTypes);
        this.extraConfigTypes = Object.freeze([...extraConfigTypes]);
        this[ConfigArraySymbol.configCache] = /* @__PURE__ */ new Map();
        dataCache.set(this, {
          explicitMatches: /* @__PURE__ */ new Map(),
          directoryMatches: /* @__PURE__ */ new Map(),
          files: void 0,
          ignores: void 0
        });
        if (Array.isArray(configs)) {
          this.push(...configs);
        } else {
          this.push(configs);
        }
      }
      /**
       * Prevent normal array methods from creating a new `ConfigArray` instance.
       * This is to ensure that methods such as `slice()` won't try to create a 
       * new instance of `ConfigArray` behind the scenes as doing so may throw
       * an error due to the different constructor signature.
       * @returns {Function} The `Array` constructor.
       */
      static get [Symbol.species]() {
        return Array;
      }
      /**
       * Returns the `files` globs from every config object in the array.
       * This can be used to determine which files will be matched by a
       * config array or to use as a glob pattern when no patterns are provided
       * for a command line interface.
       * @returns {Array<string|Function>} An array of matchers.
       */
      get files() {
        assertNormalized(this);
        const cache = dataCache.get(this);
        if (cache.files) {
          return cache.files;
        }
        const result = [];
        for (const config of this) {
          if (config.files) {
            config.files.forEach((filePattern) => {
              result.push(filePattern);
            });
          }
        }
        cache.files = result;
        dataCache.set(this, cache);
        return result;
      }
      /**
       * Returns ignore matchers that should always be ignored regardless of
       * the matching `files` fields in any configs. This is necessary to mimic
       * the behavior of things like .gitignore and .eslintignore, allowing a
       * globbing operation to be faster.
       * @returns {string[]} An array of string patterns and functions to be ignored.
       */
      get ignores() {
        assertNormalized(this);
        const cache = dataCache.get(this);
        if (cache.ignores) {
          return cache.ignores;
        }
        const result = [];
        for (const config of this) {
          if (config.ignores && Object.keys(config).length === 1) {
            config.ignores.forEach((ignore) => {
              result.push(ignore);
              if (typeof ignore === "string") {
                if (ignore.startsWith("!")) {
                  if (ignore.endsWith("/**")) {
                    result.push(ignore.slice(0, ignore.length - 3));
                  } else if (ignore.endsWith("/*")) {
                    result.push(ignore.slice(0, ignore.length - 2));
                  }
                }
                if (ignore.endsWith("/")) {
                  result.push(ignore.slice(0, ignore.length - 1));
                  result.push(ignore + "**");
                } else if (!ignore.endsWith("*")) {
                  result.push(ignore + "/**");
                }
              }
            });
          }
        }
        cache.ignores = result;
        dataCache.set(this, cache);
        return result;
      }
      /**
       * Indicates if the config array has been normalized.
       * @returns {boolean} True if the config array is normalized, false if not.
       */
      isNormalized() {
        return this[ConfigArraySymbol.isNormalized];
      }
      /**
       * Normalizes a config array by flattening embedded arrays and executing
       * config functions.
       * @param {ConfigContext} context The context object for config functions.
       * @returns {Promise<ConfigArray>} The current ConfigArray instance.
       */
      async normalize(context = {}) {
        if (!this.isNormalized()) {
          const normalizedConfigs = await normalize(this, context, this.extraConfigTypes);
          this.length = 0;
          this.push(...normalizedConfigs.map(this[ConfigArraySymbol.preprocessConfig].bind(this)));
          this[ConfigArraySymbol.isNormalized] = true;
          Object.freeze(this);
        }
        return this;
      }
      /**
       * Normalizes a config array by flattening embedded arrays and executing
       * config functions.
       * @param {ConfigContext} context The context object for config functions.
       * @returns {ConfigArray} The current ConfigArray instance.
       */
      normalizeSync(context = {}) {
        if (!this.isNormalized()) {
          const normalizedConfigs = normalizeSync(this, context, this.extraConfigTypes);
          this.length = 0;
          this.push(...normalizedConfigs.map(this[ConfigArraySymbol.preprocessConfig].bind(this)));
          this[ConfigArraySymbol.isNormalized] = true;
          Object.freeze(this);
        }
        return this;
      }
      /**
       * Finalizes the state of a config before being cached and returned by
       * `getConfig()`. Does nothing by default but is provided to be
       * overridden by subclasses as necessary.
       * @param {Object} config The config to finalize.
       * @returns {Object} The finalized config.
       */
      [ConfigArraySymbol.finalizeConfig](config) {
        return config;
      }
      /**
       * Preprocesses a config during the normalization process. This is the
       * method to override if you want to convert an array item before it is
       * validated for the first time. For example, if you want to replace a
       * string with an object, this is the method to override.
       * @param {Object} config The config to preprocess.
       * @returns {Object} The config to use in place of the argument.
       */
      [ConfigArraySymbol.preprocessConfig](config) {
        return config;
      }
      /**
       * Determines if a given file path explicitly matches a `files` entry
       * and also doesn't match an `ignores` entry. Configs that don't have
       * a `files` property are not considered an explicit match.
       * @param {string} filePath The complete path of a file to check.
       * @returns {boolean} True if the file path matches a `files` entry
       * 		or false if not.
       */
      isExplicitMatch(filePath) {
        assertNormalized(this);
        const cache = dataCache.get(this);
        let result = cache.explicitMatches.get(filePath);
        if (typeof result == "boolean") {
          return result;
        }
        const relativeFilePath = path2.relative(this.basePath, filePath);
        if (shouldIgnorePath(this.ignores, filePath, relativeFilePath)) {
          debug(`Ignoring ${filePath}`);
          cache.explicitMatches.set(filePath, false);
          return false;
        }
        for (const config of this) {
          if (!config.files) {
            continue;
          }
          if (pathMatches(filePath, this.basePath, config)) {
            debug(`Matching config found for ${filePath}`);
            cache.explicitMatches.set(filePath, true);
            return true;
          }
        }
        return false;
      }
      /**
       * Returns the config object for a given file path.
       * @param {string} filePath The complete path of a file to get a config for.
       * @returns {Object} The config object for this file.
       */
      getConfig(filePath) {
        assertNormalized(this);
        const cache = this[ConfigArraySymbol.configCache];
        let finalConfig = cache.get(filePath);
        if (finalConfig) {
          return finalConfig;
        }
        if (this.isDirectoryIgnored(path2.dirname(filePath))) {
          debug(`Ignoring ${filePath} based on directory pattern`);
          cache.set(filePath, finalConfig);
          return finalConfig;
        }
        const relativeFilePath = path2.relative(this.basePath, filePath);
        if (shouldIgnorePath(this.ignores, filePath, relativeFilePath)) {
          debug(`Ignoring ${filePath} based on file pattern`);
          cache.set(filePath, finalConfig);
          return finalConfig;
        }
        const matchingConfigIndices = [];
        let matchFound = false;
        const universalPattern = /\/\*{1,2}$/;
        this.forEach((config, index) => {
          if (!config.files) {
            debug(`Anonymous universal config found for ${filePath}`);
            matchingConfigIndices.push(index);
            return;
          }
          assertNonEmptyFilesArray(config);
          const universalFiles = config.files.filter(
            (pattern) => universalPattern.test(pattern)
          );
          if (universalFiles.length) {
            debug("Universal files patterns found. Checking carefully.");
            const nonUniversalFiles = config.files.filter(
              (pattern) => !universalPattern.test(pattern)
            );
            if (nonUniversalFiles.length && pathMatches(
              filePath,
              this.basePath,
              { files: nonUniversalFiles, ignores: config.ignores }
            )) {
              debug(`Matching config found for ${filePath}`);
              matchingConfigIndices.push(index);
              matchFound = true;
              return;
            }
            if (universalFiles.length && pathMatches(
              filePath,
              this.basePath,
              { files: universalFiles, ignores: config.ignores }
            )) {
              debug(`Matching config found for ${filePath}`);
              matchingConfigIndices.push(index);
              return;
            }
            return;
          }
          if (pathMatches(filePath, this.basePath, config)) {
            debug(`Matching config found for ${filePath}`);
            matchingConfigIndices.push(index);
            matchFound = true;
            return;
          }
        });
        if (!matchFound) {
          debug(`No matching configs found for ${filePath}`);
          cache.set(filePath, finalConfig);
          return finalConfig;
        }
        finalConfig = cache.get(matchingConfigIndices.toString());
        if (finalConfig) {
          cache.set(filePath, finalConfig);
          return finalConfig;
        }
        finalConfig = matchingConfigIndices.reduce((result, index) => {
          return this[ConfigArraySymbol.schema].merge(result, this[index]);
        }, {}, this);
        finalConfig = this[ConfigArraySymbol.finalizeConfig](finalConfig);
        cache.set(filePath, finalConfig);
        cache.set(matchingConfigIndices.toString(), finalConfig);
        return finalConfig;
      }
      /**
       * Determines if the given filepath is ignored based on the configs.
       * @param {string} filePath The complete path of a file to check.
       * @returns {boolean} True if the path is ignored, false if not.
       * @deprecated Use `isFileIgnored` instead.
       */
      isIgnored(filePath) {
        return this.isFileIgnored(filePath);
      }
      /**
       * Determines if the given filepath is ignored based on the configs.
       * @param {string} filePath The complete path of a file to check.
       * @returns {boolean} True if the path is ignored, false if not.
       */
      isFileIgnored(filePath) {
        return this.getConfig(filePath) === void 0;
      }
      /**
       * Determines if the given directory is ignored based on the configs.
       * This checks only default `ignores` that don't have `files` in the 
       * same config. A pattern such as `/foo` be considered to ignore the directory
       * while a pattern such as `/foo/**` is not considered to ignore the
       * directory because it is matching files.
       * @param {string} directoryPath The complete path of a directory to check.
       * @returns {boolean} True if the directory is ignored, false if not. Will
       * 		return true for any directory that is not inside of `basePath`.
       * @throws {Error} When the `ConfigArray` is not normalized.
       */
      isDirectoryIgnored(directoryPath) {
        assertNormalized(this);
        const relativeDirectoryPath = path2.relative(this.basePath, directoryPath).replace(/\\/g, "/");
        if (relativeDirectoryPath.startsWith("..")) {
          return true;
        }
        const cache = dataCache.get(this).directoryMatches;
        if (cache.has(relativeDirectoryPath)) {
          return cache.get(relativeDirectoryPath);
        }
        const directoryParts = relativeDirectoryPath.split("/");
        let relativeDirectoryToCheck = "";
        let result = false;
        do {
          relativeDirectoryToCheck += directoryParts.shift() + "/";
          result = shouldIgnorePath(
            this.ignores,
            path2.join(this.basePath, relativeDirectoryToCheck),
            relativeDirectoryToCheck
          );
          cache.set(relativeDirectoryToCheck, result);
        } while (!result && directoryParts.length);
        cache.set(relativeDirectoryPath, result);
        return result;
      }
    };
    exports.ConfigArray = ConfigArray;
    exports.ConfigArraySymbol = ConfigArraySymbol;
  }
});

// node_modules/eslint/lib/config/flat-config-schema.js
var require_flat_config_schema = __commonJS({
  "node_modules/eslint/lib/config/flat-config-schema.js"(exports) {
    "use strict";
    var ruleSeverities = /* @__PURE__ */ new Map([
      [0, 0],
      ["off", 0],
      [1, 1],
      ["warn", 1],
      [2, 2],
      ["error", 2]
    ]);
    var globalVariablesValues = /* @__PURE__ */ new Set([
      true,
      "true",
      "writable",
      "writeable",
      false,
      "false",
      "readonly",
      "readable",
      null,
      "off"
    ]);
    function isNonNullObject(value2) {
      return typeof value2 === "object" && value2 !== null;
    }
    function isUndefined2(value2) {
      return typeof value2 === "undefined";
    }
    function deepMerge(first2 = {}, second = {}) {
      if (Array.isArray(second)) {
        return second;
      }
      const result = {
        ...first2,
        ...second
      };
      for (const key of Object.keys(second)) {
        if (key === "__proto__") {
          continue;
        }
        const firstValue = first2[key];
        const secondValue = second[key];
        if (isNonNullObject(firstValue)) {
          result[key] = deepMerge(firstValue, secondValue);
        } else if (isUndefined2(firstValue)) {
          if (isNonNullObject(secondValue)) {
            result[key] = deepMerge(
              Array.isArray(secondValue) ? [] : {},
              secondValue
            );
          } else if (!isUndefined2(secondValue)) {
            result[key] = secondValue;
          }
        }
      }
      return result;
    }
    function normalizeRuleOptions(ruleOptions) {
      const finalOptions = Array.isArray(ruleOptions) ? ruleOptions.slice(0) : [ruleOptions];
      finalOptions[0] = ruleSeverities.get(finalOptions[0]);
      return finalOptions;
    }
    function assertIsRuleOptions(value2) {
      if (typeof value2 !== "string" && typeof value2 !== "number" && !Array.isArray(value2)) {
        throw new TypeError("Expected a string, number, or array.");
      }
    }
    function assertIsRuleSeverity(value2) {
      const severity = typeof value2 === "string" ? ruleSeverities.get(value2.toLowerCase()) : ruleSeverities.get(value2);
      if (typeof severity === "undefined") {
        throw new TypeError('Expected severity of "off", 0, "warn", 1, "error", or 2.');
      }
    }
    function assertIsPluginMemberName(value2) {
      if (!/[@a-z0-9-_$]+(?:\/(?:[a-z0-9-_$]+))+$/iu.test(value2)) {
        throw new TypeError(`Expected string in the form "pluginName/objectName" but found "${value2}".`);
      }
    }
    function assertIsObject(value2) {
      if (!isNonNullObject(value2)) {
        throw new TypeError("Expected an object.");
      }
    }
    function assertIsObjectOrString(value2) {
      if ((!value2 || typeof value2 !== "object") && typeof value2 !== "string") {
        throw new TypeError("Expected an object or string.");
      }
    }
    var booleanSchema = {
      merge: "replace",
      validate: "boolean"
    };
    var deepObjectAssignSchema = {
      merge(first2 = {}, second = {}) {
        return deepMerge(first2, second);
      },
      validate: "object"
    };
    var globalsSchema = {
      merge: "assign",
      validate(value2) {
        assertIsObject(value2);
        for (const key of Object.keys(value2)) {
          if (key === "__proto__") {
            continue;
          }
          if (key !== key.trim()) {
            throw new TypeError(`Global "${key}" has leading or trailing whitespace.`);
          }
          if (!globalVariablesValues.has(value2[key])) {
            throw new TypeError(`Key "${key}": Expected "readonly", "writable", or "off".`);
          }
        }
      }
    };
    var parserSchema = {
      merge: "replace",
      validate(value2) {
        assertIsObjectOrString(value2);
        if (typeof value2 === "object" && typeof value2.parse !== "function" && typeof value2.parseForESLint !== "function") {
          throw new TypeError("Expected object to have a parse() or parseForESLint() method.");
        }
        if (typeof value2 === "string") {
          assertIsPluginMemberName(value2);
        }
      }
    };
    var pluginsSchema = {
      merge(first2 = {}, second = {}) {
        const keys3 = /* @__PURE__ */ new Set([...Object.keys(first2), ...Object.keys(second)]);
        const result = {};
        for (const key of keys3) {
          if (key === "__proto__") {
            continue;
          }
          if (key in first2 && key in second && first2[key] !== second[key]) {
            throw new TypeError(`Cannot redefine plugin "${key}".`);
          }
          result[key] = second[key] || first2[key];
        }
        return result;
      },
      validate(value2) {
        if (value2 === null || typeof value2 !== "object") {
          throw new TypeError("Expected an object.");
        }
        for (const key of Object.keys(value2)) {
          if (key === "__proto__") {
            continue;
          }
          if (value2[key] === null || typeof value2[key] !== "object") {
            throw new TypeError(`Key "${key}": Expected an object.`);
          }
        }
      }
    };
    var processorSchema = {
      merge: "replace",
      validate(value2) {
        if (typeof value2 === "string") {
          assertIsPluginMemberName(value2);
        } else if (value2 && typeof value2 === "object") {
          if (typeof value2.preprocess !== "function" || typeof value2.postprocess !== "function") {
            throw new TypeError("Object must have a preprocess() and a postprocess() method.");
          }
        } else {
          throw new TypeError("Expected an object or a string.");
        }
      }
    };
    var rulesSchema = {
      merge(first2 = {}, second = {}) {
        const result = {
          ...first2,
          ...second
        };
        for (const ruleId of Object.keys(result)) {
          if (ruleId === "__proto__") {
            delete result.__proto__;
            continue;
          }
          result[ruleId] = normalizeRuleOptions(result[ruleId]);
          if (!(ruleId in first2) || !(ruleId in second)) {
            continue;
          }
          const firstRuleOptions = normalizeRuleOptions(first2[ruleId]);
          const secondRuleOptions = normalizeRuleOptions(second[ruleId]);
          if (secondRuleOptions.length === 1) {
            result[ruleId] = [secondRuleOptions[0], ...firstRuleOptions.slice(1)];
            continue;
          }
        }
        return result;
      },
      validate(value2) {
        assertIsObject(value2);
        let lastRuleId;
        try {
          for (const ruleId of Object.keys(value2)) {
            if (ruleId === "__proto__") {
              continue;
            }
            lastRuleId = ruleId;
            const ruleOptions = value2[ruleId];
            assertIsRuleOptions(ruleOptions);
            if (Array.isArray(ruleOptions)) {
              assertIsRuleSeverity(ruleOptions[0]);
            } else {
              assertIsRuleSeverity(ruleOptions);
            }
          }
        } catch (error) {
          error.message = `Key "${lastRuleId}": ${error.message}`;
          throw error;
        }
      }
    };
    var ecmaVersionSchema = {
      merge: "replace",
      validate(value2) {
        if (typeof value2 === "number" || value2 === "latest") {
          return;
        }
        throw new TypeError('Expected a number or "latest".');
      }
    };
    var sourceTypeSchema = {
      merge: "replace",
      validate(value2) {
        if (typeof value2 !== "string" || !/^(?:script|module|commonjs)$/u.test(value2)) {
          throw new TypeError('Expected "script", "module", or "commonjs".');
        }
      }
    };
    exports.flatConfigSchema = {
      settings: deepObjectAssignSchema,
      linterOptions: {
        schema: {
          noInlineConfig: booleanSchema,
          reportUnusedDisableDirectives: booleanSchema
        }
      },
      languageOptions: {
        schema: {
          ecmaVersion: ecmaVersionSchema,
          sourceType: sourceTypeSchema,
          globals: globalsSchema,
          parser: parserSchema,
          parserOptions: deepObjectAssignSchema
        }
      },
      processor: processorSchema,
      plugins: pluginsSchema,
      rules: rulesSchema
    };
  }
});

// node_modules/ajv/lib/refs/json-schema-draft-04.json
var require_json_schema_draft_04 = __commonJS({
  "node_modules/ajv/lib/refs/json-schema-draft-04.json"(exports, module2) {
    module2.exports = {
      id: "http://json-schema.org/draft-04/schema#",
      $schema: "http://json-schema.org/draft-04/schema#",
      description: "Core schema meta-schema",
      definitions: {
        schemaArray: {
          type: "array",
          minItems: 1,
          items: { $ref: "#" }
        },
        positiveInteger: {
          type: "integer",
          minimum: 0
        },
        positiveIntegerDefault0: {
          allOf: [{ $ref: "#/definitions/positiveInteger" }, { default: 0 }]
        },
        simpleTypes: {
          enum: ["array", "boolean", "integer", "null", "number", "object", "string"]
        },
        stringArray: {
          type: "array",
          items: { type: "string" },
          minItems: 1,
          uniqueItems: true
        }
      },
      type: "object",
      properties: {
        id: {
          type: "string"
        },
        $schema: {
          type: "string"
        },
        title: {
          type: "string"
        },
        description: {
          type: "string"
        },
        default: {},
        multipleOf: {
          type: "number",
          minimum: 0,
          exclusiveMinimum: true
        },
        maximum: {
          type: "number"
        },
        exclusiveMaximum: {
          type: "boolean",
          default: false
        },
        minimum: {
          type: "number"
        },
        exclusiveMinimum: {
          type: "boolean",
          default: false
        },
        maxLength: { $ref: "#/definitions/positiveInteger" },
        minLength: { $ref: "#/definitions/positiveIntegerDefault0" },
        pattern: {
          type: "string",
          format: "regex"
        },
        additionalItems: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        items: {
          anyOf: [
            { $ref: "#" },
            { $ref: "#/definitions/schemaArray" }
          ],
          default: {}
        },
        maxItems: { $ref: "#/definitions/positiveInteger" },
        minItems: { $ref: "#/definitions/positiveIntegerDefault0" },
        uniqueItems: {
          type: "boolean",
          default: false
        },
        maxProperties: { $ref: "#/definitions/positiveInteger" },
        minProperties: { $ref: "#/definitions/positiveIntegerDefault0" },
        required: { $ref: "#/definitions/stringArray" },
        additionalProperties: {
          anyOf: [
            { type: "boolean" },
            { $ref: "#" }
          ],
          default: {}
        },
        definitions: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        properties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        patternProperties: {
          type: "object",
          additionalProperties: { $ref: "#" },
          default: {}
        },
        dependencies: {
          type: "object",
          additionalProperties: {
            anyOf: [
              { $ref: "#" },
              { $ref: "#/definitions/stringArray" }
            ]
          }
        },
        enum: {
          type: "array",
          minItems: 1,
          uniqueItems: true
        },
        type: {
          anyOf: [
            { $ref: "#/definitions/simpleTypes" },
            {
              type: "array",
              items: { $ref: "#/definitions/simpleTypes" },
              minItems: 1,
              uniqueItems: true
            }
          ]
        },
        format: { type: "string" },
        allOf: { $ref: "#/definitions/schemaArray" },
        anyOf: { $ref: "#/definitions/schemaArray" },
        oneOf: { $ref: "#/definitions/schemaArray" },
        not: { $ref: "#" }
      },
      dependencies: {
        exclusiveMaximum: ["maximum"],
        exclusiveMinimum: ["minimum"]
      },
      default: {}
    };
  }
});

// node_modules/eslint/lib/shared/ajv.js
var require_ajv2 = __commonJS({
  "node_modules/eslint/lib/shared/ajv.js"(exports, module2) {
    "use strict";
    var Ajv = require_ajv();
    var metaSchema = require_json_schema_draft_04();
    module2.exports = (additionalOptions = {}) => {
      const ajv = new Ajv({
        meta: false,
        useDefaults: true,
        validateSchema: false,
        missingRefs: "ignore",
        verbose: true,
        schemaId: "auto",
        ...additionalOptions
      });
      ajv.addMetaSchema(metaSchema);
      ajv._opts.defaultMeta = metaSchema.id;
      return ajv;
    };
  }
});

// node_modules/eslint/lib/config/rule-validator.js
var require_rule_validator = __commonJS({
  "node_modules/eslint/lib/config/rule-validator.js"(exports) {
    "use strict";
    var ajv = require_ajv2()();
    var {
      parseRuleId,
      getRuleFromConfig,
      getRuleOptionsSchema
    } = require_flat_config_helpers();
    var ruleReplacements = require_replacements();
    function throwRuleNotFoundError({ pluginName, ruleName }, config) {
      const ruleId = pluginName === "@" ? ruleName : `${pluginName}/${ruleName}`;
      const errorMessageHeader = `Key "rules": Key "${ruleId}"`;
      let errorMessage = `${errorMessageHeader}: Could not find plugin "${pluginName}".`;
      if (config.plugins && config.plugins[pluginName]) {
        const replacementRuleName = ruleReplacements.rules[ruleName];
        if (pluginName === "@" && replacementRuleName) {
          errorMessage = `${errorMessageHeader}: Rule "${ruleName}" was removed and replaced by "${replacementRuleName}".`;
        } else {
          errorMessage = `${errorMessageHeader}: Could not find "${ruleName}" in plugin "${pluginName}".`;
          for (const [otherPluginName, otherPlugin] of Object.entries(config.plugins)) {
            if (otherPlugin.rules && otherPlugin.rules[ruleName]) {
              errorMessage += ` Did you mean "${otherPluginName}/${ruleName}"?`;
              break;
            }
          }
        }
      }
      throw new TypeError(errorMessage);
    }
    var RuleValidator = class {
      /**
       * Creates a new instance.
       */
      constructor() {
        this.validators = /* @__PURE__ */ new WeakMap();
      }
      /**
       * Validates all of the rule configurations in a config against each
       * rule's schema.
       * @param {Object} config The full config to validate. This object must
       *      contain both the rules section and the plugins section.
       * @returns {void}
       * @throws {Error} If a rule's configuration does not match its schema.
       */
      validate(config) {
        if (!config.rules) {
          return;
        }
        for (const [ruleId, ruleOptions] of Object.entries(config.rules)) {
          if (ruleId === "__proto__") {
            continue;
          }
          if (ruleOptions[0] === 0) {
            continue;
          }
          const rule = getRuleFromConfig(ruleId, config);
          if (!rule) {
            throwRuleNotFoundError(parseRuleId(ruleId), config);
          }
          if (!this.validators.has(rule)) {
            const schema = getRuleOptionsSchema(rule);
            if (schema) {
              this.validators.set(rule, ajv.compile(schema));
            }
          }
          const validateRule = this.validators.get(rule);
          if (validateRule) {
            validateRule(ruleOptions.slice(1));
            if (validateRule.errors) {
              throw new Error(`Key "rules": Key "${ruleId}": ${validateRule.errors.map(
                (error) => `	Value ${JSON.stringify(error.data)} ${error.message}.
`
              ).join("")}`);
            }
          }
        }
      }
    };
    exports.RuleValidator = RuleValidator;
  }
});

// node_modules/eslint/lib/config/default-config.js
var require_default_config = __commonJS({
  "node_modules/eslint/lib/config/default-config.js"(exports) {
    "use strict";
    var Rules = require_rules2();
    exports.defaultConfig = [
      {
        plugins: {
          "@": {
            parsers: {
              espree: require("espree")
            },
            /*
             * Because we try to delay loading rules until absolutely
             * necessary, a proxy allows us to hook into the lazy-loading
             * aspect of the rules map while still keeping all of the
             * relevant configuration inside of the config array.
             */
            rules: new Proxy({}, {
              get(target, property) {
                return Rules.get(property);
              },
              has(target, property) {
                return Rules.has(property);
              }
            })
          }
        },
        languageOptions: {
          sourceType: "module",
          ecmaVersion: "latest",
          parser: "@/espree",
          parserOptions: {}
        }
      },
      // default ignores are listed here
      {
        ignores: [
          "**/node_modules/*",
          ".git/"
        ]
      },
      // intentionally empty config to ensure these files are globbed by default
      {
        files: ["**/*.js", "**/*.mjs"]
      },
      {
        files: ["**/*.cjs"],
        languageOptions: {
          sourceType: "commonjs",
          ecmaVersion: "latest"
        }
      }
    ];
  }
});

// node_modules/eslint/lib/config/flat-config-array.js
var require_flat_config_array = __commonJS({
  "node_modules/eslint/lib/config/flat-config-array.js"(exports) {
    "use strict";
    var { ConfigArray, ConfigArraySymbol } = require_api();
    var { flatConfigSchema } = require_flat_config_schema();
    var { RuleValidator } = require_rule_validator();
    var { defaultConfig } = require_default_config();
    var recommendedConfig = require_eslint_recommended();
    var ruleValidator = new RuleValidator();
    function splitPluginIdentifier(identifier3) {
      const parts = identifier3.split("/");
      return {
        objectName: parts.pop(),
        pluginName: parts.join("/")
      };
    }
    var originalBaseConfig = Symbol("originalBaseConfig");
    var FlatConfigArray = class extends ConfigArray {
      /**
       * Creates a new instance.
       * @param {*[]} configs An array of configuration information.
       * @param {{basePath: string, shouldIgnore: boolean, baseConfig: FlatConfig}} options The options
       *      to use for the config array instance.
       */
      constructor(configs, {
        basePath,
        shouldIgnore = true,
        baseConfig = defaultConfig
      } = {}) {
        super(configs, {
          basePath,
          schema: flatConfigSchema
        });
        if (baseConfig[Symbol.iterator]) {
          this.unshift(...baseConfig);
        } else {
          this.unshift(baseConfig);
        }
        this[originalBaseConfig] = baseConfig;
        Object.defineProperty(this, originalBaseConfig, { writable: false });
        this.shouldIgnore = shouldIgnore;
        Object.defineProperty(this, "shouldIgnore", { writable: false });
      }
      /* eslint-disable class-methods-use-this -- Desired as instance method */
      /**
       * Replaces a config with another config to allow us to put strings
       * in the config array that will be replaced by objects before
       * normalization.
       * @param {Object} config The config to preprocess.
       * @returns {Object} The preprocessed config.
       */
      [ConfigArraySymbol.preprocessConfig](config) {
        if (config === "eslint:recommended") {
          return recommendedConfig;
        }
        if (config === "eslint:all") {
          return require_eslint_all();
        }
        if (!this.shouldIgnore && !this[originalBaseConfig].includes(config) && config.ignores && !config.files) {
          const { ignores, ...otherKeys } = config;
          return otherKeys;
        }
        return config;
      }
      /**
       * Finalizes the config by replacing plugin references with their objects
       * and validating rule option schemas.
       * @param {Object} config The config to finalize.
       * @returns {Object} The finalized config.
       * @throws {TypeError} If the config is invalid.
       */
      [ConfigArraySymbol.finalizeConfig](config) {
        const { plugins, languageOptions, processor } = config;
        let parserName, processorName;
        let invalidParser = false, invalidProcessor = false;
        if (languageOptions && languageOptions.parser) {
          if (typeof languageOptions.parser === "string") {
            const { pluginName, objectName: localParserName } = splitPluginIdentifier(languageOptions.parser);
            parserName = languageOptions.parser;
            if (!plugins || !plugins[pluginName] || !plugins[pluginName].parsers || !plugins[pluginName].parsers[localParserName]) {
              throw new TypeError(`Key "parser": Could not find "${localParserName}" in plugin "${pluginName}".`);
            }
            languageOptions.parser = plugins[pluginName].parsers[localParserName];
          } else {
            invalidParser = true;
          }
        }
        if (processor) {
          if (typeof processor === "string") {
            const { pluginName, objectName: localProcessorName } = splitPluginIdentifier(processor);
            processorName = processor;
            if (!plugins || !plugins[pluginName] || !plugins[pluginName].processors || !plugins[pluginName].processors[localProcessorName]) {
              throw new TypeError(`Key "processor": Could not find "${localProcessorName}" in plugin "${pluginName}".`);
            }
            config.processor = plugins[pluginName].processors[localProcessorName];
          } else {
            invalidProcessor = true;
          }
        }
        ruleValidator.validate(config);
        Object.defineProperty(config, "toJSON", {
          value: function() {
            if (invalidParser) {
              throw new Error("Caching is not supported when parser is an object.");
            }
            if (invalidProcessor) {
              throw new Error("Caching is not supported when processor is an object.");
            }
            return {
              ...this,
              plugins: Object.keys(plugins),
              languageOptions: {
                ...languageOptions,
                parser: parserName
              },
              processor: processorName
            };
          }
        });
        return config;
      }
      /* eslint-enable class-methods-use-this -- Desired as instance method */
    };
    exports.FlatConfigArray = FlatConfigArray;
  }
});

// node_modules/eslint/conf/globals.js
var require_globals5 = __commonJS({
  "node_modules/eslint/conf/globals.js"(exports, module2) {
    "use strict";
    var commonjs = {
      exports: true,
      global: false,
      module: false,
      require: false
    };
    var es3 = {
      Array: false,
      Boolean: false,
      constructor: false,
      Date: false,
      decodeURI: false,
      decodeURIComponent: false,
      encodeURI: false,
      encodeURIComponent: false,
      Error: false,
      escape: false,
      eval: false,
      EvalError: false,
      Function: false,
      hasOwnProperty: false,
      Infinity: false,
      isFinite: false,
      isNaN: false,
      isPrototypeOf: false,
      Math: false,
      NaN: false,
      Number: false,
      Object: false,
      parseFloat: false,
      parseInt: false,
      propertyIsEnumerable: false,
      RangeError: false,
      ReferenceError: false,
      RegExp: false,
      String: false,
      SyntaxError: false,
      toLocaleString: false,
      toString: false,
      TypeError: false,
      undefined: false,
      unescape: false,
      URIError: false,
      valueOf: false
    };
    var es5 = {
      ...es3,
      JSON: false
    };
    var es2015 = {
      ...es5,
      ArrayBuffer: false,
      DataView: false,
      Float32Array: false,
      Float64Array: false,
      Int16Array: false,
      Int32Array: false,
      Int8Array: false,
      Map: false,
      Promise: false,
      Proxy: false,
      Reflect: false,
      Set: false,
      Symbol: false,
      Uint16Array: false,
      Uint32Array: false,
      Uint8Array: false,
      Uint8ClampedArray: false,
      WeakMap: false,
      WeakSet: false
    };
    var es2016 = {
      ...es2015
    };
    var es2017 = {
      ...es2016,
      Atomics: false,
      SharedArrayBuffer: false
    };
    var es2018 = {
      ...es2017
    };
    var es2019 = {
      ...es2018
    };
    var es2020 = {
      ...es2019,
      BigInt: false,
      BigInt64Array: false,
      BigUint64Array: false,
      globalThis: false
    };
    var es2021 = {
      ...es2020,
      AggregateError: false,
      FinalizationRegistry: false,
      WeakRef: false
    };
    var es2022 = {
      ...es2021
    };
    var es2023 = {
      ...es2022
    };
    module2.exports = {
      commonjs,
      es3,
      es5,
      es2015,
      es2016,
      es2017,
      es2018,
      es2019,
      es2020,
      es2021,
      es2022,
      es2023
    };
  }
});

// node_modules/eslint/lib/linter/linter.js
var require_linter = __commonJS({
  "node_modules/eslint/lib/linter/linter.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var eslintScope = require_eslint_scope();
    var evk = require_eslint_visitor_keys();
    var espree = require("espree");
    var merge4 = require_lodash2();
    var pkg = require_package4();
    var astUtils = require_ast_utils();
    var {
      Legacy: {
        ConfigOps,
        ConfigValidator,
        environments: BuiltInEnvironments
      }
    } = require_eslintrc_universal();
    var Traverser = require_traverser();
    var { SourceCode } = require_source_code2();
    var CodePathAnalyzer = require_code_path_analyzer();
    var applyDisableDirectives = require_apply_disable_directives();
    var ConfigCommentParser = require_config_comment_parser();
    var NodeEventGenerator = require_node_event_generator();
    var createReportTranslator = require_report_translator();
    var Rules = require_rules3();
    var createEmitter = require_safe_emitter();
    var SourceCodeFixer = require_source_code_fixer();
    var timing = require_timing();
    var ruleReplacements = require_replacements();
    var { getRuleFromConfig } = require_flat_config_helpers();
    var { FlatConfigArray } = require_flat_config_array();
    var debug = require_src()("eslint:linter");
    var MAX_AUTOFIX_PASSES = 10;
    var DEFAULT_PARSER_NAME = "espree";
    var DEFAULT_ECMA_VERSION = 5;
    var commentParser = new ConfigCommentParser();
    var DEFAULT_ERROR_LOC = { start: { line: 1, column: 0 }, end: { line: 1, column: 1 } };
    var parserSymbol = Symbol.for("eslint.RuleTester.parser");
    var globals = require_globals5();
    function isEspree(parser) {
      return !!(parser === espree || parser[parserSymbol] === espree);
    }
    function getGlobalsForEcmaVersion(ecmaVersion) {
      switch (ecmaVersion) {
        case 3:
          return globals.es3;
        case 5:
          return globals.es5;
        default:
          if (ecmaVersion < 2015) {
            return globals[`es${ecmaVersion + 2009}`];
          }
          return globals[`es${ecmaVersion}`];
      }
    }
    function addDeclaredGlobals(globalScope, configGlobals, { exportedVariables, enabledGlobals }) {
      for (const id of /* @__PURE__ */ new Set([...Object.keys(configGlobals), ...Object.keys(enabledGlobals)])) {
        const configValue = configGlobals[id] === void 0 ? void 0 : ConfigOps.normalizeConfigGlobal(configGlobals[id]);
        const commentValue = enabledGlobals[id] && enabledGlobals[id].value;
        const value2 = commentValue || configValue;
        const sourceComments = enabledGlobals[id] && enabledGlobals[id].comments;
        if (value2 === "off") {
          continue;
        }
        let variable = globalScope.set.get(id);
        if (!variable) {
          variable = new eslintScope.Variable(id, globalScope);
          globalScope.variables.push(variable);
          globalScope.set.set(id, variable);
        }
        variable.eslintImplicitGlobalSetting = configValue;
        variable.eslintExplicitGlobal = sourceComments !== void 0;
        variable.eslintExplicitGlobalComments = sourceComments;
        variable.writeable = value2 === "writable";
      }
      Object.keys(exportedVariables).forEach((name) => {
        const variable = globalScope.set.get(name);
        if (variable) {
          variable.eslintUsed = true;
          variable.eslintExported = true;
        }
      });
      globalScope.through = globalScope.through.filter((reference) => {
        const name = reference.identifier.name;
        const variable = globalScope.set.get(name);
        if (variable) {
          reference.resolved = variable;
          variable.references.push(reference);
          return false;
        }
        return true;
      });
    }
    function createMissingRuleMessage(ruleId) {
      return Object.prototype.hasOwnProperty.call(ruleReplacements.rules, ruleId) ? `Rule '${ruleId}' was removed and replaced by: ${ruleReplacements.rules[ruleId].join(", ")}` : `Definition for rule '${ruleId}' was not found.`;
    }
    function createLintingProblem(options) {
      const {
        ruleId = null,
        loc = DEFAULT_ERROR_LOC,
        message = createMissingRuleMessage(options.ruleId),
        severity = 2
      } = options;
      return {
        ruleId,
        message,
        line: loc.start.line,
        column: loc.start.column + 1,
        endLine: loc.end.line,
        endColumn: loc.end.column + 1,
        severity,
        nodeType: null
      };
    }
    function createDisableDirectives(options) {
      const { commentToken, type, value: value2, justification, ruleMapper } = options;
      const ruleIds = Object.keys(commentParser.parseListConfig(value2));
      const directiveRules = ruleIds.length ? ruleIds : [null];
      const result = {
        directives: [],
        // valid disable directives
        directiveProblems: []
        // problems in directives
      };
      const parentComment = { commentToken, ruleIds };
      for (const ruleId of directiveRules) {
        if (ruleId === null || !!ruleMapper(ruleId)) {
          if (type === "disable-next-line") {
            result.directives.push({
              parentComment,
              type,
              line: commentToken.loc.end.line,
              column: commentToken.loc.end.column + 1,
              ruleId,
              justification
            });
          } else {
            result.directives.push({
              parentComment,
              type,
              line: commentToken.loc.start.line,
              column: commentToken.loc.start.column + 1,
              ruleId,
              justification
            });
          }
        } else {
          result.directiveProblems.push(createLintingProblem({ ruleId, loc: commentToken.loc }));
        }
      }
      return result;
    }
    function extractDirectiveComment(value2) {
      const match = /\s-{2,}\s/u.exec(value2);
      if (!match) {
        return { directivePart: value2.trim(), justificationPart: "" };
      }
      const directive = value2.slice(0, match.index).trim();
      const justification = value2.slice(match.index + match[0].length).trim();
      return { directivePart: directive, justificationPart: justification };
    }
    function getDirectiveComments(ast, ruleMapper, warnInlineConfig) {
      const configuredRules = {};
      const enabledGlobals = /* @__PURE__ */ Object.create(null);
      const exportedVariables = {};
      const problems = [];
      const disableDirectives = [];
      const validator = new ConfigValidator({
        builtInRules: Rules
      });
      ast.comments.filter((token) => token.type !== "Shebang").forEach((comment) => {
        const { directivePart, justificationPart } = extractDirectiveComment(comment.value);
        const match = /^(eslint(?:-env|-enable|-disable(?:(?:-next)?-line)?)?|exported|globals?)(?:\s|$)/u.exec(directivePart);
        if (!match) {
          return;
        }
        const directiveText = match[1];
        const lineCommentSupported = /^eslint-disable-(next-)?line$/u.test(directiveText);
        if (comment.type === "Line" && !lineCommentSupported) {
          return;
        }
        if (warnInlineConfig) {
          const kind = comment.type === "Block" ? `/*${directiveText}*/` : `//${directiveText}`;
          problems.push(createLintingProblem({
            ruleId: null,
            message: `'${kind}' has no effect because you have 'noInlineConfig' setting in ${warnInlineConfig}.`,
            loc: comment.loc,
            severity: 1
          }));
          return;
        }
        if (directiveText === "eslint-disable-line" && comment.loc.start.line !== comment.loc.end.line) {
          const message = `${directiveText} comment should not span multiple lines.`;
          problems.push(createLintingProblem({
            ruleId: null,
            message,
            loc: comment.loc
          }));
          return;
        }
        const directiveValue = directivePart.slice(match.index + directiveText.length);
        switch (directiveText) {
          case "eslint-disable":
          case "eslint-enable":
          case "eslint-disable-next-line":
          case "eslint-disable-line": {
            const directiveType = directiveText.slice("eslint-".length);
            const options = { commentToken: comment, type: directiveType, value: directiveValue, justification: justificationPart, ruleMapper };
            const { directives, directiveProblems } = createDisableDirectives(options);
            disableDirectives.push(...directives);
            problems.push(...directiveProblems);
            break;
          }
          case "exported":
            Object.assign(exportedVariables, commentParser.parseStringConfig(directiveValue, comment));
            break;
          case "globals":
          case "global":
            for (const [id, { value: value2 }] of Object.entries(commentParser.parseStringConfig(directiveValue, comment))) {
              let normalizedValue;
              try {
                normalizedValue = ConfigOps.normalizeConfigGlobal(value2);
              } catch (err) {
                problems.push(createLintingProblem({
                  ruleId: null,
                  loc: comment.loc,
                  message: err.message
                }));
                continue;
              }
              if (enabledGlobals[id]) {
                enabledGlobals[id].comments.push(comment);
                enabledGlobals[id].value = normalizedValue;
              } else {
                enabledGlobals[id] = {
                  comments: [comment],
                  value: normalizedValue
                };
              }
            }
            break;
          case "eslint": {
            const parseResult = commentParser.parseJsonConfig(directiveValue, comment.loc);
            if (parseResult.success) {
              Object.keys(parseResult.config).forEach((name) => {
                const rule = ruleMapper(name);
                const ruleValue = parseResult.config[name];
                if (!rule) {
                  problems.push(createLintingProblem({ ruleId: name, loc: comment.loc }));
                  return;
                }
                try {
                  validator.validateRuleOptions(rule, name, ruleValue);
                } catch (err) {
                  problems.push(createLintingProblem({
                    ruleId: name,
                    message: err.message,
                    loc: comment.loc
                  }));
                  return;
                }
                configuredRules[name] = ruleValue;
              });
            } else {
              problems.push(parseResult.error);
            }
            break;
          }
        }
      });
      return {
        configuredRules,
        enabledGlobals,
        exportedVariables,
        problems,
        disableDirectives
      };
    }
    function normalizeEcmaVersion(parser, ecmaVersion) {
      if (isEspree(parser)) {
        if (ecmaVersion === "latest") {
          return espree.latestEcmaVersion;
        }
      }
      return ecmaVersion >= 2015 ? ecmaVersion - 2009 : ecmaVersion;
    }
    function normalizeEcmaVersionForLanguageOptions(ecmaVersion) {
      switch (ecmaVersion) {
        case 3:
          return 3;
        case 5:
        case void 0:
          return 5;
        default:
          if (typeof ecmaVersion === "number") {
            return ecmaVersion >= 2015 ? ecmaVersion : ecmaVersion + 2009;
          }
      }
      return espree.latestEcmaVersion + 2009;
    }
    var eslintEnvPattern = /\/\*\s*eslint-env\s(.+?)(?:\*\/|$)/gsu;
    function findEslintEnv(text) {
      let match, retv;
      eslintEnvPattern.lastIndex = 0;
      while ((match = eslintEnvPattern.exec(text)) !== null) {
        if (match[0].endsWith("*/")) {
          retv = Object.assign(
            retv || {},
            commentParser.parseListConfig(extractDirectiveComment(match[1]).directivePart)
          );
        }
      }
      return retv;
    }
    function normalizeFilename(filename) {
      const parts = filename.split(path2.sep);
      const index = parts.lastIndexOf("<text>");
      return index === -1 ? filename : parts.slice(index).join(path2.sep);
    }
    function normalizeVerifyOptions(providedOptions, config) {
      const linterOptions = config.linterOptions || config;
      const disableInlineConfig = linterOptions.noInlineConfig === true;
      const ignoreInlineConfig = providedOptions.allowInlineConfig === false;
      const configNameOfNoInlineConfig = config.configNameOfNoInlineConfig ? ` (${config.configNameOfNoInlineConfig})` : "";
      let reportUnusedDisableDirectives = providedOptions.reportUnusedDisableDirectives;
      if (typeof reportUnusedDisableDirectives === "boolean") {
        reportUnusedDisableDirectives = reportUnusedDisableDirectives ? "error" : "off";
      }
      if (typeof reportUnusedDisableDirectives !== "string") {
        reportUnusedDisableDirectives = linterOptions.reportUnusedDisableDirectives ? "warn" : "off";
      }
      return {
        filename: normalizeFilename(providedOptions.filename || "<input>"),
        allowInlineConfig: !ignoreInlineConfig,
        warnInlineConfig: disableInlineConfig && !ignoreInlineConfig ? `your config${configNameOfNoInlineConfig}` : null,
        reportUnusedDisableDirectives,
        disableFixes: Boolean(providedOptions.disableFixes)
      };
    }
    function resolveParserOptions(parser, providedOptions, enabledEnvironments) {
      const parserOptionsFromEnv = enabledEnvironments.filter((env) => env.parserOptions).reduce((parserOptions, env) => merge4(parserOptions, env.parserOptions), {});
      const mergedParserOptions = merge4(parserOptionsFromEnv, providedOptions || {});
      const isModule = mergedParserOptions.sourceType === "module";
      if (isModule) {
        mergedParserOptions.ecmaFeatures = Object.assign({}, mergedParserOptions.ecmaFeatures, { globalReturn: false });
      }
      mergedParserOptions.ecmaVersion = normalizeEcmaVersion(parser, mergedParserOptions.ecmaVersion);
      return mergedParserOptions;
    }
    function createLanguageOptions({ globals: configuredGlobals, parser, parserOptions }) {
      const {
        ecmaVersion,
        sourceType
      } = parserOptions;
      return {
        globals: configuredGlobals,
        ecmaVersion: normalizeEcmaVersionForLanguageOptions(ecmaVersion),
        sourceType,
        parser,
        parserOptions
      };
    }
    function resolveGlobals(providedGlobals, enabledEnvironments) {
      return Object.assign(
        {},
        ...enabledEnvironments.filter((env) => env.globals).map((env) => env.globals),
        providedGlobals
      );
    }
    function stripUnicodeBOM(text) {
      if (text.charCodeAt(0) === 65279) {
        return text.slice(1);
      }
      return text;
    }
    function getRuleOptions(ruleConfig) {
      if (Array.isArray(ruleConfig)) {
        return ruleConfig.slice(1);
      }
      return [];
    }
    function analyzeScope(ast, languageOptions, visitorKeys) {
      const parserOptions = languageOptions.parserOptions;
      const ecmaFeatures = parserOptions.ecmaFeatures || {};
      const ecmaVersion = languageOptions.ecmaVersion || DEFAULT_ECMA_VERSION;
      return eslintScope.analyze(ast, {
        ignoreEval: true,
        nodejsScope: ecmaFeatures.globalReturn,
        impliedStrict: ecmaFeatures.impliedStrict,
        ecmaVersion: typeof ecmaVersion === "number" ? ecmaVersion : 6,
        sourceType: languageOptions.sourceType || "script",
        childVisitorKeys: visitorKeys || evk.KEYS,
        fallback: Traverser.getKeys
      });
    }
    function parse3(text, languageOptions, filePath) {
      const textToParse = stripUnicodeBOM(text).replace(astUtils.shebangPattern, (match, captured) => `//${captured}`);
      const { ecmaVersion, sourceType, parser } = languageOptions;
      const parserOptions = Object.assign(
        { ecmaVersion, sourceType },
        languageOptions.parserOptions,
        {
          loc: true,
          range: true,
          raw: true,
          tokens: true,
          comment: true,
          eslintVisitorKeys: true,
          eslintScopeManager: true,
          filePath
        }
      );
      try {
        debug("Parsing:", filePath);
        const parseResult = typeof parser.parseForESLint === "function" ? parser.parseForESLint(textToParse, parserOptions) : { ast: parser.parse(textToParse, parserOptions) };
        debug("Parsing successful:", filePath);
        const ast = parseResult.ast;
        const parserServices = parseResult.services || {};
        const visitorKeys = parseResult.visitorKeys || evk.KEYS;
        debug("Scope analysis:", filePath);
        const scopeManager = parseResult.scopeManager || analyzeScope(ast, languageOptions, visitorKeys);
        debug("Scope analysis successful:", filePath);
        return {
          success: true,
          /*
           * Save all values that `parseForESLint()` returned.
           * If a `SourceCode` object is given as the first parameter instead of source code text,
           * linter skips the parsing process and reuses the source code object.
           * In that case, linter needs all the values that `parseForESLint()` returned.
           */
          sourceCode: new SourceCode({
            text,
            ast,
            parserServices,
            scopeManager,
            visitorKeys
          })
        };
      } catch (ex) {
        const message = `Parsing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
        debug("%s\n%s", message, ex.stack);
        return {
          success: false,
          error: {
            ruleId: null,
            fatal: true,
            severity: 2,
            message,
            line: ex.lineNumber,
            column: ex.column
          }
        };
      }
    }
    function getScope(scopeManager, currentNode) {
      const inner = currentNode.type !== "Program";
      for (let node = currentNode; node; node = node.parent) {
        const scope = scopeManager.acquire(node, inner);
        if (scope) {
          if (scope.type === "function-expression-name") {
            return scope.childScopes[0];
          }
          return scope;
        }
      }
      return scopeManager.scopes[0];
    }
    function markVariableAsUsed(scopeManager, currentNode, languageOptions, name) {
      const parserOptions = languageOptions.parserOptions;
      const sourceType = languageOptions.sourceType;
      const hasGlobalReturn = parserOptions.ecmaFeatures && parserOptions.ecmaFeatures.globalReturn || sourceType === "commonjs";
      const specialScope = hasGlobalReturn || sourceType === "module";
      const currentScope = getScope(scopeManager, currentNode);
      const initialScope = currentScope.type === "global" && specialScope ? currentScope.childScopes[0] : currentScope;
      for (let scope = initialScope; scope; scope = scope.upper) {
        const variable = scope.variables.find((scopeVar) => scopeVar.name === name);
        if (variable) {
          variable.eslintUsed = true;
          return true;
        }
      }
      return false;
    }
    function createRuleListeners(rule, ruleContext) {
      try {
        return rule.create(ruleContext);
      } catch (ex) {
        ex.message = `Error while loading rule '${ruleContext.id}': ${ex.message}`;
        throw ex;
      }
    }
    function getAncestors(node) {
      const ancestorsStartingAtParent = [];
      for (let ancestor = node.parent; ancestor; ancestor = ancestor.parent) {
        ancestorsStartingAtParent.push(ancestor);
      }
      return ancestorsStartingAtParent.reverse();
    }
    var DEPRECATED_SOURCECODE_PASSTHROUGHS = {
      getSource: "getText",
      getSourceLines: "getLines",
      getAllComments: "getAllComments",
      getNodeByRangeIndex: "getNodeByRangeIndex",
      getComments: "getComments",
      getCommentsBefore: "getCommentsBefore",
      getCommentsAfter: "getCommentsAfter",
      getCommentsInside: "getCommentsInside",
      getJSDocComment: "getJSDocComment",
      getFirstToken: "getFirstToken",
      getFirstTokens: "getFirstTokens",
      getLastToken: "getLastToken",
      getLastTokens: "getLastTokens",
      getTokenAfter: "getTokenAfter",
      getTokenBefore: "getTokenBefore",
      getTokenByRangeStart: "getTokenByRangeStart",
      getTokens: "getTokens",
      getTokensAfter: "getTokensAfter",
      getTokensBefore: "getTokensBefore",
      getTokensBetween: "getTokensBetween"
    };
    var BASE_TRAVERSAL_CONTEXT = Object.freeze(
      Object.keys(DEPRECATED_SOURCECODE_PASSTHROUGHS).reduce(
        (contextInfo, methodName) => Object.assign(contextInfo, {
          [methodName](...args) {
            return this.getSourceCode()[DEPRECATED_SOURCECODE_PASSTHROUGHS[methodName]](...args);
          }
        }),
        {}
      )
    );
    function runRules(sourceCode, configuredRules, ruleMapper, parserName, languageOptions, settings, filename, disableFixes, cwd, physicalFilename) {
      const emitter = createEmitter();
      const nodeQueue = [];
      let currentNode = sourceCode.ast;
      Traverser.traverse(sourceCode.ast, {
        enter(node, parent) {
          node.parent = parent;
          nodeQueue.push({ isEntering: true, node });
        },
        leave(node) {
          nodeQueue.push({ isEntering: false, node });
        },
        visitorKeys: sourceCode.visitorKeys
      });
      const sharedTraversalContext = Object.freeze(
        Object.assign(
          Object.create(BASE_TRAVERSAL_CONTEXT),
          {
            getAncestors: () => getAncestors(currentNode),
            getDeclaredVariables: sourceCode.scopeManager.getDeclaredVariables.bind(sourceCode.scopeManager),
            getCwd: () => cwd,
            getFilename: () => filename,
            getPhysicalFilename: () => physicalFilename || filename,
            getScope: () => getScope(sourceCode.scopeManager, currentNode),
            getSourceCode: () => sourceCode,
            markVariableAsUsed: (name) => markVariableAsUsed(sourceCode.scopeManager, currentNode, languageOptions, name),
            parserOptions: {
              ...languageOptions.parserOptions
            },
            parserPath: parserName,
            languageOptions,
            parserServices: sourceCode.parserServices,
            settings
          }
        )
      );
      const lintingProblems = [];
      Object.keys(configuredRules).forEach((ruleId) => {
        const severity = ConfigOps.getRuleSeverity(configuredRules[ruleId]);
        if (severity === 0) {
          return;
        }
        const rule = ruleMapper(ruleId);
        if (!rule) {
          lintingProblems.push(createLintingProblem({ ruleId }));
          return;
        }
        const messageIds = rule.meta && rule.meta.messages;
        let reportTranslator = null;
        const ruleContext = Object.freeze(
          Object.assign(
            Object.create(sharedTraversalContext),
            {
              id: ruleId,
              options: getRuleOptions(configuredRules[ruleId]),
              report(...args) {
                if (reportTranslator === null) {
                  reportTranslator = createReportTranslator({
                    ruleId,
                    severity,
                    sourceCode,
                    messageIds,
                    disableFixes
                  });
                }
                const problem = reportTranslator(...args);
                if (problem.fix && !(rule.meta && rule.meta.fixable)) {
                  throw new Error('Fixable rules must set the `meta.fixable` property to "code" or "whitespace".');
                }
                if (problem.suggestions && !(rule.meta && rule.meta.hasSuggestions === true)) {
                  if (rule.meta && rule.meta.docs && typeof rule.meta.docs.suggestion !== "undefined") {
                    throw new Error("Rules with suggestions must set the `meta.hasSuggestions` property to `true`. `meta.docs.suggestion` is ignored by ESLint.");
                  }
                  throw new Error("Rules with suggestions must set the `meta.hasSuggestions` property to `true`.");
                }
                lintingProblems.push(problem);
              }
            }
          )
        );
        const ruleListeners = timing.enabled ? timing.time(ruleId, createRuleListeners)(rule, ruleContext) : createRuleListeners(rule, ruleContext);
        function addRuleErrorHandler(ruleListener) {
          return function ruleErrorHandler(...listenerArgs) {
            try {
              return ruleListener(...listenerArgs);
            } catch (e) {
              e.ruleId = ruleId;
              throw e;
            }
          };
        }
        if (typeof ruleListeners === "undefined" || ruleListeners === null) {
          throw new Error(`The create() function for rule '${ruleId}' did not return an object.`);
        }
        Object.keys(ruleListeners).forEach((selector) => {
          const ruleListener = timing.enabled ? timing.time(ruleId, ruleListeners[selector]) : ruleListeners[selector];
          emitter.on(
            selector,
            addRuleErrorHandler(ruleListener)
          );
        });
      });
      const eventGenerator = nodeQueue[0].node.type === "Program" ? new CodePathAnalyzer(new NodeEventGenerator(emitter, { visitorKeys: sourceCode.visitorKeys, fallback: Traverser.getKeys })) : new NodeEventGenerator(emitter, { visitorKeys: sourceCode.visitorKeys, fallback: Traverser.getKeys });
      nodeQueue.forEach((traversalInfo) => {
        currentNode = traversalInfo.node;
        try {
          if (traversalInfo.isEntering) {
            eventGenerator.enterNode(currentNode);
          } else {
            eventGenerator.leaveNode(currentNode);
          }
        } catch (err) {
          err.currentNode = currentNode;
          throw err;
        }
      });
      return lintingProblems;
    }
    function ensureText(textOrSourceCode) {
      if (typeof textOrSourceCode === "object") {
        const { hasBOM, text } = textOrSourceCode;
        const bom = hasBOM ? "\uFEFF" : "";
        return bom + text;
      }
      return String(textOrSourceCode);
    }
    function getEnv(slots, envId) {
      return slots.lastConfigArray && slots.lastConfigArray.pluginEnvironments.get(envId) || BuiltInEnvironments.get(envId) || null;
    }
    function getRule(slots, ruleId) {
      return slots.lastConfigArray && slots.lastConfigArray.pluginRules.get(ruleId) || slots.ruleMap.get(ruleId);
    }
    function normalizeCwd(cwd) {
      if (cwd) {
        return cwd;
      }
      if (typeof process === "object") {
        return process.cwd();
      }
      return void 0;
    }
    var internalSlotsMap = /* @__PURE__ */ new WeakMap();
    function assertEslintrcConfig(linter) {
      const { configType } = internalSlotsMap.get(linter);
      if (configType === "flat") {
        throw new Error("This method cannot be used with flat config. Add your entries directly into the config array.");
      }
    }
    var Linter = class {
      /**
       * Initialize the Linter.
       * @param {Object} [config] the config object
       * @param {string} [config.cwd] path to a directory that should be considered as the current working directory, can be undefined.
       * @param {"flat"|"eslintrc"} [config.configType="eslintrc"] the type of config used.
       */
      constructor({ cwd, configType } = {}) {
        internalSlotsMap.set(this, {
          cwd: normalizeCwd(cwd),
          lastConfigArray: null,
          lastSourceCode: null,
          lastSuppressedMessages: [],
          configType,
          // TODO: Remove after flat config conversion
          parserMap: /* @__PURE__ */ new Map([["espree", espree]]),
          ruleMap: new Rules()
        });
        this.version = pkg.version;
      }
      /**
       * Getter for package version.
       * @static
       * @returns {string} The version from package.json.
       */
      static get version() {
        return pkg.version;
      }
      /**
       * Same as linter.verify, except without support for processors.
       * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
       * @param {ConfigData} providedConfig An ESLintConfig instance to configure everything.
       * @param {VerifyOptions} [providedOptions] The optional filename of the file being checked.
       * @throws {Error} If during rule execution.
       * @returns {(LintMessage|SuppressedLintMessage)[]} The results as an array of messages or an empty array if no messages.
       */
      _verifyWithoutProcessors(textOrSourceCode, providedConfig, providedOptions) {
        const slots = internalSlotsMap.get(this);
        const config = providedConfig || {};
        const options = normalizeVerifyOptions(providedOptions, config);
        let text;
        if (typeof textOrSourceCode === "string") {
          slots.lastSourceCode = null;
          text = textOrSourceCode;
        } else {
          slots.lastSourceCode = textOrSourceCode;
          text = textOrSourceCode.text;
        }
        let parserName = DEFAULT_PARSER_NAME;
        let parser = espree;
        if (typeof config.parser === "object" && config.parser !== null) {
          parserName = config.parser.filePath;
          parser = config.parser.definition;
        } else if (typeof config.parser === "string") {
          if (!slots.parserMap.has(config.parser)) {
            return [{
              ruleId: null,
              fatal: true,
              severity: 2,
              message: `Configured parser '${config.parser}' was not found.`,
              line: 0,
              column: 0
            }];
          }
          parserName = config.parser;
          parser = slots.parserMap.get(config.parser);
        }
        const envInFile = options.allowInlineConfig && !options.warnInlineConfig ? findEslintEnv(text) : {};
        const resolvedEnvConfig = Object.assign({ builtin: true }, config.env, envInFile);
        const enabledEnvs = Object.keys(resolvedEnvConfig).filter((envName) => resolvedEnvConfig[envName]).map((envName) => getEnv(slots, envName)).filter((env) => env);
        const parserOptions = resolveParserOptions(parser, config.parserOptions || {}, enabledEnvs);
        const configuredGlobals = resolveGlobals(config.globals || {}, enabledEnvs);
        const settings = config.settings || {};
        const languageOptions = createLanguageOptions({
          globals: config.globals,
          parser,
          parserOptions
        });
        if (!slots.lastSourceCode) {
          const parseResult = parse3(
            text,
            languageOptions,
            options.filename
          );
          if (!parseResult.success) {
            return [parseResult.error];
          }
          slots.lastSourceCode = parseResult.sourceCode;
        } else {
          if (!slots.lastSourceCode.scopeManager) {
            slots.lastSourceCode = new SourceCode({
              text: slots.lastSourceCode.text,
              ast: slots.lastSourceCode.ast,
              parserServices: slots.lastSourceCode.parserServices,
              visitorKeys: slots.lastSourceCode.visitorKeys,
              scopeManager: analyzeScope(slots.lastSourceCode.ast, languageOptions)
            });
          }
        }
        const sourceCode = slots.lastSourceCode;
        const commentDirectives = options.allowInlineConfig ? getDirectiveComments(sourceCode.ast, (ruleId) => getRule(slots, ruleId), options.warnInlineConfig) : { configuredRules: {}, enabledGlobals: {}, exportedVariables: {}, problems: [], disableDirectives: [] };
        addDeclaredGlobals(
          sourceCode.scopeManager.scopes[0],
          configuredGlobals,
          { exportedVariables: commentDirectives.exportedVariables, enabledGlobals: commentDirectives.enabledGlobals }
        );
        const configuredRules = Object.assign({}, config.rules, commentDirectives.configuredRules);
        let lintingProblems;
        try {
          lintingProblems = runRules(
            sourceCode,
            configuredRules,
            (ruleId) => getRule(slots, ruleId),
            parserName,
            languageOptions,
            settings,
            options.filename,
            options.disableFixes,
            slots.cwd,
            providedOptions.physicalFilename
          );
        } catch (err) {
          err.message += `
Occurred while linting ${options.filename}`;
          debug("An error occurred while traversing");
          debug("Filename:", options.filename);
          if (err.currentNode) {
            const { line } = err.currentNode.loc.start;
            debug("Line:", line);
            err.message += `:${line}`;
          }
          debug("Parser Options:", parserOptions);
          debug("Parser Path:", parserName);
          debug("Settings:", settings);
          if (err.ruleId) {
            err.message += `
Rule: "${err.ruleId}"`;
          }
          throw err;
        }
        return applyDisableDirectives({
          directives: commentDirectives.disableDirectives,
          disableFixes: options.disableFixes,
          problems: lintingProblems.concat(commentDirectives.problems).sort((problemA, problemB) => problemA.line - problemB.line || problemA.column - problemB.column),
          reportUnusedDisableDirectives: options.reportUnusedDisableDirectives
        });
      }
      /**
       * Verifies the text against the rules specified by the second argument.
       * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
       * @param {ConfigData|ConfigArray} config An ESLintConfig instance to configure everything.
       * @param {(string|(VerifyOptions&ProcessorOptions))} [filenameOrOptions] The optional filename of the file being checked.
       *      If this is not set, the filename will default to '<input>' in the rule context. If
       *      an object, then it has "filename", "allowInlineConfig", and some properties.
       * @returns {LintMessage[]} The results as an array of messages or an empty array if no messages.
       */
      verify(textOrSourceCode, config, filenameOrOptions) {
        debug("Verify");
        const { configType } = internalSlotsMap.get(this);
        const options = typeof filenameOrOptions === "string" ? { filename: filenameOrOptions } : filenameOrOptions || {};
        if (config) {
          if (configType === "flat") {
            let configArray = config;
            if (!Array.isArray(config) || typeof config.getConfig !== "function") {
              configArray = new FlatConfigArray(config);
              configArray.normalizeSync();
            }
            return this._distinguishSuppressedMessages(this._verifyWithFlatConfigArray(textOrSourceCode, configArray, options, true));
          }
          if (typeof config.extractConfig === "function") {
            return this._distinguishSuppressedMessages(this._verifyWithConfigArray(textOrSourceCode, config, options));
          }
        }
        if (options.preprocess || options.postprocess) {
          return this._distinguishSuppressedMessages(this._verifyWithProcessor(textOrSourceCode, config, options));
        }
        return this._distinguishSuppressedMessages(this._verifyWithoutProcessors(textOrSourceCode, config, options));
      }
      /**
       * Verify with a processor.
       * @param {string|SourceCode} textOrSourceCode The source code.
       * @param {FlatConfig} config The config array.
       * @param {VerifyOptions&ProcessorOptions} options The options.
       * @param {FlatConfigArray} [configForRecursive] The `ConfigArray` object to apply multiple processors recursively.
       * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
       */
      _verifyWithFlatConfigArrayAndProcessor(textOrSourceCode, config, options, configForRecursive) {
        const filename = options.filename || "<input>";
        const filenameToExpose = normalizeFilename(filename);
        const physicalFilename = options.physicalFilename || filenameToExpose;
        const text = ensureText(textOrSourceCode);
        const preprocess = options.preprocess || ((rawText) => [rawText]);
        const postprocess = options.postprocess || ((messagesList) => messagesList.flat());
        const filterCodeBlock = options.filterCodeBlock || ((blockFilename) => blockFilename.endsWith(".js"));
        const originalExtname = path2.extname(filename);
        let blocks;
        try {
          blocks = preprocess(text, filenameToExpose);
        } catch (ex) {
          const message = `Preprocessing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
          debug("%s\n%s", message, ex.stack);
          return [
            {
              ruleId: null,
              fatal: true,
              severity: 2,
              message,
              line: ex.lineNumber,
              column: ex.column
            }
          ];
        }
        const messageLists = blocks.map((block, i) => {
          debug("A code block was found: %o", block.filename || "(unnamed)");
          if (typeof block === "string") {
            return this._verifyWithFlatConfigArrayAndWithoutProcessors(block, config, options);
          }
          const blockText = block.text;
          const blockName = path2.join(filename, `${i}_${block.filename}`);
          if (!filterCodeBlock(blockName, blockText)) {
            debug("This code block was skipped.");
            return [];
          }
          if (configForRecursive && (text !== blockText || path2.extname(blockName) !== originalExtname)) {
            debug("Resolving configuration again because the file content or extension was changed.");
            return this._verifyWithFlatConfigArray(
              blockText,
              configForRecursive,
              { ...options, filename: blockName, physicalFilename }
            );
          }
          return this._verifyWithFlatConfigArrayAndWithoutProcessors(
            blockText,
            config,
            { ...options, filename: blockName, physicalFilename }
          );
        });
        return postprocess(messageLists, filenameToExpose);
      }
      /**
       * Same as linter.verify, except without support for processors.
       * @param {string|SourceCode} textOrSourceCode The text to parse or a SourceCode object.
       * @param {FlatConfig} providedConfig An ESLintConfig instance to configure everything.
       * @param {VerifyOptions} [providedOptions] The optional filename of the file being checked.
       * @throws {Error} If during rule execution.
       * @returns {(LintMessage|SuppressedLintMessage)[]} The results as an array of messages or an empty array if no messages.
       */
      _verifyWithFlatConfigArrayAndWithoutProcessors(textOrSourceCode, providedConfig, providedOptions) {
        const slots = internalSlotsMap.get(this);
        const config = providedConfig || {};
        const options = normalizeVerifyOptions(providedOptions, config);
        let text;
        if (typeof textOrSourceCode === "string") {
          slots.lastSourceCode = null;
          text = textOrSourceCode;
        } else {
          slots.lastSourceCode = textOrSourceCode;
          text = textOrSourceCode.text;
        }
        const languageOptions = config.languageOptions;
        languageOptions.ecmaVersion = normalizeEcmaVersionForLanguageOptions(
          languageOptions.ecmaVersion
        );
        const configuredGlobals = Object.assign(
          {},
          getGlobalsForEcmaVersion(languageOptions.ecmaVersion),
          languageOptions.sourceType === "commonjs" ? globals.commonjs : void 0,
          languageOptions.globals
        );
        if (!languageOptions.parser) {
          throw new TypeError(`No parser specified for ${options.filename}`);
        }
        if (isEspree(languageOptions.parser)) {
          const parserOptions = languageOptions.parserOptions;
          if (languageOptions.sourceType) {
            parserOptions.sourceType = languageOptions.sourceType;
            if (parserOptions.sourceType === "module" && parserOptions.ecmaFeatures && parserOptions.ecmaFeatures.globalReturn) {
              parserOptions.ecmaFeatures.globalReturn = false;
            }
          }
        }
        const settings = config.settings || {};
        if (!slots.lastSourceCode) {
          const parseResult = parse3(
            text,
            languageOptions,
            options.filename
          );
          if (!parseResult.success) {
            return [parseResult.error];
          }
          slots.lastSourceCode = parseResult.sourceCode;
        } else {
          if (!slots.lastSourceCode.scopeManager) {
            slots.lastSourceCode = new SourceCode({
              text: slots.lastSourceCode.text,
              ast: slots.lastSourceCode.ast,
              parserServices: slots.lastSourceCode.parserServices,
              visitorKeys: slots.lastSourceCode.visitorKeys,
              scopeManager: analyzeScope(slots.lastSourceCode.ast, languageOptions)
            });
          }
        }
        const sourceCode = slots.lastSourceCode;
        const commentDirectives = options.allowInlineConfig ? getDirectiveComments(
          sourceCode.ast,
          (ruleId) => getRuleFromConfig(ruleId, config),
          options.warnInlineConfig
        ) : { configuredRules: {}, enabledGlobals: {}, exportedVariables: {}, problems: [], disableDirectives: [] };
        addDeclaredGlobals(
          sourceCode.scopeManager.scopes[0],
          configuredGlobals,
          { exportedVariables: commentDirectives.exportedVariables, enabledGlobals: commentDirectives.enabledGlobals }
        );
        const configuredRules = Object.assign({}, config.rules, commentDirectives.configuredRules);
        let lintingProblems;
        try {
          lintingProblems = runRules(
            sourceCode,
            configuredRules,
            (ruleId) => getRuleFromConfig(ruleId, config),
            void 0,
            languageOptions,
            settings,
            options.filename,
            options.disableFixes,
            slots.cwd,
            providedOptions.physicalFilename
          );
        } catch (err) {
          err.message += `
Occurred while linting ${options.filename}`;
          debug("An error occurred while traversing");
          debug("Filename:", options.filename);
          if (err.currentNode) {
            const { line } = err.currentNode.loc.start;
            debug("Line:", line);
            err.message += `:${line}`;
          }
          debug("Parser Options:", languageOptions.parserOptions);
          debug("Settings:", settings);
          if (err.ruleId) {
            err.message += `
Rule: "${err.ruleId}"`;
          }
          throw err;
        }
        return applyDisableDirectives({
          directives: commentDirectives.disableDirectives,
          disableFixes: options.disableFixes,
          problems: lintingProblems.concat(commentDirectives.problems).sort((problemA, problemB) => problemA.line - problemB.line || problemA.column - problemB.column),
          reportUnusedDisableDirectives: options.reportUnusedDisableDirectives
        });
      }
      /**
       * Verify a given code with `ConfigArray`.
       * @param {string|SourceCode} textOrSourceCode The source code.
       * @param {ConfigArray} configArray The config array.
       * @param {VerifyOptions&ProcessorOptions} options The options.
       * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
       */
      _verifyWithConfigArray(textOrSourceCode, configArray, options) {
        debug("With ConfigArray: %s", options.filename);
        internalSlotsMap.get(this).lastConfigArray = configArray;
        const config = configArray.extractConfig(options.filename);
        const processor = config.processor && configArray.pluginProcessors.get(config.processor);
        if (processor) {
          debug("Apply the processor: %o", config.processor);
          const { preprocess, postprocess, supportsAutofix } = processor;
          const disableFixes = options.disableFixes || !supportsAutofix;
          return this._verifyWithProcessor(
            textOrSourceCode,
            config,
            { ...options, disableFixes, postprocess, preprocess },
            configArray
          );
        }
        return this._verifyWithoutProcessors(textOrSourceCode, config, options);
      }
      /**
       * Verify a given code with a flat config.
       * @param {string|SourceCode} textOrSourceCode The source code.
       * @param {FlatConfigArray} configArray The config array.
       * @param {VerifyOptions&ProcessorOptions} options The options.
       * @param {boolean} [firstCall=false] Indicates if this is being called directly
       *      from verify(). (TODO: Remove once eslintrc is removed.)
       * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
       */
      _verifyWithFlatConfigArray(textOrSourceCode, configArray, options, firstCall = false) {
        debug("With flat config: %s", options.filename);
        const filename = options.filename || "__placeholder__.js";
        internalSlotsMap.get(this).lastConfigArray = configArray;
        const config = configArray.getConfig(filename);
        if (!config) {
          return [
            {
              ruleId: null,
              severity: 1,
              message: `No matching configuration found for ${filename}.`,
              line: 0,
              column: 0
            }
          ];
        }
        if (config.processor) {
          debug("Apply the processor: %o", config.processor);
          const { preprocess, postprocess, supportsAutofix } = config.processor;
          const disableFixes = options.disableFixes || !supportsAutofix;
          return this._verifyWithFlatConfigArrayAndProcessor(
            textOrSourceCode,
            config,
            { ...options, filename, disableFixes, postprocess, preprocess },
            configArray
          );
        }
        if (firstCall && (options.preprocess || options.postprocess)) {
          return this._verifyWithFlatConfigArrayAndProcessor(textOrSourceCode, config, options);
        }
        return this._verifyWithFlatConfigArrayAndWithoutProcessors(textOrSourceCode, config, options);
      }
      /**
       * Verify with a processor.
       * @param {string|SourceCode} textOrSourceCode The source code.
       * @param {ConfigData|ExtractedConfig} config The config array.
       * @param {VerifyOptions&ProcessorOptions} options The options.
       * @param {ConfigArray} [configForRecursive] The `ConfigArray` object to apply multiple processors recursively.
       * @returns {(LintMessage|SuppressedLintMessage)[]} The found problems.
       */
      _verifyWithProcessor(textOrSourceCode, config, options, configForRecursive) {
        const filename = options.filename || "<input>";
        const filenameToExpose = normalizeFilename(filename);
        const physicalFilename = options.physicalFilename || filenameToExpose;
        const text = ensureText(textOrSourceCode);
        const preprocess = options.preprocess || ((rawText) => [rawText]);
        const postprocess = options.postprocess || ((messagesList) => messagesList.flat());
        const filterCodeBlock = options.filterCodeBlock || ((blockFilename) => blockFilename.endsWith(".js"));
        const originalExtname = path2.extname(filename);
        let blocks;
        try {
          blocks = preprocess(text, filenameToExpose);
        } catch (ex) {
          const message = `Preprocessing error: ${ex.message.replace(/^line \d+:/iu, "").trim()}`;
          debug("%s\n%s", message, ex.stack);
          return [
            {
              ruleId: null,
              fatal: true,
              severity: 2,
              message,
              line: ex.lineNumber,
              column: ex.column
            }
          ];
        }
        const messageLists = blocks.map((block, i) => {
          debug("A code block was found: %o", block.filename || "(unnamed)");
          if (typeof block === "string") {
            return this._verifyWithoutProcessors(block, config, options);
          }
          const blockText = block.text;
          const blockName = path2.join(filename, `${i}_${block.filename}`);
          if (!filterCodeBlock(blockName, blockText)) {
            debug("This code block was skipped.");
            return [];
          }
          if (configForRecursive && (text !== blockText || path2.extname(blockName) !== originalExtname)) {
            debug("Resolving configuration again because the file content or extension was changed.");
            return this._verifyWithConfigArray(
              blockText,
              configForRecursive,
              { ...options, filename: blockName, physicalFilename }
            );
          }
          return this._verifyWithoutProcessors(
            blockText,
            config,
            { ...options, filename: blockName, physicalFilename }
          );
        });
        return postprocess(messageLists, filenameToExpose);
      }
      /**
       * Given a list of reported problems, distinguish problems between normal messages and suppressed messages.
       * The normal messages will be returned and the suppressed messages will be stored as lastSuppressedMessages.
       * @param {Problem[]} problems A list of reported problems.
       * @returns {LintMessage[]} A list of LintMessage.
       */
      _distinguishSuppressedMessages(problems) {
        const messages = [];
        const suppressedMessages = [];
        const slots = internalSlotsMap.get(this);
        for (const problem of problems) {
          if (problem.suppressions) {
            suppressedMessages.push(problem);
          } else {
            messages.push(problem);
          }
        }
        slots.lastSuppressedMessages = suppressedMessages;
        return messages;
      }
      /**
       * Gets the SourceCode object representing the parsed source.
       * @returns {SourceCode} The SourceCode object.
       */
      getSourceCode() {
        return internalSlotsMap.get(this).lastSourceCode;
      }
      /**
       * Gets the list of SuppressedLintMessage produced in the last running.
       * @returns {SuppressedLintMessage[]} The list of SuppressedLintMessage
       */
      getSuppressedMessages() {
        return internalSlotsMap.get(this).lastSuppressedMessages;
      }
      /**
       * Defines a new linting rule.
       * @param {string} ruleId A unique rule identifier
       * @param {Function | Rule} ruleModule Function from context to object mapping AST node types to event handlers
       * @returns {void}
       */
      defineRule(ruleId, ruleModule) {
        assertEslintrcConfig(this);
        internalSlotsMap.get(this).ruleMap.define(ruleId, ruleModule);
      }
      /**
       * Defines many new linting rules.
       * @param {Record<string, Function | Rule>} rulesToDefine map from unique rule identifier to rule
       * @returns {void}
       */
      defineRules(rulesToDefine) {
        assertEslintrcConfig(this);
        Object.getOwnPropertyNames(rulesToDefine).forEach((ruleId) => {
          this.defineRule(ruleId, rulesToDefine[ruleId]);
        });
      }
      /**
       * Gets an object with all loaded rules.
       * @returns {Map<string, Rule>} All loaded rules
       */
      getRules() {
        assertEslintrcConfig(this);
        const { lastConfigArray, ruleMap } = internalSlotsMap.get(this);
        return new Map(function* () {
          yield* ruleMap;
          if (lastConfigArray) {
            yield* lastConfigArray.pluginRules;
          }
        }());
      }
      /**
       * Define a new parser module
       * @param {string} parserId Name of the parser
       * @param {Parser} parserModule The parser object
       * @returns {void}
       */
      defineParser(parserId, parserModule) {
        assertEslintrcConfig(this);
        internalSlotsMap.get(this).parserMap.set(parserId, parserModule);
      }
      /**
       * Performs multiple autofix passes over the text until as many fixes as possible
       * have been applied.
       * @param {string} text The source text to apply fixes to.
       * @param {ConfigData|ConfigArray|FlatConfigArray} config The ESLint config object to use.
       * @param {VerifyOptions&ProcessorOptions&FixOptions} options The ESLint options object to use.
       * @returns {{fixed:boolean,messages:LintMessage[],output:string}} The result of the fix operation as returned from the
       *      SourceCodeFixer.
       */
      verifyAndFix(text, config, options) {
        let messages = [], fixedResult, fixed = false, passNumber = 0, currentText = text;
        const debugTextDescription = options && options.filename || `${text.slice(0, 10)}...`;
        const shouldFix = options && typeof options.fix !== "undefined" ? options.fix : true;
        do {
          passNumber++;
          debug(`Linting code for ${debugTextDescription} (pass ${passNumber})`);
          messages = this.verify(currentText, config, options);
          debug(`Generating fixed text for ${debugTextDescription} (pass ${passNumber})`);
          fixedResult = SourceCodeFixer.applyFixes(currentText, messages, shouldFix);
          if (messages.length === 1 && messages[0].fatal) {
            break;
          }
          fixed = fixed || fixedResult.fixed;
          currentText = fixedResult.output;
        } while (fixedResult.fixed && passNumber < MAX_AUTOFIX_PASSES);
        if (fixedResult.fixed) {
          fixedResult.messages = this.verify(currentText, config, options);
        }
        fixedResult.fixed = fixed;
        fixedResult.output = currentText;
        return fixedResult;
      }
    };
    module2.exports = {
      Linter,
      /**
       * Get the internal slots of a given Linter instance for tests.
       * @param {Linter} instance The Linter instance to get.
       * @returns {LinterInternalSlots} The internal slots.
       */
      getLinterInternalSlots(instance) {
        return internalSlotsMap.get(instance);
      }
    };
  }
});

// node_modules/eslint/lib/linter/index.js
var require_linter2 = __commonJS({
  "node_modules/eslint/lib/linter/index.js"(exports, module2) {
    "use strict";
    var { Linter } = require_linter();
    var interpolate = require_interpolate();
    var SourceCodeFixer = require_source_code_fixer();
    module2.exports = {
      Linter,
      // For testers.
      SourceCodeFixer,
      interpolate
    };
  }
});

// node_modules/eslint/lib/cli-engine/load-rules.js
var require_load_rules = __commonJS({
  "node_modules/eslint/lib/cli-engine/load-rules.js"(exports, module2) {
    "use strict";
    var fs2 = require("fs");
    var path2 = require("path");
    var rulesDirCache = {};
    module2.exports = function(relativeRulesDir, cwd) {
      const rulesDir = path2.resolve(cwd, relativeRulesDir);
      if (rulesDirCache[rulesDir]) {
        return rulesDirCache[rulesDir];
      }
      const rules = /* @__PURE__ */ Object.create(null);
      fs2.readdirSync(rulesDir).forEach((file) => {
        if (path2.extname(file) !== ".js") {
          return;
        }
        rules[file.slice(0, -3)] = require(path2.join(rulesDir, file));
      });
      rulesDirCache[rulesDir] = rules;
      return rules;
    };
  }
});

// node_modules/imurmurhash/imurmurhash.js
var require_imurmurhash = __commonJS({
  "node_modules/imurmurhash/imurmurhash.js"(exports, module2) {
    (function() {
      var cache;
      function MurmurHash3(key, seed) {
        var m = this instanceof MurmurHash3 ? this : cache;
        m.reset(seed);
        if (typeof key === "string" && key.length > 0) {
          m.hash(key);
        }
        if (m !== this) {
          return m;
        }
      }
      ;
      MurmurHash3.prototype.hash = function(key) {
        var h1, k1, i, top, len;
        len = key.length;
        this.len += len;
        k1 = this.k1;
        i = 0;
        switch (this.rem) {
          case 0:
            k1 ^= len > i ? key.charCodeAt(i++) & 65535 : 0;
          case 1:
            k1 ^= len > i ? (key.charCodeAt(i++) & 65535) << 8 : 0;
          case 2:
            k1 ^= len > i ? (key.charCodeAt(i++) & 65535) << 16 : 0;
          case 3:
            k1 ^= len > i ? (key.charCodeAt(i) & 255) << 24 : 0;
            k1 ^= len > i ? (key.charCodeAt(i++) & 65280) >> 8 : 0;
        }
        this.rem = len + this.rem & 3;
        len -= this.rem;
        if (len > 0) {
          h1 = this.h1;
          while (1) {
            k1 = k1 * 11601 + (k1 & 65535) * 3432906752 & 4294967295;
            k1 = k1 << 15 | k1 >>> 17;
            k1 = k1 * 13715 + (k1 & 65535) * 461832192 & 4294967295;
            h1 ^= k1;
            h1 = h1 << 13 | h1 >>> 19;
            h1 = h1 * 5 + 3864292196 & 4294967295;
            if (i >= len) {
              break;
            }
            k1 = key.charCodeAt(i++) & 65535 ^ (key.charCodeAt(i++) & 65535) << 8 ^ (key.charCodeAt(i++) & 65535) << 16;
            top = key.charCodeAt(i++);
            k1 ^= (top & 255) << 24 ^ (top & 65280) >> 8;
          }
          k1 = 0;
          switch (this.rem) {
            case 3:
              k1 ^= (key.charCodeAt(i + 2) & 65535) << 16;
            case 2:
              k1 ^= (key.charCodeAt(i + 1) & 65535) << 8;
            case 1:
              k1 ^= key.charCodeAt(i) & 65535;
          }
          this.h1 = h1;
        }
        this.k1 = k1;
        return this;
      };
      MurmurHash3.prototype.result = function() {
        var k1, h1;
        k1 = this.k1;
        h1 = this.h1;
        if (k1 > 0) {
          k1 = k1 * 11601 + (k1 & 65535) * 3432906752 & 4294967295;
          k1 = k1 << 15 | k1 >>> 17;
          k1 = k1 * 13715 + (k1 & 65535) * 461832192 & 4294967295;
          h1 ^= k1;
        }
        h1 ^= this.len;
        h1 ^= h1 >>> 16;
        h1 = h1 * 51819 + (h1 & 65535) * 2246770688 & 4294967295;
        h1 ^= h1 >>> 13;
        h1 = h1 * 44597 + (h1 & 65535) * 3266445312 & 4294967295;
        h1 ^= h1 >>> 16;
        return h1 >>> 0;
      };
      MurmurHash3.prototype.reset = function(seed) {
        this.h1 = typeof seed === "number" ? seed : 0;
        this.rem = this.k1 = this.len = 0;
        return this;
      };
      cache = new MurmurHash3();
      if (typeof module2 != "undefined") {
        module2.exports = MurmurHash3;
      } else {
        this.MurmurHash3 = MurmurHash3;
      }
    })();
  }
});

// node_modules/eslint/lib/cli-engine/hash.js
var require_hash = __commonJS({
  "node_modules/eslint/lib/cli-engine/hash.js"(exports, module2) {
    "use strict";
    var murmur = require_imurmurhash();
    function hash(str) {
      return murmur(str).result().toString(36);
    }
    module2.exports = hash;
  }
});

// node_modules/flatted/cjs/index.js
var require_cjs3 = __commonJS({
  "node_modules/flatted/cjs/index.js"(exports) {
    "use strict";
    var { parse: $parse, stringify: $stringify } = JSON;
    var { keys: keys3 } = Object;
    var Primitive = String;
    var primitive = "string";
    var ignore = {};
    var object = "object";
    var noop = (_, value2) => value2;
    var primitives = (value2) => value2 instanceof Primitive ? Primitive(value2) : value2;
    var Primitives = (_, value2) => typeof value2 === primitive ? new Primitive(value2) : value2;
    var revive = (input, parsed, output, $2) => {
      const lazy = [];
      for (let ke = keys3(output), { length } = ke, y = 0; y < length; y++) {
        const k = ke[y];
        const value2 = output[k];
        if (value2 instanceof Primitive) {
          const tmp = input[value2];
          if (typeof tmp === object && !parsed.has(tmp)) {
            parsed.add(tmp);
            output[k] = ignore;
            lazy.push({ k, a: [input, parsed, tmp, $2] });
          } else
            output[k] = $2.call(output, k, tmp);
        } else if (output[k] !== ignore)
          output[k] = $2.call(output, k, value2);
      }
      for (let { length } = lazy, i = 0; i < length; i++) {
        const { k, a } = lazy[i];
        output[k] = $2.call(output, k, revive.apply(null, a));
      }
      return output;
    };
    var set = (known, input, value2) => {
      const index = Primitive(input.push(value2) - 1);
      known.set(value2, index);
      return index;
    };
    var parse3 = (text, reviver) => {
      const input = $parse(text, Primitives).map(primitives);
      const value2 = input[0];
      const $2 = reviver || noop;
      const tmp = typeof value2 === object && value2 ? revive(input, /* @__PURE__ */ new Set(), value2, $2) : value2;
      return $2.call({ "": tmp }, "", tmp);
    };
    exports.parse = parse3;
    var stringify = (value2, replacer, space) => {
      const $2 = replacer && typeof replacer === object ? (k, v) => k === "" || -1 < replacer.indexOf(k) ? v : void 0 : replacer || noop;
      const known = /* @__PURE__ */ new Map();
      const input = [];
      const output = [];
      let i = +set(known, input, $2.call({ "": value2 }, "", value2));
      let firstRun = !i;
      while (i < input.length) {
        firstRun = true;
        output[i] = $stringify(input[i++], replace, space);
      }
      return "[" + output.join(",") + "]";
      function replace(key, value3) {
        if (firstRun) {
          firstRun = !firstRun;
          return value3;
        }
        const after = $2.call(this, key, value3);
        switch (typeof after) {
          case object:
            if (after === null)
              return after;
          case primitive:
            return known.get(after) || set(known, input, after);
        }
        return after;
      }
    };
    exports.stringify = stringify;
    var toJSON = (any) => $parse(stringify(any));
    exports.toJSON = toJSON;
    var fromJSON = (any) => parse3($stringify(any));
    exports.fromJSON = fromJSON;
  }
});

// node_modules/flat-cache/src/utils.js
var require_utils4 = __commonJS({
  "node_modules/flat-cache/src/utils.js"(exports, module2) {
    var fs2 = require("fs");
    var path2 = require("path");
    var flatted = require_cjs3();
    module2.exports = {
      tryParse: function(filePath, defaultValue) {
        var result;
        try {
          result = this.readJSON(filePath);
        } catch (ex) {
          result = defaultValue;
        }
        return result;
      },
      /**
       * Read json file synchronously using flatted
       *
       * @method readJSON
       * @param  {String} filePath Json filepath
       * @returns {*} parse result
       */
      readJSON: function(filePath) {
        return flatted.parse(
          fs2.readFileSync(filePath, {
            encoding: "utf8"
          })
        );
      },
      /**
       * Write json file synchronously using circular-json
       *
       * @method writeJSON
       * @param  {String} filePath Json filepath
       * @param  {*} data Object to serialize
       */
      writeJSON: function(filePath, data) {
        fs2.mkdirSync(path2.dirname(filePath), {
          recursive: true
        });
        fs2.writeFileSync(filePath, flatted.stringify(data));
      }
    };
  }
});

// node_modules/rimraf/rimraf.js
var require_rimraf = __commonJS({
  "node_modules/rimraf/rimraf.js"(exports, module2) {
    var assert = require("assert");
    var path2 = require("path");
    var fs2 = require("fs");
    var glob2 = void 0;
    try {
      glob2 = require_glob();
    } catch (_err) {
    }
    var defaultGlobOpts = {
      nosort: true,
      silent: true
    };
    var timeout = 0;
    var isWindows = process.platform === "win32";
    var defaults = (options) => {
      const methods = [
        "unlink",
        "chmod",
        "stat",
        "lstat",
        "rmdir",
        "readdir"
      ];
      methods.forEach((m) => {
        options[m] = options[m] || fs2[m];
        m = m + "Sync";
        options[m] = options[m] || fs2[m];
      });
      options.maxBusyTries = options.maxBusyTries || 3;
      options.emfileWait = options.emfileWait || 1e3;
      if (options.glob === false) {
        options.disableGlob = true;
      }
      if (options.disableGlob !== true && glob2 === void 0) {
        throw Error("glob dependency not found, set `options.disableGlob = true` if intentional");
      }
      options.disableGlob = options.disableGlob || false;
      options.glob = options.glob || defaultGlobOpts;
    };
    var rimraf = (p, options, cb) => {
      if (typeof options === "function") {
        cb = options;
        options = {};
      }
      assert(p, "rimraf: missing path");
      assert.equal(typeof p, "string", "rimraf: path should be a string");
      assert.equal(typeof cb, "function", "rimraf: callback function required");
      assert(options, "rimraf: invalid options argument provided");
      assert.equal(typeof options, "object", "rimraf: options should be object");
      defaults(options);
      let busyTries = 0;
      let errState = null;
      let n = 0;
      const next = (er) => {
        errState = errState || er;
        if (--n === 0)
          cb(errState);
      };
      const afterGlob = (er, results) => {
        if (er)
          return cb(er);
        n = results.length;
        if (n === 0)
          return cb();
        results.forEach((p2) => {
          const CB = (er2) => {
            if (er2) {
              if ((er2.code === "EBUSY" || er2.code === "ENOTEMPTY" || er2.code === "EPERM") && busyTries < options.maxBusyTries) {
                busyTries++;
                return setTimeout(() => rimraf_(p2, options, CB), busyTries * 100);
              }
              if (er2.code === "EMFILE" && timeout < options.emfileWait) {
                return setTimeout(() => rimraf_(p2, options, CB), timeout++);
              }
              if (er2.code === "ENOENT")
                er2 = null;
            }
            timeout = 0;
            next(er2);
          };
          rimraf_(p2, options, CB);
        });
      };
      if (options.disableGlob || !glob2.hasMagic(p))
        return afterGlob(null, [p]);
      options.lstat(p, (er, stat) => {
        if (!er)
          return afterGlob(null, [p]);
        glob2(p, options.glob, afterGlob);
      });
    };
    var rimraf_ = (p, options, cb) => {
      assert(p);
      assert(options);
      assert(typeof cb === "function");
      options.lstat(p, (er, st) => {
        if (er && er.code === "ENOENT")
          return cb(null);
        if (er && er.code === "EPERM" && isWindows)
          fixWinEPERM(p, options, er, cb);
        if (st && st.isDirectory())
          return rmdir(p, options, er, cb);
        options.unlink(p, (er2) => {
          if (er2) {
            if (er2.code === "ENOENT")
              return cb(null);
            if (er2.code === "EPERM")
              return isWindows ? fixWinEPERM(p, options, er2, cb) : rmdir(p, options, er2, cb);
            if (er2.code === "EISDIR")
              return rmdir(p, options, er2, cb);
          }
          return cb(er2);
        });
      });
    };
    var fixWinEPERM = (p, options, er, cb) => {
      assert(p);
      assert(options);
      assert(typeof cb === "function");
      options.chmod(p, 438, (er2) => {
        if (er2)
          cb(er2.code === "ENOENT" ? null : er);
        else
          options.stat(p, (er3, stats) => {
            if (er3)
              cb(er3.code === "ENOENT" ? null : er);
            else if (stats.isDirectory())
              rmdir(p, options, er, cb);
            else
              options.unlink(p, cb);
          });
      });
    };
    var fixWinEPERMSync = (p, options, er) => {
      assert(p);
      assert(options);
      try {
        options.chmodSync(p, 438);
      } catch (er2) {
        if (er2.code === "ENOENT")
          return;
        else
          throw er;
      }
      let stats;
      try {
        stats = options.statSync(p);
      } catch (er3) {
        if (er3.code === "ENOENT")
          return;
        else
          throw er;
      }
      if (stats.isDirectory())
        rmdirSync(p, options, er);
      else
        options.unlinkSync(p);
    };
    var rmdir = (p, options, originalEr, cb) => {
      assert(p);
      assert(options);
      assert(typeof cb === "function");
      options.rmdir(p, (er) => {
        if (er && (er.code === "ENOTEMPTY" || er.code === "EEXIST" || er.code === "EPERM"))
          rmkids(p, options, cb);
        else if (er && er.code === "ENOTDIR")
          cb(originalEr);
        else
          cb(er);
      });
    };
    var rmkids = (p, options, cb) => {
      assert(p);
      assert(options);
      assert(typeof cb === "function");
      options.readdir(p, (er, files) => {
        if (er)
          return cb(er);
        let n = files.length;
        if (n === 0)
          return options.rmdir(p, cb);
        let errState;
        files.forEach((f) => {
          rimraf(path2.join(p, f), options, (er2) => {
            if (errState)
              return;
            if (er2)
              return cb(errState = er2);
            if (--n === 0)
              options.rmdir(p, cb);
          });
        });
      });
    };
    var rimrafSync = (p, options) => {
      options = options || {};
      defaults(options);
      assert(p, "rimraf: missing path");
      assert.equal(typeof p, "string", "rimraf: path should be a string");
      assert(options, "rimraf: missing options");
      assert.equal(typeof options, "object", "rimraf: options should be object");
      let results;
      if (options.disableGlob || !glob2.hasMagic(p)) {
        results = [p];
      } else {
        try {
          options.lstatSync(p);
          results = [p];
        } catch (er) {
          results = glob2.sync(p, options.glob);
        }
      }
      if (!results.length)
        return;
      for (let i = 0; i < results.length; i++) {
        const p2 = results[i];
        let st;
        try {
          st = options.lstatSync(p2);
        } catch (er) {
          if (er.code === "ENOENT")
            return;
          if (er.code === "EPERM" && isWindows)
            fixWinEPERMSync(p2, options, er);
        }
        try {
          if (st && st.isDirectory())
            rmdirSync(p2, options, null);
          else
            options.unlinkSync(p2);
        } catch (er) {
          if (er.code === "ENOENT")
            return;
          if (er.code === "EPERM")
            return isWindows ? fixWinEPERMSync(p2, options, er) : rmdirSync(p2, options, er);
          if (er.code !== "EISDIR")
            throw er;
          rmdirSync(p2, options, er);
        }
      }
    };
    var rmdirSync = (p, options, originalEr) => {
      assert(p);
      assert(options);
      try {
        options.rmdirSync(p);
      } catch (er) {
        if (er.code === "ENOENT")
          return;
        if (er.code === "ENOTDIR")
          throw originalEr;
        if (er.code === "ENOTEMPTY" || er.code === "EEXIST" || er.code === "EPERM")
          rmkidsSync(p, options);
      }
    };
    var rmkidsSync = (p, options) => {
      assert(p);
      assert(options);
      options.readdirSync(p).forEach((f) => rimrafSync(path2.join(p, f), options));
      const retries = isWindows ? 100 : 1;
      let i = 0;
      do {
        let threw = true;
        try {
          const ret = options.rmdirSync(p, options);
          threw = false;
          return ret;
        } finally {
          if (++i < retries && threw)
            continue;
        }
      } while (true);
    };
    module2.exports = rimraf;
    rimraf.sync = rimrafSync;
  }
});

// node_modules/flat-cache/src/del.js
var require_del = __commonJS({
  "node_modules/flat-cache/src/del.js"(exports, module2) {
    var rimraf = require_rimraf().sync;
    var fs2 = require("fs");
    module2.exports = function del(file) {
      if (fs2.existsSync(file)) {
        rimraf(file, {
          glob: false
        });
        return true;
      }
      return false;
    };
  }
});

// node_modules/flat-cache/src/cache.js
var require_cache2 = __commonJS({
  "node_modules/flat-cache/src/cache.js"(exports, module2) {
    var path2 = require("path");
    var fs2 = require("fs");
    var utils2 = require_utils4();
    var del = require_del();
    var writeJSON = utils2.writeJSON;
    var cache = {
      /**
       * Load a cache identified by the given Id. If the element does not exists, then initialize an empty
       * cache storage. If specified `cacheDir` will be used as the directory to persist the data to. If omitted
       * then the cache module directory `./cache` will be used instead
       *
       * @method load
       * @param docId {String} the id of the cache, would also be used as the name of the file cache
       * @param [cacheDir] {String} directory for the cache entry
       */
      load: function(docId, cacheDir) {
        var me = this;
        me._visited = {};
        me._persisted = {};
        me._pathToFile = cacheDir ? path2.resolve(cacheDir, docId) : path2.resolve(__dirname, "../.cache/", docId);
        if (fs2.existsSync(me._pathToFile)) {
          me._persisted = utils2.tryParse(me._pathToFile, {});
        }
      },
      /**
       * Load the cache from the provided file
       * @method loadFile
       * @param  {String} pathToFile the path to the file containing the info for the cache
       */
      loadFile: function(pathToFile) {
        var me = this;
        var dir = path2.dirname(pathToFile);
        var fName = path2.basename(pathToFile);
        me.load(fName, dir);
      },
      /**
       * Returns the entire persisted object
       * @method all
       * @returns {*}
       */
      all: function() {
        return this._persisted;
      },
      keys: function() {
        return Object.keys(this._persisted);
      },
      /**
       * sets a key to a given value
       * @method setKey
       * @param key {string} the key to set
       * @param value {object} the value of the key. Could be any object that can be serialized with JSON.stringify
       */
      setKey: function(key, value2) {
        this._visited[key] = true;
        this._persisted[key] = value2;
      },
      /**
       * remove a given key from the cache
       * @method removeKey
       * @param key {String} the key to remove from the object
       */
      removeKey: function(key) {
        delete this._visited[key];
        delete this._persisted[key];
      },
      /**
       * Return the value of the provided key
       * @method getKey
       * @param key {String} the name of the key to retrieve
       * @returns {*} the value from the key
       */
      getKey: function(key) {
        this._visited[key] = true;
        return this._persisted[key];
      },
      /**
       * Remove keys that were not accessed/set since the
       * last time the `prune` method was called.
       * @method _prune
       * @private
       */
      _prune: function() {
        var me = this;
        var obj = {};
        var keys3 = Object.keys(me._visited);
        if (keys3.length === 0) {
          return;
        }
        keys3.forEach(function(key) {
          obj[key] = me._persisted[key];
        });
        me._visited = {};
        me._persisted = obj;
      },
      /**
       * Save the state of the cache identified by the docId to disk
       * as a JSON structure
       * @param [noPrune=false] {Boolean} whether to remove from cache the non visited files
       * @method save
       */
      save: function(noPrune) {
        var me = this;
        !noPrune && me._prune();
        writeJSON(me._pathToFile, me._persisted);
      },
      /**
       * remove the file where the cache is persisted
       * @method removeCacheFile
       * @return {Boolean} true or false if the file was successfully deleted
       */
      removeCacheFile: function() {
        return del(this._pathToFile);
      },
      /**
       * Destroy the file cache and cache content.
       * @method destroy
       */
      destroy: function() {
        var me = this;
        me._visited = {};
        me._persisted = {};
        me.removeCacheFile();
      }
    };
    module2.exports = {
      /**
       * Alias for create. Should be considered depreacted. Will be removed in next releases
       *
       * @method load
       * @param docId {String} the id of the cache, would also be used as the name of the file cache
       * @param [cacheDir] {String} directory for the cache entry
       * @returns {cache} cache instance
       */
      load: function(docId, cacheDir) {
        return this.create(docId, cacheDir);
      },
      /**
       * Load a cache identified by the given Id. If the element does not exists, then initialize an empty
       * cache storage.
       *
       * @method create
       * @param docId {String} the id of the cache, would also be used as the name of the file cache
       * @param [cacheDir] {String} directory for the cache entry
       * @returns {cache} cache instance
       */
      create: function(docId, cacheDir) {
        var obj = Object.create(cache);
        obj.load(docId, cacheDir);
        return obj;
      },
      createFromFile: function(filePath) {
        var obj = Object.create(cache);
        obj.loadFile(filePath);
        return obj;
      },
      /**
       * Clear the cache identified by the given id. Caches stored in a different cache directory can be deleted directly
       *
       * @method clearCache
       * @param docId {String} the id of the cache, would also be used as the name of the file cache
       * @param cacheDir {String} the directory where the cache file was written
       * @returns {Boolean} true if the cache folder was deleted. False otherwise
       */
      clearCacheById: function(docId, cacheDir) {
        var filePath = cacheDir ? path2.resolve(cacheDir, docId) : path2.resolve(__dirname, "../.cache/", docId);
        return del(filePath);
      },
      /**
       * Remove all cache stored in the cache directory
       * @method clearAll
       * @returns {Boolean} true if the cache folder was deleted. False otherwise
       */
      clearAll: function(cacheDir) {
        var filePath = cacheDir ? path2.resolve(cacheDir) : path2.resolve(__dirname, "../.cache/");
        return del(filePath);
      }
    };
  }
});

// node_modules/file-entry-cache/cache.js
var require_cache3 = __commonJS({
  "node_modules/file-entry-cache/cache.js"(exports, module2) {
    var path2 = require("path");
    var crypto = require("crypto");
    module2.exports = {
      createFromFile: function(filePath, useChecksum) {
        var fname = path2.basename(filePath);
        var dir = path2.dirname(filePath);
        return this.create(fname, dir, useChecksum);
      },
      create: function(cacheId, _path, useChecksum) {
        var fs2 = require("fs");
        var flatCache = require_cache2();
        var cache = flatCache.load(cacheId, _path);
        var normalizedEntries = {};
        var removeNotFoundFiles = function removeNotFoundFiles2() {
          const cachedEntries = cache.keys();
          cachedEntries.forEach(function remover(fPath) {
            try {
              fs2.statSync(fPath);
            } catch (err) {
              if (err.code === "ENOENT") {
                cache.removeKey(fPath);
              }
            }
          });
        };
        removeNotFoundFiles();
        return {
          /**
           * the flat cache storage used to persist the metadata of the `files
           * @type {Object}
           */
          cache,
          /**
           * Given a buffer, calculate md5 hash of its content.
           * @method getHash
           * @param  {Buffer} buffer   buffer to calculate hash on
           * @return {String}          content hash digest
           */
          getHash: function(buffer) {
            return crypto.createHash("md5").update(buffer).digest("hex");
          },
          /**
           * Return whether or not a file has changed since last time reconcile was called.
           * @method hasFileChanged
           * @param  {String}  file  the filepath to check
           * @return {Boolean}       wheter or not the file has changed
           */
          hasFileChanged: function(file) {
            return this.getFileDescriptor(file).changed;
          },
          /**
           * given an array of file paths it return and object with three arrays:
           *  - changedFiles: Files that changed since previous run
           *  - notChangedFiles: Files that haven't change
           *  - notFoundFiles: Files that were not found, probably deleted
           *
           * @param  {Array} files the files to analyze and compare to the previous seen files
           * @return {[type]}       [description]
           */
          analyzeFiles: function(files) {
            var me = this;
            files = files || [];
            var res = {
              changedFiles: [],
              notFoundFiles: [],
              notChangedFiles: []
            };
            me.normalizeEntries(files).forEach(function(entry) {
              if (entry.changed) {
                res.changedFiles.push(entry.key);
                return;
              }
              if (entry.notFound) {
                res.notFoundFiles.push(entry.key);
                return;
              }
              res.notChangedFiles.push(entry.key);
            });
            return res;
          },
          getFileDescriptor: function(file) {
            var fstat;
            try {
              fstat = fs2.statSync(file);
            } catch (ex) {
              this.removeEntry(file);
              return { key: file, notFound: true, err: ex };
            }
            if (useChecksum) {
              return this._getFileDescriptorUsingChecksum(file);
            }
            return this._getFileDescriptorUsingMtimeAndSize(file, fstat);
          },
          _getFileDescriptorUsingMtimeAndSize: function(file, fstat) {
            var meta = cache.getKey(file);
            var cacheExists = !!meta;
            var cSize = fstat.size;
            var cTime = fstat.mtime.getTime();
            var isDifferentDate;
            var isDifferentSize;
            if (!meta) {
              meta = { size: cSize, mtime: cTime };
            } else {
              isDifferentDate = cTime !== meta.mtime;
              isDifferentSize = cSize !== meta.size;
            }
            var nEntry = normalizedEntries[file] = {
              key: file,
              changed: !cacheExists || isDifferentDate || isDifferentSize,
              meta
            };
            return nEntry;
          },
          _getFileDescriptorUsingChecksum: function(file) {
            var meta = cache.getKey(file);
            var cacheExists = !!meta;
            var contentBuffer;
            try {
              contentBuffer = fs2.readFileSync(file);
            } catch (ex) {
              contentBuffer = "";
            }
            var isDifferent = true;
            var hash = this.getHash(contentBuffer);
            if (!meta) {
              meta = { hash };
            } else {
              isDifferent = hash !== meta.hash;
            }
            var nEntry = normalizedEntries[file] = {
              key: file,
              changed: !cacheExists || isDifferent,
              meta
            };
            return nEntry;
          },
          /**
           * Return the list o the files that changed compared
           * against the ones stored in the cache
           *
           * @method getUpdated
           * @param files {Array} the array of files to compare against the ones in the cache
           * @returns {Array}
           */
          getUpdatedFiles: function(files) {
            var me = this;
            files = files || [];
            return me.normalizeEntries(files).filter(function(entry) {
              return entry.changed;
            }).map(function(entry) {
              return entry.key;
            });
          },
          /**
           * return the list of files
           * @method normalizeEntries
           * @param files
           * @returns {*}
           */
          normalizeEntries: function(files) {
            files = files || [];
            var me = this;
            var nEntries = files.map(function(file) {
              return me.getFileDescriptor(file);
            });
            return nEntries;
          },
          /**
           * Remove an entry from the file-entry-cache. Useful to force the file to still be considered
           * modified the next time the process is run
           *
           * @method removeEntry
           * @param entryName
           */
          removeEntry: function(entryName) {
            delete normalizedEntries[entryName];
            cache.removeKey(entryName);
          },
          /**
           * Delete the cache file from the disk
           * @method deleteCacheFile
           */
          deleteCacheFile: function() {
            cache.removeCacheFile();
          },
          /**
           * remove the cache from the file and clear the memory cache
           */
          destroy: function() {
            normalizedEntries = {};
            cache.destroy();
          },
          _getMetaForFileUsingCheckSum: function(cacheEntry) {
            var contentBuffer = fs2.readFileSync(cacheEntry.key);
            var hash = this.getHash(contentBuffer);
            var meta = Object.assign(cacheEntry.meta, { hash });
            delete meta.size;
            delete meta.mtime;
            return meta;
          },
          _getMetaForFileUsingMtimeAndSize: function(cacheEntry) {
            var stat = fs2.statSync(cacheEntry.key);
            var meta = Object.assign(cacheEntry.meta, {
              size: stat.size,
              mtime: stat.mtime.getTime()
            });
            delete meta.hash;
            return meta;
          },
          /**
           * Sync the files and persist them to the cache
           * @method reconcile
           */
          reconcile: function(noPrune) {
            removeNotFoundFiles();
            noPrune = typeof noPrune === "undefined" ? true : noPrune;
            var entries = normalizedEntries;
            var keys3 = Object.keys(entries);
            if (keys3.length === 0) {
              return;
            }
            var me = this;
            keys3.forEach(function(entryName) {
              var cacheEntry = entries[entryName];
              try {
                var meta = useChecksum ? me._getMetaForFileUsingCheckSum(cacheEntry) : me._getMetaForFileUsingMtimeAndSize(cacheEntry);
                cache.setKey(entryName, meta);
              } catch (err) {
                if (err.code !== "ENOENT") {
                  throw err;
                }
              }
            });
            cache.save(noPrune);
          }
        };
      }
    };
  }
});

// node_modules/json-stable-stringify-without-jsonify/index.js
var require_json_stable_stringify_without_jsonify = __commonJS({
  "node_modules/json-stable-stringify-without-jsonify/index.js"(exports, module2) {
    module2.exports = function(obj, opts) {
      if (!opts)
        opts = {};
      if (typeof opts === "function")
        opts = { cmp: opts };
      var space = opts.space || "";
      if (typeof space === "number")
        space = Array(space + 1).join(" ");
      var cycles = typeof opts.cycles === "boolean" ? opts.cycles : false;
      var replacer = opts.replacer || function(key, value2) {
        return value2;
      };
      var cmp = opts.cmp && function(f) {
        return function(node) {
          return function(a, b) {
            var aobj = { key: a, value: node[a] };
            var bobj = { key: b, value: node[b] };
            return f(aobj, bobj);
          };
        };
      }(opts.cmp);
      var seen = [];
      return function stringify(parent, key, node, level) {
        var indent = space ? "\n" + new Array(level + 1).join(space) : "";
        var colonSeparator = space ? ": " : ":";
        if (node && node.toJSON && typeof node.toJSON === "function") {
          node = node.toJSON();
        }
        node = replacer.call(parent, key, node);
        if (node === void 0) {
          return;
        }
        if (typeof node !== "object" || node === null) {
          return JSON.stringify(node);
        }
        if (isArray2(node)) {
          var out = [];
          for (var i = 0; i < node.length; i++) {
            var item = stringify(node, i, node[i], level + 1) || JSON.stringify(null);
            out.push(indent + space + item);
          }
          return "[" + out.join(",") + indent + "]";
        } else {
          if (seen.indexOf(node) !== -1) {
            if (cycles)
              return JSON.stringify("__cycle__");
            throw new TypeError("Converting circular structure to JSON");
          } else
            seen.push(node);
          var keys3 = objectKeys(node).sort(cmp && cmp(node));
          var out = [];
          for (var i = 0; i < keys3.length; i++) {
            var key = keys3[i];
            var value2 = stringify(node, key, node[key], level + 1);
            if (!value2)
              continue;
            var keyValue = JSON.stringify(key) + colonSeparator + value2;
            ;
            out.push(indent + space + keyValue);
          }
          seen.splice(seen.indexOf(node), 1);
          return "{" + out.join(",") + indent + "}";
        }
      }({ "": obj }, "", obj, 0);
    };
    var isArray2 = Array.isArray || function(x) {
      return {}.toString.call(x) === "[object Array]";
    };
    var objectKeys = Object.keys || function(obj) {
      var has = Object.prototype.hasOwnProperty || function() {
        return true;
      };
      var keys3 = [];
      for (var key in obj) {
        if (has.call(obj, key))
          keys3.push(key);
      }
      return keys3;
    };
  }
});

// node_modules/eslint/lib/cli-engine/lint-result-cache.js
var require_lint_result_cache = __commonJS({
  "node_modules/eslint/lib/cli-engine/lint-result-cache.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var fs2 = require("fs");
    var fileEntryCache = require_cache3();
    var stringify = require_json_stable_stringify_without_jsonify();
    var pkg = require_package4();
    var hash = require_hash();
    var debug = require_src()("eslint:lint-result-cache");
    var configHashCache = /* @__PURE__ */ new WeakMap();
    var nodeVersion = process && process.version;
    var validCacheStrategies = ["metadata", "content"];
    var invalidCacheStrategyErrorMessage = `Cache strategy must be one of: ${validCacheStrategies.map((strategy) => `"${strategy}"`).join(", ")}`;
    function isValidCacheStrategy(cacheStrategy) {
      return validCacheStrategies.includes(cacheStrategy);
    }
    function hashOfConfigFor(config) {
      if (!configHashCache.has(config)) {
        configHashCache.set(config, hash(`${pkg.version}_${nodeVersion}_${stringify(config)}`));
      }
      return configHashCache.get(config);
    }
    var LintResultCache = class {
      /**
       * Creates a new LintResultCache instance.
       * @param {string} cacheFileLocation The cache file location.
       * @param {"metadata" | "content"} cacheStrategy The cache strategy to use.
       */
      constructor(cacheFileLocation, cacheStrategy) {
        assert(cacheFileLocation, "Cache file location is required");
        assert(cacheStrategy, "Cache strategy is required");
        assert(
          isValidCacheStrategy(cacheStrategy),
          invalidCacheStrategyErrorMessage
        );
        debug(`Caching results to ${cacheFileLocation}`);
        const useChecksum = cacheStrategy === "content";
        debug(
          `Using "${cacheStrategy}" strategy to detect changes`
        );
        this.fileEntryCache = fileEntryCache.create(
          cacheFileLocation,
          void 0,
          useChecksum
        );
        this.cacheFileLocation = cacheFileLocation;
      }
      /**
       * Retrieve cached lint results for a given file path, if present in the
       * cache. If the file is present and has not been changed, rebuild any
       * missing result information.
       * @param {string} filePath The file for which to retrieve lint results.
       * @param {ConfigArray} config The config of the file.
       * @returns {Object|null} The rebuilt lint results, or null if the file is
       *   changed or not in the filesystem.
       */
      getCachedLintResults(filePath, config) {
        const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
        const hashOfConfig = hashOfConfigFor(config);
        const changed = fileDescriptor.changed || fileDescriptor.meta.hashOfConfig !== hashOfConfig;
        if (fileDescriptor.notFound) {
          debug(`File not found on the file system: ${filePath}`);
          return null;
        }
        if (changed) {
          debug(`Cache entry not found or no longer valid: ${filePath}`);
          return null;
        }
        if (fileDescriptor.meta.results && fileDescriptor.meta.results.source === null) {
          debug(`Rereading cached result source from filesystem: ${filePath}`);
          fileDescriptor.meta.results.source = fs2.readFileSync(filePath, "utf-8");
        }
        return fileDescriptor.meta.results;
      }
      /**
       * Set the cached lint results for a given file path, after removing any
       * information that will be both unnecessary and difficult to serialize.
       * Avoids caching results with an "output" property (meaning fixes were
       * applied), to prevent potentially incorrect results if fixes are not
       * written to disk.
       * @param {string} filePath The file for which to set lint results.
       * @param {ConfigArray} config The config of the file.
       * @param {Object} result The lint result to be set for the file.
       * @returns {void}
       */
      setCachedLintResults(filePath, config, result) {
        if (result && Object.prototype.hasOwnProperty.call(result, "output")) {
          return;
        }
        const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
        if (fileDescriptor && !fileDescriptor.notFound) {
          debug(`Updating cached result: ${filePath}`);
          const resultToSerialize = Object.assign({}, result);
          if (Object.prototype.hasOwnProperty.call(resultToSerialize, "source")) {
            resultToSerialize.source = null;
          }
          fileDescriptor.meta.results = resultToSerialize;
          fileDescriptor.meta.hashOfConfig = hashOfConfigFor(config);
        }
      }
      /**
       * Persists the in-memory cache to disk.
       * @returns {void}
       */
      reconcile() {
        debug(`Persisting cached results: ${this.cacheFileLocation}`);
        this.fileEntryCache.reconcile();
      }
    };
    module2.exports = LintResultCache;
  }
});

// node_modules/eslint/lib/cli-engine/cli-engine.js
var require_cli_engine = __commonJS({
  "node_modules/eslint/lib/cli-engine/cli-engine.js"(exports, module2) {
    "use strict";
    var fs2 = require("fs");
    var path2 = require("path");
    var defaultOptions2 = require_default_cli_options();
    var pkg = require_package4();
    var {
      Legacy: {
        ConfigOps,
        naming,
        CascadingConfigArrayFactory,
        IgnorePattern,
        getUsedExtractedConfigs,
        ModuleResolver
      }
    } = require_eslintrc();
    var { FileEnumerator } = require_file_enumerator();
    var { Linter } = require_linter2();
    var builtInRules = require_rules2();
    var loadRules = require_load_rules();
    var hash = require_hash();
    var LintResultCache = require_lint_result_cache();
    var debug = require_src()("eslint:cli-engine");
    var validFixTypes = /* @__PURE__ */ new Set(["directive", "problem", "suggestion", "layout"]);
    var internalSlotsMap = /* @__PURE__ */ new WeakMap();
    function validateFixTypes(fixTypes) {
      for (const fixType of fixTypes) {
        if (!validFixTypes.has(fixType)) {
          throw new Error(`Invalid fix type "${fixType}" found.`);
        }
      }
    }
    function calculateStatsPerFile(messages) {
      return messages.reduce((stat, message) => {
        if (message.fatal || message.severity === 2) {
          stat.errorCount++;
          if (message.fatal) {
            stat.fatalErrorCount++;
          }
          if (message.fix) {
            stat.fixableErrorCount++;
          }
        } else {
          stat.warningCount++;
          if (message.fix) {
            stat.fixableWarningCount++;
          }
        }
        return stat;
      }, {
        errorCount: 0,
        fatalErrorCount: 0,
        warningCount: 0,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      });
    }
    function calculateStatsPerRun(results) {
      return results.reduce((stat, result) => {
        stat.errorCount += result.errorCount;
        stat.fatalErrorCount += result.fatalErrorCount;
        stat.warningCount += result.warningCount;
        stat.fixableErrorCount += result.fixableErrorCount;
        stat.fixableWarningCount += result.fixableWarningCount;
        return stat;
      }, {
        errorCount: 0,
        fatalErrorCount: 0,
        warningCount: 0,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      });
    }
    function verifyText({
      text,
      cwd,
      filePath: providedFilePath,
      config,
      fix,
      allowInlineConfig,
      reportUnusedDisableDirectives,
      fileEnumerator,
      linter
    }) {
      const filePath = providedFilePath || "<text>";
      debug(`Lint ${filePath}`);
      const filePathToVerify = filePath === "<text>" ? path2.join(cwd, filePath) : filePath;
      const { fixed, messages, output } = linter.verifyAndFix(
        text,
        config,
        {
          allowInlineConfig,
          filename: filePathToVerify,
          fix,
          reportUnusedDisableDirectives,
          /**
           * Check if the linter should adopt a given code block or not.
           * @param {string} blockFilename The virtual filename of a code block.
           * @returns {boolean} `true` if the linter should adopt the code block.
           */
          filterCodeBlock(blockFilename) {
            return fileEnumerator.isTargetPath(blockFilename);
          }
        }
      );
      const result = {
        filePath,
        messages,
        suppressedMessages: linter.getSuppressedMessages(),
        ...calculateStatsPerFile(messages)
      };
      if (fixed) {
        result.output = output;
      }
      if (result.errorCount + result.warningCount > 0 && typeof result.output === "undefined") {
        result.source = text;
      }
      return result;
    }
    function createIgnoreResult(filePath, baseDir) {
      let message;
      const isHidden = filePath.split(path2.sep).find((segment) => /^\./u.test(segment));
      const isInNodeModules = baseDir && path2.relative(baseDir, filePath).startsWith("node_modules");
      if (isHidden) {
        message = `File ignored by default.  Use a negated ignore pattern (like "--ignore-pattern '!<relative/path/to/filename>'") to override.`;
      } else if (isInNodeModules) {
        message = `File ignored by default. Use "--ignore-pattern '!node_modules/*'" to override.`;
      } else {
        message = 'File ignored because of a matching ignore pattern. Use "--no-ignore" to override.';
      }
      return {
        filePath: path2.resolve(filePath),
        messages: [
          {
            fatal: false,
            severity: 1,
            message
          }
        ],
        suppressedMessages: [],
        errorCount: 0,
        fatalErrorCount: 0,
        warningCount: 1,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      };
    }
    function getRule(ruleId, configArrays) {
      for (const configArray of configArrays) {
        const rule = configArray.pluginRules.get(ruleId);
        if (rule) {
          return rule;
        }
      }
      return builtInRules.get(ruleId) || null;
    }
    function shouldMessageBeFixed(message, lastConfigArrays, fixTypes) {
      if (!message.ruleId) {
        return fixTypes.has("directive");
      }
      const rule = message.ruleId && getRule(message.ruleId, lastConfigArrays);
      return Boolean(rule && rule.meta && fixTypes.has(rule.meta.type));
    }
    function* iterateRuleDeprecationWarnings(usedConfigArrays) {
      const processedRuleIds = /* @__PURE__ */ new Set();
      const configs = usedConfigArrays.flatMap(getUsedExtractedConfigs);
      for (const config of configs) {
        for (const [ruleId, ruleConfig] of Object.entries(config.rules)) {
          if (processedRuleIds.has(ruleId)) {
            continue;
          }
          processedRuleIds.add(ruleId);
          if (!ConfigOps.getRuleSeverity(ruleConfig)) {
            continue;
          }
          const rule = getRule(ruleId, usedConfigArrays);
          if (!(rule && rule.meta && rule.meta.deprecated)) {
            continue;
          }
          yield {
            ruleId,
            replacedBy: rule.meta.replacedBy || []
          };
        }
      }
    }
    function isErrorMessage(message) {
      return message.severity === 2;
    }
    function getCacheFile(cacheFile, cwd) {
      const normalizedCacheFile = path2.normalize(cacheFile);
      const resolvedCacheFile = path2.resolve(cwd, normalizedCacheFile);
      const looksLikeADirectory = normalizedCacheFile.slice(-1) === path2.sep;
      function getCacheFileForDirectory() {
        return path2.join(resolvedCacheFile, `.cache_${hash(cwd)}`);
      }
      let fileStats;
      try {
        fileStats = fs2.lstatSync(resolvedCacheFile);
      } catch {
        fileStats = null;
      }
      if (fileStats) {
        if (fileStats.isDirectory() || looksLikeADirectory) {
          return getCacheFileForDirectory();
        }
        return resolvedCacheFile;
      }
      if (looksLikeADirectory) {
        return getCacheFileForDirectory();
      }
      return resolvedCacheFile;
    }
    function toBooleanMap(keys3, defaultValue, displayName) {
      if (keys3 && !Array.isArray(keys3)) {
        throw new Error(`${displayName} must be an array.`);
      }
      if (keys3 && keys3.length > 0) {
        return keys3.reduce((map, def) => {
          const [key, value2] = def.split(":");
          if (key !== "__proto__") {
            map[key] = value2 === void 0 ? defaultValue : value2 === "true";
          }
          return map;
        }, {});
      }
      return void 0;
    }
    function createConfigDataFromOptions(options) {
      const {
        ignorePattern,
        parser,
        parserOptions,
        plugins,
        rules
      } = options;
      const env = toBooleanMap(options.envs, true, "envs");
      const globals = toBooleanMap(options.globals, false, "globals");
      if (env === void 0 && globals === void 0 && (ignorePattern === void 0 || ignorePattern.length === 0) && parser === void 0 && parserOptions === void 0 && plugins === void 0 && rules === void 0) {
        return null;
      }
      return {
        env,
        globals,
        ignorePatterns: ignorePattern,
        parser,
        parserOptions,
        plugins,
        rules
      };
    }
    function directoryExists(resolvedPath) {
      try {
        return fs2.statSync(resolvedPath).isDirectory();
      } catch (error) {
        if (error && (error.code === "ENOENT" || error.code === "ENOTDIR")) {
          return false;
        }
        throw error;
      }
    }
    var CLIEngine = class {
      /**
       * Creates a new instance of the core CLI engine.
       * @param {CLIEngineOptions} providedOptions The options for this instance.
       * @param {Object} [additionalData] Additional settings that are not CLIEngineOptions.
       * @param {Record<string,Plugin>|null} [additionalData.preloadedPlugins] Preloaded plugins.
       */
      constructor(providedOptions, { preloadedPlugins } = {}) {
        const options = Object.assign(
          /* @__PURE__ */ Object.create(null),
          defaultOptions2,
          { cwd: process.cwd() },
          providedOptions
        );
        if (options.fix === void 0) {
          options.fix = false;
        }
        const additionalPluginPool = /* @__PURE__ */ new Map();
        if (preloadedPlugins) {
          for (const [id, plugin] of Object.entries(preloadedPlugins)) {
            additionalPluginPool.set(id, plugin);
          }
        }
        const cacheFilePath = getCacheFile(
          options.cacheLocation || options.cacheFile,
          options.cwd
        );
        const configArrayFactory = new CascadingConfigArrayFactory({
          additionalPluginPool,
          baseConfig: options.baseConfig || null,
          cliConfig: createConfigDataFromOptions(options),
          cwd: options.cwd,
          ignorePath: options.ignorePath,
          resolvePluginsRelativeTo: options.resolvePluginsRelativeTo,
          rulePaths: options.rulePaths,
          specificConfigPath: options.configFile,
          useEslintrc: options.useEslintrc,
          builtInRules,
          loadRules,
          getEslintRecommendedConfig: () => require_eslint_recommended(),
          getEslintAllConfig: () => require_eslint_all()
        });
        const fileEnumerator = new FileEnumerator({
          configArrayFactory,
          cwd: options.cwd,
          extensions: options.extensions,
          globInputPaths: options.globInputPaths,
          errorOnUnmatchedPattern: options.errorOnUnmatchedPattern,
          ignore: options.ignore
        });
        const lintResultCache = options.cache ? new LintResultCache(cacheFilePath, options.cacheStrategy) : null;
        const linter = new Linter({ cwd: options.cwd });
        const lastConfigArrays = [configArrayFactory.getConfigArrayForFile()];
        internalSlotsMap.set(this, {
          additionalPluginPool,
          cacheFilePath,
          configArrayFactory,
          defaultIgnores: IgnorePattern.createDefaultIgnore(options.cwd),
          fileEnumerator,
          lastConfigArrays,
          lintResultCache,
          linter,
          options
        });
        if (options.fix && options.fixTypes && options.fixTypes.length > 0) {
          debug(`Using fix types ${options.fixTypes}`);
          validateFixTypes(options.fixTypes);
          const fixTypes = new Set(options.fixTypes);
          const originalFix = typeof options.fix === "function" ? options.fix : () => true;
          options.fix = (message) => shouldMessageBeFixed(message, lastConfigArrays, fixTypes) && originalFix(message);
        }
      }
      getRules() {
        const { lastConfigArrays } = internalSlotsMap.get(this);
        return new Map(function* () {
          yield* builtInRules;
          for (const configArray of lastConfigArrays) {
            yield* configArray.pluginRules;
          }
        }());
      }
      /**
       * Returns results that only contains errors.
       * @param {LintResult[]} results The results to filter.
       * @returns {LintResult[]} The filtered results.
       */
      static getErrorResults(results) {
        const filtered = [];
        results.forEach((result) => {
          const filteredMessages = result.messages.filter(isErrorMessage);
          const filteredSuppressedMessages = result.suppressedMessages.filter(isErrorMessage);
          if (filteredMessages.length > 0) {
            filtered.push({
              ...result,
              messages: filteredMessages,
              suppressedMessages: filteredSuppressedMessages,
              errorCount: filteredMessages.length,
              warningCount: 0,
              fixableErrorCount: result.fixableErrorCount,
              fixableWarningCount: 0
            });
          }
        });
        return filtered;
      }
      /**
       * Outputs fixes from the given results to files.
       * @param {LintReport} report The report object created by CLIEngine.
       * @returns {void}
       */
      static outputFixes(report) {
        report.results.filter((result) => Object.prototype.hasOwnProperty.call(result, "output")).forEach((result) => {
          fs2.writeFileSync(result.filePath, result.output);
        });
      }
      /**
       * Resolves the patterns passed into executeOnFiles() into glob-based patterns
       * for easier handling.
       * @param {string[]} patterns The file patterns passed on the command line.
       * @returns {string[]} The equivalent glob patterns.
       */
      resolveFileGlobPatterns(patterns) {
        const { options } = internalSlotsMap.get(this);
        if (options.globInputPaths === false) {
          return patterns.filter(Boolean);
        }
        const extensions = (options.extensions || [".js"]).map((ext) => ext.replace(/^\./u, ""));
        const dirSuffix = `/**/*.{${extensions.join(",")}}`;
        return patterns.filter(Boolean).map((pathname) => {
          const resolvedPath = path2.resolve(options.cwd, pathname);
          const newPath = directoryExists(resolvedPath) ? pathname.replace(/[/\\]$/u, "") + dirSuffix : pathname;
          return path2.normalize(newPath).replace(/\\/gu, "/");
        });
      }
      /**
       * Executes the current configuration on an array of file and directory names.
       * @param {string[]} patterns An array of file and directory names.
       * @throws {Error} As may be thrown by `fs.unlinkSync`.
       * @returns {LintReport} The results for all files that were linted.
       */
      executeOnFiles(patterns) {
        const {
          cacheFilePath,
          fileEnumerator,
          lastConfigArrays,
          lintResultCache,
          linter,
          options: {
            allowInlineConfig,
            cache,
            cwd,
            fix,
            reportUnusedDisableDirectives
          }
        } = internalSlotsMap.get(this);
        const results = [];
        const startTime = Date.now();
        lastConfigArrays.length = 0;
        if (!cache) {
          try {
            fs2.unlinkSync(cacheFilePath);
          } catch (error) {
            const errorCode = error && error.code;
            if (errorCode !== "ENOENT" && !(errorCode === "EROFS" && !fs2.existsSync(cacheFilePath))) {
              throw error;
            }
          }
        }
        for (const { config, filePath, ignored } of fileEnumerator.iterateFiles(patterns)) {
          if (ignored) {
            results.push(createIgnoreResult(filePath, cwd));
            continue;
          }
          if (!lastConfigArrays.includes(config)) {
            lastConfigArrays.push(config);
          }
          if (lintResultCache) {
            const cachedResult = lintResultCache.getCachedLintResults(filePath, config);
            if (cachedResult) {
              const hadMessages = cachedResult.messages && cachedResult.messages.length > 0;
              if (hadMessages && fix) {
                debug(`Reprocessing cached file to allow autofix: ${filePath}`);
              } else {
                debug(`Skipping file since it hasn't changed: ${filePath}`);
                results.push(cachedResult);
                continue;
              }
            }
          }
          const result = verifyText({
            text: fs2.readFileSync(filePath, "utf8"),
            filePath,
            config,
            cwd,
            fix,
            allowInlineConfig,
            reportUnusedDisableDirectives,
            fileEnumerator,
            linter
          });
          results.push(result);
          if (lintResultCache) {
            lintResultCache.setCachedLintResults(filePath, config, result);
          }
        }
        if (lintResultCache) {
          lintResultCache.reconcile();
        }
        debug(`Linting complete in: ${Date.now() - startTime}ms`);
        let usedDeprecatedRules;
        return {
          results,
          ...calculateStatsPerRun(results),
          // Initialize it lazily because CLI and `ESLint` API don't use it.
          get usedDeprecatedRules() {
            if (!usedDeprecatedRules) {
              usedDeprecatedRules = Array.from(
                iterateRuleDeprecationWarnings(lastConfigArrays)
              );
            }
            return usedDeprecatedRules;
          }
        };
      }
      /**
       * Executes the current configuration on text.
       * @param {string} text A string of JavaScript code to lint.
       * @param {string} [filename] An optional string representing the texts filename.
       * @param {boolean} [warnIgnored] Always warn when a file is ignored
       * @returns {LintReport} The results for the linting.
       */
      executeOnText(text, filename, warnIgnored) {
        const {
          configArrayFactory,
          fileEnumerator,
          lastConfigArrays,
          linter,
          options: {
            allowInlineConfig,
            cwd,
            fix,
            reportUnusedDisableDirectives
          }
        } = internalSlotsMap.get(this);
        const results = [];
        const startTime = Date.now();
        const resolvedFilename = filename && path2.resolve(cwd, filename);
        lastConfigArrays.length = 0;
        if (resolvedFilename && this.isPathIgnored(resolvedFilename)) {
          if (warnIgnored) {
            results.push(createIgnoreResult(resolvedFilename, cwd));
          }
        } else {
          const config = configArrayFactory.getConfigArrayForFile(
            resolvedFilename || "__placeholder__.js"
          );
          lastConfigArrays.push(config);
          results.push(verifyText({
            text,
            filePath: resolvedFilename,
            config,
            cwd,
            fix,
            allowInlineConfig,
            reportUnusedDisableDirectives,
            fileEnumerator,
            linter
          }));
        }
        debug(`Linting complete in: ${Date.now() - startTime}ms`);
        let usedDeprecatedRules;
        return {
          results,
          ...calculateStatsPerRun(results),
          // Initialize it lazily because CLI and `ESLint` API don't use it.
          get usedDeprecatedRules() {
            if (!usedDeprecatedRules) {
              usedDeprecatedRules = Array.from(
                iterateRuleDeprecationWarnings(lastConfigArrays)
              );
            }
            return usedDeprecatedRules;
          }
        };
      }
      /**
       * Returns a configuration object for the given file based on the CLI options.
       * This is the same logic used by the ESLint CLI executable to determine
       * configuration for each file it processes.
       * @param {string} filePath The path of the file to retrieve a config object for.
       * @throws {Error} If filepath a directory path.
       * @returns {ConfigData} A configuration object for the file.
       */
      getConfigForFile(filePath) {
        const { configArrayFactory, options } = internalSlotsMap.get(this);
        const absolutePath = path2.resolve(options.cwd, filePath);
        if (directoryExists(absolutePath)) {
          throw Object.assign(
            new Error("'filePath' should not be a directory path."),
            { messageTemplate: "print-config-with-directory-path" }
          );
        }
        return configArrayFactory.getConfigArrayForFile(absolutePath).extractConfig(absolutePath).toCompatibleObjectAsConfigFileContent();
      }
      /**
       * Checks if a given path is ignored by ESLint.
       * @param {string} filePath The path of the file to check.
       * @returns {boolean} Whether or not the given path is ignored.
       */
      isPathIgnored(filePath) {
        const {
          configArrayFactory,
          defaultIgnores,
          options: { cwd, ignore }
        } = internalSlotsMap.get(this);
        const absolutePath = path2.resolve(cwd, filePath);
        if (ignore) {
          const config = configArrayFactory.getConfigArrayForFile(absolutePath).extractConfig(absolutePath);
          const ignores = config.ignores || defaultIgnores;
          return ignores(absolutePath);
        }
        return defaultIgnores(absolutePath);
      }
      /**
       * Returns the formatter representing the given format or null if the `format` is not a string.
       * @param {string} [format] The name of the format to load or the path to a
       *      custom formatter.
       * @throws {any} As may be thrown by requiring of formatter
       * @returns {(FormatterFunction|null)} The formatter function or null if the `format` is not a string.
       */
      getFormatter(format2) {
        const resolvedFormatName = format2 || "stylish";
        if (typeof resolvedFormatName === "string") {
          const normalizedFormatName = resolvedFormatName.replace(/\\/gu, "/");
          const slots = internalSlotsMap.get(this);
          const cwd = slots ? slots.options.cwd : process.cwd();
          const namespace = naming.getNamespaceFromTerm(normalizedFormatName);
          let formatterPath;
          if (!namespace && normalizedFormatName.includes("/")) {
            formatterPath = path2.resolve(cwd, normalizedFormatName);
          } else {
            try {
              const npmFormat = naming.normalizePackageName(normalizedFormatName, "eslint-formatter");
              formatterPath = ModuleResolver.resolve(npmFormat, path2.join(cwd, "__placeholder__.js"));
            } catch {
              formatterPath = path2.resolve(__dirname, "formatters", normalizedFormatName);
            }
          }
          try {
            return require(formatterPath);
          } catch (ex) {
            if (format2 === "table" || format2 === "codeframe") {
              ex.message = `The ${format2} formatter is no longer part of core ESLint. Install it manually with \`npm install -D eslint-formatter-${format2}\``;
            } else {
              ex.message = `There was a problem loading formatter: ${formatterPath}
Error: ${ex.message}`;
            }
            throw ex;
          }
        } else {
          return null;
        }
      }
    };
    CLIEngine.version = pkg.version;
    CLIEngine.getFormatter = CLIEngine.prototype.getFormatter;
    module2.exports = {
      CLIEngine,
      /**
       * Get the internal slots of a given CLIEngine instance for tests.
       * @param {CLIEngine} instance The CLIEngine instance to get.
       * @returns {CLIEngineInternalSlots} The internal slots.
       */
      getCLIEngineInternalSlots(instance) {
        return internalSlotsMap.get(instance);
      }
    };
  }
});

// node_modules/eslint/lib/eslint/eslint.js
var require_eslint = __commonJS({
  "node_modules/eslint/lib/eslint/eslint.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var fs2 = require("fs");
    var { promisify } = require("util");
    var { CLIEngine, getCLIEngineInternalSlots } = require_cli_engine();
    var BuiltinRules = require_rules2();
    var {
      Legacy: {
        ConfigOps: {
          getRuleSeverity
        }
      }
    } = require_eslintrc();
    var { version: version2 } = require_package4();
    var writeFile2 = promisify(fs2.writeFile);
    var privateMembersMap = /* @__PURE__ */ new WeakMap();
    function isNonEmptyString(x) {
      return typeof x === "string" && x.trim() !== "";
    }
    function isArrayOfNonEmptyString(x) {
      return Array.isArray(x) && x.every(isNonEmptyString);
    }
    function isFixType(x) {
      return x === "directive" || x === "problem" || x === "suggestion" || x === "layout";
    }
    function isFixTypeArray(x) {
      return Array.isArray(x) && x.every(isFixType);
    }
    var ESLintInvalidOptionsError = class _ESLintInvalidOptionsError extends Error {
      constructor(messages) {
        super(`Invalid Options:
- ${messages.join("\n- ")}`);
        this.code = "ESLINT_INVALID_OPTIONS";
        Error.captureStackTrace(this, _ESLintInvalidOptionsError);
      }
    };
    function processOptions({
      allowInlineConfig = true,
      // ← we cannot use `overrideConfig.noInlineConfig` instead because `allowInlineConfig` has side-effect that suppress warnings that show inline configs are ignored.
      baseConfig = null,
      cache = false,
      cacheLocation = ".eslintcache",
      cacheStrategy = "metadata",
      cwd = process.cwd(),
      errorOnUnmatchedPattern = true,
      extensions = null,
      // ← should be null by default because if it's an array then it suppresses RFC20 feature.
      fix = false,
      fixTypes = null,
      // ← should be null by default because if it's an array then it suppresses rules that don't have the `meta.type` property.
      globInputPaths = true,
      ignore = true,
      ignorePath = null,
      // ← should be null by default because if it's a string then it may throw ENOENT.
      overrideConfig = null,
      overrideConfigFile = null,
      plugins = {},
      reportUnusedDisableDirectives = null,
      // ← should be null by default because if it's a string then it overrides the 'reportUnusedDisableDirectives' setting in config files. And we cannot use `overrideConfig.reportUnusedDisableDirectives` instead because we cannot configure the `error` severity with that.
      resolvePluginsRelativeTo = null,
      // ← should be null by default because if it's a string then it suppresses RFC47 feature.
      rulePaths = [],
      useEslintrc = true,
      ...unknownOptions
    }) {
      const errors = [];
      const unknownOptionKeys = Object.keys(unknownOptions);
      if (unknownOptionKeys.length >= 1) {
        errors.push(`Unknown options: ${unknownOptionKeys.join(", ")}`);
        if (unknownOptionKeys.includes("cacheFile")) {
          errors.push("'cacheFile' has been removed. Please use the 'cacheLocation' option instead.");
        }
        if (unknownOptionKeys.includes("configFile")) {
          errors.push("'configFile' has been removed. Please use the 'overrideConfigFile' option instead.");
        }
        if (unknownOptionKeys.includes("envs")) {
          errors.push("'envs' has been removed. Please use the 'overrideConfig.env' option instead.");
        }
        if (unknownOptionKeys.includes("globals")) {
          errors.push("'globals' has been removed. Please use the 'overrideConfig.globals' option instead.");
        }
        if (unknownOptionKeys.includes("ignorePattern")) {
          errors.push("'ignorePattern' has been removed. Please use the 'overrideConfig.ignorePatterns' option instead.");
        }
        if (unknownOptionKeys.includes("parser")) {
          errors.push("'parser' has been removed. Please use the 'overrideConfig.parser' option instead.");
        }
        if (unknownOptionKeys.includes("parserOptions")) {
          errors.push("'parserOptions' has been removed. Please use the 'overrideConfig.parserOptions' option instead.");
        }
        if (unknownOptionKeys.includes("rules")) {
          errors.push("'rules' has been removed. Please use the 'overrideConfig.rules' option instead.");
        }
      }
      if (typeof allowInlineConfig !== "boolean") {
        errors.push("'allowInlineConfig' must be a boolean.");
      }
      if (typeof baseConfig !== "object") {
        errors.push("'baseConfig' must be an object or null.");
      }
      if (typeof cache !== "boolean") {
        errors.push("'cache' must be a boolean.");
      }
      if (!isNonEmptyString(cacheLocation)) {
        errors.push("'cacheLocation' must be a non-empty string.");
      }
      if (cacheStrategy !== "metadata" && cacheStrategy !== "content") {
        errors.push(`'cacheStrategy' must be any of "metadata", "content".`);
      }
      if (!isNonEmptyString(cwd) || !path2.isAbsolute(cwd)) {
        errors.push("'cwd' must be an absolute path.");
      }
      if (typeof errorOnUnmatchedPattern !== "boolean") {
        errors.push("'errorOnUnmatchedPattern' must be a boolean.");
      }
      if (!isArrayOfNonEmptyString(extensions) && extensions !== null) {
        errors.push("'extensions' must be an array of non-empty strings or null.");
      }
      if (typeof fix !== "boolean" && typeof fix !== "function") {
        errors.push("'fix' must be a boolean or a function.");
      }
      if (fixTypes !== null && !isFixTypeArray(fixTypes)) {
        errors.push(`'fixTypes' must be an array of any of "directive", "problem", "suggestion", and "layout".`);
      }
      if (typeof globInputPaths !== "boolean") {
        errors.push("'globInputPaths' must be a boolean.");
      }
      if (typeof ignore !== "boolean") {
        errors.push("'ignore' must be a boolean.");
      }
      if (!isNonEmptyString(ignorePath) && ignorePath !== null) {
        errors.push("'ignorePath' must be a non-empty string or null.");
      }
      if (typeof overrideConfig !== "object") {
        errors.push("'overrideConfig' must be an object or null.");
      }
      if (!isNonEmptyString(overrideConfigFile) && overrideConfigFile !== null) {
        errors.push("'overrideConfigFile' must be a non-empty string or null.");
      }
      if (typeof plugins !== "object") {
        errors.push("'plugins' must be an object or null.");
      } else if (plugins !== null && Object.keys(plugins).includes("")) {
        errors.push("'plugins' must not include an empty string.");
      }
      if (Array.isArray(plugins)) {
        errors.push("'plugins' doesn't add plugins to configuration to load. Please use the 'overrideConfig.plugins' option instead.");
      }
      if (reportUnusedDisableDirectives !== "error" && reportUnusedDisableDirectives !== "warn" && reportUnusedDisableDirectives !== "off" && reportUnusedDisableDirectives !== null) {
        errors.push(`'reportUnusedDisableDirectives' must be any of "error", "warn", "off", and null.`);
      }
      if (!isNonEmptyString(resolvePluginsRelativeTo) && resolvePluginsRelativeTo !== null) {
        errors.push("'resolvePluginsRelativeTo' must be a non-empty string or null.");
      }
      if (!isArrayOfNonEmptyString(rulePaths)) {
        errors.push("'rulePaths' must be an array of non-empty strings.");
      }
      if (typeof useEslintrc !== "boolean") {
        errors.push("'useEslintrc' must be a boolean.");
      }
      if (errors.length > 0) {
        throw new ESLintInvalidOptionsError(errors);
      }
      return {
        allowInlineConfig,
        baseConfig,
        cache,
        cacheLocation,
        cacheStrategy,
        configFile: overrideConfigFile,
        cwd,
        errorOnUnmatchedPattern,
        extensions,
        fix,
        fixTypes,
        globInputPaths,
        ignore,
        ignorePath,
        reportUnusedDisableDirectives,
        resolvePluginsRelativeTo,
        rulePaths,
        useEslintrc
      };
    }
    function hasDefinedProperty(obj) {
      if (typeof obj === "object" && obj !== null) {
        for (const key in obj) {
          if (typeof obj[key] !== "undefined") {
            return true;
          }
        }
      }
      return false;
    }
    function createRulesMeta(rules) {
      return Array.from(rules).reduce((retVal, [id, rule]) => {
        retVal[id] = rule.meta;
        return retVal;
      }, {});
    }
    var usedDeprecatedRulesCache = /* @__PURE__ */ new WeakMap();
    function getOrFindUsedDeprecatedRules(cliEngine, maybeFilePath) {
      const {
        configArrayFactory,
        options: { cwd }
      } = getCLIEngineInternalSlots(cliEngine);
      const filePath = path2.isAbsolute(maybeFilePath) ? maybeFilePath : path2.join(cwd, "__placeholder__.js");
      const configArray = configArrayFactory.getConfigArrayForFile(filePath);
      const config = configArray.extractConfig(filePath);
      if (!usedDeprecatedRulesCache.has(config)) {
        const pluginRules = configArray.pluginRules;
        const retv = [];
        for (const [ruleId, ruleConf] of Object.entries(config.rules)) {
          if (getRuleSeverity(ruleConf) === 0) {
            continue;
          }
          const rule = pluginRules.get(ruleId) || BuiltinRules.get(ruleId);
          const meta = rule && rule.meta;
          if (meta && meta.deprecated) {
            retv.push({ ruleId, replacedBy: meta.replacedBy || [] });
          }
        }
        usedDeprecatedRulesCache.set(config, Object.freeze(retv));
      }
      return usedDeprecatedRulesCache.get(config);
    }
    function processCLIEngineLintReport(cliEngine, { results }) {
      const descriptor = {
        configurable: true,
        enumerable: true,
        get() {
          return getOrFindUsedDeprecatedRules(cliEngine, this.filePath);
        }
      };
      for (const result of results) {
        Object.defineProperty(result, "usedDeprecatedRules", descriptor);
      }
      return results;
    }
    function compareResultsByFilePath(a, b) {
      if (a.filePath < b.filePath) {
        return -1;
      }
      if (a.filePath > b.filePath) {
        return 1;
      }
      return 0;
    }
    var ESLint = class {
      /**
       * Creates a new instance of the main ESLint API.
       * @param {ESLintOptions} options The options for this instance.
       */
      constructor(options = {}) {
        const processedOptions = processOptions(options);
        const cliEngine = new CLIEngine(processedOptions, { preloadedPlugins: options.plugins });
        const {
          configArrayFactory,
          lastConfigArrays
        } = getCLIEngineInternalSlots(cliEngine);
        let updated = false;
        if (hasDefinedProperty(options.overrideConfig)) {
          configArrayFactory.setOverrideConfig(options.overrideConfig);
          updated = true;
        }
        if (updated) {
          configArrayFactory.clearCache();
          lastConfigArrays[0] = configArrayFactory.getConfigArrayForFile();
        }
        privateMembersMap.set(this, {
          cliEngine,
          options: processedOptions
        });
      }
      /**
       * The version text.
       * @type {string}
       */
      static get version() {
        return version2;
      }
      /**
       * Outputs fixes from the given results to files.
       * @param {LintResult[]} results The lint results.
       * @returns {Promise<void>} Returns a promise that is used to track side effects.
       */
      static async outputFixes(results) {
        if (!Array.isArray(results)) {
          throw new Error("'results' must be an array");
        }
        await Promise.all(
          results.filter((result) => {
            if (typeof result !== "object" || result === null) {
              throw new Error("'results' must include only objects");
            }
            return typeof result.output === "string" && path2.isAbsolute(result.filePath);
          }).map((r) => writeFile2(r.filePath, r.output))
        );
      }
      /**
       * Returns results that only contains errors.
       * @param {LintResult[]} results The results to filter.
       * @returns {LintResult[]} The filtered results.
       */
      static getErrorResults(results) {
        return CLIEngine.getErrorResults(results);
      }
      /**
       * Returns meta objects for each rule represented in the lint results.
       * @param {LintResult[]} results The results to fetch rules meta for.
       * @returns {Object} A mapping of ruleIds to rule meta objects.
       */
      getRulesMetaForResults(results) {
        const resultRuleIds = /* @__PURE__ */ new Set();
        for (const result of results) {
          for (const { ruleId } of result.messages) {
            resultRuleIds.add(ruleId);
          }
          for (const { ruleId } of result.suppressedMessages) {
            resultRuleIds.add(ruleId);
          }
        }
        const { cliEngine } = privateMembersMap.get(this);
        const rules = cliEngine.getRules();
        const resultRules = /* @__PURE__ */ new Map();
        for (const [ruleId, rule] of rules) {
          if (resultRuleIds.has(ruleId)) {
            resultRules.set(ruleId, rule);
          }
        }
        return createRulesMeta(resultRules);
      }
      /**
       * Executes the current configuration on an array of file and directory names.
       * @param {string[]} patterns An array of file and directory names.
       * @returns {Promise<LintResult[]>} The results of linting the file patterns given.
       */
      async lintFiles(patterns) {
        if (!isNonEmptyString(patterns) && !isArrayOfNonEmptyString(patterns)) {
          throw new Error("'patterns' must be a non-empty string or an array of non-empty strings");
        }
        const { cliEngine } = privateMembersMap.get(this);
        return processCLIEngineLintReport(
          cliEngine,
          cliEngine.executeOnFiles(patterns)
        );
      }
      /**
       * Executes the current configuration on text.
       * @param {string} code A string of JavaScript code to lint.
       * @param {Object} [options] The options.
       * @param {string} [options.filePath] The path to the file of the source code.
       * @param {boolean} [options.warnIgnored] When set to true, warn if given filePath is an ignored path.
       * @returns {Promise<LintResult[]>} The results of linting the string of code given.
       */
      async lintText(code, options = {}) {
        if (typeof code !== "string") {
          throw new Error("'code' must be a string");
        }
        if (typeof options !== "object") {
          throw new Error("'options' must be an object, null, or undefined");
        }
        const {
          filePath,
          warnIgnored = false,
          ...unknownOptions
        } = options || {};
        const unknownOptionKeys = Object.keys(unknownOptions);
        if (unknownOptionKeys.length > 0) {
          throw new Error(`'options' must not include the unknown option(s): ${unknownOptionKeys.join(", ")}`);
        }
        if (filePath !== void 0 && !isNonEmptyString(filePath)) {
          throw new Error("'options.filePath' must be a non-empty string or undefined");
        }
        if (typeof warnIgnored !== "boolean") {
          throw new Error("'options.warnIgnored' must be a boolean or undefined");
        }
        const { cliEngine } = privateMembersMap.get(this);
        return processCLIEngineLintReport(
          cliEngine,
          cliEngine.executeOnText(code, filePath, warnIgnored)
        );
      }
      /**
       * Returns the formatter representing the given formatter name.
       * @param {string} [name] The name of the formatter to load.
       * The following values are allowed:
       * - `undefined` ... Load `stylish` builtin formatter.
       * - A builtin formatter name ... Load the builtin formatter.
       * - A third-party formatter name:
       *   - `foo` → `eslint-formatter-foo`
       *   - `@foo` → `@foo/eslint-formatter`
       *   - `@foo/bar` → `@foo/eslint-formatter-bar`
       * - A file path ... Load the file.
       * @returns {Promise<LoadedFormatter>} A promise resolving to the formatter object.
       * This promise will be rejected if the given formatter was not found or not
       * a function.
       */
      async loadFormatter(name = "stylish") {
        if (typeof name !== "string") {
          throw new Error("'name' must be a string");
        }
        const { cliEngine, options } = privateMembersMap.get(this);
        const formatter = cliEngine.getFormatter(name);
        if (typeof formatter !== "function") {
          throw new Error(`Formatter must be a function, but got a ${typeof formatter}.`);
        }
        return {
          /**
           * The main formatter method.
           * @param {LintResult[]} results The lint results to format.
           * @param {ResultsMeta} resultsMeta Warning count and max threshold.
           * @returns {string | Promise<string>} The formatted lint results.
           */
          format(results, resultsMeta) {
            let rulesMeta = null;
            results.sort(compareResultsByFilePath);
            return formatter(results, {
              ...resultsMeta,
              get cwd() {
                return options.cwd;
              },
              get rulesMeta() {
                if (!rulesMeta) {
                  rulesMeta = createRulesMeta(cliEngine.getRules());
                }
                return rulesMeta;
              }
            });
          }
        };
      }
      /**
       * Returns a configuration object for the given file based on the CLI options.
       * This is the same logic used by the ESLint CLI executable to determine
       * configuration for each file it processes.
       * @param {string} filePath The path of the file to retrieve a config object for.
       * @returns {Promise<ConfigData>} A configuration object for the file.
       */
      async calculateConfigForFile(filePath) {
        if (!isNonEmptyString(filePath)) {
          throw new Error("'filePath' must be a non-empty string");
        }
        const { cliEngine } = privateMembersMap.get(this);
        return cliEngine.getConfigForFile(filePath);
      }
      /**
       * Checks if a given path is ignored by ESLint.
       * @param {string} filePath The path of the file to check.
       * @returns {Promise<boolean>} Whether or not the given path is ignored.
       */
      async isPathIgnored(filePath) {
        if (!isNonEmptyString(filePath)) {
          throw new Error("'filePath' must be a non-empty string");
        }
        const { cliEngine } = privateMembersMap.get(this);
        return cliEngine.isPathIgnored(filePath);
      }
    };
    module2.exports = {
      ESLint,
      /**
       * Get the private class members of a given ESLint instance for tests.
       * @param {ESLint} instance The ESLint instance to get.
       * @returns {ESLintPrivateMembers} The instance's private class members.
       */
      getESLintPrivateMembers(instance) {
        return privateMembersMap.get(instance);
      }
    };
  }
});

// node_modules/yocto-queue/index.js
var require_yocto_queue = __commonJS({
  "node_modules/yocto-queue/index.js"(exports, module2) {
    var Node2 = class {
      /// value;
      /// next;
      constructor(value2) {
        this.value = value2;
        this.next = void 0;
      }
    };
    var Queue = class {
      // TODO: Use private class fields when targeting Node.js 12.
      // #_head;
      // #_tail;
      // #_size;
      constructor() {
        this.clear();
      }
      enqueue(value2) {
        const node = new Node2(value2);
        if (this._head) {
          this._tail.next = node;
          this._tail = node;
        } else {
          this._head = node;
          this._tail = node;
        }
        this._size++;
      }
      dequeue() {
        const current = this._head;
        if (!current) {
          return;
        }
        this._head = this._head.next;
        this._size--;
        return current.value;
      }
      clear() {
        this._head = void 0;
        this._tail = void 0;
        this._size = 0;
      }
      get size() {
        return this._size;
      }
      *[Symbol.iterator]() {
        let current = this._head;
        while (current) {
          yield current.value;
          current = current.next;
        }
      }
    };
    module2.exports = Queue;
  }
});

// node_modules/p-limit/index.js
var require_p_limit = __commonJS({
  "node_modules/p-limit/index.js"(exports, module2) {
    "use strict";
    var Queue = require_yocto_queue();
    var pLimit = (concurrency) => {
      if (!((Number.isInteger(concurrency) || concurrency === Infinity) && concurrency > 0)) {
        throw new TypeError("Expected `concurrency` to be a number from 1 and up");
      }
      const queue = new Queue();
      let activeCount = 0;
      const next = () => {
        activeCount--;
        if (queue.size > 0) {
          queue.dequeue()();
        }
      };
      const run = async (fn, resolve, ...args) => {
        activeCount++;
        const result = (async () => fn(...args))();
        resolve(result);
        try {
          await result;
        } catch {
        }
        next();
      };
      const enqueue = (fn, resolve, ...args) => {
        queue.enqueue(run.bind(null, fn, resolve, ...args));
        (async () => {
          await Promise.resolve();
          if (activeCount < concurrency && queue.size > 0) {
            queue.dequeue()();
          }
        })();
      };
      const generator = (fn, ...args) => new Promise((resolve) => {
        enqueue(fn, resolve, ...args);
      });
      Object.defineProperties(generator, {
        activeCount: {
          get: () => activeCount
        },
        pendingCount: {
          get: () => queue.size
        },
        clearQueue: {
          value: () => {
            queue.clear();
          }
        }
      });
      return generator;
    };
    module2.exports = pLimit;
  }
});

// node_modules/eslint/node_modules/p-locate/index.js
var require_p_locate = __commonJS({
  "node_modules/eslint/node_modules/p-locate/index.js"(exports, module2) {
    "use strict";
    var pLimit = require_p_limit();
    var EndError = class extends Error {
      constructor(value2) {
        super();
        this.value = value2;
      }
    };
    var testElement = async (element, tester) => tester(await element);
    var finder = async (element) => {
      const values2 = await Promise.all(element);
      if (values2[1] === true) {
        throw new EndError(values2[0]);
      }
      return false;
    };
    var pLocate = async (iterable, tester, options) => {
      options = {
        concurrency: Infinity,
        preserveOrder: true,
        ...options
      };
      const limit = pLimit(options.concurrency);
      const items = [...iterable].map((element) => [element, limit(testElement, element, tester)]);
      const checkLimit = pLimit(options.preserveOrder ? 1 : Infinity);
      try {
        await Promise.all(items.map((element) => checkLimit(finder, element)));
      } catch (error) {
        if (error instanceof EndError) {
          return error.value;
        }
        throw error;
      }
    };
    module2.exports = pLocate;
  }
});

// node_modules/eslint/node_modules/locate-path/index.js
var require_locate_path = __commonJS({
  "node_modules/eslint/node_modules/locate-path/index.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var fs2 = require("fs");
    var { promisify } = require("util");
    var pLocate = require_p_locate();
    var fsStat = promisify(fs2.stat);
    var fsLStat = promisify(fs2.lstat);
    var typeMappings = {
      directory: "isDirectory",
      file: "isFile"
    };
    function checkType({ type }) {
      if (type in typeMappings) {
        return;
      }
      throw new Error(`Invalid type specified: ${type}`);
    }
    var matchType = (type, stat) => type === void 0 || stat[typeMappings[type]]();
    module2.exports = async (paths, options) => {
      options = {
        cwd: process.cwd(),
        type: "file",
        allowSymlinks: true,
        ...options
      };
      checkType(options);
      const statFn = options.allowSymlinks ? fsStat : fsLStat;
      return pLocate(paths, async (path_) => {
        try {
          const stat = await statFn(path2.resolve(options.cwd, path_));
          return matchType(options.type, stat);
        } catch {
          return false;
        }
      }, options);
    };
    module2.exports.sync = (paths, options) => {
      options = {
        cwd: process.cwd(),
        allowSymlinks: true,
        type: "file",
        ...options
      };
      checkType(options);
      const statFn = options.allowSymlinks ? fs2.statSync : fs2.lstatSync;
      for (const path_ of paths) {
        try {
          const stat = statFn(path2.resolve(options.cwd, path_));
          if (matchType(options.type, stat)) {
            return path_;
          }
        } catch {
        }
      }
    };
  }
});

// node_modules/path-exists/index.js
var require_path_exists = __commonJS({
  "node_modules/path-exists/index.js"(exports, module2) {
    "use strict";
    var fs2 = require("fs");
    var { promisify } = require("util");
    var pAccess = promisify(fs2.access);
    module2.exports = async (path2) => {
      try {
        await pAccess(path2);
        return true;
      } catch (_) {
        return false;
      }
    };
    module2.exports.sync = (path2) => {
      try {
        fs2.accessSync(path2);
        return true;
      } catch (_) {
        return false;
      }
    };
  }
});

// node_modules/eslint/node_modules/find-up/index.js
var require_find_up = __commonJS({
  "node_modules/eslint/node_modules/find-up/index.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var locatePath = require_locate_path();
    var pathExists = require_path_exists();
    var stop = Symbol("findUp.stop");
    module2.exports = async (name, options = {}) => {
      let directory = path2.resolve(options.cwd || "");
      const { root: root2 } = path2.parse(directory);
      const paths = [].concat(name);
      const runMatcher = async (locateOptions) => {
        if (typeof name !== "function") {
          return locatePath(paths, locateOptions);
        }
        const foundPath = await name(locateOptions.cwd);
        if (typeof foundPath === "string") {
          return locatePath([foundPath], locateOptions);
        }
        return foundPath;
      };
      while (true) {
        const foundPath = await runMatcher({ ...options, cwd: directory });
        if (foundPath === stop) {
          return;
        }
        if (foundPath) {
          return path2.resolve(directory, foundPath);
        }
        if (directory === root2) {
          return;
        }
        directory = path2.dirname(directory);
      }
    };
    module2.exports.sync = (name, options = {}) => {
      let directory = path2.resolve(options.cwd || "");
      const { root: root2 } = path2.parse(directory);
      const paths = [].concat(name);
      const runMatcher = (locateOptions) => {
        if (typeof name !== "function") {
          return locatePath.sync(paths, locateOptions);
        }
        const foundPath = name(locateOptions.cwd);
        if (typeof foundPath === "string") {
          return locatePath.sync([foundPath], locateOptions);
        }
        return foundPath;
      };
      while (true) {
        const foundPath = runMatcher({ ...options, cwd: directory });
        if (foundPath === stop) {
          return;
        }
        if (foundPath) {
          return path2.resolve(directory, foundPath);
        }
        if (directory === root2) {
          return;
        }
        directory = path2.dirname(directory);
      }
    };
    module2.exports.exists = pathExists;
    module2.exports.sync.exists = pathExists.sync;
    module2.exports.stop = stop;
  }
});

// node_modules/@nodelib/fs.stat/out/providers/async.js
var require_async3 = __commonJS({
  "node_modules/@nodelib/fs.stat/out/providers/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read = void 0;
    function read(path2, settings, callback) {
      settings.fs.lstat(path2, (lstatError, lstat) => {
        if (lstatError !== null) {
          callFailureCallback(callback, lstatError);
          return;
        }
        if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
          callSuccessCallback(callback, lstat);
          return;
        }
        settings.fs.stat(path2, (statError, stat) => {
          if (statError !== null) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              callFailureCallback(callback, statError);
              return;
            }
            callSuccessCallback(callback, lstat);
            return;
          }
          if (settings.markSymbolicLink) {
            stat.isSymbolicLink = () => true;
          }
          callSuccessCallback(callback, stat);
        });
      });
    }
    exports.read = read;
    function callFailureCallback(callback, error) {
      callback(error);
    }
    function callSuccessCallback(callback, result) {
      callback(null, result);
    }
  }
});

// node_modules/@nodelib/fs.stat/out/providers/sync.js
var require_sync2 = __commonJS({
  "node_modules/@nodelib/fs.stat/out/providers/sync.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read = void 0;
    function read(path2, settings) {
      const lstat = settings.fs.lstatSync(path2);
      if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
        return lstat;
      }
      try {
        const stat = settings.fs.statSync(path2);
        if (settings.markSymbolicLink) {
          stat.isSymbolicLink = () => true;
        }
        return stat;
      } catch (error) {
        if (!settings.throwErrorOnBrokenSymbolicLink) {
          return lstat;
        }
        throw error;
      }
    }
    exports.read = read;
  }
});

// node_modules/@nodelib/fs.stat/out/adapters/fs.js
var require_fs2 = __commonJS({
  "node_modules/@nodelib/fs.stat/out/adapters/fs.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createFileSystemAdapter = exports.FILE_SYSTEM_ADAPTER = void 0;
    var fs2 = require("fs");
    exports.FILE_SYSTEM_ADAPTER = {
      lstat: fs2.lstat,
      stat: fs2.stat,
      lstatSync: fs2.lstatSync,
      statSync: fs2.statSync
    };
    function createFileSystemAdapter(fsMethods) {
      if (fsMethods === void 0) {
        return exports.FILE_SYSTEM_ADAPTER;
      }
      return Object.assign(Object.assign({}, exports.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    exports.createFileSystemAdapter = createFileSystemAdapter;
  }
});

// node_modules/@nodelib/fs.stat/out/settings.js
var require_settings = __commonJS({
  "node_modules/@nodelib/fs.stat/out/settings.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var fs2 = require_fs2();
    var Settings = class {
      constructor(_options = {}) {
        this._options = _options;
        this.followSymbolicLink = this._getValue(this._options.followSymbolicLink, true);
        this.fs = fs2.createFileSystemAdapter(this._options.fs);
        this.markSymbolicLink = this._getValue(this._options.markSymbolicLink, false);
        this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
      }
      _getValue(option, value2) {
        return option !== null && option !== void 0 ? option : value2;
      }
    };
    exports.default = Settings;
  }
});

// node_modules/@nodelib/fs.stat/out/index.js
var require_out = __commonJS({
  "node_modules/@nodelib/fs.stat/out/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.statSync = exports.stat = exports.Settings = void 0;
    var async = require_async3();
    var sync = require_sync2();
    var settings_1 = require_settings();
    exports.Settings = settings_1.default;
    function stat(path2, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        async.read(path2, getSettings(), optionsOrSettingsOrCallback);
        return;
      }
      async.read(path2, getSettings(optionsOrSettingsOrCallback), callback);
    }
    exports.stat = stat;
    function statSync(path2, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      return sync.read(path2, settings);
    }
    exports.statSync = statSync;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
  }
});

// node_modules/queue-microtask/index.js
var require_queue_microtask = __commonJS({
  "node_modules/queue-microtask/index.js"(exports, module2) {
    var promise;
    module2.exports = typeof queueMicrotask === "function" ? queueMicrotask.bind(typeof window !== "undefined" ? window : global) : (cb) => (promise || (promise = Promise.resolve())).then(cb).catch((err) => setTimeout(() => {
      throw err;
    }, 0));
  }
});

// node_modules/run-parallel/index.js
var require_run_parallel = __commonJS({
  "node_modules/run-parallel/index.js"(exports, module2) {
    module2.exports = runParallel;
    var queueMicrotask2 = require_queue_microtask();
    function runParallel(tasks, cb) {
      let results, pending, keys3;
      let isSync = true;
      if (Array.isArray(tasks)) {
        results = [];
        pending = tasks.length;
      } else {
        keys3 = Object.keys(tasks);
        results = {};
        pending = keys3.length;
      }
      function done(err) {
        function end() {
          if (cb)
            cb(err, results);
          cb = null;
        }
        if (isSync)
          queueMicrotask2(end);
        else
          end();
      }
      function each(i, err, result) {
        results[i] = result;
        if (--pending === 0 || err) {
          done(err);
        }
      }
      if (!pending) {
        done(null);
      } else if (keys3) {
        keys3.forEach(function(key) {
          tasks[key](function(err, result) {
            each(key, err, result);
          });
        });
      } else {
        tasks.forEach(function(task, i) {
          task(function(err, result) {
            each(i, err, result);
          });
        });
      }
      isSync = false;
    }
  }
});

// node_modules/@nodelib/fs.scandir/out/constants.js
var require_constants = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/constants.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.IS_SUPPORT_READDIR_WITH_FILE_TYPES = void 0;
    var NODE_PROCESS_VERSION_PARTS = process.versions.node.split(".");
    if (NODE_PROCESS_VERSION_PARTS[0] === void 0 || NODE_PROCESS_VERSION_PARTS[1] === void 0) {
      throw new Error(`Unexpected behavior. The 'process.versions.node' variable has invalid value: ${process.versions.node}`);
    }
    var MAJOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[0], 10);
    var MINOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[1], 10);
    var SUPPORTED_MAJOR_VERSION = 10;
    var SUPPORTED_MINOR_VERSION = 10;
    var IS_MATCHED_BY_MAJOR = MAJOR_VERSION > SUPPORTED_MAJOR_VERSION;
    var IS_MATCHED_BY_MAJOR_AND_MINOR = MAJOR_VERSION === SUPPORTED_MAJOR_VERSION && MINOR_VERSION >= SUPPORTED_MINOR_VERSION;
    exports.IS_SUPPORT_READDIR_WITH_FILE_TYPES = IS_MATCHED_BY_MAJOR || IS_MATCHED_BY_MAJOR_AND_MINOR;
  }
});

// node_modules/@nodelib/fs.scandir/out/utils/fs.js
var require_fs3 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/utils/fs.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createDirentFromStats = void 0;
    var DirentFromStats = class {
      constructor(name, stats) {
        this.name = name;
        this.isBlockDevice = stats.isBlockDevice.bind(stats);
        this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
        this.isDirectory = stats.isDirectory.bind(stats);
        this.isFIFO = stats.isFIFO.bind(stats);
        this.isFile = stats.isFile.bind(stats);
        this.isSocket = stats.isSocket.bind(stats);
        this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
      }
    };
    function createDirentFromStats(name, stats) {
      return new DirentFromStats(name, stats);
    }
    exports.createDirentFromStats = createDirentFromStats;
  }
});

// node_modules/@nodelib/fs.scandir/out/utils/index.js
var require_utils5 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/utils/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.fs = void 0;
    var fs2 = require_fs3();
    exports.fs = fs2;
  }
});

// node_modules/@nodelib/fs.scandir/out/providers/common.js
var require_common3 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/providers/common.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.joinPathSegments = void 0;
    function joinPathSegments(a, b, separator) {
      if (a.endsWith(separator)) {
        return a + b;
      }
      return a + separator + b;
    }
    exports.joinPathSegments = joinPathSegments;
  }
});

// node_modules/@nodelib/fs.scandir/out/providers/async.js
var require_async4 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/providers/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.readdir = exports.readdirWithFileTypes = exports.read = void 0;
    var fsStat = require_out();
    var rpl = require_run_parallel();
    var constants_1 = require_constants();
    var utils2 = require_utils5();
    var common = require_common3();
    function read(directory, settings, callback) {
      if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
        readdirWithFileTypes(directory, settings, callback);
        return;
      }
      readdir(directory, settings, callback);
    }
    exports.read = read;
    function readdirWithFileTypes(directory, settings, callback) {
      settings.fs.readdir(directory, { withFileTypes: true }, (readdirError, dirents) => {
        if (readdirError !== null) {
          callFailureCallback(callback, readdirError);
          return;
        }
        const entries = dirents.map((dirent) => ({
          dirent,
          name: dirent.name,
          path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
        }));
        if (!settings.followSymbolicLinks) {
          callSuccessCallback(callback, entries);
          return;
        }
        const tasks = entries.map((entry) => makeRplTaskEntry(entry, settings));
        rpl(tasks, (rplError, rplEntries) => {
          if (rplError !== null) {
            callFailureCallback(callback, rplError);
            return;
          }
          callSuccessCallback(callback, rplEntries);
        });
      });
    }
    exports.readdirWithFileTypes = readdirWithFileTypes;
    function makeRplTaskEntry(entry, settings) {
      return (done) => {
        if (!entry.dirent.isSymbolicLink()) {
          done(null, entry);
          return;
        }
        settings.fs.stat(entry.path, (statError, stats) => {
          if (statError !== null) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              done(statError);
              return;
            }
            done(null, entry);
            return;
          }
          entry.dirent = utils2.fs.createDirentFromStats(entry.name, stats);
          done(null, entry);
        });
      };
    }
    function readdir(directory, settings, callback) {
      settings.fs.readdir(directory, (readdirError, names) => {
        if (readdirError !== null) {
          callFailureCallback(callback, readdirError);
          return;
        }
        const tasks = names.map((name) => {
          const path2 = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
          return (done) => {
            fsStat.stat(path2, settings.fsStatSettings, (error, stats) => {
              if (error !== null) {
                done(error);
                return;
              }
              const entry = {
                name,
                path: path2,
                dirent: utils2.fs.createDirentFromStats(name, stats)
              };
              if (settings.stats) {
                entry.stats = stats;
              }
              done(null, entry);
            });
          };
        });
        rpl(tasks, (rplError, entries) => {
          if (rplError !== null) {
            callFailureCallback(callback, rplError);
            return;
          }
          callSuccessCallback(callback, entries);
        });
      });
    }
    exports.readdir = readdir;
    function callFailureCallback(callback, error) {
      callback(error);
    }
    function callSuccessCallback(callback, result) {
      callback(null, result);
    }
  }
});

// node_modules/@nodelib/fs.scandir/out/providers/sync.js
var require_sync3 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/providers/sync.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.readdir = exports.readdirWithFileTypes = exports.read = void 0;
    var fsStat = require_out();
    var constants_1 = require_constants();
    var utils2 = require_utils5();
    var common = require_common3();
    function read(directory, settings) {
      if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
        return readdirWithFileTypes(directory, settings);
      }
      return readdir(directory, settings);
    }
    exports.read = read;
    function readdirWithFileTypes(directory, settings) {
      const dirents = settings.fs.readdirSync(directory, { withFileTypes: true });
      return dirents.map((dirent) => {
        const entry = {
          dirent,
          name: dirent.name,
          path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
        };
        if (entry.dirent.isSymbolicLink() && settings.followSymbolicLinks) {
          try {
            const stats = settings.fs.statSync(entry.path);
            entry.dirent = utils2.fs.createDirentFromStats(entry.name, stats);
          } catch (error) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              throw error;
            }
          }
        }
        return entry;
      });
    }
    exports.readdirWithFileTypes = readdirWithFileTypes;
    function readdir(directory, settings) {
      const names = settings.fs.readdirSync(directory);
      return names.map((name) => {
        const entryPath = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
        const stats = fsStat.statSync(entryPath, settings.fsStatSettings);
        const entry = {
          name,
          path: entryPath,
          dirent: utils2.fs.createDirentFromStats(name, stats)
        };
        if (settings.stats) {
          entry.stats = stats;
        }
        return entry;
      });
    }
    exports.readdir = readdir;
  }
});

// node_modules/@nodelib/fs.scandir/out/adapters/fs.js
var require_fs4 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/adapters/fs.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createFileSystemAdapter = exports.FILE_SYSTEM_ADAPTER = void 0;
    var fs2 = require("fs");
    exports.FILE_SYSTEM_ADAPTER = {
      lstat: fs2.lstat,
      stat: fs2.stat,
      lstatSync: fs2.lstatSync,
      statSync: fs2.statSync,
      readdir: fs2.readdir,
      readdirSync: fs2.readdirSync
    };
    function createFileSystemAdapter(fsMethods) {
      if (fsMethods === void 0) {
        return exports.FILE_SYSTEM_ADAPTER;
      }
      return Object.assign(Object.assign({}, exports.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    exports.createFileSystemAdapter = createFileSystemAdapter;
  }
});

// node_modules/@nodelib/fs.scandir/out/settings.js
var require_settings2 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/settings.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var path2 = require("path");
    var fsStat = require_out();
    var fs2 = require_fs4();
    var Settings = class {
      constructor(_options = {}) {
        this._options = _options;
        this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, false);
        this.fs = fs2.createFileSystemAdapter(this._options.fs);
        this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path2.sep);
        this.stats = this._getValue(this._options.stats, false);
        this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
        this.fsStatSettings = new fsStat.Settings({
          followSymbolicLink: this.followSymbolicLinks,
          fs: this.fs,
          throwErrorOnBrokenSymbolicLink: this.throwErrorOnBrokenSymbolicLink
        });
      }
      _getValue(option, value2) {
        return option !== null && option !== void 0 ? option : value2;
      }
    };
    exports.default = Settings;
  }
});

// node_modules/@nodelib/fs.scandir/out/index.js
var require_out2 = __commonJS({
  "node_modules/@nodelib/fs.scandir/out/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Settings = exports.scandirSync = exports.scandir = void 0;
    var async = require_async4();
    var sync = require_sync3();
    var settings_1 = require_settings2();
    exports.Settings = settings_1.default;
    function scandir(path2, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        async.read(path2, getSettings(), optionsOrSettingsOrCallback);
        return;
      }
      async.read(path2, getSettings(optionsOrSettingsOrCallback), callback);
    }
    exports.scandir = scandir;
    function scandirSync(path2, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      return sync.read(path2, settings);
    }
    exports.scandirSync = scandirSync;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
  }
});

// node_modules/reusify/reusify.js
var require_reusify = __commonJS({
  "node_modules/reusify/reusify.js"(exports, module2) {
    "use strict";
    function reusify(Constructor) {
      var head = new Constructor();
      var tail = head;
      function get() {
        var current = head;
        if (current.next) {
          head = current.next;
        } else {
          head = new Constructor();
          tail = head;
        }
        current.next = null;
        return current;
      }
      function release(obj) {
        tail.next = obj;
        tail = obj;
      }
      return {
        get,
        release
      };
    }
    module2.exports = reusify;
  }
});

// node_modules/fastq/queue.js
var require_queue2 = __commonJS({
  "node_modules/fastq/queue.js"(exports, module2) {
    "use strict";
    var reusify = require_reusify();
    function fastqueue(context, worker, concurrency) {
      if (typeof context === "function") {
        concurrency = worker;
        worker = context;
        context = null;
      }
      if (concurrency < 1) {
        throw new Error("fastqueue concurrency must be greater than 1");
      }
      var cache = reusify(Task);
      var queueHead = null;
      var queueTail = null;
      var _running = 0;
      var errorHandler = null;
      var self2 = {
        push,
        drain: noop,
        saturated: noop,
        pause,
        paused: false,
        concurrency,
        running,
        resume,
        idle,
        length,
        getQueue,
        unshift,
        empty: noop,
        kill,
        killAndDrain,
        error
      };
      return self2;
      function running() {
        return _running;
      }
      function pause() {
        self2.paused = true;
      }
      function length() {
        var current = queueHead;
        var counter = 0;
        while (current) {
          current = current.next;
          counter++;
        }
        return counter;
      }
      function getQueue() {
        var current = queueHead;
        var tasks = [];
        while (current) {
          tasks.push(current.value);
          current = current.next;
        }
        return tasks;
      }
      function resume() {
        if (!self2.paused)
          return;
        self2.paused = false;
        for (var i = 0; i < self2.concurrency; i++) {
          _running++;
          release();
        }
      }
      function idle() {
        return _running === 0 && self2.length() === 0;
      }
      function push(value2, done) {
        var current = cache.get();
        current.context = context;
        current.release = release;
        current.value = value2;
        current.callback = done || noop;
        current.errorHandler = errorHandler;
        if (_running === self2.concurrency || self2.paused) {
          if (queueTail) {
            queueTail.next = current;
            queueTail = current;
          } else {
            queueHead = current;
            queueTail = current;
            self2.saturated();
          }
        } else {
          _running++;
          worker.call(context, current.value, current.worked);
        }
      }
      function unshift(value2, done) {
        var current = cache.get();
        current.context = context;
        current.release = release;
        current.value = value2;
        current.callback = done || noop;
        if (_running === self2.concurrency || self2.paused) {
          if (queueHead) {
            current.next = queueHead;
            queueHead = current;
          } else {
            queueHead = current;
            queueTail = current;
            self2.saturated();
          }
        } else {
          _running++;
          worker.call(context, current.value, current.worked);
        }
      }
      function release(holder) {
        if (holder) {
          cache.release(holder);
        }
        var next = queueHead;
        if (next) {
          if (!self2.paused) {
            if (queueTail === queueHead) {
              queueTail = null;
            }
            queueHead = next.next;
            next.next = null;
            worker.call(context, next.value, next.worked);
            if (queueTail === null) {
              self2.empty();
            }
          } else {
            _running--;
          }
        } else if (--_running === 0) {
          self2.drain();
        }
      }
      function kill() {
        queueHead = null;
        queueTail = null;
        self2.drain = noop;
      }
      function killAndDrain() {
        queueHead = null;
        queueTail = null;
        self2.drain();
        self2.drain = noop;
      }
      function error(handler) {
        errorHandler = handler;
      }
    }
    function noop() {
    }
    function Task() {
      this.value = null;
      this.callback = noop;
      this.next = null;
      this.release = noop;
      this.context = null;
      this.errorHandler = null;
      var self2 = this;
      this.worked = function worked(err, result) {
        var callback = self2.callback;
        var errorHandler = self2.errorHandler;
        var val = self2.value;
        self2.value = null;
        self2.callback = noop;
        if (self2.errorHandler) {
          errorHandler(err, val);
        }
        callback.call(self2.context, err, result);
        self2.release(self2);
      };
    }
    function queueAsPromised(context, worker, concurrency) {
      if (typeof context === "function") {
        concurrency = worker;
        worker = context;
        context = null;
      }
      function asyncWrapper(arg, cb) {
        worker.call(this, arg).then(function(res) {
          cb(null, res);
        }, cb);
      }
      var queue = fastqueue(context, asyncWrapper, concurrency);
      var pushCb = queue.push;
      var unshiftCb = queue.unshift;
      queue.push = push;
      queue.unshift = unshift;
      queue.drained = drained;
      return queue;
      function push(value2) {
        var p = new Promise(function(resolve, reject) {
          pushCb(value2, function(err, result) {
            if (err) {
              reject(err);
              return;
            }
            resolve(result);
          });
        });
        p.catch(noop);
        return p;
      }
      function unshift(value2) {
        var p = new Promise(function(resolve, reject) {
          unshiftCb(value2, function(err, result) {
            if (err) {
              reject(err);
              return;
            }
            resolve(result);
          });
        });
        p.catch(noop);
        return p;
      }
      function drained() {
        if (queue.idle()) {
          return new Promise(function(resolve) {
            resolve();
          });
        }
        var previousDrain = queue.drain;
        var p = new Promise(function(resolve) {
          queue.drain = function() {
            previousDrain();
            resolve();
          };
        });
        return p;
      }
    }
    module2.exports = fastqueue;
    module2.exports.promise = queueAsPromised;
  }
});

// node_modules/@nodelib/fs.walk/out/readers/common.js
var require_common4 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/readers/common.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.joinPathSegments = exports.replacePathSegmentSeparator = exports.isAppliedFilter = exports.isFatalError = void 0;
    function isFatalError(settings, error) {
      if (settings.errorFilter === null) {
        return true;
      }
      return !settings.errorFilter(error);
    }
    exports.isFatalError = isFatalError;
    function isAppliedFilter(filter, value2) {
      return filter === null || filter(value2);
    }
    exports.isAppliedFilter = isAppliedFilter;
    function replacePathSegmentSeparator(filepath, separator) {
      return filepath.split(/[/\\]/).join(separator);
    }
    exports.replacePathSegmentSeparator = replacePathSegmentSeparator;
    function joinPathSegments(a, b, separator) {
      if (a === "") {
        return b;
      }
      if (a.endsWith(separator)) {
        return a + b;
      }
      return a + separator + b;
    }
    exports.joinPathSegments = joinPathSegments;
  }
});

// node_modules/@nodelib/fs.walk/out/readers/reader.js
var require_reader = __commonJS({
  "node_modules/@nodelib/fs.walk/out/readers/reader.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var common = require_common4();
    var Reader = class {
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._root = common.replacePathSegmentSeparator(_root, _settings.pathSegmentSeparator);
      }
    };
    exports.default = Reader;
  }
});

// node_modules/@nodelib/fs.walk/out/readers/async.js
var require_async5 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/readers/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var events_1 = require("events");
    var fsScandir = require_out2();
    var fastq = require_queue2();
    var common = require_common4();
    var reader_1 = require_reader();
    var AsyncReader = class extends reader_1.default {
      constructor(_root, _settings) {
        super(_root, _settings);
        this._settings = _settings;
        this._scandir = fsScandir.scandir;
        this._emitter = new events_1.EventEmitter();
        this._queue = fastq(this._worker.bind(this), this._settings.concurrency);
        this._isFatalError = false;
        this._isDestroyed = false;
        this._queue.drain = () => {
          if (!this._isFatalError) {
            this._emitter.emit("end");
          }
        };
      }
      read() {
        this._isFatalError = false;
        this._isDestroyed = false;
        setImmediate(() => {
          this._pushToQueue(this._root, this._settings.basePath);
        });
        return this._emitter;
      }
      get isDestroyed() {
        return this._isDestroyed;
      }
      destroy() {
        if (this._isDestroyed) {
          throw new Error("The reader is already destroyed");
        }
        this._isDestroyed = true;
        this._queue.killAndDrain();
      }
      onEntry(callback) {
        this._emitter.on("entry", callback);
      }
      onError(callback) {
        this._emitter.once("error", callback);
      }
      onEnd(callback) {
        this._emitter.once("end", callback);
      }
      _pushToQueue(directory, base) {
        const queueItem = { directory, base };
        this._queue.push(queueItem, (error) => {
          if (error !== null) {
            this._handleError(error);
          }
        });
      }
      _worker(item, done) {
        this._scandir(item.directory, this._settings.fsScandirSettings, (error, entries) => {
          if (error !== null) {
            done(error, void 0);
            return;
          }
          for (const entry of entries) {
            this._handleEntry(entry, item.base);
          }
          done(null, void 0);
        });
      }
      _handleError(error) {
        if (this._isDestroyed || !common.isFatalError(this._settings, error)) {
          return;
        }
        this._isFatalError = true;
        this._isDestroyed = true;
        this._emitter.emit("error", error);
      }
      _handleEntry(entry, base) {
        if (this._isDestroyed || this._isFatalError) {
          return;
        }
        const fullpath = entry.path;
        if (base !== void 0) {
          entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
        }
        if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
          this._emitEntry(entry);
        }
        if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
          this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
        }
      }
      _emitEntry(entry) {
        this._emitter.emit("entry", entry);
      }
    };
    exports.default = AsyncReader;
  }
});

// node_modules/@nodelib/fs.walk/out/providers/async.js
var require_async6 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/providers/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var async_1 = require_async5();
    var AsyncProvider = class {
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new async_1.default(this._root, this._settings);
        this._storage = [];
      }
      read(callback) {
        this._reader.onError((error) => {
          callFailureCallback(callback, error);
        });
        this._reader.onEntry((entry) => {
          this._storage.push(entry);
        });
        this._reader.onEnd(() => {
          callSuccessCallback(callback, this._storage);
        });
        this._reader.read();
      }
    };
    exports.default = AsyncProvider;
    function callFailureCallback(callback, error) {
      callback(error);
    }
    function callSuccessCallback(callback, entries) {
      callback(null, entries);
    }
  }
});

// node_modules/@nodelib/fs.walk/out/providers/stream.js
var require_stream2 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/providers/stream.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var stream_1 = require("stream");
    var async_1 = require_async5();
    var StreamProvider = class {
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new async_1.default(this._root, this._settings);
        this._stream = new stream_1.Readable({
          objectMode: true,
          read: () => {
          },
          destroy: () => {
            if (!this._reader.isDestroyed) {
              this._reader.destroy();
            }
          }
        });
      }
      read() {
        this._reader.onError((error) => {
          this._stream.emit("error", error);
        });
        this._reader.onEntry((entry) => {
          this._stream.push(entry);
        });
        this._reader.onEnd(() => {
          this._stream.push(null);
        });
        this._reader.read();
        return this._stream;
      }
    };
    exports.default = StreamProvider;
  }
});

// node_modules/@nodelib/fs.walk/out/readers/sync.js
var require_sync4 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/readers/sync.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var fsScandir = require_out2();
    var common = require_common4();
    var reader_1 = require_reader();
    var SyncReader = class extends reader_1.default {
      constructor() {
        super(...arguments);
        this._scandir = fsScandir.scandirSync;
        this._storage = [];
        this._queue = /* @__PURE__ */ new Set();
      }
      read() {
        this._pushToQueue(this._root, this._settings.basePath);
        this._handleQueue();
        return this._storage;
      }
      _pushToQueue(directory, base) {
        this._queue.add({ directory, base });
      }
      _handleQueue() {
        for (const item of this._queue.values()) {
          this._handleDirectory(item.directory, item.base);
        }
      }
      _handleDirectory(directory, base) {
        try {
          const entries = this._scandir(directory, this._settings.fsScandirSettings);
          for (const entry of entries) {
            this._handleEntry(entry, base);
          }
        } catch (error) {
          this._handleError(error);
        }
      }
      _handleError(error) {
        if (!common.isFatalError(this._settings, error)) {
          return;
        }
        throw error;
      }
      _handleEntry(entry, base) {
        const fullpath = entry.path;
        if (base !== void 0) {
          entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
        }
        if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
          this._pushToStorage(entry);
        }
        if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
          this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
        }
      }
      _pushToStorage(entry) {
        this._storage.push(entry);
      }
    };
    exports.default = SyncReader;
  }
});

// node_modules/@nodelib/fs.walk/out/providers/sync.js
var require_sync5 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/providers/sync.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var sync_1 = require_sync4();
    var SyncProvider = class {
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new sync_1.default(this._root, this._settings);
      }
      read() {
        return this._reader.read();
      }
    };
    exports.default = SyncProvider;
  }
});

// node_modules/@nodelib/fs.walk/out/settings.js
var require_settings3 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/settings.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var path2 = require("path");
    var fsScandir = require_out2();
    var Settings = class {
      constructor(_options = {}) {
        this._options = _options;
        this.basePath = this._getValue(this._options.basePath, void 0);
        this.concurrency = this._getValue(this._options.concurrency, Number.POSITIVE_INFINITY);
        this.deepFilter = this._getValue(this._options.deepFilter, null);
        this.entryFilter = this._getValue(this._options.entryFilter, null);
        this.errorFilter = this._getValue(this._options.errorFilter, null);
        this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path2.sep);
        this.fsScandirSettings = new fsScandir.Settings({
          followSymbolicLinks: this._options.followSymbolicLinks,
          fs: this._options.fs,
          pathSegmentSeparator: this._options.pathSegmentSeparator,
          stats: this._options.stats,
          throwErrorOnBrokenSymbolicLink: this._options.throwErrorOnBrokenSymbolicLink
        });
      }
      _getValue(option, value2) {
        return option !== null && option !== void 0 ? option : value2;
      }
    };
    exports.default = Settings;
  }
});

// node_modules/@nodelib/fs.walk/out/index.js
var require_out3 = __commonJS({
  "node_modules/@nodelib/fs.walk/out/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Settings = exports.walkStream = exports.walkSync = exports.walk = void 0;
    var async_1 = require_async6();
    var stream_1 = require_stream2();
    var sync_1 = require_sync5();
    var settings_1 = require_settings3();
    exports.Settings = settings_1.default;
    function walk(directory, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        new async_1.default(directory, getSettings()).read(optionsOrSettingsOrCallback);
        return;
      }
      new async_1.default(directory, getSettings(optionsOrSettingsOrCallback)).read(callback);
    }
    exports.walk = walk;
    function walkSync(directory, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      const provider = new sync_1.default(directory, settings);
      return provider.read();
    }
    exports.walkSync = walkSync;
    function walkStream(directory, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      const provider = new stream_1.default(directory, settings);
      return provider.read();
    }
    exports.walkStream = walkStream;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
  }
});

// node_modules/is-path-inside/index.js
var require_is_path_inside = __commonJS({
  "node_modules/is-path-inside/index.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    module2.exports = (childPath, parentPath) => {
      const relation = path2.relative(parentPath, childPath);
      return Boolean(
        relation && relation !== ".." && !relation.startsWith(`..${path2.sep}`) && relation !== path2.resolve(childPath)
      );
    };
  }
});

// node_modules/eslint/lib/eslint/eslint-helpers.js
var require_eslint_helpers = __commonJS({
  "node_modules/eslint/lib/eslint/eslint-helpers.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var fs2 = require("fs");
    var fsp = fs2.promises;
    var isGlob = require_is_glob();
    var hash = require_hash();
    var minimatch = require_minimatch();
    var util = require("util");
    var fswalk = require_out3();
    var globParent = require_glob_parent();
    var isPathInside = require_is_path_inside();
    var doFsWalk = util.promisify(fswalk.walk);
    var Minimatch = minimatch.Minimatch;
    var MINIMATCH_OPTIONS = { dot: true };
    var NoFilesFoundError = class extends Error {
      /**
       * @param {string} pattern The glob pattern which was not found.
       * @param {boolean} globEnabled If `false` then the pattern was a glob pattern, but glob was disabled.
       */
      constructor(pattern, globEnabled) {
        super(`No files matching '${pattern}' were found${!globEnabled ? " (glob was disabled)" : ""}.`);
        this.messageTemplate = "file-not-found";
        this.messageData = { pattern, globDisabled: !globEnabled };
      }
    };
    var UnmatchedSearchPatternsError = class extends Error {
      /**
       * @param {Object} options The options for the error.
       * @param {string} options.basePath The directory that was searched.
       * @param {Array<string>} options.unmatchedPatterns The glob patterns
       *      which were not found.
       * @param {Array<string>} options.patterns The glob patterns that were
       *      searched.
       * @param {Array<string>} options.rawPatterns The raw glob patterns that
       *      were searched.
       */
      constructor({ basePath, unmatchedPatterns, patterns, rawPatterns }) {
        super(`No files matching '${rawPatterns}' in '${basePath}' were found.`);
        this.basePath = basePath;
        this.unmatchedPatterns = unmatchedPatterns;
        this.patterns = patterns;
        this.rawPatterns = rawPatterns;
      }
    };
    var AllFilesIgnoredError = class extends Error {
      /**
       * @param {string} pattern The glob pattern which was not found.
       */
      constructor(pattern) {
        super(`All files matched by '${pattern}' are ignored.`);
        this.messageTemplate = "all-files-ignored";
        this.messageData = { pattern };
      }
    };
    function isNonEmptyString(x) {
      return typeof x === "string" && x.trim() !== "";
    }
    function isArrayOfNonEmptyString(x) {
      return Array.isArray(x) && x.every(isNonEmptyString);
    }
    function normalizeToPosix(pattern) {
      return pattern.replace(/\\/gu, "/");
    }
    function isGlobPattern(pattern) {
      return isGlob(path2.sep === "\\" ? normalizeToPosix(pattern) : pattern);
    }
    function globMatch({ basePath, pattern }) {
      let found = false;
      const patternToUse = path2.isAbsolute(pattern) ? normalizeToPosix(path2.relative(basePath, pattern)) : pattern;
      const matcher = new Minimatch(patternToUse, MINIMATCH_OPTIONS);
      const fsWalkSettings = {
        deepFilter(entry) {
          const relativePath = normalizeToPosix(path2.relative(basePath, entry.path));
          return !found && matcher.match(relativePath, true);
        },
        entryFilter(entry) {
          if (found || entry.dirent.isDirectory()) {
            return false;
          }
          const relativePath = normalizeToPosix(path2.relative(basePath, entry.path));
          if (matcher.match(relativePath)) {
            found = true;
            return true;
          }
          return false;
        }
      };
      return new Promise((resolve) => {
        const globStream = fswalk.walkStream(basePath, fsWalkSettings);
        globStream.on("data", () => {
          globStream.destroy();
          resolve(true);
        });
        globStream.on("error", () => {
        });
        globStream.on("end", () => {
          resolve(false);
        });
        globStream.read();
      });
    }
    async function globSearch({
      basePath,
      patterns,
      rawPatterns,
      configs,
      errorOnUnmatchedPattern
    }) {
      if (patterns.length === 0) {
        return [];
      }
      const relativeToPatterns = /* @__PURE__ */ new Map();
      const matchers = patterns.map((pattern, i) => {
        const patternToUse = path2.isAbsolute(pattern) ? normalizeToPosix(path2.relative(basePath, pattern)) : pattern;
        relativeToPatterns.set(patternToUse, patterns[i]);
        return new Minimatch(patternToUse, MINIMATCH_OPTIONS);
      });
      const unmatchedPatterns = /* @__PURE__ */ new Set([...relativeToPatterns.keys()]);
      const filePaths = (await doFsWalk(basePath, {
        deepFilter(entry) {
          const relativePath = normalizeToPosix(path2.relative(basePath, entry.path));
          const matchesPattern = matchers.some((matcher) => matcher.match(relativePath, true));
          return matchesPattern && !configs.isDirectoryIgnored(entry.path);
        },
        entryFilter(entry) {
          const relativePath = normalizeToPosix(path2.relative(basePath, entry.path));
          if (entry.dirent.isDirectory()) {
            return false;
          }
          const matchesPattern = unmatchedPatterns.size > 0 ? matchers.reduce((previousValue, matcher) => {
            const pathMatches = matcher.match(relativePath);
            if (pathMatches && !configs.isFileIgnored(entry.path)) {
              unmatchedPatterns.delete(matcher.pattern);
            }
            return pathMatches || previousValue;
          }, false) : matchers.some((matcher) => matcher.match(relativePath));
          return matchesPattern && !configs.isFileIgnored(entry.path);
        }
      })).map((entry) => entry.path);
      if (errorOnUnmatchedPattern && unmatchedPatterns.size > 0) {
        throw new UnmatchedSearchPatternsError({
          basePath,
          unmatchedPatterns: [...unmatchedPatterns].map(
            (pattern) => relativeToPatterns.get(pattern)
          ),
          patterns,
          rawPatterns
        });
      }
      return filePaths;
    }
    async function throwErrorForUnmatchedPatterns({
      basePath,
      patterns,
      rawPatterns,
      unmatchedPatterns
    }) {
      const pattern = unmatchedPatterns[0];
      const rawPattern = rawPatterns[patterns.indexOf(pattern)];
      const patternHasMatch = await globMatch({
        basePath,
        pattern
      });
      if (patternHasMatch) {
        throw new AllFilesIgnoredError(rawPattern);
      }
      throw new NoFilesFoundError(rawPattern, true);
    }
    async function globMultiSearch({ searches, configs, errorOnUnmatchedPattern }) {
      const normalizedSearches = [...searches].map(
        ([basePath, { patterns, rawPatterns }]) => ({ basePath, patterns, rawPatterns })
      ).filter(({ patterns }) => patterns.length > 0);
      const results = await Promise.allSettled(
        normalizedSearches.map(
          ({ basePath, patterns, rawPatterns }) => globSearch({
            basePath,
            patterns,
            rawPatterns,
            configs,
            errorOnUnmatchedPattern
          })
        )
      );
      const filePaths = [];
      for (let i = 0; i < results.length; i++) {
        const result = results[i];
        const currentSearch = normalizedSearches[i];
        if (result.status === "fulfilled") {
          if (result.value.length > 0) {
            filePaths.push(...result.value);
          }
          continue;
        }
        const error = result.reason;
        if (!error.basePath) {
          throw error;
        }
        if (errorOnUnmatchedPattern) {
          await throwErrorForUnmatchedPatterns({
            ...currentSearch,
            unmatchedPatterns: error.unmatchedPatterns
          });
        }
      }
      return [...new Set(filePaths)];
    }
    async function findFiles({
      patterns,
      globInputPaths,
      cwd,
      configs,
      errorOnUnmatchedPattern
    }) {
      const results = [];
      const missingPatterns = [];
      let globbyPatterns = [];
      let rawPatterns = [];
      const searches = /* @__PURE__ */ new Map([[cwd, { patterns: globbyPatterns, rawPatterns: [] }]]);
      const filePaths = patterns.map((filePath) => path2.resolve(cwd, filePath));
      const stats = await Promise.all(
        filePaths.map(
          (filePath) => fsp.stat(filePath).catch(() => {
          })
        )
      );
      stats.forEach((stat, index) => {
        const filePath = filePaths[index];
        const pattern = normalizeToPosix(patterns[index]);
        if (stat) {
          if (stat.isFile()) {
            results.push({
              filePath,
              ignored: configs.isFileIgnored(filePath)
            });
          }
          if (stat.isDirectory()) {
            if (isPathInside(filePath, cwd)) {
              ({ patterns: globbyPatterns, rawPatterns } = searches.get(cwd));
            } else {
              if (!searches.has(filePath)) {
                searches.set(filePath, { patterns: [], rawPatterns: [] });
              }
              ({ patterns: globbyPatterns, rawPatterns } = searches.get(filePath));
            }
            globbyPatterns.push(`${normalizeToPosix(filePath)}/**`);
            rawPatterns.push(pattern);
          }
          return;
        }
        if (globInputPaths && isGlobPattern(filePath)) {
          const basePath = globParent(filePath);
          if (isPathInside(basePath, cwd)) {
            ({ patterns: globbyPatterns, rawPatterns } = searches.get(cwd));
          } else {
            if (!searches.has(basePath)) {
              searches.set(basePath, { patterns: [], rawPatterns: [] });
            }
            ({ patterns: globbyPatterns, rawPatterns } = searches.get(basePath));
          }
          globbyPatterns.push(filePath);
          rawPatterns.push(pattern);
        } else {
          missingPatterns.push(pattern);
        }
      });
      if (errorOnUnmatchedPattern && missingPatterns.length) {
        throw new NoFilesFoundError(missingPatterns[0], globInputPaths);
      }
      const globbyResults = await globMultiSearch({
        searches,
        configs,
        errorOnUnmatchedPattern
      });
      return [
        ...results,
        ...globbyResults.map((filePath) => ({
          filePath: path2.resolve(filePath),
          ignored: false
        }))
      ];
    }
    function fileExists(resolvedPath) {
      try {
        return fs2.statSync(resolvedPath).isFile();
      } catch (error) {
        if (error && (error.code === "ENOENT" || error.code === "ENOTDIR")) {
          return false;
        }
        throw error;
      }
    }
    function directoryExists(resolvedPath) {
      try {
        return fs2.statSync(resolvedPath).isDirectory();
      } catch (error) {
        if (error && (error.code === "ENOENT" || error.code === "ENOTDIR")) {
          return false;
        }
        throw error;
      }
    }
    function isErrorMessage(message) {
      return message.severity === 2;
    }
    function createIgnoreResult(filePath, baseDir) {
      let message;
      const isHidden = filePath.split(path2.sep).find((segment) => /^\./u.test(segment));
      const isInNodeModules = baseDir && path2.relative(baseDir, filePath).startsWith("node_modules");
      if (isHidden) {
        message = `File ignored by default.  Use a negated ignore pattern (like "--ignore-pattern '!<relative/path/to/filename>'") to override.`;
      } else if (isInNodeModules) {
        message = `File ignored by default. Use "--ignore-pattern '!node_modules/*'" to override.`;
      } else {
        message = 'File ignored because of a matching ignore pattern. Use "--no-ignore" to override.';
      }
      return {
        filePath: path2.resolve(filePath),
        messages: [
          {
            fatal: false,
            severity: 1,
            message
          }
        ],
        suppressedMessages: [],
        errorCount: 0,
        warningCount: 1,
        fatalErrorCount: 0,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      };
    }
    function isFixType(x) {
      return x === "directive" || x === "problem" || x === "suggestion" || x === "layout";
    }
    function isFixTypeArray(x) {
      return Array.isArray(x) && x.every(isFixType);
    }
    var ESLintInvalidOptionsError = class _ESLintInvalidOptionsError extends Error {
      constructor(messages) {
        super(`Invalid Options:
- ${messages.join("\n- ")}`);
        this.code = "ESLINT_INVALID_OPTIONS";
        Error.captureStackTrace(this, _ESLintInvalidOptionsError);
      }
    };
    function processOptions({
      allowInlineConfig = true,
      // ← we cannot use `overrideConfig.noInlineConfig` instead because `allowInlineConfig` has side-effect that suppress warnings that show inline configs are ignored.
      baseConfig = null,
      cache = false,
      cacheLocation = ".eslintcache",
      cacheStrategy = "metadata",
      cwd = process.cwd(),
      errorOnUnmatchedPattern = true,
      fix = false,
      fixTypes = null,
      // ← should be null by default because if it's an array then it suppresses rules that don't have the `meta.type` property.
      globInputPaths = true,
      ignore = true,
      ignorePatterns = null,
      overrideConfig = null,
      overrideConfigFile = null,
      plugins = {},
      reportUnusedDisableDirectives = null,
      // ← should be null by default because if it's a string then it overrides the 'reportUnusedDisableDirectives' setting in config files. And we cannot use `overrideConfig.reportUnusedDisableDirectives` instead because we cannot configure the `error` severity with that.
      ...unknownOptions
    }) {
      const errors = [];
      const unknownOptionKeys = Object.keys(unknownOptions);
      if (unknownOptionKeys.length >= 1) {
        errors.push(`Unknown options: ${unknownOptionKeys.join(", ")}`);
        if (unknownOptionKeys.includes("cacheFile")) {
          errors.push("'cacheFile' has been removed. Please use the 'cacheLocation' option instead.");
        }
        if (unknownOptionKeys.includes("configFile")) {
          errors.push("'configFile' has been removed. Please use the 'overrideConfigFile' option instead.");
        }
        if (unknownOptionKeys.includes("envs")) {
          errors.push("'envs' has been removed.");
        }
        if (unknownOptionKeys.includes("extensions")) {
          errors.push("'extensions' has been removed.");
        }
        if (unknownOptionKeys.includes("resolvePluginsRelativeTo")) {
          errors.push("'resolvePluginsRelativeTo' has been removed.");
        }
        if (unknownOptionKeys.includes("globals")) {
          errors.push("'globals' has been removed. Please use the 'overrideConfig.languageOptions.globals' option instead.");
        }
        if (unknownOptionKeys.includes("ignorePath")) {
          errors.push("'ignorePath' has been removed.");
        }
        if (unknownOptionKeys.includes("ignorePattern")) {
          errors.push("'ignorePattern' has been removed. Please use the 'overrideConfig.ignorePatterns' option instead.");
        }
        if (unknownOptionKeys.includes("parser")) {
          errors.push("'parser' has been removed. Please use the 'overrideConfig.languageOptions.parser' option instead.");
        }
        if (unknownOptionKeys.includes("parserOptions")) {
          errors.push("'parserOptions' has been removed. Please use the 'overrideConfig.languageOptions.parserOptions' option instead.");
        }
        if (unknownOptionKeys.includes("rules")) {
          errors.push("'rules' has been removed. Please use the 'overrideConfig.rules' option instead.");
        }
        if (unknownOptionKeys.includes("rulePaths")) {
          errors.push("'rulePaths' has been removed. Please define your rules using plugins.");
        }
      }
      if (typeof allowInlineConfig !== "boolean") {
        errors.push("'allowInlineConfig' must be a boolean.");
      }
      if (typeof baseConfig !== "object") {
        errors.push("'baseConfig' must be an object or null.");
      }
      if (typeof cache !== "boolean") {
        errors.push("'cache' must be a boolean.");
      }
      if (!isNonEmptyString(cacheLocation)) {
        errors.push("'cacheLocation' must be a non-empty string.");
      }
      if (cacheStrategy !== "metadata" && cacheStrategy !== "content") {
        errors.push(`'cacheStrategy' must be any of "metadata", "content".`);
      }
      if (!isNonEmptyString(cwd) || !path2.isAbsolute(cwd)) {
        errors.push("'cwd' must be an absolute path.");
      }
      if (typeof errorOnUnmatchedPattern !== "boolean") {
        errors.push("'errorOnUnmatchedPattern' must be a boolean.");
      }
      if (typeof fix !== "boolean" && typeof fix !== "function") {
        errors.push("'fix' must be a boolean or a function.");
      }
      if (fixTypes !== null && !isFixTypeArray(fixTypes)) {
        errors.push(`'fixTypes' must be an array of any of "directive", "problem", "suggestion", and "layout".`);
      }
      if (typeof globInputPaths !== "boolean") {
        errors.push("'globInputPaths' must be a boolean.");
      }
      if (typeof ignore !== "boolean") {
        errors.push("'ignore' must be a boolean.");
      }
      if (typeof overrideConfig !== "object") {
        errors.push("'overrideConfig' must be an object or null.");
      }
      if (!isNonEmptyString(overrideConfigFile) && overrideConfigFile !== null && overrideConfigFile !== true) {
        errors.push("'overrideConfigFile' must be a non-empty string, null, or true.");
      }
      if (typeof plugins !== "object") {
        errors.push("'plugins' must be an object or null.");
      } else if (plugins !== null && Object.keys(plugins).includes("")) {
        errors.push("'plugins' must not include an empty string.");
      }
      if (Array.isArray(plugins)) {
        errors.push("'plugins' doesn't add plugins to configuration to load. Please use the 'overrideConfig.plugins' option instead.");
      }
      if (reportUnusedDisableDirectives !== "error" && reportUnusedDisableDirectives !== "warn" && reportUnusedDisableDirectives !== "off" && reportUnusedDisableDirectives !== null) {
        errors.push(`'reportUnusedDisableDirectives' must be any of "error", "warn", "off", and null.`);
      }
      if (errors.length > 0) {
        throw new ESLintInvalidOptionsError(errors);
      }
      return {
        allowInlineConfig,
        baseConfig,
        cache,
        cacheLocation,
        cacheStrategy,
        // when overrideConfigFile is true that means don't do config file lookup
        configFile: overrideConfigFile === true ? false : overrideConfigFile,
        overrideConfig,
        cwd,
        errorOnUnmatchedPattern,
        fix,
        fixTypes,
        globInputPaths,
        ignore,
        ignorePatterns,
        reportUnusedDisableDirectives
      };
    }
    function getCacheFile(cacheFile, cwd) {
      const normalizedCacheFile = path2.normalize(cacheFile);
      const resolvedCacheFile = path2.resolve(cwd, normalizedCacheFile);
      const looksLikeADirectory = normalizedCacheFile.slice(-1) === path2.sep;
      function getCacheFileForDirectory() {
        return path2.join(resolvedCacheFile, `.cache_${hash(cwd)}`);
      }
      let fileStats;
      try {
        fileStats = fs2.lstatSync(resolvedCacheFile);
      } catch {
        fileStats = null;
      }
      if (fileStats) {
        if (fileStats.isDirectory() || looksLikeADirectory) {
          return getCacheFileForDirectory();
        }
        return resolvedCacheFile;
      }
      if (looksLikeADirectory) {
        return getCacheFileForDirectory();
      }
      return resolvedCacheFile;
    }
    module2.exports = {
      isGlobPattern,
      directoryExists,
      fileExists,
      findFiles,
      isNonEmptyString,
      isArrayOfNonEmptyString,
      createIgnoreResult,
      isErrorMessage,
      processOptions,
      getCacheFile
    };
  }
});

// node_modules/eslint/lib/eslint/flat-eslint.js
var require_flat_eslint = __commonJS({
  "node_modules/eslint/lib/eslint/flat-eslint.js"(exports, module2) {
    "use strict";
    var fs2 = require("fs").promises;
    var path2 = require("path");
    var findUp = require_find_up();
    var { version: version2 } = require_package4();
    var { Linter } = require_linter2();
    var { getRuleFromConfig } = require_flat_config_helpers();
    var {
      Legacy: {
        ConfigOps: {
          getRuleSeverity
        },
        ModuleResolver,
        naming
      }
    } = require_eslintrc();
    var {
      findFiles,
      getCacheFile,
      isNonEmptyString,
      isArrayOfNonEmptyString,
      createIgnoreResult,
      isErrorMessage,
      processOptions
    } = require_eslint_helpers();
    var { pathToFileURL } = require("url");
    var { FlatConfigArray } = require_flat_config_array();
    var LintResultCache = require_lint_result_cache();
    var FLAT_CONFIG_FILENAME = "eslint.config.js";
    var debug = require_src()("eslint:flat-eslint");
    var removedFormatters = /* @__PURE__ */ new Set(["table", "codeframe"]);
    var privateMembers = /* @__PURE__ */ new WeakMap();
    var importedConfigFileModificationTime = /* @__PURE__ */ new Map();
    function calculateStatsPerFile(messages) {
      return messages.reduce((stat, message) => {
        if (message.fatal || message.severity === 2) {
          stat.errorCount++;
          if (message.fatal) {
            stat.fatalErrorCount++;
          }
          if (message.fix) {
            stat.fixableErrorCount++;
          }
        } else {
          stat.warningCount++;
          if (message.fix) {
            stat.fixableWarningCount++;
          }
        }
        return stat;
      }, {
        errorCount: 0,
        fatalErrorCount: 0,
        warningCount: 0,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      });
    }
    function calculateStatsPerRun(results) {
      return results.reduce((stat, result) => {
        stat.errorCount += result.errorCount;
        stat.fatalErrorCount += result.fatalErrorCount;
        stat.warningCount += result.warningCount;
        stat.fixableErrorCount += result.fixableErrorCount;
        stat.fixableWarningCount += result.fixableWarningCount;
        return stat;
      }, {
        errorCount: 0,
        fatalErrorCount: 0,
        warningCount: 0,
        fixableErrorCount: 0,
        fixableWarningCount: 0
      });
    }
    function createRulesMeta(rules) {
      return Array.from(rules).reduce((retVal, [id, rule]) => {
        retVal[id] = rule.meta;
        return retVal;
      }, {});
    }
    function getPlaceholderPath(cwd) {
      return path2.join(cwd, "__placeholder__.js");
    }
    var usedDeprecatedRulesCache = /* @__PURE__ */ new WeakMap();
    function getOrFindUsedDeprecatedRules(eslint, maybeFilePath) {
      const {
        configs,
        options: { cwd }
      } = privateMembers.get(eslint);
      const filePath = path2.isAbsolute(maybeFilePath) ? maybeFilePath : getPlaceholderPath(cwd);
      const config = configs.getConfig(filePath);
      if (config && !usedDeprecatedRulesCache.has(config)) {
        const retv = [];
        if (config.rules) {
          for (const [ruleId, ruleConf] of Object.entries(config.rules)) {
            if (getRuleSeverity(ruleConf) === 0) {
              continue;
            }
            const rule = getRuleFromConfig(ruleId, config);
            const meta = rule && rule.meta;
            if (meta && meta.deprecated) {
              retv.push({ ruleId, replacedBy: meta.replacedBy || [] });
            }
          }
        }
        usedDeprecatedRulesCache.set(config, Object.freeze(retv));
      }
      return config ? usedDeprecatedRulesCache.get(config) : Object.freeze([]);
    }
    function processLintReport(eslint, { results }) {
      const descriptor = {
        configurable: true,
        enumerable: true,
        get() {
          return getOrFindUsedDeprecatedRules(eslint, this.filePath);
        }
      };
      for (const result of results) {
        Object.defineProperty(result, "usedDeprecatedRules", descriptor);
      }
      return results;
    }
    function compareResultsByFilePath(a, b) {
      if (a.filePath < b.filePath) {
        return -1;
      }
      if (a.filePath > b.filePath) {
        return 1;
      }
      return 0;
    }
    function findFlatConfigFile(cwd) {
      return findUp(
        FLAT_CONFIG_FILENAME,
        { cwd }
      );
    }
    async function loadFlatConfigFile(filePath) {
      debug(`Loading config from ${filePath}`);
      const fileURL = pathToFileURL(filePath);
      debug(`Config file URL is ${fileURL}`);
      const mtime = (await fs2.stat(filePath)).mtime.getTime();
      fileURL.searchParams.append("mtime", mtime);
      if (importedConfigFileModificationTime.get(filePath) !== mtime) {
        delete require.cache[filePath];
      }
      const config = (await import(fileURL)).default;
      importedConfigFileModificationTime.set(filePath, mtime);
      return config;
    }
    async function calculateConfigArray(eslint, {
      cwd,
      baseConfig,
      overrideConfig,
      configFile,
      ignore: shouldIgnore,
      ignorePatterns
    }) {
      const slots = privateMembers.get(eslint);
      if (slots.configs) {
        return slots.configs;
      }
      let configFilePath;
      let basePath = cwd;
      if (typeof configFile === "string") {
        debug(`Override config file path is ${configFile}`);
        configFilePath = path2.resolve(cwd, configFile);
      } else if (configFile !== false) {
        debug("Searching for eslint.config.js");
        configFilePath = await findFlatConfigFile(cwd);
        if (!configFilePath) {
          throw new Error("Could not find config file.");
        }
        basePath = path2.resolve(path2.dirname(configFilePath));
      }
      const configs = new FlatConfigArray(baseConfig || [], { basePath, shouldIgnore });
      if (configFilePath) {
        const fileConfig = await loadFlatConfigFile(configFilePath);
        if (Array.isArray(fileConfig)) {
          configs.push(...fileConfig);
        } else {
          configs.push(fileConfig);
        }
      }
      configs.push(...slots.defaultConfigs);
      let allIgnorePatterns = [];
      if (ignorePatterns) {
        if (typeof ignorePatterns === "string") {
          allIgnorePatterns.push(ignorePatterns);
        } else {
          allIgnorePatterns.push(...ignorePatterns);
        }
      }
      if (basePath !== cwd && allIgnorePatterns.length) {
        const relativeIgnorePath = path2.relative(basePath, cwd);
        allIgnorePatterns = allIgnorePatterns.map((pattern) => {
          const negated = pattern.startsWith("!");
          const basePattern = negated ? pattern.slice(1) : pattern;
          return (negated ? "!" : "") + path2.posix.join(relativeIgnorePath, basePattern);
        });
      }
      if (allIgnorePatterns.length) {
        configs.push({
          ignores: allIgnorePatterns
        });
      }
      if (overrideConfig) {
        if (Array.isArray(overrideConfig)) {
          configs.push(...overrideConfig);
        } else {
          configs.push(overrideConfig);
        }
      }
      await configs.normalize();
      slots.configs = configs;
      return configs;
    }
    function verifyText({
      text,
      cwd,
      filePath: providedFilePath,
      configs,
      fix,
      allowInlineConfig,
      reportUnusedDisableDirectives,
      linter
    }) {
      const filePath = providedFilePath || "<text>";
      debug(`Lint ${filePath}`);
      const filePathToVerify = filePath === "<text>" ? getPlaceholderPath(cwd) : filePath;
      const { fixed, messages, output } = linter.verifyAndFix(
        text,
        configs,
        {
          allowInlineConfig,
          filename: filePathToVerify,
          fix,
          reportUnusedDisableDirectives,
          /**
           * Check if the linter should adopt a given code block or not.
           * @param {string} blockFilename The virtual filename of a code block.
           * @returns {boolean} `true` if the linter should adopt the code block.
           */
          filterCodeBlock(blockFilename) {
            return configs.isExplicitMatch(blockFilename);
          }
        }
      );
      const result = {
        filePath: filePath === "<text>" ? filePath : path2.resolve(filePath),
        messages,
        suppressedMessages: linter.getSuppressedMessages(),
        ...calculateStatsPerFile(messages)
      };
      if (fixed) {
        result.output = output;
      }
      if (result.errorCount + result.warningCount > 0 && typeof result.output === "undefined") {
        result.source = text;
      }
      return result;
    }
    function shouldMessageBeFixed(message, config, fixTypes) {
      if (!message.ruleId) {
        return fixTypes.has("directive");
      }
      const rule = message.ruleId && getRuleFromConfig(message.ruleId, config);
      return Boolean(rule && rule.meta && fixTypes.has(rule.meta.type));
    }
    function* iterateRuleDeprecationWarnings(configs) {
      const processedRuleIds = /* @__PURE__ */ new Set();
      for (const config of configs) {
        for (const [ruleId, ruleConfig] of Object.entries(config.rules)) {
          if (processedRuleIds.has(ruleId)) {
            continue;
          }
          processedRuleIds.add(ruleId);
          if (!getRuleSeverity(ruleConfig)) {
            continue;
          }
          const rule = getRuleFromConfig(ruleId, config);
          if (!(rule && rule.meta && rule.meta.deprecated)) {
            continue;
          }
          yield {
            ruleId,
            replacedBy: rule.meta.replacedBy || []
          };
        }
      }
    }
    function createExtraneousResultsError() {
      return new TypeError("Results object was not created from this ESLint instance.");
    }
    var FlatESLint = class {
      /**
       * Creates a new instance of the main ESLint API.
       * @param {FlatESLintOptions} options The options for this instance.
       */
      constructor(options = {}) {
        const defaultConfigs = [];
        const processedOptions = processOptions(options);
        const linter = new Linter({
          cwd: processedOptions.cwd,
          configType: "flat"
        });
        const cacheFilePath = getCacheFile(
          processedOptions.cacheLocation,
          processedOptions.cwd
        );
        const lintResultCache = processedOptions.cache ? new LintResultCache(cacheFilePath, processedOptions.cacheStrategy) : null;
        privateMembers.set(this, {
          options: processedOptions,
          linter,
          cacheFilePath,
          lintResultCache,
          defaultConfigs,
          defaultIgnores: () => false,
          configs: null
        });
        if (options.plugins) {
          const plugins = {};
          for (const [pluginName, plugin] of Object.entries(options.plugins)) {
            plugins[naming.getShorthandName(pluginName, "eslint-plugin")] = plugin;
          }
          defaultConfigs.push({
            plugins
          });
        }
      }
      /**
       * The version text.
       * @type {string}
       */
      static get version() {
        return version2;
      }
      /**
       * Outputs fixes from the given results to files.
       * @param {LintResult[]} results The lint results.
       * @returns {Promise<void>} Returns a promise that is used to track side effects.
       */
      static async outputFixes(results) {
        if (!Array.isArray(results)) {
          throw new Error("'results' must be an array");
        }
        await Promise.all(
          results.filter((result) => {
            if (typeof result !== "object" || result === null) {
              throw new Error("'results' must include only objects");
            }
            return typeof result.output === "string" && path2.isAbsolute(result.filePath);
          }).map((r) => fs2.writeFile(r.filePath, r.output))
        );
      }
      /**
       * Returns results that only contains errors.
       * @param {LintResult[]} results The results to filter.
       * @returns {LintResult[]} The filtered results.
       */
      static getErrorResults(results) {
        const filtered = [];
        results.forEach((result) => {
          const filteredMessages = result.messages.filter(isErrorMessage);
          const filteredSuppressedMessages = result.suppressedMessages.filter(isErrorMessage);
          if (filteredMessages.length > 0) {
            filtered.push({
              ...result,
              messages: filteredMessages,
              suppressedMessages: filteredSuppressedMessages,
              errorCount: filteredMessages.length,
              warningCount: 0,
              fixableErrorCount: result.fixableErrorCount,
              fixableWarningCount: 0
            });
          }
        });
        return filtered;
      }
      /**
       * Returns meta objects for each rule represented in the lint results.
       * @param {LintResult[]} results The results to fetch rules meta for.
       * @returns {Object} A mapping of ruleIds to rule meta objects.
       * @throws {TypeError} When the results object wasn't created from this ESLint instance.
       * @throws {TypeError} When a plugin or rule is missing.
       */
      getRulesMetaForResults(results) {
        if (results.length === 0) {
          return {};
        }
        const resultRules = /* @__PURE__ */ new Map();
        const {
          configs,
          options: { cwd }
        } = privateMembers.get(this);
        if (!configs) {
          throw createExtraneousResultsError();
        }
        for (const result of results) {
          const filePath = result.filePath === "<text>" ? getPlaceholderPath(cwd) : result.filePath;
          const allMessages = result.messages.concat(result.suppressedMessages);
          for (const { ruleId } of allMessages) {
            if (!ruleId) {
              continue;
            }
            const config = configs.getConfig(filePath);
            if (!config) {
              throw createExtraneousResultsError();
            }
            const rule = getRuleFromConfig(ruleId, config);
            if (!rule) {
              throw new TypeError(`Could not find the rule "${ruleId}".`);
            }
            resultRules.set(ruleId, rule);
          }
        }
        return createRulesMeta(resultRules);
      }
      /**
       * Executes the current configuration on an array of file and directory names.
       * @param {string|string[]} patterns An array of file and directory names.
       * @returns {Promise<LintResult[]>} The results of linting the file patterns given.
       */
      async lintFiles(patterns) {
        if (!isNonEmptyString(patterns) && !isArrayOfNonEmptyString(patterns)) {
          throw new Error("'patterns' must be a non-empty string or an array of non-empty strings");
        }
        const {
          cacheFilePath,
          lintResultCache,
          linter,
          options: eslintOptions
        } = privateMembers.get(this);
        const configs = await calculateConfigArray(this, eslintOptions);
        const {
          allowInlineConfig,
          cache,
          cwd,
          fix,
          fixTypes,
          reportUnusedDisableDirectives,
          globInputPaths,
          errorOnUnmatchedPattern
        } = eslintOptions;
        const startTime = Date.now();
        const usedConfigs = [];
        const fixTypesSet = fixTypes ? new Set(fixTypes) : null;
        if (!cache && cacheFilePath) {
          debug(`Deleting cache file at ${cacheFilePath}`);
          try {
            await fs2.unlink(cacheFilePath);
          } catch (error) {
            const errorCode = error && error.code;
            if (errorCode !== "ENOENT" && !(errorCode === "EROFS" && !await fs2.exists(cacheFilePath))) {
              throw error;
            }
          }
        }
        const filePaths = await findFiles({
          patterns: typeof patterns === "string" ? [patterns] : patterns,
          cwd,
          globInputPaths,
          configs,
          errorOnUnmatchedPattern
        });
        debug(`${filePaths.length} files found in: ${Date.now() - startTime}ms`);
        const results = await Promise.all(
          filePaths.map(({ filePath, ignored }) => {
            if (ignored) {
              return createIgnoreResult(filePath, cwd);
            }
            const config = configs.getConfig(filePath);
            if (!config) {
              return void 0;
            }
            if (!usedConfigs.includes(config)) {
              usedConfigs.push(config);
            }
            if (lintResultCache) {
              const cachedResult = lintResultCache.getCachedLintResults(filePath, config);
              if (cachedResult) {
                const hadMessages = cachedResult.messages && cachedResult.messages.length > 0;
                if (hadMessages && fix) {
                  debug(`Reprocessing cached file to allow autofix: ${filePath}`);
                } else {
                  debug(`Skipping file since it hasn't changed: ${filePath}`);
                  return cachedResult;
                }
              }
            }
            let fixer = fix;
            if (fix && fixTypesSet) {
              const originalFix = typeof fix === "function" ? fix : () => true;
              fixer = (message) => shouldMessageBeFixed(message, config, fixTypesSet) && originalFix(message);
            }
            return fs2.readFile(filePath, "utf8").then((text) => {
              const result = verifyText({
                text,
                filePath,
                configs,
                cwd,
                fix: fixer,
                allowInlineConfig,
                reportUnusedDisableDirectives,
                linter
              });
              if (lintResultCache) {
                lintResultCache.setCachedLintResults(filePath, config, result);
              }
              return result;
            });
          })
        );
        if (lintResultCache) {
          lintResultCache.reconcile();
        }
        let usedDeprecatedRules;
        const finalResults = results.filter((result) => !!result);
        return processLintReport(this, {
          results: finalResults,
          ...calculateStatsPerRun(finalResults),
          // Initialize it lazily because CLI and `ESLint` API don't use it.
          get usedDeprecatedRules() {
            if (!usedDeprecatedRules) {
              usedDeprecatedRules = Array.from(
                iterateRuleDeprecationWarnings(usedConfigs)
              );
            }
            return usedDeprecatedRules;
          }
        });
      }
      /**
       * Executes the current configuration on text.
       * @param {string} code A string of JavaScript code to lint.
       * @param {Object} [options] The options.
       * @param {string} [options.filePath] The path to the file of the source code.
       * @param {boolean} [options.warnIgnored] When set to true, warn if given filePath is an ignored path.
       * @returns {Promise<LintResult[]>} The results of linting the string of code given.
       */
      async lintText(code, options = {}) {
        if (typeof code !== "string") {
          throw new Error("'code' must be a string");
        }
        if (typeof options !== "object") {
          throw new Error("'options' must be an object, null, or undefined");
        }
        const {
          filePath,
          warnIgnored = false,
          ...unknownOptions
        } = options || {};
        const unknownOptionKeys = Object.keys(unknownOptions);
        if (unknownOptionKeys.length > 0) {
          throw new Error(`'options' must not include the unknown option(s): ${unknownOptionKeys.join(", ")}`);
        }
        if (filePath !== void 0 && !isNonEmptyString(filePath)) {
          throw new Error("'options.filePath' must be a non-empty string or undefined");
        }
        if (typeof warnIgnored !== "boolean") {
          throw new Error("'options.warnIgnored' must be a boolean or undefined");
        }
        const {
          linter,
          options: eslintOptions
        } = privateMembers.get(this);
        const configs = await calculateConfigArray(this, eslintOptions);
        const {
          allowInlineConfig,
          cwd,
          fix,
          reportUnusedDisableDirectives
        } = eslintOptions;
        const results = [];
        const startTime = Date.now();
        const resolvedFilename = path2.resolve(cwd, filePath || "__placeholder__.js");
        let config;
        if (resolvedFilename && await this.isPathIgnored(resolvedFilename)) {
          if (warnIgnored) {
            results.push(createIgnoreResult(resolvedFilename, cwd));
          }
        } else {
          config = configs.getConfig(resolvedFilename);
          results.push(verifyText({
            text: code,
            filePath: resolvedFilename.endsWith("__placeholder__.js") ? "<text>" : resolvedFilename,
            configs,
            cwd,
            fix,
            allowInlineConfig,
            reportUnusedDisableDirectives,
            linter
          }));
        }
        debug(`Linting complete in: ${Date.now() - startTime}ms`);
        let usedDeprecatedRules;
        return processLintReport(this, {
          results,
          ...calculateStatsPerRun(results),
          // Initialize it lazily because CLI and `ESLint` API don't use it.
          get usedDeprecatedRules() {
            if (!usedDeprecatedRules) {
              usedDeprecatedRules = Array.from(
                iterateRuleDeprecationWarnings(config)
              );
            }
            return usedDeprecatedRules;
          }
        });
      }
      /**
       * Returns the formatter representing the given formatter name.
       * @param {string} [name] The name of the formatter to load.
       * The following values are allowed:
       * - `undefined` ... Load `stylish` builtin formatter.
       * - A builtin formatter name ... Load the builtin formatter.
       * - A third-party formatter name:
       *   - `foo` → `eslint-formatter-foo`
       *   - `@foo` → `@foo/eslint-formatter`
       *   - `@foo/bar` → `@foo/eslint-formatter-bar`
       * - A file path ... Load the file.
       * @returns {Promise<Formatter>} A promise resolving to the formatter object.
       * This promise will be rejected if the given formatter was not found or not
       * a function.
       */
      async loadFormatter(name = "stylish") {
        if (typeof name !== "string") {
          throw new Error("'name' must be a string");
        }
        const normalizedFormatName = name.replace(/\\/gu, "/");
        const namespace = naming.getNamespaceFromTerm(normalizedFormatName);
        const { cwd } = privateMembers.get(this).options;
        let formatterPath;
        if (!namespace && normalizedFormatName.includes("/")) {
          formatterPath = path2.resolve(cwd, normalizedFormatName);
        } else {
          try {
            const npmFormat = naming.normalizePackageName(normalizedFormatName, "eslint-formatter");
            formatterPath = ModuleResolver.resolve(npmFormat, getPlaceholderPath(cwd));
          } catch {
            formatterPath = path2.resolve(__dirname, "../", "cli-engine", "formatters", `${normalizedFormatName}.js`);
          }
        }
        let formatter;
        try {
          formatter = (await import(pathToFileURL(formatterPath))).default;
        } catch (ex) {
          if (removedFormatters.has(name)) {
            ex.message = `The ${name} formatter is no longer part of core ESLint. Install it manually with \`npm install -D eslint-formatter-${name}\``;
          } else {
            ex.message = `There was a problem loading formatter: ${formatterPath}
Error: ${ex.message}`;
          }
          throw ex;
        }
        if (typeof formatter !== "function") {
          throw new TypeError(`Formatter must be a function, but got a ${typeof formatter}.`);
        }
        const eslint = this;
        return {
          /**
           * The main formatter method.
           * @param {LintResults[]} results The lint results to format.
           * @param {ResultsMeta} resultsMeta Warning count and max threshold.
           * @returns {string} The formatted lint results.
           */
          format(results, resultsMeta) {
            let rulesMeta = null;
            results.sort(compareResultsByFilePath);
            return formatter(results, {
              ...resultsMeta,
              cwd,
              get rulesMeta() {
                if (!rulesMeta) {
                  rulesMeta = eslint.getRulesMetaForResults(results);
                }
                return rulesMeta;
              }
            });
          }
        };
      }
      /**
       * Returns a configuration object for the given file based on the CLI options.
       * This is the same logic used by the ESLint CLI executable to determine
       * configuration for each file it processes.
       * @param {string} filePath The path of the file to retrieve a config object for.
       * @returns {Promise<ConfigData|undefined>} A configuration object for the file
       *      or `undefined` if there is no configuration data for the object.
       */
      async calculateConfigForFile(filePath) {
        if (!isNonEmptyString(filePath)) {
          throw new Error("'filePath' must be a non-empty string");
        }
        const options = privateMembers.get(this).options;
        const absolutePath = path2.resolve(options.cwd, filePath);
        const configs = await calculateConfigArray(this, options);
        return configs.getConfig(absolutePath);
      }
      /**
       * Checks if a given path is ignored by ESLint.
       * @param {string} filePath The path of the file to check.
       * @returns {Promise<boolean>} Whether or not the given path is ignored.
       */
      async isPathIgnored(filePath) {
        const config = await this.calculateConfigForFile(filePath);
        return config === void 0;
      }
    };
    module2.exports = {
      FlatESLint,
      findFlatConfigFile
    };
  }
});

// node_modules/eslint/lib/eslint/index.js
var require_eslint2 = __commonJS({
  "node_modules/eslint/lib/eslint/index.js"(exports, module2) {
    "use strict";
    var { ESLint } = require_eslint();
    var { FlatESLint } = require_flat_eslint();
    module2.exports = {
      ESLint,
      FlatESLint
    };
  }
});

// node_modules/eslint/conf/config-schema.js
var require_config_schema = __commonJS({
  "node_modules/eslint/conf/config-schema.js"(exports, module2) {
    "use strict";
    var baseConfigProperties = {
      $schema: { type: "string" },
      env: { type: "object" },
      extends: { $ref: "#/definitions/stringOrStrings" },
      globals: { type: "object" },
      overrides: {
        type: "array",
        items: { $ref: "#/definitions/overrideConfig" },
        additionalItems: false
      },
      parser: { type: ["string", "null"] },
      parserOptions: { type: "object" },
      plugins: { type: "array" },
      processor: { type: "string" },
      rules: { type: "object" },
      settings: { type: "object" },
      noInlineConfig: { type: "boolean" },
      reportUnusedDisableDirectives: { type: "boolean" },
      ecmaFeatures: { type: "object" }
      // deprecated; logs a warning when used
    };
    var configSchema = {
      definitions: {
        stringOrStrings: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false
            }
          ]
        },
        stringOrStringsRequired: {
          oneOf: [
            { type: "string" },
            {
              type: "array",
              items: { type: "string" },
              additionalItems: false,
              minItems: 1
            }
          ]
        },
        // Config at top-level.
        objectConfig: {
          type: "object",
          properties: {
            root: { type: "boolean" },
            ignorePatterns: { $ref: "#/definitions/stringOrStrings" },
            ...baseConfigProperties
          },
          additionalProperties: false
        },
        // Config in `overrides`.
        overrideConfig: {
          type: "object",
          properties: {
            excludedFiles: { $ref: "#/definitions/stringOrStrings" },
            files: { $ref: "#/definitions/stringOrStringsRequired" },
            ...baseConfigProperties
          },
          required: ["files"],
          additionalProperties: false
        }
      },
      $ref: "#/definitions/objectConfig"
    };
    module2.exports = configSchema;
  }
});

// node_modules/eslint/lib/shared/deprecation-warnings.js
var require_deprecation_warnings = __commonJS({
  "node_modules/eslint/lib/shared/deprecation-warnings.js"(exports, module2) {
    "use strict";
    var path2 = require("path");
    var deprecationWarningMessages = {
      ESLINT_LEGACY_ECMAFEATURES: "The 'ecmaFeatures' config file property is deprecated and has no effect."
    };
    var sourceFileErrorCache = /* @__PURE__ */ new Set();
    function emitDeprecationWarning(source, errorCode) {
      const cacheKey = JSON.stringify({ source, errorCode });
      if (sourceFileErrorCache.has(cacheKey)) {
        return;
      }
      sourceFileErrorCache.add(cacheKey);
      const rel = path2.relative(process.cwd(), source);
      const message = deprecationWarningMessages[errorCode];
      process.emitWarning(
        `${message} (found in "${rel}")`,
        "DeprecationWarning",
        errorCode
      );
    }
    module2.exports = {
      emitDeprecationWarning
    };
  }
});

// node_modules/eslint/lib/shared/config-validator.js
var require_config_validator = __commonJS({
  "node_modules/eslint/lib/shared/config-validator.js"(exports, module2) {
    "use strict";
    var util = require("util");
    var configSchema = require_config_schema();
    var BuiltInRules = require_rules2();
    var {
      Legacy: {
        ConfigOps,
        environments: BuiltInEnvironments
      }
    } = require_eslintrc();
    var { emitDeprecationWarning } = require_deprecation_warnings();
    var ajv = require_ajv2()();
    var ruleValidators = /* @__PURE__ */ new WeakMap();
    var noop = Function.prototype;
    var validateSchema;
    var severityMap = {
      error: 2,
      warn: 1,
      off: 0
    };
    function getRuleOptionsSchema(rule) {
      if (!rule) {
        return null;
      }
      const schema = rule.schema || rule.meta && rule.meta.schema;
      if (Array.isArray(schema)) {
        if (schema.length) {
          return {
            type: "array",
            items: schema,
            minItems: 0,
            maxItems: schema.length
          };
        }
        return {
          type: "array",
          minItems: 0,
          maxItems: 0
        };
      }
      return schema || null;
    }
    function validateRuleSeverity(options) {
      const severity = Array.isArray(options) ? options[0] : options;
      const normSeverity = typeof severity === "string" ? severityMap[severity.toLowerCase()] : severity;
      if (normSeverity === 0 || normSeverity === 1 || normSeverity === 2) {
        return normSeverity;
      }
      throw new Error(`	Severity should be one of the following: 0 = off, 1 = warn, 2 = error (you passed '${util.inspect(severity).replace(/'/gu, '"').replace(/\n/gu, "")}').
`);
    }
    function validateRuleSchema(rule, localOptions) {
      if (!ruleValidators.has(rule)) {
        const schema = getRuleOptionsSchema(rule);
        if (schema) {
          ruleValidators.set(rule, ajv.compile(schema));
        }
      }
      const validateRule = ruleValidators.get(rule);
      if (validateRule) {
        validateRule(localOptions);
        if (validateRule.errors) {
          throw new Error(validateRule.errors.map(
            (error) => `	Value ${JSON.stringify(error.data)} ${error.message}.
`
          ).join(""));
        }
      }
    }
    function validateRuleOptions(rule, ruleId, options, source = null) {
      try {
        const severity = validateRuleSeverity(options);
        if (severity !== 0) {
          validateRuleSchema(rule, Array.isArray(options) ? options.slice(1) : []);
        }
      } catch (err) {
        const enhancedMessage = `Configuration for rule "${ruleId}" is invalid:
${err.message}`;
        if (typeof source === "string") {
          throw new Error(`${source}:
	${enhancedMessage}`);
        } else {
          throw new Error(enhancedMessage);
        }
      }
    }
    function validateEnvironment(environment, source, getAdditionalEnv = noop) {
      if (!environment) {
        return;
      }
      Object.keys(environment).forEach((id) => {
        const env = getAdditionalEnv(id) || BuiltInEnvironments.get(id) || null;
        if (!env) {
          const message = `${source}:
	Environment key "${id}" is unknown
`;
          throw new Error(message);
        }
      });
    }
    function validateRules(rulesConfig, source, getAdditionalRule = noop) {
      if (!rulesConfig) {
        return;
      }
      Object.keys(rulesConfig).forEach((id) => {
        const rule = getAdditionalRule(id) || BuiltInRules.get(id) || null;
        validateRuleOptions(rule, id, rulesConfig[id], source);
      });
    }
    function validateGlobals(globalsConfig, source = null) {
      if (!globalsConfig) {
        return;
      }
      Object.entries(globalsConfig).forEach(([configuredGlobal, configuredValue]) => {
        try {
          ConfigOps.normalizeConfigGlobal(configuredValue);
        } catch (err) {
          throw new Error(`ESLint configuration of global '${configuredGlobal}' in ${source} is invalid:
${err.message}`);
        }
      });
    }
    function validateProcessor(processorName, source, getProcessor) {
      if (processorName && !getProcessor(processorName)) {
        throw new Error(`ESLint configuration of processor in '${source}' is invalid: '${processorName}' was not found.`);
      }
    }
    function formatErrors(errors) {
      return errors.map((error) => {
        if (error.keyword === "additionalProperties") {
          const formattedPropertyPath = error.dataPath.length ? `${error.dataPath.slice(1)}.${error.params.additionalProperty}` : error.params.additionalProperty;
          return `Unexpected top-level property "${formattedPropertyPath}"`;
        }
        if (error.keyword === "type") {
          const formattedField = error.dataPath.slice(1);
          const formattedExpectedType = Array.isArray(error.schema) ? error.schema.join("/") : error.schema;
          const formattedValue = JSON.stringify(error.data);
          return `Property "${formattedField}" is the wrong type (expected ${formattedExpectedType} but got \`${formattedValue}\`)`;
        }
        const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
        return `"${field}" ${error.message}. Value: ${JSON.stringify(error.data)}`;
      }).map((message) => `	- ${message}.
`).join("");
    }
    function validateConfigSchema(config, source = null) {
      validateSchema = validateSchema || ajv.compile(configSchema);
      if (!validateSchema(config)) {
        throw new Error(`ESLint configuration in ${source} is invalid:
${formatErrors(validateSchema.errors)}`);
      }
      if (Object.hasOwnProperty.call(config, "ecmaFeatures")) {
        emitDeprecationWarning(source, "ESLINT_LEGACY_ECMAFEATURES");
      }
    }
    function validate(config, source, getAdditionalRule, getAdditionalEnv) {
      validateConfigSchema(config, source);
      validateRules(config.rules, source, getAdditionalRule);
      validateEnvironment(config.env, source, getAdditionalEnv);
      validateGlobals(config.globals, source);
      for (const override of config.overrides || []) {
        validateRules(override.rules, source, getAdditionalRule);
        validateEnvironment(override.env, source, getAdditionalEnv);
        validateGlobals(config.globals, source);
      }
    }
    var validated = /* @__PURE__ */ new WeakSet();
    function validateConfigArray(configArray) {
      const getPluginEnv = Map.prototype.get.bind(configArray.pluginEnvironments);
      const getPluginProcessor = Map.prototype.get.bind(configArray.pluginProcessors);
      const getPluginRule = Map.prototype.get.bind(configArray.pluginRules);
      for (const element of configArray) {
        if (validated.has(element)) {
          continue;
        }
        validated.add(element);
        validateEnvironment(element.env, element.name, getPluginEnv);
        validateGlobals(element.globals, element.name);
        validateProcessor(element.processor, element.name, getPluginProcessor);
        validateRules(element.rules, element.name, getPluginRule);
      }
    }
    module2.exports = {
      getRuleOptionsSchema,
      validate,
      validateConfigArray,
      validateConfigSchema,
      validateRuleOptions
    };
  }
});

// node_modules/eslint/lib/rule-tester/rule-tester.js
var require_rule_tester = __commonJS({
  "node_modules/eslint/lib/rule-tester/rule-tester.js"(exports, module2) {
    "use strict";
    var assert = require("assert");
    var path2 = require("path");
    var util = require("util");
    var merge4 = require_lodash2();
    var equal = require_fast_deep_equal();
    var Traverser = require_traverser();
    var { getRuleOptionsSchema, validate } = require_config_validator();
    var { Linter, SourceCodeFixer, interpolate } = require_linter2();
    var ajv = require_ajv2()({ strictDefaults: true });
    var espreePath = require.resolve("espree");
    var parserSymbol = Symbol.for("eslint.RuleTester.parser");
    var { SourceCode } = require_source_code2();
    var testerDefaultConfig = { rules: {} };
    var defaultConfig = { rules: {} };
    var RuleTesterParameters = [
      "name",
      "code",
      "filename",
      "options",
      "errors",
      "output",
      "only"
    ];
    var errorObjectParameters = /* @__PURE__ */ new Set([
      "message",
      "messageId",
      "data",
      "type",
      "line",
      "column",
      "endLine",
      "endColumn",
      "suggestions"
    ]);
    var friendlyErrorObjectParameterList = `[${[...errorObjectParameters].map((key) => `'${key}'`).join(", ")}]`;
    var suggestionObjectParameters = /* @__PURE__ */ new Set([
      "desc",
      "messageId",
      "data",
      "output"
    ]);
    var friendlySuggestionObjectParameterList = `[${[...suggestionObjectParameters].map((key) => `'${key}'`).join(", ")}]`;
    var hasOwnProperty = Function.call.bind(Object.hasOwnProperty);
    function cloneDeeplyExcludesParent(x) {
      if (typeof x === "object" && x !== null) {
        if (Array.isArray(x)) {
          return x.map(cloneDeeplyExcludesParent);
        }
        const retv = {};
        for (const key in x) {
          if (key !== "parent" && hasOwnProperty(x, key)) {
            retv[key] = cloneDeeplyExcludesParent(x[key]);
          }
        }
        return retv;
      }
      return x;
    }
    function freezeDeeply(x) {
      if (typeof x === "object" && x !== null) {
        if (Array.isArray(x)) {
          x.forEach(freezeDeeply);
        } else {
          for (const key in x) {
            if (key !== "parent" && hasOwnProperty(x, key)) {
              freezeDeeply(x[key]);
            }
          }
        }
        Object.freeze(x);
      }
    }
    function sanitize(text) {
      if (typeof text !== "string") {
        return "";
      }
      return text.replace(
        /[\u0000-\u0009\u000b-\u001a]/gu,
        // eslint-disable-line no-control-regex -- Escaping controls
        (c) => `\\u${c.codePointAt(0).toString(16).padStart(4, "0")}`
      );
    }
    function defineStartEndAsError(objName, node) {
      Object.defineProperties(node, {
        start: {
          get() {
            throw new Error(`Use ${objName}.range[0] instead of ${objName}.start`);
          },
          configurable: true,
          enumerable: false
        },
        end: {
          get() {
            throw new Error(`Use ${objName}.range[1] instead of ${objName}.end`);
          },
          configurable: true,
          enumerable: false
        }
      });
    }
    function defineStartEndAsErrorInTree(ast, visitorKeys) {
      Traverser.traverse(ast, { visitorKeys, enter: defineStartEndAsError.bind(null, "node") });
      ast.tokens.forEach(defineStartEndAsError.bind(null, "token"));
      ast.comments.forEach(defineStartEndAsError.bind(null, "token"));
    }
    function wrapParser(parser) {
      if (typeof parser.parseForESLint === "function") {
        return {
          [parserSymbol]: parser,
          parseForESLint(...args) {
            const ret = parser.parseForESLint(...args);
            defineStartEndAsErrorInTree(ret.ast, ret.visitorKeys);
            return ret;
          }
        };
      }
      return {
        [parserSymbol]: parser,
        parse(...args) {
          const ast = parser.parse(...args);
          defineStartEndAsErrorInTree(ast);
          return ast;
        }
      };
    }
    function getCommentsDeprecation() {
      throw new Error(
        "`SourceCode#getComments()` is deprecated and will be removed in a future major version. Use `getCommentsBefore()`, `getCommentsAfter()`, and `getCommentsInside()` instead."
      );
    }
    function emitLegacyRuleAPIWarning(ruleName) {
      if (!emitLegacyRuleAPIWarning[`warned-${ruleName}`]) {
        emitLegacyRuleAPIWarning[`warned-${ruleName}`] = true;
        process.emitWarning(
          `"${ruleName}" rule is using the deprecated function-style format and will stop working in ESLint v9. Please use object-style format: https://eslint.org/docs/developer-guide/working-with-rules`,
          "DeprecationWarning"
        );
      }
    }
    function emitMissingSchemaWarning(ruleName) {
      if (!emitMissingSchemaWarning[`warned-${ruleName}`]) {
        emitMissingSchemaWarning[`warned-${ruleName}`] = true;
        process.emitWarning(
          `"${ruleName}" rule has options but is missing the "meta.schema" property and will stop working in ESLint v9. Please add a schema: https://eslint.org/docs/developer-guide/working-with-rules#options-schemas`,
          "DeprecationWarning"
        );
      }
    }
    var DESCRIBE = Symbol("describe");
    var IT = Symbol("it");
    var IT_ONLY = Symbol("itOnly");
    function itDefaultHandler(text, method) {
      try {
        return method.call(this);
      } catch (err) {
        if (err instanceof assert.AssertionError) {
          err.message += ` (${util.inspect(err.actual)} ${err.operator} ${util.inspect(err.expected)})`;
        }
        throw err;
      }
    }
    function describeDefaultHandler(text, method) {
      return method.call(this);
    }
    var RuleTester = class {
      /**
       * Creates a new instance of RuleTester.
       * @param {Object} [testerConfig] Optional, extra configuration for the tester
       */
      constructor(testerConfig) {
        this.testerConfig = merge4(
          {},
          defaultConfig,
          testerConfig,
          { rules: { "rule-tester/validate-ast": "error" } }
        );
        this.rules = {};
        this.linter = new Linter();
      }
      /**
       * Set the configuration to use for all future tests
       * @param {Object} config the configuration to use.
       * @throws {TypeError} If non-object config.
       * @returns {void}
       */
      static setDefaultConfig(config) {
        if (typeof config !== "object") {
          throw new TypeError("RuleTester.setDefaultConfig: config must be an object");
        }
        defaultConfig = config;
        defaultConfig.rules = defaultConfig.rules || {};
      }
      /**
       * Get the current configuration used for all tests
       * @returns {Object} the current configuration
       */
      static getDefaultConfig() {
        return defaultConfig;
      }
      /**
       * Reset the configuration to the initial configuration of the tester removing
       * any changes made until now.
       * @returns {void}
       */
      static resetDefaultConfig() {
        defaultConfig = merge4({}, testerDefaultConfig);
      }
      /*
       * If people use `mocha test.js --watch` command, `describe` and `it` function
       * instances are different for each execution. So `describe` and `it` should get fresh instance
       * always.
       */
      static get describe() {
        return this[DESCRIBE] || (typeof describe === "function" ? describe : describeDefaultHandler);
      }
      static set describe(value2) {
        this[DESCRIBE] = value2;
      }
      static get it() {
        return this[IT] || (typeof it === "function" ? it : itDefaultHandler);
      }
      static set it(value2) {
        this[IT] = value2;
      }
      /**
       * Adds the `only` property to a test to run it in isolation.
       * @param {string | ValidTestCase | InvalidTestCase} item A single test to run by itself.
       * @returns {ValidTestCase | InvalidTestCase} The test with `only` set.
       */
      static only(item) {
        if (typeof item === "string") {
          return { code: item, only: true };
        }
        return { ...item, only: true };
      }
      static get itOnly() {
        if (typeof this[IT_ONLY] === "function") {
          return this[IT_ONLY];
        }
        if (typeof this[IT] === "function" && typeof this[IT].only === "function") {
          return Function.bind.call(this[IT].only, this[IT]);
        }
        if (typeof it === "function" && typeof it.only === "function") {
          return Function.bind.call(it.only, it);
        }
        if (typeof this[DESCRIBE] === "function" || typeof this[IT] === "function") {
          throw new Error(
            "Set `RuleTester.itOnly` to use `only` with a custom test framework.\nSee https://eslint.org/docs/developer-guide/nodejs-api#customizing-ruletester for more."
          );
        }
        if (typeof it === "function") {
          throw new Error("The current test framework does not support exclusive tests with `only`.");
        }
        throw new Error("To use `only`, use RuleTester with a test framework that provides `it.only()` like Mocha.");
      }
      static set itOnly(value2) {
        this[IT_ONLY] = value2;
      }
      /**
       * Define a rule for one particular run of tests.
       * @param {string} name The name of the rule to define.
       * @param {Function} rule The rule definition.
       * @returns {void}
       */
      defineRule(name, rule) {
        this.rules[name] = rule;
      }
      /**
       * Adds a new rule test to execute.
       * @param {string} ruleName The name of the rule to run.
       * @param {Function} rule The rule to test.
       * @param {{
       *   valid: (ValidTestCase | string)[],
       *   invalid: InvalidTestCase[]
       * }} test The collection of tests to run.
       * @throws {TypeError|Error} If non-object `test`, or if a required
       * scenario of the given type is missing.
       * @returns {void}
       */
      run(ruleName, rule, test) {
        const testerConfig = this.testerConfig, requiredScenarios = ["valid", "invalid"], scenarioErrors = [], linter = this.linter;
        if (!test || typeof test !== "object") {
          throw new TypeError(`Test Scenarios for rule ${ruleName} : Could not find test scenario object`);
        }
        requiredScenarios.forEach((scenarioType) => {
          if (!test[scenarioType]) {
            scenarioErrors.push(`Could not find any ${scenarioType} test scenarios`);
          }
        });
        if (scenarioErrors.length > 0) {
          throw new Error([
            `Test Scenarios for rule ${ruleName} is invalid:`
          ].concat(scenarioErrors).join("\n"));
        }
        if (typeof rule === "function") {
          emitLegacyRuleAPIWarning(ruleName);
        }
        linter.defineRule(ruleName, Object.assign({}, rule, {
          // Create a wrapper rule that freezes the `context` properties.
          create(context) {
            freezeDeeply(context.options);
            freezeDeeply(context.settings);
            freezeDeeply(context.parserOptions);
            return (typeof rule === "function" ? rule : rule.create)(context);
          }
        }));
        linter.defineRules(this.rules);
        function runRuleForItem(item) {
          let config = merge4({}, testerConfig), code, filename, output, beforeAST, afterAST;
          if (typeof item === "string") {
            code = item;
          } else {
            code = item.code;
            const itemConfig = { ...item };
            for (const parameter of RuleTesterParameters) {
              delete itemConfig[parameter];
            }
            config = merge4(
              config,
              itemConfig
            );
          }
          if (item.filename) {
            filename = item.filename;
          }
          if (hasOwnProperty(item, "options")) {
            assert(Array.isArray(item.options), "options must be an array");
            if (item.options.length > 0 && typeof rule === "object" && (!rule.meta || rule.meta && (typeof rule.meta.schema === "undefined" || rule.meta.schema === null))) {
              emitMissingSchemaWarning(ruleName);
            }
            config.rules[ruleName] = [1].concat(item.options);
          } else {
            config.rules[ruleName] = 1;
          }
          const schema = getRuleOptionsSchema(rule);
          linter.defineRule("rule-tester/validate-ast", {
            create() {
              return {
                Program(node) {
                  beforeAST = cloneDeeplyExcludesParent(node);
                },
                "Program:exit"(node) {
                  afterAST = node;
                }
              };
            }
          });
          if (typeof config.parser === "string") {
            assert(path2.isAbsolute(config.parser), "Parsers provided as strings to RuleTester must be absolute paths");
          } else {
            config.parser = espreePath;
          }
          linter.defineParser(config.parser, wrapParser(require(config.parser)));
          if (schema) {
            ajv.validateSchema(schema);
            if (ajv.errors) {
              const errors = ajv.errors.map((error) => {
                const field = error.dataPath[0] === "." ? error.dataPath.slice(1) : error.dataPath;
                return `	${field}: ${error.message}`;
              }).join("\n");
              throw new Error([`Schema for rule ${ruleName} is invalid:`, errors]);
            }
            try {
              ajv.compile(schema);
            } catch (err) {
              throw new Error(`Schema for rule ${ruleName} is invalid: ${err.message}`);
            }
          }
          validate(config, "rule-tester", (id) => id === ruleName ? rule : null);
          const { getComments } = SourceCode.prototype;
          let messages;
          try {
            SourceCode.prototype.getComments = getCommentsDeprecation;
            messages = linter.verify(code, config, filename);
          } finally {
            SourceCode.prototype.getComments = getComments;
          }
          const fatalErrorMessage = messages.find((m) => m.fatal);
          assert(!fatalErrorMessage, `A fatal parsing error occurred: ${fatalErrorMessage && fatalErrorMessage.message}`);
          if (messages.some((m) => m.fix)) {
            output = SourceCodeFixer.applyFixes(code, messages).output;
            const errorMessageInFix = linter.verify(output, config, filename).find((m) => m.fatal);
            assert(!errorMessageInFix, [
              "A fatal parsing error occurred in autofix.",
              `Error: ${errorMessageInFix && errorMessageInFix.message}`,
              "Autofix output:",
              output
            ].join("\n"));
          } else {
            output = code;
          }
          return {
            messages,
            output,
            beforeAST,
            afterAST: cloneDeeplyExcludesParent(afterAST)
          };
        }
        function assertASTDidntChange(beforeAST, afterAST) {
          if (!equal(beforeAST, afterAST)) {
            assert.fail("Rule should not modify AST.");
          }
        }
        function testValidTemplate(item) {
          const code = typeof item === "object" ? item.code : item;
          assert.ok(typeof code === "string", "Test case must specify a string value for 'code'");
          if (item.name) {
            assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
          }
          const result = runRuleForItem(item);
          const messages = result.messages;
          assert.strictEqual(messages.length, 0, util.format(
            "Should have no errors but had %d: %s",
            messages.length,
            util.inspect(messages)
          ));
          assertASTDidntChange(result.beforeAST, result.afterAST);
        }
        function assertMessageMatches(actual, expected) {
          if (expected instanceof RegExp) {
            assert.ok(
              expected.test(actual),
              `Expected '${actual}' to match ${expected}`
            );
          } else {
            assert.strictEqual(actual, expected);
          }
        }
        function testInvalidTemplate(item) {
          assert.ok(typeof item.code === "string", "Test case must specify a string value for 'code'");
          if (item.name) {
            assert.ok(typeof item.name === "string", "Optional test case property 'name' must be a string");
          }
          assert.ok(
            item.errors || item.errors === 0,
            `Did not specify errors for an invalid test of ${ruleName}`
          );
          if (Array.isArray(item.errors) && item.errors.length === 0) {
            assert.fail("Invalid cases must have at least one error");
          }
          const ruleHasMetaMessages = hasOwnProperty(rule, "meta") && hasOwnProperty(rule.meta, "messages");
          const friendlyIDList = ruleHasMetaMessages ? `[${Object.keys(rule.meta.messages).map((key) => `'${key}'`).join(", ")}]` : null;
          const result = runRuleForItem(item);
          const messages = result.messages;
          if (typeof item.errors === "number") {
            if (item.errors === 0) {
              assert.fail("Invalid cases must have 'error' value greater than 0");
            }
            assert.strictEqual(messages.length, item.errors, util.format(
              "Should have %d error%s but had %d: %s",
              item.errors,
              item.errors === 1 ? "" : "s",
              messages.length,
              util.inspect(messages)
            ));
          } else {
            assert.strictEqual(
              messages.length,
              item.errors.length,
              util.format(
                "Should have %d error%s but had %d: %s",
                item.errors.length,
                item.errors.length === 1 ? "" : "s",
                messages.length,
                util.inspect(messages)
              )
            );
            const hasMessageOfThisRule = messages.some((m) => m.ruleId === ruleName);
            for (let i = 0, l = item.errors.length; i < l; i++) {
              const error = item.errors[i];
              const message = messages[i];
              assert(hasMessageOfThisRule, "Error rule name should be the same as the name of the rule being tested");
              if (typeof error === "string" || error instanceof RegExp) {
                assertMessageMatches(message.message, error);
              } else if (typeof error === "object" && error !== null) {
                Object.keys(error).forEach((propertyName) => {
                  assert.ok(
                    errorObjectParameters.has(propertyName),
                    `Invalid error property name '${propertyName}'. Expected one of ${friendlyErrorObjectParameterList}.`
                  );
                });
                if (hasOwnProperty(error, "message")) {
                  assert.ok(!hasOwnProperty(error, "messageId"), "Error should not specify both 'message' and a 'messageId'.");
                  assert.ok(!hasOwnProperty(error, "data"), "Error should not specify both 'data' and 'message'.");
                  assertMessageMatches(message.message, error.message);
                } else if (hasOwnProperty(error, "messageId")) {
                  assert.ok(
                    ruleHasMetaMessages,
                    "Error can not use 'messageId' if rule under test doesn't define 'meta.messages'."
                  );
                  if (!hasOwnProperty(rule.meta.messages, error.messageId)) {
                    assert(false, `Invalid messageId '${error.messageId}'. Expected one of ${friendlyIDList}.`);
                  }
                  assert.strictEqual(
                    message.messageId,
                    error.messageId,
                    `messageId '${message.messageId}' does not match expected messageId '${error.messageId}'.`
                  );
                  if (hasOwnProperty(error, "data")) {
                    const unformattedOriginalMessage = rule.meta.messages[error.messageId];
                    const rehydratedMessage = interpolate(unformattedOriginalMessage, error.data);
                    assert.strictEqual(
                      message.message,
                      rehydratedMessage,
                      `Hydrated message "${rehydratedMessage}" does not match "${message.message}"`
                    );
                  }
                }
                assert.ok(
                  hasOwnProperty(error, "data") ? hasOwnProperty(error, "messageId") : true,
                  "Error must specify 'messageId' if 'data' is used."
                );
                if (error.type) {
                  assert.strictEqual(message.nodeType, error.type, `Error type should be ${error.type}, found ${message.nodeType}`);
                }
                if (hasOwnProperty(error, "line")) {
                  assert.strictEqual(message.line, error.line, `Error line should be ${error.line}`);
                }
                if (hasOwnProperty(error, "column")) {
                  assert.strictEqual(message.column, error.column, `Error column should be ${error.column}`);
                }
                if (hasOwnProperty(error, "endLine")) {
                  assert.strictEqual(message.endLine, error.endLine, `Error endLine should be ${error.endLine}`);
                }
                if (hasOwnProperty(error, "endColumn")) {
                  assert.strictEqual(message.endColumn, error.endColumn, `Error endColumn should be ${error.endColumn}`);
                }
                if (hasOwnProperty(error, "suggestions")) {
                  if (!error.suggestions || Array.isArray(error.suggestions) && error.suggestions.length === 0) {
                    if (Array.isArray(message.suggestions) && message.suggestions.length > 0) {
                      assert.fail(`Error should have no suggestions on error with message: "${message.message}"`);
                    }
                  } else {
                    assert.strictEqual(Array.isArray(message.suggestions), true, `Error should have an array of suggestions. Instead received "${message.suggestions}" on error with message: "${message.message}"`);
                    assert.strictEqual(message.suggestions.length, error.suggestions.length, `Error should have ${error.suggestions.length} suggestions. Instead found ${message.suggestions.length} suggestions`);
                    error.suggestions.forEach((expectedSuggestion, index) => {
                      assert.ok(
                        typeof expectedSuggestion === "object" && expectedSuggestion !== null,
                        "Test suggestion in 'suggestions' array must be an object."
                      );
                      Object.keys(expectedSuggestion).forEach((propertyName) => {
                        assert.ok(
                          suggestionObjectParameters.has(propertyName),
                          `Invalid suggestion property name '${propertyName}'. Expected one of ${friendlySuggestionObjectParameterList}.`
                        );
                      });
                      const actualSuggestion = message.suggestions[index];
                      const suggestionPrefix = `Error Suggestion at index ${index} :`;
                      if (hasOwnProperty(expectedSuggestion, "desc")) {
                        assert.ok(
                          !hasOwnProperty(expectedSuggestion, "data"),
                          `${suggestionPrefix} Test should not specify both 'desc' and 'data'.`
                        );
                        assert.strictEqual(
                          actualSuggestion.desc,
                          expectedSuggestion.desc,
                          `${suggestionPrefix} desc should be "${expectedSuggestion.desc}" but got "${actualSuggestion.desc}" instead.`
                        );
                      }
                      if (hasOwnProperty(expectedSuggestion, "messageId")) {
                        assert.ok(
                          ruleHasMetaMessages,
                          `${suggestionPrefix} Test can not use 'messageId' if rule under test doesn't define 'meta.messages'.`
                        );
                        assert.ok(
                          hasOwnProperty(rule.meta.messages, expectedSuggestion.messageId),
                          `${suggestionPrefix} Test has invalid messageId '${expectedSuggestion.messageId}', the rule under test allows only one of ${friendlyIDList}.`
                        );
                        assert.strictEqual(
                          actualSuggestion.messageId,
                          expectedSuggestion.messageId,
                          `${suggestionPrefix} messageId should be '${expectedSuggestion.messageId}' but got '${actualSuggestion.messageId}' instead.`
                        );
                        if (hasOwnProperty(expectedSuggestion, "data")) {
                          const unformattedMetaMessage = rule.meta.messages[expectedSuggestion.messageId];
                          const rehydratedDesc = interpolate(unformattedMetaMessage, expectedSuggestion.data);
                          assert.strictEqual(
                            actualSuggestion.desc,
                            rehydratedDesc,
                            `${suggestionPrefix} Hydrated test desc "${rehydratedDesc}" does not match received desc "${actualSuggestion.desc}".`
                          );
                        }
                      } else {
                        assert.ok(
                          !hasOwnProperty(expectedSuggestion, "data"),
                          `${suggestionPrefix} Test must specify 'messageId' if 'data' is used.`
                        );
                      }
                      if (hasOwnProperty(expectedSuggestion, "output")) {
                        const codeWithAppliedSuggestion = SourceCodeFixer.applyFixes(item.code, [actualSuggestion]).output;
                        assert.strictEqual(codeWithAppliedSuggestion, expectedSuggestion.output, `Expected the applied suggestion fix to match the test suggestion output for suggestion at index: ${index} on error with message: "${message.message}"`);
                      }
                    });
                  }
                }
              } else {
                assert.fail(`Error should be a string, object, or RegExp, but found (${util.inspect(message)})`);
              }
            }
          }
          if (hasOwnProperty(item, "output")) {
            if (item.output === null) {
              assert.strictEqual(
                result.output,
                item.code,
                "Expected no autofixes to be suggested"
              );
            } else {
              assert.strictEqual(result.output, item.output, "Output is incorrect.");
            }
          } else {
            assert.strictEqual(
              result.output,
              item.code,
              "The rule fixed the code. Please add 'output' property."
            );
          }
          assertASTDidntChange(result.beforeAST, result.afterAST);
        }
        this.constructor.describe(ruleName, () => {
          this.constructor.describe("valid", () => {
            test.valid.forEach((valid) => {
              this.constructor[valid.only ? "itOnly" : "it"](
                sanitize(typeof valid === "object" ? valid.name || valid.code : valid),
                () => {
                  testValidTemplate(valid);
                }
              );
            });
          });
          this.constructor.describe("invalid", () => {
            test.invalid.forEach((invalid) => {
              this.constructor[invalid.only ? "itOnly" : "it"](
                sanitize(invalid.name || invalid.code),
                () => {
                  testInvalidTemplate(invalid);
                }
              );
            });
          });
        });
      }
    };
    RuleTester[DESCRIBE] = RuleTester[IT] = RuleTester[IT_ONLY] = null;
    module2.exports = RuleTester;
  }
});

// node_modules/eslint/lib/rule-tester/index.js
var require_rule_tester2 = __commonJS({
  "node_modules/eslint/lib/rule-tester/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      RuleTester: require_rule_tester()
    };
  }
});

// node_modules/eslint/lib/api.js
var require_api2 = __commonJS({
  "node_modules/eslint/lib/api.js"(exports, module2) {
    "use strict";
    var { ESLint } = require_eslint2();
    var { Linter } = require_linter2();
    var { RuleTester } = require_rule_tester2();
    var { SourceCode } = require_source_code2();
    module2.exports = {
      Linter,
      ESLint,
      RuleTester,
      SourceCode
    };
  }
});

// node_modules/vue-eslint-parser-private/index.js
var require_vue_eslint_parser_private = __commonJS({
  "node_modules/vue-eslint-parser-private/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function _interopDefault(ex) {
      return ex && typeof ex === "object" && "default" in ex ? ex["default"] : ex;
    }
    var path2 = require("path");
    var path__default = _interopDefault(path2);
    var Evk = _interopDefault(require_lib3());
    var sortedLastIndex = _interopDefault(require_sortedLastIndex());
    var assert = _interopDefault(require("assert"));
    var last2 = _interopDefault(require_last2());
    var findLastIndex = _interopDefault(require_findLastIndex());
    var debugFactory = _interopDefault(require_src());
    var first2 = _interopDefault(require_first2());
    var sortedIndexBy = _interopDefault(require_sortedIndexBy());
    var escope = _interopDefault(require_lib4());
    var Module = _interopDefault(require("module"));
    var semver = require_semver();
    var dependencyEspree = require("espree");
    var sortedLastIndexBy = _interopDefault(require_sortedLastIndexBy());
    var EventEmitter = _interopDefault(require("events"));
    var esquery = _interopDefault(require_esquery_min());
    var union = _interopDefault(require_union());
    var intersection = _interopDefault(require_intersection());
    var memoize = _interopDefault(require_memoize());
    function isAcornStyleParseError(x) {
      return typeof x.message === "string" && typeof x.pos === "number" && typeof x.loc === "object" && x.loc !== null && typeof x.loc.line === "number" && typeof x.loc.column === "number";
    }
    var ParseError = class _ParseError extends SyntaxError {
      constructor(message, code, offset, line, column) {
        super(message);
        this.code = code;
        this.index = offset;
        this.lineNumber = line;
        this.column = column;
      }
      static fromCode(code, offset, line, column) {
        return new _ParseError(code, code, offset, line, column);
      }
      static normalize(x) {
        if (_ParseError.isParseError(x)) {
          return x;
        }
        if (isAcornStyleParseError(x)) {
          return new _ParseError(x.message, void 0, x.pos, x.loc.line, x.loc.column);
        }
        return null;
      }
      static isParseError(x) {
        return x instanceof _ParseError || typeof x.message === "string" && typeof x.index === "number" && typeof x.lineNumber === "number" && typeof x.column === "number";
      }
    };
    var NS = Object.freeze({
      HTML: "http://www.w3.org/1999/xhtml",
      MathML: "http://www.w3.org/1998/Math/MathML",
      SVG: "http://www.w3.org/2000/svg",
      XLink: "http://www.w3.org/1999/xlink",
      XML: "http://www.w3.org/XML/1998/namespace",
      XMLNS: "http://www.w3.org/2000/xmlns/"
    });
    var KEYS = Evk.unionWith({
      VAttribute: ["key", "value"],
      VDirectiveKey: ["name", "argument", "modifiers"],
      VDocumentFragment: ["children"],
      VElement: ["startTag", "children", "endTag"],
      VEndTag: [],
      VExpressionContainer: ["expression"],
      VFilter: ["callee", "arguments"],
      VFilterSequenceExpression: ["expression", "filters"],
      VForExpression: ["left", "right"],
      VIdentifier: [],
      VLiteral: [],
      VOnExpression: ["body"],
      VSlotScopeExpression: ["params"],
      VStartTag: ["attributes"],
      VText: []
    });
    function fallbackKeysFilter(key) {
      let value2 = null;
      return key !== "comments" && key !== "leadingComments" && key !== "loc" && key !== "parent" && key !== "range" && key !== "tokens" && key !== "trailingComments" && (value2 = this[key]) !== null && typeof value2 === "object" && (typeof value2.type === "string" || Array.isArray(value2));
    }
    function getFallbackKeys(node) {
      return Object.keys(node).filter(fallbackKeysFilter, node);
    }
    function isNode(x) {
      return x !== null && typeof x === "object" && typeof x.type === "string";
    }
    function traverse3(node, parent, visitor) {
      let i = 0;
      let j = 0;
      visitor.enterNode(node, parent);
      const keys3 = (visitor.visitorKeys || KEYS)[node.type] || getFallbackKeys(node);
      for (i = 0; i < keys3.length; ++i) {
        const child = node[keys3[i]];
        if (Array.isArray(child)) {
          for (j = 0; j < child.length; ++j) {
            if (isNode(child[j])) {
              traverse3(child[j], node, visitor);
            }
          }
        } else if (isNode(child)) {
          traverse3(child, node, visitor);
        }
      }
      visitor.leaveNode(node, parent);
    }
    function traverseNodes2(node, visitor) {
      traverse3(node, null, visitor);
    }
    var index = /* @__PURE__ */ Object.freeze({
      __proto__: null,
      ParseError,
      NS,
      KEYS,
      traverseNodes: traverseNodes2,
      getFallbackKeys
    });
    var LinesAndColumns = class {
      constructor(ltOffsets) {
        this.ltOffsets = ltOffsets;
      }
      getLocFromIndex(index2) {
        const line = sortedLastIndex(this.ltOffsets, index2) + 1;
        const column = index2 - (line === 1 ? 0 : this.ltOffsets[line - 2]);
        return { line, column };
      }
    };
    var LocationCalculatorForHtml = class _LocationCalculatorForHtml extends LinesAndColumns {
      constructor(gapOffsets, ltOffsets, baseOffset, shiftOffset = 0) {
        super(ltOffsets);
        this.gapOffsets = gapOffsets;
        this.ltOffsets = ltOffsets;
        this.baseOffset = baseOffset || 0;
        this.baseIndexOfGap = this.baseOffset === 0 ? 0 : sortedLastIndex(gapOffsets, this.baseOffset);
        this.shiftOffset = shiftOffset;
      }
      getSubCalculatorAfter(offset) {
        return new _LocationCalculatorForHtml(this.gapOffsets, this.ltOffsets, this.baseOffset + offset, this.shiftOffset);
      }
      getSubCalculatorShift(offset) {
        return new _LocationCalculatorForHtml(this.gapOffsets, this.ltOffsets, this.baseOffset, this.shiftOffset + offset);
      }
      _getGap(index2) {
        const offsets = this.gapOffsets;
        let g0 = sortedLastIndex(offsets, index2 + this.baseOffset);
        let pos = index2 + this.baseOffset + g0 - this.baseIndexOfGap;
        while (g0 < offsets.length && offsets[g0] <= pos) {
          g0 += 1;
          pos += 1;
        }
        return g0 - this.baseIndexOfGap;
      }
      getLocation(index2) {
        return this.getLocFromIndex(this.getOffsetWithGap(index2));
      }
      getOffsetWithGap(index2) {
        return index2 + this.getFixOffset(index2);
      }
      getFixOffset(offset) {
        const shiftOffset = this.shiftOffset;
        const gap = this._getGap(offset + shiftOffset);
        return this.baseOffset + gap + shiftOffset;
      }
    };
    var debug = debugFactory("vue-eslint-parser");
    function isScriptElement(node) {
      return node.type === "VElement" && node.name === "script";
    }
    function isScriptSetupElement(script) {
      return isScriptElement(script) && script.startTag.attributes.some((attr) => !attr.directive && attr.key.name === "setup");
    }
    function isTemplateElement2(node) {
      return node.type === "VElement" && node.name === "template";
    }
    function isStyleElement(node) {
      return node.type === "VElement" && node.name === "style";
    }
    function getOwnerDocument(leafNode) {
      let node = leafNode;
      while (node != null && node.type !== "VDocumentFragment") {
        node = node.parent;
      }
      return node;
    }
    function isLang(attribute) {
      return attribute.directive === false && attribute.key.name === "lang";
    }
    function getLang(element) {
      const langAttr = element && element.startTag.attributes.find(isLang);
      const lang = langAttr && langAttr.value && langAttr.value.value;
      return lang || null;
    }
    function isSFCFile(parserOptions) {
      if (parserOptions.filePath === "<input>") {
        return true;
      }
      return path2.extname(parserOptions.filePath || "unknown.vue") === ".vue";
    }
    function getScriptParser(parser, doc, block) {
      if (parser && typeof parser === "object") {
        if (block === "template") {
          const parserForTemplate = parser["<template>"];
          if (typeof parserForTemplate === "string") {
            return parserForTemplate;
          }
        }
        const lang = getScriptLang();
        if (lang) {
          const parserForLang = parser[lang];
          if (typeof parserForLang === "string") {
            return parserForLang;
          }
        }
        return parser.js;
      }
      return typeof parser === "string" ? parser : void 0;
      function getScriptLang() {
        if (doc) {
          const scripts = doc.children.filter(isScriptElement);
          const script = scripts.length === 2 ? scripts.find(isScriptSetupElement) : scripts[0];
          if (script) {
            return getLang(script);
          }
        }
        return null;
      }
    }
    var createRequire = Module.createRequire || Module.createRequireFromPath || ((modname) => {
      const mod = new Module(modname);
      mod.filename = modname;
      mod.paths = Module._nodeModulePaths(path__default.dirname(modname));
      mod._compile("module.exports = require;", modname);
      return mod.exports;
    });
    function isLinterPath(p) {
      return p.includes(`eslint${path__default.sep}lib${path__default.sep}linter${path__default.sep}linter.js`) || p.includes(`eslint${path__default.sep}lib${path__default.sep}linter.js`);
    }
    function getLinterRequire() {
      const linterPath = Object.keys(require.cache).find(isLinterPath);
      if (linterPath) {
        try {
          return createRequire(linterPath);
        } catch (_a) {
        }
      }
      return null;
    }
    var escopeCache = null;
    function getEslintScope() {
      var _a;
      if (!escopeCache) {
        escopeCache = (_a = getLinterRequire()) === null || _a === void 0 ? void 0 : _a("eslint-scope");
        if (!escopeCache || escopeCache.version == null || semver.lte(escopeCache.version, escope.version)) {
          escopeCache = escope;
        }
      }
      return escopeCache;
    }
    var espreeCache = null;
    function getEspreeFromEcmaVersion(ecmaVersion) {
      const linterEspree = getEspreeFromLinter();
      if (ecmaVersion == null) {
        return linterEspree;
      }
      if (ecmaVersion === "latest") {
        return getNewestEspree();
      }
      if (normalizeEcmaVersion(ecmaVersion) <= getLatestEcmaVersion(linterEspree)) {
        return linterEspree;
      }
      const userEspree = getEspreeFromUser();
      if (normalizeEcmaVersion(ecmaVersion) <= getLatestEcmaVersion(userEspree)) {
        return userEspree;
      }
      return linterEspree;
    }
    function getEspreeFromUser() {
      try {
        const cwd = process.cwd();
        const relativeTo = path__default.join(cwd, "__placeholder__.js");
        return createRequire(relativeTo)("espree");
      } catch (_a) {
        return getEspreeFromLinter();
      }
    }
    function getEspreeFromLinter() {
      var _a;
      if (!espreeCache) {
        espreeCache = (_a = getLinterRequire()) === null || _a === void 0 ? void 0 : _a("espree");
        if (!espreeCache) {
          espreeCache = dependencyEspree;
        }
      }
      return espreeCache;
    }
    function getNewestEspree() {
      let newest = dependencyEspree;
      const linterEspree = getEspreeFromLinter();
      if (linterEspree.version != null && semver.lte(newest.version, linterEspree.version)) {
        newest = linterEspree;
      }
      const userEspree = getEspreeFromUser();
      if (userEspree.version != null && semver.lte(newest.version, userEspree.version)) {
        newest = userEspree;
      }
      return newest;
    }
    function getEcmaVersionIfUseEspree(parserOptions, getDefault) {
      var _a;
      if (parserOptions.parser != null && parserOptions.parser !== "espree") {
        return void 0;
      }
      if (parserOptions.ecmaVersion === "latest") {
        return normalizeEcmaVersion(getLatestEcmaVersion(getNewestEspree()));
      }
      if (parserOptions.ecmaVersion == null) {
        const defVer = getDefaultEcmaVersion();
        return (_a = getDefault === null || getDefault === void 0 ? void 0 : getDefault(defVer)) !== null && _a !== void 0 ? _a : defVer;
      }
      return normalizeEcmaVersion(parserOptions.ecmaVersion);
    }
    function getDefaultEcmaVersion() {
      if (semver.lt(getEspreeFromLinter().version, "9.0.0")) {
        return 5;
      }
      return normalizeEcmaVersion(getLatestEcmaVersion(getNewestEspree()));
    }
    function normalizeEcmaVersion(version2) {
      if (version2 > 5 && version2 < 2015) {
        return version2 + 2009;
      }
      return version2;
    }
    function getLatestEcmaVersion(espree) {
      if (espree.latestEcmaVersion == null) {
        for (const { v, latest } of [
          { v: "6.1.0", latest: 2020 },
          { v: "4.0.0", latest: 2019 }
        ]) {
          if (semver.lte(v, espree.version)) {
            return latest;
          }
        }
        return 2018;
      }
      return normalizeEcmaVersion(espree.latestEcmaVersion);
    }
    function isUnique(reference, index2, references) {
      return index2 === 0 || reference.identifier !== references[index2 - 1].identifier;
    }
    function hasDefinition(variable) {
      return variable.defs.length >= 1;
    }
    function transformReference(reference) {
      const ret = {
        id: reference.identifier,
        mode: reference.isReadOnly() ? "r" : reference.isWriteOnly() ? "w" : "rw",
        variable: null
      };
      Object.defineProperty(ret, "variable", { enumerable: false });
      return ret;
    }
    function transformVariable(variable) {
      const ret = {
        id: variable.defs[0].name,
        kind: variable.scope.type === "for" ? "v-for" : "scope",
        references: []
      };
      Object.defineProperty(ret, "references", { enumerable: false });
      return ret;
    }
    function getForScope(scope) {
      const child = scope.childScopes[0];
      return child.block === scope.block ? child.childScopes[0] : child;
    }
    function analyze(ast, parserOptions) {
      const ecmaVersion = getEcmaVersionIfUseEspree(parserOptions) || 2022;
      const ecmaFeatures = parserOptions.ecmaFeatures || {};
      const sourceType = parserOptions.sourceType || "script";
      const result = getEslintScope().analyze(ast, {
        ignoreEval: true,
        nodejsScope: false,
        impliedStrict: ecmaFeatures.impliedStrict,
        ecmaVersion,
        sourceType,
        fallback: getFallbackKeys
      });
      return result.globalScope;
    }
    function analyzeExternalReferences(ast, parserOptions) {
      const scope = analyze(ast, parserOptions);
      return scope.through.filter(isUnique).map(transformReference);
    }
    function analyzeVariablesAndExternalReferences(ast, parserOptions) {
      const scope = analyze(ast, parserOptions);
      return {
        variables: getForScope(scope).variables.filter(hasDefinition).map(transformVariable),
        references: scope.through.filter(isUnique).map(transformReference)
      };
    }
    function fixLocations(result, locationCalculator) {
      fixNodeLocations(result.ast, result.visitorKeys, locationCalculator);
      for (const token of result.ast.tokens || []) {
        fixLocation(token, locationCalculator);
      }
      for (const comment of result.ast.comments || []) {
        fixLocation(comment, locationCalculator);
      }
    }
    function fixNodeLocations(rootNode, visitorKeys, locationCalculator) {
      const traversed = /* @__PURE__ */ new Map();
      traverseNodes2(rootNode, {
        visitorKeys,
        enterNode(node, parent) {
          if (!traversed.has(node)) {
            traversed.set(node, node);
            node.parent = parent;
            if (traversed.has(node.range)) {
              if (!traversed.has(node.loc)) {
                node.loc.start = locationCalculator.getLocFromIndex(node.range[0]);
                node.loc.end = locationCalculator.getLocFromIndex(node.range[1]);
                traversed.set(node.loc, node);
              } else if (node.start != null || node.end != null) {
                const traversedNode = traversed.get(node.range);
                if (traversedNode.type === node.type) {
                  node.start = traversedNode.start;
                  node.end = traversedNode.end;
                }
              }
            } else {
              fixLocation(node, locationCalculator);
              traversed.set(node.range, node);
              traversed.set(node.loc, node);
            }
          }
        },
        leaveNode() {
        }
      });
    }
    function fixLocation(node, locationCalculator) {
      const range = node.range;
      const loc = node.loc;
      const d0 = locationCalculator.getFixOffset(range[0], "start");
      const d1 = locationCalculator.getFixOffset(range[1], "end");
      if (d0 !== 0) {
        range[0] += d0;
        if (node.start != null) {
          node.start += d0;
        }
        loc.start = locationCalculator.getLocFromIndex(range[0]);
      }
      if (d1 !== 0) {
        range[1] += d1;
        if (node.end != null) {
          node.end += d0;
        }
        loc.end = locationCalculator.getLocFromIndex(range[1]);
      }
      return node;
    }
    function fixErrorLocation(error, locationCalculator) {
      const diff = locationCalculator.getFixOffset(error.index, "start");
      error.index += diff;
      const loc = locationCalculator.getLocFromIndex(error.index);
      error.lineNumber = loc.line;
      error.column = loc.column;
    }
    var DEFAULT_ECMA_VERSION = 2017;
    function getScriptSetupParserOptions(parserOptions) {
      const espreeEcmaVersion = getEcmaVersionIfUseEspree(parserOptions, getDefaultEcmaVersion$1);
      return Object.assign(Object.assign({}, parserOptions), { ecmaVersion: espreeEcmaVersion });
    }
    function getDefaultEcmaVersion$1(def) {
      if (semver.lte("8.0.0", getEspreeFromUser().version)) {
        return getEspreeFromUser().latestEcmaVersion;
      }
      return Math.max(def, DEFAULT_ECMA_VERSION);
    }
    var ALIAS_ITERATOR = /^([\s\S]*?(?:\s|\)))(\bin\b|\bof\b)([\s\S]*)$/u;
    var PARENS = /^(\s*\()([\s\S]*?)(\)\s*)$/u;
    var DUMMY_PARENT = {};
    var IS_FUNCTION_EXPRESSION = /^\s*([\w$_]+|\([^)]*?\))\s*=>|^function\s*\(/u;
    var IS_SIMPLE_PATH = /^[A-Za-z_$][\w$]*(?:\.[A-Za-z_$][\w$]*|\['[^']*?'\]|\["[^"]*?"\]|\[\d+\]|\[[A-Za-z_$][\w$]*\])*$/u;
    function processVForAliasAndIterator(code) {
      const match = ALIAS_ITERATOR.exec(code);
      if (match != null) {
        const aliases = match[1];
        const parenMatch = PARENS.exec(aliases);
        return {
          aliases,
          hasParens: Boolean(parenMatch),
          aliasesWithBrackets: parenMatch ? `${parenMatch[1].slice(0, -1)}[${parenMatch[2]}]${parenMatch[3].slice(1)}` : `[${aliases.slice(0, -1)}]`,
          delimiter: match[2] || "",
          iterator: match[3]
        };
      }
      return {
        aliases: "",
        hasParens: false,
        aliasesWithBrackets: "",
        delimiter: "",
        iterator: code
      };
    }
    function getCommaTokenBeforeNode(tokens, node) {
      let tokenIndex = sortedIndexBy(tokens, { range: node.range }, (t3) => t3.range[0]);
      while (tokenIndex >= 0) {
        const token = tokens[tokenIndex];
        if (token.type === "Punctuator" && token.value === ",") {
          return token;
        }
        tokenIndex -= 1;
      }
      return null;
    }
    function throwEmptyError(locationCalculator, expected) {
      const loc = locationCalculator.getLocation(0);
      const err = new ParseError(`Expected to be ${expected}, but got empty.`, void 0, 0, loc.line, loc.column);
      fixErrorLocation(err, locationCalculator);
      throw err;
    }
    function throwUnexpectedTokenError(name, token) {
      const err = new ParseError(`Unexpected token '${name}'.`, void 0, token.range[0], token.loc.start.line, token.loc.start.column);
      throw err;
    }
    function throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator) {
      if (ParseError.isParseError(err)) {
        const endOffset = locationCalculator.getOffsetWithGap(code.length);
        if (err.index >= endOffset) {
          err.message = "Unexpected end of expression.";
        }
      }
      throw err;
    }
    function parseScriptFragment(code, locationCalculator, parserOptions) {
      try {
        const result = parseScript(code, parserOptions);
        fixLocations(result, locationCalculator);
        return result;
      } catch (err) {
        const perr = ParseError.normalize(err);
        if (perr) {
          fixErrorLocation(perr, locationCalculator);
          throw perr;
        }
        throw err;
      }
    }
    var validDivisionCharRE = /[\w).+\-_$\]]/u;
    function splitFilters(exp) {
      const result = [];
      let inSingle = false;
      let inDouble = false;
      let inTemplateString = false;
      let inRegex = false;
      let curly = 0;
      let square = 0;
      let paren = 0;
      let lastFilterIndex = 0;
      let c = 0;
      let prev = 0;
      for (let i = 0; i < exp.length; i++) {
        prev = c;
        c = exp.charCodeAt(i);
        if (inSingle) {
          if (c === 39 && prev !== 92) {
            inSingle = false;
          }
        } else if (inDouble) {
          if (c === 34 && prev !== 92) {
            inDouble = false;
          }
        } else if (inTemplateString) {
          if (c === 96 && prev !== 92) {
            inTemplateString = false;
          }
        } else if (inRegex) {
          if (c === 47 && prev !== 92) {
            inRegex = false;
          }
        } else if (c === 124 && exp.charCodeAt(i + 1) !== 124 && exp.charCodeAt(i - 1) !== 124 && !curly && !square && !paren) {
          result.push(exp.slice(lastFilterIndex, i));
          lastFilterIndex = i + 1;
        } else {
          switch (c) {
            case 34:
              inDouble = true;
              break;
            case 39:
              inSingle = true;
              break;
            case 96:
              inTemplateString = true;
              break;
            case 40:
              paren++;
              break;
            case 41:
              paren--;
              break;
            case 91:
              square++;
              break;
            case 93:
              square--;
              break;
            case 123:
              curly++;
              break;
            case 125:
              curly--;
              break;
          }
          if (c === 47) {
            let j = i - 1;
            let p;
            for (; j >= 0; j--) {
              p = exp.charAt(j);
              if (p !== " ") {
                break;
              }
            }
            if (!p || !validDivisionCharRE.test(p)) {
              inRegex = true;
            }
          }
        }
      }
      result.push(exp.slice(lastFilterIndex));
      return result;
    }
    function parseExpressionBody(code, locationCalculator, parserOptions, allowEmpty = false) {
      debug('[script] parse expression: "0(%s)"', code);
      try {
        const ast = parseScriptFragment(`0(${code})`, locationCalculator.getSubCalculatorShift(-2), parserOptions).ast;
        const tokens = ast.tokens || [];
        const comments = ast.comments || [];
        const references = analyzeExternalReferences(ast, parserOptions);
        const statement = ast.body[0];
        const callExpression3 = statement.expression;
        const expression = callExpression3.arguments[0];
        if (!allowEmpty && !expression) {
          return throwEmptyError(locationCalculator, "an expression");
        }
        if (expression && expression.type === "SpreadElement") {
          return throwUnexpectedTokenError("...", expression);
        }
        if (callExpression3.arguments[1]) {
          const node = callExpression3.arguments[1];
          return throwUnexpectedTokenError(",", getCommaTokenBeforeNode(tokens, node) || node);
        }
        tokens.shift();
        tokens.shift();
        tokens.pop();
        return { expression, tokens, comments, references, variables: [] };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function parseFilter(code, locationCalculator, parserOptions) {
      debug('[script] parse filter: "%s"', code);
      try {
        const expression = {
          type: "VFilter",
          parent: null,
          range: [0, 0],
          loc: {},
          callee: null,
          arguments: []
        };
        const tokens = [];
        const comments = [];
        const references = [];
        const paren = code.indexOf("(");
        const calleeCode = paren === -1 ? code : code.slice(0, paren);
        const argsCode = paren === -1 ? null : code.slice(paren);
        if (calleeCode.trim()) {
          const spaces = /^\s*/u.exec(calleeCode)[0];
          const subCalculator = locationCalculator.getSubCalculatorShift(spaces.length);
          const { ast } = parseScriptFragment(`"${calleeCode.trim()}"`, subCalculator, parserOptions);
          const statement = ast.body[0];
          const callee = statement.expression;
          if (callee.type !== "Literal") {
            const { loc, range } = ast.tokens[0];
            return throwUnexpectedTokenError('"', {
              range: [range[1] - 1, range[1]],
              loc: {
                start: {
                  line: loc.end.line,
                  column: loc.end.column - 1
                },
                end: loc.end
              }
            });
          }
          expression.callee = {
            type: "Identifier",
            parent: expression,
            range: [
              callee.range[0],
              subCalculator.getOffsetWithGap(calleeCode.trim().length)
            ],
            loc: {
              start: callee.loc.start,
              end: subCalculator.getLocation(calleeCode.trim().length)
            },
            name: String(callee.value)
          };
          tokens.push({
            type: "Identifier",
            value: calleeCode.trim(),
            range: expression.callee.range,
            loc: expression.callee.loc
          });
        } else {
          return throwEmptyError(locationCalculator, "a filter name");
        }
        if (argsCode != null) {
          const { ast } = parseScriptFragment(`0${argsCode}`, locationCalculator.getSubCalculatorAfter(paren).getSubCalculatorShift(-1), parserOptions);
          const statement = ast.body[0];
          const callExpression3 = statement.expression;
          ast.tokens.shift();
          if (callExpression3.type !== "CallExpression" || callExpression3.callee.type !== "Literal") {
            let nestCount = 1;
            for (const token2 of ast.tokens.slice(1)) {
              if (nestCount === 0) {
                return throwUnexpectedTokenError(token2.value, token2);
              }
              if (token2.type === "Punctuator" && token2.value === "(") {
                nestCount += 1;
              }
              if (token2.type === "Punctuator" && token2.value === ")") {
                nestCount -= 1;
              }
            }
            const token = last2(ast.tokens);
            return throwUnexpectedTokenError(token.value, token);
          }
          for (const argument of callExpression3.arguments) {
            argument.parent = expression;
            expression.arguments.push(argument);
          }
          tokens.push(...ast.tokens);
          comments.push(...ast.comments);
          references.push(...analyzeExternalReferences(ast, parserOptions));
        }
        const firstToken = tokens[0];
        const lastToken = last2(tokens);
        expression.range = [firstToken.range[0], lastToken.range[1]];
        expression.loc = { start: firstToken.loc.start, end: lastToken.loc.end };
        return { expression, tokens, comments, references, variables: [] };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function loadParser(parser) {
      if (parser !== "espree") {
        return require(parser);
      }
      return getEspreeFromUser();
    }
    function parseScript(code, parserOptions) {
      const parser = typeof parserOptions.parser === "string" ? loadParser(parserOptions.parser) : getEspreeFromEcmaVersion(parserOptions.ecmaVersion);
      const result = typeof parser.parseForESLint === "function" ? parser.parseForESLint(code, parserOptions) : parser.parse(code, parserOptions);
      if (result.ast != null) {
        return result;
      }
      return { ast: result };
    }
    function parseScriptElement(node, globalLocationCalculator, originalParserOptions) {
      const parserOptions = isScriptSetupElement(node) ? getScriptSetupParserOptions(originalParserOptions) : Object.assign(Object.assign({}, originalParserOptions), { ecmaVersion: originalParserOptions.ecmaVersion || DEFAULT_ECMA_VERSION });
      const text = node.children[0];
      const { code, offset } = text != null && text.type === "VText" ? { code: text.value, offset: text.range[0] } : { code: "", offset: node.startTag.range[1] };
      const locationCalculator = globalLocationCalculator.getSubCalculatorAfter(offset);
      const result = parseScriptFragment(code, locationCalculator, parserOptions);
      if (result.ast.tokens != null) {
        const startTag = node.startTag;
        const endTag = node.endTag;
        result.ast.tokens.unshift({
          type: "Punctuator",
          range: startTag.range,
          loc: startTag.loc,
          value: "<script>"
        });
        if (endTag != null) {
          result.ast.tokens.push({
            type: "Punctuator",
            range: endTag.range,
            loc: endTag.loc,
            value: "</script>"
          });
        }
      }
      return result;
    }
    function parseExpression(code, locationCalculator, parserOptions, { allowEmpty = false, allowFilters = false } = {}) {
      var _a, _b;
      debug('[script] parse expression: "%s"', code);
      const [mainCode, ...filterCodes] = allowFilters && ((_b = (_a = parserOptions.vueFeatures) === null || _a === void 0 ? void 0 : _a.filter) !== null && _b !== void 0 ? _b : true) ? splitFilters(code) : [code];
      if (filterCodes.length === 0) {
        return parseExpressionBody(code, locationCalculator, parserOptions, allowEmpty);
      }
      const retB = parseExpressionBody(mainCode, locationCalculator, parserOptions);
      if (!retB.expression) {
        return retB;
      }
      const ret = retB;
      ret.expression = {
        type: "VFilterSequenceExpression",
        parent: null,
        expression: retB.expression,
        filters: [],
        range: retB.expression.range.slice(0),
        loc: Object.assign({}, retB.expression.loc)
      };
      ret.expression.expression.parent = ret.expression;
      let prevLoc = mainCode.length;
      for (const filterCode of filterCodes) {
        ret.tokens.push(fixLocation({
          type: "Punctuator",
          value: "|",
          range: [prevLoc, prevLoc + 1],
          loc: {}
        }, locationCalculator));
        const retF = parseFilter(filterCode, locationCalculator.getSubCalculatorShift(prevLoc + 1), parserOptions);
        if (retF) {
          if (retF.expression) {
            ret.expression.filters.push(retF.expression);
            retF.expression.parent = ret.expression;
          }
          ret.tokens.push(...retF.tokens);
          ret.comments.push(...retF.comments);
          ret.references.push(...retF.references);
        }
        prevLoc += 1 + filterCode.length;
      }
      const lastToken = last2(ret.tokens);
      ret.expression.range[1] = lastToken.range[1];
      ret.expression.loc.end = lastToken.loc.end;
      return ret;
    }
    function parseVForExpression(code, locationCalculator, parserOptions) {
      if (code.trim() === "") {
        throwEmptyError(locationCalculator, "'<alias> in <expression>'");
      }
      if (isEcmaVersion5(parserOptions)) {
        return parseVForExpressionForEcmaVersion5(code, locationCalculator, parserOptions);
      }
      const processed = processVForAliasAndIterator(code);
      if (!processed.aliases.trim()) {
        return throwEmptyError(locationCalculator, "an alias");
      }
      try {
        debug('[script] parse v-for expression: "for(%s%s%s);"', processed.aliasesWithBrackets, processed.delimiter, processed.iterator);
        const ast = parseScriptFragment(`for(let ${processed.aliasesWithBrackets}${processed.delimiter}${processed.iterator});`, locationCalculator.getSubCalculatorShift(processed.hasParens ? -8 : -9), parserOptions).ast;
        const tokens = ast.tokens || [];
        const comments = ast.comments || [];
        const scope = analyzeVariablesAndExternalReferences(ast, parserOptions);
        const references = scope.references;
        const variables = scope.variables;
        const statement = ast.body[0];
        const varDecl = statement.left;
        const id = varDecl.declarations[0].id;
        const left = id.elements;
        const right = statement.right;
        if (!processed.hasParens && !left.length) {
          return throwEmptyError(locationCalculator, "an alias");
        }
        tokens.shift();
        tokens.shift();
        tokens.shift();
        tokens.pop();
        tokens.pop();
        const closeOffset = statement.left.range[1] - 1;
        const closeIndex = tokens.findIndex((t3) => t3.range[0] === closeOffset);
        if (processed.hasParens) {
          const open = tokens[0];
          if (open != null) {
            open.value = "(";
          }
          const close = tokens[closeIndex];
          if (close != null) {
            close.value = ")";
          }
        } else {
          tokens.splice(closeIndex, 1);
          tokens.shift();
        }
        const firstToken = tokens[0] || statement.left;
        const lastToken = tokens[tokens.length - 1] || statement.right;
        const expression = {
          type: "VForExpression",
          range: [firstToken.range[0], lastToken.range[1]],
          loc: { start: firstToken.loc.start, end: lastToken.loc.end },
          parent: DUMMY_PARENT,
          left,
          right
        };
        for (const l of left) {
          if (l != null) {
            l.parent = expression;
          }
        }
        right.parent = expression;
        return { expression, tokens, comments, references, variables };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function isEcmaVersion5(parserOptions) {
      const ecmaVersion = getEcmaVersionIfUseEspree(parserOptions);
      return ecmaVersion != null && ecmaVersion <= 5;
    }
    function parseVForExpressionForEcmaVersion5(code, locationCalculator, parserOptions) {
      const processed = processVForAliasAndIterator(code);
      if (!processed.aliases.trim()) {
        return throwEmptyError(locationCalculator, "an alias");
      }
      try {
        const tokens = [];
        const comments = [];
        const parsedAliases = parseVForAliasesForEcmaVersion5(processed.aliasesWithBrackets, locationCalculator.getSubCalculatorShift(processed.hasParens ? 0 : -1), parserOptions);
        if (processed.hasParens) {
          const open = parsedAliases.tokens[0];
          if (open != null) {
            open.value = "(";
          }
          const close = last2(parsedAliases.tokens);
          if (close != null) {
            close.value = ")";
          }
        } else {
          parsedAliases.tokens.shift();
          parsedAliases.tokens.pop();
        }
        tokens.push(...parsedAliases.tokens);
        comments.push(...parsedAliases.comments);
        const { left, variables } = parsedAliases;
        if (!processed.hasParens && !left.length) {
          return throwEmptyError(locationCalculator, "an alias");
        }
        const delimiterStart = processed.aliases.length;
        const delimiterEnd = delimiterStart + processed.delimiter.length;
        tokens.push(fixLocation({
          type: processed.delimiter === "in" ? "Keyword" : "Identifier",
          value: processed.delimiter,
          start: delimiterStart,
          end: delimiterEnd,
          loc: {},
          range: [delimiterStart, delimiterEnd]
        }, locationCalculator));
        const parsedIterator = parseVForIteratorForEcmaVersion5(processed.iterator, locationCalculator.getSubCalculatorShift(delimiterEnd), parserOptions);
        tokens.push(...parsedIterator.tokens);
        comments.push(...parsedIterator.comments);
        const { right, references } = parsedIterator;
        const firstToken = tokens[0];
        const lastToken = last2(tokens) || firstToken;
        const expression = {
          type: "VForExpression",
          range: [firstToken.range[0], lastToken.range[1]],
          loc: { start: firstToken.loc.start, end: lastToken.loc.end },
          parent: DUMMY_PARENT,
          left,
          right
        };
        for (const l of left) {
          if (l != null) {
            l.parent = expression;
          }
        }
        right.parent = expression;
        return { expression, tokens, comments, references, variables };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function parseVForAliasesForEcmaVersion5(code, locationCalculator, parserOptions) {
      const ast = parseScriptFragment(`0(${code})`, locationCalculator.getSubCalculatorShift(-2), parserOptions).ast;
      const tokens = ast.tokens || [];
      const comments = ast.comments || [];
      const variables = analyzeExternalReferences(ast, parserOptions).map(transformVariable2);
      const statement = ast.body[0];
      const callExpression3 = statement.expression;
      const expression = callExpression3.arguments[0];
      const left = expression.elements.filter((e) => {
        if (e == null || e.type === "Identifier") {
          return true;
        }
        const errorToken = tokens.find((t3) => e.range[0] <= t3.range[0] && t3.range[1] <= e.range[1]);
        return throwUnexpectedTokenError(errorToken.value, errorToken);
      });
      tokens.shift();
      tokens.shift();
      tokens.pop();
      return { left, tokens, comments, variables };
      function transformVariable2(reference) {
        const ret = {
          id: reference.id,
          kind: "v-for",
          references: []
        };
        Object.defineProperty(ret, "references", { enumerable: false });
        return ret;
      }
    }
    function parseVForIteratorForEcmaVersion5(code, locationCalculator, parserOptions) {
      const ast = parseScriptFragment(`0(${code})`, locationCalculator.getSubCalculatorShift(-2), parserOptions).ast;
      const tokens = ast.tokens || [];
      const comments = ast.comments || [];
      const references = analyzeExternalReferences(ast, parserOptions);
      const statement = ast.body[0];
      const callExpression3 = statement.expression;
      const expression = callExpression3.arguments[0];
      if (!expression) {
        return throwEmptyError(locationCalculator, "an expression");
      }
      if (expression && expression.type === "SpreadElement") {
        return throwUnexpectedTokenError("...", expression);
      }
      const right = expression;
      tokens.shift();
      tokens.shift();
      tokens.pop();
      return { right, tokens, comments, references };
    }
    function parseVOnExpression(code, locationCalculator, parserOptions) {
      if (IS_FUNCTION_EXPRESSION.test(code) || IS_SIMPLE_PATH.test(code)) {
        return parseExpressionBody(code, locationCalculator, parserOptions);
      }
      return parseVOnExpressionBody(code, locationCalculator, parserOptions);
    }
    function parseVOnExpressionBody(code, locationCalculator, parserOptions) {
      debug('[script] parse v-on expression: "void function($event){%s}"', code);
      if (code.trim() === "") {
        throwEmptyError(locationCalculator, "statements");
      }
      try {
        const ast = parseScriptFragment(`void function($event){${code}}`, locationCalculator.getSubCalculatorShift(-22), parserOptions).ast;
        const references = analyzeExternalReferences(ast, parserOptions);
        const outermostStatement = ast.body[0];
        const functionDecl = outermostStatement.expression.argument;
        const block = functionDecl.body;
        const body = block.body;
        const firstStatement = first2(body);
        const lastStatement = last2(body);
        const expression = {
          type: "VOnExpression",
          range: [
            firstStatement != null ? firstStatement.range[0] : block.range[0] + 1,
            lastStatement != null ? lastStatement.range[1] : block.range[1] - 1
          ],
          loc: {
            start: firstStatement != null ? firstStatement.loc.start : locationCalculator.getLocation(1),
            end: lastStatement != null ? lastStatement.loc.end : locationCalculator.getLocation(code.length + 1)
          },
          parent: DUMMY_PARENT,
          body
        };
        const tokens = ast.tokens || [];
        const comments = ast.comments || [];
        for (const b of body) {
          b.parent = expression;
        }
        tokens.splice(0, 6);
        tokens.pop();
        return { expression, tokens, comments, references, variables: [] };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function parseSlotScopeExpression(code, locationCalculator, parserOptions) {
      debug('[script] parse slot-scope expression: "void function(%s) {}"', code);
      if (code.trim() === "") {
        throwEmptyError(locationCalculator, "an identifier or an array/object pattern");
      }
      try {
        const ast = parseScriptFragment(`void function(${code}) {}`, locationCalculator.getSubCalculatorShift(-14), parserOptions).ast;
        const statement = ast.body[0];
        const rawExpression = statement.expression;
        const functionDecl = rawExpression.argument;
        const params = functionDecl.params;
        if (params.length === 0) {
          return {
            expression: null,
            tokens: [],
            comments: [],
            references: [],
            variables: []
          };
        }
        const tokens = ast.tokens || [];
        const comments = ast.comments || [];
        const scope = analyzeVariablesAndExternalReferences(ast, parserOptions);
        const references = scope.references;
        const variables = scope.variables;
        const firstParam = first2(params);
        const lastParam = last2(params);
        const expression = {
          type: "VSlotScopeExpression",
          range: [firstParam.range[0], lastParam.range[1]],
          loc: { start: firstParam.loc.start, end: lastParam.loc.end },
          parent: DUMMY_PARENT,
          params: functionDecl.params
        };
        for (const param of params) {
          param.parent = expression;
        }
        tokens.shift();
        tokens.shift();
        tokens.shift();
        tokens.pop();
        tokens.pop();
        tokens.pop();
        return { expression, tokens, comments, references, variables };
      } catch (err) {
        return throwErrorAsAdjustingOutsideOfCode(err, code, locationCalculator);
      }
    }
    function replaceTokens(document2, node, newTokens) {
      if (document2 == null) {
        return;
      }
      const index2 = sortedIndexBy(document2.tokens, node, byRange0);
      const count = sortedLastIndexBy(document2.tokens, node, byRange1) - index2;
      document2.tokens.splice(index2, count, ...newTokens);
    }
    function replaceAndSplitTokens(document2, node, newTokens) {
      if (document2 == null) {
        return;
      }
      const index2 = sortedIndexBy(document2.tokens, node, byRange0);
      if (document2.tokens.length === index2 || node.range[0] < document2.tokens[index2].range[0]) {
        const beforeToken = document2.tokens[index2 - 1];
        const value2 = beforeToken.value;
        const splitOffset = node.range[0] - beforeToken.range[0];
        const afterToken = {
          type: beforeToken.type,
          range: [node.range[0], beforeToken.range[1]],
          loc: {
            start: Object.assign({}, node.loc.start),
            end: Object.assign({}, beforeToken.loc.end)
          },
          value: value2.slice(splitOffset)
        };
        beforeToken.range[1] = node.range[0];
        beforeToken.loc.end = Object.assign({}, node.loc.start);
        beforeToken.value = value2.slice(0, splitOffset);
        document2.tokens.splice(index2, 0, afterToken);
      }
      let lastIndex = sortedLastIndexBy(document2.tokens, node, byRange1);
      if (lastIndex === 0 || node.range[1] < document2.tokens[lastIndex].range[1]) {
        const beforeToken = document2.tokens[lastIndex];
        const value2 = beforeToken.value;
        const splitOffset = beforeToken.range[1] - beforeToken.range[0] - (beforeToken.range[1] - node.range[1]);
        const afterToken = {
          type: beforeToken.type,
          range: [node.range[1], beforeToken.range[1]],
          loc: {
            start: Object.assign({}, node.loc.end),
            end: Object.assign({}, beforeToken.loc.end)
          },
          value: value2.slice(splitOffset)
        };
        beforeToken.range[1] = node.range[1];
        beforeToken.loc.end = Object.assign({}, node.loc.end);
        beforeToken.value = value2.slice(0, splitOffset);
        document2.tokens.splice(lastIndex + 1, 0, afterToken);
        lastIndex++;
      }
      const count = lastIndex - index2;
      document2.tokens.splice(index2, count, ...newTokens);
    }
    function insertComments(document2, newComments) {
      if (document2 == null || newComments.length === 0) {
        return;
      }
      const index2 = sortedIndexBy(document2.comments, newComments[0], byRange0);
      document2.comments.splice(index2, 0, ...newComments);
    }
    function createSimpleToken(type, start, end, value2, linesAndColumns) {
      return {
        type,
        range: [start, end],
        loc: {
          start: linesAndColumns.getLocFromIndex(start),
          end: linesAndColumns.getLocFromIndex(end)
        },
        value: value2
      };
    }
    function byRange0(x) {
      return x.range[0];
    }
    function byRange1(x) {
      return x.range[1];
    }
    function insertError(document2, error) {
      if (document2 == null) {
        return;
      }
      const index2 = sortedIndexBy(document2.errors, error, byIndex);
      document2.errors.splice(index2, 0, error);
    }
    function byIndex(x) {
      return x.index;
    }
    var shorthandSign = /^[.:@#]/u;
    var shorthandNameMap = { ":": "bind", ".": "bind", "@": "on", "#": "slot" };
    var invalidDynamicArgumentNextChar = /^[\s\r\n=/>]$/u;
    function getTagName(startTagOrElement, isSFC) {
      return isSFC ? startTagOrElement.rawName : startTagOrElement.name;
    }
    function parseDirectiveKeyStatically(node, document2) {
      const { name: text, rawName: rawText, range: [offset], loc: { start: { column, line } } } = node;
      const directiveKey = {
        type: "VDirectiveKey",
        range: node.range,
        loc: node.loc,
        parent: node.parent,
        name: null,
        argument: null,
        modifiers: []
      };
      let i = 0;
      function createIdentifier(start, end, name) {
        return {
          type: "VIdentifier",
          parent: directiveKey,
          range: [offset + start, offset + end],
          loc: {
            start: { column: column + start, line },
            end: { column: column + end, line }
          },
          name: name || text.slice(start, end),
          rawName: rawText.slice(start, end)
        };
      }
      if (shorthandSign.test(text)) {
        const sign = text[0];
        directiveKey.name = createIdentifier(0, 1, shorthandNameMap[sign]);
        i = 1;
      } else {
        const colon = text.indexOf(":");
        if (colon !== -1) {
          directiveKey.name = createIdentifier(0, colon);
          i = colon + 1;
        }
      }
      if (directiveKey.name != null && text[i] === "[") {
        const len = text.slice(i).lastIndexOf("]");
        if (len !== -1) {
          directiveKey.argument = createIdentifier(i, i + len + 1);
          i = i + len + 1 + (text[i + len + 1] === "." ? 1 : 0);
        }
      }
      const modifiers = text.slice(i).split(".").map((modifierName) => {
        const modifier = createIdentifier(i, i + modifierName.length);
        if (modifierName === "" && i < text.length) {
          insertError(document2, new ParseError(`Unexpected token '${text[i]}'`, void 0, offset + i, line, column + i));
        }
        i += modifierName.length + 1;
        return modifier;
      });
      if (directiveKey.name == null) {
        directiveKey.name = modifiers.shift();
      } else if (directiveKey.argument == null && modifiers[0].name !== "") {
        directiveKey.argument = modifiers.shift() || null;
      }
      directiveKey.modifiers = modifiers.filter(isNotEmptyModifier);
      if (directiveKey.name.name === "v-") {
        insertError(document2, new ParseError(`Unexpected token '${text[directiveKey.name.range[1] - offset]}'`, void 0, directiveKey.name.range[1], directiveKey.name.loc.end.line, directiveKey.name.loc.end.column));
      }
      if (directiveKey.name.rawName === "." && !directiveKey.modifiers.some(isPropModifier)) {
        const pos = (directiveKey.argument || directiveKey.name).range[1] - offset;
        const propModifier = createIdentifier(pos, pos, "prop");
        directiveKey.modifiers.unshift(propModifier);
      }
      return directiveKey;
    }
    function isPropModifier(node) {
      return node.name === "prop";
    }
    function isNotEmptyModifier(node) {
      return node.name !== "";
    }
    function parseDirectiveKeyTokens(node) {
      const { name, argument, modifiers } = node;
      const shorthand = name.range[1] - name.range[0] === 1;
      const tokens = [];
      if (shorthand) {
        tokens.push({
          type: "Punctuator",
          range: name.range,
          loc: name.loc,
          value: name.rawName
        });
      } else {
        tokens.push({
          type: "HTMLIdentifier",
          range: name.range,
          loc: name.loc,
          value: name.rawName
        });
        if (argument) {
          tokens.push({
            type: "Punctuator",
            range: [name.range[1], argument.range[0]],
            loc: { start: name.loc.end, end: argument.loc.start },
            value: ":"
          });
        }
      }
      if (argument) {
        tokens.push({
          type: "HTMLIdentifier",
          range: argument.range,
          loc: argument.loc,
          value: argument.rawName
        });
      }
      let lastNode = argument || name;
      for (const modifier of modifiers) {
        if (modifier.rawName === "") {
          continue;
        }
        tokens.push({
          type: "Punctuator",
          range: [lastNode.range[1], modifier.range[0]],
          loc: { start: lastNode.loc.end, end: modifier.loc.start },
          value: "."
        }, {
          type: "HTMLIdentifier",
          range: modifier.range,
          loc: modifier.loc,
          value: modifier.rawName
        });
        lastNode = modifier;
      }
      return tokens;
    }
    function convertDynamicArgument(node, document2, parserOptions, locationCalculator) {
      const { argument } = node;
      if (!(argument != null && argument.type === "VIdentifier" && argument.name.startsWith("[") && argument.name.endsWith("]"))) {
        return;
      }
      const { rawName, range, loc } = argument;
      try {
        const { comments, expression, references, tokens } = parseExpression(rawName.slice(1, -1), locationCalculator.getSubCalculatorAfter(range[0] + 1), parserOptions);
        node.argument = {
          type: "VExpressionContainer",
          range,
          loc,
          parent: node,
          expression,
          references
        };
        if (expression != null) {
          expression.parent = node.argument;
        }
        tokens.unshift(createSimpleToken("Punctuator", range[0], range[0] + 1, "[", locationCalculator));
        tokens.push(createSimpleToken("Punctuator", range[1] - 1, range[1], "]", locationCalculator));
        replaceTokens(document2, node.argument, tokens);
        insertComments(document2, comments);
      } catch (error) {
        debug("[template] Parse error: %s", error);
        if (ParseError.isParseError(error)) {
          node.argument = {
            type: "VExpressionContainer",
            range,
            loc,
            parent: node,
            expression: null,
            references: []
          };
          insertError(document2, error);
        } else {
          throw error;
        }
      }
    }
    function createDirectiveKey(node, document2, parserOptions, locationCalculator) {
      const directiveKey = parseDirectiveKeyStatically(node, document2);
      const tokens = parseDirectiveKeyTokens(directiveKey);
      replaceTokens(document2, directiveKey, tokens);
      if (directiveKey.name.name.startsWith("v-")) {
        directiveKey.name.name = directiveKey.name.name.slice(2);
      }
      if (directiveKey.name.rawName.startsWith("v-")) {
        directiveKey.name.rawName = directiveKey.name.rawName.slice(2);
      }
      convertDynamicArgument(directiveKey, document2, parserOptions, locationCalculator);
      return directiveKey;
    }
    function parseAttributeValue(code, parserOptions, globalLocationCalculator, node, tagName, directiveKey) {
      const firstChar = code[node.range[0]];
      const quoted = firstChar === '"' || firstChar === "'";
      const locationCalculator = globalLocationCalculator.getSubCalculatorAfter(node.range[0] + (quoted ? 1 : 0));
      const directiveName = directiveKey.name.name;
      let result;
      if (quoted && node.value === "") {
        result = {
          expression: null,
          tokens: [],
          comments: [],
          variables: [],
          references: []
        };
      } else if (directiveName === "for") {
        result = parseVForExpression(node.value, locationCalculator, parserOptions);
      } else if (directiveName === "on" && directiveKey.argument != null) {
        result = parseVOnExpression(node.value, locationCalculator, parserOptions);
      } else if (directiveName === "slot" || directiveName === "slot-scope" || tagName === "template" && directiveName === "scope") {
        result = parseSlotScopeExpression(node.value, locationCalculator, parserOptions);
      } else if (directiveName === "bind") {
        result = parseExpression(node.value, locationCalculator, parserOptions, { allowFilters: true });
      } else {
        result = parseExpression(node.value, locationCalculator, parserOptions);
      }
      if (quoted) {
        result.tokens.unshift(createSimpleToken("Punctuator", node.range[0], node.range[0] + 1, firstChar, globalLocationCalculator));
        result.tokens.push(createSimpleToken("Punctuator", node.range[1] - 1, node.range[1], firstChar, globalLocationCalculator));
      }
      return result;
    }
    function resolveReference(referene, element) {
      let node = element;
      while (node != null && node.type === "VElement") {
        for (const variable of node.variables) {
          if (variable.id.name === referene.id.name) {
            referene.variable = variable;
            variable.references.push(referene);
            return;
          }
        }
        node = node.parent;
      }
    }
    function convertToDirective(code, parserOptions, locationCalculator, node) {
      debug('[template] convert to directive: %s="%s" %j', node.key.name, node.value && node.value.value, node.range);
      const document2 = getOwnerDocument(node);
      const directive = node;
      directive.directive = true;
      directive.key = createDirectiveKey(node.key, document2, parserOptions, locationCalculator);
      const { argument } = directive.key;
      if (argument && argument.type === "VIdentifier" && argument.name.startsWith("[")) {
        const nextChar = code[argument.range[1]];
        if (nextChar == null || invalidDynamicArgumentNextChar.test(nextChar)) {
          const char = nextChar == null ? "EOF" : JSON.stringify(nextChar).slice(1, -1);
          insertError(document2, new ParseError(`Dynamic argument cannot contain the '${char}' character.`, void 0, argument.range[1], argument.loc.end.line, argument.loc.end.column));
        }
      }
      if (node.value == null) {
        return;
      }
      try {
        const ret = parseAttributeValue(code, parserOptions, locationCalculator, node.value, getTagName(node.parent.parent, isSFCFile(parserOptions)), directive.key);
        directive.value = {
          type: "VExpressionContainer",
          range: node.value.range,
          loc: node.value.loc,
          parent: directive,
          expression: ret.expression,
          references: ret.references
        };
        if (ret.expression != null) {
          ret.expression.parent = directive.value;
        }
        for (const variable of ret.variables) {
          node.parent.parent.variables.push(variable);
        }
        replaceTokens(document2, node.value, ret.tokens);
        insertComments(document2, ret.comments);
      } catch (err) {
        debug("[template] Parse error: %s", err);
        if (ParseError.isParseError(err)) {
          directive.value = {
            type: "VExpressionContainer",
            range: node.value.range,
            loc: node.value.loc,
            parent: directive,
            expression: null,
            references: []
          };
          insertError(document2, err);
        } else {
          throw err;
        }
      }
    }
    function processMustache(parserOptions, globalLocationCalculator, node, mustache) {
      const range = [
        mustache.startToken.range[1],
        mustache.endToken.range[0]
      ];
      debug("[template] convert mustache {{%s}} %j", mustache.value, range);
      const document2 = getOwnerDocument(node);
      try {
        const locationCalculator = globalLocationCalculator.getSubCalculatorAfter(range[0]);
        const ret = parseExpression(mustache.value, locationCalculator, parserOptions, { allowEmpty: true, allowFilters: true });
        node.expression = ret.expression || null;
        node.references = ret.references;
        if (ret.expression != null) {
          ret.expression.parent = node;
        }
        replaceTokens(document2, { range }, ret.tokens);
        insertComments(document2, ret.comments);
      } catch (err) {
        debug("[template] Parse error: %s", err);
        if (ParseError.isParseError(err)) {
          insertError(document2, err);
        } else {
          throw err;
        }
      }
    }
    function resolveReferences(container) {
      let element = container.parent;
      while (element != null && element.type !== "VElement") {
        element = element.parent;
      }
      if (element != null) {
        for (const reference of container.references) {
          resolveReference(reference, element);
        }
      }
    }
    var SVG_ATTRIBUTE_NAME_MAP = /* @__PURE__ */ new Map([
      ["attributename", "attributeName"],
      ["attributetype", "attributeType"],
      ["basefrequency", "baseFrequency"],
      ["baseprofile", "baseProfile"],
      ["calcmode", "calcMode"],
      ["clippathunits", "clipPathUnits"],
      ["diffuseconstant", "diffuseConstant"],
      ["edgemode", "edgeMode"],
      ["filterunits", "filterUnits"],
      ["glyphref", "glyphRef"],
      ["gradienttransform", "gradientTransform"],
      ["gradientunits", "gradientUnits"],
      ["kernelmatrix", "kernelMatrix"],
      ["kernelunitlength", "kernelUnitLength"],
      ["keypoints", "keyPoints"],
      ["keysplines", "keySplines"],
      ["keytimes", "keyTimes"],
      ["lengthadjust", "lengthAdjust"],
      ["limitingconeangle", "limitingConeAngle"],
      ["markerheight", "markerHeight"],
      ["markerunits", "markerUnits"],
      ["markerwidth", "markerWidth"],
      ["maskcontentunits", "maskContentUnits"],
      ["maskunits", "maskUnits"],
      ["numoctaves", "numOctaves"],
      ["pathlength", "pathLength"],
      ["patterncontentunits", "patternContentUnits"],
      ["patterntransform", "patternTransform"],
      ["patternunits", "patternUnits"],
      ["pointsatx", "pointsAtX"],
      ["pointsaty", "pointsAtY"],
      ["pointsatz", "pointsAtZ"],
      ["preservealpha", "preserveAlpha"],
      ["preserveaspectratio", "preserveAspectRatio"],
      ["primitiveunits", "primitiveUnits"],
      ["refx", "refX"],
      ["refy", "refY"],
      ["repeatcount", "repeatCount"],
      ["repeatdur", "repeatDur"],
      ["requiredextensions", "requiredExtensions"],
      ["requiredfeatures", "requiredFeatures"],
      ["specularconstant", "specularConstant"],
      ["specularexponent", "specularExponent"],
      ["spreadmethod", "spreadMethod"],
      ["startoffset", "startOffset"],
      ["stddeviation", "stdDeviation"],
      ["stitchtiles", "stitchTiles"],
      ["surfacescale", "surfaceScale"],
      ["systemlanguage", "systemLanguage"],
      ["tablevalues", "tableValues"],
      ["targetx", "targetX"],
      ["targety", "targetY"],
      ["textlength", "textLength"],
      ["viewbox", "viewBox"],
      ["viewtarget", "viewTarget"],
      ["xchannelselector", "xChannelSelector"],
      ["ychannelselector", "yChannelSelector"],
      ["zoomandpan", "zoomAndPan"]
    ]);
    var MATHML_ATTRIBUTE_NAME_MAP = /* @__PURE__ */ new Map([
      ["definitionurl", "definitionUrl"]
    ]);
    var HTML_VOID_ELEMENT_TAGS = /* @__PURE__ */ new Set([
      "area",
      "base",
      "br",
      "col",
      "embed",
      "hr",
      "img",
      "input",
      "link",
      "meta",
      "param",
      "source",
      "track",
      "wbr"
    ]);
    var HTML_CAN_BE_LEFT_OPEN_TAGS = /* @__PURE__ */ new Set([
      "colgroup",
      "li",
      "options",
      "p",
      "td",
      "tfoot",
      "th",
      "thead",
      "tr",
      "source"
    ]);
    var HTML_NON_FHRASING_TAGS = /* @__PURE__ */ new Set([
      "address",
      "article",
      "aside",
      "base",
      "blockquote",
      "body",
      "caption",
      "col",
      "colgroup",
      "dd",
      "details",
      "dialog",
      "div",
      "dl",
      "dt",
      "fieldset",
      "figcaption",
      "figure",
      "footer",
      "form",
      "h1",
      "h2",
      "h3",
      "h4",
      "h5",
      "h6",
      "head",
      "header",
      "hgroup",
      "hr",
      "html",
      "legend",
      "li",
      "menuitem",
      "meta",
      "optgroup",
      "option",
      "param",
      "rp",
      "rt",
      "source",
      "style",
      "summary",
      "tbody",
      "td",
      "tfoot",
      "th",
      "thead",
      "title",
      "tr",
      "track"
    ]);
    var HTML_RCDATA_TAGS = /* @__PURE__ */ new Set([
      "title",
      "textarea"
    ]);
    var HTML_RAWTEXT_TAGS = /* @__PURE__ */ new Set([
      "style",
      "xmp",
      "iframe",
      "noembed",
      "noframes",
      "noscript",
      "script"
    ]);
    var SVG_TAGS = /* @__PURE__ */ new Set([
      "a",
      "altGlyph",
      "altGlyphDef",
      "altGlyphItem",
      "animate",
      "animateColor",
      "animateMotion",
      "animateTransform",
      "animation",
      "audio",
      "canvas",
      "circle",
      "clipPath",
      "color-profile",
      "cursor",
      "defs",
      "desc",
      "discard",
      "ellipse",
      "feBlend",
      "feColorMatrix",
      "feComponentTransfer",
      "feComposite",
      "feConvolveMatrix",
      "feDiffuseLighting",
      "feDisplacementMap",
      "feDistantLight",
      "feDropShadow",
      "feFlood",
      "feFuncA",
      "feFuncB",
      "feFuncG",
      "feFuncR",
      "feGaussianBlur",
      "feImage",
      "feMerge",
      "feMergeNode",
      "feMorphology",
      "feOffset",
      "fePointLight",
      "feSpecularLighting",
      "feSpotLight",
      "feTile",
      "feTurbulence",
      "filter",
      "font",
      "font-face",
      "font-face-format",
      "font-face-name",
      "font-face-src",
      "font-face-uri",
      "foreignObject",
      "g",
      "glyph",
      "glyphRef",
      "handler",
      "hatch",
      "hatchpath",
      "hkern",
      "iframe",
      "image",
      "line",
      "linearGradient",
      "listener",
      "marker",
      "mask",
      "mesh",
      "meshgradient",
      "meshpatch",
      "meshrow",
      "metadata",
      "missing-glyph",
      "mpath",
      "path",
      "pattern",
      "polygon",
      "polyline",
      "prefetch",
      "radialGradient",
      "rect",
      "script",
      "set",
      "solidColor",
      "solidcolor",
      "stop",
      "style",
      "svg",
      "switch",
      "symbol",
      "tbreak",
      "text",
      "textArea",
      "textPath",
      "title",
      "tref",
      "tspan",
      "unknown",
      "use",
      "video",
      "view",
      "vkern"
    ]);
    var SVG_ELEMENT_NAME_MAP = /* @__PURE__ */ new Map();
    for (const name of SVG_TAGS) {
      if (/[A-Z]/.test(name)) {
        SVG_ELEMENT_NAME_MAP.set(name.toLowerCase(), name);
      }
    }
    var DUMMY_PARENT$1 = Object.freeze({});
    function concat(text, token) {
      return text + token.value;
    }
    var IntermediateTokenizer = class {
      constructor(tokenizer) {
        this.tokenizer = tokenizer;
        this.currentToken = null;
        this.attribute = null;
        this.attributeNames = /* @__PURE__ */ new Set();
        this.expressionStartToken = null;
        this.expressionTokens = [];
        this.tokens = [];
        this.comments = [];
      }
      get text() {
        return this.tokenizer.text;
      }
      get errors() {
        return this.tokenizer.errors;
      }
      get state() {
        return this.tokenizer.state;
      }
      set state(value2) {
        this.tokenizer.state = value2;
      }
      get namespace() {
        return this.tokenizer.namespace;
      }
      set namespace(value2) {
        this.tokenizer.namespace = value2;
      }
      get expressionEnabled() {
        return this.tokenizer.expressionEnabled;
      }
      set expressionEnabled(value2) {
        this.tokenizer.expressionEnabled = value2;
      }
      nextToken() {
        let token = null;
        let result = null;
        while (result == null && (token = this.tokenizer.nextToken()) != null) {
          result = this[token.type](token);
        }
        if (result == null && token == null && this.currentToken != null) {
          result = this.commit();
        }
        return result;
      }
      commit() {
        assert(this.currentToken != null || this.expressionStartToken != null);
        let token = this.currentToken;
        this.currentToken = null;
        this.attribute = null;
        if (this.expressionStartToken != null) {
          const start = this.expressionStartToken;
          const end = last2(this.expressionTokens) || start;
          const value2 = this.expressionTokens.reduce(concat, start.value);
          this.expressionStartToken = null;
          this.expressionTokens = [];
          if (token == null) {
            token = {
              type: "Text",
              range: [start.range[0], end.range[1]],
              loc: { start: start.loc.start, end: end.loc.end },
              value: value2
            };
          } else if (token.type === "Text") {
            token.range[1] = end.range[1];
            token.loc.end = end.loc.end;
            token.value += value2;
          } else {
            throw new Error("unreachable");
          }
        }
        return token;
      }
      reportParseError(token, code) {
        const error = ParseError.fromCode(code, token.range[0], token.loc.start.line, token.loc.start.column);
        this.errors.push(error);
        debug("[html] syntax error:", error.message);
      }
      processComment(token) {
        this.comments.push(token);
        if (this.currentToken != null && this.currentToken.type === "Text") {
          return this.commit();
        }
        return null;
      }
      processText(token) {
        this.tokens.push(token);
        let result = null;
        if (this.expressionStartToken != null) {
          const lastToken = last2(this.expressionTokens) || this.expressionStartToken;
          if (lastToken.range[1] === token.range[0]) {
            this.expressionTokens.push(token);
            return null;
          }
          result = this.commit();
        } else if (this.currentToken != null) {
          if (this.currentToken.type === "Text" && this.currentToken.range[1] === token.range[0]) {
            this.currentToken.value += token.value;
            this.currentToken.range[1] = token.range[1];
            this.currentToken.loc.end = token.loc.end;
            return null;
          }
          result = this.commit();
        }
        assert(this.currentToken == null);
        this.currentToken = {
          type: "Text",
          range: [token.range[0], token.range[1]],
          loc: { start: token.loc.start, end: token.loc.end },
          value: token.value
        };
        return result;
      }
      HTMLAssociation(token) {
        this.tokens.push(token);
        if (this.attribute != null) {
          this.attribute.range[1] = token.range[1];
          this.attribute.loc.end = token.loc.end;
          if (this.currentToken == null || this.currentToken.type !== "StartTag") {
            throw new Error("unreachable");
          }
          this.currentToken.range[1] = token.range[1];
          this.currentToken.loc.end = token.loc.end;
        }
        return null;
      }
      HTMLBogusComment(token) {
        return this.processComment(token);
      }
      HTMLCDataText(token) {
        return this.processText(token);
      }
      HTMLComment(token) {
        return this.processComment(token);
      }
      HTMLEndTagOpen(token) {
        this.tokens.push(token);
        let result = null;
        if (this.currentToken != null || this.expressionStartToken != null) {
          result = this.commit();
        }
        this.currentToken = {
          type: "EndTag",
          range: [token.range[0], token.range[1]],
          loc: { start: token.loc.start, end: token.loc.end },
          name: token.value
        };
        return result;
      }
      HTMLIdentifier(token) {
        this.tokens.push(token);
        if (this.currentToken == null || this.currentToken.type === "Text" || this.currentToken.type === "Mustache") {
          throw new Error("unreachable");
        }
        if (this.currentToken.type === "EndTag") {
          this.reportParseError(token, "end-tag-with-attributes");
          return null;
        }
        if (this.attributeNames.has(token.value)) {
          this.reportParseError(token, "duplicate-attribute");
        }
        this.attributeNames.add(token.value);
        this.attribute = {
          type: "VAttribute",
          range: [token.range[0], token.range[1]],
          loc: { start: token.loc.start, end: token.loc.end },
          parent: DUMMY_PARENT$1,
          directive: false,
          key: {
            type: "VIdentifier",
            range: [token.range[0], token.range[1]],
            loc: { start: token.loc.start, end: token.loc.end },
            parent: DUMMY_PARENT$1,
            name: token.value,
            rawName: this.text.slice(token.range[0], token.range[1])
          },
          value: null
        };
        this.attribute.key.parent = this.attribute;
        this.currentToken.range[1] = token.range[1];
        this.currentToken.loc.end = token.loc.end;
        this.currentToken.attributes.push(this.attribute);
        return null;
      }
      HTMLLiteral(token) {
        this.tokens.push(token);
        if (this.attribute != null) {
          this.attribute.range[1] = token.range[1];
          this.attribute.loc.end = token.loc.end;
          this.attribute.value = {
            type: "VLiteral",
            range: [token.range[0], token.range[1]],
            loc: { start: token.loc.start, end: token.loc.end },
            parent: this.attribute,
            value: token.value
          };
          if (this.currentToken == null || this.currentToken.type !== "StartTag") {
            throw new Error("unreachable");
          }
          this.currentToken.range[1] = token.range[1];
          this.currentToken.loc.end = token.loc.end;
        }
        return null;
      }
      HTMLRCDataText(token) {
        return this.processText(token);
      }
      HTMLRawText(token) {
        return this.processText(token);
      }
      HTMLSelfClosingTagClose(token) {
        this.tokens.push(token);
        if (this.currentToken == null || this.currentToken.type === "Text") {
          throw new Error("unreachable");
        }
        if (this.currentToken.type === "StartTag") {
          this.currentToken.selfClosing = true;
        } else {
          this.reportParseError(token, "end-tag-with-trailing-solidus");
        }
        this.currentToken.range[1] = token.range[1];
        this.currentToken.loc.end = token.loc.end;
        return this.commit();
      }
      HTMLTagClose(token) {
        this.tokens.push(token);
        if (this.currentToken == null || this.currentToken.type === "Text") {
          throw new Error("unreachable");
        }
        this.currentToken.range[1] = token.range[1];
        this.currentToken.loc.end = token.loc.end;
        return this.commit();
      }
      HTMLTagOpen(token) {
        this.tokens.push(token);
        let result = null;
        if (this.currentToken != null || this.expressionStartToken != null) {
          result = this.commit();
        }
        this.currentToken = {
          type: "StartTag",
          range: [token.range[0], token.range[1]],
          loc: { start: token.loc.start, end: token.loc.end },
          name: token.value,
          rawName: this.text.slice(token.range[0] + 1, token.range[1]),
          selfClosing: false,
          attributes: []
        };
        this.attribute = null;
        this.attributeNames.clear();
        return result;
      }
      HTMLText(token) {
        return this.processText(token);
      }
      HTMLWhitespace(token) {
        return this.processText(token);
      }
      VExpressionStart(token) {
        if (this.expressionStartToken != null) {
          return this.processText(token);
        }
        const separated = this.currentToken != null && this.currentToken.range[1] !== token.range[0];
        const result = separated ? this.commit() : null;
        this.tokens.push(token);
        this.expressionStartToken = token;
        return result;
      }
      VExpressionEnd(token) {
        if (this.expressionStartToken == null) {
          return this.processText(token);
        }
        const start = this.expressionStartToken;
        const end = last2(this.expressionTokens) || start;
        if (token.range[0] === start.range[1]) {
          this.tokens.pop();
          this.expressionStartToken = null;
          const result2 = this.processText(start);
          this.processText(token);
          return result2;
        }
        if (end.range[1] !== token.range[0]) {
          const result2 = this.commit();
          this.processText(token);
          return result2;
        }
        const value2 = this.expressionTokens.reduce(concat, "");
        this.tokens.push(token);
        this.expressionStartToken = null;
        this.expressionTokens = [];
        const result = this.currentToken != null ? this.commit() : null;
        this.currentToken = {
          type: "Mustache",
          range: [start.range[0], token.range[1]],
          loc: { start: start.loc.start, end: token.loc.end },
          value: value2,
          startToken: start,
          endToken: token
        };
        return result || this.commit();
      }
    };
    var DIRECTIVE_NAME = /^(?:v-|[.:@#]).*[^.:@#]$/u;
    var DT_DD = /^d[dt]$/u;
    var DUMMY_PARENT$2 = Object.freeze({});
    function getTagName$1(startTagOrElement, isSFC) {
      return isSFC ? startTagOrElement.rawName : startTagOrElement.name;
    }
    function isMathMLIntegrationPoint(element, isSFC) {
      if (element.namespace === NS.MathML) {
        const name = getTagName$1(element, isSFC);
        return name === "mi" || name === "mo" || name === "mn" || name === "ms" || name === "mtext";
      }
      return false;
    }
    function isHTMLIntegrationPoint(element, isSFC) {
      if (element.namespace === NS.MathML) {
        return getTagName$1(element, isSFC) === "annotation-xml" && element.startTag.attributes.some((a) => a.directive === false && a.key.name === "encoding" && a.value != null && (a.value.value === "text/html" || a.value.value === "application/xhtml+xml"));
      }
      if (element.namespace === NS.SVG) {
        const name = getTagName$1(element, isSFC);
        return name === "foreignObject" || name === "desc" || name === "title";
      }
      return false;
    }
    function adjustElementName(name, namespace) {
      if (namespace === NS.SVG) {
        return SVG_ELEMENT_NAME_MAP.get(name) || name;
      }
      return name;
    }
    function adjustAttributeName(name, namespace) {
      if (namespace === NS.SVG) {
        return SVG_ATTRIBUTE_NAME_MAP.get(name) || name;
      }
      if (namespace === NS.MathML) {
        return MATHML_ATTRIBUTE_NAME_MAP.get(name) || name;
      }
      return name;
    }
    function propagateEndLocation(node) {
      const lastChild = (node.type === "VElement" ? node.endTag : null) || last2(node.children);
      if (lastChild != null) {
        node.range[1] = lastChild.range[1];
        node.loc.end = lastChild.loc.end;
      }
    }
    var Parser2 = class {
      constructor(tokenizer, parserOptions) {
        this.postProcessesForScript = [];
        this.tokenizer = new IntermediateTokenizer(tokenizer);
        this.locationCalculator = new LocationCalculatorForHtml(tokenizer.gaps, tokenizer.lineTerminators);
        this.baseParserOptions = parserOptions;
        this.isSFC = isSFCFile(parserOptions);
        this.document = {
          type: "VDocumentFragment",
          range: [0, 0],
          loc: {
            start: { line: 1, column: 0 },
            end: { line: 1, column: 0 }
          },
          parent: null,
          children: [],
          tokens: this.tokens,
          comments: this.comments,
          errors: this.errors
        };
        this.elementStack = [];
        this.vPreElement = null;
        this.postProcessesForScript = [];
      }
      get text() {
        return this.tokenizer.text;
      }
      get tokens() {
        return this.tokenizer.tokens;
      }
      get comments() {
        return this.tokenizer.comments;
      }
      get errors() {
        return this.tokenizer.errors;
      }
      get namespace() {
        return this.tokenizer.namespace;
      }
      set namespace(value2) {
        this.tokenizer.namespace = value2;
      }
      get expressionEnabled() {
        return this.tokenizer.expressionEnabled;
      }
      set expressionEnabled(value2) {
        this.tokenizer.expressionEnabled = value2;
      }
      get currentNode() {
        return last2(this.elementStack) || this.document;
      }
      get isInVPreElement() {
        return this.vPreElement != null;
      }
      parse() {
        let token = null;
        while ((token = this.tokenizer.nextToken()) != null) {
          this[token.type](token);
        }
        this.popElementStackUntil(0);
        propagateEndLocation(this.document);
        const parserOptions = Object.assign(Object.assign({}, this.baseParserOptions), { parser: getScriptParser(this.baseParserOptions.parser, this.document, "template") });
        for (const proc of this.postProcessesForScript) {
          proc(parserOptions);
        }
        this.postProcessesForScript = [];
        return this.document;
      }
      reportParseError(token, code) {
        const error = ParseError.fromCode(code, token.range[0], token.loc.start.line, token.loc.start.column);
        this.errors.push(error);
        debug("[html] syntax error:", error.message);
      }
      popElementStack() {
        assert(this.elementStack.length >= 1);
        const element = this.elementStack.pop();
        propagateEndLocation(element);
        const current = this.currentNode;
        this.namespace = current.type === "VElement" ? current.namespace : NS.HTML;
        if (this.vPreElement === element) {
          this.vPreElement = null;
          this.expressionEnabled = true;
        }
        if (this.elementStack.length === 0) {
          this.expressionEnabled = false;
        }
      }
      popElementStackUntil(index2) {
        while (this.elementStack.length > index2) {
          this.popElementStack();
        }
      }
      getTagName(startTagOrElement) {
        return getTagName$1(startTagOrElement, this.isSFC);
      }
      detectNamespace(token) {
        const name = this.getTagName(token);
        let ns = this.namespace;
        if (ns === NS.MathML || ns === NS.SVG) {
          const element = this.currentNode;
          if (element.type === "VElement") {
            if (element.namespace === NS.MathML && this.getTagName(element) === "annotation-xml" && name === "svg") {
              return NS.SVG;
            }
            if (isHTMLIntegrationPoint(element, this.isSFC) || isMathMLIntegrationPoint(element, this.isSFC) && name !== "mglyph" && name !== "malignmark") {
              ns = NS.HTML;
            }
          }
        }
        if (ns === NS.HTML) {
          if (name === "svg") {
            return NS.SVG;
          }
          if (name === "math") {
            return NS.MathML;
          }
        }
        if (name === "template") {
          const xmlns = token.attributes.find((a) => a.key.name === "xmlns");
          const value2 = xmlns && xmlns.value && xmlns.value.value;
          if (value2 === NS.HTML || value2 === NS.MathML || value2 === NS.SVG) {
            return value2;
          }
        }
        return ns;
      }
      closeCurrentElementIfNecessary(token) {
        const element = this.currentNode;
        if (element.type !== "VElement") {
          return;
        }
        const name = this.getTagName(token);
        const elementName = this.getTagName(element);
        if (elementName === "p" && HTML_NON_FHRASING_TAGS.has(name)) {
          this.popElementStack();
        }
        if (elementName === name && HTML_CAN_BE_LEFT_OPEN_TAGS.has(name)) {
          this.popElementStack();
        }
        if (DT_DD.test(elementName) && DT_DD.test(name)) {
          this.popElementStack();
        }
      }
      processAttribute(node, namespace) {
        const tagName = this.getTagName(node.parent.parent);
        const attrName = this.getTagName(node.key);
        if ((this.expressionEnabled || attrName === "v-pre" && !this.isInVPreElement) && (DIRECTIVE_NAME.test(attrName) || attrName === "slot-scope" || tagName === "template" && attrName === "scope")) {
          this.postProcessesForScript.push((parserOptions) => {
            convertToDirective(this.text, parserOptions, this.locationCalculator, node);
          });
          return;
        }
        node.key.name = adjustAttributeName(node.key.name, namespace);
        const key = this.getTagName(node.key);
        const value2 = node.value && node.value.value;
        if (key === "xmlns" && value2 !== namespace) {
          this.reportParseError(node, "x-invalid-namespace");
        } else if (key === "xmlns:xlink" && value2 !== NS.XLink) {
          this.reportParseError(node, "x-invalid-namespace");
        }
      }
      StartTag(token) {
        var _a;
        debug("[html] StartTag %j", token);
        this.closeCurrentElementIfNecessary(token);
        const parent = this.currentNode;
        const namespace = this.detectNamespace(token);
        const element = {
          type: "VElement",
          range: [token.range[0], token.range[1]],
          loc: { start: token.loc.start, end: token.loc.end },
          parent,
          name: adjustElementName(token.name, namespace),
          rawName: token.rawName,
          namespace,
          startTag: {
            type: "VStartTag",
            range: token.range,
            loc: token.loc,
            parent: DUMMY_PARENT$2,
            selfClosing: token.selfClosing,
            attributes: token.attributes
          },
          children: [],
          endTag: null,
          variables: []
        };
        const hasVPre = !this.isInVPreElement && token.attributes.some((a) => this.getTagName(a.key) === "v-pre");
        if (hasVPre) {
          this.expressionEnabled = false;
        }
        parent.children.push(element);
        element.startTag.parent = element;
        for (const attribute of token.attributes) {
          attribute.parent = element.startTag;
          this.processAttribute(attribute, namespace);
        }
        this.postProcessesForScript.push(() => {
          for (const attribute of element.startTag.attributes) {
            if (attribute.directive) {
              if (attribute.key.argument != null && attribute.key.argument.type === "VExpressionContainer") {
                resolveReferences(attribute.key.argument);
              }
              if (attribute.value != null) {
                resolveReferences(attribute.value);
              }
            }
          }
        });
        const isVoid = namespace === NS.HTML && HTML_VOID_ELEMENT_TAGS.has(this.getTagName(element));
        if (token.selfClosing && !isVoid && namespace === NS.HTML) {
          this.reportParseError(token, "non-void-html-element-start-tag-with-trailing-solidus");
        }
        if (token.selfClosing || isVoid) {
          this.expressionEnabled = !this.isInVPreElement;
          return;
        }
        this.elementStack.push(element);
        if (hasVPre) {
          assert(this.vPreElement === null);
          this.vPreElement = element;
        }
        this.namespace = namespace;
        if (namespace === NS.HTML) {
          const elementName = this.getTagName(element);
          if (element.parent.type === "VDocumentFragment") {
            const langAttr = element.startTag.attributes.find((a) => !a.directive && a.key.name === "lang");
            const lang = (_a = langAttr === null || langAttr === void 0 ? void 0 : langAttr.value) === null || _a === void 0 ? void 0 : _a.value;
            if (elementName === "template") {
              if (lang && lang !== "html") {
                this.tokenizer.state = "RAWTEXT";
              }
              this.expressionEnabled = true;
            } else if (this.isSFC) {
              if (!lang || lang !== "html") {
                this.tokenizer.state = "RAWTEXT";
              }
            } else {
              if (HTML_RCDATA_TAGS.has(elementName)) {
                this.tokenizer.state = "RCDATA";
              }
              if (HTML_RAWTEXT_TAGS.has(elementName)) {
                this.tokenizer.state = "RAWTEXT";
              }
            }
          } else {
            if (HTML_RCDATA_TAGS.has(elementName)) {
              this.tokenizer.state = "RCDATA";
            }
            if (HTML_RAWTEXT_TAGS.has(elementName)) {
              this.tokenizer.state = "RAWTEXT";
            }
          }
        }
      }
      EndTag(token) {
        debug("[html] EndTag %j", token);
        const i = findLastIndex(this.elementStack, (el) => el.name.toLowerCase() === token.name);
        if (i === -1) {
          this.reportParseError(token, "x-invalid-end-tag");
          return;
        }
        const element = this.elementStack[i];
        element.endTag = {
          type: "VEndTag",
          range: token.range,
          loc: token.loc,
          parent: element
        };
        this.popElementStackUntil(i);
      }
      Text(token) {
        debug("[html] Text %j", token);
        const parent = this.currentNode;
        parent.children.push({
          type: "VText",
          range: token.range,
          loc: token.loc,
          parent,
          value: token.value
        });
      }
      Mustache(token) {
        debug("[html] Mustache %j", token);
        const parent = this.currentNode;
        const container = {
          type: "VExpressionContainer",
          range: token.range,
          loc: token.loc,
          parent,
          expression: null,
          references: []
        };
        parent.children.push(container);
        this.postProcessesForScript.push((parserOptions) => {
          processMustache(parserOptions, this.locationCalculator, container, token);
          resolveReferences(container);
        });
      }
    };
    var alternativeCR = /* @__PURE__ */ new Map([[128, 8364], [130, 8218], [131, 402], [132, 8222], [133, 8230], [134, 8224], [135, 8225], [136, 710], [137, 8240], [138, 352], [139, 8249], [140, 338], [142, 381], [145, 8216], [146, 8217], [147, 8220], [148, 8221], [149, 8226], [150, 8211], [151, 8212], [152, 732], [153, 8482], [154, 353], [155, 8250], [156, 339], [158, 382], [159, 376]]);
    var entitySets = [{ "length": 32, "entities": { "CounterClockwiseContourIntegral;": [8755] } }, { "length": 25, "entities": { "ClockwiseContourIntegral;": [8754], "DoubleLongLeftRightArrow;": [10234] } }, { "length": 24, "entities": { "NotNestedGreaterGreater;": [10914, 824] } }, { "length": 23, "entities": { "DiacriticalDoubleAcute;": [733], "NotSquareSupersetEqual;": [8931] } }, { "length": 22, "entities": { "CloseCurlyDoubleQuote;": [8221], "DoubleContourIntegral;": [8751], "FilledVerySmallSquare;": [9642], "NegativeVeryThinSpace;": [8203], "NotPrecedesSlantEqual;": [8928], "NotRightTriangleEqual;": [8941], "NotSucceedsSlantEqual;": [8929] } }, { "length": 21, "entities": { "CapitalDifferentialD;": [8517], "DoubleLeftRightArrow;": [8660], "DoubleLongRightArrow;": [10233], "EmptyVerySmallSquare;": [9643], "NestedGreaterGreater;": [8811], "NotDoubleVerticalBar;": [8742], "NotGreaterSlantEqual;": [10878, 824], "NotLeftTriangleEqual;": [8940], "NotSquareSubsetEqual;": [8930], "OpenCurlyDoubleQuote;": [8220], "ReverseUpEquilibrium;": [10607] } }, { "length": 20, "entities": { "DoubleLongLeftArrow;": [10232], "DownLeftRightVector;": [10576], "LeftArrowRightArrow;": [8646], "NegativeMediumSpace;": [8203], "NotGreaterFullEqual;": [8807, 824], "NotRightTriangleBar;": [10704, 824], "RightArrowLeftArrow;": [8644], "SquareSupersetEqual;": [8850], "leftrightsquigarrow;": [8621] } }, { "length": 19, "entities": { "DownRightTeeVector;": [10591], "DownRightVectorBar;": [10583], "LongLeftRightArrow;": [10231], "Longleftrightarrow;": [10234], "NegativeThickSpace;": [8203], "NotLeftTriangleBar;": [10703, 824], "PrecedesSlantEqual;": [8828], "ReverseEquilibrium;": [8651], "RightDoubleBracket;": [10215], "RightDownTeeVector;": [10589], "RightDownVectorBar;": [10581], "RightTriangleEqual;": [8885], "SquareIntersection;": [8851], "SucceedsSlantEqual;": [8829], "blacktriangleright;": [9656], "longleftrightarrow;": [10231] } }, { "length": 18, "entities": { "DoubleUpDownArrow;": [8661], "DoubleVerticalBar;": [8741], "DownLeftTeeVector;": [10590], "DownLeftVectorBar;": [10582], "FilledSmallSquare;": [9724], "GreaterSlantEqual;": [10878], "LeftDoubleBracket;": [10214], "LeftDownTeeVector;": [10593], "LeftDownVectorBar;": [10585], "LeftTriangleEqual;": [8884], "NegativeThinSpace;": [8203], "NotGreaterGreater;": [8811, 824], "NotLessSlantEqual;": [10877, 824], "NotNestedLessLess;": [10913, 824], "NotReverseElement;": [8716], "NotSquareSuperset;": [8848, 824], "NotTildeFullEqual;": [8775], "RightAngleBracket;": [10217], "RightUpDownVector;": [10575], "SquareSubsetEqual;": [8849], "VerticalSeparator;": [10072], "blacktriangledown;": [9662], "blacktriangleleft;": [9666], "leftrightharpoons;": [8651], "rightleftharpoons;": [8652], "twoheadrightarrow;": [8608] } }, { "length": 17, "entities": { "DiacriticalAcute;": [180], "DiacriticalGrave;": [96], "DiacriticalTilde;": [732], "DoubleRightArrow;": [8658], "DownArrowUpArrow;": [8693], "EmptySmallSquare;": [9723], "GreaterEqualLess;": [8923], "GreaterFullEqual;": [8807], "LeftAngleBracket;": [10216], "LeftUpDownVector;": [10577], "LessEqualGreater;": [8922], "NonBreakingSpace;": [160], "NotPrecedesEqual;": [10927, 824], "NotRightTriangle;": [8939], "NotSucceedsEqual;": [10928, 824], "NotSucceedsTilde;": [8831, 824], "NotSupersetEqual;": [8841], "RightTriangleBar;": [10704], "RightUpTeeVector;": [10588], "RightUpVectorBar;": [10580], "UnderParenthesis;": [9181], "UpArrowDownArrow;": [8645], "circlearrowright;": [8635], "downharpoonright;": [8642], "ntrianglerighteq;": [8941], "rightharpoondown;": [8641], "rightrightarrows;": [8649], "twoheadleftarrow;": [8606], "vartriangleright;": [8883] } }, { "length": 16, "entities": { "CloseCurlyQuote;": [8217], "ContourIntegral;": [8750], "DoubleDownArrow;": [8659], "DoubleLeftArrow;": [8656], "DownRightVector;": [8641], "LeftRightVector;": [10574], "LeftTriangleBar;": [10703], "LeftUpTeeVector;": [10592], "LeftUpVectorBar;": [10584], "LowerRightArrow;": [8600], "NotGreaterEqual;": [8817], "NotGreaterTilde;": [8821], "NotHumpDownHump;": [8782, 824], "NotLeftTriangle;": [8938], "NotSquareSubset;": [8847, 824], "OverParenthesis;": [9180], "RightDownVector;": [8642], "ShortRightArrow;": [8594], "UpperRightArrow;": [8599], "bigtriangledown;": [9661], "circlearrowleft;": [8634], "curvearrowright;": [8631], "downharpoonleft;": [8643], "leftharpoondown;": [8637], "leftrightarrows;": [8646], "nLeftrightarrow;": [8654], "nleftrightarrow;": [8622], "ntrianglelefteq;": [8940], "rightleftarrows;": [8644], "rightsquigarrow;": [8605], "rightthreetimes;": [8908], "straightepsilon;": [1013], "trianglerighteq;": [8885], "vartriangleleft;": [8882] } }, { "length": 15, "entities": { "DiacriticalDot;": [729], "DoubleRightTee;": [8872], "DownLeftVector;": [8637], "GreaterGreater;": [10914], "HorizontalLine;": [9472], "InvisibleComma;": [8291], "InvisibleTimes;": [8290], "LeftDownVector;": [8643], "LeftRightArrow;": [8596], "Leftrightarrow;": [8660], "LessSlantEqual;": [10877], "LongRightArrow;": [10230], "Longrightarrow;": [10233], "LowerLeftArrow;": [8601], "NestedLessLess;": [8810], "NotGreaterLess;": [8825], "NotLessGreater;": [8824], "NotSubsetEqual;": [8840], "NotVerticalBar;": [8740], "OpenCurlyQuote;": [8216], "ReverseElement;": [8715], "RightTeeVector;": [10587], "RightVectorBar;": [10579], "ShortDownArrow;": [8595], "ShortLeftArrow;": [8592], "SquareSuperset;": [8848], "TildeFullEqual;": [8773], "UpperLeftArrow;": [8598], "ZeroWidthSpace;": [8203], "curvearrowleft;": [8630], "doublebarwedge;": [8966], "downdownarrows;": [8650], "hookrightarrow;": [8618], "leftleftarrows;": [8647], "leftrightarrow;": [8596], "leftthreetimes;": [8907], "longrightarrow;": [10230], "looparrowright;": [8620], "nshortparallel;": [8742], "ntriangleright;": [8939], "rightarrowtail;": [8611], "rightharpoonup;": [8640], "trianglelefteq;": [8884], "upharpoonright;": [8638] } }, { "length": 14, "entities": { "ApplyFunction;": [8289], "DifferentialD;": [8518], "DoubleLeftTee;": [10980], "DoubleUpArrow;": [8657], "LeftTeeVector;": [10586], "LeftVectorBar;": [10578], "LessFullEqual;": [8806], "LongLeftArrow;": [10229], "Longleftarrow;": [10232], "NotEqualTilde;": [8770, 824], "NotTildeEqual;": [8772], "NotTildeTilde;": [8777], "Poincareplane;": [8460], "PrecedesEqual;": [10927], "PrecedesTilde;": [8830], "RightArrowBar;": [8677], "RightTeeArrow;": [8614], "RightTriangle;": [8883], "RightUpVector;": [8638], "SucceedsEqual;": [10928], "SucceedsTilde;": [8831], "SupersetEqual;": [8839], "UpEquilibrium;": [10606], "VerticalTilde;": [8768], "VeryThinSpace;": [8202], "bigtriangleup;": [9651], "blacktriangle;": [9652], "divideontimes;": [8903], "fallingdotseq;": [8786], "hookleftarrow;": [8617], "leftarrowtail;": [8610], "leftharpoonup;": [8636], "longleftarrow;": [10229], "looparrowleft;": [8619], "measuredangle;": [8737], "ntriangleleft;": [8938], "shortparallel;": [8741], "smallsetminus;": [8726], "triangleright;": [9657], "upharpoonleft;": [8639], "varsubsetneqq;": [10955, 65024], "varsupsetneqq;": [10956, 65024] } }, { "length": 13, "entities": { "DownArrowBar;": [10515], "DownTeeArrow;": [8615], "ExponentialE;": [8519], "GreaterEqual;": [8805], "GreaterTilde;": [8819], "HilbertSpace;": [8459], "HumpDownHump;": [8782], "Intersection;": [8898], "LeftArrowBar;": [8676], "LeftTeeArrow;": [8612], "LeftTriangle;": [8882], "LeftUpVector;": [8639], "NotCongruent;": [8802], "NotHumpEqual;": [8783, 824], "NotLessEqual;": [8816], "NotLessTilde;": [8820], "Proportional;": [8733], "RightCeiling;": [8969], "RoundImplies;": [10608], "ShortUpArrow;": [8593], "SquareSubset;": [8847], "UnderBracket;": [9141], "VerticalLine;": [124], "blacklozenge;": [10731], "exponentiale;": [8519], "risingdotseq;": [8787], "triangledown;": [9663], "triangleleft;": [9667], "varsubsetneq;": [8842, 65024], "varsupsetneq;": [8843, 65024] } }, { "length": 12, "entities": { "CircleMinus;": [8854], "CircleTimes;": [8855], "Equilibrium;": [8652], "GreaterLess;": [8823], "LeftCeiling;": [8968], "LessGreater;": [8822], "MediumSpace;": [8287], "NotLessLess;": [8810, 824], "NotPrecedes;": [8832], "NotSucceeds;": [8833], "NotSuperset;": [8835, 8402], "OverBracket;": [9140], "RightVector;": [8640], "Rrightarrow;": [8667], "RuleDelayed;": [10740], "SmallCircle;": [8728], "SquareUnion;": [8852], "SubsetEqual;": [8838], "UpDownArrow;": [8597], "Updownarrow;": [8661], "VerticalBar;": [8739], "backepsilon;": [1014], "blacksquare;": [9642], "circledcirc;": [8858], "circleddash;": [8861], "curlyeqprec;": [8926], "curlyeqsucc;": [8927], "diamondsuit;": [9830], "eqslantless;": [10901], "expectation;": [8496], "nRightarrow;": [8655], "nrightarrow;": [8603], "preccurlyeq;": [8828], "precnapprox;": [10937], "quaternions;": [8461], "straightphi;": [981], "succcurlyeq;": [8829], "succnapprox;": [10938], "thickapprox;": [8776], "updownarrow;": [8597] } }, { "length": 11, "entities": { "Bernoullis;": [8492], "CirclePlus;": [8853], "EqualTilde;": [8770], "Fouriertrf;": [8497], "ImaginaryI;": [8520], "Laplacetrf;": [8466], "LeftVector;": [8636], "Lleftarrow;": [8666], "NotElement;": [8713], "NotGreater;": [8815], "Proportion;": [8759], "RightArrow;": [8594], "RightFloor;": [8971], "Rightarrow;": [8658], "ThickSpace;": [8287, 8202], "TildeEqual;": [8771], "TildeTilde;": [8776], "UnderBrace;": [9183], "UpArrowBar;": [10514], "UpTeeArrow;": [8613], "circledast;": [8859], "complement;": [8705], "curlywedge;": [8911], "eqslantgtr;": [10902], "gtreqqless;": [10892], "lessapprox;": [10885], "lesseqqgtr;": [10891], "lmoustache;": [9136], "longmapsto;": [10236], "mapstodown;": [8615], "mapstoleft;": [8612], "nLeftarrow;": [8653], "nleftarrow;": [8602], "nsubseteqq;": [10949, 824], "nsupseteqq;": [10950, 824], "precapprox;": [10935], "rightarrow;": [8594], "rmoustache;": [9137], "sqsubseteq;": [8849], "sqsupseteq;": [8850], "subsetneqq;": [10955], "succapprox;": [10936], "supsetneqq;": [10956], "upuparrows;": [8648], "varepsilon;": [1013], "varnothing;": [8709] } }, { "length": 10, "entities": { "Backslash;": [8726], "CenterDot;": [183], "CircleDot;": [8857], "Congruent;": [8801], "Coproduct;": [8720], "DoubleDot;": [168], "DownArrow;": [8595], "DownBreve;": [785], "Downarrow;": [8659], "HumpEqual;": [8783], "LeftArrow;": [8592], "LeftFloor;": [8970], "Leftarrow;": [8656], "LessTilde;": [8818], "Mellintrf;": [8499], "MinusPlus;": [8723], "NotCupCap;": [8813], "NotExists;": [8708], "NotSubset;": [8834, 8402], "OverBrace;": [9182], "PlusMinus;": [177], "Therefore;": [8756], "ThinSpace;": [8201], "TripleDot;": [8411], "UnionPlus;": [8846], "backprime;": [8245], "backsimeq;": [8909], "bigotimes;": [10754], "centerdot;": [183], "checkmark;": [10003], "complexes;": [8450], "dotsquare;": [8865], "downarrow;": [8595], "gtrapprox;": [10886], "gtreqless;": [8923], "gvertneqq;": [8809, 65024], "heartsuit;": [9829], "leftarrow;": [8592], "lesseqgtr;": [8922], "lvertneqq;": [8808, 65024], "ngeqslant;": [10878, 824], "nleqslant;": [10877, 824], "nparallel;": [8742], "nshortmid;": [8740], "nsubseteq;": [8840], "nsupseteq;": [8841], "pitchfork;": [8916], "rationals;": [8474], "spadesuit;": [9824], "subseteqq;": [10949], "subsetneq;": [8842], "supseteqq;": [10950], "supsetneq;": [8843], "therefore;": [8756], "triangleq;": [8796], "varpropto;": [8733] } }, { "length": 9, "entities": { "DDotrahd;": [10513], "DotEqual;": [8784], "Integral;": [8747], "LessLess;": [10913], "NotEqual;": [8800], "NotTilde;": [8769], "PartialD;": [8706], "Precedes;": [8826], "RightTee;": [8866], "Succeeds;": [8827], "SuchThat;": [8715], "Superset;": [8835], "Uarrocir;": [10569], "UnderBar;": [95], "andslope;": [10840], "angmsdaa;": [10664], "angmsdab;": [10665], "angmsdac;": [10666], "angmsdad;": [10667], "angmsdae;": [10668], "angmsdaf;": [10669], "angmsdag;": [10670], "angmsdah;": [10671], "angrtvbd;": [10653], "approxeq;": [8778], "awconint;": [8755], "backcong;": [8780], "barwedge;": [8965], "bbrktbrk;": [9142], "bigoplus;": [10753], "bigsqcup;": [10758], "biguplus;": [10756], "bigwedge;": [8896], "boxminus;": [8863], "boxtimes;": [8864], "bsolhsub;": [10184], "capbrcup;": [10825], "circledR;": [174], "circledS;": [9416], "cirfnint;": [10768], "clubsuit;": [9827], "cupbrcap;": [10824], "curlyvee;": [8910], "cwconint;": [8754], "doteqdot;": [8785], "dotminus;": [8760], "drbkarow;": [10512], "dzigrarr;": [10239], "elinters;": [9191], "emptyset;": [8709], "eqvparsl;": [10725], "fpartint;": [10765], "geqslant;": [10878], "gesdotol;": [10884], "gnapprox;": [10890], "hksearow;": [10533], "hkswarow;": [10534], "imagline;": [8464], "imagpart;": [8465], "infintie;": [10717], "integers;": [8484], "intercal;": [8890], "intlarhk;": [10775], "laemptyv;": [10676], "ldrushar;": [10571], "leqslant;": [10877], "lesdotor;": [10883], "llcorner;": [8990], "lnapprox;": [10889], "lrcorner;": [8991], "lurdshar;": [10570], "mapstoup;": [8613], "multimap;": [8888], "naturals;": [8469], "ncongdot;": [10861, 824], "notindot;": [8949, 824], "otimesas;": [10806], "parallel;": [8741], "plusacir;": [10787], "pointint;": [10773], "precneqq;": [10933], "precnsim;": [8936], "profalar;": [9006], "profline;": [8978], "profsurf;": [8979], "raemptyv;": [10675], "realpart;": [8476], "rppolint;": [10770], "rtriltri;": [10702], "scpolint;": [10771], "setminus;": [8726], "shortmid;": [8739], "smeparsl;": [10724], "sqsubset;": [8847], "sqsupset;": [8848], "subseteq;": [8838], "succneqq;": [10934], "succnsim;": [8937], "supseteq;": [8839], "thetasym;": [977], "thicksim;": [8764], "timesbar;": [10801], "triangle;": [9653], "triminus;": [10810], "trpezium;": [9186], "ulcorner;": [8988], "urcorner;": [8989], "varkappa;": [1008], "varsigma;": [962], "vartheta;": [977] } }, { "length": 8, "entities": { "Because;": [8757], "Cayleys;": [8493], "Cconint;": [8752], "Cedilla;": [184], "Diamond;": [8900], "DownTee;": [8868], "Element;": [8712], "Epsilon;": [917], "Implies;": [8658], "LeftTee;": [8867], "NewLine;": [10], "NoBreak;": [8288], "NotLess;": [8814], "Omicron;": [927], "OverBar;": [8254], "Product;": [8719], "UpArrow;": [8593], "Uparrow;": [8657], "Upsilon;": [933], "alefsym;": [8501], "angrtvb;": [8894], "angzarr;": [9084], "asympeq;": [8781], "backsim;": [8765], "because;": [8757], "bemptyv;": [10672], "between;": [8812], "bigcirc;": [9711], "bigodot;": [10752], "bigstar;": [9733], "bnequiv;": [8801, 8421], "boxplus;": [8862], "ccupssm;": [10832], "cemptyv;": [10674], "cirscir;": [10690], "coloneq;": [8788], "congdot;": [10861], "cudarrl;": [10552], "cudarrr;": [10549], "cularrp;": [10557], "curarrm;": [10556], "dbkarow;": [10511], "ddagger;": [8225], "ddotseq;": [10871], "demptyv;": [10673], "diamond;": [8900], "digamma;": [989], "dotplus;": [8724], "dwangle;": [10662], "epsilon;": [949], "eqcolon;": [8789], "equivDD;": [10872], "gesdoto;": [10882], "gtquest;": [10876], "gtrless;": [8823], "harrcir;": [10568], "intprod;": [10812], "isindot;": [8949], "larrbfs;": [10527], "larrsim;": [10611], "lbrksld;": [10639], "lbrkslu;": [10637], "ldrdhar;": [10599], "lesdoto;": [10881], "lessdot;": [8918], "lessgtr;": [8822], "lesssim;": [8818], "lotimes;": [10804], "lozenge;": [9674], "ltquest;": [10875], "luruhar;": [10598], "maltese;": [10016], "minusdu;": [10794], "napprox;": [8777], "natural;": [9838], "nearrow;": [8599], "nexists;": [8708], "notinva;": [8713], "notinvb;": [8951], "notinvc;": [8950], "notniva;": [8716], "notnivb;": [8958], "notnivc;": [8957], "npolint;": [10772], "npreceq;": [10927, 824], "nsqsube;": [8930], "nsqsupe;": [8931], "nsubset;": [8834, 8402], "nsucceq;": [10928, 824], "nsupset;": [8835, 8402], "nvinfin;": [10718], "nvltrie;": [8884, 8402], "nvrtrie;": [8885, 8402], "nwarrow;": [8598], "olcross;": [10683], "omicron;": [959], "orderof;": [8500], "orslope;": [10839], "pertenk;": [8241], "planckh;": [8462], "pluscir;": [10786], "plussim;": [10790], "plustwo;": [10791], "precsim;": [8830], "quatint;": [10774], "questeq;": [8799], "rarrbfs;": [10528], "rarrsim;": [10612], "rbrksld;": [10638], "rbrkslu;": [10640], "rdldhar;": [10601], "realine;": [8475], "rotimes;": [10805], "ruluhar;": [10600], "searrow;": [8600], "simplus;": [10788], "simrarr;": [10610], "subedot;": [10947], "submult;": [10945], "subplus;": [10943], "subrarr;": [10617], "succsim;": [8831], "supdsub;": [10968], "supedot;": [10948], "suphsol;": [10185], "suphsub;": [10967], "suplarr;": [10619], "supmult;": [10946], "supplus;": [10944], "swarrow;": [8601], "topfork;": [10970], "triplus;": [10809], "tritime;": [10811], "uparrow;": [8593], "upsilon;": [965], "uwangle;": [10663], "vzigzag;": [10650], "zigrarr;": [8669] } }, { "length": 7, "entities": { "Aacute;": [193], "Abreve;": [258], "Agrave;": [192], "Assign;": [8788], "Atilde;": [195], "Barwed;": [8966], "Bumpeq;": [8782], "Cacute;": [262], "Ccaron;": [268], "Ccedil;": [199], "Colone;": [10868], "Conint;": [8751], "CupCap;": [8781], "Dagger;": [8225], "Dcaron;": [270], "DotDot;": [8412], "Dstrok;": [272], "Eacute;": [201], "Ecaron;": [282], "Egrave;": [200], "Exists;": [8707], "ForAll;": [8704], "Gammad;": [988], "Gbreve;": [286], "Gcedil;": [290], "HARDcy;": [1066], "Hstrok;": [294], "Iacute;": [205], "Igrave;": [204], "Itilde;": [296], "Jsercy;": [1032], "Kcedil;": [310], "Lacute;": [313], "Lambda;": [923], "Lcaron;": [317], "Lcedil;": [315], "Lmidot;": [319], "Lstrok;": [321], "Nacute;": [323], "Ncaron;": [327], "Ncedil;": [325], "Ntilde;": [209], "Oacute;": [211], "Odblac;": [336], "Ograve;": [210], "Oslash;": [216], "Otilde;": [213], "Otimes;": [10807], "Racute;": [340], "Rarrtl;": [10518], "Rcaron;": [344], "Rcedil;": [342], "SHCHcy;": [1065], "SOFTcy;": [1068], "Sacute;": [346], "Scaron;": [352], "Scedil;": [350], "Square;": [9633], "Subset;": [8912], "Supset;": [8913], "Tcaron;": [356], "Tcedil;": [354], "Tstrok;": [358], "Uacute;": [218], "Ubreve;": [364], "Udblac;": [368], "Ugrave;": [217], "Utilde;": [360], "Vdashl;": [10982], "Verbar;": [8214], "Vvdash;": [8874], "Yacute;": [221], "Zacute;": [377], "Zcaron;": [381], "aacute;": [225], "abreve;": [259], "agrave;": [224], "andand;": [10837], "angmsd;": [8737], "angsph;": [8738], "apacir;": [10863], "approx;": [8776], "atilde;": [227], "barvee;": [8893], "barwed;": [8965], "becaus;": [8757], "bernou;": [8492], "bigcap;": [8898], "bigcup;": [8899], "bigvee;": [8897], "bkarow;": [10509], "bottom;": [8869], "bowtie;": [8904], "boxbox;": [10697], "bprime;": [8245], "brvbar;": [166], "bullet;": [8226], "bumpeq;": [8783], "cacute;": [263], "capand;": [10820], "capcap;": [10827], "capcup;": [10823], "capdot;": [10816], "ccaron;": [269], "ccedil;": [231], "circeq;": [8791], "cirmid;": [10991], "colone;": [8788], "commat;": [64], "compfn;": [8728], "conint;": [8750], "coprod;": [8720], "copysr;": [8471], "cularr;": [8630], "cupcap;": [10822], "cupcup;": [10826], "cupdot;": [8845], "curarr;": [8631], "curren;": [164], "cylcty;": [9005], "dagger;": [8224], "daleth;": [8504], "dcaron;": [271], "dfisht;": [10623], "divide;": [247], "divonx;": [8903], "dlcorn;": [8990], "dlcrop;": [8973], "dollar;": [36], "drcorn;": [8991], "drcrop;": [8972], "dstrok;": [273], "eacute;": [233], "easter;": [10862], "ecaron;": [283], "ecolon;": [8789], "egrave;": [232], "egsdot;": [10904], "elsdot;": [10903], "emptyv;": [8709], "emsp13;": [8196], "emsp14;": [8197], "eparsl;": [10723], "eqcirc;": [8790], "equals;": [61], "equest;": [8799], "female;": [9792], "ffilig;": [64259], "ffllig;": [64260], "forall;": [8704], "frac12;": [189], "frac13;": [8531], "frac14;": [188], "frac15;": [8533], "frac16;": [8537], "frac18;": [8539], "frac23;": [8532], "frac25;": [8534], "frac34;": [190], "frac35;": [8535], "frac38;": [8540], "frac45;": [8536], "frac56;": [8538], "frac58;": [8541], "frac78;": [8542], "gacute;": [501], "gammad;": [989], "gbreve;": [287], "gesdot;": [10880], "gesles;": [10900], "gtlPar;": [10645], "gtrarr;": [10616], "gtrdot;": [8919], "gtrsim;": [8819], "hairsp;": [8202], "hamilt;": [8459], "hardcy;": [1098], "hearts;": [9829], "hellip;": [8230], "hercon;": [8889], "homtht;": [8763], "horbar;": [8213], "hslash;": [8463], "hstrok;": [295], "hybull;": [8259], "hyphen;": [8208], "iacute;": [237], "igrave;": [236], "iiiint;": [10764], "iinfin;": [10716], "incare;": [8453], "inodot;": [305], "intcal;": [8890], "iquest;": [191], "isinsv;": [8947], "itilde;": [297], "jsercy;": [1112], "kappav;": [1008], "kcedil;": [311], "kgreen;": [312], "lAtail;": [10523], "lacute;": [314], "lagran;": [8466], "lambda;": [955], "langle;": [10216], "larrfs;": [10525], "larrhk;": [8617], "larrlp;": [8619], "larrpl;": [10553], "larrtl;": [8610], "latail;": [10521], "lbrace;": [123], "lbrack;": [91], "lcaron;": [318], "lcedil;": [316], "ldquor;": [8222], "lesdot;": [10879], "lesges;": [10899], "lfisht;": [10620], "lfloor;": [8970], "lharul;": [10602], "llhard;": [10603], "lmidot;": [320], "lmoust;": [9136], "loplus;": [10797], "lowast;": [8727], "lowbar;": [95], "lparlt;": [10643], "lrhard;": [10605], "lsaquo;": [8249], "lsquor;": [8218], "lstrok;": [322], "lthree;": [8907], "ltimes;": [8905], "ltlarr;": [10614], "ltrPar;": [10646], "mapsto;": [8614], "marker;": [9646], "mcomma;": [10793], "midast;": [42], "midcir;": [10992], "middot;": [183], "minusb;": [8863], "minusd;": [8760], "mnplus;": [8723], "models;": [8871], "mstpos;": [8766], "nVDash;": [8879], "nVdash;": [8878], "nacute;": [324], "nbumpe;": [8783, 824], "ncaron;": [328], "ncedil;": [326], "nearhk;": [10532], "nequiv;": [8802], "nesear;": [10536], "nexist;": [8708], "nltrie;": [8940], "notinE;": [8953, 824], "nparsl;": [11005, 8421], "nprcue;": [8928], "nrarrc;": [10547, 824], "nrarrw;": [8605, 824], "nrtrie;": [8941], "nsccue;": [8929], "nsimeq;": [8772], "ntilde;": [241], "numero;": [8470], "nvDash;": [8877], "nvHarr;": [10500], "nvdash;": [8876], "nvlArr;": [10498], "nvrArr;": [10499], "nwarhk;": [10531], "nwnear;": [10535], "oacute;": [243], "odblac;": [337], "odsold;": [10684], "ograve;": [242], "ominus;": [8854], "origof;": [8886], "oslash;": [248], "otilde;": [245], "otimes;": [8855], "parsim;": [10995], "percnt;": [37], "period;": [46], "permil;": [8240], "phmmat;": [8499], "planck;": [8463], "plankv;": [8463], "plusdo;": [8724], "plusdu;": [10789], "plusmn;": [177], "preceq;": [10927], "primes;": [8473], "prnsim;": [8936], "propto;": [8733], "prurel;": [8880], "puncsp;": [8200], "qprime;": [8279], "rAtail;": [10524], "racute;": [341], "rangle;": [10217], "rarrap;": [10613], "rarrfs;": [10526], "rarrhk;": [8618], "rarrlp;": [8620], "rarrpl;": [10565], "rarrtl;": [8611], "ratail;": [10522], "rbrace;": [125], "rbrack;": [93], "rcaron;": [345], "rcedil;": [343], "rdquor;": [8221], "rfisht;": [10621], "rfloor;": [8971], "rharul;": [10604], "rmoust;": [9137], "roplus;": [10798], "rpargt;": [10644], "rsaquo;": [8250], "rsquor;": [8217], "rthree;": [8908], "rtimes;": [8906], "sacute;": [347], "scaron;": [353], "scedil;": [351], "scnsim;": [8937], "searhk;": [10533], "seswar;": [10537], "sfrown;": [8994], "shchcy;": [1097], "sigmaf;": [962], "sigmav;": [962], "simdot;": [10858], "smashp;": [10803], "softcy;": [1100], "solbar;": [9023], "spades;": [9824], "sqcaps;": [8851, 65024], "sqcups;": [8852, 65024], "sqsube;": [8849], "sqsupe;": [8850], "square;": [9633], "squarf;": [9642], "ssetmn;": [8726], "ssmile;": [8995], "sstarf;": [8902], "subdot;": [10941], "subset;": [8834], "subsim;": [10951], "subsub;": [10965], "subsup;": [10963], "succeq;": [10928], "supdot;": [10942], "supset;": [8835], "supsim;": [10952], "supsub;": [10964], "supsup;": [10966], "swarhk;": [10534], "swnwar;": [10538], "target;": [8982], "tcaron;": [357], "tcedil;": [355], "telrec;": [8981], "there4;": [8756], "thetav;": [977], "thinsp;": [8201], "thksim;": [8764], "timesb;": [8864], "timesd;": [10800], "topbot;": [9014], "topcir;": [10993], "tprime;": [8244], "tridot;": [9708], "tstrok;": [359], "uacute;": [250], "ubreve;": [365], "udblac;": [369], "ufisht;": [10622], "ugrave;": [249], "ulcorn;": [8988], "ulcrop;": [8975], "urcorn;": [8989], "urcrop;": [8974], "utilde;": [361], "vangrt;": [10652], "varphi;": [981], "varrho;": [1009], "veebar;": [8891], "vellip;": [8942], "verbar;": [124], "vsubnE;": [10955, 65024], "vsubne;": [8842, 65024], "vsupnE;": [10956, 65024], "vsupne;": [8843, 65024], "wedbar;": [10847], "wedgeq;": [8793], "weierp;": [8472], "wreath;": [8768], "xoplus;": [10753], "xotime;": [10754], "xsqcup;": [10758], "xuplus;": [10756], "xwedge;": [8896], "yacute;": [253], "zacute;": [378], "zcaron;": [382], "zeetrf;": [8488] } }, { "length": 6, "entities": { "AElig;": [198], "Aacute": [193], "Acirc;": [194], "Agrave": [192], "Alpha;": [913], "Amacr;": [256], "Aogon;": [260], "Aring;": [197], "Atilde": [195], "Breve;": [728], "Ccedil": [199], "Ccirc;": [264], "Colon;": [8759], "Cross;": [10799], "Dashv;": [10980], "Delta;": [916], "Eacute": [201], "Ecirc;": [202], "Egrave": [200], "Emacr;": [274], "Eogon;": [280], "Equal;": [10869], "Gamma;": [915], "Gcirc;": [284], "Hacek;": [711], "Hcirc;": [292], "IJlig;": [306], "Iacute": [205], "Icirc;": [206], "Igrave": [204], "Imacr;": [298], "Iogon;": [302], "Iukcy;": [1030], "Jcirc;": [308], "Jukcy;": [1028], "Kappa;": [922], "Ntilde": [209], "OElig;": [338], "Oacute": [211], "Ocirc;": [212], "Ograve": [210], "Omacr;": [332], "Omega;": [937], "Oslash": [216], "Otilde": [213], "Prime;": [8243], "RBarr;": [10512], "Scirc;": [348], "Sigma;": [931], "THORN;": [222], "TRADE;": [8482], "TSHcy;": [1035], "Theta;": [920], "Tilde;": [8764], "Uacute": [218], "Ubrcy;": [1038], "Ucirc;": [219], "Ugrave": [217], "Umacr;": [362], "Union;": [8899], "Uogon;": [370], "UpTee;": [8869], "Uring;": [366], "VDash;": [8875], "Vdash;": [8873], "Wcirc;": [372], "Wedge;": [8896], "Yacute": [221], "Ycirc;": [374], "aacute": [225], "acirc;": [226], "acute;": [180], "aelig;": [230], "agrave": [224], "aleph;": [8501], "alpha;": [945], "amacr;": [257], "amalg;": [10815], "angle;": [8736], "angrt;": [8735], "angst;": [197], "aogon;": [261], "aring;": [229], "asymp;": [8776], "atilde": [227], "awint;": [10769], "bcong;": [8780], "bdquo;": [8222], "bepsi;": [1014], "blank;": [9251], "blk12;": [9618], "blk14;": [9617], "blk34;": [9619], "block;": [9608], "boxDL;": [9559], "boxDR;": [9556], "boxDl;": [9558], "boxDr;": [9555], "boxHD;": [9574], "boxHU;": [9577], "boxHd;": [9572], "boxHu;": [9575], "boxUL;": [9565], "boxUR;": [9562], "boxUl;": [9564], "boxUr;": [9561], "boxVH;": [9580], "boxVL;": [9571], "boxVR;": [9568], "boxVh;": [9579], "boxVl;": [9570], "boxVr;": [9567], "boxdL;": [9557], "boxdR;": [9554], "boxdl;": [9488], "boxdr;": [9484], "boxhD;": [9573], "boxhU;": [9576], "boxhd;": [9516], "boxhu;": [9524], "boxuL;": [9563], "boxuR;": [9560], "boxul;": [9496], "boxur;": [9492], "boxvH;": [9578], "boxvL;": [9569], "boxvR;": [9566], "boxvh;": [9532], "boxvl;": [9508], "boxvr;": [9500], "breve;": [728], "brvbar": [166], "bsemi;": [8271], "bsime;": [8909], "bsolb;": [10693], "bumpE;": [10926], "bumpe;": [8783], "caret;": [8257], "caron;": [711], "ccaps;": [10829], "ccedil": [231], "ccirc;": [265], "ccups;": [10828], "cedil;": [184], "check;": [10003], "clubs;": [9827], "colon;": [58], "comma;": [44], "crarr;": [8629], "cross;": [10007], "csube;": [10961], "csupe;": [10962], "ctdot;": [8943], "cuepr;": [8926], "cuesc;": [8927], "cupor;": [10821], "curren": [164], "cuvee;": [8910], "cuwed;": [8911], "cwint;": [8753], "dashv;": [8867], "dblac;": [733], "ddarr;": [8650], "delta;": [948], "dharl;": [8643], "dharr;": [8642], "diams;": [9830], "disin;": [8946], "divide": [247], "doteq;": [8784], "dtdot;": [8945], "dtrif;": [9662], "duarr;": [8693], "duhar;": [10607], "eDDot;": [10871], "eacute": [233], "ecirc;": [234], "efDot;": [8786], "egrave": [232], "emacr;": [275], "empty;": [8709], "eogon;": [281], "eplus;": [10865], "epsiv;": [1013], "eqsim;": [8770], "equiv;": [8801], "erDot;": [8787], "erarr;": [10609], "esdot;": [8784], "exist;": [8707], "fflig;": [64256], "filig;": [64257], "fjlig;": [102, 106], "fllig;": [64258], "fltns;": [9649], "forkv;": [10969], "frac12": [189], "frac14": [188], "frac34": [190], "frasl;": [8260], "frown;": [8994], "gamma;": [947], "gcirc;": [285], "gescc;": [10921], "gimel;": [8503], "gneqq;": [8809], "gnsim;": [8935], "grave;": [96], "gsime;": [10894], "gsiml;": [10896], "gtcir;": [10874], "gtdot;": [8919], "harrw;": [8621], "hcirc;": [293], "hoarr;": [8703], "iacute": [237], "icirc;": [238], "iexcl;": [161], "igrave": [236], "iiint;": [8749], "iiota;": [8489], "ijlig;": [307], "imacr;": [299], "image;": [8465], "imath;": [305], "imped;": [437], "infin;": [8734], "iogon;": [303], "iprod;": [10812], "iquest": [191], "isinE;": [8953], "isins;": [8948], "isinv;": [8712], "iukcy;": [1110], "jcirc;": [309], "jmath;": [567], "jukcy;": [1108], "kappa;": [954], "lAarr;": [8666], "lBarr;": [10510], "langd;": [10641], "laquo;": [171], "larrb;": [8676], "lates;": [10925, 65024], "lbarr;": [10508], "lbbrk;": [10098], "lbrke;": [10635], "lceil;": [8968], "ldquo;": [8220], "lescc;": [10920], "lhard;": [8637], "lharu;": [8636], "lhblk;": [9604], "llarr;": [8647], "lltri;": [9722], "lneqq;": [8808], "lnsim;": [8934], "loang;": [10220], "loarr;": [8701], "lobrk;": [10214], "lopar;": [10629], "lrarr;": [8646], "lrhar;": [8651], "lrtri;": [8895], "lsime;": [10893], "lsimg;": [10895], "lsquo;": [8216], "ltcir;": [10873], "ltdot;": [8918], "ltrie;": [8884], "ltrif;": [9666], "mDDot;": [8762], "mdash;": [8212], "micro;": [181], "middot": [183], "minus;": [8722], "mumap;": [8888], "nabla;": [8711], "napid;": [8779, 824], "napos;": [329], "natur;": [9838], "nbump;": [8782, 824], "ncong;": [8775], "ndash;": [8211], "neArr;": [8663], "nearr;": [8599], "nedot;": [8784, 824], "nesim;": [8770, 824], "ngeqq;": [8807, 824], "ngsim;": [8821], "nhArr;": [8654], "nharr;": [8622], "nhpar;": [10994], "nlArr;": [8653], "nlarr;": [8602], "nleqq;": [8806, 824], "nless;": [8814], "nlsim;": [8820], "nltri;": [8938], "notin;": [8713], "notni;": [8716], "npart;": [8706, 824], "nprec;": [8832], "nrArr;": [8655], "nrarr;": [8603], "nrtri;": [8939], "nsime;": [8772], "nsmid;": [8740], "nspar;": [8742], "nsubE;": [10949, 824], "nsube;": [8840], "nsucc;": [8833], "nsupE;": [10950, 824], "nsupe;": [8841], "ntilde": [241], "numsp;": [8199], "nvsim;": [8764, 8402], "nwArr;": [8662], "nwarr;": [8598], "oacute": [243], "ocirc;": [244], "odash;": [8861], "oelig;": [339], "ofcir;": [10687], "ograve": [242], "ohbar;": [10677], "olarr;": [8634], "olcir;": [10686], "oline;": [8254], "omacr;": [333], "omega;": [969], "operp;": [10681], "oplus;": [8853], "orarr;": [8635], "order;": [8500], "oslash": [248], "otilde": [245], "ovbar;": [9021], "parsl;": [11005], "phone;": [9742], "plusb;": [8862], "pluse;": [10866], "plusmn": [177], "pound;": [163], "prcue;": [8828], "prime;": [8242], "prnap;": [10937], "prsim;": [8830], "quest;": [63], "rAarr;": [8667], "rBarr;": [10511], "radic;": [8730], "rangd;": [10642], "range;": [10661], "raquo;": [187], "rarrb;": [8677], "rarrc;": [10547], "rarrw;": [8605], "ratio;": [8758], "rbarr;": [10509], "rbbrk;": [10099], "rbrke;": [10636], "rceil;": [8969], "rdquo;": [8221], "reals;": [8477], "rhard;": [8641], "rharu;": [8640], "rlarr;": [8644], "rlhar;": [8652], "rnmid;": [10990], "roang;": [10221], "roarr;": [8702], "robrk;": [10215], "ropar;": [10630], "rrarr;": [8649], "rsquo;": [8217], "rtrie;": [8885], "rtrif;": [9656], "sbquo;": [8218], "sccue;": [8829], "scirc;": [349], "scnap;": [10938], "scsim;": [8831], "sdotb;": [8865], "sdote;": [10854], "seArr;": [8664], "searr;": [8600], "setmn;": [8726], "sharp;": [9839], "sigma;": [963], "simeq;": [8771], "simgE;": [10912], "simlE;": [10911], "simne;": [8774], "slarr;": [8592], "smile;": [8995], "smtes;": [10924, 65024], "sqcap;": [8851], "sqcup;": [8852], "sqsub;": [8847], "sqsup;": [8848], "srarr;": [8594], "starf;": [9733], "strns;": [175], "subnE;": [10955], "subne;": [8842], "supnE;": [10956], "supne;": [8843], "swArr;": [8665], "swarr;": [8601], "szlig;": [223], "theta;": [952], "thkap;": [8776], "thorn;": [254], "tilde;": [732], "times;": [215], "trade;": [8482], "trisb;": [10701], "tshcy;": [1115], "twixt;": [8812], "uacute": [250], "ubrcy;": [1118], "ucirc;": [251], "udarr;": [8645], "udhar;": [10606], "ugrave": [249], "uharl;": [8639], "uharr;": [8638], "uhblk;": [9600], "ultri;": [9720], "umacr;": [363], "uogon;": [371], "uplus;": [8846], "upsih;": [978], "uring;": [367], "urtri;": [9721], "utdot;": [8944], "utrif;": [9652], "uuarr;": [8648], "vBarv;": [10985], "vDash;": [8872], "varpi;": [982], "vdash;": [8866], "veeeq;": [8794], "vltri;": [8882], "vnsub;": [8834, 8402], "vnsup;": [8835, 8402], "vprop;": [8733], "vrtri;": [8883], "wcirc;": [373], "wedge;": [8743], "xcirc;": [9711], "xdtri;": [9661], "xhArr;": [10234], "xharr;": [10231], "xlArr;": [10232], "xlarr;": [10229], "xodot;": [10752], "xrArr;": [10233], "xrarr;": [10230], "xutri;": [9651], "yacute": [253], "ycirc;": [375] } }, { "length": 5, "entities": { "AElig": [198], "Acirc": [194], "Aopf;": [120120], "Aring": [197], "Ascr;": [119964], "Auml;": [196], "Barv;": [10983], "Beta;": [914], "Bopf;": [120121], "Bscr;": [8492], "CHcy;": [1063], "COPY;": [169], "Cdot;": [266], "Copf;": [8450], "Cscr;": [119966], "DJcy;": [1026], "DScy;": [1029], "DZcy;": [1039], "Darr;": [8609], "Dopf;": [120123], "Dscr;": [119967], "Ecirc": [202], "Edot;": [278], "Eopf;": [120124], "Escr;": [8496], "Esim;": [10867], "Euml;": [203], "Fopf;": [120125], "Fscr;": [8497], "GJcy;": [1027], "Gdot;": [288], "Gopf;": [120126], "Gscr;": [119970], "Hopf;": [8461], "Hscr;": [8459], "IEcy;": [1045], "IOcy;": [1025], "Icirc": [206], "Idot;": [304], "Iopf;": [120128], "Iota;": [921], "Iscr;": [8464], "Iuml;": [207], "Jopf;": [120129], "Jscr;": [119973], "KHcy;": [1061], "KJcy;": [1036], "Kopf;": [120130], "Kscr;": [119974], "LJcy;": [1033], "Lang;": [10218], "Larr;": [8606], "Lopf;": [120131], "Lscr;": [8466], "Mopf;": [120132], "Mscr;": [8499], "NJcy;": [1034], "Nopf;": [8469], "Nscr;": [119977], "Ocirc": [212], "Oopf;": [120134], "Oscr;": [119978], "Ouml;": [214], "Popf;": [8473], "Pscr;": [119979], "QUOT;": [34], "Qopf;": [8474], "Qscr;": [119980], "Rang;": [10219], "Rarr;": [8608], "Ropf;": [8477], "Rscr;": [8475], "SHcy;": [1064], "Sopf;": [120138], "Sqrt;": [8730], "Sscr;": [119982], "Star;": [8902], "THORN": [222], "TScy;": [1062], "Topf;": [120139], "Tscr;": [119983], "Uarr;": [8607], "Ucirc": [219], "Uopf;": [120140], "Upsi;": [978], "Uscr;": [119984], "Uuml;": [220], "Vbar;": [10987], "Vert;": [8214], "Vopf;": [120141], "Vscr;": [119985], "Wopf;": [120142], "Wscr;": [119986], "Xopf;": [120143], "Xscr;": [119987], "YAcy;": [1071], "YIcy;": [1031], "YUcy;": [1070], "Yopf;": [120144], "Yscr;": [119988], "Yuml;": [376], "ZHcy;": [1046], "Zdot;": [379], "Zeta;": [918], "Zopf;": [8484], "Zscr;": [119989], "acirc": [226], "acute": [180], "aelig": [230], "andd;": [10844], "andv;": [10842], "ange;": [10660], "aopf;": [120146], "apid;": [8779], "apos;": [39], "aring": [229], "ascr;": [119990], "auml;": [228], "bNot;": [10989], "bbrk;": [9141], "beta;": [946], "beth;": [8502], "bnot;": [8976], "bopf;": [120147], "boxH;": [9552], "boxV;": [9553], "boxh;": [9472], "boxv;": [9474], "bscr;": [119991], "bsim;": [8765], "bsol;": [92], "bull;": [8226], "bump;": [8782], "caps;": [8745, 65024], "cdot;": [267], "cedil": [184], "cent;": [162], "chcy;": [1095], "cirE;": [10691], "circ;": [710], "cire;": [8791], "comp;": [8705], "cong;": [8773], "copf;": [120148], "copy;": [169], "cscr;": [119992], "csub;": [10959], "csup;": [10960], "cups;": [8746, 65024], "dArr;": [8659], "dHar;": [10597], "darr;": [8595], "dash;": [8208], "diam;": [8900], "djcy;": [1106], "dopf;": [120149], "dscr;": [119993], "dscy;": [1109], "dsol;": [10742], "dtri;": [9663], "dzcy;": [1119], "eDot;": [8785], "ecir;": [8790], "ecirc": [234], "edot;": [279], "emsp;": [8195], "ensp;": [8194], "eopf;": [120150], "epar;": [8917], "epsi;": [949], "escr;": [8495], "esim;": [8770], "euml;": [235], "euro;": [8364], "excl;": [33], "flat;": [9837], "fnof;": [402], "fopf;": [120151], "fork;": [8916], "fscr;": [119995], "gdot;": [289], "geqq;": [8807], "gesl;": [8923, 65024], "gjcy;": [1107], "gnap;": [10890], "gneq;": [10888], "gopf;": [120152], "gscr;": [8458], "gsim;": [8819], "gtcc;": [10919], "gvnE;": [8809, 65024], "hArr;": [8660], "half;": [189], "harr;": [8596], "hbar;": [8463], "hopf;": [120153], "hscr;": [119997], "icirc": [238], "iecy;": [1077], "iexcl": [161], "imof;": [8887], "iocy;": [1105], "iopf;": [120154], "iota;": [953], "iscr;": [119998], "isin;": [8712], "iuml;": [239], "jopf;": [120155], "jscr;": [119999], "khcy;": [1093], "kjcy;": [1116], "kopf;": [120156], "kscr;": [12e4], "lArr;": [8656], "lHar;": [10594], "lang;": [10216], "laquo": [171], "larr;": [8592], "late;": [10925], "lcub;": [123], "ldca;": [10550], "ldsh;": [8626], "leqq;": [8806], "lesg;": [8922, 65024], "ljcy;": [1113], "lnap;": [10889], "lneq;": [10887], "lopf;": [120157], "lozf;": [10731], "lpar;": [40], "lscr;": [120001], "lsim;": [8818], "lsqb;": [91], "ltcc;": [10918], "ltri;": [9667], "lvnE;": [8808, 65024], "macr;": [175], "male;": [9794], "malt;": [10016], "micro": [181], "mlcp;": [10971], "mldr;": [8230], "mopf;": [120158], "mscr;": [120002], "nGtv;": [8811, 824], "nLtv;": [8810, 824], "nang;": [8736, 8402], "napE;": [10864, 824], "nbsp;": [160], "ncap;": [10819], "ncup;": [10818], "ngeq;": [8817], "nges;": [10878, 824], "ngtr;": [8815], "nisd;": [8954], "njcy;": [1114], "nldr;": [8229], "nleq;": [8816], "nles;": [10877, 824], "nmid;": [8740], "nopf;": [120159], "npar;": [8742], "npre;": [10927, 824], "nsce;": [10928, 824], "nscr;": [120003], "nsim;": [8769], "nsub;": [8836], "nsup;": [8837], "ntgl;": [8825], "ntlg;": [8824], "nvap;": [8781, 8402], "nvge;": [8805, 8402], "nvgt;": [62, 8402], "nvle;": [8804, 8402], "nvlt;": [60, 8402], "oast;": [8859], "ocir;": [8858], "ocirc": [244], "odiv;": [10808], "odot;": [8857], "ogon;": [731], "oint;": [8750], "omid;": [10678], "oopf;": [120160], "opar;": [10679], "ordf;": [170], "ordm;": [186], "oror;": [10838], "oscr;": [8500], "osol;": [8856], "ouml;": [246], "para;": [182], "part;": [8706], "perp;": [8869], "phiv;": [981], "plus;": [43], "popf;": [120161], "pound": [163], "prap;": [10935], "prec;": [8826], "prnE;": [10933], "prod;": [8719], "prop;": [8733], "pscr;": [120005], "qint;": [10764], "qopf;": [120162], "qscr;": [120006], "quot;": [34], "rArr;": [8658], "rHar;": [10596], "race;": [8765, 817], "rang;": [10217], "raquo": [187], "rarr;": [8594], "rcub;": [125], "rdca;": [10551], "rdsh;": [8627], "real;": [8476], "rect;": [9645], "rhov;": [1009], "ring;": [730], "ropf;": [120163], "rpar;": [41], "rscr;": [120007], "rsqb;": [93], "rtri;": [9657], "scap;": [10936], "scnE;": [10934], "sdot;": [8901], "sect;": [167], "semi;": [59], "sext;": [10038], "shcy;": [1096], "sime;": [8771], "simg;": [10910], "siml;": [10909], "smid;": [8739], "smte;": [10924], "solb;": [10692], "sopf;": [120164], "spar;": [8741], "squf;": [9642], "sscr;": [120008], "star;": [9734], "subE;": [10949], "sube;": [8838], "succ;": [8827], "sung;": [9834], "sup1;": [185], "sup2;": [178], "sup3;": [179], "supE;": [10950], "supe;": [8839], "szlig": [223], "tbrk;": [9140], "tdot;": [8411], "thorn": [254], "times": [215], "tint;": [8749], "toea;": [10536], "topf;": [120165], "tosa;": [10537], "trie;": [8796], "tscr;": [120009], "tscy;": [1094], "uArr;": [8657], "uHar;": [10595], "uarr;": [8593], "ucirc": [251], "uopf;": [120166], "upsi;": [965], "uscr;": [120010], "utri;": [9653], "uuml;": [252], "vArr;": [8661], "vBar;": [10984], "varr;": [8597], "vert;": [124], "vopf;": [120167], "vscr;": [120011], "wopf;": [120168], "wscr;": [120012], "xcap;": [8898], "xcup;": [8899], "xmap;": [10236], "xnis;": [8955], "xopf;": [120169], "xscr;": [120013], "xvee;": [8897], "yacy;": [1103], "yicy;": [1111], "yopf;": [120170], "yscr;": [120014], "yucy;": [1102], "yuml;": [255], "zdot;": [380], "zeta;": [950], "zhcy;": [1078], "zopf;": [120171], "zscr;": [120015], "zwnj;": [8204] } }, { "length": 4, "entities": { "AMP;": [38], "Acy;": [1040], "Afr;": [120068], "And;": [10835], "Auml": [196], "Bcy;": [1041], "Bfr;": [120069], "COPY": [169], "Cap;": [8914], "Cfr;": [8493], "Chi;": [935], "Cup;": [8915], "Dcy;": [1044], "Del;": [8711], "Dfr;": [120071], "Dot;": [168], "ENG;": [330], "ETH;": [208], "Ecy;": [1069], "Efr;": [120072], "Eta;": [919], "Euml": [203], "Fcy;": [1060], "Ffr;": [120073], "Gcy;": [1043], "Gfr;": [120074], "Hat;": [94], "Hfr;": [8460], "Icy;": [1048], "Ifr;": [8465], "Int;": [8748], "Iuml": [207], "Jcy;": [1049], "Jfr;": [120077], "Kcy;": [1050], "Kfr;": [120078], "Lcy;": [1051], "Lfr;": [120079], "Lsh;": [8624], "Map;": [10501], "Mcy;": [1052], "Mfr;": [120080], "Ncy;": [1053], "Nfr;": [120081], "Not;": [10988], "Ocy;": [1054], "Ofr;": [120082], "Ouml": [214], "Pcy;": [1055], "Pfr;": [120083], "Phi;": [934], "Psi;": [936], "QUOT": [34], "Qfr;": [120084], "REG;": [174], "Rcy;": [1056], "Rfr;": [8476], "Rho;": [929], "Rsh;": [8625], "Scy;": [1057], "Sfr;": [120086], "Sub;": [8912], "Sum;": [8721], "Sup;": [8913], "Tab;": [9], "Tau;": [932], "Tcy;": [1058], "Tfr;": [120087], "Ucy;": [1059], "Ufr;": [120088], "Uuml": [220], "Vcy;": [1042], "Vee;": [8897], "Vfr;": [120089], "Wfr;": [120090], "Xfr;": [120091], "Ycy;": [1067], "Yfr;": [120092], "Zcy;": [1047], "Zfr;": [8488], "acE;": [8766, 819], "acd;": [8767], "acy;": [1072], "afr;": [120094], "amp;": [38], "and;": [8743], "ang;": [8736], "apE;": [10864], "ape;": [8778], "ast;": [42], "auml": [228], "bcy;": [1073], "bfr;": [120095], "bne;": [61, 8421], "bot;": [8869], "cap;": [8745], "cent": [162], "cfr;": [120096], "chi;": [967], "cir;": [9675], "copy": [169], "cup;": [8746], "dcy;": [1076], "deg;": [176], "dfr;": [120097], "die;": [168], "div;": [247], "dot;": [729], "ecy;": [1101], "efr;": [120098], "egs;": [10902], "ell;": [8467], "els;": [10901], "eng;": [331], "eta;": [951], "eth;": [240], "euml": [235], "fcy;": [1092], "ffr;": [120099], "gEl;": [10892], "gap;": [10886], "gcy;": [1075], "gel;": [8923], "geq;": [8805], "ges;": [10878], "gfr;": [120100], "ggg;": [8921], "glE;": [10898], "gla;": [10917], "glj;": [10916], "gnE;": [8809], "gne;": [10888], "hfr;": [120101], "icy;": [1080], "iff;": [8660], "ifr;": [120102], "int;": [8747], "iuml": [239], "jcy;": [1081], "jfr;": [120103], "kcy;": [1082], "kfr;": [120104], "lEg;": [10891], "lap;": [10885], "lat;": [10923], "lcy;": [1083], "leg;": [8922], "leq;": [8804], "les;": [10877], "lfr;": [120105], "lgE;": [10897], "lnE;": [8808], "lne;": [10887], "loz;": [9674], "lrm;": [8206], "lsh;": [8624], "macr": [175], "map;": [8614], "mcy;": [1084], "mfr;": [120106], "mho;": [8487], "mid;": [8739], "nGg;": [8921, 824], "nGt;": [8811, 8402], "nLl;": [8920, 824], "nLt;": [8810, 8402], "nap;": [8777], "nbsp": [160], "ncy;": [1085], "nfr;": [120107], "ngE;": [8807, 824], "nge;": [8817], "ngt;": [8815], "nis;": [8956], "niv;": [8715], "nlE;": [8806, 824], "nle;": [8816], "nlt;": [8814], "not;": [172], "npr;": [8832], "nsc;": [8833], "num;": [35], "ocy;": [1086], "ofr;": [120108], "ogt;": [10689], "ohm;": [937], "olt;": [10688], "ord;": [10845], "ordf": [170], "ordm": [186], "orv;": [10843], "ouml": [246], "par;": [8741], "para": [182], "pcy;": [1087], "pfr;": [120109], "phi;": [966], "piv;": [982], "prE;": [10931], "pre;": [10927], "psi;": [968], "qfr;": [120110], "quot": [34], "rcy;": [1088], "reg;": [174], "rfr;": [120111], "rho;": [961], "rlm;": [8207], "rsh;": [8625], "scE;": [10932], "sce;": [10928], "scy;": [1089], "sect": [167], "sfr;": [120112], "shy;": [173], "sim;": [8764], "smt;": [10922], "sol;": [47], "squ;": [9633], "sub;": [8834], "sum;": [8721], "sup1": [185], "sup2": [178], "sup3": [179], "sup;": [8835], "tau;": [964], "tcy;": [1090], "tfr;": [120113], "top;": [8868], "ucy;": [1091], "ufr;": [120114], "uml;": [168], "uuml": [252], "vcy;": [1074], "vee;": [8744], "vfr;": [120115], "wfr;": [120116], "xfr;": [120117], "ycy;": [1099], "yen;": [165], "yfr;": [120118], "yuml": [255], "zcy;": [1079], "zfr;": [120119], "zwj;": [8205] } }, { "length": 3, "entities": { "AMP": [38], "DD;": [8517], "ETH": [208], "GT;": [62], "Gg;": [8921], "Gt;": [8811], "Im;": [8465], "LT;": [60], "Ll;": [8920], "Lt;": [8810], "Mu;": [924], "Nu;": [925], "Or;": [10836], "Pi;": [928], "Pr;": [10939], "REG": [174], "Re;": [8476], "Sc;": [10940], "Xi;": [926], "ac;": [8766], "af;": [8289], "amp": [38], "ap;": [8776], "dd;": [8518], "deg": [176], "ee;": [8519], "eg;": [10906], "el;": [10905], "eth": [240], "gE;": [8807], "ge;": [8805], "gg;": [8811], "gl;": [8823], "gt;": [62], "ic;": [8291], "ii;": [8520], "in;": [8712], "it;": [8290], "lE;": [8806], "le;": [8804], "lg;": [8822], "ll;": [8810], "lt;": [60], "mp;": [8723], "mu;": [956], "ne;": [8800], "ni;": [8715], "not": [172], "nu;": [957], "oS;": [9416], "or;": [8744], "pi;": [960], "pm;": [177], "pr;": [8826], "reg": [174], "rx;": [8478], "sc;": [8827], "shy": [173], "uml": [168], "wp;": [8472], "wr;": [8768], "xi;": [958], "yen": [165] } }, { "length": 2, "entities": { "GT": [62], "LT": [60], "gt": [62], "lt": [60] } }];
    var EOF = -1;
    var NULL = 0;
    var TABULATION = 9;
    var CARRIAGE_RETURN = 13;
    var LINE_FEED = 10;
    var FORM_FEED = 12;
    var SPACE = 32;
    var EXCLAMATION_MARK = 33;
    var QUOTATION_MARK = 34;
    var NUMBER_SIGN = 35;
    var AMPERSAND = 38;
    var APOSTROPHE = 39;
    var HYPHEN_MINUS = 45;
    var SOLIDUS = 47;
    var DIGIT_0 = 48;
    var DIGIT_9 = 57;
    var SEMICOLON = 59;
    var LESS_THAN_SIGN = 60;
    var EQUALS_SIGN = 61;
    var GREATER_THAN_SIGN = 62;
    var QUESTION_MARK = 63;
    var LATIN_CAPITAL_A = 65;
    var LATIN_CAPITAL_D = 68;
    var LATIN_CAPITAL_F = 70;
    var LATIN_CAPITAL_X = 88;
    var LATIN_CAPITAL_Z = 90;
    var LEFT_SQUARE_BRACKET = 91;
    var RIGHT_SQUARE_BRACKET = 93;
    var GRAVE_ACCENT = 96;
    var LATIN_SMALL_A = 97;
    var LATIN_SMALL_F = 102;
    var LATIN_SMALL_X = 120;
    var LATIN_SMALL_Z = 122;
    var LEFT_CURLY_BRACKET = 123;
    var RIGHT_CURLY_BRACKET = 125;
    var NULL_REPLACEMENT = 65533;
    function isWhitespace(cp) {
      return cp === TABULATION || cp === LINE_FEED || cp === FORM_FEED || cp === CARRIAGE_RETURN || cp === SPACE;
    }
    function isUpperLetter(cp) {
      return cp >= LATIN_CAPITAL_A && cp <= LATIN_CAPITAL_Z;
    }
    function isLowerLetter(cp) {
      return cp >= LATIN_SMALL_A && cp <= LATIN_SMALL_Z;
    }
    function isLetter(cp) {
      return isLowerLetter(cp) || isUpperLetter(cp);
    }
    function isDigit(cp) {
      return cp >= DIGIT_0 && cp <= DIGIT_9;
    }
    function isUpperHexDigit(cp) {
      return cp >= LATIN_CAPITAL_A && cp <= LATIN_CAPITAL_F;
    }
    function isLowerHexDigit(cp) {
      return cp >= LATIN_SMALL_A && cp <= LATIN_SMALL_F;
    }
    function isHexDigit(cp) {
      return isDigit(cp) || isUpperHexDigit(cp) || isLowerHexDigit(cp);
    }
    function isControl(cp) {
      return cp >= 0 && cp <= 31 || cp >= 127 && cp <= 159;
    }
    function isSurrogate(cp) {
      return cp >= 55296 && cp <= 57343;
    }
    function isSurrogatePair(cp) {
      return cp >= 56320 && cp <= 57343;
    }
    function isNonCharacter(cp) {
      return cp >= 64976 && cp <= 65007 || (cp & 65534) === 65534 && cp <= 1114111;
    }
    function toLowerCodePoint(cp) {
      return cp + 32;
    }
    var Tokenizer = class {
      constructor(text, parserOptions) {
        this.vExpressionScriptState = null;
        debug("[html] the source code length: %d", text.length);
        this.text = text;
        this.gaps = [];
        this.lineTerminators = [];
        this.parserOptions = parserOptions || {};
        this.lastCodePoint = NULL;
        this.offset = -1;
        this.column = -1;
        this.line = 1;
        this.state = "DATA";
        this.returnState = "DATA";
        this.reconsuming = false;
        this.buffer = [];
        this.crStartOffset = -1;
        this.crCode = 0;
        this.errors = [];
        this.committedToken = null;
        this.provisionalToken = null;
        this.currentToken = null;
        this.lastTagOpenToken = null;
        this.tokenStartOffset = -1;
        this.tokenStartColumn = -1;
        this.tokenStartLine = 1;
        this.namespace = NS.HTML;
        this.expressionEnabled = false;
      }
      nextToken() {
        let cp = this.lastCodePoint;
        while (this.committedToken == null && (cp !== EOF || this.reconsuming)) {
          if (this.provisionalToken != null && !this.isProvisionalState()) {
            this.commitProvisionalToken();
            if (this.committedToken != null) {
              break;
            }
          }
          if (this.reconsuming) {
            this.reconsuming = false;
            cp = this.lastCodePoint;
          } else {
            cp = this.consumeNextCodePoint();
          }
          debug("[html] parse", cp, this.state);
          this.state = this[this.state](cp);
        }
        {
          const token = this.consumeCommittedToken();
          if (token != null) {
            return token;
          }
        }
        assert(cp === EOF);
        if (this.currentToken != null) {
          this.endToken();
          const token = this.consumeCommittedToken();
          if (token != null) {
            return token;
          }
        }
        return this.currentToken;
      }
      consumeCommittedToken() {
        const token = this.committedToken;
        this.committedToken = null;
        return token;
      }
      consumeNextCodePoint() {
        if (this.offset >= this.text.length) {
          this.lastCodePoint = EOF;
          return EOF;
        }
        this.offset += this.lastCodePoint >= 65536 ? 2 : 1;
        if (this.offset >= this.text.length) {
          this.advanceLocation();
          this.lastCodePoint = EOF;
          return EOF;
        }
        const cp = this.text.codePointAt(this.offset);
        if (isSurrogate(this.text.charCodeAt(this.offset)) && !isSurrogatePair(this.text.charCodeAt(this.offset + 1))) {
          this.reportParseError("surrogate-in-input-stream");
        }
        if (isNonCharacter(cp)) {
          this.reportParseError("noncharacter-in-input-stream");
        }
        if (isControl(cp) && !isWhitespace(cp) && cp !== NULL) {
          this.reportParseError("control-character-in-input-stream");
        }
        if (this.lastCodePoint === CARRIAGE_RETURN && cp === LINE_FEED) {
          this.lastCodePoint = LINE_FEED;
          this.gaps.push(this.offset);
          return this.consumeNextCodePoint();
        }
        this.advanceLocation();
        this.lastCodePoint = cp;
        if (cp === CARRIAGE_RETURN) {
          return LINE_FEED;
        }
        return cp;
      }
      advanceLocation() {
        if (this.lastCodePoint === LINE_FEED) {
          this.lineTerminators.push(this.offset);
          this.line += 1;
          this.column = 0;
        } else {
          this.column += this.lastCodePoint >= 65536 ? 2 : 1;
        }
      }
      reconsumeAs(state) {
        this.reconsuming = true;
        return state;
      }
      reportParseError(code) {
        const error = ParseError.fromCode(code, this.offset, this.line, this.column);
        this.errors.push(error);
        debug("[html] syntax error:", error.message);
      }
      setStartTokenMark() {
        this.tokenStartOffset = this.offset;
        this.tokenStartLine = this.line;
        this.tokenStartColumn = this.column;
      }
      clearStartTokenMark() {
        this.tokenStartOffset = -1;
      }
      startToken(type) {
        if (this.tokenStartOffset === -1) {
          this.setStartTokenMark();
        }
        const offset = this.tokenStartOffset;
        const line = this.tokenStartLine;
        const column = this.tokenStartColumn;
        if (this.currentToken != null) {
          this.endToken();
        }
        this.tokenStartOffset = -1;
        const token = this.currentToken = {
          type,
          range: [offset, -1],
          loc: {
            start: { line, column },
            end: { line: -1, column: -1 }
          },
          value: ""
        };
        debug("[html] start token: %d %s", offset, token.type);
        return this.currentToken;
      }
      endToken() {
        if (this.currentToken == null) {
          throw new Error("Invalid state");
        }
        if (this.tokenStartOffset === -1) {
          this.setStartTokenMark();
        }
        const token = this.currentToken;
        const offset = this.tokenStartOffset;
        const line = this.tokenStartLine;
        const column = this.tokenStartColumn;
        const provisional = this.isProvisionalState();
        this.currentToken = null;
        this.tokenStartOffset = -1;
        token.range[1] = offset;
        token.loc.end.line = line;
        token.loc.end.column = column;
        if (token.range[0] === offset && !provisional) {
          debug("[html] abandon token: %j %s %j", token.range, token.type, token.value);
          return null;
        }
        if (provisional) {
          if (this.provisionalToken != null) {
            this.commitProvisionalToken();
          }
          this.provisionalToken = token;
          debug("[html] provisional-commit token: %j %s %j", token.range, token.type, token.value);
        } else {
          this.commitToken(token);
        }
        return token;
      }
      commitToken(token) {
        assert(this.committedToken == null, "Invalid state: the commited token existed already.");
        debug("[html] commit token: %j %j %s %j", token.range, token.loc, token.type, token.value);
        this.committedToken = token;
        if (token.type === "HTMLTagOpen") {
          this.lastTagOpenToken = token;
        }
      }
      isProvisionalState() {
        return this.state.startsWith("RCDATA_") || this.state.startsWith("RAWTEXT_");
      }
      commitProvisionalToken() {
        assert(this.provisionalToken != null, "Invalid state: the provisional token was not found.");
        const token = this.provisionalToken;
        this.provisionalToken = null;
        if (token.range[0] < token.range[1]) {
          this.commitToken(token);
        }
      }
      rollbackProvisionalToken() {
        assert(this.currentToken != null);
        assert(this.provisionalToken != null);
        const token = this.currentToken;
        debug("[html] rollback token: %d %s", token.range[0], token.type);
        this.currentToken = this.provisionalToken;
        this.provisionalToken = null;
      }
      appendTokenValue(cp, expected) {
        const token = this.currentToken;
        if (token == null || expected != null && token.type !== expected) {
          const msg1 = expected ? `"${expected}" type` : "any token";
          const msg2 = token ? `"${token.type}" type` : "no token";
          throw new Error(`Tokenizer: Invalid state. Expected ${msg1}, but got ${msg2}.`);
        }
        token.value += String.fromCodePoint(cp);
      }
      isAppropriateEndTagOpen() {
        return this.currentToken != null && this.lastTagOpenToken != null && this.currentToken.type === "HTMLEndTagOpen" && this.currentToken.value === this.lastTagOpenToken.value;
      }
      DATA(cp) {
        this.clearStartTokenMark();
        while (true) {
          const type = isWhitespace(cp) ? "HTMLWhitespace" : "HTMLText";
          if (this.currentToken != null && this.currentToken.type !== type) {
            this.endToken();
            return this.reconsumeAs(this.state);
          }
          if (this.currentToken == null) {
            this.startToken(type);
          }
          if (cp === AMPERSAND) {
            this.returnState = "DATA";
            return "CHARACTER_REFERENCE";
          }
          if (cp === LESS_THAN_SIGN) {
            this.setStartTokenMark();
            return "TAG_OPEN";
          }
          if (cp === LEFT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "DATA";
            return "V_EXPRESSION_START";
          }
          if (cp === RIGHT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "DATA";
            return "V_EXPRESSION_END";
          }
          if (cp === EOF) {
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
          }
          this.appendTokenValue(cp, type);
          cp = this.consumeNextCodePoint();
        }
      }
      RCDATA(cp) {
        this.clearStartTokenMark();
        while (true) {
          const type = isWhitespace(cp) ? "HTMLWhitespace" : "HTMLRCDataText";
          if (this.currentToken != null && this.currentToken.type !== type) {
            this.endToken();
            return this.reconsumeAs(this.state);
          }
          if (this.currentToken == null) {
            this.startToken(type);
          }
          if (cp === AMPERSAND) {
            this.returnState = "RCDATA";
            return "CHARACTER_REFERENCE";
          }
          if (cp === LESS_THAN_SIGN) {
            this.setStartTokenMark();
            return "RCDATA_LESS_THAN_SIGN";
          }
          if (cp === LEFT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "RCDATA";
            return "V_EXPRESSION_START";
          }
          if (cp === RIGHT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "RCDATA";
            return "V_EXPRESSION_END";
          }
          if (cp === EOF) {
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          this.appendTokenValue(cp, type);
          cp = this.consumeNextCodePoint();
        }
      }
      RAWTEXT(cp) {
        this.clearStartTokenMark();
        while (true) {
          const type = isWhitespace(cp) ? "HTMLWhitespace" : "HTMLRawText";
          if (this.currentToken != null && this.currentToken.type !== type) {
            this.endToken();
            return this.reconsumeAs(this.state);
          }
          if (this.currentToken == null) {
            this.startToken(type);
          }
          if (cp === LESS_THAN_SIGN) {
            this.setStartTokenMark();
            return "RAWTEXT_LESS_THAN_SIGN";
          }
          if (cp === LEFT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "RAWTEXT";
            return "V_EXPRESSION_START";
          }
          if (cp === RIGHT_CURLY_BRACKET && this.expressionEnabled) {
            this.setStartTokenMark();
            this.returnState = "RAWTEXT";
            return "V_EXPRESSION_END";
          }
          if (cp === EOF) {
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          this.appendTokenValue(cp, type);
          cp = this.consumeNextCodePoint();
        }
      }
      TAG_OPEN(cp) {
        if (cp === EXCLAMATION_MARK) {
          return "MARKUP_DECLARATION_OPEN";
        }
        if (cp === SOLIDUS) {
          return "END_TAG_OPEN";
        }
        if (isLetter(cp)) {
          this.startToken("HTMLTagOpen");
          return this.reconsumeAs("TAG_NAME");
        }
        if (cp === QUESTION_MARK) {
          this.reportParseError("unexpected-question-mark-instead-of-tag-name");
          this.startToken("HTMLBogusComment");
          return this.reconsumeAs("BOGUS_COMMENT");
        }
        if (cp === EOF) {
          this.clearStartTokenMark();
          this.reportParseError("eof-before-tag-name");
          this.appendTokenValue(LESS_THAN_SIGN, "HTMLText");
          return "DATA";
        }
        this.reportParseError("invalid-first-character-of-tag-name");
        this.appendTokenValue(LESS_THAN_SIGN, "HTMLText");
        return this.reconsumeAs("DATA");
      }
      END_TAG_OPEN(cp) {
        if (isLetter(cp)) {
          this.startToken("HTMLEndTagOpen");
          return this.reconsumeAs("TAG_NAME");
        }
        if (cp === GREATER_THAN_SIGN) {
          this.endToken();
          this.reportParseError("missing-end-tag-name");
          return "DATA";
        }
        if (cp === EOF) {
          this.clearStartTokenMark();
          this.reportParseError("eof-before-tag-name");
          this.appendTokenValue(LESS_THAN_SIGN, "HTMLText");
          this.appendTokenValue(SOLIDUS, "HTMLText");
          return "DATA";
        }
        this.reportParseError("invalid-first-character-of-tag-name");
        this.startToken("HTMLBogusComment");
        return this.reconsumeAs("BOGUS_COMMENT");
      }
      TAG_NAME(cp) {
        while (true) {
          if (isWhitespace(cp)) {
            this.endToken();
            return "BEFORE_ATTRIBUTE_NAME";
          }
          if (cp === SOLIDUS) {
            this.endToken();
            this.setStartTokenMark();
            return "SELF_CLOSING_START_TAG";
          }
          if (cp === GREATER_THAN_SIGN) {
            this.startToken("HTMLTagClose");
            return "DATA";
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-tag");
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          this.appendTokenValue(isUpperLetter(cp) ? toLowerCodePoint(cp) : cp, null);
          cp = this.consumeNextCodePoint();
        }
      }
      RCDATA_LESS_THAN_SIGN(cp) {
        if (cp === SOLIDUS) {
          this.buffer = [];
          return "RCDATA_END_TAG_OPEN";
        }
        this.appendTokenValue(LESS_THAN_SIGN, "HTMLRCDataText");
        return this.reconsumeAs("RCDATA");
      }
      RCDATA_END_TAG_OPEN(cp) {
        if (isLetter(cp)) {
          this.startToken("HTMLEndTagOpen");
          return this.reconsumeAs("RCDATA_END_TAG_NAME");
        }
        this.appendTokenValue(LESS_THAN_SIGN, "HTMLRCDataText");
        this.appendTokenValue(SOLIDUS, "HTMLRCDataText");
        return this.reconsumeAs("RCDATA");
      }
      RCDATA_END_TAG_NAME(cp) {
        while (true) {
          if (isWhitespace(cp) && this.isAppropriateEndTagOpen()) {
            this.endToken();
            return "BEFORE_ATTRIBUTE_NAME";
          }
          if (cp === SOLIDUS && this.isAppropriateEndTagOpen()) {
            this.endToken();
            this.setStartTokenMark();
            return "SELF_CLOSING_START_TAG";
          }
          if (cp === GREATER_THAN_SIGN && this.isAppropriateEndTagOpen()) {
            this.startToken("HTMLTagClose");
            return "DATA";
          }
          if (!isLetter(cp)) {
            this.rollbackProvisionalToken();
            this.appendTokenValue(LESS_THAN_SIGN, "HTMLRCDataText");
            this.appendTokenValue(SOLIDUS, "HTMLRCDataText");
            for (const cp1 of this.buffer) {
              this.appendTokenValue(cp1, "HTMLRCDataText");
            }
            return this.reconsumeAs("RCDATA");
          }
          this.appendTokenValue(isUpperLetter(cp) ? toLowerCodePoint(cp) : cp, "HTMLEndTagOpen");
          this.buffer.push(cp);
          cp = this.consumeNextCodePoint();
        }
      }
      RAWTEXT_LESS_THAN_SIGN(cp) {
        if (cp === SOLIDUS) {
          this.buffer = [];
          return "RAWTEXT_END_TAG_OPEN";
        }
        this.appendTokenValue(LESS_THAN_SIGN, "HTMLRawText");
        return this.reconsumeAs("RAWTEXT");
      }
      RAWTEXT_END_TAG_OPEN(cp) {
        if (isLetter(cp)) {
          this.startToken("HTMLEndTagOpen");
          return this.reconsumeAs("RAWTEXT_END_TAG_NAME");
        }
        this.appendTokenValue(LESS_THAN_SIGN, "HTMLRawText");
        this.appendTokenValue(SOLIDUS, "HTMLRawText");
        return this.reconsumeAs("RAWTEXT");
      }
      RAWTEXT_END_TAG_NAME(cp) {
        while (true) {
          if (cp === SOLIDUS && this.isAppropriateEndTagOpen()) {
            this.endToken();
            this.setStartTokenMark();
            return "SELF_CLOSING_START_TAG";
          }
          if (cp === GREATER_THAN_SIGN && this.isAppropriateEndTagOpen()) {
            this.startToken("HTMLTagClose");
            return "DATA";
          }
          if (isWhitespace(cp) && this.isAppropriateEndTagOpen()) {
            this.endToken();
            return "BEFORE_ATTRIBUTE_NAME";
          }
          if (!isLetter(cp) && !maybeValidCustomBlock.call(this, cp)) {
            this.rollbackProvisionalToken();
            this.appendTokenValue(LESS_THAN_SIGN, "HTMLRawText");
            this.appendTokenValue(SOLIDUS, "HTMLRawText");
            for (const cp1 of this.buffer) {
              this.appendTokenValue(cp1, "HTMLRawText");
            }
            return this.reconsumeAs("RAWTEXT");
          }
          this.appendTokenValue(isUpperLetter(cp) ? toLowerCodePoint(cp) : cp, "HTMLEndTagOpen");
          this.buffer.push(cp);
          cp = this.consumeNextCodePoint();
        }
        function maybeValidCustomBlock(nextCp) {
          return this.currentToken && this.lastTagOpenToken && this.lastTagOpenToken.value.startsWith(this.currentToken.value + String.fromCodePoint(nextCp));
        }
      }
      BEFORE_ATTRIBUTE_NAME(cp) {
        while (isWhitespace(cp)) {
          cp = this.consumeNextCodePoint();
        }
        if (cp === SOLIDUS || cp === GREATER_THAN_SIGN || cp === EOF) {
          return this.reconsumeAs("AFTER_ATTRIBUTE_NAME");
        }
        if (cp === EQUALS_SIGN) {
          this.reportParseError("unexpected-equals-sign-before-attribute-name");
          this.startToken("HTMLIdentifier");
          this.appendTokenValue(cp, "HTMLIdentifier");
          return "ATTRIBUTE_NAME";
        }
        this.startToken("HTMLIdentifier");
        return this.reconsumeAs("ATTRIBUTE_NAME");
      }
      ATTRIBUTE_NAME(cp) {
        while (true) {
          if (isWhitespace(cp) || cp === SOLIDUS || cp === GREATER_THAN_SIGN || cp === EOF) {
            this.endToken();
            return this.reconsumeAs("AFTER_ATTRIBUTE_NAME");
          }
          if (cp === EQUALS_SIGN) {
            this.startToken("HTMLAssociation");
            return "BEFORE_ATTRIBUTE_VALUE";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          if (cp === QUOTATION_MARK || cp === APOSTROPHE || cp === LESS_THAN_SIGN) {
            this.reportParseError("unexpected-character-in-attribute-name");
          }
          this.appendTokenValue(isUpperLetter(cp) ? toLowerCodePoint(cp) : cp, "HTMLIdentifier");
          cp = this.consumeNextCodePoint();
        }
      }
      AFTER_ATTRIBUTE_NAME(cp) {
        while (isWhitespace(cp)) {
          cp = this.consumeNextCodePoint();
        }
        if (cp === SOLIDUS) {
          this.setStartTokenMark();
          return "SELF_CLOSING_START_TAG";
        }
        if (cp === EQUALS_SIGN) {
          this.startToken("HTMLAssociation");
          return "BEFORE_ATTRIBUTE_VALUE";
        }
        if (cp === GREATER_THAN_SIGN) {
          this.startToken("HTMLTagClose");
          return "DATA";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-tag");
          return "DATA";
        }
        this.startToken("HTMLIdentifier");
        return this.reconsumeAs("ATTRIBUTE_NAME");
      }
      BEFORE_ATTRIBUTE_VALUE(cp) {
        this.endToken();
        while (isWhitespace(cp)) {
          cp = this.consumeNextCodePoint();
        }
        if (cp === GREATER_THAN_SIGN) {
          this.reportParseError("missing-attribute-value");
          this.startToken("HTMLTagClose");
          return "DATA";
        }
        this.startToken("HTMLLiteral");
        if (cp === QUOTATION_MARK) {
          return "ATTRIBUTE_VALUE_DOUBLE_QUOTED";
        }
        if (cp === APOSTROPHE) {
          return "ATTRIBUTE_VALUE_SINGLE_QUOTED";
        }
        return this.reconsumeAs("ATTRIBUTE_VALUE_UNQUOTED");
      }
      ATTRIBUTE_VALUE_DOUBLE_QUOTED(cp) {
        while (true) {
          if (cp === QUOTATION_MARK) {
            return "AFTER_ATTRIBUTE_VALUE_QUOTED";
          }
          if (cp === AMPERSAND) {
            this.returnState = "ATTRIBUTE_VALUE_DOUBLE_QUOTED";
            return "CHARACTER_REFERENCE";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-tag");
            return "DATA";
          }
          this.appendTokenValue(cp, "HTMLLiteral");
          cp = this.consumeNextCodePoint();
        }
      }
      ATTRIBUTE_VALUE_SINGLE_QUOTED(cp) {
        while (true) {
          if (cp === APOSTROPHE) {
            return "AFTER_ATTRIBUTE_VALUE_QUOTED";
          }
          if (cp === AMPERSAND) {
            this.returnState = "ATTRIBUTE_VALUE_SINGLE_QUOTED";
            return "CHARACTER_REFERENCE";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-tag");
            return "DATA";
          }
          this.appendTokenValue(cp, "HTMLLiteral");
          cp = this.consumeNextCodePoint();
        }
      }
      ATTRIBUTE_VALUE_UNQUOTED(cp) {
        while (true) {
          if (isWhitespace(cp)) {
            this.endToken();
            return "BEFORE_ATTRIBUTE_NAME";
          }
          if (cp === AMPERSAND) {
            this.returnState = "ATTRIBUTE_VALUE_UNQUOTED";
            return "CHARACTER_REFERENCE";
          }
          if (cp === GREATER_THAN_SIGN) {
            this.startToken("HTMLTagClose");
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          if (cp === QUOTATION_MARK || cp === APOSTROPHE || cp === LESS_THAN_SIGN || cp === EQUALS_SIGN || cp === GRAVE_ACCENT) {
            this.reportParseError("unexpected-character-in-unquoted-attribute-value");
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-tag");
            return "DATA";
          }
          this.appendTokenValue(cp, "HTMLLiteral");
          cp = this.consumeNextCodePoint();
        }
      }
      AFTER_ATTRIBUTE_VALUE_QUOTED(cp) {
        this.endToken();
        if (isWhitespace(cp)) {
          return "BEFORE_ATTRIBUTE_NAME";
        }
        if (cp === SOLIDUS) {
          this.setStartTokenMark();
          return "SELF_CLOSING_START_TAG";
        }
        if (cp === GREATER_THAN_SIGN) {
          this.startToken("HTMLTagClose");
          return "DATA";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-tag");
          return "DATA";
        }
        this.reportParseError("missing-whitespace-between-attributes");
        return this.reconsumeAs("BEFORE_ATTRIBUTE_NAME");
      }
      SELF_CLOSING_START_TAG(cp) {
        if (cp === GREATER_THAN_SIGN) {
          this.startToken("HTMLSelfClosingTagClose");
          return "DATA";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-tag");
          return "DATA";
        }
        this.reportParseError("unexpected-solidus-in-tag");
        this.clearStartTokenMark();
        return this.reconsumeAs("BEFORE_ATTRIBUTE_NAME");
      }
      BOGUS_COMMENT(cp) {
        while (true) {
          if (cp === GREATER_THAN_SIGN) {
            return "DATA";
          }
          if (cp === EOF) {
            return "DATA";
          }
          if (cp === NULL) {
            cp = NULL_REPLACEMENT;
          }
          this.appendTokenValue(cp, null);
          cp = this.consumeNextCodePoint();
        }
      }
      MARKUP_DECLARATION_OPEN(cp) {
        if (cp === HYPHEN_MINUS && this.text[this.offset + 1] === "-") {
          this.offset += 1;
          this.column += 1;
          this.startToken("HTMLComment");
          return "COMMENT_START";
        }
        if (cp === LATIN_CAPITAL_D && this.text.slice(this.offset + 1, this.offset + 7) === "OCTYPE") {
          this.startToken("HTMLBogusComment");
          this.appendTokenValue(cp, "HTMLBogusComment");
          return "BOGUS_COMMENT";
        }
        if (cp === LEFT_SQUARE_BRACKET && this.text.slice(this.offset + 1, this.offset + 7) === "CDATA[") {
          this.offset += 6;
          this.column += 6;
          if (this.namespace === NS.HTML) {
            this.reportParseError("cdata-in-html-content");
            this.startToken("HTMLBogusComment").value = "[CDATA[";
            return "BOGUS_COMMENT";
          }
          this.startToken("HTMLCDataText");
          return "CDATA_SECTION";
        }
        this.reportParseError("incorrectly-opened-comment");
        this.startToken("HTMLBogusComment");
        return this.reconsumeAs("BOGUS_COMMENT");
      }
      COMMENT_START(cp) {
        if (cp === HYPHEN_MINUS) {
          return "COMMENT_START_DASH";
        }
        if (cp === GREATER_THAN_SIGN) {
          this.reportParseError("abrupt-closing-of-empty-comment");
          return "DATA";
        }
        return this.reconsumeAs("COMMENT");
      }
      COMMENT_START_DASH(cp) {
        if (cp === HYPHEN_MINUS) {
          return "COMMENT_END";
        }
        if (cp === GREATER_THAN_SIGN) {
          this.reportParseError("abrupt-closing-of-empty-comment");
          return "DATA";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-comment");
          return "DATA";
        }
        this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
        return this.reconsumeAs("COMMENT");
      }
      COMMENT(cp) {
        while (true) {
          if (cp === LESS_THAN_SIGN) {
            this.appendTokenValue(LESS_THAN_SIGN, "HTMLComment");
            return "COMMENT_LESS_THAN_SIGN";
          }
          if (cp === HYPHEN_MINUS) {
            return "COMMENT_END_DASH";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
            cp = NULL_REPLACEMENT;
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-comment");
            return "DATA";
          }
          this.appendTokenValue(cp, "HTMLComment");
          cp = this.consumeNextCodePoint();
        }
      }
      COMMENT_LESS_THAN_SIGN(cp) {
        while (true) {
          if (cp === EXCLAMATION_MARK) {
            this.appendTokenValue(cp, "HTMLComment");
            return "COMMENT_LESS_THAN_SIGN_BANG";
          }
          if (cp !== LESS_THAN_SIGN) {
            return this.reconsumeAs("COMMENT");
          }
          this.appendTokenValue(cp, "HTMLComment");
          cp = this.consumeNextCodePoint();
        }
      }
      COMMENT_LESS_THAN_SIGN_BANG(cp) {
        if (cp === HYPHEN_MINUS) {
          return "COMMENT_LESS_THAN_SIGN_BANG_DASH";
        }
        return this.reconsumeAs("COMMENT");
      }
      COMMENT_LESS_THAN_SIGN_BANG_DASH(cp) {
        if (cp === HYPHEN_MINUS) {
          return "COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH";
        }
        return this.reconsumeAs("COMMENT_END_DASH");
      }
      COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH(cp) {
        if (cp !== GREATER_THAN_SIGN && cp !== EOF) {
          this.reportParseError("nested-comment");
        }
        return this.reconsumeAs("COMMENT_END");
      }
      COMMENT_END_DASH(cp) {
        if (cp === HYPHEN_MINUS) {
          return "COMMENT_END";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-comment");
          return "DATA";
        }
        this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
        return this.reconsumeAs("COMMENT");
      }
      COMMENT_END(cp) {
        while (true) {
          if (cp === GREATER_THAN_SIGN) {
            return "DATA";
          }
          if (cp === EXCLAMATION_MARK) {
            return "COMMENT_END_BANG";
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-comment");
            return "DATA";
          }
          this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
          if (cp !== HYPHEN_MINUS) {
            this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
            return this.reconsumeAs("COMMENT");
          }
          cp = this.consumeNextCodePoint();
        }
      }
      COMMENT_END_BANG(cp) {
        if (cp === HYPHEN_MINUS) {
          this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
          this.appendTokenValue(EXCLAMATION_MARK, "HTMLComment");
          return "COMMENT_END_DASH";
        }
        if (cp === GREATER_THAN_SIGN) {
          this.reportParseError("incorrectly-closed-comment");
          return "DATA";
        }
        if (cp === EOF) {
          this.reportParseError("eof-in-comment");
          return "DATA";
        }
        this.appendTokenValue(HYPHEN_MINUS, "HTMLComment");
        this.appendTokenValue(EXCLAMATION_MARK, "HTMLComment");
        return this.reconsumeAs("COMMENT");
      }
      CDATA_SECTION(cp) {
        while (true) {
          if (cp === RIGHT_SQUARE_BRACKET) {
            return "CDATA_SECTION_BRACKET";
          }
          if (cp === EOF) {
            this.reportParseError("eof-in-cdata");
            return "DATA";
          }
          this.appendTokenValue(cp, "HTMLCDataText");
          cp = this.consumeNextCodePoint();
        }
      }
      CDATA_SECTION_BRACKET(cp) {
        if (cp === RIGHT_SQUARE_BRACKET) {
          return "CDATA_SECTION_END";
        }
        this.appendTokenValue(RIGHT_SQUARE_BRACKET, "HTMLCDataText");
        return this.reconsumeAs("CDATA_SECTION");
      }
      CDATA_SECTION_END(cp) {
        while (true) {
          if (cp === GREATER_THAN_SIGN) {
            return "DATA";
          }
          if (cp !== RIGHT_SQUARE_BRACKET) {
            this.appendTokenValue(RIGHT_SQUARE_BRACKET, "HTMLCDataText");
            this.appendTokenValue(RIGHT_SQUARE_BRACKET, "HTMLCDataText");
            return this.reconsumeAs("CDATA_SECTION");
          }
          this.appendTokenValue(RIGHT_SQUARE_BRACKET, "HTMLCDataText");
          cp = this.consumeNextCodePoint();
        }
      }
      CHARACTER_REFERENCE(cp) {
        this.crStartOffset = this.offset - 1;
        this.buffer = [AMPERSAND];
        if (isWhitespace(cp) || cp === LESS_THAN_SIGN || cp === EOF) {
          return this.reconsumeAs("CHARACTER_REFERENCE_END");
        }
        if (cp === NUMBER_SIGN) {
          this.buffer.push(cp);
          return "NUMERIC_CHARACTER_REFERENCE";
        }
        return this.reconsumeAs("NAMED_CHARACTER_REFERENCE");
      }
      NAMED_CHARACTER_REFERENCE(cp) {
        for (const entitySet of entitySets) {
          const length = entitySet.length;
          const entities = entitySet.entities;
          const text = this.text.slice(this.offset, this.offset + length);
          const codepoints = entities[text];
          if (codepoints == null) {
            continue;
          }
          const semi = text.endsWith(";");
          const next = this.text.codePointAt(this.offset + 1);
          this.offset += length - 1;
          this.column += length - 1;
          if (this.returnState.startsWith("ATTR") && !semi && next != null && (next === EQUALS_SIGN || isLetter(next) || isDigit(next))) {
            for (const cp1 of text) {
              this.buffer.push(cp1.codePointAt(0));
            }
          } else {
            if (!semi) {
              this.reportParseError("missing-semicolon-after-character-reference");
            }
            this.buffer = codepoints;
          }
          return "CHARACTER_REFERENCE_END";
        }
        for (const cp0 of this.buffer) {
          this.appendTokenValue(cp0, null);
        }
        this.appendTokenValue(cp, null);
        return "AMBIGUOUS_AMPERSAND";
      }
      AMBIGUOUS_AMPERSAND(cp) {
        while (isDigit(cp) || isLetter(cp)) {
          this.appendTokenValue(cp, null);
          cp = this.consumeNextCodePoint();
        }
        if (cp === SEMICOLON) {
          this.reportParseError("unknown-named-character-reference");
        }
        return this.reconsumeAs(this.returnState);
      }
      NUMERIC_CHARACTER_REFERENCE(cp) {
        this.crCode = 0;
        if (cp === LATIN_SMALL_X || cp === LATIN_CAPITAL_X) {
          this.buffer.push(cp);
          return "HEXADEMICAL_CHARACTER_REFERENCE_START";
        }
        return this.reconsumeAs("DECIMAL_CHARACTER_REFERENCE_START");
      }
      HEXADEMICAL_CHARACTER_REFERENCE_START(cp) {
        if (isHexDigit(cp)) {
          return this.reconsumeAs("HEXADEMICAL_CHARACTER_REFERENCE");
        }
        this.reportParseError("absence-of-digits-in-numeric-character-reference");
        return this.reconsumeAs("CHARACTER_REFERENCE_END");
      }
      DECIMAL_CHARACTER_REFERENCE_START(cp) {
        if (isDigit(cp)) {
          return this.reconsumeAs("DECIMAL_CHARACTER_REFERENCE");
        }
        this.reportParseError("absence-of-digits-in-numeric-character-reference");
        return this.reconsumeAs("CHARACTER_REFERENCE_END");
      }
      HEXADEMICAL_CHARACTER_REFERENCE(cp) {
        while (true) {
          if (isDigit(cp)) {
            this.crCode = 16 * this.crCode + (cp - 48);
          } else if (isUpperHexDigit(cp)) {
            this.crCode = 16 * this.crCode + (cp - 55);
          } else if (isLowerHexDigit(cp)) {
            this.crCode = 16 * this.crCode + (cp - 87);
          } else {
            if (cp === SEMICOLON) {
              return "NUMERIC_CHARACTER_REFERENCE_END";
            }
            this.reportParseError("missing-semicolon-after-character-reference");
            return this.reconsumeAs("NUMERIC_CHARACTER_REFERENCE_END");
          }
          cp = this.consumeNextCodePoint();
        }
      }
      DECIMAL_CHARACTER_REFERENCE(cp) {
        while (true) {
          if (isDigit(cp)) {
            this.crCode = 10 * this.crCode + (cp - 48);
          } else {
            if (cp === SEMICOLON) {
              return "NUMERIC_CHARACTER_REFERENCE_END";
            }
            this.reportParseError("missing-semicolon-after-character-reference");
            return this.reconsumeAs("NUMERIC_CHARACTER_REFERENCE_END");
          }
          cp = this.consumeNextCodePoint();
        }
      }
      NUMERIC_CHARACTER_REFERENCE_END(_cp) {
        let code = this.crCode;
        if (code === 0) {
          this.reportParseError("null-character-reference");
          code = NULL_REPLACEMENT;
        } else if (code > 1114111) {
          this.reportParseError("character-reference-outside-unicode-range");
          code = NULL_REPLACEMENT;
        } else if (isSurrogate(code)) {
          this.reportParseError("surrogate-character-reference");
          code = NULL_REPLACEMENT;
        } else if (isNonCharacter(code)) {
          this.reportParseError("noncharacter-character-reference");
        } else if (code === 13 || isControl(code) && !isWhitespace(code)) {
          this.reportParseError("control-character-reference");
          code = alternativeCR.get(code) || code;
        }
        this.buffer = [code];
        return this.reconsumeAs("CHARACTER_REFERENCE_END");
      }
      CHARACTER_REFERENCE_END(_cp) {
        assert(this.currentToken != null);
        const token = this.currentToken;
        const len0 = token.value.length;
        for (const cp1 of this.buffer) {
          this.appendTokenValue(cp1, null);
        }
        const newLength = token.value.length - len0;
        for (let i = this.crStartOffset + newLength; i < this.offset; ++i) {
          this.gaps.push(i);
        }
        return this.reconsumeAs(this.returnState);
      }
      V_EXPRESSION_START(cp) {
        var _a;
        if (cp === LEFT_CURLY_BRACKET) {
          this.startToken("VExpressionStart");
          this.appendTokenValue(LEFT_CURLY_BRACKET, null);
          this.appendTokenValue(LEFT_CURLY_BRACKET, null);
          if (!((_a = this.parserOptions.vueFeatures) === null || _a === void 0 ? void 0 : _a.interpolationAsNonHTML)) {
            return this.returnState;
          }
          const closeIndex = this.text.indexOf("}}", this.offset + 1);
          if (closeIndex === -1) {
            this.reportParseError("x-missing-interpolation-end");
            return this.returnState;
          }
          this.vExpressionScriptState = {
            state: this.returnState
          };
          return "V_EXPRESSION_DATA";
        }
        this.appendTokenValue(LEFT_CURLY_BRACKET, null);
        return this.reconsumeAs(this.returnState);
      }
      V_EXPRESSION_DATA(cp) {
        this.clearStartTokenMark();
        const state = this.vExpressionScriptState.state;
        while (true) {
          const type = isWhitespace(cp) ? "HTMLWhitespace" : state === "RCDATA" ? "HTMLRawText" : state === "RAWTEXT" ? "HTMLRCDataText" : "HTMLText";
          if (this.currentToken != null && this.currentToken.type !== type) {
            this.endToken();
            return this.reconsumeAs(this.state);
          }
          if (this.currentToken == null) {
            this.startToken(type);
          }
          if (cp === AMPERSAND && state !== "RAWTEXT") {
            this.returnState = "V_EXPRESSION_DATA";
            return "CHARACTER_REFERENCE";
          }
          if (cp === RIGHT_CURLY_BRACKET) {
            this.setStartTokenMark();
            this.returnState = "V_EXPRESSION_DATA";
            return "V_EXPRESSION_END";
          }
          if (cp === EOF) {
            this.reportParseError("x-missing-interpolation-end");
            return "DATA";
          }
          if (cp === NULL) {
            this.reportParseError("unexpected-null-character");
          }
          this.appendTokenValue(cp, type);
          cp = this.consumeNextCodePoint();
        }
      }
      V_EXPRESSION_END(cp) {
        if (cp === RIGHT_CURLY_BRACKET) {
          this.startToken("VExpressionEnd");
          this.appendTokenValue(RIGHT_CURLY_BRACKET, null);
          this.appendTokenValue(RIGHT_CURLY_BRACKET, null);
          return this.vExpressionScriptState ? this.vExpressionScriptState.state : this.returnState;
        }
        this.appendTokenValue(RIGHT_CURLY_BRACKET, null);
        return this.reconsumeAs(this.returnState);
      }
    };
    function getPossibleTypes(parsedSelector) {
      switch (parsedSelector.type) {
        case "identifier":
          return [parsedSelector.value];
        case "matches": {
          const typesForComponents = parsedSelector.selectors.map(getPossibleTypes);
          if (typesForComponents.every(Boolean)) {
            return union(...typesForComponents);
          }
          return null;
        }
        case "compound": {
          const typesForComponents = parsedSelector.selectors.map(getPossibleTypes).filter(Boolean);
          if (!typesForComponents.length) {
            return null;
          }
          return intersection(...typesForComponents);
        }
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return getPossibleTypes(parsedSelector.right);
        default:
          return null;
      }
    }
    function countClassAttributes(parsedSelector) {
      switch (parsedSelector.type) {
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return countClassAttributes(parsedSelector.left) + countClassAttributes(parsedSelector.right);
        case "compound":
        case "not":
        case "matches":
          return parsedSelector.selectors.reduce((sum, childSelector) => sum + countClassAttributes(childSelector), 0);
        case "attribute":
        case "field":
        case "nth-child":
        case "nth-last-child":
          return 1;
        default:
          return 0;
      }
    }
    function countIdentifiers(parsedSelector) {
      switch (parsedSelector.type) {
        case "child":
        case "descendant":
        case "sibling":
        case "adjacent":
          return countIdentifiers(parsedSelector.left) + countIdentifiers(parsedSelector.right);
        case "compound":
        case "not":
        case "matches":
          return parsedSelector.selectors.reduce((sum, childSelector) => sum + countIdentifiers(childSelector), 0);
        case "identifier":
          return 1;
        default:
          return 0;
      }
    }
    function compareSpecificity(selectorA, selectorB) {
      return selectorA.attributeCount - selectorB.attributeCount || selectorA.identifierCount - selectorB.identifierCount || (selectorA.rawSelector <= selectorB.rawSelector ? -1 : 1);
    }
    function tryParseSelector(rawSelector) {
      try {
        return esquery.parse(rawSelector.replace(/:exit$/, ""));
      } catch (err) {
        if (typeof err.offset === "number") {
          throw new Error(`Syntax error in selector "${rawSelector}" at position ${err.offset}: ${err.message}`);
        }
        throw err;
      }
    }
    var parseSelector = memoize((rawSelector) => {
      const parsedSelector = tryParseSelector(rawSelector);
      return {
        rawSelector,
        isExit: rawSelector.endsWith(":exit"),
        parsedSelector,
        listenerTypes: getPossibleTypes(parsedSelector),
        attributeCount: countClassAttributes(parsedSelector),
        identifierCount: countIdentifiers(parsedSelector)
      };
    });
    var NodeEventGenerator = class {
      constructor(emitter, esqueryOptions) {
        this.emitter = emitter;
        this.esqueryOptions = esqueryOptions;
        this.currentAncestry = [];
        this.enterSelectorsByNodeType = /* @__PURE__ */ new Map();
        this.exitSelectorsByNodeType = /* @__PURE__ */ new Map();
        this.anyTypeEnterSelectors = [];
        this.anyTypeExitSelectors = [];
        const eventNames = typeof emitter.eventNames === "function" ? emitter.eventNames() : Object.keys(emitter._events);
        for (const rawSelector of eventNames) {
          if (typeof rawSelector === "symbol") {
            continue;
          }
          const selector = parseSelector(rawSelector);
          if (selector.listenerTypes) {
            for (const nodeType of selector.listenerTypes) {
              const typeMap = selector.isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType;
              let selectors = typeMap.get(nodeType);
              if (selectors == null) {
                typeMap.set(nodeType, selectors = []);
              }
              selectors.push(selector);
            }
          } else {
            (selector.isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors).push(selector);
          }
        }
        this.anyTypeEnterSelectors.sort(compareSpecificity);
        this.anyTypeExitSelectors.sort(compareSpecificity);
        for (const selectorList of this.enterSelectorsByNodeType.values()) {
          selectorList.sort(compareSpecificity);
        }
        for (const selectorList of this.exitSelectorsByNodeType.values()) {
          selectorList.sort(compareSpecificity);
        }
      }
      applySelector(node, selector) {
        if (esquery.matches(node, selector.parsedSelector, this.currentAncestry, this.esqueryOptions)) {
          this.emitter.emit(selector.rawSelector, node);
        }
      }
      applySelectors(node, isExit) {
        const selectorsByNodeType = (isExit ? this.exitSelectorsByNodeType : this.enterSelectorsByNodeType).get(node.type) || [];
        const anyTypeSelectors = isExit ? this.anyTypeExitSelectors : this.anyTypeEnterSelectors;
        let selectorsByTypeIndex = 0;
        let anyTypeSelectorsIndex = 0;
        while (selectorsByTypeIndex < selectorsByNodeType.length || anyTypeSelectorsIndex < anyTypeSelectors.length) {
          if (selectorsByTypeIndex >= selectorsByNodeType.length || anyTypeSelectorsIndex < anyTypeSelectors.length && compareSpecificity(anyTypeSelectors[anyTypeSelectorsIndex], selectorsByNodeType[selectorsByTypeIndex]) < 0) {
            this.applySelector(node, anyTypeSelectors[anyTypeSelectorsIndex++]);
          } else {
            this.applySelector(node, selectorsByNodeType[selectorsByTypeIndex++]);
          }
        }
      }
      enterNode(node) {
        if (node.parent) {
          this.currentAncestry.unshift(node.parent);
        }
        this.applySelectors(node, false);
      }
      leaveNode(node) {
        this.applySelectors(node, true);
        this.currentAncestry.shift();
      }
    };
    function getStartLocation(token) {
      return token.range[0];
    }
    function search(tokens, location) {
      return sortedIndexBy(tokens, { range: [location] }, getStartLocation);
    }
    function getFirstIndex(tokens, indexMap, startLoc) {
      if (startLoc in indexMap) {
        return indexMap[startLoc];
      }
      if (startLoc - 1 in indexMap) {
        const index2 = indexMap[startLoc - 1];
        const token = index2 >= 0 && index2 < tokens.length ? tokens[index2] : null;
        if (token && token.range[0] >= startLoc) {
          return index2;
        }
        return index2 + 1;
      }
      return 0;
    }
    function getLastIndex(tokens, indexMap, endLoc) {
      if (endLoc in indexMap) {
        return indexMap[endLoc] - 1;
      }
      if (endLoc - 1 in indexMap) {
        const index2 = indexMap[endLoc - 1];
        const token = index2 >= 0 && index2 < tokens.length ? tokens[index2] : null;
        if (token && token.range[1] > endLoc) {
          return index2 - 1;
        }
        return index2;
      }
      return tokens.length - 1;
    }
    var Cursor = class {
      constructor() {
        this.current = null;
      }
      getOneToken() {
        return this.moveNext() ? this.current : null;
      }
      getAllTokens() {
        const tokens = [];
        while (this.moveNext()) {
          tokens.push(this.current);
        }
        return tokens;
      }
    };
    var BackwardTokenCommentCursor = class extends Cursor {
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.comments = comments;
        this.tokenIndex = getLastIndex(tokens, indexMap, endLoc);
        this.commentIndex = search(comments, endLoc) - 1;
        this.border = startLoc;
      }
      moveNext() {
        const token = this.tokenIndex >= 0 ? this.tokens[this.tokenIndex] : null;
        const comment = this.commentIndex >= 0 ? this.comments[this.commentIndex] : null;
        if (token && (!comment || token.range[1] > comment.range[1])) {
          this.current = token;
          this.tokenIndex -= 1;
        } else if (comment) {
          this.current = comment;
          this.commentIndex -= 1;
        } else {
          this.current = null;
        }
        return this.current != null && (this.border === -1 || this.current.range[0] >= this.border);
      }
    };
    var BackwardTokenCursor = class extends Cursor {
      constructor(tokens, _comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.index = getLastIndex(tokens, indexMap, endLoc);
        this.indexEnd = getFirstIndex(tokens, indexMap, startLoc);
      }
      moveNext() {
        if (this.index >= this.indexEnd) {
          this.current = this.tokens[this.index];
          this.index -= 1;
          return true;
        }
        return false;
      }
      getOneToken() {
        return this.index >= this.indexEnd ? this.tokens[this.index] : null;
      }
    };
    var DecorativeCursor = class extends Cursor {
      constructor(cursor) {
        super();
        this.cursor = cursor;
      }
      moveNext() {
        const retv = this.cursor.moveNext();
        this.current = this.cursor.current;
        return retv;
      }
    };
    var FilterCursor = class extends DecorativeCursor {
      constructor(cursor, predicate) {
        super(cursor);
        this.predicate = predicate;
      }
      moveNext() {
        const predicate = this.predicate;
        while (super.moveNext()) {
          if (predicate(this.current)) {
            return true;
          }
        }
        return false;
      }
    };
    var ForwardTokenCommentCursor = class extends Cursor {
      constructor(tokens, comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.comments = comments;
        this.tokenIndex = getFirstIndex(tokens, indexMap, startLoc);
        this.commentIndex = search(comments, startLoc);
        this.border = endLoc;
      }
      moveNext() {
        const token = this.tokenIndex < this.tokens.length ? this.tokens[this.tokenIndex] : null;
        const comment = this.commentIndex < this.comments.length ? this.comments[this.commentIndex] : null;
        if (token && (!comment || token.range[0] < comment.range[0])) {
          this.current = token;
          this.tokenIndex += 1;
        } else if (comment) {
          this.current = comment;
          this.commentIndex += 1;
        } else {
          this.current = null;
        }
        return this.current != null && (this.border === -1 || this.current.range[1] <= this.border);
      }
    };
    var ForwardTokenCursor = class extends Cursor {
      constructor(tokens, _comments, indexMap, startLoc, endLoc) {
        super();
        this.tokens = tokens;
        this.index = getFirstIndex(tokens, indexMap, startLoc);
        this.indexEnd = getLastIndex(tokens, indexMap, endLoc);
      }
      moveNext() {
        if (this.index <= this.indexEnd) {
          this.current = this.tokens[this.index];
          this.index += 1;
          return true;
        }
        return false;
      }
      getOneToken() {
        return this.index <= this.indexEnd ? this.tokens[this.index] : null;
      }
      getAllTokens() {
        return this.tokens.slice(this.index, this.indexEnd + 1);
      }
    };
    var LimitCursor = class extends DecorativeCursor {
      constructor(cursor, count) {
        super(cursor);
        this.count = count;
      }
      moveNext() {
        if (this.count > 0) {
          this.count -= 1;
          return super.moveNext();
        }
        return false;
      }
    };
    var SkipCursor = class extends DecorativeCursor {
      constructor(cursor, count) {
        super(cursor);
        this.count = count;
      }
      moveNext() {
        while (this.count > 0) {
          this.count -= 1;
          if (!super.moveNext()) {
            return false;
          }
        }
        return super.moveNext();
      }
    };
    var CursorFactory = class {
      constructor(TokenCursor, TokenCommentCursor) {
        this.TokenCursor = TokenCursor;
        this.TokenCommentCursor = TokenCommentCursor;
      }
      createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments) {
        const TokenCursor = includeComments ? this.TokenCommentCursor : this.TokenCursor;
        return new TokenCursor(tokens, comments, indexMap, startLoc, endLoc);
      }
      createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, count) {
        let cursor = this.createBaseCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments);
        if (filter) {
          cursor = new FilterCursor(cursor, filter);
        }
        if (skip >= 1) {
          cursor = new SkipCursor(cursor, skip);
        }
        if (count >= 0) {
          cursor = new LimitCursor(cursor, count);
        }
        return cursor;
      }
    };
    var forward = new CursorFactory(ForwardTokenCursor, ForwardTokenCommentCursor);
    var backward = new CursorFactory(BackwardTokenCursor, BackwardTokenCommentCursor);
    var PaddedTokenCursor = class extends ForwardTokenCursor {
      constructor(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
        super(tokens, comments, indexMap, startLoc, endLoc);
        this.index = Math.max(0, this.index - beforeCount);
        this.indexEnd = Math.min(tokens.length - 1, this.indexEnd + afterCount);
      }
    };
    function isCommentToken(token) {
      return token.type === "Line" || token.type === "Block" || token.type === "Shebang";
    }
    function createIndexMap(tokens, comments) {
      const map = /* @__PURE__ */ Object.create(null);
      let tokenIndex = 0;
      let commentIndex = 0;
      let nextStart = 0;
      let range = null;
      while (tokenIndex < tokens.length || commentIndex < comments.length) {
        nextStart = commentIndex < comments.length ? comments[commentIndex].range[0] : Number.MAX_SAFE_INTEGER;
        while (tokenIndex < tokens.length && (range = tokens[tokenIndex].range)[0] < nextStart) {
          map[range[0]] = tokenIndex;
          map[range[1] - 1] = tokenIndex;
          tokenIndex += 1;
        }
        nextStart = tokenIndex < tokens.length ? tokens[tokenIndex].range[0] : Number.MAX_SAFE_INTEGER;
        while (commentIndex < comments.length && (range = comments[commentIndex].range)[0] < nextStart) {
          map[range[0]] = tokenIndex;
          map[range[1] - 1] = tokenIndex;
          commentIndex += 1;
        }
      }
      return map;
    }
    function createCursorWithSkip(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
      let includeComments = false;
      let skip = 0;
      let filter = null;
      if (typeof opts === "number") {
        skip = opts | 0;
      } else if (typeof opts === "function") {
        filter = opts;
      } else if (opts) {
        includeComments = Boolean(opts.includeComments);
        skip = opts.skip || 0;
        filter = opts.filter || null;
      }
      assert(skip >= 0, "options.skip should be zero or a positive integer.");
      assert(!filter || typeof filter === "function", "options.filter should be a function.");
      return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, skip, -1);
    }
    function createCursorWithCount(factory, tokens, comments, indexMap, startLoc, endLoc, opts) {
      let includeComments = false;
      let count = 0;
      let countExists = false;
      let filter = null;
      if (typeof opts === "number") {
        count = opts | 0;
        countExists = true;
      } else if (typeof opts === "function") {
        filter = opts;
      } else if (opts) {
        includeComments = Boolean(opts.includeComments);
        count = opts.count || 0;
        countExists = typeof opts.count === "number";
        filter = opts.filter || null;
      }
      assert(count >= 0, "options.count should be zero or a positive integer.");
      assert(!filter || typeof filter === "function", "options.filter should be a function.");
      return factory.createCursor(tokens, comments, indexMap, startLoc, endLoc, includeComments, filter, 0, countExists ? count : -1);
    }
    function createCursorWithPadding(tokens, comments, indexMap, startLoc, endLoc, beforeCount, afterCount) {
      if (typeof beforeCount === "undefined" && typeof afterCount === "undefined") {
        return new ForwardTokenCursor(tokens, comments, indexMap, startLoc, endLoc);
      }
      if (typeof beforeCount === "number" || typeof beforeCount === "undefined") {
        return new PaddedTokenCursor(tokens, comments, indexMap, startLoc, endLoc, beforeCount || 0, afterCount || 0);
      }
      return createCursorWithCount(forward, tokens, comments, indexMap, startLoc, endLoc, beforeCount);
    }
    function getAdjacentCommentTokensFromCursor(cursor) {
      const tokens = [];
      let currentToken = cursor.getOneToken();
      while (currentToken && isCommentToken(currentToken)) {
        tokens.push(currentToken);
        currentToken = cursor.getOneToken();
      }
      return tokens;
    }
    var TokenStore = class {
      constructor(tokens, comments) {
        this._tokens = tokens;
        this._comments = comments;
        this._indexMap = createIndexMap(tokens, comments);
      }
      getTokenByRangeStart(offset, options) {
        const includeComments = Boolean(options && options.includeComments);
        const token = forward.createBaseCursor(this._tokens, this._comments, this._indexMap, offset, -1, includeComments).getOneToken();
        if (token && token.range[0] === offset) {
          return token;
        }
        return null;
      }
      getFirstToken(node, options) {
        return createCursorWithSkip(forward, this._tokens, this._comments, this._indexMap, node.range[0], node.range[1], options).getOneToken();
      }
      getLastToken(node, options) {
        return createCursorWithSkip(backward, this._tokens, this._comments, this._indexMap, node.range[0], node.range[1], options).getOneToken();
      }
      getTokenBefore(node, options) {
        return createCursorWithSkip(backward, this._tokens, this._comments, this._indexMap, -1, node.range[0], options).getOneToken();
      }
      getTokenAfter(node, options) {
        return createCursorWithSkip(forward, this._tokens, this._comments, this._indexMap, node.range[1], -1, options).getOneToken();
      }
      getFirstTokenBetween(left, right, options) {
        return createCursorWithSkip(forward, this._tokens, this._comments, this._indexMap, left.range[1], right.range[0], options).getOneToken();
      }
      getLastTokenBetween(left, right, options) {
        return createCursorWithSkip(backward, this._tokens, this._comments, this._indexMap, left.range[1], right.range[0], options).getOneToken();
      }
      getTokenOrCommentBefore(node, skip) {
        return this.getTokenBefore(node, { includeComments: true, skip });
      }
      getTokenOrCommentAfter(node, skip) {
        return this.getTokenAfter(node, { includeComments: true, skip });
      }
      getFirstTokens(node, options) {
        return createCursorWithCount(forward, this._tokens, this._comments, this._indexMap, node.range[0], node.range[1], options).getAllTokens();
      }
      getLastTokens(node, options) {
        return createCursorWithCount(backward, this._tokens, this._comments, this._indexMap, node.range[0], node.range[1], options).getAllTokens().reverse();
      }
      getTokensBefore(node, options) {
        return createCursorWithCount(backward, this._tokens, this._comments, this._indexMap, -1, node.range[0], options).getAllTokens().reverse();
      }
      getTokensAfter(node, options) {
        return createCursorWithCount(forward, this._tokens, this._comments, this._indexMap, node.range[1], -1, options).getAllTokens();
      }
      getFirstTokensBetween(left, right, options) {
        return createCursorWithCount(forward, this._tokens, this._comments, this._indexMap, left.range[1], right.range[0], options).getAllTokens();
      }
      getLastTokensBetween(left, right, options) {
        return createCursorWithCount(backward, this._tokens, this._comments, this._indexMap, left.range[1], right.range[0], options).getAllTokens().reverse();
      }
      getTokens(node, beforeCount, afterCount) {
        return createCursorWithPadding(this._tokens, this._comments, this._indexMap, node.range[0], node.range[1], beforeCount, afterCount).getAllTokens();
      }
      getTokensBetween(left, right, padding) {
        return createCursorWithPadding(this._tokens, this._comments, this._indexMap, left.range[1], right.range[0], padding, typeof padding === "number" ? padding : void 0).getAllTokens();
      }
      commentsExistBetween(left, right) {
        const index2 = search(this._comments, left.range[1]);
        return index2 < this._comments.length && this._comments[index2].range[1] <= right.range[0];
      }
      getCommentsBefore(nodeOrToken) {
        const cursor = createCursorWithCount(backward, this._tokens, this._comments, this._indexMap, -1, nodeOrToken.range[0], { includeComments: true });
        return getAdjacentCommentTokensFromCursor(cursor).reverse();
      }
      getCommentsAfter(nodeOrToken) {
        const cursor = createCursorWithCount(forward, this._tokens, this._comments, this._indexMap, nodeOrToken.range[1], -1, { includeComments: true });
        return getAdjacentCommentTokensFromCursor(cursor);
      }
      getCommentsInside(node) {
        return this.getTokens(node, {
          includeComments: true,
          filter: isCommentToken
        });
      }
    };
    function isVElement(node) {
      return node.type === "VElement";
    }
    function getCustomBlocks(document2) {
      return document2 ? document2.children.filter(isVElement).filter((block) => block.name !== "script" && block.name !== "template" && block.name !== "style") : [];
    }
    function parseCustomBlockElement(node, parser, globalLocationCalculator, parserOptions) {
      const text = node.children[0];
      const { code, range, loc } = text != null && text.type === "VText" ? {
        code: text.value,
        range: text.range,
        loc: text.loc
      } : {
        code: "",
        range: [
          node.startTag.range[1],
          node.endTag.range[0]
        ],
        loc: {
          start: node.startTag.loc.end,
          end: node.endTag.loc.start
        }
      };
      const locationCalculator = globalLocationCalculator.getSubCalculatorAfter(range[0]);
      try {
        return parseCustomBlockFragment(code, parser, locationCalculator, parserOptions);
      } catch (e) {
        return {
          error: e,
          ast: {
            type: "Program",
            sourceType: "module",
            loc: {
              start: Object.assign({}, loc.start),
              end: Object.assign({}, loc.end)
            },
            range: [...range],
            body: [],
            tokens: [],
            comments: []
          }
        };
      }
    }
    function parseCustomBlockFragment(code, parser, locationCalculator, parserOptions) {
      try {
        const result = parseBlock(code, parser, Object.assign({ ecmaVersion: DEFAULT_ECMA_VERSION, loc: true, range: true, raw: true, tokens: true, comment: true, eslintVisitorKeys: true, eslintScopeManager: true }, parserOptions));
        fixLocations(result, locationCalculator);
        return result;
      } catch (err) {
        const perr = ParseError.normalize(err);
        if (perr) {
          fixErrorLocation(perr, locationCalculator);
          throw perr;
        }
        throw err;
      }
    }
    function parseBlock(code, parser, parserOptions) {
      const result = typeof parser.parseForESLint === "function" ? parser.parseForESLint(code, parserOptions) : parser.parse(code, parserOptions);
      if (result.ast != null) {
        return result;
      }
      return { ast: result };
    }
    function createCustomBlockSharedContext({ text, customBlock, parsedResult, globalLocationCalculator, parserOptions }) {
      let sourceCode;
      let scopeManager;
      let currentNode;
      return {
        serCurrentNode(node) {
          currentNode = node;
        },
        context: {
          getAncestors: () => getAncestors(currentNode),
          getDeclaredVariables: (...args) => getScopeManager().getDeclaredVariables(...args),
          getScope: () => getScope(getScopeManager(), currentNode),
          markVariableAsUsed: (name) => markVariableAsUsed(getScopeManager(), currentNode, parserOptions, name),
          parserServices: Object.assign(Object.assign({ customBlock, parseCustomBlockElement(parser, options) {
            return parseCustomBlockElement(customBlock, parser, globalLocationCalculator, Object.assign(Object.assign({}, parserOptions), options));
          } }, parsedResult.services || {}), parsedResult.error ? { parseError: parsedResult.error } : {}),
          getSourceCode
        }
      };
      function getSourceCode() {
        return sourceCode || (sourceCode = new (require_api2()).SourceCode({
          text,
          ast: parsedResult.ast,
          parserServices: parsedResult.services,
          scopeManager: getScopeManager(),
          visitorKeys: parsedResult.visitorKeys
        }));
      }
      function getScopeManager() {
        if (parsedResult.scopeManager || scopeManager) {
          return parsedResult.scopeManager || scopeManager;
        }
        const ecmaVersion = getEcmaVersionIfUseEspree(parserOptions) || 2022;
        const ecmaFeatures = parserOptions.ecmaFeatures || {};
        const sourceType = parserOptions.sourceType || "script";
        scopeManager = getEslintScope().analyze(parsedResult.ast, {
          ignoreEval: true,
          nodejsScope: false,
          impliedStrict: ecmaFeatures.impliedStrict,
          ecmaVersion,
          sourceType,
          fallback: getFallbackKeys
        });
        return scopeManager;
      }
    }
    function getAncestors(node) {
      const ancestorsStartingAtParent = [];
      for (let ancestor = node.parent; ancestor; ancestor = ancestor.parent) {
        ancestorsStartingAtParent.push(ancestor);
      }
      return ancestorsStartingAtParent.reverse();
    }
    function getScope(scopeManager, currentNode) {
      const inner = currentNode.type !== "Program";
      for (let node = currentNode; node; node = node.parent || null) {
        const scope = scopeManager.acquire(node, inner);
        if (scope) {
          if (scope.type === "function-expression-name") {
            return scope.childScopes[0];
          }
          return scope;
        }
      }
      return scopeManager.scopes[0];
    }
    function markVariableAsUsed(scopeManager, currentNode, parserOptions, name) {
      const hasGlobalReturn = parserOptions.ecmaFeatures && parserOptions.ecmaFeatures.globalReturn;
      const specialScope = hasGlobalReturn || parserOptions.sourceType === "module";
      const currentScope = getScope(scopeManager, currentNode);
      const initialScope = currentScope.type === "global" && specialScope ? currentScope.childScopes[0] : currentScope;
      for (let scope = initialScope; scope; scope = scope.upper) {
        const variable = scope.variables.find((scopeVar) => scopeVar.name === name);
        if (variable) {
          variable.eslintUsed = true;
          return true;
        }
      }
      return false;
    }
    function define2(sourceText, rootAST, document2, globalLocationCalculator, { parserOptions }) {
      const templateBodyEmitters = /* @__PURE__ */ new Map();
      const stores = /* @__PURE__ */ new WeakMap();
      const customBlocksEmitters = /* @__PURE__ */ new Map();
      const isSFC = isSFCFile(parserOptions);
      return {
        defineTemplateBodyVisitor(templateBodyVisitor, scriptVisitor, options) {
          var _a;
          if (scriptVisitor == null) {
            scriptVisitor = {};
          }
          if (rootAST.templateBody == null) {
            return scriptVisitor;
          }
          const templateBodyTriggerSelector = (_a = options === null || options === void 0 ? void 0 : options.templateBodyTriggerSelector) !== null && _a !== void 0 ? _a : "Program:exit";
          let emitter = templateBodyEmitters.get(templateBodyTriggerSelector);
          if (emitter == null) {
            emitter = new EventEmitter();
            emitter.setMaxListeners(0);
            templateBodyEmitters.set(templateBodyTriggerSelector, emitter);
            const programExitHandler = scriptVisitor[templateBodyTriggerSelector];
            scriptVisitor[templateBodyTriggerSelector] = (node) => {
              try {
                if (typeof programExitHandler === "function") {
                  programExitHandler(node);
                }
                const generator = new NodeEventGenerator(emitter, {
                  visitorKeys: KEYS,
                  fallback: getFallbackKeys
                });
                traverseNodes2(rootAST.templateBody, generator);
              } finally {
                scriptVisitor[templateBodyTriggerSelector] = programExitHandler;
                templateBodyEmitters.delete(templateBodyTriggerSelector);
              }
            };
          }
          for (const selector of Object.keys(templateBodyVisitor)) {
            emitter.on(selector, templateBodyVisitor[selector]);
          }
          return scriptVisitor;
        },
        defineCustomBlocksVisitor(context, parser, rule, scriptVisitor) {
          var _a;
          if (scriptVisitor == null) {
            scriptVisitor = {};
          }
          if (!isSFC) {
            return scriptVisitor;
          }
          parserOptions = Object.assign({}, parserOptions);
          const customBlocks = getCustomBlocks(document2).filter((block) => block.endTag && !block.startTag.attributes.some((attr) => !attr.directive && attr.key.name === "src"));
          if (!customBlocks.length || globalLocationCalculator == null) {
            return {};
          }
          const key = (_a = parser.parseForESLint) !== null && _a !== void 0 ? _a : parser.parse;
          let factories = customBlocksEmitters.get(key);
          if (factories == null) {
            factories = [];
            customBlocksEmitters.set(key, factories);
            const visitorFactories = factories;
            const programExitHandler = scriptVisitor["Program:exit"];
            scriptVisitor["Program:exit"] = (node) => {
              try {
                if (typeof programExitHandler === "function") {
                  programExitHandler(node);
                }
                for (const customBlock of customBlocks) {
                  const lang = getLang(customBlock);
                  const activeVisitorFactories = visitorFactories.filter((f) => f.test(lang, customBlock));
                  if (!activeVisitorFactories.length) {
                    continue;
                  }
                  const parsedResult = parseCustomBlockElement(customBlock, parser, globalLocationCalculator, parserOptions);
                  const { serCurrentNode, context: customBlockContext } = createCustomBlockSharedContext({
                    text: sourceText,
                    customBlock,
                    parsedResult,
                    globalLocationCalculator,
                    parserOptions
                  });
                  const emitter = new EventEmitter();
                  emitter.setMaxListeners(0);
                  for (const factory of activeVisitorFactories) {
                    const ctx = Object.assign({}, customBlockContext);
                    ctx.__proto__ = factory.context;
                    const visitor = factory.create(ctx);
                    for (const selector of Object.keys(visitor || {})) {
                      emitter.on(selector, visitor[selector]);
                    }
                  }
                  const generator = new NodeEventGenerator(emitter, {
                    visitorKeys: parsedResult.visitorKeys,
                    fallback: getFallbackKeys
                  });
                  traverseNodes2(parsedResult.ast, {
                    visitorKeys: parsedResult.visitorKeys,
                    enterNode(n) {
                      serCurrentNode(n);
                      generator.enterNode(n);
                    },
                    leaveNode(n) {
                      serCurrentNode(n);
                      generator.leaveNode(n);
                    }
                  });
                }
              } finally {
                scriptVisitor["Program:exit"] = programExitHandler;
                customBlocksEmitters.delete(key);
              }
            };
          }
          const target = rule.target;
          const test = typeof target === "function" ? target : Array.isArray(target) ? (lang) => Boolean(lang && target.includes(lang)) : (lang) => target === lang;
          factories.push({
            context,
            test,
            create: rule.create
          });
          return scriptVisitor;
        },
        getTemplateBodyTokenStore() {
          const ast = rootAST.templateBody;
          const key = ast || stores;
          let store = stores.get(key);
          if (!store) {
            store = ast != null ? new TokenStore(ast.tokens, ast.comments) : new TokenStore([], []);
            stores.set(key, store);
          }
          return store;
        },
        getDocumentFragment() {
          return document2;
        }
      };
    }
    var CodeBlocks = class {
      constructor() {
        this.remapBlocks = [];
        this.splitPunctuators = [];
        this.code = "";
      }
      get length() {
        return this.code.length;
      }
      append(codeLet, originalOffset) {
        const rangeStart = this.code.length;
        this.code += codeLet.trimRight();
        this.remapBlocks.push({
          range: [rangeStart, this.code.length],
          offset: originalOffset - rangeStart
        });
      }
      appendSplitPunctuators(punctuator) {
        this.splitPunctuators.push(this.code.length, this.code.length + 1);
        this.code += `
${punctuator}
`;
      }
      appendCodeBlocks(codeBlocks) {
        const start = this.code.length;
        this.code += codeBlocks.code;
        this.remapBlocks.push(...codeBlocks.remapBlocks.map((b) => ({
          range: [b.range[0] + start, b.range[1] + start],
          offset: b.offset - start
        })));
        this.splitPunctuators.push(...codeBlocks.splitPunctuators.map((s) => s + start));
      }
    };
    var RestoreASTCallbacks = class {
      constructor() {
        this.callbacks = [];
      }
      addCallback(originalOffsetStart, range, callback) {
        this.callbacks.push({
          range: [
            originalOffsetStart + range[0],
            originalOffsetStart + range[1]
          ],
          callback
        });
      }
      restore(program2, scriptSetupStatements, linesAndColumns) {
        if (this.callbacks.length === 0) {
          return;
        }
        const callbacks = new Set(this.callbacks);
        for (const statement of scriptSetupStatements) {
          for (const cb of callbacks) {
            if (cb.range[0] <= statement.range[0] && statement.range[1] <= cb.range[1]) {
              const restored = cb.callback(statement);
              if (restored) {
                const removeIndex = program2.body.indexOf(statement);
                if (removeIndex >= 0) {
                  program2.body.splice(removeIndex, 1);
                  program2.body.push(restored.statement);
                  program2.tokens.push(...restored.tokens);
                  restored.statement.parent = program2;
                  callbacks.delete(cb);
                  break;
                }
              }
            }
          }
        }
        if (callbacks.size) {
          const [cb] = callbacks;
          const loc = linesAndColumns.getLocFromIndex(cb.range[0]);
          throw new ParseError("Could not parse <script setup>. Failed to restore ExportNamedDeclaration.", void 0, cb.range[0], loc.line, loc.column);
        }
      }
    };
    function parseScript$1(code, parserOptions, locationCalculator) {
      try {
        return parseScript(code, parserOptions);
      } catch (err) {
        const perr = ParseError.normalize(err);
        if (perr) {
          fixErrorLocation(perr, locationCalculator);
          throw perr;
        }
        throw err;
      }
    }
    function parseScriptSetupElements(scriptSetupElement, scriptElement, code, linesAndColumns, originalParserOptions) {
      const parserOptions = getScriptSetupParserOptions(originalParserOptions);
      const scriptSetupModuleCodeBlocks = getScriptSetupModuleCodeBlocks(scriptSetupElement, scriptElement, code, linesAndColumns, parserOptions);
      if (!scriptSetupModuleCodeBlocks) {
        return parseScriptFragment("", simpleOffsetLocationCalculator(scriptSetupElement.startTag.range[1], linesAndColumns), parserOptions);
      }
      const locationCalculator = {
        getFixOffset(offset, kind) {
          const test = kind === "start" ? (block) => offset < block.range[1] : (block) => offset <= block.range[1];
          for (const block of scriptSetupModuleCodeBlocks.codeBlocks.remapBlocks) {
            if (test(block)) {
              return block.offset;
            }
          }
          return offset;
        },
        getLocFromIndex: linesAndColumns.getLocFromIndex.bind(linesAndColumns)
      };
      const result = parseScript$1(scriptSetupModuleCodeBlocks.codeBlocks.code, parserOptions, locationCalculator);
      const scriptSetupStatements = remapAST(result, scriptSetupModuleCodeBlocks);
      remapLocationAndTokens(result, scriptSetupModuleCodeBlocks, locationCalculator);
      if (scriptSetupModuleCodeBlocks.restoreASTCallbacks) {
        scriptSetupModuleCodeBlocks.restoreASTCallbacks.restore(result.ast, scriptSetupStatements, linesAndColumns);
      }
      if (result.ast.tokens != null) {
        for (const node of [scriptSetupElement, scriptElement]) {
          const startTag = node.startTag;
          const endTag = node.endTag;
          result.ast.tokens.unshift({
            type: "Punctuator",
            range: startTag.range,
            loc: startTag.loc,
            value: "<script>"
          });
          if (endTag != null) {
            result.ast.tokens.push({
              type: "Punctuator",
              range: endTag.range,
              loc: endTag.loc,
              value: "</script>"
            });
          }
        }
        result.ast.tokens.sort((a, b) => a.range[0] - b.range[0]);
      }
      result.ast.body.sort((a, b) => a.range[0] - b.range[0]);
      const programEndOffset = result.ast.body.reduce((end, node) => Math.max(end, node.range[1]), 0);
      result.ast.range[1] = programEndOffset;
      result.ast.loc.end = locationCalculator.getLocFromIndex(programEndOffset);
      if (result.ast.end != null) {
        result.ast.end = [scriptSetupElement, scriptElement].reduce((end, node) => {
          var _a, _b;
          const textNode = node.children[0];
          return Math.max(end, textNode != null && textNode.type === "VText" ? textNode.range[1] : (_b = (_a = node.endTag) === null || _a === void 0 ? void 0 : _a.range[1]) !== null && _b !== void 0 ? _b : node.range[1]);
        }, 0);
      }
      return result;
    }
    function getScriptSetupModuleCodeBlocks(scriptSetupElement, scriptElement, sfcCode, linesAndColumns, parserOptions) {
      const scriptSetupCodeBlocks = getScriptSetupCodeBlocks(scriptSetupElement, sfcCode, linesAndColumns, parserOptions);
      const textNode = scriptElement.children[0];
      if (textNode == null || textNode.type !== "VText") {
        return scriptSetupCodeBlocks;
      }
      const [scriptStartOffset, scriptEndOffset] = textNode.range;
      const codeBlocks = new CodeBlocks();
      codeBlocks.append(sfcCode.slice(scriptStartOffset, scriptEndOffset), scriptStartOffset);
      if (scriptSetupCodeBlocks == null) {
        return { codeBlocks };
      }
      codeBlocks.appendSplitPunctuators(";");
      const scriptSetupOffset = codeBlocks.length;
      codeBlocks.appendCodeBlocks(scriptSetupCodeBlocks.codeBlocks);
      return {
        codeBlocks,
        scriptSetupBlockRange: [
          scriptSetupCodeBlocks.scriptSetupBlockRange[0] + scriptSetupOffset,
          scriptSetupCodeBlocks.scriptSetupBlockRange[1] + scriptSetupOffset
        ],
        restoreASTCallbacks: scriptSetupCodeBlocks.restoreASTCallbacks
      };
    }
    function getScriptSetupCodeBlocks(node, sfcCode, linesAndColumns, parserOptions) {
      const textNode = node.children[0];
      if (textNode == null || textNode.type !== "VText") {
        return null;
      }
      const [scriptSetupStartOffset, scriptSetupEndOffset] = textNode.range;
      const scriptCode = sfcCode.slice(scriptSetupStartOffset, scriptSetupEndOffset);
      const offsetLocationCalculator = simpleOffsetLocationCalculator(scriptSetupStartOffset, linesAndColumns);
      const result = parseScript$1(scriptCode, parserOptions, offsetLocationCalculator);
      const { ast } = result;
      const importCodeBlocks = new CodeBlocks();
      const statementCodeBlocks = new CodeBlocks();
      const exportDefaultCodeBlocks = new CodeBlocks();
      const restoreASTCallbacks = new RestoreASTCallbacks();
      let astOffset = 0;
      function processAppend(codeBlocks2, start, end) {
        if (start < end) {
          codeBlocks2.append(scriptCode.slice(start, end), scriptSetupStartOffset + start);
          astOffset = end;
        }
      }
      function processStatementCodeBlock(start) {
        if (astOffset < start) {
          processAppend(statementCodeBlocks, astOffset, start);
          statementCodeBlocks.appendSplitPunctuators(";");
        }
      }
      function processModuleCodeBlock(codeBlocks2, start, end) {
        processAppend(codeBlocks2, start, end);
        codeBlocks2.appendSplitPunctuators(";");
      }
      for (const body of ast.body) {
        if (body.type === "ImportDeclaration" || body.type === "ExportAllDeclaration" || body.type === "ExportNamedDeclaration" && body.source != null) {
          const [start, end] = getNodeFullRange(body);
          processStatementCodeBlock(start);
          processModuleCodeBlock(importCodeBlocks, start, end);
        } else if (body.type === "ExportDefaultDeclaration") {
          const [start, end] = getNodeFullRange(body);
          processStatementCodeBlock(start);
          processModuleCodeBlock(exportDefaultCodeBlocks, start, end);
        } else if (body.type === "ExportNamedDeclaration") {
          const [start, end] = getNodeFullRange(body);
          processStatementCodeBlock(start);
          const tokens = ast.tokens;
          const exportTokenIndex = tokens.findIndex((t3) => t3.range[0] === body.range[0]);
          const exportToken = tokens[exportTokenIndex];
          if (exportToken && exportToken.value === "export") {
            processAppend(statementCodeBlocks, astOffset, exportToken.range[0]);
            if (body.declaration) {
              processModuleCodeBlock(statementCodeBlocks, exportToken.range[1], end);
              restoreASTCallbacks.addCallback(scriptSetupStartOffset, [start, end], (statement) => {
                if (statement.type !== body.declaration.type) {
                  return null;
                }
                fixNodeLocations(body, result.visitorKeys, offsetLocationCalculator);
                fixLocation(exportToken, offsetLocationCalculator);
                body.declaration = statement;
                statement.parent = body;
                return {
                  statement: body,
                  tokens: [exportToken]
                };
              });
            } else {
              statementCodeBlocks.appendSplitPunctuators("(");
              const restoreTokens = [exportToken];
              let startOffset = exportToken.range[1];
              for (const spec of body.specifiers) {
                if (spec.local.range[0] < spec.exported.range[0]) {
                  const localTokenIndex = tokens.findIndex((t3) => t3.range[0] === spec.local.range[0], exportTokenIndex);
                  checkToken(tokens[localTokenIndex], spec.local.name);
                  const asToken = tokens[localTokenIndex + 1];
                  checkToken(asToken, "as");
                  restoreTokens.push(asToken);
                  const exportedToken = tokens[localTokenIndex + 2];
                  checkToken(exportedToken, spec.exported.name);
                  restoreTokens.push(exportedToken);
                  processAppend(statementCodeBlocks, startOffset, asToken.range[0]);
                  processAppend(statementCodeBlocks, asToken.range[1], exportedToken.range[0]);
                  startOffset = exportedToken.range[1];
                }
              }
              processAppend(statementCodeBlocks, startOffset, end);
              statementCodeBlocks.appendSplitPunctuators(")");
              statementCodeBlocks.appendSplitPunctuators(";");
              restoreASTCallbacks.addCallback(scriptSetupStartOffset, [start, end], (statement) => {
                if (statement.type !== "ExpressionStatement" || statement.expression.type !== "ObjectExpression") {
                  return null;
                }
                const locals = [];
                for (const prop of statement.expression.properties) {
                  if (prop.type !== "Property" || prop.value.type !== "Identifier") {
                    return null;
                  }
                  locals.push(prop.value);
                }
                if (body.specifiers.length !== locals.length) {
                  return null;
                }
                const map = /* @__PURE__ */ new Map();
                for (let index2 = 0; index2 < body.specifiers.length; index2++) {
                  const spec = body.specifiers[index2];
                  const local = locals[index2];
                  if (spec.local.name !== local.name) {
                    return null;
                  }
                  map.set(spec, local);
                }
                fixNodeLocations(body, result.visitorKeys, offsetLocationCalculator);
                for (const token of restoreTokens) {
                  fixLocation(token, offsetLocationCalculator);
                }
                for (const [spec, local] of map) {
                  spec.local = local;
                  local.parent = spec;
                }
                return {
                  statement: body,
                  tokens: restoreTokens
                };
              });
            }
          } else {
            processModuleCodeBlock(statementCodeBlocks, start, end);
          }
        }
      }
      processStatementCodeBlock(scriptSetupEndOffset);
      const codeBlocks = new CodeBlocks();
      codeBlocks.appendCodeBlocks(importCodeBlocks);
      const scriptSetupBlockRangeStart = codeBlocks.length;
      codeBlocks.appendSplitPunctuators("{");
      codeBlocks.appendCodeBlocks(statementCodeBlocks);
      codeBlocks.appendSplitPunctuators("}");
      const scriptSetupBlockRangeEnd = codeBlocks.length;
      codeBlocks.appendCodeBlocks(exportDefaultCodeBlocks);
      return {
        codeBlocks,
        scriptSetupBlockRange: [
          scriptSetupBlockRangeStart,
          scriptSetupBlockRangeEnd
        ],
        restoreASTCallbacks
      };
      function getNodeFullRange(n) {
        let start = n.range[0];
        let end = n.range[1];
        traverseNodes2(n, {
          visitorKeys: result.visitorKeys,
          enterNode(c) {
            start = Math.min(start, c.range[0]);
            end = Math.max(end, c.range[1]);
          },
          leaveNode() {
          }
        });
        return [start, end];
      }
      function checkToken(token, value2) {
        if (token.value === value2) {
          return;
        }
        const perr = new ParseError(`Could not parse <script setup>. Expected "${value2}", but it was "${token.value}".`, void 0, token.range[0], token.loc.start.line, token.loc.start.column);
        fixErrorLocation(perr, offsetLocationCalculator);
        throw perr;
      }
    }
    function remapAST(result, { scriptSetupBlockRange, codeBlocks }) {
      if (!scriptSetupBlockRange) {
        return [];
      }
      let scriptSetupBlock = null;
      const scriptSetupStatements = [];
      for (let index2 = result.ast.body.length - 1; index2 >= 0; index2--) {
        const body = result.ast.body[index2];
        if (body.type === "BlockStatement") {
          if (scriptSetupBlockRange[0] <= body.range[0] && body.range[1] <= scriptSetupBlockRange[1]) {
            if (scriptSetupBlock) {
              throw new Error(`Unexpected state error: An unexpected block statement was found. ${JSON.stringify(body.loc)}`);
            }
            scriptSetupBlock = body;
            scriptSetupStatements.push(...body.body.filter((b) => !isSplitPunctuatorsEmptyStatement(b)));
            result.ast.body.splice(index2, 1, ...scriptSetupStatements);
          }
        } else if (body.type === "EmptyStatement") {
          if (isSplitPunctuatorsEmptyStatement(body)) {
            result.ast.body.splice(index2, 1);
          }
        }
      }
      if (result.scopeManager && scriptSetupBlock) {
        const blockScope = result.scopeManager.acquire(scriptSetupBlock, true);
        remapScope(result.scopeManager, blockScope);
      }
      return scriptSetupStatements;
      function isSplitPunctuatorsEmptyStatement(body) {
        return body.type === "EmptyStatement" && codeBlocks.splitPunctuators.includes(body.range[1] - 1);
      }
      function remapScope(scopeManager, blockScope) {
        const moduleScope = blockScope.upper;
        for (const reference of blockScope.references) {
          reference.from = moduleScope;
          moduleScope.references.push(reference);
        }
        for (const variable of blockScope.variables) {
          variable.scope = moduleScope;
          const alreadyVariable = moduleScope.variables.find((v) => v.name === variable.name);
          if (alreadyVariable) {
            alreadyVariable.defs.push(...variable.defs);
            alreadyVariable.identifiers.push(...variable.identifiers);
            alreadyVariable.references.push(...variable.references);
            for (const reference of variable.references) {
              reference.resolved = alreadyVariable;
            }
          } else {
            moduleScope.variables.push(variable);
            moduleScope.set.set(variable.name, variable);
          }
        }
        const upper = blockScope.upper;
        if (upper) {
          const index3 = upper.childScopes.indexOf(blockScope);
          if (index3 >= 0) {
            upper.childScopes.splice(index3, 1);
          }
        }
        const index2 = scopeManager.scopes.indexOf(blockScope);
        if (index2 >= 0) {
          scopeManager.scopes.splice(index2, 1);
        }
      }
    }
    function remapLocationAndTokens(result, { codeBlocks }, locationCalculator) {
      const tokens = result.ast.tokens || [];
      const endMap = /* @__PURE__ */ new Map();
      const buffer = [];
      for (let index2 = tokens.length - 1; index2 >= 0; index2--) {
        const token = tokens[index2];
        if (token.range[0] + 1 === token.range[1] && codeBlocks.splitPunctuators.includes(token.range[0])) {
          tokens.splice(index2, 1);
          buffer.push(token.range[1]);
          continue;
        } else {
          for (const end of buffer) {
            endMap.set(end, token.range[1]);
          }
          buffer.length = 0;
        }
      }
      traverseNodes2(result.ast, {
        visitorKeys: result.visitorKeys,
        enterNode(node) {
          const rangeEnd = endMap.get(node.range[1]);
          if (rangeEnd != null) {
            node.range[1] = rangeEnd;
          }
          if (node.end) {
            const end = endMap.get(node.end);
            if (end != null) {
              node.end = rangeEnd;
            }
          }
        },
        leaveNode() {
        }
      });
      fixLocations(result, locationCalculator);
    }
    function simpleOffsetLocationCalculator(offset, linesAndColumns) {
      return {
        getFixOffset() {
          return offset;
        },
        getLocFromIndex: linesAndColumns.getLocFromIndex.bind(linesAndColumns)
      };
    }
    function parseStyleElements(elements, globalLocationCalculator, originalParserOptions) {
      const parserOptions = Object.assign(Object.assign({}, originalParserOptions), { ecmaVersion: originalParserOptions.ecmaVersion || DEFAULT_ECMA_VERSION });
      for (const style of elements) {
        style.style = true;
        parseStyleElement(style, globalLocationCalculator, parserOptions, {
          inlineComment: (getLang(style) || "css") !== "css"
        });
      }
    }
    function parseStyleElement(style, globalLocationCalculator, parserOptions, cssOptions) {
      if (style.children.length !== 1) {
        return;
      }
      const textNode = style.children[0];
      if (textNode.type !== "VText") {
        return;
      }
      const code = textNode.value;
      if (!code.includes("v-bind(")) {
        return;
      }
      const locationCalculator = globalLocationCalculator.getSubCalculatorAfter(textNode.range[0]);
      const document2 = getOwnerDocument(style);
      parseStyle(document2, style, code, locationCalculator, parserOptions, cssOptions);
    }
    function parseStyle(document2, style, code, locationCalculator, parserOptions, cssOptions) {
      let textStart = 0;
      for (const { range, expr, exprOffset, quote, comments } of iterateVBind(code, cssOptions)) {
        insertComments(document2, comments.map((c) => createSimpleToken(c.type, locationCalculator.getOffsetWithGap(c.range[0]), locationCalculator.getOffsetWithGap(c.range[1]), c.value, locationCalculator)));
        const container = {
          type: "VExpressionContainer",
          range: [
            locationCalculator.getOffsetWithGap(range[0]),
            locationCalculator.getOffsetWithGap(range[1])
          ],
          loc: {
            start: locationCalculator.getLocation(range[0]),
            end: locationCalculator.getLocation(range[1])
          },
          parent: style,
          expression: null,
          references: []
        };
        const beforeTokens = [
          createSimpleToken("HTMLText", container.range[0], container.range[0] + 6, "v-bind", locationCalculator),
          createSimpleToken("Punctuator", container.range[0] + 6, container.range[0] + 7, "(", locationCalculator)
        ];
        const afterTokens = [
          createSimpleToken("Punctuator", container.range[1] - 1, container.range[1], ")", locationCalculator)
        ];
        if (quote) {
          const openStart = locationCalculator.getOffsetWithGap(exprOffset - 1);
          beforeTokens.push(createSimpleToken("Punctuator", openStart, openStart + 1, quote, locationCalculator));
          const closeStart = locationCalculator.getOffsetWithGap(exprOffset + expr.length);
          afterTokens.unshift(createSimpleToken("Punctuator", closeStart, closeStart + 1, quote, locationCalculator));
        }
        const beforeLast = beforeTokens[beforeTokens.length - 1];
        replaceAndSplitTokens(document2, {
          range: [container.range[0], beforeLast.range[1]],
          loc: { start: container.loc.start, end: beforeLast.loc.end }
        }, beforeTokens);
        const afterFirst = afterTokens[0];
        replaceAndSplitTokens(document2, {
          range: [afterFirst.range[0], container.range[1]],
          loc: { start: afterFirst.loc.start, end: container.loc.end }
        }, afterTokens);
        const lastChild = style.children[style.children.length - 1];
        style.children.push(container);
        if (lastChild.type === "VText") {
          const newTextNode = {
            type: "VText",
            range: [container.range[1], lastChild.range[1]],
            loc: {
              start: Object.assign({}, container.loc.end),
              end: Object.assign({}, lastChild.loc.end)
            },
            parent: style,
            value: code.slice(range[1])
          };
          style.children.push(newTextNode);
          lastChild.range[1] = container.range[0];
          lastChild.loc.end = Object.assign({}, container.loc.start);
          lastChild.value = code.slice(textStart, range[0]);
          textStart = range[1];
        }
        try {
          const ret = parseExpression(expr, locationCalculator.getSubCalculatorShift(exprOffset), parserOptions, { allowEmpty: false, allowFilters: false });
          if (ret.expression) {
            ret.expression.parent = container;
            container.expression = ret.expression;
            container.references = ret.references;
          }
          replaceAndSplitTokens(document2, {
            range: [beforeLast.range[1], afterFirst.range[0]],
            loc: {
              start: beforeLast.loc.end,
              end: afterFirst.loc.start
            }
          }, ret.tokens);
          insertComments(document2, ret.comments);
          for (const variable of ret.variables) {
            style.variables.push(variable);
          }
          resolveReferences(container);
        } catch (err) {
          debug("[style] Parse error: %s", err);
          if (ParseError.isParseError(err)) {
            insertError(document2, err);
          } else {
            throw err;
          }
        }
      }
    }
    function* iterateVBind(code, cssOptions) {
      const re = cssOptions.inlineComment ? /"|'|\/[*/]|\bv-bind\(/gu : /"|'|\/\*|\bv-bind\(/gu;
      let match;
      while (match = re.exec(code)) {
        const startOrVBind = match[0];
        if (startOrVBind === '"' || startOrVBind === "'") {
          re.lastIndex = skipString(code, startOrVBind, re.lastIndex);
        } else if (startOrVBind === "/*" || startOrVBind === "//") {
          re.lastIndex = skipComment(code, startOrVBind === "/*" ? "block" : "line", re.lastIndex);
        } else {
          const start = match.index;
          const arg = parseVBindArg(code, re.lastIndex, cssOptions);
          if (!arg) {
            continue;
          }
          yield {
            range: [start, arg.end],
            expr: arg.expr,
            exprOffset: arg.exprOffset,
            quote: arg.quote,
            comments: arg.comments
          };
          re.lastIndex = arg.end;
        }
      }
    }
    function parseVBindArg(code, nextIndex, cssOptions) {
      const re = cssOptions.inlineComment ? /"|'|\/[*/]|\)/gu : /"|'|\/\*|\)/gu;
      const startTokenIndex = re.lastIndex = skipSpaces(code, nextIndex);
      let match;
      const stringRanges = [];
      const comments = [];
      while (match = re.exec(code)) {
        const startOrVBind = match[0];
        if (startOrVBind === '"' || startOrVBind === "'") {
          const start = match.index;
          const end = re.lastIndex = skipString(code, startOrVBind, re.lastIndex);
          stringRanges.push([start, end]);
        } else if (startOrVBind === "/*" || startOrVBind === "//") {
          const block = startOrVBind === "/*";
          const start = match.index;
          const end = re.lastIndex = skipComment(code, block ? "block" : "line", re.lastIndex);
          comments.push({
            type: block ? "Block" : "Line",
            range: [start, end],
            value: block ? code.slice(start + 2, end - 2) : code.slice(start + 2, end - 1)
          });
        } else {
          if (stringRanges.length === 1) {
            const range = stringRanges[0];
            const exprRange = [range[0] + 1, range[1] - 1];
            return {
              expr: code.slice(...exprRange),
              exprOffset: exprRange[0],
              quote: code[range[0]],
              end: re.lastIndex,
              comments
            };
          }
          return {
            expr: code.slice(startTokenIndex, match.index).trim(),
            exprOffset: startTokenIndex,
            quote: null,
            end: re.lastIndex,
            comments: []
          };
        }
      }
      return null;
    }
    function skipString(code, quote, nextIndex) {
      for (let index2 = nextIndex; index2 < code.length; index2++) {
        const c = code[index2];
        if (c === "\\") {
          index2++;
          continue;
        }
        if (c === quote) {
          return index2 + 1;
        }
      }
      return code.length;
    }
    function skipComment(code, kind, nextIndex) {
      const closing = kind === "block" ? "*/" : "\n";
      const index2 = code.indexOf(closing, nextIndex);
      if (index2 >= nextIndex) {
        return index2 + closing.length;
      }
      return code.length;
    }
    function skipSpaces(code, nextIndex) {
      for (let index2 = nextIndex; index2 < code.length; index2++) {
        const c = code[index2];
        if (c.trim()) {
          return index2;
        }
      }
      return code.length;
    }
    var STARTS_WITH_LT = /^\s*</u;
    function isVueFile(code, options) {
      const filePath = options.filePath || "unknown.js";
      return path2.extname(filePath) === ".vue" || STARTS_WITH_LT.test(code);
    }
    function parseForESLint2(code, parserOptions) {
      var _a, _b;
      const options = Object.assign({
        comment: true,
        loc: true,
        range: true,
        tokens: true
      }, parserOptions || {});
      let result;
      let document2;
      let locationCalculator;
      if (!isVueFile(code, options)) {
        result = parseScript(code, Object.assign(Object.assign({}, options), { ecmaVersion: options.ecmaVersion || DEFAULT_ECMA_VERSION, parser: getScriptParser(options.parser, null, "script") }));
        document2 = null;
        locationCalculator = null;
      } else {
        const optionsForTemplate = Object.assign(Object.assign({}, options), { ecmaVersion: options.ecmaVersion || DEFAULT_ECMA_VERSION });
        const skipParsingScript = options.parser === false;
        const tokenizer = new Tokenizer(code, optionsForTemplate);
        const rootAST = new Parser2(tokenizer, optionsForTemplate).parse();
        locationCalculator = new LocationCalculatorForHtml(tokenizer.gaps, tokenizer.lineTerminators);
        const scripts = rootAST.children.filter(isScriptElement);
        const template = rootAST.children.find(isTemplateElement2);
        const templateLang = getLang(template) || "html";
        const concreteInfo = {
          tokens: rootAST.tokens,
          comments: rootAST.comments,
          errors: rootAST.errors
        };
        const templateBody = template != null && templateLang === "html" ? Object.assign(template, concreteInfo) : void 0;
        const scriptParser = getScriptParser(options.parser, rootAST, "script");
        let scriptSetup;
        if (skipParsingScript || !scripts.length) {
          result = parseScript("", Object.assign(Object.assign({}, options), { ecmaVersion: options.ecmaVersion || DEFAULT_ECMA_VERSION }));
        } else if (scripts.length === 2 && (scriptSetup = scripts.find(isScriptSetupElement))) {
          result = parseScriptSetupElements(scriptSetup, scripts.find((e) => e !== scriptSetup), code, new LinesAndColumns(tokenizer.lineTerminators), Object.assign(Object.assign({}, options), { parser: scriptParser }));
        } else {
          result = parseScriptElement(scripts[0], locationCalculator, Object.assign(Object.assign({}, options), { parser: scriptParser }));
        }
        if ((_b = (_a = options.vueFeatures) === null || _a === void 0 ? void 0 : _a.styleCSSVariableInjection) !== null && _b !== void 0 ? _b : true) {
          const styles = rootAST.children.filter(isStyleElement);
          parseStyleElements(styles, locationCalculator, Object.assign(Object.assign({}, options), { parser: getScriptParser(options.parser, rootAST, "template") }));
        }
        result.ast.templateBody = templateBody;
        document2 = rootAST;
      }
      result.services = Object.assign(result.services || {}, define2(code, result.ast, document2, locationCalculator, {
        parserOptions: options
      }));
      return result;
    }
    function parse3(code, options) {
      return parseForESLint2(code, options).ast;
    }
    exports.AST = index;
    exports.parse = parse3;
    exports.parseForESLint = parseForESLint2;
    exports.traverseNodes = traverseNodes2;
  }
});

// node_modules/@babel/traverse/lib/path/lib/virtual-types.js
var require_virtual_types = __commonJS({
  "node_modules/@babel/traverse/lib/path/lib/virtual-types.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.Var = exports.User = exports.Statement = exports.SpreadProperty = exports.Scope = exports.RestProperty = exports.ReferencedMemberExpression = exports.ReferencedIdentifier = exports.Referenced = exports.Pure = exports.NumericLiteralTypeAnnotation = exports.Generated = exports.ForAwaitStatement = exports.Flow = exports.Expression = exports.ExistentialTypeParam = exports.BlockScoped = exports.BindingIdentifier = void 0;
    var ReferencedIdentifier = ["Identifier", "JSXIdentifier"];
    exports.ReferencedIdentifier = ReferencedIdentifier;
    var ReferencedMemberExpression = ["MemberExpression"];
    exports.ReferencedMemberExpression = ReferencedMemberExpression;
    var BindingIdentifier = ["Identifier"];
    exports.BindingIdentifier = BindingIdentifier;
    var Statement = ["Statement"];
    exports.Statement = Statement;
    var Expression = ["Expression"];
    exports.Expression = Expression;
    var Scope = ["Scopable", "Pattern"];
    exports.Scope = Scope;
    var Referenced = null;
    exports.Referenced = Referenced;
    var BlockScoped = null;
    exports.BlockScoped = BlockScoped;
    var Var = ["VariableDeclaration"];
    exports.Var = Var;
    var User = null;
    exports.User = User;
    var Generated = null;
    exports.Generated = Generated;
    var Pure = null;
    exports.Pure = Pure;
    var Flow = ["Flow", "ImportDeclaration", "ExportDeclaration", "ImportSpecifier"];
    exports.Flow = Flow;
    var RestProperty = ["RestElement"];
    exports.RestProperty = RestProperty;
    var SpreadProperty = ["RestElement"];
    exports.SpreadProperty = SpreadProperty;
    var ExistentialTypeParam = ["ExistsTypeAnnotation"];
    exports.ExistentialTypeParam = ExistentialTypeParam;
    var NumericLiteralTypeAnnotation = ["NumberLiteralTypeAnnotation"];
    exports.NumericLiteralTypeAnnotation = NumericLiteralTypeAnnotation;
    var ForAwaitStatement = ["ForOfStatement"];
    exports.ForAwaitStatement = ForAwaitStatement;
  }
});

// node_modules/@babel/types/lib/utils/shallowEqual.js
var require_shallowEqual = __commonJS({
  "node_modules/@babel/types/lib/utils/shallowEqual.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = shallowEqual;
    function shallowEqual(actual, expected) {
      const keys3 = Object.keys(expected);
      for (const key of keys3) {
        if (actual[key] !== expected[key]) {
          return false;
        }
      }
      return true;
    }
  }
});

// node_modules/@babel/types/lib/validators/generated/index.js
var require_generated = __commonJS({
  "node_modules/@babel/types/lib/validators/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isAccessor = isAccessor;
    exports.isAnyTypeAnnotation = isAnyTypeAnnotation;
    exports.isArgumentPlaceholder = isArgumentPlaceholder;
    exports.isArrayExpression = isArrayExpression;
    exports.isArrayPattern = isArrayPattern;
    exports.isArrayTypeAnnotation = isArrayTypeAnnotation;
    exports.isArrowFunctionExpression = isArrowFunctionExpression;
    exports.isAssignmentExpression = isAssignmentExpression;
    exports.isAssignmentPattern = isAssignmentPattern;
    exports.isAwaitExpression = isAwaitExpression;
    exports.isBigIntLiteral = isBigIntLiteral;
    exports.isBinary = isBinary;
    exports.isBinaryExpression = isBinaryExpression;
    exports.isBindExpression = isBindExpression;
    exports.isBlock = isBlock;
    exports.isBlockParent = isBlockParent;
    exports.isBlockStatement = isBlockStatement2;
    exports.isBooleanLiteral = isBooleanLiteral;
    exports.isBooleanLiteralTypeAnnotation = isBooleanLiteralTypeAnnotation;
    exports.isBooleanTypeAnnotation = isBooleanTypeAnnotation;
    exports.isBreakStatement = isBreakStatement;
    exports.isCallExpression = isCallExpression2;
    exports.isCatchClause = isCatchClause;
    exports.isClass = isClass;
    exports.isClassAccessorProperty = isClassAccessorProperty;
    exports.isClassBody = isClassBody;
    exports.isClassDeclaration = isClassDeclaration;
    exports.isClassExpression = isClassExpression;
    exports.isClassImplements = isClassImplements;
    exports.isClassMethod = isClassMethod;
    exports.isClassPrivateMethod = isClassPrivateMethod;
    exports.isClassPrivateProperty = isClassPrivateProperty;
    exports.isClassProperty = isClassProperty;
    exports.isCompletionStatement = isCompletionStatement;
    exports.isConditional = isConditional;
    exports.isConditionalExpression = isConditionalExpression;
    exports.isContinueStatement = isContinueStatement;
    exports.isDebuggerStatement = isDebuggerStatement;
    exports.isDecimalLiteral = isDecimalLiteral;
    exports.isDeclaration = isDeclaration;
    exports.isDeclareClass = isDeclareClass;
    exports.isDeclareExportAllDeclaration = isDeclareExportAllDeclaration;
    exports.isDeclareExportDeclaration = isDeclareExportDeclaration;
    exports.isDeclareFunction = isDeclareFunction;
    exports.isDeclareInterface = isDeclareInterface;
    exports.isDeclareModule = isDeclareModule;
    exports.isDeclareModuleExports = isDeclareModuleExports;
    exports.isDeclareOpaqueType = isDeclareOpaqueType;
    exports.isDeclareTypeAlias = isDeclareTypeAlias;
    exports.isDeclareVariable = isDeclareVariable;
    exports.isDeclaredPredicate = isDeclaredPredicate;
    exports.isDecorator = isDecorator;
    exports.isDirective = isDirective;
    exports.isDirectiveLiteral = isDirectiveLiteral;
    exports.isDoExpression = isDoExpression;
    exports.isDoWhileStatement = isDoWhileStatement;
    exports.isEmptyStatement = isEmptyStatement;
    exports.isEmptyTypeAnnotation = isEmptyTypeAnnotation;
    exports.isEnumBody = isEnumBody;
    exports.isEnumBooleanBody = isEnumBooleanBody;
    exports.isEnumBooleanMember = isEnumBooleanMember;
    exports.isEnumDeclaration = isEnumDeclaration;
    exports.isEnumDefaultedMember = isEnumDefaultedMember;
    exports.isEnumMember = isEnumMember;
    exports.isEnumNumberBody = isEnumNumberBody;
    exports.isEnumNumberMember = isEnumNumberMember;
    exports.isEnumStringBody = isEnumStringBody;
    exports.isEnumStringMember = isEnumStringMember;
    exports.isEnumSymbolBody = isEnumSymbolBody;
    exports.isExistsTypeAnnotation = isExistsTypeAnnotation;
    exports.isExportAllDeclaration = isExportAllDeclaration;
    exports.isExportDeclaration = isExportDeclaration;
    exports.isExportDefaultDeclaration = isExportDefaultDeclaration;
    exports.isExportDefaultSpecifier = isExportDefaultSpecifier;
    exports.isExportNamedDeclaration = isExportNamedDeclaration;
    exports.isExportNamespaceSpecifier = isExportNamespaceSpecifier;
    exports.isExportSpecifier = isExportSpecifier;
    exports.isExpression = isExpression2;
    exports.isExpressionStatement = isExpressionStatement;
    exports.isExpressionWrapper = isExpressionWrapper;
    exports.isFile = isFile2;
    exports.isFlow = isFlow;
    exports.isFlowBaseAnnotation = isFlowBaseAnnotation;
    exports.isFlowDeclaration = isFlowDeclaration;
    exports.isFlowPredicate = isFlowPredicate;
    exports.isFlowType = isFlowType;
    exports.isFor = isFor;
    exports.isForInStatement = isForInStatement;
    exports.isForOfStatement = isForOfStatement;
    exports.isForStatement = isForStatement;
    exports.isForXStatement = isForXStatement;
    exports.isFunction = isFunction;
    exports.isFunctionDeclaration = isFunctionDeclaration;
    exports.isFunctionExpression = isFunctionExpression;
    exports.isFunctionParent = isFunctionParent;
    exports.isFunctionTypeAnnotation = isFunctionTypeAnnotation;
    exports.isFunctionTypeParam = isFunctionTypeParam;
    exports.isGenericTypeAnnotation = isGenericTypeAnnotation;
    exports.isIdentifier = isIdentifier2;
    exports.isIfStatement = isIfStatement;
    exports.isImmutable = isImmutable;
    exports.isImport = isImport;
    exports.isImportAttribute = isImportAttribute;
    exports.isImportDeclaration = isImportDeclaration;
    exports.isImportDefaultSpecifier = isImportDefaultSpecifier;
    exports.isImportNamespaceSpecifier = isImportNamespaceSpecifier;
    exports.isImportSpecifier = isImportSpecifier2;
    exports.isIndexedAccessType = isIndexedAccessType;
    exports.isInferredPredicate = isInferredPredicate;
    exports.isInterfaceDeclaration = isInterfaceDeclaration;
    exports.isInterfaceExtends = isInterfaceExtends;
    exports.isInterfaceTypeAnnotation = isInterfaceTypeAnnotation;
    exports.isInterpreterDirective = isInterpreterDirective;
    exports.isIntersectionTypeAnnotation = isIntersectionTypeAnnotation;
    exports.isJSX = isJSX;
    exports.isJSXAttribute = isJSXAttribute;
    exports.isJSXClosingElement = isJSXClosingElement;
    exports.isJSXClosingFragment = isJSXClosingFragment;
    exports.isJSXElement = isJSXElement2;
    exports.isJSXEmptyExpression = isJSXEmptyExpression;
    exports.isJSXExpressionContainer = isJSXExpressionContainer;
    exports.isJSXFragment = isJSXFragment;
    exports.isJSXIdentifier = isJSXIdentifier;
    exports.isJSXMemberExpression = isJSXMemberExpression;
    exports.isJSXNamespacedName = isJSXNamespacedName;
    exports.isJSXOpeningElement = isJSXOpeningElement;
    exports.isJSXOpeningFragment = isJSXOpeningFragment;
    exports.isJSXSpreadAttribute = isJSXSpreadAttribute;
    exports.isJSXSpreadChild = isJSXSpreadChild;
    exports.isJSXText = isJSXText;
    exports.isLVal = isLVal;
    exports.isLabeledStatement = isLabeledStatement;
    exports.isLiteral = isLiteral;
    exports.isLogicalExpression = isLogicalExpression;
    exports.isLoop = isLoop;
    exports.isMemberExpression = isMemberExpression;
    exports.isMetaProperty = isMetaProperty;
    exports.isMethod = isMethod;
    exports.isMiscellaneous = isMiscellaneous;
    exports.isMixedTypeAnnotation = isMixedTypeAnnotation;
    exports.isModuleDeclaration = isModuleDeclaration;
    exports.isModuleExpression = isModuleExpression;
    exports.isModuleSpecifier = isModuleSpecifier;
    exports.isNewExpression = isNewExpression;
    exports.isNoop = isNoop;
    exports.isNullLiteral = isNullLiteral;
    exports.isNullLiteralTypeAnnotation = isNullLiteralTypeAnnotation;
    exports.isNullableTypeAnnotation = isNullableTypeAnnotation;
    exports.isNumberLiteral = isNumberLiteral;
    exports.isNumberLiteralTypeAnnotation = isNumberLiteralTypeAnnotation;
    exports.isNumberTypeAnnotation = isNumberTypeAnnotation;
    exports.isNumericLiteral = isNumericLiteral;
    exports.isObjectExpression = isObjectExpression;
    exports.isObjectMember = isObjectMember;
    exports.isObjectMethod = isObjectMethod;
    exports.isObjectPattern = isObjectPattern;
    exports.isObjectProperty = isObjectProperty;
    exports.isObjectTypeAnnotation = isObjectTypeAnnotation;
    exports.isObjectTypeCallProperty = isObjectTypeCallProperty;
    exports.isObjectTypeIndexer = isObjectTypeIndexer;
    exports.isObjectTypeInternalSlot = isObjectTypeInternalSlot;
    exports.isObjectTypeProperty = isObjectTypeProperty;
    exports.isObjectTypeSpreadProperty = isObjectTypeSpreadProperty;
    exports.isOpaqueType = isOpaqueType;
    exports.isOptionalCallExpression = isOptionalCallExpression;
    exports.isOptionalIndexedAccessType = isOptionalIndexedAccessType;
    exports.isOptionalMemberExpression = isOptionalMemberExpression;
    exports.isParenthesizedExpression = isParenthesizedExpression;
    exports.isPattern = isPattern;
    exports.isPatternLike = isPatternLike;
    exports.isPipelineBareFunction = isPipelineBareFunction;
    exports.isPipelinePrimaryTopicReference = isPipelinePrimaryTopicReference;
    exports.isPipelineTopicExpression = isPipelineTopicExpression;
    exports.isPlaceholder = isPlaceholder;
    exports.isPrivate = isPrivate;
    exports.isPrivateName = isPrivateName;
    exports.isProgram = isProgram;
    exports.isProperty = isProperty;
    exports.isPureish = isPureish;
    exports.isQualifiedTypeIdentifier = isQualifiedTypeIdentifier;
    exports.isRecordExpression = isRecordExpression;
    exports.isRegExpLiteral = isRegExpLiteral;
    exports.isRegexLiteral = isRegexLiteral;
    exports.isRestElement = isRestElement;
    exports.isRestProperty = isRestProperty;
    exports.isReturnStatement = isReturnStatement2;
    exports.isScopable = isScopable;
    exports.isSequenceExpression = isSequenceExpression;
    exports.isSpreadElement = isSpreadElement;
    exports.isSpreadProperty = isSpreadProperty;
    exports.isStandardized = isStandardized;
    exports.isStatement = isStatement;
    exports.isStaticBlock = isStaticBlock;
    exports.isStringLiteral = isStringLiteral3;
    exports.isStringLiteralTypeAnnotation = isStringLiteralTypeAnnotation;
    exports.isStringTypeAnnotation = isStringTypeAnnotation;
    exports.isSuper = isSuper;
    exports.isSwitchCase = isSwitchCase;
    exports.isSwitchStatement = isSwitchStatement;
    exports.isSymbolTypeAnnotation = isSymbolTypeAnnotation;
    exports.isTSAnyKeyword = isTSAnyKeyword;
    exports.isTSArrayType = isTSArrayType;
    exports.isTSAsExpression = isTSAsExpression;
    exports.isTSBaseType = isTSBaseType;
    exports.isTSBigIntKeyword = isTSBigIntKeyword;
    exports.isTSBooleanKeyword = isTSBooleanKeyword;
    exports.isTSCallSignatureDeclaration = isTSCallSignatureDeclaration;
    exports.isTSConditionalType = isTSConditionalType;
    exports.isTSConstructSignatureDeclaration = isTSConstructSignatureDeclaration;
    exports.isTSConstructorType = isTSConstructorType;
    exports.isTSDeclareFunction = isTSDeclareFunction;
    exports.isTSDeclareMethod = isTSDeclareMethod;
    exports.isTSEntityName = isTSEntityName;
    exports.isTSEnumDeclaration = isTSEnumDeclaration;
    exports.isTSEnumMember = isTSEnumMember;
    exports.isTSExportAssignment = isTSExportAssignment;
    exports.isTSExpressionWithTypeArguments = isTSExpressionWithTypeArguments;
    exports.isTSExternalModuleReference = isTSExternalModuleReference;
    exports.isTSFunctionType = isTSFunctionType;
    exports.isTSImportEqualsDeclaration = isTSImportEqualsDeclaration;
    exports.isTSImportType = isTSImportType;
    exports.isTSIndexSignature = isTSIndexSignature;
    exports.isTSIndexedAccessType = isTSIndexedAccessType;
    exports.isTSInferType = isTSInferType;
    exports.isTSInstantiationExpression = isTSInstantiationExpression;
    exports.isTSInterfaceBody = isTSInterfaceBody;
    exports.isTSInterfaceDeclaration = isTSInterfaceDeclaration;
    exports.isTSIntersectionType = isTSIntersectionType;
    exports.isTSIntrinsicKeyword = isTSIntrinsicKeyword;
    exports.isTSLiteralType = isTSLiteralType;
    exports.isTSMappedType = isTSMappedType;
    exports.isTSMethodSignature = isTSMethodSignature;
    exports.isTSModuleBlock = isTSModuleBlock;
    exports.isTSModuleDeclaration = isTSModuleDeclaration;
    exports.isTSNamedTupleMember = isTSNamedTupleMember;
    exports.isTSNamespaceExportDeclaration = isTSNamespaceExportDeclaration;
    exports.isTSNeverKeyword = isTSNeverKeyword;
    exports.isTSNonNullExpression = isTSNonNullExpression;
    exports.isTSNullKeyword = isTSNullKeyword;
    exports.isTSNumberKeyword = isTSNumberKeyword;
    exports.isTSObjectKeyword = isTSObjectKeyword;
    exports.isTSOptionalType = isTSOptionalType;
    exports.isTSParameterProperty = isTSParameterProperty;
    exports.isTSParenthesizedType = isTSParenthesizedType;
    exports.isTSPropertySignature = isTSPropertySignature;
    exports.isTSQualifiedName = isTSQualifiedName;
    exports.isTSRestType = isTSRestType;
    exports.isTSSatisfiesExpression = isTSSatisfiesExpression;
    exports.isTSStringKeyword = isTSStringKeyword;
    exports.isTSSymbolKeyword = isTSSymbolKeyword;
    exports.isTSThisType = isTSThisType;
    exports.isTSTupleType = isTSTupleType;
    exports.isTSType = isTSType2;
    exports.isTSTypeAliasDeclaration = isTSTypeAliasDeclaration;
    exports.isTSTypeAnnotation = isTSTypeAnnotation;
    exports.isTSTypeAssertion = isTSTypeAssertion;
    exports.isTSTypeElement = isTSTypeElement;
    exports.isTSTypeLiteral = isTSTypeLiteral;
    exports.isTSTypeOperator = isTSTypeOperator;
    exports.isTSTypeParameter = isTSTypeParameter;
    exports.isTSTypeParameterDeclaration = isTSTypeParameterDeclaration;
    exports.isTSTypeParameterInstantiation = isTSTypeParameterInstantiation;
    exports.isTSTypePredicate = isTSTypePredicate;
    exports.isTSTypeQuery = isTSTypeQuery;
    exports.isTSTypeReference = isTSTypeReference;
    exports.isTSUndefinedKeyword = isTSUndefinedKeyword;
    exports.isTSUnionType = isTSUnionType;
    exports.isTSUnknownKeyword = isTSUnknownKeyword;
    exports.isTSVoidKeyword = isTSVoidKeyword;
    exports.isTaggedTemplateExpression = isTaggedTemplateExpression;
    exports.isTemplateElement = isTemplateElement2;
    exports.isTemplateLiteral = isTemplateLiteral;
    exports.isTerminatorless = isTerminatorless;
    exports.isThisExpression = isThisExpression;
    exports.isThisTypeAnnotation = isThisTypeAnnotation;
    exports.isThrowStatement = isThrowStatement;
    exports.isTopicReference = isTopicReference;
    exports.isTryStatement = isTryStatement;
    exports.isTupleExpression = isTupleExpression;
    exports.isTupleTypeAnnotation = isTupleTypeAnnotation;
    exports.isTypeAlias = isTypeAlias;
    exports.isTypeAnnotation = isTypeAnnotation;
    exports.isTypeCastExpression = isTypeCastExpression;
    exports.isTypeParameter = isTypeParameter;
    exports.isTypeParameterDeclaration = isTypeParameterDeclaration;
    exports.isTypeParameterInstantiation = isTypeParameterInstantiation;
    exports.isTypeScript = isTypeScript;
    exports.isTypeofTypeAnnotation = isTypeofTypeAnnotation;
    exports.isUnaryExpression = isUnaryExpression;
    exports.isUnaryLike = isUnaryLike;
    exports.isUnionTypeAnnotation = isUnionTypeAnnotation;
    exports.isUpdateExpression = isUpdateExpression;
    exports.isUserWhitespacable = isUserWhitespacable;
    exports.isV8IntrinsicIdentifier = isV8IntrinsicIdentifier;
    exports.isVariableDeclaration = isVariableDeclaration;
    exports.isVariableDeclarator = isVariableDeclarator2;
    exports.isVariance = isVariance;
    exports.isVoidTypeAnnotation = isVoidTypeAnnotation;
    exports.isWhile = isWhile;
    exports.isWhileStatement = isWhileStatement;
    exports.isWithStatement = isWithStatement;
    exports.isYieldExpression = isYieldExpression;
    var _shallowEqual = require_shallowEqual();
    function isArrayExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ArrayExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isAssignmentExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "AssignmentExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBinaryExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BinaryExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isInterpreterDirective(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "InterpreterDirective") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDirective(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Directive") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDirectiveLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DirectiveLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBlockStatement2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BlockStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBreakStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BreakStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isCallExpression2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "CallExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isCatchClause(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "CatchClause") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isConditionalExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ConditionalExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isContinueStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ContinueStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDebuggerStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DebuggerStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDoWhileStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DoWhileStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEmptyStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EmptyStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExpressionStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExpressionStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFile2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "File") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isForInStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ForInStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isForStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ForStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunctionDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "FunctionDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunctionExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "FunctionExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isIdentifier2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Identifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isIfStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "IfStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isLabeledStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "LabeledStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStringLiteral3(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "StringLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNumericLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NumericLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNullLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NullLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBooleanLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BooleanLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isRegExpLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "RegExpLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isLogicalExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "LogicalExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isMemberExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "MemberExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNewExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NewExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isProgram(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Program") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectMethod(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectMethod") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isRestElement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "RestElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isReturnStatement2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ReturnStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSequenceExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SequenceExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isParenthesizedExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ParenthesizedExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSwitchCase(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SwitchCase") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSwitchStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SwitchStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isThisExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ThisExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isThrowStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ThrowStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTryStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TryStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isUnaryExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "UnaryExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isUpdateExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "UpdateExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isVariableDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "VariableDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isVariableDeclarator2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "VariableDeclarator") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isWhileStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "WhileStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isWithStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "WithStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isAssignmentPattern(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "AssignmentPattern") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isArrayPattern(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ArrayPattern") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isArrowFunctionExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ArrowFunctionExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportAllDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportAllDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportDefaultDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportDefaultDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportNamedDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportNamedDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isForOfStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ForOfStatement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImportDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ImportDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImportDefaultSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ImportDefaultSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImportNamespaceSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ImportNamespaceSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImportSpecifier2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ImportSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isMetaProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "MetaProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassMethod(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassMethod") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectPattern(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectPattern") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSpreadElement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SpreadElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSuper(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Super") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTaggedTemplateExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TaggedTemplateExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTemplateElement2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TemplateElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTemplateLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TemplateLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isYieldExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "YieldExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isAwaitExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "AwaitExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImport(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Import") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBigIntLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BigIntLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportNamespaceSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportNamespaceSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isOptionalMemberExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "OptionalMemberExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isOptionalCallExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "OptionalCallExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassAccessorProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassAccessorProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassPrivateProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassPrivateProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassPrivateMethod(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassPrivateMethod") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPrivateName(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "PrivateName") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStaticBlock(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "StaticBlock") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isAnyTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "AnyTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isArrayTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ArrayTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBooleanTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BooleanTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBooleanLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BooleanLiteralTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNullLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NullLiteralTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClassImplements(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ClassImplements") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareClass(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareClass") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareFunction(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareFunction") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareInterface(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareInterface") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareModule(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareModule") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareModuleExports(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareModuleExports") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareTypeAlias(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareTypeAlias") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareOpaqueType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareOpaqueType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareVariable(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareVariable") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareExportDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareExportDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclareExportAllDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclareExportAllDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclaredPredicate(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DeclaredPredicate") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExistsTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExistsTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunctionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "FunctionTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunctionTypeParam(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "FunctionTypeParam") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isGenericTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "GenericTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isInferredPredicate(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "InferredPredicate") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isInterfaceExtends(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "InterfaceExtends") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isInterfaceDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "InterfaceDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isInterfaceTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "InterfaceTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isIntersectionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "IntersectionTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isMixedTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "MixedTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEmptyTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EmptyTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNullableTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NullableTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNumberLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NumberLiteralTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNumberTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NumberTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeInternalSlot(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeInternalSlot") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeCallProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeCallProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeIndexer(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeIndexer") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectTypeSpreadProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ObjectTypeSpreadProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isOpaqueType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "OpaqueType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isQualifiedTypeIdentifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "QualifiedTypeIdentifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStringLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "StringLiteralTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStringTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "StringTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSymbolTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SymbolTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isThisTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ThisTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTupleTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TupleTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeofTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeofTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeAlias(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeAlias") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeCastExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeCastExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeParameter(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeParameter") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeParameterDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeParameterDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeParameterInstantiation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TypeParameterInstantiation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isUnionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "UnionTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isVariance(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Variance") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isVoidTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "VoidTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumBooleanBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumBooleanBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumNumberBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumNumberBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumStringBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumStringBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumSymbolBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumSymbolBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumBooleanMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumBooleanMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumNumberMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumNumberMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumStringMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumStringMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumDefaultedMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "EnumDefaultedMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isIndexedAccessType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "IndexedAccessType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isOptionalIndexedAccessType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "OptionalIndexedAccessType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXAttribute(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXAttribute") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXClosingElement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXClosingElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXElement2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXEmptyExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXEmptyExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXExpressionContainer(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXExpressionContainer") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXSpreadChild(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXSpreadChild") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXIdentifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXIdentifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXMemberExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXMemberExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXNamespacedName(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXNamespacedName") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXOpeningElement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXOpeningElement") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXSpreadAttribute(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXSpreadAttribute") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXText(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXText") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXFragment(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXFragment") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXOpeningFragment(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXOpeningFragment") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSXClosingFragment(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "JSXClosingFragment") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNoop(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Noop") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPlaceholder(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Placeholder") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isV8IntrinsicIdentifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "V8IntrinsicIdentifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isArgumentPlaceholder(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ArgumentPlaceholder") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBindExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "BindExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImportAttribute(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ImportAttribute") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDecorator(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "Decorator") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDoExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DoExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportDefaultSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ExportDefaultSpecifier") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isRecordExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "RecordExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTupleExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TupleExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDecimalLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "DecimalLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isModuleExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "ModuleExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTopicReference(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TopicReference") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPipelineTopicExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "PipelineTopicExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPipelineBareFunction(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "PipelineBareFunction") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPipelinePrimaryTopicReference(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "PipelinePrimaryTopicReference") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSParameterProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSParameterProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSDeclareFunction(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSDeclareFunction") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSDeclareMethod(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSDeclareMethod") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSQualifiedName(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSQualifiedName") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSCallSignatureDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSCallSignatureDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSConstructSignatureDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSConstructSignatureDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSPropertySignature(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSPropertySignature") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSMethodSignature(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSMethodSignature") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSIndexSignature(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSIndexSignature") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSAnyKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSAnyKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSBooleanKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSBooleanKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSBigIntKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSBigIntKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSIntrinsicKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSIntrinsicKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNeverKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNeverKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNullKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNullKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNumberKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNumberKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSObjectKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSObjectKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSStringKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSStringKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSSymbolKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSSymbolKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSUndefinedKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSUndefinedKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSUnknownKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSUnknownKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSVoidKeyword(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSVoidKeyword") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSThisType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSThisType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSFunctionType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSFunctionType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSConstructorType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSConstructorType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeReference(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeReference") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypePredicate(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypePredicate") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeQuery(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeQuery") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSArrayType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSArrayType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTupleType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTupleType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSOptionalType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSOptionalType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSRestType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSRestType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNamedTupleMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNamedTupleMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSUnionType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSUnionType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSIntersectionType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSIntersectionType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSConditionalType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSConditionalType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSInferType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSInferType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSParenthesizedType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSParenthesizedType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeOperator(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeOperator") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSIndexedAccessType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSIndexedAccessType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSMappedType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSMappedType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSLiteralType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSLiteralType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSExpressionWithTypeArguments(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSExpressionWithTypeArguments") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSInterfaceDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSInterfaceDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSInterfaceBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSInterfaceBody") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeAliasDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeAliasDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSInstantiationExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSInstantiationExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSAsExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSAsExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSSatisfiesExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSSatisfiesExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeAssertion(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeAssertion") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSEnumDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSEnumDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSEnumMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSEnumMember") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSModuleDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSModuleDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSModuleBlock(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSModuleBlock") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSImportType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSImportType") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSImportEqualsDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSImportEqualsDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSExternalModuleReference(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSExternalModuleReference") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNonNullExpression(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNonNullExpression") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSExportAssignment(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSExportAssignment") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSNamespaceExportDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSNamespaceExportDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeAnnotation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeParameterInstantiation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeParameterInstantiation") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeParameterDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeParameterDeclaration") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeParameter(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "TSTypeParameter") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStandardized(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ArrayExpression" === nodeType || "AssignmentExpression" === nodeType || "BinaryExpression" === nodeType || "InterpreterDirective" === nodeType || "Directive" === nodeType || "DirectiveLiteral" === nodeType || "BlockStatement" === nodeType || "BreakStatement" === nodeType || "CallExpression" === nodeType || "CatchClause" === nodeType || "ConditionalExpression" === nodeType || "ContinueStatement" === nodeType || "DebuggerStatement" === nodeType || "DoWhileStatement" === nodeType || "EmptyStatement" === nodeType || "ExpressionStatement" === nodeType || "File" === nodeType || "ForInStatement" === nodeType || "ForStatement" === nodeType || "FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "Identifier" === nodeType || "IfStatement" === nodeType || "LabeledStatement" === nodeType || "StringLiteral" === nodeType || "NumericLiteral" === nodeType || "NullLiteral" === nodeType || "BooleanLiteral" === nodeType || "RegExpLiteral" === nodeType || "LogicalExpression" === nodeType || "MemberExpression" === nodeType || "NewExpression" === nodeType || "Program" === nodeType || "ObjectExpression" === nodeType || "ObjectMethod" === nodeType || "ObjectProperty" === nodeType || "RestElement" === nodeType || "ReturnStatement" === nodeType || "SequenceExpression" === nodeType || "ParenthesizedExpression" === nodeType || "SwitchCase" === nodeType || "SwitchStatement" === nodeType || "ThisExpression" === nodeType || "ThrowStatement" === nodeType || "TryStatement" === nodeType || "UnaryExpression" === nodeType || "UpdateExpression" === nodeType || "VariableDeclaration" === nodeType || "VariableDeclarator" === nodeType || "WhileStatement" === nodeType || "WithStatement" === nodeType || "AssignmentPattern" === nodeType || "ArrayPattern" === nodeType || "ArrowFunctionExpression" === nodeType || "ClassBody" === nodeType || "ClassExpression" === nodeType || "ClassDeclaration" === nodeType || "ExportAllDeclaration" === nodeType || "ExportDefaultDeclaration" === nodeType || "ExportNamedDeclaration" === nodeType || "ExportSpecifier" === nodeType || "ForOfStatement" === nodeType || "ImportDeclaration" === nodeType || "ImportDefaultSpecifier" === nodeType || "ImportNamespaceSpecifier" === nodeType || "ImportSpecifier" === nodeType || "MetaProperty" === nodeType || "ClassMethod" === nodeType || "ObjectPattern" === nodeType || "SpreadElement" === nodeType || "Super" === nodeType || "TaggedTemplateExpression" === nodeType || "TemplateElement" === nodeType || "TemplateLiteral" === nodeType || "YieldExpression" === nodeType || "AwaitExpression" === nodeType || "Import" === nodeType || "BigIntLiteral" === nodeType || "ExportNamespaceSpecifier" === nodeType || "OptionalMemberExpression" === nodeType || "OptionalCallExpression" === nodeType || "ClassProperty" === nodeType || "ClassAccessorProperty" === nodeType || "ClassPrivateProperty" === nodeType || "ClassPrivateMethod" === nodeType || "PrivateName" === nodeType || "StaticBlock" === nodeType || nodeType === "Placeholder" && ("Identifier" === node.expectedNode || "StringLiteral" === node.expectedNode || "BlockStatement" === node.expectedNode || "ClassBody" === node.expectedNode)) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExpression2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ArrayExpression" === nodeType || "AssignmentExpression" === nodeType || "BinaryExpression" === nodeType || "CallExpression" === nodeType || "ConditionalExpression" === nodeType || "FunctionExpression" === nodeType || "Identifier" === nodeType || "StringLiteral" === nodeType || "NumericLiteral" === nodeType || "NullLiteral" === nodeType || "BooleanLiteral" === nodeType || "RegExpLiteral" === nodeType || "LogicalExpression" === nodeType || "MemberExpression" === nodeType || "NewExpression" === nodeType || "ObjectExpression" === nodeType || "SequenceExpression" === nodeType || "ParenthesizedExpression" === nodeType || "ThisExpression" === nodeType || "UnaryExpression" === nodeType || "UpdateExpression" === nodeType || "ArrowFunctionExpression" === nodeType || "ClassExpression" === nodeType || "MetaProperty" === nodeType || "Super" === nodeType || "TaggedTemplateExpression" === nodeType || "TemplateLiteral" === nodeType || "YieldExpression" === nodeType || "AwaitExpression" === nodeType || "Import" === nodeType || "BigIntLiteral" === nodeType || "OptionalMemberExpression" === nodeType || "OptionalCallExpression" === nodeType || "TypeCastExpression" === nodeType || "JSXElement" === nodeType || "JSXFragment" === nodeType || "BindExpression" === nodeType || "DoExpression" === nodeType || "RecordExpression" === nodeType || "TupleExpression" === nodeType || "DecimalLiteral" === nodeType || "ModuleExpression" === nodeType || "TopicReference" === nodeType || "PipelineTopicExpression" === nodeType || "PipelineBareFunction" === nodeType || "PipelinePrimaryTopicReference" === nodeType || "TSInstantiationExpression" === nodeType || "TSAsExpression" === nodeType || "TSSatisfiesExpression" === nodeType || "TSTypeAssertion" === nodeType || "TSNonNullExpression" === nodeType || nodeType === "Placeholder" && ("Expression" === node.expectedNode || "Identifier" === node.expectedNode || "StringLiteral" === node.expectedNode)) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBinary(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BinaryExpression" === nodeType || "LogicalExpression" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isScopable(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BlockStatement" === nodeType || "CatchClause" === nodeType || "DoWhileStatement" === nodeType || "ForInStatement" === nodeType || "ForStatement" === nodeType || "FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "Program" === nodeType || "ObjectMethod" === nodeType || "SwitchStatement" === nodeType || "WhileStatement" === nodeType || "ArrowFunctionExpression" === nodeType || "ClassExpression" === nodeType || "ClassDeclaration" === nodeType || "ForOfStatement" === nodeType || "ClassMethod" === nodeType || "ClassPrivateMethod" === nodeType || "StaticBlock" === nodeType || "TSModuleBlock" === nodeType || nodeType === "Placeholder" && "BlockStatement" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBlockParent(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BlockStatement" === nodeType || "CatchClause" === nodeType || "DoWhileStatement" === nodeType || "ForInStatement" === nodeType || "ForStatement" === nodeType || "FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "Program" === nodeType || "ObjectMethod" === nodeType || "SwitchStatement" === nodeType || "WhileStatement" === nodeType || "ArrowFunctionExpression" === nodeType || "ForOfStatement" === nodeType || "ClassMethod" === nodeType || "ClassPrivateMethod" === nodeType || "StaticBlock" === nodeType || "TSModuleBlock" === nodeType || nodeType === "Placeholder" && "BlockStatement" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isBlock(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BlockStatement" === nodeType || "Program" === nodeType || "TSModuleBlock" === nodeType || nodeType === "Placeholder" && "BlockStatement" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BlockStatement" === nodeType || "BreakStatement" === nodeType || "ContinueStatement" === nodeType || "DebuggerStatement" === nodeType || "DoWhileStatement" === nodeType || "EmptyStatement" === nodeType || "ExpressionStatement" === nodeType || "ForInStatement" === nodeType || "ForStatement" === nodeType || "FunctionDeclaration" === nodeType || "IfStatement" === nodeType || "LabeledStatement" === nodeType || "ReturnStatement" === nodeType || "SwitchStatement" === nodeType || "ThrowStatement" === nodeType || "TryStatement" === nodeType || "VariableDeclaration" === nodeType || "WhileStatement" === nodeType || "WithStatement" === nodeType || "ClassDeclaration" === nodeType || "ExportAllDeclaration" === nodeType || "ExportDefaultDeclaration" === nodeType || "ExportNamedDeclaration" === nodeType || "ForOfStatement" === nodeType || "ImportDeclaration" === nodeType || "DeclareClass" === nodeType || "DeclareFunction" === nodeType || "DeclareInterface" === nodeType || "DeclareModule" === nodeType || "DeclareModuleExports" === nodeType || "DeclareTypeAlias" === nodeType || "DeclareOpaqueType" === nodeType || "DeclareVariable" === nodeType || "DeclareExportDeclaration" === nodeType || "DeclareExportAllDeclaration" === nodeType || "InterfaceDeclaration" === nodeType || "OpaqueType" === nodeType || "TypeAlias" === nodeType || "EnumDeclaration" === nodeType || "TSDeclareFunction" === nodeType || "TSInterfaceDeclaration" === nodeType || "TSTypeAliasDeclaration" === nodeType || "TSEnumDeclaration" === nodeType || "TSModuleDeclaration" === nodeType || "TSImportEqualsDeclaration" === nodeType || "TSExportAssignment" === nodeType || "TSNamespaceExportDeclaration" === nodeType || nodeType === "Placeholder" && ("Statement" === node.expectedNode || "Declaration" === node.expectedNode || "BlockStatement" === node.expectedNode)) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTerminatorless(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BreakStatement" === nodeType || "ContinueStatement" === nodeType || "ReturnStatement" === nodeType || "ThrowStatement" === nodeType || "YieldExpression" === nodeType || "AwaitExpression" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isCompletionStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("BreakStatement" === nodeType || "ContinueStatement" === nodeType || "ReturnStatement" === nodeType || "ThrowStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isConditional(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ConditionalExpression" === nodeType || "IfStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isLoop(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("DoWhileStatement" === nodeType || "ForInStatement" === nodeType || "ForStatement" === nodeType || "WhileStatement" === nodeType || "ForOfStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isWhile(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("DoWhileStatement" === nodeType || "WhileStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExpressionWrapper(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ExpressionStatement" === nodeType || "ParenthesizedExpression" === nodeType || "TypeCastExpression" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFor(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ForInStatement" === nodeType || "ForStatement" === nodeType || "ForOfStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isForXStatement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ForInStatement" === nodeType || "ForOfStatement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunction(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "ObjectMethod" === nodeType || "ArrowFunctionExpression" === nodeType || "ClassMethod" === nodeType || "ClassPrivateMethod" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFunctionParent(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "ObjectMethod" === nodeType || "ArrowFunctionExpression" === nodeType || "ClassMethod" === nodeType || "ClassPrivateMethod" === nodeType || "StaticBlock" === nodeType || "TSModuleBlock" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPureish(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("FunctionDeclaration" === nodeType || "FunctionExpression" === nodeType || "StringLiteral" === nodeType || "NumericLiteral" === nodeType || "NullLiteral" === nodeType || "BooleanLiteral" === nodeType || "RegExpLiteral" === nodeType || "ArrowFunctionExpression" === nodeType || "BigIntLiteral" === nodeType || "DecimalLiteral" === nodeType || nodeType === "Placeholder" && "StringLiteral" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("FunctionDeclaration" === nodeType || "VariableDeclaration" === nodeType || "ClassDeclaration" === nodeType || "ExportAllDeclaration" === nodeType || "ExportDefaultDeclaration" === nodeType || "ExportNamedDeclaration" === nodeType || "ImportDeclaration" === nodeType || "DeclareClass" === nodeType || "DeclareFunction" === nodeType || "DeclareInterface" === nodeType || "DeclareModule" === nodeType || "DeclareModuleExports" === nodeType || "DeclareTypeAlias" === nodeType || "DeclareOpaqueType" === nodeType || "DeclareVariable" === nodeType || "DeclareExportDeclaration" === nodeType || "DeclareExportAllDeclaration" === nodeType || "InterfaceDeclaration" === nodeType || "OpaqueType" === nodeType || "TypeAlias" === nodeType || "EnumDeclaration" === nodeType || "TSDeclareFunction" === nodeType || "TSInterfaceDeclaration" === nodeType || "TSTypeAliasDeclaration" === nodeType || "TSEnumDeclaration" === nodeType || "TSModuleDeclaration" === nodeType || nodeType === "Placeholder" && "Declaration" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPatternLike(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("Identifier" === nodeType || "RestElement" === nodeType || "AssignmentPattern" === nodeType || "ArrayPattern" === nodeType || "ObjectPattern" === nodeType || "TSAsExpression" === nodeType || "TSSatisfiesExpression" === nodeType || "TSTypeAssertion" === nodeType || "TSNonNullExpression" === nodeType || nodeType === "Placeholder" && ("Pattern" === node.expectedNode || "Identifier" === node.expectedNode)) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isLVal(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("Identifier" === nodeType || "MemberExpression" === nodeType || "RestElement" === nodeType || "AssignmentPattern" === nodeType || "ArrayPattern" === nodeType || "ObjectPattern" === nodeType || "TSParameterProperty" === nodeType || "TSAsExpression" === nodeType || "TSSatisfiesExpression" === nodeType || "TSTypeAssertion" === nodeType || "TSNonNullExpression" === nodeType || nodeType === "Placeholder" && ("Pattern" === node.expectedNode || "Identifier" === node.expectedNode)) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSEntityName(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("Identifier" === nodeType || "TSQualifiedName" === nodeType || nodeType === "Placeholder" && "Identifier" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isLiteral(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("StringLiteral" === nodeType || "NumericLiteral" === nodeType || "NullLiteral" === nodeType || "BooleanLiteral" === nodeType || "RegExpLiteral" === nodeType || "TemplateLiteral" === nodeType || "BigIntLiteral" === nodeType || "DecimalLiteral" === nodeType || nodeType === "Placeholder" && "StringLiteral" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isImmutable(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("StringLiteral" === nodeType || "NumericLiteral" === nodeType || "NullLiteral" === nodeType || "BooleanLiteral" === nodeType || "BigIntLiteral" === nodeType || "JSXAttribute" === nodeType || "JSXClosingElement" === nodeType || "JSXElement" === nodeType || "JSXExpressionContainer" === nodeType || "JSXSpreadChild" === nodeType || "JSXOpeningElement" === nodeType || "JSXText" === nodeType || "JSXFragment" === nodeType || "JSXOpeningFragment" === nodeType || "JSXClosingFragment" === nodeType || "DecimalLiteral" === nodeType || nodeType === "Placeholder" && "StringLiteral" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isUserWhitespacable(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ObjectMethod" === nodeType || "ObjectProperty" === nodeType || "ObjectTypeInternalSlot" === nodeType || "ObjectTypeCallProperty" === nodeType || "ObjectTypeIndexer" === nodeType || "ObjectTypeProperty" === nodeType || "ObjectTypeSpreadProperty" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isMethod(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ObjectMethod" === nodeType || "ClassMethod" === nodeType || "ClassPrivateMethod" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isObjectMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ObjectMethod" === nodeType || "ObjectProperty" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isProperty(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ObjectProperty" === nodeType || "ClassProperty" === nodeType || "ClassAccessorProperty" === nodeType || "ClassPrivateProperty" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isUnaryLike(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("UnaryExpression" === nodeType || "SpreadElement" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPattern(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("AssignmentPattern" === nodeType || "ArrayPattern" === nodeType || "ObjectPattern" === nodeType || nodeType === "Placeholder" && "Pattern" === node.expectedNode) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isClass(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ClassExpression" === nodeType || "ClassDeclaration" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isModuleDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ExportAllDeclaration" === nodeType || "ExportDefaultDeclaration" === nodeType || "ExportNamedDeclaration" === nodeType || "ImportDeclaration" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isExportDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ExportAllDeclaration" === nodeType || "ExportDefaultDeclaration" === nodeType || "ExportNamedDeclaration" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isModuleSpecifier(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ExportSpecifier" === nodeType || "ImportDefaultSpecifier" === nodeType || "ImportNamespaceSpecifier" === nodeType || "ImportSpecifier" === nodeType || "ExportNamespaceSpecifier" === nodeType || "ExportDefaultSpecifier" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isAccessor(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ClassAccessorProperty" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isPrivate(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("ClassPrivateProperty" === nodeType || "ClassPrivateMethod" === nodeType || "PrivateName" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFlow(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("AnyTypeAnnotation" === nodeType || "ArrayTypeAnnotation" === nodeType || "BooleanTypeAnnotation" === nodeType || "BooleanLiteralTypeAnnotation" === nodeType || "NullLiteralTypeAnnotation" === nodeType || "ClassImplements" === nodeType || "DeclareClass" === nodeType || "DeclareFunction" === nodeType || "DeclareInterface" === nodeType || "DeclareModule" === nodeType || "DeclareModuleExports" === nodeType || "DeclareTypeAlias" === nodeType || "DeclareOpaqueType" === nodeType || "DeclareVariable" === nodeType || "DeclareExportDeclaration" === nodeType || "DeclareExportAllDeclaration" === nodeType || "DeclaredPredicate" === nodeType || "ExistsTypeAnnotation" === nodeType || "FunctionTypeAnnotation" === nodeType || "FunctionTypeParam" === nodeType || "GenericTypeAnnotation" === nodeType || "InferredPredicate" === nodeType || "InterfaceExtends" === nodeType || "InterfaceDeclaration" === nodeType || "InterfaceTypeAnnotation" === nodeType || "IntersectionTypeAnnotation" === nodeType || "MixedTypeAnnotation" === nodeType || "EmptyTypeAnnotation" === nodeType || "NullableTypeAnnotation" === nodeType || "NumberLiteralTypeAnnotation" === nodeType || "NumberTypeAnnotation" === nodeType || "ObjectTypeAnnotation" === nodeType || "ObjectTypeInternalSlot" === nodeType || "ObjectTypeCallProperty" === nodeType || "ObjectTypeIndexer" === nodeType || "ObjectTypeProperty" === nodeType || "ObjectTypeSpreadProperty" === nodeType || "OpaqueType" === nodeType || "QualifiedTypeIdentifier" === nodeType || "StringLiteralTypeAnnotation" === nodeType || "StringTypeAnnotation" === nodeType || "SymbolTypeAnnotation" === nodeType || "ThisTypeAnnotation" === nodeType || "TupleTypeAnnotation" === nodeType || "TypeofTypeAnnotation" === nodeType || "TypeAlias" === nodeType || "TypeAnnotation" === nodeType || "TypeCastExpression" === nodeType || "TypeParameter" === nodeType || "TypeParameterDeclaration" === nodeType || "TypeParameterInstantiation" === nodeType || "UnionTypeAnnotation" === nodeType || "Variance" === nodeType || "VoidTypeAnnotation" === nodeType || "EnumDeclaration" === nodeType || "EnumBooleanBody" === nodeType || "EnumNumberBody" === nodeType || "EnumStringBody" === nodeType || "EnumSymbolBody" === nodeType || "EnumBooleanMember" === nodeType || "EnumNumberMember" === nodeType || "EnumStringMember" === nodeType || "EnumDefaultedMember" === nodeType || "IndexedAccessType" === nodeType || "OptionalIndexedAccessType" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFlowType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("AnyTypeAnnotation" === nodeType || "ArrayTypeAnnotation" === nodeType || "BooleanTypeAnnotation" === nodeType || "BooleanLiteralTypeAnnotation" === nodeType || "NullLiteralTypeAnnotation" === nodeType || "ExistsTypeAnnotation" === nodeType || "FunctionTypeAnnotation" === nodeType || "GenericTypeAnnotation" === nodeType || "InterfaceTypeAnnotation" === nodeType || "IntersectionTypeAnnotation" === nodeType || "MixedTypeAnnotation" === nodeType || "EmptyTypeAnnotation" === nodeType || "NullableTypeAnnotation" === nodeType || "NumberLiteralTypeAnnotation" === nodeType || "NumberTypeAnnotation" === nodeType || "ObjectTypeAnnotation" === nodeType || "StringLiteralTypeAnnotation" === nodeType || "StringTypeAnnotation" === nodeType || "SymbolTypeAnnotation" === nodeType || "ThisTypeAnnotation" === nodeType || "TupleTypeAnnotation" === nodeType || "TypeofTypeAnnotation" === nodeType || "UnionTypeAnnotation" === nodeType || "VoidTypeAnnotation" === nodeType || "IndexedAccessType" === nodeType || "OptionalIndexedAccessType" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFlowBaseAnnotation(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("AnyTypeAnnotation" === nodeType || "BooleanTypeAnnotation" === nodeType || "NullLiteralTypeAnnotation" === nodeType || "MixedTypeAnnotation" === nodeType || "EmptyTypeAnnotation" === nodeType || "NumberTypeAnnotation" === nodeType || "StringTypeAnnotation" === nodeType || "SymbolTypeAnnotation" === nodeType || "ThisTypeAnnotation" === nodeType || "VoidTypeAnnotation" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFlowDeclaration(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("DeclareClass" === nodeType || "DeclareFunction" === nodeType || "DeclareInterface" === nodeType || "DeclareModule" === nodeType || "DeclareModuleExports" === nodeType || "DeclareTypeAlias" === nodeType || "DeclareOpaqueType" === nodeType || "DeclareVariable" === nodeType || "DeclareExportDeclaration" === nodeType || "DeclareExportAllDeclaration" === nodeType || "InterfaceDeclaration" === nodeType || "OpaqueType" === nodeType || "TypeAlias" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isFlowPredicate(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("DeclaredPredicate" === nodeType || "InferredPredicate" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumBody(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("EnumBooleanBody" === nodeType || "EnumNumberBody" === nodeType || "EnumStringBody" === nodeType || "EnumSymbolBody" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isEnumMember(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("EnumBooleanMember" === nodeType || "EnumNumberMember" === nodeType || "EnumStringMember" === nodeType || "EnumDefaultedMember" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isJSX(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("JSXAttribute" === nodeType || "JSXClosingElement" === nodeType || "JSXElement" === nodeType || "JSXEmptyExpression" === nodeType || "JSXExpressionContainer" === nodeType || "JSXSpreadChild" === nodeType || "JSXIdentifier" === nodeType || "JSXMemberExpression" === nodeType || "JSXNamespacedName" === nodeType || "JSXOpeningElement" === nodeType || "JSXSpreadAttribute" === nodeType || "JSXText" === nodeType || "JSXFragment" === nodeType || "JSXOpeningFragment" === nodeType || "JSXClosingFragment" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isMiscellaneous(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("Noop" === nodeType || "Placeholder" === nodeType || "V8IntrinsicIdentifier" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTypeScript(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("TSParameterProperty" === nodeType || "TSDeclareFunction" === nodeType || "TSDeclareMethod" === nodeType || "TSQualifiedName" === nodeType || "TSCallSignatureDeclaration" === nodeType || "TSConstructSignatureDeclaration" === nodeType || "TSPropertySignature" === nodeType || "TSMethodSignature" === nodeType || "TSIndexSignature" === nodeType || "TSAnyKeyword" === nodeType || "TSBooleanKeyword" === nodeType || "TSBigIntKeyword" === nodeType || "TSIntrinsicKeyword" === nodeType || "TSNeverKeyword" === nodeType || "TSNullKeyword" === nodeType || "TSNumberKeyword" === nodeType || "TSObjectKeyword" === nodeType || "TSStringKeyword" === nodeType || "TSSymbolKeyword" === nodeType || "TSUndefinedKeyword" === nodeType || "TSUnknownKeyword" === nodeType || "TSVoidKeyword" === nodeType || "TSThisType" === nodeType || "TSFunctionType" === nodeType || "TSConstructorType" === nodeType || "TSTypeReference" === nodeType || "TSTypePredicate" === nodeType || "TSTypeQuery" === nodeType || "TSTypeLiteral" === nodeType || "TSArrayType" === nodeType || "TSTupleType" === nodeType || "TSOptionalType" === nodeType || "TSRestType" === nodeType || "TSNamedTupleMember" === nodeType || "TSUnionType" === nodeType || "TSIntersectionType" === nodeType || "TSConditionalType" === nodeType || "TSInferType" === nodeType || "TSParenthesizedType" === nodeType || "TSTypeOperator" === nodeType || "TSIndexedAccessType" === nodeType || "TSMappedType" === nodeType || "TSLiteralType" === nodeType || "TSExpressionWithTypeArguments" === nodeType || "TSInterfaceDeclaration" === nodeType || "TSInterfaceBody" === nodeType || "TSTypeAliasDeclaration" === nodeType || "TSInstantiationExpression" === nodeType || "TSAsExpression" === nodeType || "TSSatisfiesExpression" === nodeType || "TSTypeAssertion" === nodeType || "TSEnumDeclaration" === nodeType || "TSEnumMember" === nodeType || "TSModuleDeclaration" === nodeType || "TSModuleBlock" === nodeType || "TSImportType" === nodeType || "TSImportEqualsDeclaration" === nodeType || "TSExternalModuleReference" === nodeType || "TSNonNullExpression" === nodeType || "TSExportAssignment" === nodeType || "TSNamespaceExportDeclaration" === nodeType || "TSTypeAnnotation" === nodeType || "TSTypeParameterInstantiation" === nodeType || "TSTypeParameterDeclaration" === nodeType || "TSTypeParameter" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSTypeElement(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("TSCallSignatureDeclaration" === nodeType || "TSConstructSignatureDeclaration" === nodeType || "TSPropertySignature" === nodeType || "TSMethodSignature" === nodeType || "TSIndexSignature" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSType2(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("TSAnyKeyword" === nodeType || "TSBooleanKeyword" === nodeType || "TSBigIntKeyword" === nodeType || "TSIntrinsicKeyword" === nodeType || "TSNeverKeyword" === nodeType || "TSNullKeyword" === nodeType || "TSNumberKeyword" === nodeType || "TSObjectKeyword" === nodeType || "TSStringKeyword" === nodeType || "TSSymbolKeyword" === nodeType || "TSUndefinedKeyword" === nodeType || "TSUnknownKeyword" === nodeType || "TSVoidKeyword" === nodeType || "TSThisType" === nodeType || "TSFunctionType" === nodeType || "TSConstructorType" === nodeType || "TSTypeReference" === nodeType || "TSTypePredicate" === nodeType || "TSTypeQuery" === nodeType || "TSTypeLiteral" === nodeType || "TSArrayType" === nodeType || "TSTupleType" === nodeType || "TSOptionalType" === nodeType || "TSRestType" === nodeType || "TSUnionType" === nodeType || "TSIntersectionType" === nodeType || "TSConditionalType" === nodeType || "TSInferType" === nodeType || "TSParenthesizedType" === nodeType || "TSTypeOperator" === nodeType || "TSIndexedAccessType" === nodeType || "TSMappedType" === nodeType || "TSLiteralType" === nodeType || "TSExpressionWithTypeArguments" === nodeType || "TSImportType" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isTSBaseType(node, opts) {
      if (!node)
        return false;
      const nodeType = node.type;
      if ("TSAnyKeyword" === nodeType || "TSBooleanKeyword" === nodeType || "TSBigIntKeyword" === nodeType || "TSIntrinsicKeyword" === nodeType || "TSNeverKeyword" === nodeType || "TSNullKeyword" === nodeType || "TSNumberKeyword" === nodeType || "TSObjectKeyword" === nodeType || "TSStringKeyword" === nodeType || "TSSymbolKeyword" === nodeType || "TSUndefinedKeyword" === nodeType || "TSUnknownKeyword" === nodeType || "TSVoidKeyword" === nodeType || "TSThisType" === nodeType || "TSLiteralType" === nodeType) {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isNumberLiteral(node, opts) {
      console.trace("The node type NumberLiteral has been renamed to NumericLiteral");
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "NumberLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isRegexLiteral(node, opts) {
      console.trace("The node type RegexLiteral has been renamed to RegExpLiteral");
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "RegexLiteral") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isRestProperty(node, opts) {
      console.trace("The node type RestProperty has been renamed to RestElement");
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "RestProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
    function isSpreadProperty(node, opts) {
      console.trace("The node type SpreadProperty has been renamed to SpreadElement");
      if (!node)
        return false;
      const nodeType = node.type;
      if (nodeType === "SpreadProperty") {
        if (typeof opts === "undefined") {
          return true;
        } else {
          return (0, _shallowEqual.default)(node, opts);
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/types/lib/validators/matchesPattern.js
var require_matchesPattern = __commonJS({
  "node_modules/@babel/types/lib/validators/matchesPattern.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = matchesPattern;
    var _generated = require_generated();
    function matchesPattern(member, match, allowPartial) {
      if (!(0, _generated.isMemberExpression)(member))
        return false;
      const parts = Array.isArray(match) ? match : match.split(".");
      const nodes = [];
      let node;
      for (node = member; (0, _generated.isMemberExpression)(node); node = node.object) {
        nodes.push(node.property);
      }
      nodes.push(node);
      if (nodes.length < parts.length)
        return false;
      if (!allowPartial && nodes.length > parts.length)
        return false;
      for (let i = 0, j = nodes.length - 1; i < parts.length; i++, j--) {
        const node2 = nodes[j];
        let value2;
        if ((0, _generated.isIdentifier)(node2)) {
          value2 = node2.name;
        } else if ((0, _generated.isStringLiteral)(node2)) {
          value2 = node2.value;
        } else if ((0, _generated.isThisExpression)(node2)) {
          value2 = "this";
        } else {
          return false;
        }
        if (parts[i] !== value2)
          return false;
      }
      return true;
    }
  }
});

// node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js
var require_buildMatchMemberExpression = __commonJS({
  "node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = buildMatchMemberExpression;
    var _matchesPattern = require_matchesPattern();
    function buildMatchMemberExpression(match, allowPartial) {
      const parts = match.split(".");
      return (member) => (0, _matchesPattern.default)(member, parts, allowPartial);
    }
  }
});

// node_modules/@babel/types/lib/validators/react/isReactComponent.js
var require_isReactComponent = __commonJS({
  "node_modules/@babel/types/lib/validators/react/isReactComponent.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _buildMatchMemberExpression = require_buildMatchMemberExpression();
    var isReactComponent = (0, _buildMatchMemberExpression.default)("React.Component");
    var _default = isReactComponent;
    exports.default = _default;
  }
});

// node_modules/@babel/types/lib/validators/react/isCompatTag.js
var require_isCompatTag = __commonJS({
  "node_modules/@babel/types/lib/validators/react/isCompatTag.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isCompatTag;
    function isCompatTag(tagName) {
      return !!tagName && /^[a-z]/.test(tagName);
    }
  }
});

// node_modules/to-fast-properties/index.js
var require_to_fast_properties = __commonJS({
  "node_modules/to-fast-properties/index.js"(exports, module2) {
    "use strict";
    var fastProto = null;
    function FastObject(o) {
      if (fastProto !== null && typeof fastProto.property) {
        const result = fastProto;
        fastProto = FastObject.prototype = null;
        return result;
      }
      fastProto = FastObject.prototype = o == null ? /* @__PURE__ */ Object.create(null) : o;
      return new FastObject();
    }
    FastObject();
    module2.exports = function toFastproperties(o) {
      return FastObject(o);
    };
  }
});

// node_modules/@babel/types/lib/validators/isType.js
var require_isType = __commonJS({
  "node_modules/@babel/types/lib/validators/isType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isType;
    var _definitions = require_definitions();
    function isType(nodeType, targetType) {
      if (nodeType === targetType)
        return true;
      if (_definitions.ALIAS_KEYS[targetType])
        return false;
      const aliases = _definitions.FLIPPED_ALIAS_KEYS[targetType];
      if (aliases) {
        if (aliases[0] === nodeType)
          return true;
        for (const alias of aliases) {
          if (nodeType === alias)
            return true;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/types/lib/validators/isPlaceholderType.js
var require_isPlaceholderType = __commonJS({
  "node_modules/@babel/types/lib/validators/isPlaceholderType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isPlaceholderType;
    var _definitions = require_definitions();
    function isPlaceholderType(placeholderType, targetType) {
      if (placeholderType === targetType)
        return true;
      const aliases = _definitions.PLACEHOLDERS_ALIAS[placeholderType];
      if (aliases) {
        for (const alias of aliases) {
          if (targetType === alias)
            return true;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/types/lib/validators/is.js
var require_is = __commonJS({
  "node_modules/@babel/types/lib/validators/is.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = is;
    var _shallowEqual = require_shallowEqual();
    var _isType = require_isType();
    var _isPlaceholderType = require_isPlaceholderType();
    var _definitions = require_definitions();
    function is(type, node, opts) {
      if (!node)
        return false;
      const matches = (0, _isType.default)(node.type, type);
      if (!matches) {
        if (!opts && node.type === "Placeholder" && type in _definitions.FLIPPED_ALIAS_KEYS) {
          return (0, _isPlaceholderType.default)(node.expectedNode, type);
        }
        return false;
      }
      if (typeof opts === "undefined") {
        return true;
      } else {
        return (0, _shallowEqual.default)(node, opts);
      }
    }
  }
});

// node_modules/@babel/helper-validator-identifier/lib/identifier.js
var require_identifier = __commonJS({
  "node_modules/@babel/helper-validator-identifier/lib/identifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isIdentifierChar = isIdentifierChar;
    exports.isIdentifierName = isIdentifierName;
    exports.isIdentifierStart = isIdentifierStart;
    var nonASCIIidentifierStartChars = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC";
    var nonASCIIidentifierChars = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F";
    var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
    var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
    nonASCIIidentifierStartChars = nonASCIIidentifierChars = null;
    var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
    var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
    function isInAstralSet(code, set) {
      let pos = 65536;
      for (let i = 0, length = set.length; i < length; i += 2) {
        pos += set[i];
        if (pos > code)
          return false;
        pos += set[i + 1];
        if (pos >= code)
          return true;
      }
      return false;
    }
    function isIdentifierStart(code) {
      if (code < 65)
        return code === 36;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifierStart.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes);
    }
    function isIdentifierChar(code) {
      if (code < 48)
        return code === 36;
      if (code < 58)
        return true;
      if (code < 65)
        return false;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifier.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
    }
    function isIdentifierName(name) {
      let isFirst = true;
      for (let i = 0; i < name.length; i++) {
        let cp = name.charCodeAt(i);
        if ((cp & 64512) === 55296 && i + 1 < name.length) {
          const trail = name.charCodeAt(++i);
          if ((trail & 64512) === 56320) {
            cp = 65536 + ((cp & 1023) << 10) + (trail & 1023);
          }
        }
        if (isFirst) {
          isFirst = false;
          if (!isIdentifierStart(cp)) {
            return false;
          }
        } else if (!isIdentifierChar(cp)) {
          return false;
        }
      }
      return !isFirst;
    }
  }
});

// node_modules/@babel/helper-validator-identifier/lib/keyword.js
var require_keyword3 = __commonJS({
  "node_modules/@babel/helper-validator-identifier/lib/keyword.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isKeyword = isKeyword;
    exports.isReservedWord = isReservedWord;
    exports.isStrictBindOnlyReservedWord = isStrictBindOnlyReservedWord;
    exports.isStrictBindReservedWord = isStrictBindReservedWord;
    exports.isStrictReservedWord = isStrictReservedWord;
    var reservedWords = {
      keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"],
      strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"],
      strictBind: ["eval", "arguments"]
    };
    var keywords = new Set(reservedWords.keyword);
    var reservedWordsStrictSet = new Set(reservedWords.strict);
    var reservedWordsStrictBindSet = new Set(reservedWords.strictBind);
    function isReservedWord(word, inModule) {
      return inModule && word === "await" || word === "enum";
    }
    function isStrictReservedWord(word, inModule) {
      return isReservedWord(word, inModule) || reservedWordsStrictSet.has(word);
    }
    function isStrictBindOnlyReservedWord(word) {
      return reservedWordsStrictBindSet.has(word);
    }
    function isStrictBindReservedWord(word, inModule) {
      return isStrictReservedWord(word, inModule) || isStrictBindOnlyReservedWord(word);
    }
    function isKeyword(word) {
      return keywords.has(word);
    }
  }
});

// node_modules/@babel/helper-validator-identifier/lib/index.js
var require_lib9 = __commonJS({
  "node_modules/@babel/helper-validator-identifier/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "isIdentifierChar", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierChar;
      }
    });
    Object.defineProperty(exports, "isIdentifierName", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierName;
      }
    });
    Object.defineProperty(exports, "isIdentifierStart", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierStart;
      }
    });
    Object.defineProperty(exports, "isKeyword", {
      enumerable: true,
      get: function() {
        return _keyword.isKeyword;
      }
    });
    Object.defineProperty(exports, "isReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictBindOnlyReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictBindOnlyReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictBindReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictBindReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictReservedWord;
      }
    });
    var _identifier = require_identifier();
    var _keyword = require_keyword3();
  }
});

// node_modules/@babel/types/lib/validators/isValidIdentifier.js
var require_isValidIdentifier = __commonJS({
  "node_modules/@babel/types/lib/validators/isValidIdentifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isValidIdentifier;
    var _helperValidatorIdentifier = require_lib9();
    function isValidIdentifier(name, reserved = true) {
      if (typeof name !== "string")
        return false;
      if (reserved) {
        if ((0, _helperValidatorIdentifier.isKeyword)(name) || (0, _helperValidatorIdentifier.isStrictReservedWord)(name, true)) {
          return false;
        }
      }
      return (0, _helperValidatorIdentifier.isIdentifierName)(name);
    }
  }
});

// node_modules/@babel/helper-string-parser/lib/index.js
var require_lib10 = __commonJS({
  "node_modules/@babel/helper-string-parser/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.readCodePoint = readCodePoint;
    exports.readInt = readInt;
    exports.readStringContents = readStringContents;
    var _isDigit = function isDigit(code) {
      return code >= 48 && code <= 57;
    };
    var forbiddenNumericSeparatorSiblings = {
      decBinOct: /* @__PURE__ */ new Set([46, 66, 69, 79, 95, 98, 101, 111]),
      hex: /* @__PURE__ */ new Set([46, 88, 95, 120])
    };
    var isAllowedNumericSeparatorSibling = {
      bin: (ch) => ch === 48 || ch === 49,
      oct: (ch) => ch >= 48 && ch <= 55,
      dec: (ch) => ch >= 48 && ch <= 57,
      hex: (ch) => ch >= 48 && ch <= 57 || ch >= 65 && ch <= 70 || ch >= 97 && ch <= 102
    };
    function readStringContents(type, input, pos, lineStart, curLine, errors) {
      const initialPos = pos;
      const initialLineStart = lineStart;
      const initialCurLine = curLine;
      let out = "";
      let firstInvalidLoc = null;
      let chunkStart = pos;
      const {
        length
      } = input;
      for (; ; ) {
        if (pos >= length) {
          errors.unterminated(initialPos, initialLineStart, initialCurLine);
          out += input.slice(chunkStart, pos);
          break;
        }
        const ch = input.charCodeAt(pos);
        if (isStringEnd(type, ch, input, pos)) {
          out += input.slice(chunkStart, pos);
          break;
        }
        if (ch === 92) {
          out += input.slice(chunkStart, pos);
          const res = readEscapedChar(input, pos, lineStart, curLine, type === "template", errors);
          if (res.ch === null && !firstInvalidLoc) {
            firstInvalidLoc = {
              pos,
              lineStart,
              curLine
            };
          } else {
            out += res.ch;
          }
          ({
            pos,
            lineStart,
            curLine
          } = res);
          chunkStart = pos;
        } else if (ch === 8232 || ch === 8233) {
          ++pos;
          ++curLine;
          lineStart = pos;
        } else if (ch === 10 || ch === 13) {
          if (type === "template") {
            out += input.slice(chunkStart, pos) + "\n";
            ++pos;
            if (ch === 13 && input.charCodeAt(pos) === 10) {
              ++pos;
            }
            ++curLine;
            chunkStart = lineStart = pos;
          } else {
            errors.unterminated(initialPos, initialLineStart, initialCurLine);
          }
        } else {
          ++pos;
        }
      }
      return {
        pos,
        str: out,
        firstInvalidLoc,
        lineStart,
        curLine,
        containsInvalid: !!firstInvalidLoc
      };
    }
    function isStringEnd(type, ch, input, pos) {
      if (type === "template") {
        return ch === 96 || ch === 36 && input.charCodeAt(pos + 1) === 123;
      }
      return ch === (type === "double" ? 34 : 39);
    }
    function readEscapedChar(input, pos, lineStart, curLine, inTemplate, errors) {
      const throwOnInvalid = !inTemplate;
      pos++;
      const res = (ch2) => ({
        pos,
        ch: ch2,
        lineStart,
        curLine
      });
      const ch = input.charCodeAt(pos++);
      switch (ch) {
        case 110:
          return res("\n");
        case 114:
          return res("\r");
        case 120: {
          let code;
          ({
            code,
            pos
          } = readHexChar(input, pos, lineStart, curLine, 2, false, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCharCode(code));
        }
        case 117: {
          let code;
          ({
            code,
            pos
          } = readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCodePoint(code));
        }
        case 116:
          return res("	");
        case 98:
          return res("\b");
        case 118:
          return res("\v");
        case 102:
          return res("\f");
        case 13:
          if (input.charCodeAt(pos) === 10) {
            ++pos;
          }
        case 10:
          lineStart = pos;
          ++curLine;
        case 8232:
        case 8233:
          return res("");
        case 56:
        case 57:
          if (inTemplate) {
            return res(null);
          } else {
            errors.strictNumericEscape(pos - 1, lineStart, curLine);
          }
        default:
          if (ch >= 48 && ch <= 55) {
            const startPos = pos - 1;
            const match = input.slice(startPos, pos + 2).match(/^[0-7]+/);
            let octalStr = match[0];
            let octal = parseInt(octalStr, 8);
            if (octal > 255) {
              octalStr = octalStr.slice(0, -1);
              octal = parseInt(octalStr, 8);
            }
            pos += octalStr.length - 1;
            const next = input.charCodeAt(pos);
            if (octalStr !== "0" || next === 56 || next === 57) {
              if (inTemplate) {
                return res(null);
              } else {
                errors.strictNumericEscape(startPos, lineStart, curLine);
              }
            }
            return res(String.fromCharCode(octal));
          }
          return res(String.fromCharCode(ch));
      }
    }
    function readHexChar(input, pos, lineStart, curLine, len, forceLen, throwOnInvalid, errors) {
      const initialPos = pos;
      let n;
      ({
        n,
        pos
      } = readInt(input, pos, lineStart, curLine, 16, len, forceLen, false, errors, !throwOnInvalid));
      if (n === null) {
        if (throwOnInvalid) {
          errors.invalidEscapeSequence(initialPos, lineStart, curLine);
        } else {
          pos = initialPos - 1;
        }
      }
      return {
        code: n,
        pos
      };
    }
    function readInt(input, pos, lineStart, curLine, radix, len, forceLen, allowNumSeparator, errors, bailOnError) {
      const start = pos;
      const forbiddenSiblings = radix === 16 ? forbiddenNumericSeparatorSiblings.hex : forbiddenNumericSeparatorSiblings.decBinOct;
      const isAllowedSibling = radix === 16 ? isAllowedNumericSeparatorSibling.hex : radix === 10 ? isAllowedNumericSeparatorSibling.dec : radix === 8 ? isAllowedNumericSeparatorSibling.oct : isAllowedNumericSeparatorSibling.bin;
      let invalid = false;
      let total = 0;
      for (let i = 0, e = len == null ? Infinity : len; i < e; ++i) {
        const code = input.charCodeAt(pos);
        let val;
        if (code === 95 && allowNumSeparator !== "bail") {
          const prev = input.charCodeAt(pos - 1);
          const next = input.charCodeAt(pos + 1);
          if (!allowNumSeparator) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.numericSeparatorInEscapeSequence(pos, lineStart, curLine);
          } else if (Number.isNaN(next) || !isAllowedSibling(next) || forbiddenSiblings.has(prev) || forbiddenSiblings.has(next)) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.unexpectedNumericSeparator(pos, lineStart, curLine);
          }
          ++pos;
          continue;
        }
        if (code >= 97) {
          val = code - 97 + 10;
        } else if (code >= 65) {
          val = code - 65 + 10;
        } else if (_isDigit(code)) {
          val = code - 48;
        } else {
          val = Infinity;
        }
        if (val >= radix) {
          if (val <= 9 && bailOnError) {
            return {
              n: null,
              pos
            };
          } else if (val <= 9 && errors.invalidDigit(pos, lineStart, curLine, radix)) {
            val = 0;
          } else if (forceLen) {
            val = 0;
            invalid = true;
          } else {
            break;
          }
        }
        ++pos;
        total = total * radix + val;
      }
      if (pos === start || len != null && pos - start !== len || invalid) {
        return {
          n: null,
          pos
        };
      }
      return {
        n: total,
        pos
      };
    }
    function readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors) {
      const ch = input.charCodeAt(pos);
      let code;
      if (ch === 123) {
        ++pos;
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, input.indexOf("}", pos) - pos, true, throwOnInvalid, errors));
        ++pos;
        if (code !== null && code > 1114111) {
          if (throwOnInvalid) {
            errors.invalidCodePoint(pos, lineStart, curLine);
          } else {
            return {
              code: null,
              pos
            };
          }
        }
      } else {
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, 4, false, throwOnInvalid, errors));
      }
      return {
        code,
        pos
      };
    }
  }
});

// node_modules/@babel/types/lib/constants/index.js
var require_constants2 = __commonJS({
  "node_modules/@babel/types/lib/constants/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.UPDATE_OPERATORS = exports.UNARY_OPERATORS = exports.STRING_UNARY_OPERATORS = exports.STATEMENT_OR_BLOCK_KEYS = exports.NUMBER_UNARY_OPERATORS = exports.NUMBER_BINARY_OPERATORS = exports.NOT_LOCAL_BINDING = exports.LOGICAL_OPERATORS = exports.INHERIT_KEYS = exports.FOR_INIT_KEYS = exports.FLATTENABLE_KEYS = exports.EQUALITY_BINARY_OPERATORS = exports.COMPARISON_BINARY_OPERATORS = exports.COMMENT_KEYS = exports.BOOLEAN_UNARY_OPERATORS = exports.BOOLEAN_NUMBER_BINARY_OPERATORS = exports.BOOLEAN_BINARY_OPERATORS = exports.BLOCK_SCOPED_SYMBOL = exports.BINARY_OPERATORS = exports.ASSIGNMENT_OPERATORS = void 0;
    var STATEMENT_OR_BLOCK_KEYS = ["consequent", "body", "alternate"];
    exports.STATEMENT_OR_BLOCK_KEYS = STATEMENT_OR_BLOCK_KEYS;
    var FLATTENABLE_KEYS = ["body", "expressions"];
    exports.FLATTENABLE_KEYS = FLATTENABLE_KEYS;
    var FOR_INIT_KEYS = ["left", "init"];
    exports.FOR_INIT_KEYS = FOR_INIT_KEYS;
    var COMMENT_KEYS = ["leadingComments", "trailingComments", "innerComments"];
    exports.COMMENT_KEYS = COMMENT_KEYS;
    var LOGICAL_OPERATORS = ["||", "&&", "??"];
    exports.LOGICAL_OPERATORS = LOGICAL_OPERATORS;
    var UPDATE_OPERATORS = ["++", "--"];
    exports.UPDATE_OPERATORS = UPDATE_OPERATORS;
    var BOOLEAN_NUMBER_BINARY_OPERATORS = [">", "<", ">=", "<="];
    exports.BOOLEAN_NUMBER_BINARY_OPERATORS = BOOLEAN_NUMBER_BINARY_OPERATORS;
    var EQUALITY_BINARY_OPERATORS = ["==", "===", "!=", "!=="];
    exports.EQUALITY_BINARY_OPERATORS = EQUALITY_BINARY_OPERATORS;
    var COMPARISON_BINARY_OPERATORS = [...EQUALITY_BINARY_OPERATORS, "in", "instanceof"];
    exports.COMPARISON_BINARY_OPERATORS = COMPARISON_BINARY_OPERATORS;
    var BOOLEAN_BINARY_OPERATORS = [...COMPARISON_BINARY_OPERATORS, ...BOOLEAN_NUMBER_BINARY_OPERATORS];
    exports.BOOLEAN_BINARY_OPERATORS = BOOLEAN_BINARY_OPERATORS;
    var NUMBER_BINARY_OPERATORS = ["-", "/", "%", "*", "**", "&", "|", ">>", ">>>", "<<", "^"];
    exports.NUMBER_BINARY_OPERATORS = NUMBER_BINARY_OPERATORS;
    var BINARY_OPERATORS = ["+", ...NUMBER_BINARY_OPERATORS, ...BOOLEAN_BINARY_OPERATORS, "|>"];
    exports.BINARY_OPERATORS = BINARY_OPERATORS;
    var ASSIGNMENT_OPERATORS = ["=", "+=", ...NUMBER_BINARY_OPERATORS.map((op) => op + "="), ...LOGICAL_OPERATORS.map((op) => op + "=")];
    exports.ASSIGNMENT_OPERATORS = ASSIGNMENT_OPERATORS;
    var BOOLEAN_UNARY_OPERATORS = ["delete", "!"];
    exports.BOOLEAN_UNARY_OPERATORS = BOOLEAN_UNARY_OPERATORS;
    var NUMBER_UNARY_OPERATORS = ["+", "-", "~"];
    exports.NUMBER_UNARY_OPERATORS = NUMBER_UNARY_OPERATORS;
    var STRING_UNARY_OPERATORS = ["typeof"];
    exports.STRING_UNARY_OPERATORS = STRING_UNARY_OPERATORS;
    var UNARY_OPERATORS = ["void", "throw", ...BOOLEAN_UNARY_OPERATORS, ...NUMBER_UNARY_OPERATORS, ...STRING_UNARY_OPERATORS];
    exports.UNARY_OPERATORS = UNARY_OPERATORS;
    var INHERIT_KEYS = {
      optional: ["typeAnnotation", "typeParameters", "returnType"],
      force: ["start", "loc", "end"]
    };
    exports.INHERIT_KEYS = INHERIT_KEYS;
    var BLOCK_SCOPED_SYMBOL = Symbol.for("var used to be block scoped");
    exports.BLOCK_SCOPED_SYMBOL = BLOCK_SCOPED_SYMBOL;
    var NOT_LOCAL_BINDING = Symbol.for("should not be considered a local binding");
    exports.NOT_LOCAL_BINDING = NOT_LOCAL_BINDING;
  }
});

// node_modules/@babel/types/lib/definitions/utils.js
var require_utils6 = __commonJS({
  "node_modules/@babel/types/lib/definitions/utils.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.VISITOR_KEYS = exports.NODE_PARENT_VALIDATIONS = exports.NODE_FIELDS = exports.FLIPPED_ALIAS_KEYS = exports.DEPRECATED_KEYS = exports.BUILDER_KEYS = exports.ALIAS_KEYS = void 0;
    exports.arrayOf = arrayOf;
    exports.arrayOfType = arrayOfType;
    exports.assertEach = assertEach;
    exports.assertNodeOrValueType = assertNodeOrValueType;
    exports.assertNodeType = assertNodeType;
    exports.assertOneOf = assertOneOf;
    exports.assertOptionalChainStart = assertOptionalChainStart;
    exports.assertShape = assertShape;
    exports.assertValueType = assertValueType;
    exports.chain = chain;
    exports.default = defineType;
    exports.defineAliasedType = defineAliasedType;
    exports.typeIs = typeIs;
    exports.validate = validate;
    exports.validateArrayOfType = validateArrayOfType;
    exports.validateOptional = validateOptional;
    exports.validateOptionalType = validateOptionalType;
    exports.validateType = validateType;
    var _is = require_is();
    var _validate = require_validate2();
    var VISITOR_KEYS = {};
    exports.VISITOR_KEYS = VISITOR_KEYS;
    var ALIAS_KEYS = {};
    exports.ALIAS_KEYS = ALIAS_KEYS;
    var FLIPPED_ALIAS_KEYS = {};
    exports.FLIPPED_ALIAS_KEYS = FLIPPED_ALIAS_KEYS;
    var NODE_FIELDS = {};
    exports.NODE_FIELDS = NODE_FIELDS;
    var BUILDER_KEYS = {};
    exports.BUILDER_KEYS = BUILDER_KEYS;
    var DEPRECATED_KEYS = {};
    exports.DEPRECATED_KEYS = DEPRECATED_KEYS;
    var NODE_PARENT_VALIDATIONS = {};
    exports.NODE_PARENT_VALIDATIONS = NODE_PARENT_VALIDATIONS;
    function getType(val) {
      if (Array.isArray(val)) {
        return "array";
      } else if (val === null) {
        return "null";
      } else {
        return typeof val;
      }
    }
    function validate(validate2) {
      return {
        validate: validate2
      };
    }
    function typeIs(typeName) {
      return typeof typeName === "string" ? assertNodeType(typeName) : assertNodeType(...typeName);
    }
    function validateType(typeName) {
      return validate(typeIs(typeName));
    }
    function validateOptional(validate2) {
      return {
        validate: validate2,
        optional: true
      };
    }
    function validateOptionalType(typeName) {
      return {
        validate: typeIs(typeName),
        optional: true
      };
    }
    function arrayOf(elementType) {
      return chain(assertValueType("array"), assertEach(elementType));
    }
    function arrayOfType(typeName) {
      return arrayOf(typeIs(typeName));
    }
    function validateArrayOfType(typeName) {
      return validate(arrayOfType(typeName));
    }
    function assertEach(callback) {
      function validator(node, key, val) {
        if (!Array.isArray(val))
          return;
        for (let i = 0; i < val.length; i++) {
          const subkey = `${key}[${i}]`;
          const v = val[i];
          callback(node, subkey, v);
          if (process.env.BABEL_TYPES_8_BREAKING)
            (0, _validate.validateChild)(node, subkey, v);
        }
      }
      validator.each = callback;
      return validator;
    }
    function assertOneOf(...values2) {
      function validate2(node, key, val) {
        if (values2.indexOf(val) < 0) {
          throw new TypeError(`Property ${key} expected value to be one of ${JSON.stringify(values2)} but got ${JSON.stringify(val)}`);
        }
      }
      validate2.oneOf = values2;
      return validate2;
    }
    function assertNodeType(...types) {
      function validate2(node, key, val) {
        for (const type of types) {
          if ((0, _is.default)(type, val)) {
            (0, _validate.validateChild)(node, key, val);
            return;
          }
        }
        throw new TypeError(`Property ${key} of ${node.type} expected node to be of a type ${JSON.stringify(types)} but instead got ${JSON.stringify(val == null ? void 0 : val.type)}`);
      }
      validate2.oneOfNodeTypes = types;
      return validate2;
    }
    function assertNodeOrValueType(...types) {
      function validate2(node, key, val) {
        for (const type of types) {
          if (getType(val) === type || (0, _is.default)(type, val)) {
            (0, _validate.validateChild)(node, key, val);
            return;
          }
        }
        throw new TypeError(`Property ${key} of ${node.type} expected node to be of a type ${JSON.stringify(types)} but instead got ${JSON.stringify(val == null ? void 0 : val.type)}`);
      }
      validate2.oneOfNodeOrValueTypes = types;
      return validate2;
    }
    function assertValueType(type) {
      function validate2(node, key, val) {
        const valid = getType(val) === type;
        if (!valid) {
          throw new TypeError(`Property ${key} expected type of ${type} but got ${getType(val)}`);
        }
      }
      validate2.type = type;
      return validate2;
    }
    function assertShape(shape) {
      function validate2(node, key, val) {
        const errors = [];
        for (const property of Object.keys(shape)) {
          try {
            (0, _validate.validateField)(node, property, val[property], shape[property]);
          } catch (error) {
            if (error instanceof TypeError) {
              errors.push(error.message);
              continue;
            }
            throw error;
          }
        }
        if (errors.length) {
          throw new TypeError(`Property ${key} of ${node.type} expected to have the following:
${errors.join("\n")}`);
        }
      }
      validate2.shapeOf = shape;
      return validate2;
    }
    function assertOptionalChainStart() {
      function validate2(node) {
        var _current;
        let current = node;
        while (node) {
          const {
            type
          } = current;
          if (type === "OptionalCallExpression") {
            if (current.optional)
              return;
            current = current.callee;
            continue;
          }
          if (type === "OptionalMemberExpression") {
            if (current.optional)
              return;
            current = current.object;
            continue;
          }
          break;
        }
        throw new TypeError(`Non-optional ${node.type} must chain from an optional OptionalMemberExpression or OptionalCallExpression. Found chain from ${(_current = current) == null ? void 0 : _current.type}`);
      }
      return validate2;
    }
    function chain(...fns) {
      function validate2(...args) {
        for (const fn of fns) {
          fn(...args);
        }
      }
      validate2.chainOf = fns;
      if (fns.length >= 2 && "type" in fns[0] && fns[0].type === "array" && !("each" in fns[1])) {
        throw new Error(`An assertValueType("array") validator can only be followed by an assertEach(...) validator.`);
      }
      return validate2;
    }
    var validTypeOpts = ["aliases", "builder", "deprecatedAlias", "fields", "inherits", "visitor", "validate"];
    var validFieldKeys = ["default", "optional", "validate"];
    var store = {};
    function defineAliasedType(...aliases) {
      return (type, opts = {}) => {
        let defined = opts.aliases;
        if (!defined) {
          var _store$opts$inherits$, _defined;
          if (opts.inherits)
            defined = (_store$opts$inherits$ = store[opts.inherits].aliases) == null ? void 0 : _store$opts$inherits$.slice();
          (_defined = defined) != null ? _defined : defined = [];
          opts.aliases = defined;
        }
        const additional = aliases.filter((a) => !defined.includes(a));
        defined.unshift(...additional);
        return defineType(type, opts);
      };
    }
    function defineType(type, opts = {}) {
      const inherits = opts.inherits && store[opts.inherits] || {};
      let fields = opts.fields;
      if (!fields) {
        fields = {};
        if (inherits.fields) {
          const keys3 = Object.getOwnPropertyNames(inherits.fields);
          for (const key of keys3) {
            const field = inherits.fields[key];
            const def = field.default;
            if (Array.isArray(def) ? def.length > 0 : def && typeof def === "object") {
              throw new Error("field defaults can only be primitives or empty arrays currently");
            }
            fields[key] = {
              default: Array.isArray(def) ? [] : def,
              optional: field.optional,
              validate: field.validate
            };
          }
        }
      }
      const visitor = opts.visitor || inherits.visitor || [];
      const aliases = opts.aliases || inherits.aliases || [];
      const builder = opts.builder || inherits.builder || opts.visitor || [];
      for (const k of Object.keys(opts)) {
        if (validTypeOpts.indexOf(k) === -1) {
          throw new Error(`Unknown type option "${k}" on ${type}`);
        }
      }
      if (opts.deprecatedAlias) {
        DEPRECATED_KEYS[opts.deprecatedAlias] = type;
      }
      for (const key of visitor.concat(builder)) {
        fields[key] = fields[key] || {};
      }
      for (const key of Object.keys(fields)) {
        const field = fields[key];
        if (field.default !== void 0 && builder.indexOf(key) === -1) {
          field.optional = true;
        }
        if (field.default === void 0) {
          field.default = null;
        } else if (!field.validate && field.default != null) {
          field.validate = assertValueType(getType(field.default));
        }
        for (const k of Object.keys(field)) {
          if (validFieldKeys.indexOf(k) === -1) {
            throw new Error(`Unknown field key "${k}" on ${type}.${key}`);
          }
        }
      }
      VISITOR_KEYS[type] = opts.visitor = visitor;
      BUILDER_KEYS[type] = opts.builder = builder;
      NODE_FIELDS[type] = opts.fields = fields;
      ALIAS_KEYS[type] = opts.aliases = aliases;
      aliases.forEach((alias) => {
        FLIPPED_ALIAS_KEYS[alias] = FLIPPED_ALIAS_KEYS[alias] || [];
        FLIPPED_ALIAS_KEYS[alias].push(type);
      });
      if (opts.validate) {
        NODE_PARENT_VALIDATIONS[type] = opts.validate;
      }
      store[type] = opts;
    }
  }
});

// node_modules/@babel/types/lib/definitions/core.js
var require_core = __commonJS({
  "node_modules/@babel/types/lib/definitions/core.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.patternLikeCommon = exports.functionTypeAnnotationCommon = exports.functionDeclarationCommon = exports.functionCommon = exports.classMethodOrPropertyCommon = exports.classMethodOrDeclareMethodCommon = void 0;
    var _is = require_is();
    var _isValidIdentifier = require_isValidIdentifier();
    var _helperValidatorIdentifier = require_lib9();
    var _helperStringParser = require_lib10();
    var _constants = require_constants2();
    var _utils = require_utils6();
    var defineType = (0, _utils.defineAliasedType)("Standardized");
    defineType("ArrayExpression", {
      fields: {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeOrValueType)("null", "Expression", "SpreadElement"))),
          default: !process.env.BABEL_TYPES_8_BREAKING ? [] : void 0
        }
      },
      visitor: ["elements"],
      aliases: ["Expression"]
    });
    defineType("AssignmentExpression", {
      fields: {
        operator: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertValueType)("string");
            }
            const identifier3 = (0, _utils.assertOneOf)(..._constants.ASSIGNMENT_OPERATORS);
            const pattern = (0, _utils.assertOneOf)("=");
            return function(node, key, val) {
              const validator = (0, _is.default)("Pattern", node.left) ? pattern : identifier3;
              validator(node, key, val);
            };
          }()
        },
        left: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("LVal") : (0, _utils.assertNodeType)("Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      builder: ["operator", "left", "right"],
      visitor: ["left", "right"],
      aliases: ["Expression"]
    });
    defineType("BinaryExpression", {
      builder: ["operator", "left", "right"],
      fields: {
        operator: {
          validate: (0, _utils.assertOneOf)(..._constants.BINARY_OPERATORS)
        },
        left: {
          validate: function() {
            const expression = (0, _utils.assertNodeType)("Expression");
            const inOp = (0, _utils.assertNodeType)("Expression", "PrivateName");
            const validator = Object.assign(
              function(node, key, val) {
                const validator2 = node.operator === "in" ? inOp : expression;
                validator2(node, key, val);
              },
              {
                oneOfNodeTypes: ["Expression", "PrivateName"]
              }
            );
            return validator;
          }()
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      visitor: ["left", "right"],
      aliases: ["Binary", "Expression"]
    });
    defineType("InterpreterDirective", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("Directive", {
      visitor: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertNodeType)("DirectiveLiteral")
        }
      }
    });
    defineType("DirectiveLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("BlockStatement", {
      builder: ["body", "directives"],
      visitor: ["directives", "body"],
      fields: {
        directives: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Directive"))),
          default: []
        },
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "Block", "Statement"]
    });
    defineType("BreakStatement", {
      visitor: ["label"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        }
      },
      aliases: ["Statement", "Terminatorless", "CompletionStatement"]
    });
    defineType("CallExpression", {
      visitor: ["callee", "arguments", "typeParameters", "typeArguments"],
      builder: ["callee", "arguments"],
      aliases: ["Expression"],
      fields: Object.assign({
        callee: {
          validate: (0, _utils.assertNodeType)("Expression", "Super", "V8IntrinsicIdentifier")
        },
        arguments: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement", "JSXNamespacedName", "ArgumentPlaceholder")))
        }
      }, !process.env.BABEL_TYPES_8_BREAKING ? {
        optional: {
          validate: (0, _utils.assertOneOf)(true, false),
          optional: true
        }
      } : {}, {
        typeArguments: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TSTypeParameterInstantiation"),
          optional: true
        }
      })
    });
    defineType("CatchClause", {
      visitor: ["param", "body"],
      fields: {
        param: {
          validate: (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      },
      aliases: ["Scopable", "BlockParent"]
    });
    defineType("ConditionalExpression", {
      visitor: ["test", "consequent", "alternate"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        consequent: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        alternate: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression", "Conditional"]
    });
    defineType("ContinueStatement", {
      visitor: ["label"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        }
      },
      aliases: ["Statement", "Terminatorless", "CompletionStatement"]
    });
    defineType("DebuggerStatement", {
      aliases: ["Statement"]
    });
    defineType("DoWhileStatement", {
      visitor: ["test", "body"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      },
      aliases: ["Statement", "BlockParent", "Loop", "While", "Scopable"]
    });
    defineType("EmptyStatement", {
      aliases: ["Statement"]
    });
    defineType("ExpressionStatement", {
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Statement", "ExpressionWrapper"]
    });
    defineType("File", {
      builder: ["program", "comments", "tokens"],
      visitor: ["program"],
      fields: {
        program: {
          validate: (0, _utils.assertNodeType)("Program")
        },
        comments: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? Object.assign(() => {
          }, {
            each: {
              oneOfNodeTypes: ["CommentBlock", "CommentLine"]
            }
          }) : (0, _utils.assertEach)((0, _utils.assertNodeType)("CommentBlock", "CommentLine")),
          optional: true
        },
        tokens: {
          validate: (0, _utils.assertEach)(Object.assign(() => {
          }, {
            type: "any"
          })),
          optional: true
        }
      }
    });
    defineType("ForInStatement", {
      visitor: ["left", "right", "body"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop", "ForXStatement"],
      fields: {
        left: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("VariableDeclaration", "LVal") : (0, _utils.assertNodeType)("VariableDeclaration", "Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("ForStatement", {
      visitor: ["init", "test", "update", "body"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop"],
      fields: {
        init: {
          validate: (0, _utils.assertNodeType)("VariableDeclaration", "Expression"),
          optional: true
        },
        test: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        update: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    var functionCommon = () => ({
      params: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Identifier", "Pattern", "RestElement")))
      },
      generator: {
        default: false
      },
      async: {
        default: false
      }
    });
    exports.functionCommon = functionCommon;
    var functionTypeAnnotationCommon = () => ({
      returnType: {
        validate: (0, _utils.assertNodeType)(
          "TypeAnnotation",
          "TSTypeAnnotation",
          "Noop"
        ),
        optional: true
      },
      typeParameters: {
        validate: (0, _utils.assertNodeType)(
          "TypeParameterDeclaration",
          "TSTypeParameterDeclaration",
          "Noop"
        ),
        optional: true
      }
    });
    exports.functionTypeAnnotationCommon = functionTypeAnnotationCommon;
    var functionDeclarationCommon = () => Object.assign({}, functionCommon(), {
      declare: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      id: {
        validate: (0, _utils.assertNodeType)("Identifier"),
        optional: true
      }
    });
    exports.functionDeclarationCommon = functionDeclarationCommon;
    defineType("FunctionDeclaration", {
      builder: ["id", "params", "body", "generator", "async"],
      visitor: ["id", "params", "body", "returnType", "typeParameters"],
      fields: Object.assign({}, functionDeclarationCommon(), functionTypeAnnotationCommon(), {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      }),
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Statement", "Pureish", "Declaration"],
      validate: function() {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return () => {
          };
        const identifier3 = (0, _utils.assertNodeType)("Identifier");
        return function(parent, key, node) {
          if (!(0, _is.default)("ExportDefaultDeclaration", parent)) {
            identifier3(node, "id", node.id);
          }
        };
      }()
    });
    defineType("FunctionExpression", {
      inherits: "FunctionDeclaration",
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Expression", "Pureish"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      })
    });
    var patternLikeCommon = () => ({
      typeAnnotation: {
        validate: (0, _utils.assertNodeType)(
          "TypeAnnotation",
          "TSTypeAnnotation",
          "Noop"
        ),
        optional: true
      },
      decorators: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
        optional: true
      }
    });
    exports.patternLikeCommon = patternLikeCommon;
    defineType("Identifier", {
      builder: ["name"],
      visitor: ["typeAnnotation", "decorators"],
      aliases: ["Expression", "PatternLike", "LVal", "TSEntityName"],
      fields: Object.assign({}, patternLikeCommon(), {
        name: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (!(0, _isValidIdentifier.default)(val, false)) {
              throw new TypeError(`"${val}" is not a valid identifier name`);
            }
          }, {
            type: "string"
          }))
        },
        optional: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      }),
      validate(parent, key, node) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        const match = /\.(\w+)$/.exec(key);
        if (!match)
          return;
        const [, parentKey] = match;
        const nonComp = {
          computed: false
        };
        if (parentKey === "property") {
          if ((0, _is.default)("MemberExpression", parent, nonComp))
            return;
          if ((0, _is.default)("OptionalMemberExpression", parent, nonComp))
            return;
        } else if (parentKey === "key") {
          if ((0, _is.default)("Property", parent, nonComp))
            return;
          if ((0, _is.default)("Method", parent, nonComp))
            return;
        } else if (parentKey === "exported") {
          if ((0, _is.default)("ExportSpecifier", parent))
            return;
        } else if (parentKey === "imported") {
          if ((0, _is.default)("ImportSpecifier", parent, {
            imported: node
          }))
            return;
        } else if (parentKey === "meta") {
          if ((0, _is.default)("MetaProperty", parent, {
            meta: node
          }))
            return;
        }
        if (((0, _helperValidatorIdentifier.isKeyword)(node.name) || (0, _helperValidatorIdentifier.isReservedWord)(node.name, false)) && node.name !== "this") {
          throw new TypeError(`"${node.name}" is not a valid identifier`);
        }
      }
    });
    defineType("IfStatement", {
      visitor: ["test", "consequent", "alternate"],
      aliases: ["Statement", "Conditional"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        consequent: {
          validate: (0, _utils.assertNodeType)("Statement")
        },
        alternate: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("LabeledStatement", {
      visitor: ["label", "body"],
      aliases: ["Statement"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("StringLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("NumericLiteral", {
      builder: ["value"],
      deprecatedAlias: "NumberLiteral",
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("number")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("NullLiteral", {
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("BooleanLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("boolean")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("RegExpLiteral", {
      builder: ["pattern", "flags"],
      deprecatedAlias: "RegexLiteral",
      aliases: ["Expression", "Pureish", "Literal"],
      fields: {
        pattern: {
          validate: (0, _utils.assertValueType)("string")
        },
        flags: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            const invalid = /[^gimsuy]/.exec(val);
            if (invalid) {
              throw new TypeError(`"${invalid[0]}" is not a valid RegExp flag`);
            }
          }, {
            type: "string"
          })),
          default: ""
        }
      }
    });
    defineType("LogicalExpression", {
      builder: ["operator", "left", "right"],
      visitor: ["left", "right"],
      aliases: ["Binary", "Expression"],
      fields: {
        operator: {
          validate: (0, _utils.assertOneOf)(..._constants.LOGICAL_OPERATORS)
        },
        left: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("MemberExpression", {
      builder: ["object", "property", "computed", ...!process.env.BABEL_TYPES_8_BREAKING ? ["optional"] : []],
      visitor: ["object", "property"],
      aliases: ["Expression", "LVal"],
      fields: Object.assign({
        object: {
          validate: (0, _utils.assertNodeType)("Expression", "Super")
        },
        property: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            };
            validator.oneOfNodeTypes = ["Expression", "Identifier", "PrivateName"];
            return validator;
          }()
        },
        computed: {
          default: false
        }
      }, !process.env.BABEL_TYPES_8_BREAKING ? {
        optional: {
          validate: (0, _utils.assertOneOf)(true, false),
          optional: true
        }
      } : {})
    });
    defineType("NewExpression", {
      inherits: "CallExpression"
    });
    defineType("Program", {
      visitor: ["directives", "body"],
      builder: ["body", "directives", "sourceType", "interpreter"],
      fields: {
        sourceFile: {
          validate: (0, _utils.assertValueType)("string")
        },
        sourceType: {
          validate: (0, _utils.assertOneOf)("script", "module"),
          default: "script"
        },
        interpreter: {
          validate: (0, _utils.assertNodeType)("InterpreterDirective"),
          default: null,
          optional: true
        },
        directives: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Directive"))),
          default: []
        },
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "Block"]
    });
    defineType("ObjectExpression", {
      visitor: ["properties"],
      aliases: ["Expression"],
      fields: {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ObjectMethod", "ObjectProperty", "SpreadElement")))
        }
      }
    });
    defineType("ObjectMethod", {
      builder: ["kind", "key", "params", "body", "computed", "generator", "async"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        kind: Object.assign({
          validate: (0, _utils.assertOneOf)("method", "get", "set")
        }, !process.env.BABEL_TYPES_8_BREAKING ? {
          default: "method"
        } : {}),
        computed: {
          default: false
        },
        key: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            };
            validator.oneOfNodeTypes = ["Expression", "Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral"];
            return validator;
          }()
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      }),
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      aliases: ["UserWhitespacable", "Function", "Scopable", "BlockParent", "FunctionParent", "Method", "ObjectMember"]
    });
    defineType("ObjectProperty", {
      builder: ["key", "value", "computed", "shorthand", ...!process.env.BABEL_TYPES_8_BREAKING ? ["decorators"] : []],
      fields: {
        computed: {
          default: false
        },
        key: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = Object.assign(function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            }, {
              oneOfNodeTypes: ["Expression", "Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "PrivateName"]
            });
            return validator;
          }()
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression", "PatternLike")
        },
        shorthand: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("boolean"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.computed) {
              throw new TypeError("Property shorthand of ObjectProperty cannot be true if computed is true");
            }
          }, {
            type: "boolean"
          }), function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && !(0, _is.default)("Identifier", node.key)) {
              throw new TypeError("Property shorthand of ObjectProperty cannot be true if key is not an Identifier");
            }
          }),
          default: false
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      },
      visitor: ["key", "value", "decorators"],
      aliases: ["UserWhitespacable", "Property", "ObjectMember"],
      validate: function() {
        const pattern = (0, _utils.assertNodeType)("Identifier", "Pattern", "TSAsExpression", "TSSatisfiesExpression", "TSNonNullExpression", "TSTypeAssertion");
        const expression = (0, _utils.assertNodeType)("Expression");
        return function(parent, key, node) {
          if (!process.env.BABEL_TYPES_8_BREAKING)
            return;
          const validator = (0, _is.default)("ObjectPattern", parent) ? pattern : expression;
          validator(node, "value", node.value);
        };
      }()
    });
    defineType("RestElement", {
      visitor: ["argument", "typeAnnotation"],
      builder: ["argument"],
      aliases: ["LVal", "PatternLike"],
      deprecatedAlias: "RestProperty",
      fields: Object.assign({}, patternLikeCommon(), {
        argument: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("LVal") : (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        optional: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      }),
      validate(parent, key) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        const match = /(\w+)\[(\d+)\]/.exec(key);
        if (!match)
          throw new Error("Internal Babel error: malformed key.");
        const [, listKey, index] = match;
        if (parent[listKey].length > +index + 1) {
          throw new TypeError(`RestElement must be last element of ${listKey}`);
        }
      }
    });
    defineType("ReturnStatement", {
      visitor: ["argument"],
      aliases: ["Statement", "Terminatorless", "CompletionStatement"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        }
      }
    });
    defineType("SequenceExpression", {
      visitor: ["expressions"],
      fields: {
        expressions: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression")))
        }
      },
      aliases: ["Expression"]
    });
    defineType("ParenthesizedExpression", {
      visitor: ["expression"],
      aliases: ["Expression", "ExpressionWrapper"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("SwitchCase", {
      visitor: ["test", "consequent"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        consequent: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      }
    });
    defineType("SwitchStatement", {
      visitor: ["discriminant", "cases"],
      aliases: ["Statement", "BlockParent", "Scopable"],
      fields: {
        discriminant: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        cases: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("SwitchCase")))
        }
      }
    });
    defineType("ThisExpression", {
      aliases: ["Expression"]
    });
    defineType("ThrowStatement", {
      visitor: ["argument"],
      aliases: ["Statement", "Terminatorless", "CompletionStatement"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("TryStatement", {
      visitor: ["block", "handler", "finalizer"],
      aliases: ["Statement"],
      fields: {
        block: {
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("BlockStatement"), Object.assign(function(node) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (!node.handler && !node.finalizer) {
              throw new TypeError("TryStatement expects either a handler or finalizer, or both");
            }
          }, {
            oneOfNodeTypes: ["BlockStatement"]
          }))
        },
        handler: {
          optional: true,
          validate: (0, _utils.assertNodeType)("CatchClause")
        },
        finalizer: {
          optional: true,
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      }
    });
    defineType("UnaryExpression", {
      builder: ["operator", "argument", "prefix"],
      fields: {
        prefix: {
          default: true
        },
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        operator: {
          validate: (0, _utils.assertOneOf)(..._constants.UNARY_OPERATORS)
        }
      },
      visitor: ["argument"],
      aliases: ["UnaryLike", "Expression"]
    });
    defineType("UpdateExpression", {
      builder: ["operator", "argument", "prefix"],
      fields: {
        prefix: {
          default: false
        },
        argument: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("Expression") : (0, _utils.assertNodeType)("Identifier", "MemberExpression")
        },
        operator: {
          validate: (0, _utils.assertOneOf)(..._constants.UPDATE_OPERATORS)
        }
      },
      visitor: ["argument"],
      aliases: ["Expression"]
    });
    defineType("VariableDeclaration", {
      builder: ["kind", "declarations"],
      visitor: ["declarations"],
      aliases: ["Statement", "Declaration"],
      fields: {
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        kind: {
          validate: (0, _utils.assertOneOf)(
            "var",
            "let",
            "const",
            "using"
          )
        },
        declarations: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("VariableDeclarator")))
        }
      },
      validate(parent, key, node) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        if (!(0, _is.default)("ForXStatement", parent, {
          left: node
        }))
          return;
        if (node.declarations.length !== 1) {
          throw new TypeError(`Exactly one VariableDeclarator is required in the VariableDeclaration of a ${parent.type}`);
        }
      }
    });
    defineType("VariableDeclarator", {
      visitor: ["id", "init"],
      fields: {
        id: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertNodeType)("LVal");
            }
            const normal = (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern");
            const without = (0, _utils.assertNodeType)("Identifier");
            return function(node, key, val) {
              const validator = node.init ? normal : without;
              validator(node, key, val);
            };
          }()
        },
        definite: {
          optional: true,
          validate: (0, _utils.assertValueType)("boolean")
        },
        init: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("WhileStatement", {
      visitor: ["test", "body"],
      aliases: ["Statement", "BlockParent", "Loop", "While", "Scopable"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("WithStatement", {
      visitor: ["object", "body"],
      aliases: ["Statement"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("AssignmentPattern", {
      visitor: ["left", "right", "decorators"],
      builder: ["left", "right"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        left: {
          validate: (0, _utils.assertNodeType)("Identifier", "ObjectPattern", "ArrayPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      })
    });
    defineType("ArrayPattern", {
      visitor: ["elements", "typeAnnotation"],
      builder: ["elements"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeOrValueType)("null", "PatternLike", "LVal")))
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        optional: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      })
    });
    defineType("ArrowFunctionExpression", {
      builder: ["params", "body", "async"],
      visitor: ["params", "body", "returnType", "typeParameters"],
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Expression", "Pureish"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        expression: {
          validate: (0, _utils.assertValueType)("boolean")
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement", "Expression")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      })
    });
    defineType("ClassBody", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ClassMethod", "ClassPrivateMethod", "ClassProperty", "ClassPrivateProperty", "ClassAccessorProperty", "TSDeclareMethod", "TSIndexSignature", "StaticBlock")))
        }
      }
    });
    defineType("ClassExpression", {
      builder: ["id", "superClass", "body", "decorators"],
      visitor: ["id", "body", "superClass", "mixins", "typeParameters", "superTypeParameters", "implements", "decorators"],
      aliases: ["Scopable", "Class", "Expression"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)(
            "TypeParameterDeclaration",
            "TSTypeParameterDeclaration",
            "Noop"
          ),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("ClassBody")
        },
        superClass: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        },
        superTypeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        },
        implements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSExpressionWithTypeArguments", "ClassImplements"))),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        mixins: {
          validate: (0, _utils.assertNodeType)("InterfaceExtends"),
          optional: true
        }
      }
    });
    defineType("ClassDeclaration", {
      inherits: "ClassExpression",
      aliases: ["Scopable", "Class", "Statement", "Declaration"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)(
            "TypeParameterDeclaration",
            "TSTypeParameterDeclaration",
            "Noop"
          ),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("ClassBody")
        },
        superClass: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        },
        superTypeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        },
        implements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSExpressionWithTypeArguments", "ClassImplements"))),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        mixins: {
          validate: (0, _utils.assertNodeType)("InterfaceExtends"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        abstract: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      },
      validate: function() {
        const identifier3 = (0, _utils.assertNodeType)("Identifier");
        return function(parent, key, node) {
          if (!process.env.BABEL_TYPES_8_BREAKING)
            return;
          if (!(0, _is.default)("ExportDefaultDeclaration", parent)) {
            identifier3(node, "id", node.id);
          }
        };
      }()
    });
    defineType("ExportAllDeclaration", {
      visitor: ["source"],
      aliases: ["Statement", "Declaration", "ModuleDeclaration", "ExportDeclaration"],
      fields: {
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value")),
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        }
      }
    });
    defineType("ExportDefaultDeclaration", {
      visitor: ["declaration"],
      aliases: ["Statement", "Declaration", "ModuleDeclaration", "ExportDeclaration"],
      fields: {
        declaration: {
          validate: (0, _utils.assertNodeType)("TSDeclareFunction", "FunctionDeclaration", "ClassDeclaration", "Expression")
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("value"))
      }
    });
    defineType("ExportNamedDeclaration", {
      visitor: ["declaration", "specifiers", "source"],
      aliases: ["Statement", "Declaration", "ModuleDeclaration", "ExportDeclaration"],
      fields: {
        declaration: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("Declaration"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.specifiers.length) {
              throw new TypeError("Only declaration or specifiers is allowed on ExportNamedDeclaration");
            }
          }, {
            oneOfNodeTypes: ["Declaration"]
          }), function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.source) {
              throw new TypeError("Cannot export a declaration from a source");
            }
          })
        },
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        specifiers: {
          default: [],
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)(function() {
            const sourced = (0, _utils.assertNodeType)("ExportSpecifier", "ExportDefaultSpecifier", "ExportNamespaceSpecifier");
            const sourceless = (0, _utils.assertNodeType)("ExportSpecifier");
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return sourced;
            return function(node, key, val) {
              const validator = node.source ? sourced : sourceless;
              validator(node, key, val);
            };
          }()))
        },
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral"),
          optional: true
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value"))
      }
    });
    defineType("ExportSpecifier", {
      visitor: ["local", "exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        exportKind: {
          validate: (0, _utils.assertOneOf)("type", "value"),
          optional: true
        }
      }
    });
    defineType("ForOfStatement", {
      visitor: ["left", "right", "body"],
      builder: ["left", "right", "body", "await"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop", "ForXStatement"],
      fields: {
        left: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertNodeType)("VariableDeclaration", "LVal");
            }
            const declaration = (0, _utils.assertNodeType)("VariableDeclaration");
            const lval = (0, _utils.assertNodeType)("Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression");
            return function(node, key, val) {
              if ((0, _is.default)("VariableDeclaration", val)) {
                declaration(node, key, val);
              } else {
                lval(node, key, val);
              }
            };
          }()
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        },
        await: {
          default: false
        }
      }
    });
    defineType("ImportDeclaration", {
      visitor: ["specifiers", "source"],
      aliases: ["Statement", "Declaration", "ModuleDeclaration"],
      fields: {
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        module: {
          optional: true,
          validate: (0, _utils.assertValueType)("boolean")
        },
        specifiers: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportSpecifier", "ImportDefaultSpecifier", "ImportNamespaceSpecifier")))
        },
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        },
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "typeof", "value"),
          optional: true
        }
      }
    });
    defineType("ImportDefaultSpecifier", {
      visitor: ["local"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("ImportNamespaceSpecifier", {
      visitor: ["local"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("ImportSpecifier", {
      visitor: ["local", "imported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        imported: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "typeof", "value"),
          optional: true
        }
      }
    });
    defineType("MetaProperty", {
      visitor: ["meta", "property"],
      aliases: ["Expression"],
      fields: {
        meta: {
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("Identifier"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            let property;
            switch (val.name) {
              case "function":
                property = "sent";
                break;
              case "new":
                property = "target";
                break;
              case "import":
                property = "meta";
                break;
            }
            if (!(0, _is.default)("Identifier", node.property, {
              name: property
            })) {
              throw new TypeError("Unrecognised MetaProperty");
            }
          }, {
            oneOfNodeTypes: ["Identifier"]
          }))
        },
        property: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    var classMethodOrPropertyCommon = () => ({
      abstract: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      accessibility: {
        validate: (0, _utils.assertOneOf)("public", "private", "protected"),
        optional: true
      },
      static: {
        default: false
      },
      override: {
        default: false
      },
      computed: {
        default: false
      },
      optional: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      key: {
        validate: (0, _utils.chain)(function() {
          const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral");
          const computed = (0, _utils.assertNodeType)("Expression");
          return function(node, key, val) {
            const validator = node.computed ? computed : normal;
            validator(node, key, val);
          };
        }(), (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression"))
      }
    });
    exports.classMethodOrPropertyCommon = classMethodOrPropertyCommon;
    var classMethodOrDeclareMethodCommon = () => Object.assign({}, functionCommon(), classMethodOrPropertyCommon(), {
      params: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Identifier", "Pattern", "RestElement", "TSParameterProperty")))
      },
      kind: {
        validate: (0, _utils.assertOneOf)("get", "set", "method", "constructor"),
        default: "method"
      },
      access: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), (0, _utils.assertOneOf)("public", "private", "protected")),
        optional: true
      },
      decorators: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
        optional: true
      }
    });
    exports.classMethodOrDeclareMethodCommon = classMethodOrDeclareMethodCommon;
    defineType("ClassMethod", {
      aliases: ["Function", "Scopable", "BlockParent", "FunctionParent", "Method"],
      builder: ["kind", "key", "params", "body", "computed", "static", "generator", "async"],
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      })
    });
    defineType("ObjectPattern", {
      visitor: ["properties", "typeAnnotation", "decorators"],
      builder: ["properties"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("RestElement", "ObjectProperty")))
        }
      })
    });
    defineType("SpreadElement", {
      visitor: ["argument"],
      aliases: ["UnaryLike"],
      deprecatedAlias: "SpreadProperty",
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("Super", {
      aliases: ["Expression"]
    });
    defineType("TaggedTemplateExpression", {
      visitor: ["tag", "quasi", "typeParameters"],
      builder: ["tag", "quasi"],
      aliases: ["Expression"],
      fields: {
        tag: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        quasi: {
          validate: (0, _utils.assertNodeType)("TemplateLiteral")
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("TemplateElement", {
      builder: ["value", "tail"],
      fields: {
        value: {
          validate: (0, _utils.chain)((0, _utils.assertShape)({
            raw: {
              validate: (0, _utils.assertValueType)("string")
            },
            cooked: {
              validate: (0, _utils.assertValueType)("string"),
              optional: true
            }
          }), function templateElementCookedValidator(node) {
            const raw = node.value.raw;
            let unterminatedCalled = false;
            const error = () => {
              throw new Error("Internal @babel/types error.");
            };
            const {
              str,
              firstInvalidLoc
            } = (0, _helperStringParser.readStringContents)("template", raw, 0, 0, 0, {
              unterminated() {
                unterminatedCalled = true;
              },
              strictNumericEscape: error,
              invalidEscapeSequence: error,
              numericSeparatorInEscapeSequence: error,
              unexpectedNumericSeparator: error,
              invalidDigit: error,
              invalidCodePoint: error
            });
            if (!unterminatedCalled)
              throw new Error("Invalid raw");
            node.value.cooked = firstInvalidLoc ? null : str;
          })
        },
        tail: {
          default: false
        }
      }
    });
    defineType("TemplateLiteral", {
      visitor: ["quasis", "expressions"],
      aliases: ["Expression", "Literal"],
      fields: {
        quasis: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TemplateElement")))
        },
        expressions: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)(
            "Expression",
            "TSType"
          )), function(node, key, val) {
            if (node.quasis.length !== val.length + 1) {
              throw new TypeError(`Number of ${node.type} quasis should be exactly one more than the number of expressions.
Expected ${val.length + 1} quasis but got ${node.quasis.length}`);
            }
          })
        }
      }
    });
    defineType("YieldExpression", {
      builder: ["argument", "delegate"],
      visitor: ["argument"],
      aliases: ["Expression", "Terminatorless"],
      fields: {
        delegate: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("boolean"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && !node.argument) {
              throw new TypeError("Property delegate of YieldExpression cannot be true if there is no argument");
            }
          }, {
            type: "boolean"
          })),
          default: false
        },
        argument: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("AwaitExpression", {
      builder: ["argument"],
      visitor: ["argument"],
      aliases: ["Expression", "Terminatorless"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("Import", {
      aliases: ["Expression"]
    });
    defineType("BigIntLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("ExportNamespaceSpecifier", {
      visitor: ["exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("OptionalMemberExpression", {
      builder: ["object", "property", "computed", "optional"],
      visitor: ["object", "property"],
      aliases: ["Expression"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        property: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = Object.assign(
              function(node, key, val) {
                const validator2 = node.computed ? computed : normal;
                validator2(node, key, val);
              },
              {
                oneOfNodeTypes: ["Expression", "Identifier"]
              }
            );
            return validator;
          }()
        },
        computed: {
          default: false
        },
        optional: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertValueType)("boolean") : (0, _utils.chain)((0, _utils.assertValueType)("boolean"), (0, _utils.assertOptionalChainStart)())
        }
      }
    });
    defineType("OptionalCallExpression", {
      visitor: ["callee", "arguments", "typeParameters", "typeArguments"],
      builder: ["callee", "arguments", "optional"],
      aliases: ["Expression"],
      fields: {
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        arguments: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement", "JSXNamespacedName", "ArgumentPlaceholder")))
        },
        optional: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertValueType)("boolean") : (0, _utils.chain)((0, _utils.assertValueType)("boolean"), (0, _utils.assertOptionalChainStart)())
        },
        typeArguments: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("ClassProperty", {
      visitor: ["key", "value", "typeAnnotation", "decorators"],
      builder: ["key", "value", "typeAnnotation", "decorators", "computed", "static"],
      aliases: ["Property"],
      fields: Object.assign({}, classMethodOrPropertyCommon(), {
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)(
            "TypeAnnotation",
            "TSTypeAnnotation",
            "Noop"
          ),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      })
    });
    defineType("ClassAccessorProperty", {
      visitor: ["key", "value", "typeAnnotation", "decorators"],
      builder: ["key", "value", "typeAnnotation", "decorators", "computed", "static"],
      aliases: ["Property", "Accessor"],
      fields: Object.assign({}, classMethodOrPropertyCommon(), {
        key: {
          validate: (0, _utils.chain)(function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            return function(node, key, val) {
              const validator = node.computed ? computed : normal;
              validator(node, key, val);
            };
          }(), (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression", "PrivateName"))
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)(
            "TypeAnnotation",
            "TSTypeAnnotation",
            "Noop"
          ),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      })
    });
    defineType("ClassPrivateProperty", {
      visitor: ["key", "value", "decorators", "typeAnnotation"],
      builder: ["key", "value", "decorators", "static"],
      aliases: ["Property", "Private"],
      fields: {
        key: {
          validate: (0, _utils.assertNodeType)("PrivateName")
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)(
            "TypeAnnotation",
            "TSTypeAnnotation",
            "Noop"
          ),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        static: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      }
    });
    defineType("ClassPrivateMethod", {
      builder: ["kind", "key", "params", "body", "static"],
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      aliases: ["Function", "Scopable", "BlockParent", "FunctionParent", "Method", "Private"],
      fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), {
        kind: {
          validate: (0, _utils.assertOneOf)("get", "set", "method"),
          default: "method"
        },
        key: {
          validate: (0, _utils.assertNodeType)("PrivateName")
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      })
    });
    defineType("PrivateName", {
      visitor: ["id"],
      aliases: ["Private"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("StaticBlock", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "FunctionParent"]
    });
  }
});

// node_modules/@babel/types/lib/definitions/flow.js
var require_flow = __commonJS({
  "node_modules/@babel/types/lib/definitions/flow.js"() {
    "use strict";
    var _utils = require_utils6();
    var defineType = (0, _utils.defineAliasedType)("Flow");
    var defineInterfaceishType = (name) => {
      defineType(name, {
        builder: ["id", "typeParameters", "extends", "body"],
        visitor: ["id", "typeParameters", "extends", "mixins", "implements", "body"],
        aliases: ["FlowDeclaration", "Statement", "Declaration"],
        fields: {
          id: (0, _utils.validateType)("Identifier"),
          typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
          extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends")),
          mixins: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends")),
          implements: (0, _utils.validateOptional)((0, _utils.arrayOfType)("ClassImplements")),
          body: (0, _utils.validateType)("ObjectTypeAnnotation")
        }
      });
    };
    defineType("AnyTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ArrayTypeAnnotation", {
      visitor: ["elementType"],
      aliases: ["FlowType"],
      fields: {
        elementType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("BooleanTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("BooleanLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("NullLiteralTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ClassImplements", {
      visitor: ["id", "typeParameters"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineInterfaceishType("DeclareClass");
    defineType("DeclareFunction", {
      visitor: ["id"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        predicate: (0, _utils.validateOptionalType)("DeclaredPredicate")
      }
    });
    defineInterfaceishType("DeclareInterface");
    defineType("DeclareModule", {
      builder: ["id", "body", "kind"],
      visitor: ["id", "body"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        body: (0, _utils.validateType)("BlockStatement"),
        kind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("CommonJS", "ES"))
      }
    });
    defineType("DeclareModuleExports", {
      visitor: ["typeAnnotation"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TypeAnnotation")
      }
    });
    defineType("DeclareTypeAlias", {
      visitor: ["id", "typeParameters", "right"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        right: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("DeclareOpaqueType", {
      visitor: ["id", "typeParameters", "supertype"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        supertype: (0, _utils.validateOptionalType)("FlowType"),
        impltype: (0, _utils.validateOptionalType)("FlowType")
      }
    });
    defineType("DeclareVariable", {
      visitor: ["id"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("DeclareExportDeclaration", {
      visitor: ["declaration", "specifiers", "source"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        declaration: (0, _utils.validateOptionalType)("Flow"),
        specifiers: (0, _utils.validateOptional)((0, _utils.arrayOfType)(["ExportSpecifier", "ExportNamespaceSpecifier"])),
        source: (0, _utils.validateOptionalType)("StringLiteral"),
        default: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("DeclareExportAllDeclaration", {
      visitor: ["source"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        source: (0, _utils.validateType)("StringLiteral"),
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value"))
      }
    });
    defineType("DeclaredPredicate", {
      visitor: ["value"],
      aliases: ["FlowPredicate"],
      fields: {
        value: (0, _utils.validateType)("Flow")
      }
    });
    defineType("ExistsTypeAnnotation", {
      aliases: ["FlowType"]
    });
    defineType("FunctionTypeAnnotation", {
      visitor: ["typeParameters", "params", "rest", "returnType"],
      aliases: ["FlowType"],
      fields: {
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        params: (0, _utils.validate)((0, _utils.arrayOfType)("FunctionTypeParam")),
        rest: (0, _utils.validateOptionalType)("FunctionTypeParam"),
        this: (0, _utils.validateOptionalType)("FunctionTypeParam"),
        returnType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("FunctionTypeParam", {
      visitor: ["name", "typeAnnotation"],
      fields: {
        name: (0, _utils.validateOptionalType)("Identifier"),
        typeAnnotation: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("GenericTypeAnnotation", {
      visitor: ["id", "typeParameters"],
      aliases: ["FlowType"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"]),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineType("InferredPredicate", {
      aliases: ["FlowPredicate"]
    });
    defineType("InterfaceExtends", {
      visitor: ["id", "typeParameters"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"]),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineInterfaceishType("InterfaceDeclaration");
    defineType("InterfaceTypeAnnotation", {
      visitor: ["extends", "body"],
      aliases: ["FlowType"],
      fields: {
        extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends")),
        body: (0, _utils.validateType)("ObjectTypeAnnotation")
      }
    });
    defineType("IntersectionTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("MixedTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("EmptyTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("NullableTypeAnnotation", {
      visitor: ["typeAnnotation"],
      aliases: ["FlowType"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("NumberLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("number"))
      }
    });
    defineType("NumberTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ObjectTypeAnnotation", {
      visitor: ["properties", "indexers", "callProperties", "internalSlots"],
      aliases: ["FlowType"],
      builder: ["properties", "indexers", "callProperties", "internalSlots", "exact"],
      fields: {
        properties: (0, _utils.validate)((0, _utils.arrayOfType)(["ObjectTypeProperty", "ObjectTypeSpreadProperty"])),
        indexers: {
          validate: (0, _utils.arrayOfType)("ObjectTypeIndexer"),
          optional: true,
          default: []
        },
        callProperties: {
          validate: (0, _utils.arrayOfType)("ObjectTypeCallProperty"),
          optional: true,
          default: []
        },
        internalSlots: {
          validate: (0, _utils.arrayOfType)("ObjectTypeInternalSlot"),
          optional: true,
          default: []
        },
        exact: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        },
        inexact: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeInternalSlot", {
      visitor: ["id", "value", "optional", "static", "method"],
      aliases: ["UserWhitespacable"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        value: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        method: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeCallProperty", {
      visitor: ["value"],
      aliases: ["UserWhitespacable"],
      fields: {
        value: (0, _utils.validateType)("FlowType"),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeIndexer", {
      visitor: ["id", "key", "value", "variance"],
      aliases: ["UserWhitespacable"],
      fields: {
        id: (0, _utils.validateOptionalType)("Identifier"),
        key: (0, _utils.validateType)("FlowType"),
        value: (0, _utils.validateType)("FlowType"),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        variance: (0, _utils.validateOptionalType)("Variance")
      }
    });
    defineType("ObjectTypeProperty", {
      visitor: ["key", "value", "variance"],
      aliases: ["UserWhitespacable"],
      fields: {
        key: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        value: (0, _utils.validateType)("FlowType"),
        kind: (0, _utils.validate)((0, _utils.assertOneOf)("init", "get", "set")),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        proto: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        variance: (0, _utils.validateOptionalType)("Variance"),
        method: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeSpreadProperty", {
      visitor: ["argument"],
      aliases: ["UserWhitespacable"],
      fields: {
        argument: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("OpaqueType", {
      visitor: ["id", "typeParameters", "supertype", "impltype"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        supertype: (0, _utils.validateOptionalType)("FlowType"),
        impltype: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("QualifiedTypeIdentifier", {
      visitor: ["id", "qualification"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        qualification: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"])
      }
    });
    defineType("StringLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("string"))
      }
    });
    defineType("StringTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("SymbolTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ThisTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("TupleTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("TypeofTypeAnnotation", {
      visitor: ["argument"],
      aliases: ["FlowType"],
      fields: {
        argument: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeAlias", {
      visitor: ["id", "typeParameters", "right"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        right: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeAnnotation", {
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeCastExpression", {
      visitor: ["expression", "typeAnnotation"],
      aliases: ["ExpressionWrapper", "Expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeAnnotation: (0, _utils.validateType)("TypeAnnotation")
      }
    });
    defineType("TypeParameter", {
      visitor: ["bound", "default", "variance"],
      fields: {
        name: (0, _utils.validate)((0, _utils.assertValueType)("string")),
        bound: (0, _utils.validateOptionalType)("TypeAnnotation"),
        default: (0, _utils.validateOptionalType)("FlowType"),
        variance: (0, _utils.validateOptionalType)("Variance")
      }
    });
    defineType("TypeParameterDeclaration", {
      visitor: ["params"],
      fields: {
        params: (0, _utils.validate)((0, _utils.arrayOfType)("TypeParameter"))
      }
    });
    defineType("TypeParameterInstantiation", {
      visitor: ["params"],
      fields: {
        params: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("UnionTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("Variance", {
      builder: ["kind"],
      fields: {
        kind: (0, _utils.validate)((0, _utils.assertOneOf)("minus", "plus"))
      }
    });
    defineType("VoidTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("EnumDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "body"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        body: (0, _utils.validateType)(["EnumBooleanBody", "EnumNumberBody", "EnumStringBody", "EnumSymbolBody"])
      }
    });
    defineType("EnumBooleanBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)("EnumBooleanMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumNumberBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)("EnumNumberMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumStringBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)(["EnumStringMember", "EnumDefaultedMember"]),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumSymbolBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        members: (0, _utils.validateArrayOfType)("EnumDefaultedMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumBooleanMember", {
      aliases: ["EnumMember"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("BooleanLiteral")
      }
    });
    defineType("EnumNumberMember", {
      aliases: ["EnumMember"],
      visitor: ["id", "init"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("NumericLiteral")
      }
    });
    defineType("EnumStringMember", {
      aliases: ["EnumMember"],
      visitor: ["id", "init"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("StringLiteral")
      }
    });
    defineType("EnumDefaultedMember", {
      aliases: ["EnumMember"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("IndexedAccessType", {
      visitor: ["objectType", "indexType"],
      aliases: ["FlowType"],
      fields: {
        objectType: (0, _utils.validateType)("FlowType"),
        indexType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("OptionalIndexedAccessType", {
      visitor: ["objectType", "indexType"],
      aliases: ["FlowType"],
      fields: {
        objectType: (0, _utils.validateType)("FlowType"),
        indexType: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
  }
});

// node_modules/@babel/types/lib/definitions/jsx.js
var require_jsx = __commonJS({
  "node_modules/@babel/types/lib/definitions/jsx.js"() {
    "use strict";
    var _utils = require_utils6();
    var defineType = (0, _utils.defineAliasedType)("JSX");
    defineType("JSXAttribute", {
      visitor: ["name", "value"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXNamespacedName")
        },
        value: {
          optional: true,
          validate: (0, _utils.assertNodeType)("JSXElement", "JSXFragment", "StringLiteral", "JSXExpressionContainer")
        }
      }
    });
    defineType("JSXClosingElement", {
      visitor: ["name"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName")
        }
      }
    });
    defineType("JSXElement", {
      builder: ["openingElement", "closingElement", "children", "selfClosing"],
      visitor: ["openingElement", "children", "closingElement"],
      aliases: ["Immutable", "Expression"],
      fields: Object.assign({
        openingElement: {
          validate: (0, _utils.assertNodeType)("JSXOpeningElement")
        },
        closingElement: {
          optional: true,
          validate: (0, _utils.assertNodeType)("JSXClosingElement")
        },
        children: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")))
        }
      }, {
        selfClosing: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      })
    });
    defineType("JSXEmptyExpression", {});
    defineType("JSXExpressionContainer", {
      visitor: ["expression"],
      aliases: ["Immutable"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression", "JSXEmptyExpression")
        }
      }
    });
    defineType("JSXSpreadChild", {
      visitor: ["expression"],
      aliases: ["Immutable"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("JSXIdentifier", {
      builder: ["name"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("JSXMemberExpression", {
      visitor: ["object", "property"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("JSXMemberExpression", "JSXIdentifier")
        },
        property: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        }
      }
    });
    defineType("JSXNamespacedName", {
      visitor: ["namespace", "name"],
      fields: {
        namespace: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        },
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        }
      }
    });
    defineType("JSXOpeningElement", {
      builder: ["name", "attributes", "selfClosing"],
      visitor: ["name", "attributes"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName")
        },
        selfClosing: {
          default: false
        },
        attributes: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXAttribute", "JSXSpreadAttribute")))
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("JSXSpreadAttribute", {
      visitor: ["argument"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("JSXText", {
      aliases: ["Immutable"],
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("JSXFragment", {
      builder: ["openingFragment", "closingFragment", "children"],
      visitor: ["openingFragment", "children", "closingFragment"],
      aliases: ["Immutable", "Expression"],
      fields: {
        openingFragment: {
          validate: (0, _utils.assertNodeType)("JSXOpeningFragment")
        },
        closingFragment: {
          validate: (0, _utils.assertNodeType)("JSXClosingFragment")
        },
        children: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")))
        }
      }
    });
    defineType("JSXOpeningFragment", {
      aliases: ["Immutable"]
    });
    defineType("JSXClosingFragment", {
      aliases: ["Immutable"]
    });
  }
});

// node_modules/@babel/types/lib/definitions/placeholders.js
var require_placeholders = __commonJS({
  "node_modules/@babel/types/lib/definitions/placeholders.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.PLACEHOLDERS_FLIPPED_ALIAS = exports.PLACEHOLDERS_ALIAS = exports.PLACEHOLDERS = void 0;
    var _utils = require_utils6();
    var PLACEHOLDERS = ["Identifier", "StringLiteral", "Expression", "Statement", "Declaration", "BlockStatement", "ClassBody", "Pattern"];
    exports.PLACEHOLDERS = PLACEHOLDERS;
    var PLACEHOLDERS_ALIAS = {
      Declaration: ["Statement"],
      Pattern: ["PatternLike", "LVal"]
    };
    exports.PLACEHOLDERS_ALIAS = PLACEHOLDERS_ALIAS;
    for (const type of PLACEHOLDERS) {
      const alias = _utils.ALIAS_KEYS[type];
      if (alias != null && alias.length)
        PLACEHOLDERS_ALIAS[type] = alias;
    }
    var PLACEHOLDERS_FLIPPED_ALIAS = {};
    exports.PLACEHOLDERS_FLIPPED_ALIAS = PLACEHOLDERS_FLIPPED_ALIAS;
    Object.keys(PLACEHOLDERS_ALIAS).forEach((type) => {
      PLACEHOLDERS_ALIAS[type].forEach((alias) => {
        if (!Object.hasOwnProperty.call(PLACEHOLDERS_FLIPPED_ALIAS, alias)) {
          PLACEHOLDERS_FLIPPED_ALIAS[alias] = [];
        }
        PLACEHOLDERS_FLIPPED_ALIAS[alias].push(type);
      });
    });
  }
});

// node_modules/@babel/types/lib/definitions/misc.js
var require_misc = __commonJS({
  "node_modules/@babel/types/lib/definitions/misc.js"() {
    "use strict";
    var _utils = require_utils6();
    var _placeholders = require_placeholders();
    var defineType = (0, _utils.defineAliasedType)("Miscellaneous");
    {
      defineType("Noop", {
        visitor: []
      });
    }
    defineType("Placeholder", {
      visitor: [],
      builder: ["expectedNode", "name"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        expectedNode: {
          validate: (0, _utils.assertOneOf)(..._placeholders.PLACEHOLDERS)
        }
      }
    });
    defineType("V8IntrinsicIdentifier", {
      builder: ["name"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
  }
});

// node_modules/@babel/types/lib/definitions/experimental.js
var require_experimental = __commonJS({
  "node_modules/@babel/types/lib/definitions/experimental.js"() {
    "use strict";
    var _utils = require_utils6();
    (0, _utils.default)("ArgumentPlaceholder", {});
    (0, _utils.default)("BindExpression", {
      visitor: ["object", "callee"],
      aliases: ["Expression"],
      fields: !process.env.BABEL_TYPES_8_BREAKING ? {
        object: {
          validate: Object.assign(() => {
          }, {
            oneOfNodeTypes: ["Expression"]
          })
        },
        callee: {
          validate: Object.assign(() => {
          }, {
            oneOfNodeTypes: ["Expression"]
          })
        }
      } : {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    (0, _utils.default)("ImportAttribute", {
      visitor: ["key", "value"],
      fields: {
        key: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        value: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        }
      }
    });
    (0, _utils.default)("Decorator", {
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    (0, _utils.default)("DoExpression", {
      visitor: ["body"],
      builder: ["body", "async"],
      aliases: ["Expression"],
      fields: {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        async: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        }
      }
    });
    (0, _utils.default)("ExportDefaultSpecifier", {
      visitor: ["exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    (0, _utils.default)("RecordExpression", {
      visitor: ["properties"],
      aliases: ["Expression"],
      fields: {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ObjectProperty", "SpreadElement")))
        }
      }
    });
    (0, _utils.default)("TupleExpression", {
      fields: {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement"))),
          default: []
        }
      },
      visitor: ["elements"],
      aliases: ["Expression"]
    });
    (0, _utils.default)("DecimalLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    (0, _utils.default)("ModuleExpression", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.assertNodeType)("Program")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("TopicReference", {
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelineTopicExpression", {
      builder: ["expression"],
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelineBareFunction", {
      builder: ["callee"],
      visitor: ["callee"],
      fields: {
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelinePrimaryTopicReference", {
      aliases: ["Expression"]
    });
  }
});

// node_modules/@babel/types/lib/definitions/typescript.js
var require_typescript = __commonJS({
  "node_modules/@babel/types/lib/definitions/typescript.js"() {
    "use strict";
    var _utils = require_utils6();
    var _core = require_core();
    var _is = require_is();
    var defineType = (0, _utils.defineAliasedType)("TypeScript");
    var bool = (0, _utils.assertValueType)("boolean");
    var tSFunctionTypeAnnotationCommon = () => ({
      returnType: {
        validate: (0, _utils.assertNodeType)("TSTypeAnnotation", "Noop"),
        optional: true
      },
      typeParameters: {
        validate: (0, _utils.assertNodeType)("TSTypeParameterDeclaration", "Noop"),
        optional: true
      }
    });
    defineType("TSParameterProperty", {
      aliases: ["LVal"],
      visitor: ["parameter"],
      fields: {
        accessibility: {
          validate: (0, _utils.assertOneOf)("public", "private", "protected"),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        parameter: {
          validate: (0, _utils.assertNodeType)("Identifier", "AssignmentPattern")
        },
        override: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      }
    });
    defineType("TSDeclareFunction", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "params", "returnType"],
      fields: Object.assign({}, (0, _core.functionDeclarationCommon)(), tSFunctionTypeAnnotationCommon())
    });
    defineType("TSDeclareMethod", {
      visitor: ["decorators", "key", "typeParameters", "params", "returnType"],
      fields: Object.assign({}, (0, _core.classMethodOrDeclareMethodCommon)(), tSFunctionTypeAnnotationCommon())
    });
    defineType("TSQualifiedName", {
      aliases: ["TSEntityName"],
      visitor: ["left", "right"],
      fields: {
        left: (0, _utils.validateType)("TSEntityName"),
        right: (0, _utils.validateType)("Identifier")
      }
    });
    var signatureDeclarationCommon = () => ({
      typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
      ["parameters"]: (0, _utils.validateArrayOfType)(["Identifier", "RestElement"]),
      ["typeAnnotation"]: (0, _utils.validateOptionalType)("TSTypeAnnotation")
    });
    var callConstructSignatureDeclaration = {
      aliases: ["TSTypeElement"],
      visitor: ["typeParameters", "parameters", "typeAnnotation"],
      fields: signatureDeclarationCommon()
    };
    defineType("TSCallSignatureDeclaration", callConstructSignatureDeclaration);
    defineType("TSConstructSignatureDeclaration", callConstructSignatureDeclaration);
    var namedTypeElementCommon = () => ({
      key: (0, _utils.validateType)("Expression"),
      computed: {
        default: false
      },
      optional: (0, _utils.validateOptional)(bool)
    });
    defineType("TSPropertySignature", {
      aliases: ["TSTypeElement"],
      visitor: ["key", "typeAnnotation", "initializer"],
      fields: Object.assign({}, namedTypeElementCommon(), {
        readonly: (0, _utils.validateOptional)(bool),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation"),
        initializer: (0, _utils.validateOptionalType)("Expression"),
        kind: {
          validate: (0, _utils.assertOneOf)("get", "set")
        }
      })
    });
    defineType("TSMethodSignature", {
      aliases: ["TSTypeElement"],
      visitor: ["key", "typeParameters", "parameters", "typeAnnotation"],
      fields: Object.assign({}, signatureDeclarationCommon(), namedTypeElementCommon(), {
        kind: {
          validate: (0, _utils.assertOneOf)("method", "get", "set")
        }
      })
    });
    defineType("TSIndexSignature", {
      aliases: ["TSTypeElement"],
      visitor: ["parameters", "typeAnnotation"],
      fields: {
        readonly: (0, _utils.validateOptional)(bool),
        static: (0, _utils.validateOptional)(bool),
        parameters: (0, _utils.validateArrayOfType)("Identifier"),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation")
      }
    });
    var tsKeywordTypes = ["TSAnyKeyword", "TSBooleanKeyword", "TSBigIntKeyword", "TSIntrinsicKeyword", "TSNeverKeyword", "TSNullKeyword", "TSNumberKeyword", "TSObjectKeyword", "TSStringKeyword", "TSSymbolKeyword", "TSUndefinedKeyword", "TSUnknownKeyword", "TSVoidKeyword"];
    for (const type of tsKeywordTypes) {
      defineType(type, {
        aliases: ["TSType", "TSBaseType"],
        visitor: [],
        fields: {}
      });
    }
    defineType("TSThisType", {
      aliases: ["TSType", "TSBaseType"],
      visitor: [],
      fields: {}
    });
    var fnOrCtrBase = {
      aliases: ["TSType"],
      visitor: ["typeParameters", "parameters", "typeAnnotation"]
    };
    defineType("TSFunctionType", Object.assign({}, fnOrCtrBase, {
      fields: signatureDeclarationCommon()
    }));
    defineType("TSConstructorType", Object.assign({}, fnOrCtrBase, {
      fields: Object.assign({}, signatureDeclarationCommon(), {
        abstract: (0, _utils.validateOptional)(bool)
      })
    }));
    defineType("TSTypeReference", {
      aliases: ["TSType"],
      visitor: ["typeName", "typeParameters"],
      fields: {
        typeName: (0, _utils.validateType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSTypePredicate", {
      aliases: ["TSType"],
      visitor: ["parameterName", "typeAnnotation"],
      builder: ["parameterName", "typeAnnotation", "asserts"],
      fields: {
        parameterName: (0, _utils.validateType)(["Identifier", "TSThisType"]),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation"),
        asserts: (0, _utils.validateOptional)(bool)
      }
    });
    defineType("TSTypeQuery", {
      aliases: ["TSType"],
      visitor: ["exprName", "typeParameters"],
      fields: {
        exprName: (0, _utils.validateType)(["TSEntityName", "TSImportType"]),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSTypeLiteral", {
      aliases: ["TSType"],
      visitor: ["members"],
      fields: {
        members: (0, _utils.validateArrayOfType)("TSTypeElement")
      }
    });
    defineType("TSArrayType", {
      aliases: ["TSType"],
      visitor: ["elementType"],
      fields: {
        elementType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSTupleType", {
      aliases: ["TSType"],
      visitor: ["elementTypes"],
      fields: {
        elementTypes: (0, _utils.validateArrayOfType)(["TSType", "TSNamedTupleMember"])
      }
    });
    defineType("TSOptionalType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSRestType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSNamedTupleMember", {
      visitor: ["label", "elementType"],
      builder: ["label", "elementType", "optional"],
      fields: {
        label: (0, _utils.validateType)("Identifier"),
        optional: {
          validate: bool,
          default: false
        },
        elementType: (0, _utils.validateType)("TSType")
      }
    });
    var unionOrIntersection = {
      aliases: ["TSType"],
      visitor: ["types"],
      fields: {
        types: (0, _utils.validateArrayOfType)("TSType")
      }
    };
    defineType("TSUnionType", unionOrIntersection);
    defineType("TSIntersectionType", unionOrIntersection);
    defineType("TSConditionalType", {
      aliases: ["TSType"],
      visitor: ["checkType", "extendsType", "trueType", "falseType"],
      fields: {
        checkType: (0, _utils.validateType)("TSType"),
        extendsType: (0, _utils.validateType)("TSType"),
        trueType: (0, _utils.validateType)("TSType"),
        falseType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSInferType", {
      aliases: ["TSType"],
      visitor: ["typeParameter"],
      fields: {
        typeParameter: (0, _utils.validateType)("TSTypeParameter")
      }
    });
    defineType("TSParenthesizedType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSTypeOperator", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        operator: (0, _utils.validate)((0, _utils.assertValueType)("string")),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSIndexedAccessType", {
      aliases: ["TSType"],
      visitor: ["objectType", "indexType"],
      fields: {
        objectType: (0, _utils.validateType)("TSType"),
        indexType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSMappedType", {
      aliases: ["TSType"],
      visitor: ["typeParameter", "typeAnnotation", "nameType"],
      fields: {
        readonly: (0, _utils.validateOptional)((0, _utils.assertOneOf)(true, false, "+", "-")),
        typeParameter: (0, _utils.validateType)("TSTypeParameter"),
        optional: (0, _utils.validateOptional)((0, _utils.assertOneOf)(true, false, "+", "-")),
        typeAnnotation: (0, _utils.validateOptionalType)("TSType"),
        nameType: (0, _utils.validateOptionalType)("TSType")
      }
    });
    defineType("TSLiteralType", {
      aliases: ["TSType", "TSBaseType"],
      visitor: ["literal"],
      fields: {
        literal: {
          validate: function() {
            const unaryExpression = (0, _utils.assertNodeType)("NumericLiteral", "BigIntLiteral");
            const unaryOperator = (0, _utils.assertOneOf)("-");
            const literal = (0, _utils.assertNodeType)("NumericLiteral", "StringLiteral", "BooleanLiteral", "BigIntLiteral", "TemplateLiteral");
            function validator(parent, key, node) {
              if ((0, _is.default)("UnaryExpression", node)) {
                unaryOperator(node, "operator", node.operator);
                unaryExpression(node, "argument", node.argument);
              } else {
                literal(parent, key, node);
              }
            }
            validator.oneOfNodeTypes = ["NumericLiteral", "StringLiteral", "BooleanLiteral", "BigIntLiteral", "TemplateLiteral", "UnaryExpression"];
            return validator;
          }()
        }
      }
    });
    defineType("TSExpressionWithTypeArguments", {
      aliases: ["TSType"],
      visitor: ["expression", "typeParameters"],
      fields: {
        expression: (0, _utils.validateType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSInterfaceDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "extends", "body"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
        extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("TSExpressionWithTypeArguments")),
        body: (0, _utils.validateType)("TSInterfaceBody")
      }
    });
    defineType("TSInterfaceBody", {
      visitor: ["body"],
      fields: {
        body: (0, _utils.validateArrayOfType)("TSTypeElement")
      }
    });
    defineType("TSTypeAliasDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "typeAnnotation"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSInstantiationExpression", {
      aliases: ["Expression"],
      visitor: ["expression", "typeParameters"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    var TSTypeExpression = {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["expression", "typeAnnotation"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    };
    defineType("TSAsExpression", TSTypeExpression);
    defineType("TSSatisfiesExpression", TSTypeExpression);
    defineType("TSTypeAssertion", {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["typeAnnotation", "expression"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType"),
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSEnumDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "members"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        const: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        members: (0, _utils.validateArrayOfType)("TSEnumMember"),
        initializer: (0, _utils.validateOptionalType)("Expression")
      }
    });
    defineType("TSEnumMember", {
      visitor: ["id", "initializer"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        initializer: (0, _utils.validateOptionalType)("Expression")
      }
    });
    defineType("TSModuleDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "body"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        global: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        body: (0, _utils.validateType)(["TSModuleBlock", "TSModuleDeclaration"])
      }
    });
    defineType("TSModuleBlock", {
      aliases: ["Scopable", "Block", "BlockParent", "FunctionParent"],
      visitor: ["body"],
      fields: {
        body: (0, _utils.validateArrayOfType)("Statement")
      }
    });
    defineType("TSImportType", {
      aliases: ["TSType"],
      visitor: ["argument", "qualifier", "typeParameters"],
      fields: {
        argument: (0, _utils.validateType)("StringLiteral"),
        qualifier: (0, _utils.validateOptionalType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSImportEqualsDeclaration", {
      aliases: ["Statement"],
      visitor: ["id", "moduleReference"],
      fields: {
        isExport: (0, _utils.validate)(bool),
        id: (0, _utils.validateType)("Identifier"),
        moduleReference: (0, _utils.validateType)(["TSEntityName", "TSExternalModuleReference"]),
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "value"),
          optional: true
        }
      }
    });
    defineType("TSExternalModuleReference", {
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("StringLiteral")
      }
    });
    defineType("TSNonNullExpression", {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSExportAssignment", {
      aliases: ["Statement"],
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSNamespaceExportDeclaration", {
      aliases: ["Statement"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("TSTypeAnnotation", {
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)("TSType")
        }
      }
    });
    defineType("TSTypeParameterInstantiation", {
      visitor: ["params"],
      fields: {
        params: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSType")))
        }
      }
    });
    defineType("TSTypeParameterDeclaration", {
      visitor: ["params"],
      fields: {
        params: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSTypeParameter")))
        }
      }
    });
    defineType("TSTypeParameter", {
      builder: ["constraint", "default", "name"],
      visitor: ["constraint", "default"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        },
        in: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        out: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        constraint: {
          validate: (0, _utils.assertNodeType)("TSType"),
          optional: true
        },
        default: {
          validate: (0, _utils.assertNodeType)("TSType"),
          optional: true
        }
      }
    });
  }
});

// node_modules/@babel/types/lib/definitions/index.js
var require_definitions = __commonJS({
  "node_modules/@babel/types/lib/definitions/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "ALIAS_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.ALIAS_KEYS;
      }
    });
    Object.defineProperty(exports, "BUILDER_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.BUILDER_KEYS;
      }
    });
    Object.defineProperty(exports, "DEPRECATED_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.DEPRECATED_KEYS;
      }
    });
    Object.defineProperty(exports, "FLIPPED_ALIAS_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.FLIPPED_ALIAS_KEYS;
      }
    });
    Object.defineProperty(exports, "NODE_FIELDS", {
      enumerable: true,
      get: function() {
        return _utils.NODE_FIELDS;
      }
    });
    Object.defineProperty(exports, "NODE_PARENT_VALIDATIONS", {
      enumerable: true,
      get: function() {
        return _utils.NODE_PARENT_VALIDATIONS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS_ALIAS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS_ALIAS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS_FLIPPED_ALIAS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS_FLIPPED_ALIAS;
      }
    });
    exports.TYPES = void 0;
    Object.defineProperty(exports, "VISITOR_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.VISITOR_KEYS;
      }
    });
    var _toFastProperties = require_to_fast_properties();
    require_core();
    require_flow();
    require_jsx();
    require_misc();
    require_experimental();
    require_typescript();
    var _utils = require_utils6();
    var _placeholders = require_placeholders();
    _toFastProperties(_utils.VISITOR_KEYS);
    _toFastProperties(_utils.ALIAS_KEYS);
    _toFastProperties(_utils.FLIPPED_ALIAS_KEYS);
    _toFastProperties(_utils.NODE_FIELDS);
    _toFastProperties(_utils.BUILDER_KEYS);
    _toFastProperties(_utils.DEPRECATED_KEYS);
    _toFastProperties(_placeholders.PLACEHOLDERS_ALIAS);
    _toFastProperties(_placeholders.PLACEHOLDERS_FLIPPED_ALIAS);
    var TYPES = [].concat(Object.keys(_utils.VISITOR_KEYS), Object.keys(_utils.FLIPPED_ALIAS_KEYS), Object.keys(_utils.DEPRECATED_KEYS));
    exports.TYPES = TYPES;
  }
});

// node_modules/@babel/types/lib/validators/validate.js
var require_validate2 = __commonJS({
  "node_modules/@babel/types/lib/validators/validate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = validate;
    exports.validateChild = validateChild;
    exports.validateField = validateField;
    var _definitions = require_definitions();
    function validate(node, key, val) {
      if (!node)
        return;
      const fields = _definitions.NODE_FIELDS[node.type];
      if (!fields)
        return;
      const field = fields[key];
      validateField(node, key, val, field);
      validateChild(node, key, val);
    }
    function validateField(node, key, val, field) {
      if (!(field != null && field.validate))
        return;
      if (field.optional && val == null)
        return;
      field.validate(node, key, val);
    }
    function validateChild(node, key, val) {
      if (val == null)
        return;
      const validate2 = _definitions.NODE_PARENT_VALIDATIONS[val.type];
      if (!validate2)
        return;
      validate2(node, key, val);
    }
  }
});

// node_modules/@babel/types/lib/builders/validateNode.js
var require_validateNode = __commonJS({
  "node_modules/@babel/types/lib/builders/validateNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = validateNode;
    var _validate = require_validate2();
    var _ = require_lib11();
    function validateNode(node) {
      const keys3 = _.BUILDER_KEYS[node.type];
      for (const key of keys3) {
        (0, _validate.default)(node, key, node[key]);
      }
      return node;
    }
  }
});

// node_modules/@babel/types/lib/builders/generated/index.js
var require_generated2 = __commonJS({
  "node_modules/@babel/types/lib/builders/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.anyTypeAnnotation = anyTypeAnnotation;
    exports.argumentPlaceholder = argumentPlaceholder;
    exports.arrayExpression = arrayExpression;
    exports.arrayPattern = arrayPattern;
    exports.arrayTypeAnnotation = arrayTypeAnnotation;
    exports.arrowFunctionExpression = arrowFunctionExpression;
    exports.assignmentExpression = assignmentExpression;
    exports.assignmentPattern = assignmentPattern;
    exports.awaitExpression = awaitExpression;
    exports.bigIntLiteral = bigIntLiteral;
    exports.binaryExpression = binaryExpression;
    exports.bindExpression = bindExpression;
    exports.blockStatement = blockStatement2;
    exports.booleanLiteral = booleanLiteral;
    exports.booleanLiteralTypeAnnotation = booleanLiteralTypeAnnotation;
    exports.booleanTypeAnnotation = booleanTypeAnnotation;
    exports.breakStatement = breakStatement;
    exports.callExpression = callExpression3;
    exports.catchClause = catchClause;
    exports.classAccessorProperty = classAccessorProperty;
    exports.classBody = classBody;
    exports.classDeclaration = classDeclaration;
    exports.classExpression = classExpression;
    exports.classImplements = classImplements;
    exports.classMethod = classMethod;
    exports.classPrivateMethod = classPrivateMethod;
    exports.classPrivateProperty = classPrivateProperty;
    exports.classProperty = classProperty;
    exports.conditionalExpression = conditionalExpression;
    exports.continueStatement = continueStatement;
    exports.debuggerStatement = debuggerStatement;
    exports.decimalLiteral = decimalLiteral;
    exports.declareClass = declareClass;
    exports.declareExportAllDeclaration = declareExportAllDeclaration;
    exports.declareExportDeclaration = declareExportDeclaration;
    exports.declareFunction = declareFunction;
    exports.declareInterface = declareInterface;
    exports.declareModule = declareModule;
    exports.declareModuleExports = declareModuleExports;
    exports.declareOpaqueType = declareOpaqueType;
    exports.declareTypeAlias = declareTypeAlias;
    exports.declareVariable = declareVariable;
    exports.declaredPredicate = declaredPredicate;
    exports.decorator = decorator;
    exports.directive = directive;
    exports.directiveLiteral = directiveLiteral;
    exports.doExpression = doExpression;
    exports.doWhileStatement = doWhileStatement;
    exports.emptyStatement = emptyStatement;
    exports.emptyTypeAnnotation = emptyTypeAnnotation;
    exports.enumBooleanBody = enumBooleanBody;
    exports.enumBooleanMember = enumBooleanMember;
    exports.enumDeclaration = enumDeclaration;
    exports.enumDefaultedMember = enumDefaultedMember;
    exports.enumNumberBody = enumNumberBody;
    exports.enumNumberMember = enumNumberMember;
    exports.enumStringBody = enumStringBody;
    exports.enumStringMember = enumStringMember;
    exports.enumSymbolBody = enumSymbolBody;
    exports.existsTypeAnnotation = existsTypeAnnotation;
    exports.exportAllDeclaration = exportAllDeclaration;
    exports.exportDefaultDeclaration = exportDefaultDeclaration;
    exports.exportDefaultSpecifier = exportDefaultSpecifier;
    exports.exportNamedDeclaration = exportNamedDeclaration;
    exports.exportNamespaceSpecifier = exportNamespaceSpecifier;
    exports.exportSpecifier = exportSpecifier;
    exports.expressionStatement = expressionStatement;
    exports.file = file;
    exports.forInStatement = forInStatement;
    exports.forOfStatement = forOfStatement;
    exports.forStatement = forStatement;
    exports.functionDeclaration = functionDeclaration;
    exports.functionExpression = functionExpression;
    exports.functionTypeAnnotation = functionTypeAnnotation;
    exports.functionTypeParam = functionTypeParam;
    exports.genericTypeAnnotation = genericTypeAnnotation;
    exports.identifier = identifier3;
    exports.ifStatement = ifStatement;
    exports.import = _import;
    exports.importAttribute = importAttribute;
    exports.importDeclaration = importDeclaration;
    exports.importDefaultSpecifier = importDefaultSpecifier;
    exports.importNamespaceSpecifier = importNamespaceSpecifier;
    exports.importSpecifier = importSpecifier2;
    exports.indexedAccessType = indexedAccessType;
    exports.inferredPredicate = inferredPredicate;
    exports.interfaceDeclaration = interfaceDeclaration;
    exports.interfaceExtends = interfaceExtends;
    exports.interfaceTypeAnnotation = interfaceTypeAnnotation;
    exports.interpreterDirective = interpreterDirective;
    exports.intersectionTypeAnnotation = intersectionTypeAnnotation;
    exports.jSXAttribute = exports.jsxAttribute = jsxAttribute;
    exports.jSXClosingElement = exports.jsxClosingElement = jsxClosingElement;
    exports.jSXClosingFragment = exports.jsxClosingFragment = jsxClosingFragment;
    exports.jSXElement = exports.jsxElement = jsxElement;
    exports.jSXEmptyExpression = exports.jsxEmptyExpression = jsxEmptyExpression;
    exports.jSXExpressionContainer = exports.jsxExpressionContainer = jsxExpressionContainer;
    exports.jSXFragment = exports.jsxFragment = jsxFragment;
    exports.jSXIdentifier = exports.jsxIdentifier = jsxIdentifier;
    exports.jSXMemberExpression = exports.jsxMemberExpression = jsxMemberExpression;
    exports.jSXNamespacedName = exports.jsxNamespacedName = jsxNamespacedName;
    exports.jSXOpeningElement = exports.jsxOpeningElement = jsxOpeningElement;
    exports.jSXOpeningFragment = exports.jsxOpeningFragment = jsxOpeningFragment;
    exports.jSXSpreadAttribute = exports.jsxSpreadAttribute = jsxSpreadAttribute;
    exports.jSXSpreadChild = exports.jsxSpreadChild = jsxSpreadChild;
    exports.jSXText = exports.jsxText = jsxText;
    exports.labeledStatement = labeledStatement;
    exports.logicalExpression = logicalExpression;
    exports.memberExpression = memberExpression;
    exports.metaProperty = metaProperty;
    exports.mixedTypeAnnotation = mixedTypeAnnotation;
    exports.moduleExpression = moduleExpression;
    exports.newExpression = newExpression;
    exports.noop = noop;
    exports.nullLiteral = nullLiteral;
    exports.nullLiteralTypeAnnotation = nullLiteralTypeAnnotation;
    exports.nullableTypeAnnotation = nullableTypeAnnotation;
    exports.numberLiteral = NumberLiteral;
    exports.numberLiteralTypeAnnotation = numberLiteralTypeAnnotation;
    exports.numberTypeAnnotation = numberTypeAnnotation;
    exports.numericLiteral = numericLiteral;
    exports.objectExpression = objectExpression;
    exports.objectMethod = objectMethod;
    exports.objectPattern = objectPattern2;
    exports.objectProperty = objectProperty2;
    exports.objectTypeAnnotation = objectTypeAnnotation;
    exports.objectTypeCallProperty = objectTypeCallProperty;
    exports.objectTypeIndexer = objectTypeIndexer;
    exports.objectTypeInternalSlot = objectTypeInternalSlot;
    exports.objectTypeProperty = objectTypeProperty;
    exports.objectTypeSpreadProperty = objectTypeSpreadProperty;
    exports.opaqueType = opaqueType;
    exports.optionalCallExpression = optionalCallExpression;
    exports.optionalIndexedAccessType = optionalIndexedAccessType;
    exports.optionalMemberExpression = optionalMemberExpression;
    exports.parenthesizedExpression = parenthesizedExpression;
    exports.pipelineBareFunction = pipelineBareFunction;
    exports.pipelinePrimaryTopicReference = pipelinePrimaryTopicReference;
    exports.pipelineTopicExpression = pipelineTopicExpression;
    exports.placeholder = placeholder;
    exports.privateName = privateName;
    exports.program = program2;
    exports.qualifiedTypeIdentifier = qualifiedTypeIdentifier;
    exports.recordExpression = recordExpression;
    exports.regExpLiteral = regExpLiteral;
    exports.regexLiteral = RegexLiteral;
    exports.restElement = restElement;
    exports.restProperty = RestProperty;
    exports.returnStatement = returnStatement2;
    exports.sequenceExpression = sequenceExpression;
    exports.spreadElement = spreadElement;
    exports.spreadProperty = SpreadProperty;
    exports.staticBlock = staticBlock;
    exports.stringLiteral = stringLiteral2;
    exports.stringLiteralTypeAnnotation = stringLiteralTypeAnnotation;
    exports.stringTypeAnnotation = stringTypeAnnotation;
    exports.super = _super;
    exports.switchCase = switchCase;
    exports.switchStatement = switchStatement;
    exports.symbolTypeAnnotation = symbolTypeAnnotation;
    exports.taggedTemplateExpression = taggedTemplateExpression;
    exports.templateElement = templateElement;
    exports.templateLiteral = templateLiteral;
    exports.thisExpression = thisExpression;
    exports.thisTypeAnnotation = thisTypeAnnotation;
    exports.throwStatement = throwStatement;
    exports.topicReference = topicReference;
    exports.tryStatement = tryStatement;
    exports.tSAnyKeyword = exports.tsAnyKeyword = tsAnyKeyword;
    exports.tSArrayType = exports.tsArrayType = tsArrayType;
    exports.tSAsExpression = exports.tsAsExpression = tsAsExpression;
    exports.tSBigIntKeyword = exports.tsBigIntKeyword = tsBigIntKeyword;
    exports.tSBooleanKeyword = exports.tsBooleanKeyword = tsBooleanKeyword;
    exports.tSCallSignatureDeclaration = exports.tsCallSignatureDeclaration = tsCallSignatureDeclaration;
    exports.tSConditionalType = exports.tsConditionalType = tsConditionalType;
    exports.tSConstructSignatureDeclaration = exports.tsConstructSignatureDeclaration = tsConstructSignatureDeclaration;
    exports.tSConstructorType = exports.tsConstructorType = tsConstructorType;
    exports.tSDeclareFunction = exports.tsDeclareFunction = tsDeclareFunction;
    exports.tSDeclareMethod = exports.tsDeclareMethod = tsDeclareMethod;
    exports.tSEnumDeclaration = exports.tsEnumDeclaration = tsEnumDeclaration;
    exports.tSEnumMember = exports.tsEnumMember = tsEnumMember;
    exports.tSExportAssignment = exports.tsExportAssignment = tsExportAssignment;
    exports.tSExpressionWithTypeArguments = exports.tsExpressionWithTypeArguments = tsExpressionWithTypeArguments;
    exports.tSExternalModuleReference = exports.tsExternalModuleReference = tsExternalModuleReference;
    exports.tSFunctionType = exports.tsFunctionType = tsFunctionType;
    exports.tSImportEqualsDeclaration = exports.tsImportEqualsDeclaration = tsImportEqualsDeclaration;
    exports.tSImportType = exports.tsImportType = tsImportType;
    exports.tSIndexSignature = exports.tsIndexSignature = tsIndexSignature;
    exports.tSIndexedAccessType = exports.tsIndexedAccessType = tsIndexedAccessType;
    exports.tSInferType = exports.tsInferType = tsInferType;
    exports.tSInstantiationExpression = exports.tsInstantiationExpression = tsInstantiationExpression;
    exports.tSInterfaceBody = exports.tsInterfaceBody = tsInterfaceBody;
    exports.tSInterfaceDeclaration = exports.tsInterfaceDeclaration = tsInterfaceDeclaration;
    exports.tSIntersectionType = exports.tsIntersectionType = tsIntersectionType;
    exports.tSIntrinsicKeyword = exports.tsIntrinsicKeyword = tsIntrinsicKeyword;
    exports.tSLiteralType = exports.tsLiteralType = tsLiteralType;
    exports.tSMappedType = exports.tsMappedType = tsMappedType;
    exports.tSMethodSignature = exports.tsMethodSignature = tsMethodSignature;
    exports.tSModuleBlock = exports.tsModuleBlock = tsModuleBlock;
    exports.tSModuleDeclaration = exports.tsModuleDeclaration = tsModuleDeclaration;
    exports.tSNamedTupleMember = exports.tsNamedTupleMember = tsNamedTupleMember;
    exports.tSNamespaceExportDeclaration = exports.tsNamespaceExportDeclaration = tsNamespaceExportDeclaration;
    exports.tSNeverKeyword = exports.tsNeverKeyword = tsNeverKeyword;
    exports.tSNonNullExpression = exports.tsNonNullExpression = tsNonNullExpression;
    exports.tSNullKeyword = exports.tsNullKeyword = tsNullKeyword;
    exports.tSNumberKeyword = exports.tsNumberKeyword = tsNumberKeyword;
    exports.tSObjectKeyword = exports.tsObjectKeyword = tsObjectKeyword;
    exports.tSOptionalType = exports.tsOptionalType = tsOptionalType;
    exports.tSParameterProperty = exports.tsParameterProperty = tsParameterProperty;
    exports.tSParenthesizedType = exports.tsParenthesizedType = tsParenthesizedType;
    exports.tSPropertySignature = exports.tsPropertySignature = tsPropertySignature;
    exports.tSQualifiedName = exports.tsQualifiedName = tsQualifiedName;
    exports.tSRestType = exports.tsRestType = tsRestType;
    exports.tSSatisfiesExpression = exports.tsSatisfiesExpression = tsSatisfiesExpression;
    exports.tSStringKeyword = exports.tsStringKeyword = tsStringKeyword;
    exports.tSSymbolKeyword = exports.tsSymbolKeyword = tsSymbolKeyword;
    exports.tSThisType = exports.tsThisType = tsThisType;
    exports.tSTupleType = exports.tsTupleType = tsTupleType;
    exports.tSTypeAliasDeclaration = exports.tsTypeAliasDeclaration = tsTypeAliasDeclaration;
    exports.tSTypeAnnotation = exports.tsTypeAnnotation = tsTypeAnnotation;
    exports.tSTypeAssertion = exports.tsTypeAssertion = tsTypeAssertion;
    exports.tSTypeLiteral = exports.tsTypeLiteral = tsTypeLiteral;
    exports.tSTypeOperator = exports.tsTypeOperator = tsTypeOperator;
    exports.tSTypeParameter = exports.tsTypeParameter = tsTypeParameter;
    exports.tSTypeParameterDeclaration = exports.tsTypeParameterDeclaration = tsTypeParameterDeclaration;
    exports.tSTypeParameterInstantiation = exports.tsTypeParameterInstantiation = tsTypeParameterInstantiation;
    exports.tSTypePredicate = exports.tsTypePredicate = tsTypePredicate;
    exports.tSTypeQuery = exports.tsTypeQuery = tsTypeQuery;
    exports.tSTypeReference = exports.tsTypeReference = tsTypeReference;
    exports.tSUndefinedKeyword = exports.tsUndefinedKeyword = tsUndefinedKeyword;
    exports.tSUnionType = exports.tsUnionType = tsUnionType;
    exports.tSUnknownKeyword = exports.tsUnknownKeyword = tsUnknownKeyword;
    exports.tSVoidKeyword = exports.tsVoidKeyword = tsVoidKeyword;
    exports.tupleExpression = tupleExpression;
    exports.tupleTypeAnnotation = tupleTypeAnnotation;
    exports.typeAlias = typeAlias;
    exports.typeAnnotation = typeAnnotation;
    exports.typeCastExpression = typeCastExpression;
    exports.typeParameter = typeParameter;
    exports.typeParameterDeclaration = typeParameterDeclaration;
    exports.typeParameterInstantiation = typeParameterInstantiation;
    exports.typeofTypeAnnotation = typeofTypeAnnotation;
    exports.unaryExpression = unaryExpression;
    exports.unionTypeAnnotation = unionTypeAnnotation;
    exports.updateExpression = updateExpression;
    exports.v8IntrinsicIdentifier = v8IntrinsicIdentifier;
    exports.variableDeclaration = variableDeclaration2;
    exports.variableDeclarator = variableDeclarator2;
    exports.variance = variance;
    exports.voidTypeAnnotation = voidTypeAnnotation;
    exports.whileStatement = whileStatement;
    exports.withStatement = withStatement;
    exports.yieldExpression = yieldExpression;
    var _validateNode = require_validateNode();
    function arrayExpression(elements = []) {
      return (0, _validateNode.default)({
        type: "ArrayExpression",
        elements
      });
    }
    function assignmentExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "AssignmentExpression",
        operator,
        left,
        right
      });
    }
    function binaryExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "BinaryExpression",
        operator,
        left,
        right
      });
    }
    function interpreterDirective(value2) {
      return (0, _validateNode.default)({
        type: "InterpreterDirective",
        value: value2
      });
    }
    function directive(value2) {
      return (0, _validateNode.default)({
        type: "Directive",
        value: value2
      });
    }
    function directiveLiteral(value2) {
      return (0, _validateNode.default)({
        type: "DirectiveLiteral",
        value: value2
      });
    }
    function blockStatement2(body, directives = []) {
      return (0, _validateNode.default)({
        type: "BlockStatement",
        body,
        directives
      });
    }
    function breakStatement(label = null) {
      return (0, _validateNode.default)({
        type: "BreakStatement",
        label
      });
    }
    function callExpression3(callee, _arguments) {
      return (0, _validateNode.default)({
        type: "CallExpression",
        callee,
        arguments: _arguments
      });
    }
    function catchClause(param = null, body) {
      return (0, _validateNode.default)({
        type: "CatchClause",
        param,
        body
      });
    }
    function conditionalExpression(test, consequent, alternate) {
      return (0, _validateNode.default)({
        type: "ConditionalExpression",
        test,
        consequent,
        alternate
      });
    }
    function continueStatement(label = null) {
      return (0, _validateNode.default)({
        type: "ContinueStatement",
        label
      });
    }
    function debuggerStatement() {
      return {
        type: "DebuggerStatement"
      };
    }
    function doWhileStatement(test, body) {
      return (0, _validateNode.default)({
        type: "DoWhileStatement",
        test,
        body
      });
    }
    function emptyStatement() {
      return {
        type: "EmptyStatement"
      };
    }
    function expressionStatement(expression) {
      return (0, _validateNode.default)({
        type: "ExpressionStatement",
        expression
      });
    }
    function file(program3, comments = null, tokens = null) {
      return (0, _validateNode.default)({
        type: "File",
        program: program3,
        comments,
        tokens
      });
    }
    function forInStatement(left, right, body) {
      return (0, _validateNode.default)({
        type: "ForInStatement",
        left,
        right,
        body
      });
    }
    function forStatement(init = null, test = null, update = null, body) {
      return (0, _validateNode.default)({
        type: "ForStatement",
        init,
        test,
        update,
        body
      });
    }
    function functionDeclaration(id = null, params, body, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "FunctionDeclaration",
        id,
        params,
        body,
        generator,
        async
      });
    }
    function functionExpression(id = null, params, body, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "FunctionExpression",
        id,
        params,
        body,
        generator,
        async
      });
    }
    function identifier3(name) {
      return (0, _validateNode.default)({
        type: "Identifier",
        name
      });
    }
    function ifStatement(test, consequent, alternate = null) {
      return (0, _validateNode.default)({
        type: "IfStatement",
        test,
        consequent,
        alternate
      });
    }
    function labeledStatement(label, body) {
      return (0, _validateNode.default)({
        type: "LabeledStatement",
        label,
        body
      });
    }
    function stringLiteral2(value2) {
      return (0, _validateNode.default)({
        type: "StringLiteral",
        value: value2
      });
    }
    function numericLiteral(value2) {
      return (0, _validateNode.default)({
        type: "NumericLiteral",
        value: value2
      });
    }
    function nullLiteral() {
      return {
        type: "NullLiteral"
      };
    }
    function booleanLiteral(value2) {
      return (0, _validateNode.default)({
        type: "BooleanLiteral",
        value: value2
      });
    }
    function regExpLiteral(pattern, flags = "") {
      return (0, _validateNode.default)({
        type: "RegExpLiteral",
        pattern,
        flags
      });
    }
    function logicalExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "LogicalExpression",
        operator,
        left,
        right
      });
    }
    function memberExpression(object, property, computed = false, optional = null) {
      return (0, _validateNode.default)({
        type: "MemberExpression",
        object,
        property,
        computed,
        optional
      });
    }
    function newExpression(callee, _arguments) {
      return (0, _validateNode.default)({
        type: "NewExpression",
        callee,
        arguments: _arguments
      });
    }
    function program2(body, directives = [], sourceType = "script", interpreter = null) {
      return (0, _validateNode.default)({
        type: "Program",
        body,
        directives,
        sourceType,
        interpreter,
        sourceFile: null
      });
    }
    function objectExpression(properties) {
      return (0, _validateNode.default)({
        type: "ObjectExpression",
        properties
      });
    }
    function objectMethod(kind = "method", key, params, body, computed = false, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "ObjectMethod",
        kind,
        key,
        params,
        body,
        computed,
        generator,
        async
      });
    }
    function objectProperty2(key, value2, computed = false, shorthand = false, decorators = null) {
      return (0, _validateNode.default)({
        type: "ObjectProperty",
        key,
        value: value2,
        computed,
        shorthand,
        decorators
      });
    }
    function restElement(argument) {
      return (0, _validateNode.default)({
        type: "RestElement",
        argument
      });
    }
    function returnStatement2(argument = null) {
      return (0, _validateNode.default)({
        type: "ReturnStatement",
        argument
      });
    }
    function sequenceExpression(expressions) {
      return (0, _validateNode.default)({
        type: "SequenceExpression",
        expressions
      });
    }
    function parenthesizedExpression(expression) {
      return (0, _validateNode.default)({
        type: "ParenthesizedExpression",
        expression
      });
    }
    function switchCase(test = null, consequent) {
      return (0, _validateNode.default)({
        type: "SwitchCase",
        test,
        consequent
      });
    }
    function switchStatement(discriminant, cases) {
      return (0, _validateNode.default)({
        type: "SwitchStatement",
        discriminant,
        cases
      });
    }
    function thisExpression() {
      return {
        type: "ThisExpression"
      };
    }
    function throwStatement(argument) {
      return (0, _validateNode.default)({
        type: "ThrowStatement",
        argument
      });
    }
    function tryStatement(block, handler = null, finalizer = null) {
      return (0, _validateNode.default)({
        type: "TryStatement",
        block,
        handler,
        finalizer
      });
    }
    function unaryExpression(operator, argument, prefix = true) {
      return (0, _validateNode.default)({
        type: "UnaryExpression",
        operator,
        argument,
        prefix
      });
    }
    function updateExpression(operator, argument, prefix = false) {
      return (0, _validateNode.default)({
        type: "UpdateExpression",
        operator,
        argument,
        prefix
      });
    }
    function variableDeclaration2(kind, declarations) {
      return (0, _validateNode.default)({
        type: "VariableDeclaration",
        kind,
        declarations
      });
    }
    function variableDeclarator2(id, init = null) {
      return (0, _validateNode.default)({
        type: "VariableDeclarator",
        id,
        init
      });
    }
    function whileStatement(test, body) {
      return (0, _validateNode.default)({
        type: "WhileStatement",
        test,
        body
      });
    }
    function withStatement(object, body) {
      return (0, _validateNode.default)({
        type: "WithStatement",
        object,
        body
      });
    }
    function assignmentPattern(left, right) {
      return (0, _validateNode.default)({
        type: "AssignmentPattern",
        left,
        right
      });
    }
    function arrayPattern(elements) {
      return (0, _validateNode.default)({
        type: "ArrayPattern",
        elements
      });
    }
    function arrowFunctionExpression(params, body, async = false) {
      return (0, _validateNode.default)({
        type: "ArrowFunctionExpression",
        params,
        body,
        async,
        expression: null
      });
    }
    function classBody(body) {
      return (0, _validateNode.default)({
        type: "ClassBody",
        body
      });
    }
    function classExpression(id = null, superClass = null, body, decorators = null) {
      return (0, _validateNode.default)({
        type: "ClassExpression",
        id,
        superClass,
        body,
        decorators
      });
    }
    function classDeclaration(id, superClass = null, body, decorators = null) {
      return (0, _validateNode.default)({
        type: "ClassDeclaration",
        id,
        superClass,
        body,
        decorators
      });
    }
    function exportAllDeclaration(source) {
      return (0, _validateNode.default)({
        type: "ExportAllDeclaration",
        source
      });
    }
    function exportDefaultDeclaration(declaration) {
      return (0, _validateNode.default)({
        type: "ExportDefaultDeclaration",
        declaration
      });
    }
    function exportNamedDeclaration(declaration = null, specifiers = [], source = null) {
      return (0, _validateNode.default)({
        type: "ExportNamedDeclaration",
        declaration,
        specifiers,
        source
      });
    }
    function exportSpecifier(local, exported) {
      return (0, _validateNode.default)({
        type: "ExportSpecifier",
        local,
        exported
      });
    }
    function forOfStatement(left, right, body, _await = false) {
      return (0, _validateNode.default)({
        type: "ForOfStatement",
        left,
        right,
        body,
        await: _await
      });
    }
    function importDeclaration(specifiers, source) {
      return (0, _validateNode.default)({
        type: "ImportDeclaration",
        specifiers,
        source
      });
    }
    function importDefaultSpecifier(local) {
      return (0, _validateNode.default)({
        type: "ImportDefaultSpecifier",
        local
      });
    }
    function importNamespaceSpecifier(local) {
      return (0, _validateNode.default)({
        type: "ImportNamespaceSpecifier",
        local
      });
    }
    function importSpecifier2(local, imported) {
      return (0, _validateNode.default)({
        type: "ImportSpecifier",
        local,
        imported
      });
    }
    function metaProperty(meta, property) {
      return (0, _validateNode.default)({
        type: "MetaProperty",
        meta,
        property
      });
    }
    function classMethod(kind = "method", key, params, body, computed = false, _static = false, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "ClassMethod",
        kind,
        key,
        params,
        body,
        computed,
        static: _static,
        generator,
        async
      });
    }
    function objectPattern2(properties) {
      return (0, _validateNode.default)({
        type: "ObjectPattern",
        properties
      });
    }
    function spreadElement(argument) {
      return (0, _validateNode.default)({
        type: "SpreadElement",
        argument
      });
    }
    function _super() {
      return {
        type: "Super"
      };
    }
    function taggedTemplateExpression(tag, quasi) {
      return (0, _validateNode.default)({
        type: "TaggedTemplateExpression",
        tag,
        quasi
      });
    }
    function templateElement(value2, tail = false) {
      return (0, _validateNode.default)({
        type: "TemplateElement",
        value: value2,
        tail
      });
    }
    function templateLiteral(quasis, expressions) {
      return (0, _validateNode.default)({
        type: "TemplateLiteral",
        quasis,
        expressions
      });
    }
    function yieldExpression(argument = null, delegate = false) {
      return (0, _validateNode.default)({
        type: "YieldExpression",
        argument,
        delegate
      });
    }
    function awaitExpression(argument) {
      return (0, _validateNode.default)({
        type: "AwaitExpression",
        argument
      });
    }
    function _import() {
      return {
        type: "Import"
      };
    }
    function bigIntLiteral(value2) {
      return (0, _validateNode.default)({
        type: "BigIntLiteral",
        value: value2
      });
    }
    function exportNamespaceSpecifier(exported) {
      return (0, _validateNode.default)({
        type: "ExportNamespaceSpecifier",
        exported
      });
    }
    function optionalMemberExpression(object, property, computed = false, optional) {
      return (0, _validateNode.default)({
        type: "OptionalMemberExpression",
        object,
        property,
        computed,
        optional
      });
    }
    function optionalCallExpression(callee, _arguments, optional) {
      return (0, _validateNode.default)({
        type: "OptionalCallExpression",
        callee,
        arguments: _arguments,
        optional
      });
    }
    function classProperty(key, value2 = null, typeAnnotation2 = null, decorators = null, computed = false, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassProperty",
        key,
        value: value2,
        typeAnnotation: typeAnnotation2,
        decorators,
        computed,
        static: _static
      });
    }
    function classAccessorProperty(key, value2 = null, typeAnnotation2 = null, decorators = null, computed = false, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassAccessorProperty",
        key,
        value: value2,
        typeAnnotation: typeAnnotation2,
        decorators,
        computed,
        static: _static
      });
    }
    function classPrivateProperty(key, value2 = null, decorators = null, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassPrivateProperty",
        key,
        value: value2,
        decorators,
        static: _static
      });
    }
    function classPrivateMethod(kind = "method", key, params, body, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassPrivateMethod",
        kind,
        key,
        params,
        body,
        static: _static
      });
    }
    function privateName(id) {
      return (0, _validateNode.default)({
        type: "PrivateName",
        id
      });
    }
    function staticBlock(body) {
      return (0, _validateNode.default)({
        type: "StaticBlock",
        body
      });
    }
    function anyTypeAnnotation() {
      return {
        type: "AnyTypeAnnotation"
      };
    }
    function arrayTypeAnnotation(elementType) {
      return (0, _validateNode.default)({
        type: "ArrayTypeAnnotation",
        elementType
      });
    }
    function booleanTypeAnnotation() {
      return {
        type: "BooleanTypeAnnotation"
      };
    }
    function booleanLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "BooleanLiteralTypeAnnotation",
        value: value2
      });
    }
    function nullLiteralTypeAnnotation() {
      return {
        type: "NullLiteralTypeAnnotation"
      };
    }
    function classImplements(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "ClassImplements",
        id,
        typeParameters
      });
    }
    function declareClass(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "DeclareClass",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function declareFunction(id) {
      return (0, _validateNode.default)({
        type: "DeclareFunction",
        id
      });
    }
    function declareInterface(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "DeclareInterface",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function declareModule(id, body, kind = null) {
      return (0, _validateNode.default)({
        type: "DeclareModule",
        id,
        body,
        kind
      });
    }
    function declareModuleExports(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "DeclareModuleExports",
        typeAnnotation: typeAnnotation2
      });
    }
    function declareTypeAlias(id, typeParameters = null, right) {
      return (0, _validateNode.default)({
        type: "DeclareTypeAlias",
        id,
        typeParameters,
        right
      });
    }
    function declareOpaqueType(id, typeParameters = null, supertype = null) {
      return (0, _validateNode.default)({
        type: "DeclareOpaqueType",
        id,
        typeParameters,
        supertype
      });
    }
    function declareVariable(id) {
      return (0, _validateNode.default)({
        type: "DeclareVariable",
        id
      });
    }
    function declareExportDeclaration(declaration = null, specifiers = null, source = null) {
      return (0, _validateNode.default)({
        type: "DeclareExportDeclaration",
        declaration,
        specifiers,
        source
      });
    }
    function declareExportAllDeclaration(source) {
      return (0, _validateNode.default)({
        type: "DeclareExportAllDeclaration",
        source
      });
    }
    function declaredPredicate(value2) {
      return (0, _validateNode.default)({
        type: "DeclaredPredicate",
        value: value2
      });
    }
    function existsTypeAnnotation() {
      return {
        type: "ExistsTypeAnnotation"
      };
    }
    function functionTypeAnnotation(typeParameters = null, params, rest = null, returnType) {
      return (0, _validateNode.default)({
        type: "FunctionTypeAnnotation",
        typeParameters,
        params,
        rest,
        returnType
      });
    }
    function functionTypeParam(name = null, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "FunctionTypeParam",
        name,
        typeAnnotation: typeAnnotation2
      });
    }
    function genericTypeAnnotation(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "GenericTypeAnnotation",
        id,
        typeParameters
      });
    }
    function inferredPredicate() {
      return {
        type: "InferredPredicate"
      };
    }
    function interfaceExtends(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "InterfaceExtends",
        id,
        typeParameters
      });
    }
    function interfaceDeclaration(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "InterfaceDeclaration",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function interfaceTypeAnnotation(_extends = null, body) {
      return (0, _validateNode.default)({
        type: "InterfaceTypeAnnotation",
        extends: _extends,
        body
      });
    }
    function intersectionTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "IntersectionTypeAnnotation",
        types
      });
    }
    function mixedTypeAnnotation() {
      return {
        type: "MixedTypeAnnotation"
      };
    }
    function emptyTypeAnnotation() {
      return {
        type: "EmptyTypeAnnotation"
      };
    }
    function nullableTypeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "NullableTypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function numberLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "NumberLiteralTypeAnnotation",
        value: value2
      });
    }
    function numberTypeAnnotation() {
      return {
        type: "NumberTypeAnnotation"
      };
    }
    function objectTypeAnnotation(properties, indexers = [], callProperties = [], internalSlots = [], exact = false) {
      return (0, _validateNode.default)({
        type: "ObjectTypeAnnotation",
        properties,
        indexers,
        callProperties,
        internalSlots,
        exact
      });
    }
    function objectTypeInternalSlot(id, value2, optional, _static, method) {
      return (0, _validateNode.default)({
        type: "ObjectTypeInternalSlot",
        id,
        value: value2,
        optional,
        static: _static,
        method
      });
    }
    function objectTypeCallProperty(value2) {
      return (0, _validateNode.default)({
        type: "ObjectTypeCallProperty",
        value: value2,
        static: null
      });
    }
    function objectTypeIndexer(id = null, key, value2, variance2 = null) {
      return (0, _validateNode.default)({
        type: "ObjectTypeIndexer",
        id,
        key,
        value: value2,
        variance: variance2,
        static: null
      });
    }
    function objectTypeProperty(key, value2, variance2 = null) {
      return (0, _validateNode.default)({
        type: "ObjectTypeProperty",
        key,
        value: value2,
        variance: variance2,
        kind: null,
        method: null,
        optional: null,
        proto: null,
        static: null
      });
    }
    function objectTypeSpreadProperty(argument) {
      return (0, _validateNode.default)({
        type: "ObjectTypeSpreadProperty",
        argument
      });
    }
    function opaqueType(id, typeParameters = null, supertype = null, impltype) {
      return (0, _validateNode.default)({
        type: "OpaqueType",
        id,
        typeParameters,
        supertype,
        impltype
      });
    }
    function qualifiedTypeIdentifier(id, qualification) {
      return (0, _validateNode.default)({
        type: "QualifiedTypeIdentifier",
        id,
        qualification
      });
    }
    function stringLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "StringLiteralTypeAnnotation",
        value: value2
      });
    }
    function stringTypeAnnotation() {
      return {
        type: "StringTypeAnnotation"
      };
    }
    function symbolTypeAnnotation() {
      return {
        type: "SymbolTypeAnnotation"
      };
    }
    function thisTypeAnnotation() {
      return {
        type: "ThisTypeAnnotation"
      };
    }
    function tupleTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "TupleTypeAnnotation",
        types
      });
    }
    function typeofTypeAnnotation(argument) {
      return (0, _validateNode.default)({
        type: "TypeofTypeAnnotation",
        argument
      });
    }
    function typeAlias(id, typeParameters = null, right) {
      return (0, _validateNode.default)({
        type: "TypeAlias",
        id,
        typeParameters,
        right
      });
    }
    function typeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function typeCastExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TypeCastExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function typeParameter(bound = null, _default = null, variance2 = null) {
      return (0, _validateNode.default)({
        type: "TypeParameter",
        bound,
        default: _default,
        variance: variance2,
        name: null
      });
    }
    function typeParameterDeclaration(params) {
      return (0, _validateNode.default)({
        type: "TypeParameterDeclaration",
        params
      });
    }
    function typeParameterInstantiation(params) {
      return (0, _validateNode.default)({
        type: "TypeParameterInstantiation",
        params
      });
    }
    function unionTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "UnionTypeAnnotation",
        types
      });
    }
    function variance(kind) {
      return (0, _validateNode.default)({
        type: "Variance",
        kind
      });
    }
    function voidTypeAnnotation() {
      return {
        type: "VoidTypeAnnotation"
      };
    }
    function enumDeclaration(id, body) {
      return (0, _validateNode.default)({
        type: "EnumDeclaration",
        id,
        body
      });
    }
    function enumBooleanBody(members) {
      return (0, _validateNode.default)({
        type: "EnumBooleanBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumNumberBody(members) {
      return (0, _validateNode.default)({
        type: "EnumNumberBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumStringBody(members) {
      return (0, _validateNode.default)({
        type: "EnumStringBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumSymbolBody(members) {
      return (0, _validateNode.default)({
        type: "EnumSymbolBody",
        members,
        hasUnknownMembers: null
      });
    }
    function enumBooleanMember(id) {
      return (0, _validateNode.default)({
        type: "EnumBooleanMember",
        id,
        init: null
      });
    }
    function enumNumberMember(id, init) {
      return (0, _validateNode.default)({
        type: "EnumNumberMember",
        id,
        init
      });
    }
    function enumStringMember(id, init) {
      return (0, _validateNode.default)({
        type: "EnumStringMember",
        id,
        init
      });
    }
    function enumDefaultedMember(id) {
      return (0, _validateNode.default)({
        type: "EnumDefaultedMember",
        id
      });
    }
    function indexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "IndexedAccessType",
        objectType,
        indexType
      });
    }
    function optionalIndexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "OptionalIndexedAccessType",
        objectType,
        indexType,
        optional: null
      });
    }
    function jsxAttribute(name, value2 = null) {
      return (0, _validateNode.default)({
        type: "JSXAttribute",
        name,
        value: value2
      });
    }
    function jsxClosingElement(name) {
      return (0, _validateNode.default)({
        type: "JSXClosingElement",
        name
      });
    }
    function jsxElement(openingElement, closingElement = null, children, selfClosing = null) {
      return (0, _validateNode.default)({
        type: "JSXElement",
        openingElement,
        closingElement,
        children,
        selfClosing
      });
    }
    function jsxEmptyExpression() {
      return {
        type: "JSXEmptyExpression"
      };
    }
    function jsxExpressionContainer(expression) {
      return (0, _validateNode.default)({
        type: "JSXExpressionContainer",
        expression
      });
    }
    function jsxSpreadChild(expression) {
      return (0, _validateNode.default)({
        type: "JSXSpreadChild",
        expression
      });
    }
    function jsxIdentifier(name) {
      return (0, _validateNode.default)({
        type: "JSXIdentifier",
        name
      });
    }
    function jsxMemberExpression(object, property) {
      return (0, _validateNode.default)({
        type: "JSXMemberExpression",
        object,
        property
      });
    }
    function jsxNamespacedName(namespace, name) {
      return (0, _validateNode.default)({
        type: "JSXNamespacedName",
        namespace,
        name
      });
    }
    function jsxOpeningElement(name, attributes, selfClosing = false) {
      return (0, _validateNode.default)({
        type: "JSXOpeningElement",
        name,
        attributes,
        selfClosing
      });
    }
    function jsxSpreadAttribute(argument) {
      return (0, _validateNode.default)({
        type: "JSXSpreadAttribute",
        argument
      });
    }
    function jsxText(value2) {
      return (0, _validateNode.default)({
        type: "JSXText",
        value: value2
      });
    }
    function jsxFragment(openingFragment, closingFragment, children) {
      return (0, _validateNode.default)({
        type: "JSXFragment",
        openingFragment,
        closingFragment,
        children
      });
    }
    function jsxOpeningFragment() {
      return {
        type: "JSXOpeningFragment"
      };
    }
    function jsxClosingFragment() {
      return {
        type: "JSXClosingFragment"
      };
    }
    function noop() {
      return {
        type: "Noop"
      };
    }
    function placeholder(expectedNode, name) {
      return (0, _validateNode.default)({
        type: "Placeholder",
        expectedNode,
        name
      });
    }
    function v8IntrinsicIdentifier(name) {
      return (0, _validateNode.default)({
        type: "V8IntrinsicIdentifier",
        name
      });
    }
    function argumentPlaceholder() {
      return {
        type: "ArgumentPlaceholder"
      };
    }
    function bindExpression(object, callee) {
      return (0, _validateNode.default)({
        type: "BindExpression",
        object,
        callee
      });
    }
    function importAttribute(key, value2) {
      return (0, _validateNode.default)({
        type: "ImportAttribute",
        key,
        value: value2
      });
    }
    function decorator(expression) {
      return (0, _validateNode.default)({
        type: "Decorator",
        expression
      });
    }
    function doExpression(body, async = false) {
      return (0, _validateNode.default)({
        type: "DoExpression",
        body,
        async
      });
    }
    function exportDefaultSpecifier(exported) {
      return (0, _validateNode.default)({
        type: "ExportDefaultSpecifier",
        exported
      });
    }
    function recordExpression(properties) {
      return (0, _validateNode.default)({
        type: "RecordExpression",
        properties
      });
    }
    function tupleExpression(elements = []) {
      return (0, _validateNode.default)({
        type: "TupleExpression",
        elements
      });
    }
    function decimalLiteral(value2) {
      return (0, _validateNode.default)({
        type: "DecimalLiteral",
        value: value2
      });
    }
    function moduleExpression(body) {
      return (0, _validateNode.default)({
        type: "ModuleExpression",
        body
      });
    }
    function topicReference() {
      return {
        type: "TopicReference"
      };
    }
    function pipelineTopicExpression(expression) {
      return (0, _validateNode.default)({
        type: "PipelineTopicExpression",
        expression
      });
    }
    function pipelineBareFunction(callee) {
      return (0, _validateNode.default)({
        type: "PipelineBareFunction",
        callee
      });
    }
    function pipelinePrimaryTopicReference() {
      return {
        type: "PipelinePrimaryTopicReference"
      };
    }
    function tsParameterProperty(parameter) {
      return (0, _validateNode.default)({
        type: "TSParameterProperty",
        parameter
      });
    }
    function tsDeclareFunction(id = null, typeParameters = null, params, returnType = null) {
      return (0, _validateNode.default)({
        type: "TSDeclareFunction",
        id,
        typeParameters,
        params,
        returnType
      });
    }
    function tsDeclareMethod(decorators = null, key, typeParameters = null, params, returnType = null) {
      return (0, _validateNode.default)({
        type: "TSDeclareMethod",
        decorators,
        key,
        typeParameters,
        params,
        returnType
      });
    }
    function tsQualifiedName(left, right) {
      return (0, _validateNode.default)({
        type: "TSQualifiedName",
        left,
        right
      });
    }
    function tsCallSignatureDeclaration(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSCallSignatureDeclaration",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsConstructSignatureDeclaration(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSConstructSignatureDeclaration",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsPropertySignature(key, typeAnnotation2 = null, initializer = null) {
      return (0, _validateNode.default)({
        type: "TSPropertySignature",
        key,
        typeAnnotation: typeAnnotation2,
        initializer,
        kind: null
      });
    }
    function tsMethodSignature(key, typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSMethodSignature",
        key,
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2,
        kind: null
      });
    }
    function tsIndexSignature(parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSIndexSignature",
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsAnyKeyword() {
      return {
        type: "TSAnyKeyword"
      };
    }
    function tsBooleanKeyword() {
      return {
        type: "TSBooleanKeyword"
      };
    }
    function tsBigIntKeyword() {
      return {
        type: "TSBigIntKeyword"
      };
    }
    function tsIntrinsicKeyword() {
      return {
        type: "TSIntrinsicKeyword"
      };
    }
    function tsNeverKeyword() {
      return {
        type: "TSNeverKeyword"
      };
    }
    function tsNullKeyword() {
      return {
        type: "TSNullKeyword"
      };
    }
    function tsNumberKeyword() {
      return {
        type: "TSNumberKeyword"
      };
    }
    function tsObjectKeyword() {
      return {
        type: "TSObjectKeyword"
      };
    }
    function tsStringKeyword() {
      return {
        type: "TSStringKeyword"
      };
    }
    function tsSymbolKeyword() {
      return {
        type: "TSSymbolKeyword"
      };
    }
    function tsUndefinedKeyword() {
      return {
        type: "TSUndefinedKeyword"
      };
    }
    function tsUnknownKeyword() {
      return {
        type: "TSUnknownKeyword"
      };
    }
    function tsVoidKeyword() {
      return {
        type: "TSVoidKeyword"
      };
    }
    function tsThisType() {
      return {
        type: "TSThisType"
      };
    }
    function tsFunctionType(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSFunctionType",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsConstructorType(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSConstructorType",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeReference(typeName, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSTypeReference",
        typeName,
        typeParameters
      });
    }
    function tsTypePredicate(parameterName, typeAnnotation2 = null, asserts = null) {
      return (0, _validateNode.default)({
        type: "TSTypePredicate",
        parameterName,
        typeAnnotation: typeAnnotation2,
        asserts
      });
    }
    function tsTypeQuery(exprName, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSTypeQuery",
        exprName,
        typeParameters
      });
    }
    function tsTypeLiteral(members) {
      return (0, _validateNode.default)({
        type: "TSTypeLiteral",
        members
      });
    }
    function tsArrayType(elementType) {
      return (0, _validateNode.default)({
        type: "TSArrayType",
        elementType
      });
    }
    function tsTupleType(elementTypes) {
      return (0, _validateNode.default)({
        type: "TSTupleType",
        elementTypes
      });
    }
    function tsOptionalType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSOptionalType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsRestType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSRestType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsNamedTupleMember(label, elementType, optional = false) {
      return (0, _validateNode.default)({
        type: "TSNamedTupleMember",
        label,
        elementType,
        optional
      });
    }
    function tsUnionType(types) {
      return (0, _validateNode.default)({
        type: "TSUnionType",
        types
      });
    }
    function tsIntersectionType(types) {
      return (0, _validateNode.default)({
        type: "TSIntersectionType",
        types
      });
    }
    function tsConditionalType(checkType, extendsType, trueType, falseType) {
      return (0, _validateNode.default)({
        type: "TSConditionalType",
        checkType,
        extendsType,
        trueType,
        falseType
      });
    }
    function tsInferType(typeParameter2) {
      return (0, _validateNode.default)({
        type: "TSInferType",
        typeParameter: typeParameter2
      });
    }
    function tsParenthesizedType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSParenthesizedType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeOperator(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeOperator",
        typeAnnotation: typeAnnotation2,
        operator: null
      });
    }
    function tsIndexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "TSIndexedAccessType",
        objectType,
        indexType
      });
    }
    function tsMappedType(typeParameter2, typeAnnotation2 = null, nameType = null) {
      return (0, _validateNode.default)({
        type: "TSMappedType",
        typeParameter: typeParameter2,
        typeAnnotation: typeAnnotation2,
        nameType
      });
    }
    function tsLiteralType(literal) {
      return (0, _validateNode.default)({
        type: "TSLiteralType",
        literal
      });
    }
    function tsExpressionWithTypeArguments(expression, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSExpressionWithTypeArguments",
        expression,
        typeParameters
      });
    }
    function tsInterfaceDeclaration(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "TSInterfaceDeclaration",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function tsInterfaceBody(body) {
      return (0, _validateNode.default)({
        type: "TSInterfaceBody",
        body
      });
    }
    function tsTypeAliasDeclaration(id, typeParameters = null, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeAliasDeclaration",
        id,
        typeParameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsInstantiationExpression(expression, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSInstantiationExpression",
        expression,
        typeParameters
      });
    }
    function tsAsExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSAsExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsSatisfiesExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSSatisfiesExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeAssertion(typeAnnotation2, expression) {
      return (0, _validateNode.default)({
        type: "TSTypeAssertion",
        typeAnnotation: typeAnnotation2,
        expression
      });
    }
    function tsEnumDeclaration(id, members) {
      return (0, _validateNode.default)({
        type: "TSEnumDeclaration",
        id,
        members
      });
    }
    function tsEnumMember(id, initializer = null) {
      return (0, _validateNode.default)({
        type: "TSEnumMember",
        id,
        initializer
      });
    }
    function tsModuleDeclaration(id, body) {
      return (0, _validateNode.default)({
        type: "TSModuleDeclaration",
        id,
        body
      });
    }
    function tsModuleBlock(body) {
      return (0, _validateNode.default)({
        type: "TSModuleBlock",
        body
      });
    }
    function tsImportType(argument, qualifier = null, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSImportType",
        argument,
        qualifier,
        typeParameters
      });
    }
    function tsImportEqualsDeclaration(id, moduleReference) {
      return (0, _validateNode.default)({
        type: "TSImportEqualsDeclaration",
        id,
        moduleReference,
        isExport: null
      });
    }
    function tsExternalModuleReference(expression) {
      return (0, _validateNode.default)({
        type: "TSExternalModuleReference",
        expression
      });
    }
    function tsNonNullExpression(expression) {
      return (0, _validateNode.default)({
        type: "TSNonNullExpression",
        expression
      });
    }
    function tsExportAssignment(expression) {
      return (0, _validateNode.default)({
        type: "TSExportAssignment",
        expression
      });
    }
    function tsNamespaceExportDeclaration(id) {
      return (0, _validateNode.default)({
        type: "TSNamespaceExportDeclaration",
        id
      });
    }
    function tsTypeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeParameterInstantiation(params) {
      return (0, _validateNode.default)({
        type: "TSTypeParameterInstantiation",
        params
      });
    }
    function tsTypeParameterDeclaration(params) {
      return (0, _validateNode.default)({
        type: "TSTypeParameterDeclaration",
        params
      });
    }
    function tsTypeParameter(constraint = null, _default = null, name) {
      return (0, _validateNode.default)({
        type: "TSTypeParameter",
        constraint,
        default: _default,
        name
      });
    }
    function NumberLiteral(value2) {
      console.trace("The node type NumberLiteral has been renamed to NumericLiteral");
      return numericLiteral(value2);
    }
    function RegexLiteral(pattern, flags = "") {
      console.trace("The node type RegexLiteral has been renamed to RegExpLiteral");
      return regExpLiteral(pattern, flags);
    }
    function RestProperty(argument) {
      console.trace("The node type RestProperty has been renamed to RestElement");
      return restElement(argument);
    }
    function SpreadProperty(argument) {
      console.trace("The node type SpreadProperty has been renamed to SpreadElement");
      return spreadElement(argument);
    }
  }
});

// node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js
var require_cleanJSXElementLiteralChild = __commonJS({
  "node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cleanJSXElementLiteralChild;
    var _generated = require_generated2();
    var _ = require_lib11();
    function cleanJSXElementLiteralChild(child, args) {
      const lines = child.value.split(/\r\n|\n|\r/);
      let lastNonEmptyLine = 0;
      for (let i = 0; i < lines.length; i++) {
        if (lines[i].match(/[^ \t]/)) {
          lastNonEmptyLine = i;
        }
      }
      let str = "";
      for (let i = 0; i < lines.length; i++) {
        const line = lines[i];
        const isFirstLine = i === 0;
        const isLastLine = i === lines.length - 1;
        const isLastNonEmptyLine = i === lastNonEmptyLine;
        let trimmedLine = line.replace(/\t/g, " ");
        if (!isFirstLine) {
          trimmedLine = trimmedLine.replace(/^[ ]+/, "");
        }
        if (!isLastLine) {
          trimmedLine = trimmedLine.replace(/[ ]+$/, "");
        }
        if (trimmedLine) {
          if (!isLastNonEmptyLine) {
            trimmedLine += " ";
          }
          str += trimmedLine;
        }
      }
      if (str)
        args.push((0, _.inherits)((0, _generated.stringLiteral)(str), child));
    }
  }
});

// node_modules/@babel/types/lib/builders/react/buildChildren.js
var require_buildChildren = __commonJS({
  "node_modules/@babel/types/lib/builders/react/buildChildren.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = buildChildren;
    var _generated = require_generated();
    var _cleanJSXElementLiteralChild = require_cleanJSXElementLiteralChild();
    function buildChildren(node) {
      const elements = [];
      for (let i = 0; i < node.children.length; i++) {
        let child = node.children[i];
        if ((0, _generated.isJSXText)(child)) {
          (0, _cleanJSXElementLiteralChild.default)(child, elements);
          continue;
        }
        if ((0, _generated.isJSXExpressionContainer)(child))
          child = child.expression;
        if ((0, _generated.isJSXEmptyExpression)(child))
          continue;
        elements.push(child);
      }
      return elements;
    }
  }
});

// node_modules/@babel/types/lib/validators/isNode.js
var require_isNode = __commonJS({
  "node_modules/@babel/types/lib/validators/isNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isNode;
    var _definitions = require_definitions();
    function isNode(node) {
      return !!(node && _definitions.VISITOR_KEYS[node.type]);
    }
  }
});

// node_modules/@babel/types/lib/asserts/assertNode.js
var require_assertNode = __commonJS({
  "node_modules/@babel/types/lib/asserts/assertNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = assertNode;
    var _isNode = require_isNode();
    function assertNode(node) {
      if (!(0, _isNode.default)(node)) {
        var _node$type;
        const type = (_node$type = node == null ? void 0 : node.type) != null ? _node$type : JSON.stringify(node);
        throw new TypeError(`Not a valid node of type "${type}"`);
      }
    }
  }
});

// node_modules/@babel/types/lib/asserts/generated/index.js
var require_generated3 = __commonJS({
  "node_modules/@babel/types/lib/asserts/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.assertAccessor = assertAccessor;
    exports.assertAnyTypeAnnotation = assertAnyTypeAnnotation;
    exports.assertArgumentPlaceholder = assertArgumentPlaceholder;
    exports.assertArrayExpression = assertArrayExpression;
    exports.assertArrayPattern = assertArrayPattern;
    exports.assertArrayTypeAnnotation = assertArrayTypeAnnotation;
    exports.assertArrowFunctionExpression = assertArrowFunctionExpression;
    exports.assertAssignmentExpression = assertAssignmentExpression;
    exports.assertAssignmentPattern = assertAssignmentPattern;
    exports.assertAwaitExpression = assertAwaitExpression;
    exports.assertBigIntLiteral = assertBigIntLiteral;
    exports.assertBinary = assertBinary;
    exports.assertBinaryExpression = assertBinaryExpression;
    exports.assertBindExpression = assertBindExpression;
    exports.assertBlock = assertBlock;
    exports.assertBlockParent = assertBlockParent;
    exports.assertBlockStatement = assertBlockStatement;
    exports.assertBooleanLiteral = assertBooleanLiteral;
    exports.assertBooleanLiteralTypeAnnotation = assertBooleanLiteralTypeAnnotation;
    exports.assertBooleanTypeAnnotation = assertBooleanTypeAnnotation;
    exports.assertBreakStatement = assertBreakStatement;
    exports.assertCallExpression = assertCallExpression;
    exports.assertCatchClause = assertCatchClause;
    exports.assertClass = assertClass;
    exports.assertClassAccessorProperty = assertClassAccessorProperty;
    exports.assertClassBody = assertClassBody;
    exports.assertClassDeclaration = assertClassDeclaration;
    exports.assertClassExpression = assertClassExpression;
    exports.assertClassImplements = assertClassImplements;
    exports.assertClassMethod = assertClassMethod;
    exports.assertClassPrivateMethod = assertClassPrivateMethod;
    exports.assertClassPrivateProperty = assertClassPrivateProperty;
    exports.assertClassProperty = assertClassProperty;
    exports.assertCompletionStatement = assertCompletionStatement;
    exports.assertConditional = assertConditional;
    exports.assertConditionalExpression = assertConditionalExpression;
    exports.assertContinueStatement = assertContinueStatement;
    exports.assertDebuggerStatement = assertDebuggerStatement;
    exports.assertDecimalLiteral = assertDecimalLiteral;
    exports.assertDeclaration = assertDeclaration;
    exports.assertDeclareClass = assertDeclareClass;
    exports.assertDeclareExportAllDeclaration = assertDeclareExportAllDeclaration;
    exports.assertDeclareExportDeclaration = assertDeclareExportDeclaration;
    exports.assertDeclareFunction = assertDeclareFunction;
    exports.assertDeclareInterface = assertDeclareInterface;
    exports.assertDeclareModule = assertDeclareModule;
    exports.assertDeclareModuleExports = assertDeclareModuleExports;
    exports.assertDeclareOpaqueType = assertDeclareOpaqueType;
    exports.assertDeclareTypeAlias = assertDeclareTypeAlias;
    exports.assertDeclareVariable = assertDeclareVariable;
    exports.assertDeclaredPredicate = assertDeclaredPredicate;
    exports.assertDecorator = assertDecorator;
    exports.assertDirective = assertDirective;
    exports.assertDirectiveLiteral = assertDirectiveLiteral;
    exports.assertDoExpression = assertDoExpression;
    exports.assertDoWhileStatement = assertDoWhileStatement;
    exports.assertEmptyStatement = assertEmptyStatement;
    exports.assertEmptyTypeAnnotation = assertEmptyTypeAnnotation;
    exports.assertEnumBody = assertEnumBody;
    exports.assertEnumBooleanBody = assertEnumBooleanBody;
    exports.assertEnumBooleanMember = assertEnumBooleanMember;
    exports.assertEnumDeclaration = assertEnumDeclaration;
    exports.assertEnumDefaultedMember = assertEnumDefaultedMember;
    exports.assertEnumMember = assertEnumMember;
    exports.assertEnumNumberBody = assertEnumNumberBody;
    exports.assertEnumNumberMember = assertEnumNumberMember;
    exports.assertEnumStringBody = assertEnumStringBody;
    exports.assertEnumStringMember = assertEnumStringMember;
    exports.assertEnumSymbolBody = assertEnumSymbolBody;
    exports.assertExistsTypeAnnotation = assertExistsTypeAnnotation;
    exports.assertExportAllDeclaration = assertExportAllDeclaration;
    exports.assertExportDeclaration = assertExportDeclaration;
    exports.assertExportDefaultDeclaration = assertExportDefaultDeclaration;
    exports.assertExportDefaultSpecifier = assertExportDefaultSpecifier;
    exports.assertExportNamedDeclaration = assertExportNamedDeclaration;
    exports.assertExportNamespaceSpecifier = assertExportNamespaceSpecifier;
    exports.assertExportSpecifier = assertExportSpecifier;
    exports.assertExpression = assertExpression;
    exports.assertExpressionStatement = assertExpressionStatement;
    exports.assertExpressionWrapper = assertExpressionWrapper;
    exports.assertFile = assertFile;
    exports.assertFlow = assertFlow;
    exports.assertFlowBaseAnnotation = assertFlowBaseAnnotation;
    exports.assertFlowDeclaration = assertFlowDeclaration;
    exports.assertFlowPredicate = assertFlowPredicate;
    exports.assertFlowType = assertFlowType;
    exports.assertFor = assertFor;
    exports.assertForInStatement = assertForInStatement;
    exports.assertForOfStatement = assertForOfStatement;
    exports.assertForStatement = assertForStatement;
    exports.assertForXStatement = assertForXStatement;
    exports.assertFunction = assertFunction;
    exports.assertFunctionDeclaration = assertFunctionDeclaration;
    exports.assertFunctionExpression = assertFunctionExpression;
    exports.assertFunctionParent = assertFunctionParent;
    exports.assertFunctionTypeAnnotation = assertFunctionTypeAnnotation;
    exports.assertFunctionTypeParam = assertFunctionTypeParam;
    exports.assertGenericTypeAnnotation = assertGenericTypeAnnotation;
    exports.assertIdentifier = assertIdentifier;
    exports.assertIfStatement = assertIfStatement;
    exports.assertImmutable = assertImmutable;
    exports.assertImport = assertImport;
    exports.assertImportAttribute = assertImportAttribute;
    exports.assertImportDeclaration = assertImportDeclaration;
    exports.assertImportDefaultSpecifier = assertImportDefaultSpecifier;
    exports.assertImportNamespaceSpecifier = assertImportNamespaceSpecifier;
    exports.assertImportSpecifier = assertImportSpecifier;
    exports.assertIndexedAccessType = assertIndexedAccessType;
    exports.assertInferredPredicate = assertInferredPredicate;
    exports.assertInterfaceDeclaration = assertInterfaceDeclaration;
    exports.assertInterfaceExtends = assertInterfaceExtends;
    exports.assertInterfaceTypeAnnotation = assertInterfaceTypeAnnotation;
    exports.assertInterpreterDirective = assertInterpreterDirective;
    exports.assertIntersectionTypeAnnotation = assertIntersectionTypeAnnotation;
    exports.assertJSX = assertJSX;
    exports.assertJSXAttribute = assertJSXAttribute;
    exports.assertJSXClosingElement = assertJSXClosingElement;
    exports.assertJSXClosingFragment = assertJSXClosingFragment;
    exports.assertJSXElement = assertJSXElement;
    exports.assertJSXEmptyExpression = assertJSXEmptyExpression;
    exports.assertJSXExpressionContainer = assertJSXExpressionContainer;
    exports.assertJSXFragment = assertJSXFragment;
    exports.assertJSXIdentifier = assertJSXIdentifier;
    exports.assertJSXMemberExpression = assertJSXMemberExpression;
    exports.assertJSXNamespacedName = assertJSXNamespacedName;
    exports.assertJSXOpeningElement = assertJSXOpeningElement;
    exports.assertJSXOpeningFragment = assertJSXOpeningFragment;
    exports.assertJSXSpreadAttribute = assertJSXSpreadAttribute;
    exports.assertJSXSpreadChild = assertJSXSpreadChild;
    exports.assertJSXText = assertJSXText;
    exports.assertLVal = assertLVal;
    exports.assertLabeledStatement = assertLabeledStatement;
    exports.assertLiteral = assertLiteral;
    exports.assertLogicalExpression = assertLogicalExpression;
    exports.assertLoop = assertLoop;
    exports.assertMemberExpression = assertMemberExpression;
    exports.assertMetaProperty = assertMetaProperty;
    exports.assertMethod = assertMethod;
    exports.assertMiscellaneous = assertMiscellaneous;
    exports.assertMixedTypeAnnotation = assertMixedTypeAnnotation;
    exports.assertModuleDeclaration = assertModuleDeclaration;
    exports.assertModuleExpression = assertModuleExpression;
    exports.assertModuleSpecifier = assertModuleSpecifier;
    exports.assertNewExpression = assertNewExpression;
    exports.assertNoop = assertNoop;
    exports.assertNullLiteral = assertNullLiteral;
    exports.assertNullLiteralTypeAnnotation = assertNullLiteralTypeAnnotation;
    exports.assertNullableTypeAnnotation = assertNullableTypeAnnotation;
    exports.assertNumberLiteral = assertNumberLiteral;
    exports.assertNumberLiteralTypeAnnotation = assertNumberLiteralTypeAnnotation;
    exports.assertNumberTypeAnnotation = assertNumberTypeAnnotation;
    exports.assertNumericLiteral = assertNumericLiteral;
    exports.assertObjectExpression = assertObjectExpression;
    exports.assertObjectMember = assertObjectMember;
    exports.assertObjectMethod = assertObjectMethod;
    exports.assertObjectPattern = assertObjectPattern;
    exports.assertObjectProperty = assertObjectProperty;
    exports.assertObjectTypeAnnotation = assertObjectTypeAnnotation;
    exports.assertObjectTypeCallProperty = assertObjectTypeCallProperty;
    exports.assertObjectTypeIndexer = assertObjectTypeIndexer;
    exports.assertObjectTypeInternalSlot = assertObjectTypeInternalSlot;
    exports.assertObjectTypeProperty = assertObjectTypeProperty;
    exports.assertObjectTypeSpreadProperty = assertObjectTypeSpreadProperty;
    exports.assertOpaqueType = assertOpaqueType;
    exports.assertOptionalCallExpression = assertOptionalCallExpression;
    exports.assertOptionalIndexedAccessType = assertOptionalIndexedAccessType;
    exports.assertOptionalMemberExpression = assertOptionalMemberExpression;
    exports.assertParenthesizedExpression = assertParenthesizedExpression;
    exports.assertPattern = assertPattern;
    exports.assertPatternLike = assertPatternLike;
    exports.assertPipelineBareFunction = assertPipelineBareFunction;
    exports.assertPipelinePrimaryTopicReference = assertPipelinePrimaryTopicReference;
    exports.assertPipelineTopicExpression = assertPipelineTopicExpression;
    exports.assertPlaceholder = assertPlaceholder;
    exports.assertPrivate = assertPrivate;
    exports.assertPrivateName = assertPrivateName;
    exports.assertProgram = assertProgram;
    exports.assertProperty = assertProperty;
    exports.assertPureish = assertPureish;
    exports.assertQualifiedTypeIdentifier = assertQualifiedTypeIdentifier;
    exports.assertRecordExpression = assertRecordExpression;
    exports.assertRegExpLiteral = assertRegExpLiteral;
    exports.assertRegexLiteral = assertRegexLiteral;
    exports.assertRestElement = assertRestElement;
    exports.assertRestProperty = assertRestProperty;
    exports.assertReturnStatement = assertReturnStatement;
    exports.assertScopable = assertScopable;
    exports.assertSequenceExpression = assertSequenceExpression;
    exports.assertSpreadElement = assertSpreadElement;
    exports.assertSpreadProperty = assertSpreadProperty;
    exports.assertStandardized = assertStandardized;
    exports.assertStatement = assertStatement;
    exports.assertStaticBlock = assertStaticBlock;
    exports.assertStringLiteral = assertStringLiteral;
    exports.assertStringLiteralTypeAnnotation = assertStringLiteralTypeAnnotation;
    exports.assertStringTypeAnnotation = assertStringTypeAnnotation;
    exports.assertSuper = assertSuper;
    exports.assertSwitchCase = assertSwitchCase;
    exports.assertSwitchStatement = assertSwitchStatement;
    exports.assertSymbolTypeAnnotation = assertSymbolTypeAnnotation;
    exports.assertTSAnyKeyword = assertTSAnyKeyword;
    exports.assertTSArrayType = assertTSArrayType;
    exports.assertTSAsExpression = assertTSAsExpression;
    exports.assertTSBaseType = assertTSBaseType;
    exports.assertTSBigIntKeyword = assertTSBigIntKeyword;
    exports.assertTSBooleanKeyword = assertTSBooleanKeyword;
    exports.assertTSCallSignatureDeclaration = assertTSCallSignatureDeclaration;
    exports.assertTSConditionalType = assertTSConditionalType;
    exports.assertTSConstructSignatureDeclaration = assertTSConstructSignatureDeclaration;
    exports.assertTSConstructorType = assertTSConstructorType;
    exports.assertTSDeclareFunction = assertTSDeclareFunction;
    exports.assertTSDeclareMethod = assertTSDeclareMethod;
    exports.assertTSEntityName = assertTSEntityName;
    exports.assertTSEnumDeclaration = assertTSEnumDeclaration;
    exports.assertTSEnumMember = assertTSEnumMember;
    exports.assertTSExportAssignment = assertTSExportAssignment;
    exports.assertTSExpressionWithTypeArguments = assertTSExpressionWithTypeArguments;
    exports.assertTSExternalModuleReference = assertTSExternalModuleReference;
    exports.assertTSFunctionType = assertTSFunctionType;
    exports.assertTSImportEqualsDeclaration = assertTSImportEqualsDeclaration;
    exports.assertTSImportType = assertTSImportType;
    exports.assertTSIndexSignature = assertTSIndexSignature;
    exports.assertTSIndexedAccessType = assertTSIndexedAccessType;
    exports.assertTSInferType = assertTSInferType;
    exports.assertTSInstantiationExpression = assertTSInstantiationExpression;
    exports.assertTSInterfaceBody = assertTSInterfaceBody;
    exports.assertTSInterfaceDeclaration = assertTSInterfaceDeclaration;
    exports.assertTSIntersectionType = assertTSIntersectionType;
    exports.assertTSIntrinsicKeyword = assertTSIntrinsicKeyword;
    exports.assertTSLiteralType = assertTSLiteralType;
    exports.assertTSMappedType = assertTSMappedType;
    exports.assertTSMethodSignature = assertTSMethodSignature;
    exports.assertTSModuleBlock = assertTSModuleBlock;
    exports.assertTSModuleDeclaration = assertTSModuleDeclaration;
    exports.assertTSNamedTupleMember = assertTSNamedTupleMember;
    exports.assertTSNamespaceExportDeclaration = assertTSNamespaceExportDeclaration;
    exports.assertTSNeverKeyword = assertTSNeverKeyword;
    exports.assertTSNonNullExpression = assertTSNonNullExpression;
    exports.assertTSNullKeyword = assertTSNullKeyword;
    exports.assertTSNumberKeyword = assertTSNumberKeyword;
    exports.assertTSObjectKeyword = assertTSObjectKeyword;
    exports.assertTSOptionalType = assertTSOptionalType;
    exports.assertTSParameterProperty = assertTSParameterProperty;
    exports.assertTSParenthesizedType = assertTSParenthesizedType;
    exports.assertTSPropertySignature = assertTSPropertySignature;
    exports.assertTSQualifiedName = assertTSQualifiedName;
    exports.assertTSRestType = assertTSRestType;
    exports.assertTSSatisfiesExpression = assertTSSatisfiesExpression;
    exports.assertTSStringKeyword = assertTSStringKeyword;
    exports.assertTSSymbolKeyword = assertTSSymbolKeyword;
    exports.assertTSThisType = assertTSThisType;
    exports.assertTSTupleType = assertTSTupleType;
    exports.assertTSType = assertTSType;
    exports.assertTSTypeAliasDeclaration = assertTSTypeAliasDeclaration;
    exports.assertTSTypeAnnotation = assertTSTypeAnnotation;
    exports.assertTSTypeAssertion = assertTSTypeAssertion;
    exports.assertTSTypeElement = assertTSTypeElement;
    exports.assertTSTypeLiteral = assertTSTypeLiteral;
    exports.assertTSTypeOperator = assertTSTypeOperator;
    exports.assertTSTypeParameter = assertTSTypeParameter;
    exports.assertTSTypeParameterDeclaration = assertTSTypeParameterDeclaration;
    exports.assertTSTypeParameterInstantiation = assertTSTypeParameterInstantiation;
    exports.assertTSTypePredicate = assertTSTypePredicate;
    exports.assertTSTypeQuery = assertTSTypeQuery;
    exports.assertTSTypeReference = assertTSTypeReference;
    exports.assertTSUndefinedKeyword = assertTSUndefinedKeyword;
    exports.assertTSUnionType = assertTSUnionType;
    exports.assertTSUnknownKeyword = assertTSUnknownKeyword;
    exports.assertTSVoidKeyword = assertTSVoidKeyword;
    exports.assertTaggedTemplateExpression = assertTaggedTemplateExpression;
    exports.assertTemplateElement = assertTemplateElement;
    exports.assertTemplateLiteral = assertTemplateLiteral;
    exports.assertTerminatorless = assertTerminatorless;
    exports.assertThisExpression = assertThisExpression;
    exports.assertThisTypeAnnotation = assertThisTypeAnnotation;
    exports.assertThrowStatement = assertThrowStatement;
    exports.assertTopicReference = assertTopicReference;
    exports.assertTryStatement = assertTryStatement;
    exports.assertTupleExpression = assertTupleExpression;
    exports.assertTupleTypeAnnotation = assertTupleTypeAnnotation;
    exports.assertTypeAlias = assertTypeAlias;
    exports.assertTypeAnnotation = assertTypeAnnotation;
    exports.assertTypeCastExpression = assertTypeCastExpression;
    exports.assertTypeParameter = assertTypeParameter;
    exports.assertTypeParameterDeclaration = assertTypeParameterDeclaration;
    exports.assertTypeParameterInstantiation = assertTypeParameterInstantiation;
    exports.assertTypeScript = assertTypeScript;
    exports.assertTypeofTypeAnnotation = assertTypeofTypeAnnotation;
    exports.assertUnaryExpression = assertUnaryExpression;
    exports.assertUnaryLike = assertUnaryLike;
    exports.assertUnionTypeAnnotation = assertUnionTypeAnnotation;
    exports.assertUpdateExpression = assertUpdateExpression;
    exports.assertUserWhitespacable = assertUserWhitespacable;
    exports.assertV8IntrinsicIdentifier = assertV8IntrinsicIdentifier;
    exports.assertVariableDeclaration = assertVariableDeclaration;
    exports.assertVariableDeclarator = assertVariableDeclarator;
    exports.assertVariance = assertVariance;
    exports.assertVoidTypeAnnotation = assertVoidTypeAnnotation;
    exports.assertWhile = assertWhile;
    exports.assertWhileStatement = assertWhileStatement;
    exports.assertWithStatement = assertWithStatement;
    exports.assertYieldExpression = assertYieldExpression;
    var _is = require_is();
    function assert(type, node, opts) {
      if (!(0, _is.default)(type, node, opts)) {
        throw new Error(`Expected type "${type}" with option ${JSON.stringify(opts)}, but instead got "${node.type}".`);
      }
    }
    function assertArrayExpression(node, opts) {
      assert("ArrayExpression", node, opts);
    }
    function assertAssignmentExpression(node, opts) {
      assert("AssignmentExpression", node, opts);
    }
    function assertBinaryExpression(node, opts) {
      assert("BinaryExpression", node, opts);
    }
    function assertInterpreterDirective(node, opts) {
      assert("InterpreterDirective", node, opts);
    }
    function assertDirective(node, opts) {
      assert("Directive", node, opts);
    }
    function assertDirectiveLiteral(node, opts) {
      assert("DirectiveLiteral", node, opts);
    }
    function assertBlockStatement(node, opts) {
      assert("BlockStatement", node, opts);
    }
    function assertBreakStatement(node, opts) {
      assert("BreakStatement", node, opts);
    }
    function assertCallExpression(node, opts) {
      assert("CallExpression", node, opts);
    }
    function assertCatchClause(node, opts) {
      assert("CatchClause", node, opts);
    }
    function assertConditionalExpression(node, opts) {
      assert("ConditionalExpression", node, opts);
    }
    function assertContinueStatement(node, opts) {
      assert("ContinueStatement", node, opts);
    }
    function assertDebuggerStatement(node, opts) {
      assert("DebuggerStatement", node, opts);
    }
    function assertDoWhileStatement(node, opts) {
      assert("DoWhileStatement", node, opts);
    }
    function assertEmptyStatement(node, opts) {
      assert("EmptyStatement", node, opts);
    }
    function assertExpressionStatement(node, opts) {
      assert("ExpressionStatement", node, opts);
    }
    function assertFile(node, opts) {
      assert("File", node, opts);
    }
    function assertForInStatement(node, opts) {
      assert("ForInStatement", node, opts);
    }
    function assertForStatement(node, opts) {
      assert("ForStatement", node, opts);
    }
    function assertFunctionDeclaration(node, opts) {
      assert("FunctionDeclaration", node, opts);
    }
    function assertFunctionExpression(node, opts) {
      assert("FunctionExpression", node, opts);
    }
    function assertIdentifier(node, opts) {
      assert("Identifier", node, opts);
    }
    function assertIfStatement(node, opts) {
      assert("IfStatement", node, opts);
    }
    function assertLabeledStatement(node, opts) {
      assert("LabeledStatement", node, opts);
    }
    function assertStringLiteral(node, opts) {
      assert("StringLiteral", node, opts);
    }
    function assertNumericLiteral(node, opts) {
      assert("NumericLiteral", node, opts);
    }
    function assertNullLiteral(node, opts) {
      assert("NullLiteral", node, opts);
    }
    function assertBooleanLiteral(node, opts) {
      assert("BooleanLiteral", node, opts);
    }
    function assertRegExpLiteral(node, opts) {
      assert("RegExpLiteral", node, opts);
    }
    function assertLogicalExpression(node, opts) {
      assert("LogicalExpression", node, opts);
    }
    function assertMemberExpression(node, opts) {
      assert("MemberExpression", node, opts);
    }
    function assertNewExpression(node, opts) {
      assert("NewExpression", node, opts);
    }
    function assertProgram(node, opts) {
      assert("Program", node, opts);
    }
    function assertObjectExpression(node, opts) {
      assert("ObjectExpression", node, opts);
    }
    function assertObjectMethod(node, opts) {
      assert("ObjectMethod", node, opts);
    }
    function assertObjectProperty(node, opts) {
      assert("ObjectProperty", node, opts);
    }
    function assertRestElement(node, opts) {
      assert("RestElement", node, opts);
    }
    function assertReturnStatement(node, opts) {
      assert("ReturnStatement", node, opts);
    }
    function assertSequenceExpression(node, opts) {
      assert("SequenceExpression", node, opts);
    }
    function assertParenthesizedExpression(node, opts) {
      assert("ParenthesizedExpression", node, opts);
    }
    function assertSwitchCase(node, opts) {
      assert("SwitchCase", node, opts);
    }
    function assertSwitchStatement(node, opts) {
      assert("SwitchStatement", node, opts);
    }
    function assertThisExpression(node, opts) {
      assert("ThisExpression", node, opts);
    }
    function assertThrowStatement(node, opts) {
      assert("ThrowStatement", node, opts);
    }
    function assertTryStatement(node, opts) {
      assert("TryStatement", node, opts);
    }
    function assertUnaryExpression(node, opts) {
      assert("UnaryExpression", node, opts);
    }
    function assertUpdateExpression(node, opts) {
      assert("UpdateExpression", node, opts);
    }
    function assertVariableDeclaration(node, opts) {
      assert("VariableDeclaration", node, opts);
    }
    function assertVariableDeclarator(node, opts) {
      assert("VariableDeclarator", node, opts);
    }
    function assertWhileStatement(node, opts) {
      assert("WhileStatement", node, opts);
    }
    function assertWithStatement(node, opts) {
      assert("WithStatement", node, opts);
    }
    function assertAssignmentPattern(node, opts) {
      assert("AssignmentPattern", node, opts);
    }
    function assertArrayPattern(node, opts) {
      assert("ArrayPattern", node, opts);
    }
    function assertArrowFunctionExpression(node, opts) {
      assert("ArrowFunctionExpression", node, opts);
    }
    function assertClassBody(node, opts) {
      assert("ClassBody", node, opts);
    }
    function assertClassExpression(node, opts) {
      assert("ClassExpression", node, opts);
    }
    function assertClassDeclaration(node, opts) {
      assert("ClassDeclaration", node, opts);
    }
    function assertExportAllDeclaration(node, opts) {
      assert("ExportAllDeclaration", node, opts);
    }
    function assertExportDefaultDeclaration(node, opts) {
      assert("ExportDefaultDeclaration", node, opts);
    }
    function assertExportNamedDeclaration(node, opts) {
      assert("ExportNamedDeclaration", node, opts);
    }
    function assertExportSpecifier(node, opts) {
      assert("ExportSpecifier", node, opts);
    }
    function assertForOfStatement(node, opts) {
      assert("ForOfStatement", node, opts);
    }
    function assertImportDeclaration(node, opts) {
      assert("ImportDeclaration", node, opts);
    }
    function assertImportDefaultSpecifier(node, opts) {
      assert("ImportDefaultSpecifier", node, opts);
    }
    function assertImportNamespaceSpecifier(node, opts) {
      assert("ImportNamespaceSpecifier", node, opts);
    }
    function assertImportSpecifier(node, opts) {
      assert("ImportSpecifier", node, opts);
    }
    function assertMetaProperty(node, opts) {
      assert("MetaProperty", node, opts);
    }
    function assertClassMethod(node, opts) {
      assert("ClassMethod", node, opts);
    }
    function assertObjectPattern(node, opts) {
      assert("ObjectPattern", node, opts);
    }
    function assertSpreadElement(node, opts) {
      assert("SpreadElement", node, opts);
    }
    function assertSuper(node, opts) {
      assert("Super", node, opts);
    }
    function assertTaggedTemplateExpression(node, opts) {
      assert("TaggedTemplateExpression", node, opts);
    }
    function assertTemplateElement(node, opts) {
      assert("TemplateElement", node, opts);
    }
    function assertTemplateLiteral(node, opts) {
      assert("TemplateLiteral", node, opts);
    }
    function assertYieldExpression(node, opts) {
      assert("YieldExpression", node, opts);
    }
    function assertAwaitExpression(node, opts) {
      assert("AwaitExpression", node, opts);
    }
    function assertImport(node, opts) {
      assert("Import", node, opts);
    }
    function assertBigIntLiteral(node, opts) {
      assert("BigIntLiteral", node, opts);
    }
    function assertExportNamespaceSpecifier(node, opts) {
      assert("ExportNamespaceSpecifier", node, opts);
    }
    function assertOptionalMemberExpression(node, opts) {
      assert("OptionalMemberExpression", node, opts);
    }
    function assertOptionalCallExpression(node, opts) {
      assert("OptionalCallExpression", node, opts);
    }
    function assertClassProperty(node, opts) {
      assert("ClassProperty", node, opts);
    }
    function assertClassAccessorProperty(node, opts) {
      assert("ClassAccessorProperty", node, opts);
    }
    function assertClassPrivateProperty(node, opts) {
      assert("ClassPrivateProperty", node, opts);
    }
    function assertClassPrivateMethod(node, opts) {
      assert("ClassPrivateMethod", node, opts);
    }
    function assertPrivateName(node, opts) {
      assert("PrivateName", node, opts);
    }
    function assertStaticBlock(node, opts) {
      assert("StaticBlock", node, opts);
    }
    function assertAnyTypeAnnotation(node, opts) {
      assert("AnyTypeAnnotation", node, opts);
    }
    function assertArrayTypeAnnotation(node, opts) {
      assert("ArrayTypeAnnotation", node, opts);
    }
    function assertBooleanTypeAnnotation(node, opts) {
      assert("BooleanTypeAnnotation", node, opts);
    }
    function assertBooleanLiteralTypeAnnotation(node, opts) {
      assert("BooleanLiteralTypeAnnotation", node, opts);
    }
    function assertNullLiteralTypeAnnotation(node, opts) {
      assert("NullLiteralTypeAnnotation", node, opts);
    }
    function assertClassImplements(node, opts) {
      assert("ClassImplements", node, opts);
    }
    function assertDeclareClass(node, opts) {
      assert("DeclareClass", node, opts);
    }
    function assertDeclareFunction(node, opts) {
      assert("DeclareFunction", node, opts);
    }
    function assertDeclareInterface(node, opts) {
      assert("DeclareInterface", node, opts);
    }
    function assertDeclareModule(node, opts) {
      assert("DeclareModule", node, opts);
    }
    function assertDeclareModuleExports(node, opts) {
      assert("DeclareModuleExports", node, opts);
    }
    function assertDeclareTypeAlias(node, opts) {
      assert("DeclareTypeAlias", node, opts);
    }
    function assertDeclareOpaqueType(node, opts) {
      assert("DeclareOpaqueType", node, opts);
    }
    function assertDeclareVariable(node, opts) {
      assert("DeclareVariable", node, opts);
    }
    function assertDeclareExportDeclaration(node, opts) {
      assert("DeclareExportDeclaration", node, opts);
    }
    function assertDeclareExportAllDeclaration(node, opts) {
      assert("DeclareExportAllDeclaration", node, opts);
    }
    function assertDeclaredPredicate(node, opts) {
      assert("DeclaredPredicate", node, opts);
    }
    function assertExistsTypeAnnotation(node, opts) {
      assert("ExistsTypeAnnotation", node, opts);
    }
    function assertFunctionTypeAnnotation(node, opts) {
      assert("FunctionTypeAnnotation", node, opts);
    }
    function assertFunctionTypeParam(node, opts) {
      assert("FunctionTypeParam", node, opts);
    }
    function assertGenericTypeAnnotation(node, opts) {
      assert("GenericTypeAnnotation", node, opts);
    }
    function assertInferredPredicate(node, opts) {
      assert("InferredPredicate", node, opts);
    }
    function assertInterfaceExtends(node, opts) {
      assert("InterfaceExtends", node, opts);
    }
    function assertInterfaceDeclaration(node, opts) {
      assert("InterfaceDeclaration", node, opts);
    }
    function assertInterfaceTypeAnnotation(node, opts) {
      assert("InterfaceTypeAnnotation", node, opts);
    }
    function assertIntersectionTypeAnnotation(node, opts) {
      assert("IntersectionTypeAnnotation", node, opts);
    }
    function assertMixedTypeAnnotation(node, opts) {
      assert("MixedTypeAnnotation", node, opts);
    }
    function assertEmptyTypeAnnotation(node, opts) {
      assert("EmptyTypeAnnotation", node, opts);
    }
    function assertNullableTypeAnnotation(node, opts) {
      assert("NullableTypeAnnotation", node, opts);
    }
    function assertNumberLiteralTypeAnnotation(node, opts) {
      assert("NumberLiteralTypeAnnotation", node, opts);
    }
    function assertNumberTypeAnnotation(node, opts) {
      assert("NumberTypeAnnotation", node, opts);
    }
    function assertObjectTypeAnnotation(node, opts) {
      assert("ObjectTypeAnnotation", node, opts);
    }
    function assertObjectTypeInternalSlot(node, opts) {
      assert("ObjectTypeInternalSlot", node, opts);
    }
    function assertObjectTypeCallProperty(node, opts) {
      assert("ObjectTypeCallProperty", node, opts);
    }
    function assertObjectTypeIndexer(node, opts) {
      assert("ObjectTypeIndexer", node, opts);
    }
    function assertObjectTypeProperty(node, opts) {
      assert("ObjectTypeProperty", node, opts);
    }
    function assertObjectTypeSpreadProperty(node, opts) {
      assert("ObjectTypeSpreadProperty", node, opts);
    }
    function assertOpaqueType(node, opts) {
      assert("OpaqueType", node, opts);
    }
    function assertQualifiedTypeIdentifier(node, opts) {
      assert("QualifiedTypeIdentifier", node, opts);
    }
    function assertStringLiteralTypeAnnotation(node, opts) {
      assert("StringLiteralTypeAnnotation", node, opts);
    }
    function assertStringTypeAnnotation(node, opts) {
      assert("StringTypeAnnotation", node, opts);
    }
    function assertSymbolTypeAnnotation(node, opts) {
      assert("SymbolTypeAnnotation", node, opts);
    }
    function assertThisTypeAnnotation(node, opts) {
      assert("ThisTypeAnnotation", node, opts);
    }
    function assertTupleTypeAnnotation(node, opts) {
      assert("TupleTypeAnnotation", node, opts);
    }
    function assertTypeofTypeAnnotation(node, opts) {
      assert("TypeofTypeAnnotation", node, opts);
    }
    function assertTypeAlias(node, opts) {
      assert("TypeAlias", node, opts);
    }
    function assertTypeAnnotation(node, opts) {
      assert("TypeAnnotation", node, opts);
    }
    function assertTypeCastExpression(node, opts) {
      assert("TypeCastExpression", node, opts);
    }
    function assertTypeParameter(node, opts) {
      assert("TypeParameter", node, opts);
    }
    function assertTypeParameterDeclaration(node, opts) {
      assert("TypeParameterDeclaration", node, opts);
    }
    function assertTypeParameterInstantiation(node, opts) {
      assert("TypeParameterInstantiation", node, opts);
    }
    function assertUnionTypeAnnotation(node, opts) {
      assert("UnionTypeAnnotation", node, opts);
    }
    function assertVariance(node, opts) {
      assert("Variance", node, opts);
    }
    function assertVoidTypeAnnotation(node, opts) {
      assert("VoidTypeAnnotation", node, opts);
    }
    function assertEnumDeclaration(node, opts) {
      assert("EnumDeclaration", node, opts);
    }
    function assertEnumBooleanBody(node, opts) {
      assert("EnumBooleanBody", node, opts);
    }
    function assertEnumNumberBody(node, opts) {
      assert("EnumNumberBody", node, opts);
    }
    function assertEnumStringBody(node, opts) {
      assert("EnumStringBody", node, opts);
    }
    function assertEnumSymbolBody(node, opts) {
      assert("EnumSymbolBody", node, opts);
    }
    function assertEnumBooleanMember(node, opts) {
      assert("EnumBooleanMember", node, opts);
    }
    function assertEnumNumberMember(node, opts) {
      assert("EnumNumberMember", node, opts);
    }
    function assertEnumStringMember(node, opts) {
      assert("EnumStringMember", node, opts);
    }
    function assertEnumDefaultedMember(node, opts) {
      assert("EnumDefaultedMember", node, opts);
    }
    function assertIndexedAccessType(node, opts) {
      assert("IndexedAccessType", node, opts);
    }
    function assertOptionalIndexedAccessType(node, opts) {
      assert("OptionalIndexedAccessType", node, opts);
    }
    function assertJSXAttribute(node, opts) {
      assert("JSXAttribute", node, opts);
    }
    function assertJSXClosingElement(node, opts) {
      assert("JSXClosingElement", node, opts);
    }
    function assertJSXElement(node, opts) {
      assert("JSXElement", node, opts);
    }
    function assertJSXEmptyExpression(node, opts) {
      assert("JSXEmptyExpression", node, opts);
    }
    function assertJSXExpressionContainer(node, opts) {
      assert("JSXExpressionContainer", node, opts);
    }
    function assertJSXSpreadChild(node, opts) {
      assert("JSXSpreadChild", node, opts);
    }
    function assertJSXIdentifier(node, opts) {
      assert("JSXIdentifier", node, opts);
    }
    function assertJSXMemberExpression(node, opts) {
      assert("JSXMemberExpression", node, opts);
    }
    function assertJSXNamespacedName(node, opts) {
      assert("JSXNamespacedName", node, opts);
    }
    function assertJSXOpeningElement(node, opts) {
      assert("JSXOpeningElement", node, opts);
    }
    function assertJSXSpreadAttribute(node, opts) {
      assert("JSXSpreadAttribute", node, opts);
    }
    function assertJSXText(node, opts) {
      assert("JSXText", node, opts);
    }
    function assertJSXFragment(node, opts) {
      assert("JSXFragment", node, opts);
    }
    function assertJSXOpeningFragment(node, opts) {
      assert("JSXOpeningFragment", node, opts);
    }
    function assertJSXClosingFragment(node, opts) {
      assert("JSXClosingFragment", node, opts);
    }
    function assertNoop(node, opts) {
      assert("Noop", node, opts);
    }
    function assertPlaceholder(node, opts) {
      assert("Placeholder", node, opts);
    }
    function assertV8IntrinsicIdentifier(node, opts) {
      assert("V8IntrinsicIdentifier", node, opts);
    }
    function assertArgumentPlaceholder(node, opts) {
      assert("ArgumentPlaceholder", node, opts);
    }
    function assertBindExpression(node, opts) {
      assert("BindExpression", node, opts);
    }
    function assertImportAttribute(node, opts) {
      assert("ImportAttribute", node, opts);
    }
    function assertDecorator(node, opts) {
      assert("Decorator", node, opts);
    }
    function assertDoExpression(node, opts) {
      assert("DoExpression", node, opts);
    }
    function assertExportDefaultSpecifier(node, opts) {
      assert("ExportDefaultSpecifier", node, opts);
    }
    function assertRecordExpression(node, opts) {
      assert("RecordExpression", node, opts);
    }
    function assertTupleExpression(node, opts) {
      assert("TupleExpression", node, opts);
    }
    function assertDecimalLiteral(node, opts) {
      assert("DecimalLiteral", node, opts);
    }
    function assertModuleExpression(node, opts) {
      assert("ModuleExpression", node, opts);
    }
    function assertTopicReference(node, opts) {
      assert("TopicReference", node, opts);
    }
    function assertPipelineTopicExpression(node, opts) {
      assert("PipelineTopicExpression", node, opts);
    }
    function assertPipelineBareFunction(node, opts) {
      assert("PipelineBareFunction", node, opts);
    }
    function assertPipelinePrimaryTopicReference(node, opts) {
      assert("PipelinePrimaryTopicReference", node, opts);
    }
    function assertTSParameterProperty(node, opts) {
      assert("TSParameterProperty", node, opts);
    }
    function assertTSDeclareFunction(node, opts) {
      assert("TSDeclareFunction", node, opts);
    }
    function assertTSDeclareMethod(node, opts) {
      assert("TSDeclareMethod", node, opts);
    }
    function assertTSQualifiedName(node, opts) {
      assert("TSQualifiedName", node, opts);
    }
    function assertTSCallSignatureDeclaration(node, opts) {
      assert("TSCallSignatureDeclaration", node, opts);
    }
    function assertTSConstructSignatureDeclaration(node, opts) {
      assert("TSConstructSignatureDeclaration", node, opts);
    }
    function assertTSPropertySignature(node, opts) {
      assert("TSPropertySignature", node, opts);
    }
    function assertTSMethodSignature(node, opts) {
      assert("TSMethodSignature", node, opts);
    }
    function assertTSIndexSignature(node, opts) {
      assert("TSIndexSignature", node, opts);
    }
    function assertTSAnyKeyword(node, opts) {
      assert("TSAnyKeyword", node, opts);
    }
    function assertTSBooleanKeyword(node, opts) {
      assert("TSBooleanKeyword", node, opts);
    }
    function assertTSBigIntKeyword(node, opts) {
      assert("TSBigIntKeyword", node, opts);
    }
    function assertTSIntrinsicKeyword(node, opts) {
      assert("TSIntrinsicKeyword", node, opts);
    }
    function assertTSNeverKeyword(node, opts) {
      assert("TSNeverKeyword", node, opts);
    }
    function assertTSNullKeyword(node, opts) {
      assert("TSNullKeyword", node, opts);
    }
    function assertTSNumberKeyword(node, opts) {
      assert("TSNumberKeyword", node, opts);
    }
    function assertTSObjectKeyword(node, opts) {
      assert("TSObjectKeyword", node, opts);
    }
    function assertTSStringKeyword(node, opts) {
      assert("TSStringKeyword", node, opts);
    }
    function assertTSSymbolKeyword(node, opts) {
      assert("TSSymbolKeyword", node, opts);
    }
    function assertTSUndefinedKeyword(node, opts) {
      assert("TSUndefinedKeyword", node, opts);
    }
    function assertTSUnknownKeyword(node, opts) {
      assert("TSUnknownKeyword", node, opts);
    }
    function assertTSVoidKeyword(node, opts) {
      assert("TSVoidKeyword", node, opts);
    }
    function assertTSThisType(node, opts) {
      assert("TSThisType", node, opts);
    }
    function assertTSFunctionType(node, opts) {
      assert("TSFunctionType", node, opts);
    }
    function assertTSConstructorType(node, opts) {
      assert("TSConstructorType", node, opts);
    }
    function assertTSTypeReference(node, opts) {
      assert("TSTypeReference", node, opts);
    }
    function assertTSTypePredicate(node, opts) {
      assert("TSTypePredicate", node, opts);
    }
    function assertTSTypeQuery(node, opts) {
      assert("TSTypeQuery", node, opts);
    }
    function assertTSTypeLiteral(node, opts) {
      assert("TSTypeLiteral", node, opts);
    }
    function assertTSArrayType(node, opts) {
      assert("TSArrayType", node, opts);
    }
    function assertTSTupleType(node, opts) {
      assert("TSTupleType", node, opts);
    }
    function assertTSOptionalType(node, opts) {
      assert("TSOptionalType", node, opts);
    }
    function assertTSRestType(node, opts) {
      assert("TSRestType", node, opts);
    }
    function assertTSNamedTupleMember(node, opts) {
      assert("TSNamedTupleMember", node, opts);
    }
    function assertTSUnionType(node, opts) {
      assert("TSUnionType", node, opts);
    }
    function assertTSIntersectionType(node, opts) {
      assert("TSIntersectionType", node, opts);
    }
    function assertTSConditionalType(node, opts) {
      assert("TSConditionalType", node, opts);
    }
    function assertTSInferType(node, opts) {
      assert("TSInferType", node, opts);
    }
    function assertTSParenthesizedType(node, opts) {
      assert("TSParenthesizedType", node, opts);
    }
    function assertTSTypeOperator(node, opts) {
      assert("TSTypeOperator", node, opts);
    }
    function assertTSIndexedAccessType(node, opts) {
      assert("TSIndexedAccessType", node, opts);
    }
    function assertTSMappedType(node, opts) {
      assert("TSMappedType", node, opts);
    }
    function assertTSLiteralType(node, opts) {
      assert("TSLiteralType", node, opts);
    }
    function assertTSExpressionWithTypeArguments(node, opts) {
      assert("TSExpressionWithTypeArguments", node, opts);
    }
    function assertTSInterfaceDeclaration(node, opts) {
      assert("TSInterfaceDeclaration", node, opts);
    }
    function assertTSInterfaceBody(node, opts) {
      assert("TSInterfaceBody", node, opts);
    }
    function assertTSTypeAliasDeclaration(node, opts) {
      assert("TSTypeAliasDeclaration", node, opts);
    }
    function assertTSInstantiationExpression(node, opts) {
      assert("TSInstantiationExpression", node, opts);
    }
    function assertTSAsExpression(node, opts) {
      assert("TSAsExpression", node, opts);
    }
    function assertTSSatisfiesExpression(node, opts) {
      assert("TSSatisfiesExpression", node, opts);
    }
    function assertTSTypeAssertion(node, opts) {
      assert("TSTypeAssertion", node, opts);
    }
    function assertTSEnumDeclaration(node, opts) {
      assert("TSEnumDeclaration", node, opts);
    }
    function assertTSEnumMember(node, opts) {
      assert("TSEnumMember", node, opts);
    }
    function assertTSModuleDeclaration(node, opts) {
      assert("TSModuleDeclaration", node, opts);
    }
    function assertTSModuleBlock(node, opts) {
      assert("TSModuleBlock", node, opts);
    }
    function assertTSImportType(node, opts) {
      assert("TSImportType", node, opts);
    }
    function assertTSImportEqualsDeclaration(node, opts) {
      assert("TSImportEqualsDeclaration", node, opts);
    }
    function assertTSExternalModuleReference(node, opts) {
      assert("TSExternalModuleReference", node, opts);
    }
    function assertTSNonNullExpression(node, opts) {
      assert("TSNonNullExpression", node, opts);
    }
    function assertTSExportAssignment(node, opts) {
      assert("TSExportAssignment", node, opts);
    }
    function assertTSNamespaceExportDeclaration(node, opts) {
      assert("TSNamespaceExportDeclaration", node, opts);
    }
    function assertTSTypeAnnotation(node, opts) {
      assert("TSTypeAnnotation", node, opts);
    }
    function assertTSTypeParameterInstantiation(node, opts) {
      assert("TSTypeParameterInstantiation", node, opts);
    }
    function assertTSTypeParameterDeclaration(node, opts) {
      assert("TSTypeParameterDeclaration", node, opts);
    }
    function assertTSTypeParameter(node, opts) {
      assert("TSTypeParameter", node, opts);
    }
    function assertStandardized(node, opts) {
      assert("Standardized", node, opts);
    }
    function assertExpression(node, opts) {
      assert("Expression", node, opts);
    }
    function assertBinary(node, opts) {
      assert("Binary", node, opts);
    }
    function assertScopable(node, opts) {
      assert("Scopable", node, opts);
    }
    function assertBlockParent(node, opts) {
      assert("BlockParent", node, opts);
    }
    function assertBlock(node, opts) {
      assert("Block", node, opts);
    }
    function assertStatement(node, opts) {
      assert("Statement", node, opts);
    }
    function assertTerminatorless(node, opts) {
      assert("Terminatorless", node, opts);
    }
    function assertCompletionStatement(node, opts) {
      assert("CompletionStatement", node, opts);
    }
    function assertConditional(node, opts) {
      assert("Conditional", node, opts);
    }
    function assertLoop(node, opts) {
      assert("Loop", node, opts);
    }
    function assertWhile(node, opts) {
      assert("While", node, opts);
    }
    function assertExpressionWrapper(node, opts) {
      assert("ExpressionWrapper", node, opts);
    }
    function assertFor(node, opts) {
      assert("For", node, opts);
    }
    function assertForXStatement(node, opts) {
      assert("ForXStatement", node, opts);
    }
    function assertFunction(node, opts) {
      assert("Function", node, opts);
    }
    function assertFunctionParent(node, opts) {
      assert("FunctionParent", node, opts);
    }
    function assertPureish(node, opts) {
      assert("Pureish", node, opts);
    }
    function assertDeclaration(node, opts) {
      assert("Declaration", node, opts);
    }
    function assertPatternLike(node, opts) {
      assert("PatternLike", node, opts);
    }
    function assertLVal(node, opts) {
      assert("LVal", node, opts);
    }
    function assertTSEntityName(node, opts) {
      assert("TSEntityName", node, opts);
    }
    function assertLiteral(node, opts) {
      assert("Literal", node, opts);
    }
    function assertImmutable(node, opts) {
      assert("Immutable", node, opts);
    }
    function assertUserWhitespacable(node, opts) {
      assert("UserWhitespacable", node, opts);
    }
    function assertMethod(node, opts) {
      assert("Method", node, opts);
    }
    function assertObjectMember(node, opts) {
      assert("ObjectMember", node, opts);
    }
    function assertProperty(node, opts) {
      assert("Property", node, opts);
    }
    function assertUnaryLike(node, opts) {
      assert("UnaryLike", node, opts);
    }
    function assertPattern(node, opts) {
      assert("Pattern", node, opts);
    }
    function assertClass(node, opts) {
      assert("Class", node, opts);
    }
    function assertModuleDeclaration(node, opts) {
      assert("ModuleDeclaration", node, opts);
    }
    function assertExportDeclaration(node, opts) {
      assert("ExportDeclaration", node, opts);
    }
    function assertModuleSpecifier(node, opts) {
      assert("ModuleSpecifier", node, opts);
    }
    function assertAccessor(node, opts) {
      assert("Accessor", node, opts);
    }
    function assertPrivate(node, opts) {
      assert("Private", node, opts);
    }
    function assertFlow(node, opts) {
      assert("Flow", node, opts);
    }
    function assertFlowType(node, opts) {
      assert("FlowType", node, opts);
    }
    function assertFlowBaseAnnotation(node, opts) {
      assert("FlowBaseAnnotation", node, opts);
    }
    function assertFlowDeclaration(node, opts) {
      assert("FlowDeclaration", node, opts);
    }
    function assertFlowPredicate(node, opts) {
      assert("FlowPredicate", node, opts);
    }
    function assertEnumBody(node, opts) {
      assert("EnumBody", node, opts);
    }
    function assertEnumMember(node, opts) {
      assert("EnumMember", node, opts);
    }
    function assertJSX(node, opts) {
      assert("JSX", node, opts);
    }
    function assertMiscellaneous(node, opts) {
      assert("Miscellaneous", node, opts);
    }
    function assertTypeScript(node, opts) {
      assert("TypeScript", node, opts);
    }
    function assertTSTypeElement(node, opts) {
      assert("TSTypeElement", node, opts);
    }
    function assertTSType(node, opts) {
      assert("TSType", node, opts);
    }
    function assertTSBaseType(node, opts) {
      assert("TSBaseType", node, opts);
    }
    function assertNumberLiteral(node, opts) {
      console.trace("The node type NumberLiteral has been renamed to NumericLiteral");
      assert("NumberLiteral", node, opts);
    }
    function assertRegexLiteral(node, opts) {
      console.trace("The node type RegexLiteral has been renamed to RegExpLiteral");
      assert("RegexLiteral", node, opts);
    }
    function assertRestProperty(node, opts) {
      console.trace("The node type RestProperty has been renamed to RestElement");
      assert("RestProperty", node, opts);
    }
    function assertSpreadProperty(node, opts) {
      console.trace("The node type SpreadProperty has been renamed to SpreadElement");
      assert("SpreadProperty", node, opts);
    }
  }
});

// node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js
var require_createTypeAnnotationBasedOnTypeof = __commonJS({
  "node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _generated = require_generated2();
    var _default = createTypeAnnotationBasedOnTypeof;
    exports.default = _default;
    function createTypeAnnotationBasedOnTypeof(type) {
      switch (type) {
        case "string":
          return (0, _generated.stringTypeAnnotation)();
        case "number":
          return (0, _generated.numberTypeAnnotation)();
        case "undefined":
          return (0, _generated.voidTypeAnnotation)();
        case "boolean":
          return (0, _generated.booleanTypeAnnotation)();
        case "function":
          return (0, _generated.genericTypeAnnotation)((0, _generated.identifier)("Function"));
        case "object":
          return (0, _generated.genericTypeAnnotation)((0, _generated.identifier)("Object"));
        case "symbol":
          return (0, _generated.genericTypeAnnotation)((0, _generated.identifier)("Symbol"));
        case "bigint":
          return (0, _generated.anyTypeAnnotation)();
      }
      throw new Error("Invalid typeof value: " + type);
    }
  }
});

// node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js
var require_removeTypeDuplicates = __commonJS({
  "node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeTypeDuplicates;
    var _generated = require_generated();
    function getQualifiedName(node) {
      return (0, _generated.isIdentifier)(node) ? node.name : `${node.id.name}.${getQualifiedName(node.qualification)}`;
    }
    function removeTypeDuplicates(nodes) {
      const generics = /* @__PURE__ */ new Map();
      const bases = /* @__PURE__ */ new Map();
      const typeGroups = /* @__PURE__ */ new Set();
      const types = [];
      for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        if (!node)
          continue;
        if (types.indexOf(node) >= 0) {
          continue;
        }
        if ((0, _generated.isAnyTypeAnnotation)(node)) {
          return [node];
        }
        if ((0, _generated.isFlowBaseAnnotation)(node)) {
          bases.set(node.type, node);
          continue;
        }
        if ((0, _generated.isUnionTypeAnnotation)(node)) {
          if (!typeGroups.has(node.types)) {
            nodes = nodes.concat(node.types);
            typeGroups.add(node.types);
          }
          continue;
        }
        if ((0, _generated.isGenericTypeAnnotation)(node)) {
          const name = getQualifiedName(node.id);
          if (generics.has(name)) {
            let existing = generics.get(name);
            if (existing.typeParameters) {
              if (node.typeParameters) {
                existing.typeParameters.params = removeTypeDuplicates(existing.typeParameters.params.concat(node.typeParameters.params));
              }
            } else {
              existing = node.typeParameters;
            }
          } else {
            generics.set(name, node);
          }
          continue;
        }
        types.push(node);
      }
      for (const [, baseType] of bases) {
        types.push(baseType);
      }
      for (const [, genericName] of generics) {
        types.push(genericName);
      }
      return types;
    }
  }
});

// node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js
var require_createFlowUnionType = __commonJS({
  "node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = createFlowUnionType;
    var _generated = require_generated2();
    var _removeTypeDuplicates = require_removeTypeDuplicates();
    function createFlowUnionType(types) {
      const flattened = (0, _removeTypeDuplicates.default)(types);
      if (flattened.length === 1) {
        return flattened[0];
      } else {
        return (0, _generated.unionTypeAnnotation)(flattened);
      }
    }
  }
});

// node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js
var require_removeTypeDuplicates2 = __commonJS({
  "node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeTypeDuplicates;
    var _generated = require_generated();
    function getQualifiedName(node) {
      return (0, _generated.isIdentifier)(node) ? node.name : `${node.right.name}.${getQualifiedName(node.left)}`;
    }
    function removeTypeDuplicates(nodes) {
      const generics = /* @__PURE__ */ new Map();
      const bases = /* @__PURE__ */ new Map();
      const typeGroups = /* @__PURE__ */ new Set();
      const types = [];
      for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        if (!node)
          continue;
        if (types.indexOf(node) >= 0) {
          continue;
        }
        if ((0, _generated.isTSAnyKeyword)(node)) {
          return [node];
        }
        if ((0, _generated.isTSBaseType)(node)) {
          bases.set(node.type, node);
          continue;
        }
        if ((0, _generated.isTSUnionType)(node)) {
          if (!typeGroups.has(node.types)) {
            nodes.push(...node.types);
            typeGroups.add(node.types);
          }
          continue;
        }
        if ((0, _generated.isTSTypeReference)(node) && node.typeParameters) {
          const name = getQualifiedName(node.typeName);
          if (generics.has(name)) {
            let existing = generics.get(name);
            if (existing.typeParameters) {
              if (node.typeParameters) {
                existing.typeParameters.params = removeTypeDuplicates(existing.typeParameters.params.concat(node.typeParameters.params));
              }
            } else {
              existing = node.typeParameters;
            }
          } else {
            generics.set(name, node);
          }
          continue;
        }
        types.push(node);
      }
      for (const [, baseType] of bases) {
        types.push(baseType);
      }
      for (const [, genericName] of generics) {
        types.push(genericName);
      }
      return types;
    }
  }
});

// node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js
var require_createTSUnionType = __commonJS({
  "node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = createTSUnionType;
    var _generated = require_generated2();
    var _removeTypeDuplicates = require_removeTypeDuplicates2();
    var _index = require_generated();
    function createTSUnionType(typeAnnotations) {
      const types = typeAnnotations.map((type) => {
        return (0, _index.isTSTypeAnnotation)(type) ? type.typeAnnotation : type;
      });
      const flattened = (0, _removeTypeDuplicates.default)(types);
      if (flattened.length === 1) {
        return flattened[0];
      } else {
        return (0, _generated.tsUnionType)(flattened);
      }
    }
  }
});

// node_modules/@babel/types/lib/builders/generated/uppercase.js
var require_uppercase = __commonJS({
  "node_modules/@babel/types/lib/builders/generated/uppercase.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "AnyTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.anyTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ArgumentPlaceholder", {
      enumerable: true,
      get: function() {
        return _index.argumentPlaceholder;
      }
    });
    Object.defineProperty(exports, "ArrayExpression", {
      enumerable: true,
      get: function() {
        return _index.arrayExpression;
      }
    });
    Object.defineProperty(exports, "ArrayPattern", {
      enumerable: true,
      get: function() {
        return _index.arrayPattern;
      }
    });
    Object.defineProperty(exports, "ArrayTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.arrayTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ArrowFunctionExpression", {
      enumerable: true,
      get: function() {
        return _index.arrowFunctionExpression;
      }
    });
    Object.defineProperty(exports, "AssignmentExpression", {
      enumerable: true,
      get: function() {
        return _index.assignmentExpression;
      }
    });
    Object.defineProperty(exports, "AssignmentPattern", {
      enumerable: true,
      get: function() {
        return _index.assignmentPattern;
      }
    });
    Object.defineProperty(exports, "AwaitExpression", {
      enumerable: true,
      get: function() {
        return _index.awaitExpression;
      }
    });
    Object.defineProperty(exports, "BigIntLiteral", {
      enumerable: true,
      get: function() {
        return _index.bigIntLiteral;
      }
    });
    Object.defineProperty(exports, "BinaryExpression", {
      enumerable: true,
      get: function() {
        return _index.binaryExpression;
      }
    });
    Object.defineProperty(exports, "BindExpression", {
      enumerable: true,
      get: function() {
        return _index.bindExpression;
      }
    });
    Object.defineProperty(exports, "BlockStatement", {
      enumerable: true,
      get: function() {
        return _index.blockStatement;
      }
    });
    Object.defineProperty(exports, "BooleanLiteral", {
      enumerable: true,
      get: function() {
        return _index.booleanLiteral;
      }
    });
    Object.defineProperty(exports, "BooleanLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.booleanLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "BooleanTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.booleanTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "BreakStatement", {
      enumerable: true,
      get: function() {
        return _index.breakStatement;
      }
    });
    Object.defineProperty(exports, "CallExpression", {
      enumerable: true,
      get: function() {
        return _index.callExpression;
      }
    });
    Object.defineProperty(exports, "CatchClause", {
      enumerable: true,
      get: function() {
        return _index.catchClause;
      }
    });
    Object.defineProperty(exports, "ClassAccessorProperty", {
      enumerable: true,
      get: function() {
        return _index.classAccessorProperty;
      }
    });
    Object.defineProperty(exports, "ClassBody", {
      enumerable: true,
      get: function() {
        return _index.classBody;
      }
    });
    Object.defineProperty(exports, "ClassDeclaration", {
      enumerable: true,
      get: function() {
        return _index.classDeclaration;
      }
    });
    Object.defineProperty(exports, "ClassExpression", {
      enumerable: true,
      get: function() {
        return _index.classExpression;
      }
    });
    Object.defineProperty(exports, "ClassImplements", {
      enumerable: true,
      get: function() {
        return _index.classImplements;
      }
    });
    Object.defineProperty(exports, "ClassMethod", {
      enumerable: true,
      get: function() {
        return _index.classMethod;
      }
    });
    Object.defineProperty(exports, "ClassPrivateMethod", {
      enumerable: true,
      get: function() {
        return _index.classPrivateMethod;
      }
    });
    Object.defineProperty(exports, "ClassPrivateProperty", {
      enumerable: true,
      get: function() {
        return _index.classPrivateProperty;
      }
    });
    Object.defineProperty(exports, "ClassProperty", {
      enumerable: true,
      get: function() {
        return _index.classProperty;
      }
    });
    Object.defineProperty(exports, "ConditionalExpression", {
      enumerable: true,
      get: function() {
        return _index.conditionalExpression;
      }
    });
    Object.defineProperty(exports, "ContinueStatement", {
      enumerable: true,
      get: function() {
        return _index.continueStatement;
      }
    });
    Object.defineProperty(exports, "DebuggerStatement", {
      enumerable: true,
      get: function() {
        return _index.debuggerStatement;
      }
    });
    Object.defineProperty(exports, "DecimalLiteral", {
      enumerable: true,
      get: function() {
        return _index.decimalLiteral;
      }
    });
    Object.defineProperty(exports, "DeclareClass", {
      enumerable: true,
      get: function() {
        return _index.declareClass;
      }
    });
    Object.defineProperty(exports, "DeclareExportAllDeclaration", {
      enumerable: true,
      get: function() {
        return _index.declareExportAllDeclaration;
      }
    });
    Object.defineProperty(exports, "DeclareExportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.declareExportDeclaration;
      }
    });
    Object.defineProperty(exports, "DeclareFunction", {
      enumerable: true,
      get: function() {
        return _index.declareFunction;
      }
    });
    Object.defineProperty(exports, "DeclareInterface", {
      enumerable: true,
      get: function() {
        return _index.declareInterface;
      }
    });
    Object.defineProperty(exports, "DeclareModule", {
      enumerable: true,
      get: function() {
        return _index.declareModule;
      }
    });
    Object.defineProperty(exports, "DeclareModuleExports", {
      enumerable: true,
      get: function() {
        return _index.declareModuleExports;
      }
    });
    Object.defineProperty(exports, "DeclareOpaqueType", {
      enumerable: true,
      get: function() {
        return _index.declareOpaqueType;
      }
    });
    Object.defineProperty(exports, "DeclareTypeAlias", {
      enumerable: true,
      get: function() {
        return _index.declareTypeAlias;
      }
    });
    Object.defineProperty(exports, "DeclareVariable", {
      enumerable: true,
      get: function() {
        return _index.declareVariable;
      }
    });
    Object.defineProperty(exports, "DeclaredPredicate", {
      enumerable: true,
      get: function() {
        return _index.declaredPredicate;
      }
    });
    Object.defineProperty(exports, "Decorator", {
      enumerable: true,
      get: function() {
        return _index.decorator;
      }
    });
    Object.defineProperty(exports, "Directive", {
      enumerable: true,
      get: function() {
        return _index.directive;
      }
    });
    Object.defineProperty(exports, "DirectiveLiteral", {
      enumerable: true,
      get: function() {
        return _index.directiveLiteral;
      }
    });
    Object.defineProperty(exports, "DoExpression", {
      enumerable: true,
      get: function() {
        return _index.doExpression;
      }
    });
    Object.defineProperty(exports, "DoWhileStatement", {
      enumerable: true,
      get: function() {
        return _index.doWhileStatement;
      }
    });
    Object.defineProperty(exports, "EmptyStatement", {
      enumerable: true,
      get: function() {
        return _index.emptyStatement;
      }
    });
    Object.defineProperty(exports, "EmptyTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.emptyTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "EnumBooleanBody", {
      enumerable: true,
      get: function() {
        return _index.enumBooleanBody;
      }
    });
    Object.defineProperty(exports, "EnumBooleanMember", {
      enumerable: true,
      get: function() {
        return _index.enumBooleanMember;
      }
    });
    Object.defineProperty(exports, "EnumDeclaration", {
      enumerable: true,
      get: function() {
        return _index.enumDeclaration;
      }
    });
    Object.defineProperty(exports, "EnumDefaultedMember", {
      enumerable: true,
      get: function() {
        return _index.enumDefaultedMember;
      }
    });
    Object.defineProperty(exports, "EnumNumberBody", {
      enumerable: true,
      get: function() {
        return _index.enumNumberBody;
      }
    });
    Object.defineProperty(exports, "EnumNumberMember", {
      enumerable: true,
      get: function() {
        return _index.enumNumberMember;
      }
    });
    Object.defineProperty(exports, "EnumStringBody", {
      enumerable: true,
      get: function() {
        return _index.enumStringBody;
      }
    });
    Object.defineProperty(exports, "EnumStringMember", {
      enumerable: true,
      get: function() {
        return _index.enumStringMember;
      }
    });
    Object.defineProperty(exports, "EnumSymbolBody", {
      enumerable: true,
      get: function() {
        return _index.enumSymbolBody;
      }
    });
    Object.defineProperty(exports, "ExistsTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.existsTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ExportAllDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportAllDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportDefaultDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportDefaultDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportDefaultSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportDefaultSpecifier;
      }
    });
    Object.defineProperty(exports, "ExportNamedDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportNamedDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportNamespaceSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportNamespaceSpecifier;
      }
    });
    Object.defineProperty(exports, "ExportSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportSpecifier;
      }
    });
    Object.defineProperty(exports, "ExpressionStatement", {
      enumerable: true,
      get: function() {
        return _index.expressionStatement;
      }
    });
    Object.defineProperty(exports, "File", {
      enumerable: true,
      get: function() {
        return _index.file;
      }
    });
    Object.defineProperty(exports, "ForInStatement", {
      enumerable: true,
      get: function() {
        return _index.forInStatement;
      }
    });
    Object.defineProperty(exports, "ForOfStatement", {
      enumerable: true,
      get: function() {
        return _index.forOfStatement;
      }
    });
    Object.defineProperty(exports, "ForStatement", {
      enumerable: true,
      get: function() {
        return _index.forStatement;
      }
    });
    Object.defineProperty(exports, "FunctionDeclaration", {
      enumerable: true,
      get: function() {
        return _index.functionDeclaration;
      }
    });
    Object.defineProperty(exports, "FunctionExpression", {
      enumerable: true,
      get: function() {
        return _index.functionExpression;
      }
    });
    Object.defineProperty(exports, "FunctionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.functionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "FunctionTypeParam", {
      enumerable: true,
      get: function() {
        return _index.functionTypeParam;
      }
    });
    Object.defineProperty(exports, "GenericTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.genericTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "Identifier", {
      enumerable: true,
      get: function() {
        return _index.identifier;
      }
    });
    Object.defineProperty(exports, "IfStatement", {
      enumerable: true,
      get: function() {
        return _index.ifStatement;
      }
    });
    Object.defineProperty(exports, "Import", {
      enumerable: true,
      get: function() {
        return _index.import;
      }
    });
    Object.defineProperty(exports, "ImportAttribute", {
      enumerable: true,
      get: function() {
        return _index.importAttribute;
      }
    });
    Object.defineProperty(exports, "ImportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.importDeclaration;
      }
    });
    Object.defineProperty(exports, "ImportDefaultSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importDefaultSpecifier;
      }
    });
    Object.defineProperty(exports, "ImportNamespaceSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importNamespaceSpecifier;
      }
    });
    Object.defineProperty(exports, "ImportSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importSpecifier;
      }
    });
    Object.defineProperty(exports, "IndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.indexedAccessType;
      }
    });
    Object.defineProperty(exports, "InferredPredicate", {
      enumerable: true,
      get: function() {
        return _index.inferredPredicate;
      }
    });
    Object.defineProperty(exports, "InterfaceDeclaration", {
      enumerable: true,
      get: function() {
        return _index.interfaceDeclaration;
      }
    });
    Object.defineProperty(exports, "InterfaceExtends", {
      enumerable: true,
      get: function() {
        return _index.interfaceExtends;
      }
    });
    Object.defineProperty(exports, "InterfaceTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.interfaceTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "InterpreterDirective", {
      enumerable: true,
      get: function() {
        return _index.interpreterDirective;
      }
    });
    Object.defineProperty(exports, "IntersectionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.intersectionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "JSXAttribute", {
      enumerable: true,
      get: function() {
        return _index.jsxAttribute;
      }
    });
    Object.defineProperty(exports, "JSXClosingElement", {
      enumerable: true,
      get: function() {
        return _index.jsxClosingElement;
      }
    });
    Object.defineProperty(exports, "JSXClosingFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxClosingFragment;
      }
    });
    Object.defineProperty(exports, "JSXElement", {
      enumerable: true,
      get: function() {
        return _index.jsxElement;
      }
    });
    Object.defineProperty(exports, "JSXEmptyExpression", {
      enumerable: true,
      get: function() {
        return _index.jsxEmptyExpression;
      }
    });
    Object.defineProperty(exports, "JSXExpressionContainer", {
      enumerable: true,
      get: function() {
        return _index.jsxExpressionContainer;
      }
    });
    Object.defineProperty(exports, "JSXFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxFragment;
      }
    });
    Object.defineProperty(exports, "JSXIdentifier", {
      enumerable: true,
      get: function() {
        return _index.jsxIdentifier;
      }
    });
    Object.defineProperty(exports, "JSXMemberExpression", {
      enumerable: true,
      get: function() {
        return _index.jsxMemberExpression;
      }
    });
    Object.defineProperty(exports, "JSXNamespacedName", {
      enumerable: true,
      get: function() {
        return _index.jsxNamespacedName;
      }
    });
    Object.defineProperty(exports, "JSXOpeningElement", {
      enumerable: true,
      get: function() {
        return _index.jsxOpeningElement;
      }
    });
    Object.defineProperty(exports, "JSXOpeningFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxOpeningFragment;
      }
    });
    Object.defineProperty(exports, "JSXSpreadAttribute", {
      enumerable: true,
      get: function() {
        return _index.jsxSpreadAttribute;
      }
    });
    Object.defineProperty(exports, "JSXSpreadChild", {
      enumerable: true,
      get: function() {
        return _index.jsxSpreadChild;
      }
    });
    Object.defineProperty(exports, "JSXText", {
      enumerable: true,
      get: function() {
        return _index.jsxText;
      }
    });
    Object.defineProperty(exports, "LabeledStatement", {
      enumerable: true,
      get: function() {
        return _index.labeledStatement;
      }
    });
    Object.defineProperty(exports, "LogicalExpression", {
      enumerable: true,
      get: function() {
        return _index.logicalExpression;
      }
    });
    Object.defineProperty(exports, "MemberExpression", {
      enumerable: true,
      get: function() {
        return _index.memberExpression;
      }
    });
    Object.defineProperty(exports, "MetaProperty", {
      enumerable: true,
      get: function() {
        return _index.metaProperty;
      }
    });
    Object.defineProperty(exports, "MixedTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.mixedTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ModuleExpression", {
      enumerable: true,
      get: function() {
        return _index.moduleExpression;
      }
    });
    Object.defineProperty(exports, "NewExpression", {
      enumerable: true,
      get: function() {
        return _index.newExpression;
      }
    });
    Object.defineProperty(exports, "Noop", {
      enumerable: true,
      get: function() {
        return _index.noop;
      }
    });
    Object.defineProperty(exports, "NullLiteral", {
      enumerable: true,
      get: function() {
        return _index.nullLiteral;
      }
    });
    Object.defineProperty(exports, "NullLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.nullLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NullableTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.nullableTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumberLiteral", {
      enumerable: true,
      get: function() {
        return _index.numberLiteral;
      }
    });
    Object.defineProperty(exports, "NumberLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.numberLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumberTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.numberTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumericLiteral", {
      enumerable: true,
      get: function() {
        return _index.numericLiteral;
      }
    });
    Object.defineProperty(exports, "ObjectExpression", {
      enumerable: true,
      get: function() {
        return _index.objectExpression;
      }
    });
    Object.defineProperty(exports, "ObjectMethod", {
      enumerable: true,
      get: function() {
        return _index.objectMethod;
      }
    });
    Object.defineProperty(exports, "ObjectPattern", {
      enumerable: true,
      get: function() {
        return _index.objectPattern;
      }
    });
    Object.defineProperty(exports, "ObjectProperty", {
      enumerable: true,
      get: function() {
        return _index.objectProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.objectTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ObjectTypeCallProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeCallProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeIndexer", {
      enumerable: true,
      get: function() {
        return _index.objectTypeIndexer;
      }
    });
    Object.defineProperty(exports, "ObjectTypeInternalSlot", {
      enumerable: true,
      get: function() {
        return _index.objectTypeInternalSlot;
      }
    });
    Object.defineProperty(exports, "ObjectTypeProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeSpreadProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeSpreadProperty;
      }
    });
    Object.defineProperty(exports, "OpaqueType", {
      enumerable: true,
      get: function() {
        return _index.opaqueType;
      }
    });
    Object.defineProperty(exports, "OptionalCallExpression", {
      enumerable: true,
      get: function() {
        return _index.optionalCallExpression;
      }
    });
    Object.defineProperty(exports, "OptionalIndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.optionalIndexedAccessType;
      }
    });
    Object.defineProperty(exports, "OptionalMemberExpression", {
      enumerable: true,
      get: function() {
        return _index.optionalMemberExpression;
      }
    });
    Object.defineProperty(exports, "ParenthesizedExpression", {
      enumerable: true,
      get: function() {
        return _index.parenthesizedExpression;
      }
    });
    Object.defineProperty(exports, "PipelineBareFunction", {
      enumerable: true,
      get: function() {
        return _index.pipelineBareFunction;
      }
    });
    Object.defineProperty(exports, "PipelinePrimaryTopicReference", {
      enumerable: true,
      get: function() {
        return _index.pipelinePrimaryTopicReference;
      }
    });
    Object.defineProperty(exports, "PipelineTopicExpression", {
      enumerable: true,
      get: function() {
        return _index.pipelineTopicExpression;
      }
    });
    Object.defineProperty(exports, "Placeholder", {
      enumerable: true,
      get: function() {
        return _index.placeholder;
      }
    });
    Object.defineProperty(exports, "PrivateName", {
      enumerable: true,
      get: function() {
        return _index.privateName;
      }
    });
    Object.defineProperty(exports, "Program", {
      enumerable: true,
      get: function() {
        return _index.program;
      }
    });
    Object.defineProperty(exports, "QualifiedTypeIdentifier", {
      enumerable: true,
      get: function() {
        return _index.qualifiedTypeIdentifier;
      }
    });
    Object.defineProperty(exports, "RecordExpression", {
      enumerable: true,
      get: function() {
        return _index.recordExpression;
      }
    });
    Object.defineProperty(exports, "RegExpLiteral", {
      enumerable: true,
      get: function() {
        return _index.regExpLiteral;
      }
    });
    Object.defineProperty(exports, "RegexLiteral", {
      enumerable: true,
      get: function() {
        return _index.regexLiteral;
      }
    });
    Object.defineProperty(exports, "RestElement", {
      enumerable: true,
      get: function() {
        return _index.restElement;
      }
    });
    Object.defineProperty(exports, "RestProperty", {
      enumerable: true,
      get: function() {
        return _index.restProperty;
      }
    });
    Object.defineProperty(exports, "ReturnStatement", {
      enumerable: true,
      get: function() {
        return _index.returnStatement;
      }
    });
    Object.defineProperty(exports, "SequenceExpression", {
      enumerable: true,
      get: function() {
        return _index.sequenceExpression;
      }
    });
    Object.defineProperty(exports, "SpreadElement", {
      enumerable: true,
      get: function() {
        return _index.spreadElement;
      }
    });
    Object.defineProperty(exports, "SpreadProperty", {
      enumerable: true,
      get: function() {
        return _index.spreadProperty;
      }
    });
    Object.defineProperty(exports, "StaticBlock", {
      enumerable: true,
      get: function() {
        return _index.staticBlock;
      }
    });
    Object.defineProperty(exports, "StringLiteral", {
      enumerable: true,
      get: function() {
        return _index.stringLiteral;
      }
    });
    Object.defineProperty(exports, "StringLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.stringLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "StringTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.stringTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "Super", {
      enumerable: true,
      get: function() {
        return _index.super;
      }
    });
    Object.defineProperty(exports, "SwitchCase", {
      enumerable: true,
      get: function() {
        return _index.switchCase;
      }
    });
    Object.defineProperty(exports, "SwitchStatement", {
      enumerable: true,
      get: function() {
        return _index.switchStatement;
      }
    });
    Object.defineProperty(exports, "SymbolTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.symbolTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TSAnyKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsAnyKeyword;
      }
    });
    Object.defineProperty(exports, "TSArrayType", {
      enumerable: true,
      get: function() {
        return _index.tsArrayType;
      }
    });
    Object.defineProperty(exports, "TSAsExpression", {
      enumerable: true,
      get: function() {
        return _index.tsAsExpression;
      }
    });
    Object.defineProperty(exports, "TSBigIntKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsBigIntKeyword;
      }
    });
    Object.defineProperty(exports, "TSBooleanKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsBooleanKeyword;
      }
    });
    Object.defineProperty(exports, "TSCallSignatureDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsCallSignatureDeclaration;
      }
    });
    Object.defineProperty(exports, "TSConditionalType", {
      enumerable: true,
      get: function() {
        return _index.tsConditionalType;
      }
    });
    Object.defineProperty(exports, "TSConstructSignatureDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsConstructSignatureDeclaration;
      }
    });
    Object.defineProperty(exports, "TSConstructorType", {
      enumerable: true,
      get: function() {
        return _index.tsConstructorType;
      }
    });
    Object.defineProperty(exports, "TSDeclareFunction", {
      enumerable: true,
      get: function() {
        return _index.tsDeclareFunction;
      }
    });
    Object.defineProperty(exports, "TSDeclareMethod", {
      enumerable: true,
      get: function() {
        return _index.tsDeclareMethod;
      }
    });
    Object.defineProperty(exports, "TSEnumDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsEnumDeclaration;
      }
    });
    Object.defineProperty(exports, "TSEnumMember", {
      enumerable: true,
      get: function() {
        return _index.tsEnumMember;
      }
    });
    Object.defineProperty(exports, "TSExportAssignment", {
      enumerable: true,
      get: function() {
        return _index.tsExportAssignment;
      }
    });
    Object.defineProperty(exports, "TSExpressionWithTypeArguments", {
      enumerable: true,
      get: function() {
        return _index.tsExpressionWithTypeArguments;
      }
    });
    Object.defineProperty(exports, "TSExternalModuleReference", {
      enumerable: true,
      get: function() {
        return _index.tsExternalModuleReference;
      }
    });
    Object.defineProperty(exports, "TSFunctionType", {
      enumerable: true,
      get: function() {
        return _index.tsFunctionType;
      }
    });
    Object.defineProperty(exports, "TSImportEqualsDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsImportEqualsDeclaration;
      }
    });
    Object.defineProperty(exports, "TSImportType", {
      enumerable: true,
      get: function() {
        return _index.tsImportType;
      }
    });
    Object.defineProperty(exports, "TSIndexSignature", {
      enumerable: true,
      get: function() {
        return _index.tsIndexSignature;
      }
    });
    Object.defineProperty(exports, "TSIndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.tsIndexedAccessType;
      }
    });
    Object.defineProperty(exports, "TSInferType", {
      enumerable: true,
      get: function() {
        return _index.tsInferType;
      }
    });
    Object.defineProperty(exports, "TSInstantiationExpression", {
      enumerable: true,
      get: function() {
        return _index.tsInstantiationExpression;
      }
    });
    Object.defineProperty(exports, "TSInterfaceBody", {
      enumerable: true,
      get: function() {
        return _index.tsInterfaceBody;
      }
    });
    Object.defineProperty(exports, "TSInterfaceDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsInterfaceDeclaration;
      }
    });
    Object.defineProperty(exports, "TSIntersectionType", {
      enumerable: true,
      get: function() {
        return _index.tsIntersectionType;
      }
    });
    Object.defineProperty(exports, "TSIntrinsicKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsIntrinsicKeyword;
      }
    });
    Object.defineProperty(exports, "TSLiteralType", {
      enumerable: true,
      get: function() {
        return _index.tsLiteralType;
      }
    });
    Object.defineProperty(exports, "TSMappedType", {
      enumerable: true,
      get: function() {
        return _index.tsMappedType;
      }
    });
    Object.defineProperty(exports, "TSMethodSignature", {
      enumerable: true,
      get: function() {
        return _index.tsMethodSignature;
      }
    });
    Object.defineProperty(exports, "TSModuleBlock", {
      enumerable: true,
      get: function() {
        return _index.tsModuleBlock;
      }
    });
    Object.defineProperty(exports, "TSModuleDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsModuleDeclaration;
      }
    });
    Object.defineProperty(exports, "TSNamedTupleMember", {
      enumerable: true,
      get: function() {
        return _index.tsNamedTupleMember;
      }
    });
    Object.defineProperty(exports, "TSNamespaceExportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsNamespaceExportDeclaration;
      }
    });
    Object.defineProperty(exports, "TSNeverKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNeverKeyword;
      }
    });
    Object.defineProperty(exports, "TSNonNullExpression", {
      enumerable: true,
      get: function() {
        return _index.tsNonNullExpression;
      }
    });
    Object.defineProperty(exports, "TSNullKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNullKeyword;
      }
    });
    Object.defineProperty(exports, "TSNumberKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNumberKeyword;
      }
    });
    Object.defineProperty(exports, "TSObjectKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsObjectKeyword;
      }
    });
    Object.defineProperty(exports, "TSOptionalType", {
      enumerable: true,
      get: function() {
        return _index.tsOptionalType;
      }
    });
    Object.defineProperty(exports, "TSParameterProperty", {
      enumerable: true,
      get: function() {
        return _index.tsParameterProperty;
      }
    });
    Object.defineProperty(exports, "TSParenthesizedType", {
      enumerable: true,
      get: function() {
        return _index.tsParenthesizedType;
      }
    });
    Object.defineProperty(exports, "TSPropertySignature", {
      enumerable: true,
      get: function() {
        return _index.tsPropertySignature;
      }
    });
    Object.defineProperty(exports, "TSQualifiedName", {
      enumerable: true,
      get: function() {
        return _index.tsQualifiedName;
      }
    });
    Object.defineProperty(exports, "TSRestType", {
      enumerable: true,
      get: function() {
        return _index.tsRestType;
      }
    });
    Object.defineProperty(exports, "TSSatisfiesExpression", {
      enumerable: true,
      get: function() {
        return _index.tsSatisfiesExpression;
      }
    });
    Object.defineProperty(exports, "TSStringKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsStringKeyword;
      }
    });
    Object.defineProperty(exports, "TSSymbolKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsSymbolKeyword;
      }
    });
    Object.defineProperty(exports, "TSThisType", {
      enumerable: true,
      get: function() {
        return _index.tsThisType;
      }
    });
    Object.defineProperty(exports, "TSTupleType", {
      enumerable: true,
      get: function() {
        return _index.tsTupleType;
      }
    });
    Object.defineProperty(exports, "TSTypeAliasDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAliasDeclaration;
      }
    });
    Object.defineProperty(exports, "TSTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TSTypeAssertion", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAssertion;
      }
    });
    Object.defineProperty(exports, "TSTypeLiteral", {
      enumerable: true,
      get: function() {
        return _index.tsTypeLiteral;
      }
    });
    Object.defineProperty(exports, "TSTypeOperator", {
      enumerable: true,
      get: function() {
        return _index.tsTypeOperator;
      }
    });
    Object.defineProperty(exports, "TSTypeParameter", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameter;
      }
    });
    Object.defineProperty(exports, "TSTypeParameterDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameterDeclaration;
      }
    });
    Object.defineProperty(exports, "TSTypeParameterInstantiation", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameterInstantiation;
      }
    });
    Object.defineProperty(exports, "TSTypePredicate", {
      enumerable: true,
      get: function() {
        return _index.tsTypePredicate;
      }
    });
    Object.defineProperty(exports, "TSTypeQuery", {
      enumerable: true,
      get: function() {
        return _index.tsTypeQuery;
      }
    });
    Object.defineProperty(exports, "TSTypeReference", {
      enumerable: true,
      get: function() {
        return _index.tsTypeReference;
      }
    });
    Object.defineProperty(exports, "TSUndefinedKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsUndefinedKeyword;
      }
    });
    Object.defineProperty(exports, "TSUnionType", {
      enumerable: true,
      get: function() {
        return _index.tsUnionType;
      }
    });
    Object.defineProperty(exports, "TSUnknownKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsUnknownKeyword;
      }
    });
    Object.defineProperty(exports, "TSVoidKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsVoidKeyword;
      }
    });
    Object.defineProperty(exports, "TaggedTemplateExpression", {
      enumerable: true,
      get: function() {
        return _index.taggedTemplateExpression;
      }
    });
    Object.defineProperty(exports, "TemplateElement", {
      enumerable: true,
      get: function() {
        return _index.templateElement;
      }
    });
    Object.defineProperty(exports, "TemplateLiteral", {
      enumerable: true,
      get: function() {
        return _index.templateLiteral;
      }
    });
    Object.defineProperty(exports, "ThisExpression", {
      enumerable: true,
      get: function() {
        return _index.thisExpression;
      }
    });
    Object.defineProperty(exports, "ThisTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.thisTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ThrowStatement", {
      enumerable: true,
      get: function() {
        return _index.throwStatement;
      }
    });
    Object.defineProperty(exports, "TopicReference", {
      enumerable: true,
      get: function() {
        return _index.topicReference;
      }
    });
    Object.defineProperty(exports, "TryStatement", {
      enumerable: true,
      get: function() {
        return _index.tryStatement;
      }
    });
    Object.defineProperty(exports, "TupleExpression", {
      enumerable: true,
      get: function() {
        return _index.tupleExpression;
      }
    });
    Object.defineProperty(exports, "TupleTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.tupleTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TypeAlias", {
      enumerable: true,
      get: function() {
        return _index.typeAlias;
      }
    });
    Object.defineProperty(exports, "TypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.typeAnnotation;
      }
    });
    Object.defineProperty(exports, "TypeCastExpression", {
      enumerable: true,
      get: function() {
        return _index.typeCastExpression;
      }
    });
    Object.defineProperty(exports, "TypeParameter", {
      enumerable: true,
      get: function() {
        return _index.typeParameter;
      }
    });
    Object.defineProperty(exports, "TypeParameterDeclaration", {
      enumerable: true,
      get: function() {
        return _index.typeParameterDeclaration;
      }
    });
    Object.defineProperty(exports, "TypeParameterInstantiation", {
      enumerable: true,
      get: function() {
        return _index.typeParameterInstantiation;
      }
    });
    Object.defineProperty(exports, "TypeofTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.typeofTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "UnaryExpression", {
      enumerable: true,
      get: function() {
        return _index.unaryExpression;
      }
    });
    Object.defineProperty(exports, "UnionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.unionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "UpdateExpression", {
      enumerable: true,
      get: function() {
        return _index.updateExpression;
      }
    });
    Object.defineProperty(exports, "V8IntrinsicIdentifier", {
      enumerable: true,
      get: function() {
        return _index.v8IntrinsicIdentifier;
      }
    });
    Object.defineProperty(exports, "VariableDeclaration", {
      enumerable: true,
      get: function() {
        return _index.variableDeclaration;
      }
    });
    Object.defineProperty(exports, "VariableDeclarator", {
      enumerable: true,
      get: function() {
        return _index.variableDeclarator;
      }
    });
    Object.defineProperty(exports, "Variance", {
      enumerable: true,
      get: function() {
        return _index.variance;
      }
    });
    Object.defineProperty(exports, "VoidTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.voidTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "WhileStatement", {
      enumerable: true,
      get: function() {
        return _index.whileStatement;
      }
    });
    Object.defineProperty(exports, "WithStatement", {
      enumerable: true,
      get: function() {
        return _index.withStatement;
      }
    });
    Object.defineProperty(exports, "YieldExpression", {
      enumerable: true,
      get: function() {
        return _index.yieldExpression;
      }
    });
    var _index = require_generated2();
  }
});

// node_modules/@babel/types/lib/clone/cloneNode.js
var require_cloneNode = __commonJS({
  "node_modules/@babel/types/lib/clone/cloneNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneNode;
    var _definitions = require_definitions();
    var _generated = require_generated();
    var has = Function.call.bind(Object.prototype.hasOwnProperty);
    function cloneIfNode(obj, deep, withoutLoc, commentsCache) {
      if (obj && typeof obj.type === "string") {
        return cloneNodeInternal(obj, deep, withoutLoc, commentsCache);
      }
      return obj;
    }
    function cloneIfNodeOrArray(obj, deep, withoutLoc, commentsCache) {
      if (Array.isArray(obj)) {
        return obj.map((node) => cloneIfNode(node, deep, withoutLoc, commentsCache));
      }
      return cloneIfNode(obj, deep, withoutLoc, commentsCache);
    }
    function cloneNode(node, deep = true, withoutLoc = false) {
      return cloneNodeInternal(node, deep, withoutLoc, /* @__PURE__ */ new Map());
    }
    function cloneNodeInternal(node, deep = true, withoutLoc = false, commentsCache) {
      if (!node)
        return node;
      const {
        type
      } = node;
      const newNode = {
        type: node.type
      };
      if ((0, _generated.isIdentifier)(node)) {
        newNode.name = node.name;
        if (has(node, "optional") && typeof node.optional === "boolean") {
          newNode.optional = node.optional;
        }
        if (has(node, "typeAnnotation")) {
          newNode.typeAnnotation = deep ? cloneIfNodeOrArray(node.typeAnnotation, true, withoutLoc, commentsCache) : node.typeAnnotation;
        }
      } else if (!has(_definitions.NODE_FIELDS, type)) {
        throw new Error(`Unknown node type: "${type}"`);
      } else {
        for (const field of Object.keys(_definitions.NODE_FIELDS[type])) {
          if (has(node, field)) {
            if (deep) {
              newNode[field] = (0, _generated.isFile)(node) && field === "comments" ? maybeCloneComments(node.comments, deep, withoutLoc, commentsCache) : cloneIfNodeOrArray(
                node[field],
                true,
                withoutLoc,
                commentsCache
              );
            } else {
              newNode[field] = node[field];
            }
          }
        }
      }
      if (has(node, "loc")) {
        if (withoutLoc) {
          newNode.loc = null;
        } else {
          newNode.loc = node.loc;
        }
      }
      if (has(node, "leadingComments")) {
        newNode.leadingComments = maybeCloneComments(node.leadingComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "innerComments")) {
        newNode.innerComments = maybeCloneComments(node.innerComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "trailingComments")) {
        newNode.trailingComments = maybeCloneComments(node.trailingComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "extra")) {
        newNode.extra = Object.assign({}, node.extra);
      }
      return newNode;
    }
    function maybeCloneComments(comments, deep, withoutLoc, commentsCache) {
      if (!comments || !deep) {
        return comments;
      }
      return comments.map((comment) => {
        const cache = commentsCache.get(comment);
        if (cache)
          return cache;
        const {
          type,
          value: value2,
          loc
        } = comment;
        const ret = {
          type,
          value: value2,
          loc
        };
        if (withoutLoc) {
          ret.loc = null;
        }
        commentsCache.set(comment, ret);
        return ret;
      });
    }
  }
});

// node_modules/@babel/types/lib/clone/clone.js
var require_clone3 = __commonJS({
  "node_modules/@babel/types/lib/clone/clone.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = clone;
    var _cloneNode = require_cloneNode();
    function clone(node) {
      return (0, _cloneNode.default)(node, false);
    }
  }
});

// node_modules/@babel/types/lib/clone/cloneDeep.js
var require_cloneDeep = __commonJS({
  "node_modules/@babel/types/lib/clone/cloneDeep.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneDeep3;
    var _cloneNode = require_cloneNode();
    function cloneDeep3(node) {
      return (0, _cloneNode.default)(node);
    }
  }
});

// node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js
var require_cloneDeepWithoutLoc = __commonJS({
  "node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneDeepWithoutLoc;
    var _cloneNode = require_cloneNode();
    function cloneDeepWithoutLoc(node) {
      return (0, _cloneNode.default)(node, true, true);
    }
  }
});

// node_modules/@babel/types/lib/clone/cloneWithoutLoc.js
var require_cloneWithoutLoc = __commonJS({
  "node_modules/@babel/types/lib/clone/cloneWithoutLoc.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneWithoutLoc;
    var _cloneNode = require_cloneNode();
    function cloneWithoutLoc(node) {
      return (0, _cloneNode.default)(node, false, true);
    }
  }
});

// node_modules/@babel/types/lib/comments/addComments.js
var require_addComments = __commonJS({
  "node_modules/@babel/types/lib/comments/addComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = addComments;
    function addComments(node, type, comments) {
      if (!comments || !node)
        return node;
      const key = `${type}Comments`;
      if (node[key]) {
        if (type === "leading") {
          node[key] = comments.concat(node[key]);
        } else {
          node[key].push(...comments);
        }
      } else {
        node[key] = comments;
      }
      return node;
    }
  }
});

// node_modules/@babel/types/lib/comments/addComment.js
var require_addComment = __commonJS({
  "node_modules/@babel/types/lib/comments/addComment.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = addComment;
    var _addComments = require_addComments();
    function addComment(node, type, content, line) {
      return (0, _addComments.default)(node, type, [{
        type: line ? "CommentLine" : "CommentBlock",
        value: content
      }]);
    }
  }
});

// node_modules/@babel/types/lib/utils/inherit.js
var require_inherit = __commonJS({
  "node_modules/@babel/types/lib/utils/inherit.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inherit;
    function inherit(key, child, parent) {
      if (child && parent) {
        child[key] = Array.from(new Set([].concat(child[key], parent[key]).filter(Boolean)));
      }
    }
  }
});

// node_modules/@babel/types/lib/comments/inheritInnerComments.js
var require_inheritInnerComments = __commonJS({
  "node_modules/@babel/types/lib/comments/inheritInnerComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritInnerComments;
    var _inherit = require_inherit();
    function inheritInnerComments(child, parent) {
      (0, _inherit.default)("innerComments", child, parent);
    }
  }
});

// node_modules/@babel/types/lib/comments/inheritLeadingComments.js
var require_inheritLeadingComments = __commonJS({
  "node_modules/@babel/types/lib/comments/inheritLeadingComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritLeadingComments;
    var _inherit = require_inherit();
    function inheritLeadingComments(child, parent) {
      (0, _inherit.default)("leadingComments", child, parent);
    }
  }
});

// node_modules/@babel/types/lib/comments/inheritTrailingComments.js
var require_inheritTrailingComments = __commonJS({
  "node_modules/@babel/types/lib/comments/inheritTrailingComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritTrailingComments;
    var _inherit = require_inherit();
    function inheritTrailingComments(child, parent) {
      (0, _inherit.default)("trailingComments", child, parent);
    }
  }
});

// node_modules/@babel/types/lib/comments/inheritsComments.js
var require_inheritsComments = __commonJS({
  "node_modules/@babel/types/lib/comments/inheritsComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritsComments;
    var _inheritTrailingComments = require_inheritTrailingComments();
    var _inheritLeadingComments = require_inheritLeadingComments();
    var _inheritInnerComments = require_inheritInnerComments();
    function inheritsComments(child, parent) {
      (0, _inheritTrailingComments.default)(child, parent);
      (0, _inheritLeadingComments.default)(child, parent);
      (0, _inheritInnerComments.default)(child, parent);
      return child;
    }
  }
});

// node_modules/@babel/types/lib/comments/removeComments.js
var require_removeComments = __commonJS({
  "node_modules/@babel/types/lib/comments/removeComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeComments;
    var _constants = require_constants2();
    function removeComments(node) {
      _constants.COMMENT_KEYS.forEach((key) => {
        node[key] = null;
      });
      return node;
    }
  }
});

// node_modules/@babel/types/lib/constants/generated/index.js
var require_generated4 = __commonJS({
  "node_modules/@babel/types/lib/constants/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.WHILE_TYPES = exports.USERWHITESPACABLE_TYPES = exports.UNARYLIKE_TYPES = exports.TYPESCRIPT_TYPES = exports.TSTYPE_TYPES = exports.TSTYPEELEMENT_TYPES = exports.TSENTITYNAME_TYPES = exports.TSBASETYPE_TYPES = exports.TERMINATORLESS_TYPES = exports.STATEMENT_TYPES = exports.STANDARDIZED_TYPES = exports.SCOPABLE_TYPES = exports.PUREISH_TYPES = exports.PROPERTY_TYPES = exports.PRIVATE_TYPES = exports.PATTERN_TYPES = exports.PATTERNLIKE_TYPES = exports.OBJECTMEMBER_TYPES = exports.MODULESPECIFIER_TYPES = exports.MODULEDECLARATION_TYPES = exports.MISCELLANEOUS_TYPES = exports.METHOD_TYPES = exports.LVAL_TYPES = exports.LOOP_TYPES = exports.LITERAL_TYPES = exports.JSX_TYPES = exports.IMMUTABLE_TYPES = exports.FUNCTION_TYPES = exports.FUNCTIONPARENT_TYPES = exports.FOR_TYPES = exports.FORXSTATEMENT_TYPES = exports.FLOW_TYPES = exports.FLOWTYPE_TYPES = exports.FLOWPREDICATE_TYPES = exports.FLOWDECLARATION_TYPES = exports.FLOWBASEANNOTATION_TYPES = exports.EXPRESSION_TYPES = exports.EXPRESSIONWRAPPER_TYPES = exports.EXPORTDECLARATION_TYPES = exports.ENUMMEMBER_TYPES = exports.ENUMBODY_TYPES = exports.DECLARATION_TYPES = exports.CONDITIONAL_TYPES = exports.COMPLETIONSTATEMENT_TYPES = exports.CLASS_TYPES = exports.BLOCK_TYPES = exports.BLOCKPARENT_TYPES = exports.BINARY_TYPES = exports.ACCESSOR_TYPES = void 0;
    var _definitions = require_definitions();
    var STANDARDIZED_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Standardized"];
    exports.STANDARDIZED_TYPES = STANDARDIZED_TYPES;
    var EXPRESSION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Expression"];
    exports.EXPRESSION_TYPES = EXPRESSION_TYPES;
    var BINARY_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Binary"];
    exports.BINARY_TYPES = BINARY_TYPES;
    var SCOPABLE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Scopable"];
    exports.SCOPABLE_TYPES = SCOPABLE_TYPES;
    var BLOCKPARENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["BlockParent"];
    exports.BLOCKPARENT_TYPES = BLOCKPARENT_TYPES;
    var BLOCK_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Block"];
    exports.BLOCK_TYPES = BLOCK_TYPES;
    var STATEMENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Statement"];
    exports.STATEMENT_TYPES = STATEMENT_TYPES;
    var TERMINATORLESS_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Terminatorless"];
    exports.TERMINATORLESS_TYPES = TERMINATORLESS_TYPES;
    var COMPLETIONSTATEMENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["CompletionStatement"];
    exports.COMPLETIONSTATEMENT_TYPES = COMPLETIONSTATEMENT_TYPES;
    var CONDITIONAL_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Conditional"];
    exports.CONDITIONAL_TYPES = CONDITIONAL_TYPES;
    var LOOP_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Loop"];
    exports.LOOP_TYPES = LOOP_TYPES;
    var WHILE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["While"];
    exports.WHILE_TYPES = WHILE_TYPES;
    var EXPRESSIONWRAPPER_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ExpressionWrapper"];
    exports.EXPRESSIONWRAPPER_TYPES = EXPRESSIONWRAPPER_TYPES;
    var FOR_TYPES = _definitions.FLIPPED_ALIAS_KEYS["For"];
    exports.FOR_TYPES = FOR_TYPES;
    var FORXSTATEMENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ForXStatement"];
    exports.FORXSTATEMENT_TYPES = FORXSTATEMENT_TYPES;
    var FUNCTION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Function"];
    exports.FUNCTION_TYPES = FUNCTION_TYPES;
    var FUNCTIONPARENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["FunctionParent"];
    exports.FUNCTIONPARENT_TYPES = FUNCTIONPARENT_TYPES;
    var PUREISH_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Pureish"];
    exports.PUREISH_TYPES = PUREISH_TYPES;
    var DECLARATION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Declaration"];
    exports.DECLARATION_TYPES = DECLARATION_TYPES;
    var PATTERNLIKE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["PatternLike"];
    exports.PATTERNLIKE_TYPES = PATTERNLIKE_TYPES;
    var LVAL_TYPES = _definitions.FLIPPED_ALIAS_KEYS["LVal"];
    exports.LVAL_TYPES = LVAL_TYPES;
    var TSENTITYNAME_TYPES = _definitions.FLIPPED_ALIAS_KEYS["TSEntityName"];
    exports.TSENTITYNAME_TYPES = TSENTITYNAME_TYPES;
    var LITERAL_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Literal"];
    exports.LITERAL_TYPES = LITERAL_TYPES;
    var IMMUTABLE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Immutable"];
    exports.IMMUTABLE_TYPES = IMMUTABLE_TYPES;
    var USERWHITESPACABLE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["UserWhitespacable"];
    exports.USERWHITESPACABLE_TYPES = USERWHITESPACABLE_TYPES;
    var METHOD_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Method"];
    exports.METHOD_TYPES = METHOD_TYPES;
    var OBJECTMEMBER_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ObjectMember"];
    exports.OBJECTMEMBER_TYPES = OBJECTMEMBER_TYPES;
    var PROPERTY_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Property"];
    exports.PROPERTY_TYPES = PROPERTY_TYPES;
    var UNARYLIKE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["UnaryLike"];
    exports.UNARYLIKE_TYPES = UNARYLIKE_TYPES;
    var PATTERN_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Pattern"];
    exports.PATTERN_TYPES = PATTERN_TYPES;
    var CLASS_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Class"];
    exports.CLASS_TYPES = CLASS_TYPES;
    var MODULEDECLARATION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ModuleDeclaration"];
    exports.MODULEDECLARATION_TYPES = MODULEDECLARATION_TYPES;
    var EXPORTDECLARATION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ExportDeclaration"];
    exports.EXPORTDECLARATION_TYPES = EXPORTDECLARATION_TYPES;
    var MODULESPECIFIER_TYPES = _definitions.FLIPPED_ALIAS_KEYS["ModuleSpecifier"];
    exports.MODULESPECIFIER_TYPES = MODULESPECIFIER_TYPES;
    var ACCESSOR_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Accessor"];
    exports.ACCESSOR_TYPES = ACCESSOR_TYPES;
    var PRIVATE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Private"];
    exports.PRIVATE_TYPES = PRIVATE_TYPES;
    var FLOW_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Flow"];
    exports.FLOW_TYPES = FLOW_TYPES;
    var FLOWTYPE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["FlowType"];
    exports.FLOWTYPE_TYPES = FLOWTYPE_TYPES;
    var FLOWBASEANNOTATION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["FlowBaseAnnotation"];
    exports.FLOWBASEANNOTATION_TYPES = FLOWBASEANNOTATION_TYPES;
    var FLOWDECLARATION_TYPES = _definitions.FLIPPED_ALIAS_KEYS["FlowDeclaration"];
    exports.FLOWDECLARATION_TYPES = FLOWDECLARATION_TYPES;
    var FLOWPREDICATE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["FlowPredicate"];
    exports.FLOWPREDICATE_TYPES = FLOWPREDICATE_TYPES;
    var ENUMBODY_TYPES = _definitions.FLIPPED_ALIAS_KEYS["EnumBody"];
    exports.ENUMBODY_TYPES = ENUMBODY_TYPES;
    var ENUMMEMBER_TYPES = _definitions.FLIPPED_ALIAS_KEYS["EnumMember"];
    exports.ENUMMEMBER_TYPES = ENUMMEMBER_TYPES;
    var JSX_TYPES = _definitions.FLIPPED_ALIAS_KEYS["JSX"];
    exports.JSX_TYPES = JSX_TYPES;
    var MISCELLANEOUS_TYPES = _definitions.FLIPPED_ALIAS_KEYS["Miscellaneous"];
    exports.MISCELLANEOUS_TYPES = MISCELLANEOUS_TYPES;
    var TYPESCRIPT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["TypeScript"];
    exports.TYPESCRIPT_TYPES = TYPESCRIPT_TYPES;
    var TSTYPEELEMENT_TYPES = _definitions.FLIPPED_ALIAS_KEYS["TSTypeElement"];
    exports.TSTYPEELEMENT_TYPES = TSTYPEELEMENT_TYPES;
    var TSTYPE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["TSType"];
    exports.TSTYPE_TYPES = TSTYPE_TYPES;
    var TSBASETYPE_TYPES = _definitions.FLIPPED_ALIAS_KEYS["TSBaseType"];
    exports.TSBASETYPE_TYPES = TSBASETYPE_TYPES;
  }
});

// node_modules/@babel/types/lib/converters/toBlock.js
var require_toBlock = __commonJS({
  "node_modules/@babel/types/lib/converters/toBlock.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toBlock;
    var _generated = require_generated();
    var _generated2 = require_generated2();
    function toBlock(node, parent) {
      if ((0, _generated.isBlockStatement)(node)) {
        return node;
      }
      let blockNodes = [];
      if ((0, _generated.isEmptyStatement)(node)) {
        blockNodes = [];
      } else {
        if (!(0, _generated.isStatement)(node)) {
          if ((0, _generated.isFunction)(parent)) {
            node = (0, _generated2.returnStatement)(node);
          } else {
            node = (0, _generated2.expressionStatement)(node);
          }
        }
        blockNodes = [node];
      }
      return (0, _generated2.blockStatement)(blockNodes);
    }
  }
});

// node_modules/@babel/types/lib/converters/ensureBlock.js
var require_ensureBlock = __commonJS({
  "node_modules/@babel/types/lib/converters/ensureBlock.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = ensureBlock;
    var _toBlock = require_toBlock();
    function ensureBlock(node, key = "body") {
      const result = (0, _toBlock.default)(node[key], node);
      node[key] = result;
      return result;
    }
  }
});

// node_modules/@babel/types/lib/converters/toIdentifier.js
var require_toIdentifier = __commonJS({
  "node_modules/@babel/types/lib/converters/toIdentifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toIdentifier;
    var _isValidIdentifier = require_isValidIdentifier();
    var _helperValidatorIdentifier = require_lib9();
    function toIdentifier(input) {
      input = input + "";
      let name = "";
      for (const c of input) {
        name += (0, _helperValidatorIdentifier.isIdentifierChar)(c.codePointAt(0)) ? c : "-";
      }
      name = name.replace(/^[-0-9]+/, "");
      name = name.replace(/[-\s]+(.)?/g, function(match, c) {
        return c ? c.toUpperCase() : "";
      });
      if (!(0, _isValidIdentifier.default)(name)) {
        name = `_${name}`;
      }
      return name || "_";
    }
  }
});

// node_modules/@babel/types/lib/converters/toBindingIdentifierName.js
var require_toBindingIdentifierName = __commonJS({
  "node_modules/@babel/types/lib/converters/toBindingIdentifierName.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toBindingIdentifierName;
    var _toIdentifier = require_toIdentifier();
    function toBindingIdentifierName(name) {
      name = (0, _toIdentifier.default)(name);
      if (name === "eval" || name === "arguments")
        name = "_" + name;
      return name;
    }
  }
});

// node_modules/@babel/types/lib/converters/toComputedKey.js
var require_toComputedKey = __commonJS({
  "node_modules/@babel/types/lib/converters/toComputedKey.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toComputedKey;
    var _generated = require_generated();
    var _generated2 = require_generated2();
    function toComputedKey(node, key = node.key || node.property) {
      if (!node.computed && (0, _generated.isIdentifier)(key))
        key = (0, _generated2.stringLiteral)(key.name);
      return key;
    }
  }
});

// node_modules/@babel/types/lib/converters/toExpression.js
var require_toExpression = __commonJS({
  "node_modules/@babel/types/lib/converters/toExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _generated = require_generated();
    var _default = toExpression;
    exports.default = _default;
    function toExpression(node) {
      if ((0, _generated.isExpressionStatement)(node)) {
        node = node.expression;
      }
      if ((0, _generated.isExpression)(node)) {
        return node;
      }
      if ((0, _generated.isClass)(node)) {
        node.type = "ClassExpression";
      } else if ((0, _generated.isFunction)(node)) {
        node.type = "FunctionExpression";
      }
      if (!(0, _generated.isExpression)(node)) {
        throw new Error(`cannot turn ${node.type} to an expression`);
      }
      return node;
    }
  }
});

// node_modules/@babel/types/lib/traverse/traverseFast.js
var require_traverseFast = __commonJS({
  "node_modules/@babel/types/lib/traverse/traverseFast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = traverseFast;
    var _definitions = require_definitions();
    function traverseFast(node, enter, opts) {
      if (!node)
        return;
      const keys3 = _definitions.VISITOR_KEYS[node.type];
      if (!keys3)
        return;
      opts = opts || {};
      enter(node, opts);
      for (const key of keys3) {
        const subNode = node[key];
        if (Array.isArray(subNode)) {
          for (const node2 of subNode) {
            traverseFast(node2, enter, opts);
          }
        } else {
          traverseFast(subNode, enter, opts);
        }
      }
    }
  }
});

// node_modules/@babel/types/lib/modifications/removeProperties.js
var require_removeProperties = __commonJS({
  "node_modules/@babel/types/lib/modifications/removeProperties.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeProperties;
    var _constants = require_constants2();
    var CLEAR_KEYS = [
      "tokens",
      "start",
      "end",
      "loc",
      "raw",
      "rawValue"
    ];
    var CLEAR_KEYS_PLUS_COMMENTS = [..._constants.COMMENT_KEYS, "comments", ...CLEAR_KEYS];
    function removeProperties(node, opts = {}) {
      const map = opts.preserveComments ? CLEAR_KEYS : CLEAR_KEYS_PLUS_COMMENTS;
      for (const key of map) {
        if (node[key] != null)
          node[key] = void 0;
      }
      for (const key of Object.keys(node)) {
        if (key[0] === "_" && node[key] != null)
          node[key] = void 0;
      }
      const symbols = Object.getOwnPropertySymbols(node);
      for (const sym of symbols) {
        node[sym] = null;
      }
    }
  }
});

// node_modules/@babel/types/lib/modifications/removePropertiesDeep.js
var require_removePropertiesDeep = __commonJS({
  "node_modules/@babel/types/lib/modifications/removePropertiesDeep.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removePropertiesDeep;
    var _traverseFast = require_traverseFast();
    var _removeProperties = require_removeProperties();
    function removePropertiesDeep(tree, opts) {
      (0, _traverseFast.default)(tree, _removeProperties.default, opts);
      return tree;
    }
  }
});

// node_modules/@babel/types/lib/converters/toKeyAlias.js
var require_toKeyAlias = __commonJS({
  "node_modules/@babel/types/lib/converters/toKeyAlias.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toKeyAlias;
    var _generated = require_generated();
    var _cloneNode = require_cloneNode();
    var _removePropertiesDeep = require_removePropertiesDeep();
    function toKeyAlias(node, key = node.key) {
      let alias;
      if (node.kind === "method") {
        return toKeyAlias.increment() + "";
      } else if ((0, _generated.isIdentifier)(key)) {
        alias = key.name;
      } else if ((0, _generated.isStringLiteral)(key)) {
        alias = JSON.stringify(key.value);
      } else {
        alias = JSON.stringify((0, _removePropertiesDeep.default)((0, _cloneNode.default)(key)));
      }
      if (node.computed) {
        alias = `[${alias}]`;
      }
      if (node.static) {
        alias = `static:${alias}`;
      }
      return alias;
    }
    toKeyAlias.uid = 0;
    toKeyAlias.increment = function() {
      if (toKeyAlias.uid >= Number.MAX_SAFE_INTEGER) {
        return toKeyAlias.uid = 0;
      } else {
        return toKeyAlias.uid++;
      }
    };
  }
});

// node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js
var require_getBindingIdentifiers = __commonJS({
  "node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = getBindingIdentifiers;
    var _generated = require_generated();
    function getBindingIdentifiers(node, duplicates, outerOnly) {
      const search = [].concat(node);
      const ids = /* @__PURE__ */ Object.create(null);
      while (search.length) {
        const id = search.shift();
        if (!id)
          continue;
        const keys3 = getBindingIdentifiers.keys[id.type];
        if ((0, _generated.isIdentifier)(id)) {
          if (duplicates) {
            const _ids = ids[id.name] = ids[id.name] || [];
            _ids.push(id);
          } else {
            ids[id.name] = id;
          }
          continue;
        }
        if ((0, _generated.isExportDeclaration)(id) && !(0, _generated.isExportAllDeclaration)(id)) {
          if ((0, _generated.isDeclaration)(id.declaration)) {
            search.push(id.declaration);
          }
          continue;
        }
        if (outerOnly) {
          if ((0, _generated.isFunctionDeclaration)(id)) {
            search.push(id.id);
            continue;
          }
          if ((0, _generated.isFunctionExpression)(id)) {
            continue;
          }
        }
        if (keys3) {
          for (let i = 0; i < keys3.length; i++) {
            const key = keys3[i];
            const nodes = id[key];
            if (nodes) {
              Array.isArray(nodes) ? search.push(...nodes) : search.push(nodes);
            }
          }
        }
      }
      return ids;
    }
    getBindingIdentifiers.keys = {
      DeclareClass: ["id"],
      DeclareFunction: ["id"],
      DeclareModule: ["id"],
      DeclareVariable: ["id"],
      DeclareInterface: ["id"],
      DeclareTypeAlias: ["id"],
      DeclareOpaqueType: ["id"],
      InterfaceDeclaration: ["id"],
      TypeAlias: ["id"],
      OpaqueType: ["id"],
      CatchClause: ["param"],
      LabeledStatement: ["label"],
      UnaryExpression: ["argument"],
      AssignmentExpression: ["left"],
      ImportSpecifier: ["local"],
      ImportNamespaceSpecifier: ["local"],
      ImportDefaultSpecifier: ["local"],
      ImportDeclaration: ["specifiers"],
      ExportSpecifier: ["exported"],
      ExportNamespaceSpecifier: ["exported"],
      ExportDefaultSpecifier: ["exported"],
      FunctionDeclaration: ["id", "params"],
      FunctionExpression: ["id", "params"],
      ArrowFunctionExpression: ["params"],
      ObjectMethod: ["params"],
      ClassMethod: ["params"],
      ClassPrivateMethod: ["params"],
      ForInStatement: ["left"],
      ForOfStatement: ["left"],
      ClassDeclaration: ["id"],
      ClassExpression: ["id"],
      RestElement: ["argument"],
      UpdateExpression: ["argument"],
      ObjectProperty: ["value"],
      AssignmentPattern: ["left"],
      ArrayPattern: ["elements"],
      ObjectPattern: ["properties"],
      VariableDeclaration: ["declarations"],
      VariableDeclarator: ["id"]
    };
  }
});

// node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js
var require_gatherSequenceExpressions = __commonJS({
  "node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = gatherSequenceExpressions;
    var _getBindingIdentifiers = require_getBindingIdentifiers();
    var _generated = require_generated();
    var _generated2 = require_generated2();
    var _cloneNode = require_cloneNode();
    function gatherSequenceExpressions(nodes, scope, declars) {
      const exprs = [];
      let ensureLastUndefined = true;
      for (const node of nodes) {
        if (!(0, _generated.isEmptyStatement)(node)) {
          ensureLastUndefined = false;
        }
        if ((0, _generated.isExpression)(node)) {
          exprs.push(node);
        } else if ((0, _generated.isExpressionStatement)(node)) {
          exprs.push(node.expression);
        } else if ((0, _generated.isVariableDeclaration)(node)) {
          if (node.kind !== "var")
            return;
          for (const declar of node.declarations) {
            const bindings = (0, _getBindingIdentifiers.default)(declar);
            for (const key of Object.keys(bindings)) {
              declars.push({
                kind: node.kind,
                id: (0, _cloneNode.default)(bindings[key])
              });
            }
            if (declar.init) {
              exprs.push((0, _generated2.assignmentExpression)("=", declar.id, declar.init));
            }
          }
          ensureLastUndefined = true;
        } else if ((0, _generated.isIfStatement)(node)) {
          const consequent = node.consequent ? gatherSequenceExpressions([node.consequent], scope, declars) : scope.buildUndefinedNode();
          const alternate = node.alternate ? gatherSequenceExpressions([node.alternate], scope, declars) : scope.buildUndefinedNode();
          if (!consequent || !alternate)
            return;
          exprs.push((0, _generated2.conditionalExpression)(node.test, consequent, alternate));
        } else if ((0, _generated.isBlockStatement)(node)) {
          const body = gatherSequenceExpressions(node.body, scope, declars);
          if (!body)
            return;
          exprs.push(body);
        } else if ((0, _generated.isEmptyStatement)(node)) {
          if (nodes.indexOf(node) === 0) {
            ensureLastUndefined = true;
          }
        } else {
          return;
        }
      }
      if (ensureLastUndefined) {
        exprs.push(scope.buildUndefinedNode());
      }
      if (exprs.length === 1) {
        return exprs[0];
      } else {
        return (0, _generated2.sequenceExpression)(exprs);
      }
    }
  }
});

// node_modules/@babel/types/lib/converters/toSequenceExpression.js
var require_toSequenceExpression = __commonJS({
  "node_modules/@babel/types/lib/converters/toSequenceExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toSequenceExpression;
    var _gatherSequenceExpressions = require_gatherSequenceExpressions();
    function toSequenceExpression(nodes, scope) {
      if (!(nodes != null && nodes.length))
        return;
      const declars = [];
      const result = (0, _gatherSequenceExpressions.default)(nodes, scope, declars);
      if (!result)
        return;
      for (const declar of declars) {
        scope.push(declar);
      }
      return result;
    }
  }
});

// node_modules/@babel/types/lib/converters/toStatement.js
var require_toStatement = __commonJS({
  "node_modules/@babel/types/lib/converters/toStatement.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _generated = require_generated();
    var _generated2 = require_generated2();
    var _default = toStatement;
    exports.default = _default;
    function toStatement(node, ignore) {
      if ((0, _generated.isStatement)(node)) {
        return node;
      }
      let mustHaveId = false;
      let newType;
      if ((0, _generated.isClass)(node)) {
        mustHaveId = true;
        newType = "ClassDeclaration";
      } else if ((0, _generated.isFunction)(node)) {
        mustHaveId = true;
        newType = "FunctionDeclaration";
      } else if ((0, _generated.isAssignmentExpression)(node)) {
        return (0, _generated2.expressionStatement)(node);
      }
      if (mustHaveId && !node.id) {
        newType = false;
      }
      if (!newType) {
        if (ignore) {
          return false;
        } else {
          throw new Error(`cannot turn ${node.type} to a statement`);
        }
      }
      node.type = newType;
      return node;
    }
  }
});

// node_modules/@babel/types/lib/converters/valueToNode.js
var require_valueToNode = __commonJS({
  "node_modules/@babel/types/lib/converters/valueToNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _isValidIdentifier = require_isValidIdentifier();
    var _generated = require_generated2();
    var _default = valueToNode;
    exports.default = _default;
    var objectToString = Function.call.bind(Object.prototype.toString);
    function isRegExp(value2) {
      return objectToString(value2) === "[object RegExp]";
    }
    function isPlainObject(value2) {
      if (typeof value2 !== "object" || value2 === null || Object.prototype.toString.call(value2) !== "[object Object]") {
        return false;
      }
      const proto = Object.getPrototypeOf(value2);
      return proto === null || Object.getPrototypeOf(proto) === null;
    }
    function valueToNode(value2) {
      if (value2 === void 0) {
        return (0, _generated.identifier)("undefined");
      }
      if (value2 === true || value2 === false) {
        return (0, _generated.booleanLiteral)(value2);
      }
      if (value2 === null) {
        return (0, _generated.nullLiteral)();
      }
      if (typeof value2 === "string") {
        return (0, _generated.stringLiteral)(value2);
      }
      if (typeof value2 === "number") {
        let result;
        if (Number.isFinite(value2)) {
          result = (0, _generated.numericLiteral)(Math.abs(value2));
        } else {
          let numerator;
          if (Number.isNaN(value2)) {
            numerator = (0, _generated.numericLiteral)(0);
          } else {
            numerator = (0, _generated.numericLiteral)(1);
          }
          result = (0, _generated.binaryExpression)("/", numerator, (0, _generated.numericLiteral)(0));
        }
        if (value2 < 0 || Object.is(value2, -0)) {
          result = (0, _generated.unaryExpression)("-", result);
        }
        return result;
      }
      if (isRegExp(value2)) {
        const pattern = value2.source;
        const flags = value2.toString().match(/\/([a-z]+|)$/)[1];
        return (0, _generated.regExpLiteral)(pattern, flags);
      }
      if (Array.isArray(value2)) {
        return (0, _generated.arrayExpression)(value2.map(valueToNode));
      }
      if (isPlainObject(value2)) {
        const props = [];
        for (const key of Object.keys(value2)) {
          let nodeKey;
          if ((0, _isValidIdentifier.default)(key)) {
            nodeKey = (0, _generated.identifier)(key);
          } else {
            nodeKey = (0, _generated.stringLiteral)(key);
          }
          props.push((0, _generated.objectProperty)(nodeKey, valueToNode(
            value2[key]
          )));
        }
        return (0, _generated.objectExpression)(props);
      }
      throw new Error("don't know how to turn this value into a node");
    }
  }
});

// node_modules/@babel/types/lib/modifications/appendToMemberExpression.js
var require_appendToMemberExpression = __commonJS({
  "node_modules/@babel/types/lib/modifications/appendToMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = appendToMemberExpression;
    var _generated = require_generated2();
    function appendToMemberExpression(member, append, computed = false) {
      member.object = (0, _generated.memberExpression)(member.object, member.property, member.computed);
      member.property = append;
      member.computed = !!computed;
      return member;
    }
  }
});

// node_modules/@babel/types/lib/modifications/inherits.js
var require_inherits2 = __commonJS({
  "node_modules/@babel/types/lib/modifications/inherits.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inherits;
    var _constants = require_constants2();
    var _inheritsComments = require_inheritsComments();
    function inherits(child, parent) {
      if (!child || !parent)
        return child;
      for (const key of _constants.INHERIT_KEYS.optional) {
        if (child[key] == null) {
          child[key] = parent[key];
        }
      }
      for (const key of Object.keys(parent)) {
        if (key[0] === "_" && key !== "__clone") {
          child[key] = parent[key];
        }
      }
      for (const key of _constants.INHERIT_KEYS.force) {
        child[key] = parent[key];
      }
      (0, _inheritsComments.default)(child, parent);
      return child;
    }
  }
});

// node_modules/@babel/types/lib/modifications/prependToMemberExpression.js
var require_prependToMemberExpression = __commonJS({
  "node_modules/@babel/types/lib/modifications/prependToMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = prependToMemberExpression;
    var _generated = require_generated2();
    var _ = require_lib11();
    function prependToMemberExpression(member, prepend) {
      if ((0, _.isSuper)(member.object)) {
        throw new Error("Cannot prepend node to super property access (`super.foo`).");
      }
      member.object = (0, _generated.memberExpression)(prepend, member.object);
      return member;
    }
  }
});

// node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js
var require_getOuterBindingIdentifiers = __commonJS({
  "node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _getBindingIdentifiers = require_getBindingIdentifiers();
    var _default = getOuterBindingIdentifiers;
    exports.default = _default;
    function getOuterBindingIdentifiers(node, duplicates) {
      return (0, _getBindingIdentifiers.default)(node, duplicates, true);
    }
  }
});

// node_modules/@babel/types/lib/traverse/traverse.js
var require_traverse = __commonJS({
  "node_modules/@babel/types/lib/traverse/traverse.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = traverse3;
    var _definitions = require_definitions();
    function traverse3(node, handlers, state) {
      if (typeof handlers === "function") {
        handlers = {
          enter: handlers
        };
      }
      const {
        enter,
        exit
      } = handlers;
      traverseSimpleImpl(node, enter, exit, state, []);
    }
    function traverseSimpleImpl(node, enter, exit, state, ancestors) {
      const keys3 = _definitions.VISITOR_KEYS[node.type];
      if (!keys3)
        return;
      if (enter)
        enter(node, ancestors, state);
      for (const key of keys3) {
        const subNode = node[key];
        if (Array.isArray(subNode)) {
          for (let i = 0; i < subNode.length; i++) {
            const child = subNode[i];
            if (!child)
              continue;
            ancestors.push({
              node,
              key,
              index: i
            });
            traverseSimpleImpl(child, enter, exit, state, ancestors);
            ancestors.pop();
          }
        } else if (subNode) {
          ancestors.push({
            node,
            key
          });
          traverseSimpleImpl(subNode, enter, exit, state, ancestors);
          ancestors.pop();
        }
      }
      if (exit)
        exit(node, ancestors, state);
    }
  }
});

// node_modules/@babel/types/lib/validators/isBinding.js
var require_isBinding = __commonJS({
  "node_modules/@babel/types/lib/validators/isBinding.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isBinding;
    var _getBindingIdentifiers = require_getBindingIdentifiers();
    function isBinding(node, parent, grandparent) {
      if (grandparent && node.type === "Identifier" && parent.type === "ObjectProperty" && grandparent.type === "ObjectExpression") {
        return false;
      }
      const keys3 = _getBindingIdentifiers.default.keys[parent.type];
      if (keys3) {
        for (let i = 0; i < keys3.length; i++) {
          const key = keys3[i];
          const val = parent[key];
          if (Array.isArray(val)) {
            if (val.indexOf(node) >= 0)
              return true;
          } else {
            if (val === node)
              return true;
          }
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/types/lib/validators/isLet.js
var require_isLet = __commonJS({
  "node_modules/@babel/types/lib/validators/isLet.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isLet;
    var _generated = require_generated();
    var _constants = require_constants2();
    function isLet(node) {
      return (0, _generated.isVariableDeclaration)(node) && (node.kind !== "var" || node[_constants.BLOCK_SCOPED_SYMBOL]);
    }
  }
});

// node_modules/@babel/types/lib/validators/isBlockScoped.js
var require_isBlockScoped = __commonJS({
  "node_modules/@babel/types/lib/validators/isBlockScoped.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isBlockScoped;
    var _generated = require_generated();
    var _isLet = require_isLet();
    function isBlockScoped(node) {
      return (0, _generated.isFunctionDeclaration)(node) || (0, _generated.isClassDeclaration)(node) || (0, _isLet.default)(node);
    }
  }
});

// node_modules/@babel/types/lib/validators/isImmutable.js
var require_isImmutable = __commonJS({
  "node_modules/@babel/types/lib/validators/isImmutable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isImmutable;
    var _isType = require_isType();
    var _generated = require_generated();
    function isImmutable(node) {
      if ((0, _isType.default)(node.type, "Immutable"))
        return true;
      if ((0, _generated.isIdentifier)(node)) {
        if (node.name === "undefined") {
          return true;
        } else {
          return false;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/types/lib/validators/isNodesEquivalent.js
var require_isNodesEquivalent = __commonJS({
  "node_modules/@babel/types/lib/validators/isNodesEquivalent.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isNodesEquivalent;
    var _definitions = require_definitions();
    function isNodesEquivalent(a, b) {
      if (typeof a !== "object" || typeof b !== "object" || a == null || b == null) {
        return a === b;
      }
      if (a.type !== b.type) {
        return false;
      }
      const fields = Object.keys(_definitions.NODE_FIELDS[a.type] || a.type);
      const visitorKeys = _definitions.VISITOR_KEYS[a.type];
      for (const field of fields) {
        const val_a = a[field];
        const val_b = b[field];
        if (typeof val_a !== typeof val_b) {
          return false;
        }
        if (val_a == null && val_b == null) {
          continue;
        } else if (val_a == null || val_b == null) {
          return false;
        }
        if (Array.isArray(val_a)) {
          if (!Array.isArray(val_b)) {
            return false;
          }
          if (val_a.length !== val_b.length) {
            return false;
          }
          for (let i = 0; i < val_a.length; i++) {
            if (!isNodesEquivalent(val_a[i], val_b[i])) {
              return false;
            }
          }
          continue;
        }
        if (typeof val_a === "object" && !(visitorKeys != null && visitorKeys.includes(field))) {
          for (const key of Object.keys(val_a)) {
            if (val_a[key] !== val_b[key]) {
              return false;
            }
          }
          continue;
        }
        if (!isNodesEquivalent(val_a, val_b)) {
          return false;
        }
      }
      return true;
    }
  }
});

// node_modules/@babel/types/lib/validators/isReferenced.js
var require_isReferenced = __commonJS({
  "node_modules/@babel/types/lib/validators/isReferenced.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isReferenced;
    function isReferenced(node, parent, grandparent) {
      switch (parent.type) {
        case "MemberExpression":
        case "OptionalMemberExpression":
          if (parent.property === node) {
            return !!parent.computed;
          }
          return parent.object === node;
        case "JSXMemberExpression":
          return parent.object === node;
        case "VariableDeclarator":
          return parent.init === node;
        case "ArrowFunctionExpression":
          return parent.body === node;
        case "PrivateName":
          return false;
        case "ClassMethod":
        case "ClassPrivateMethod":
        case "ObjectMethod":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return false;
        case "ObjectProperty":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return !grandparent || grandparent.type !== "ObjectPattern";
        case "ClassProperty":
        case "ClassAccessorProperty":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return true;
        case "ClassPrivateProperty":
          return parent.key !== node;
        case "ClassDeclaration":
        case "ClassExpression":
          return parent.superClass === node;
        case "AssignmentExpression":
          return parent.right === node;
        case "AssignmentPattern":
          return parent.right === node;
        case "LabeledStatement":
          return false;
        case "CatchClause":
          return false;
        case "RestElement":
          return false;
        case "BreakStatement":
        case "ContinueStatement":
          return false;
        case "FunctionDeclaration":
        case "FunctionExpression":
          return false;
        case "ExportNamespaceSpecifier":
        case "ExportDefaultSpecifier":
          return false;
        case "ExportSpecifier":
          if (grandparent != null && grandparent.source) {
            return false;
          }
          return parent.local === node;
        case "ImportDefaultSpecifier":
        case "ImportNamespaceSpecifier":
        case "ImportSpecifier":
          return false;
        case "ImportAttribute":
          return false;
        case "JSXAttribute":
          return false;
        case "ObjectPattern":
        case "ArrayPattern":
          return false;
        case "MetaProperty":
          return false;
        case "ObjectTypeProperty":
          return parent.key !== node;
        case "TSEnumMember":
          return parent.id !== node;
        case "TSPropertySignature":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return true;
      }
      return true;
    }
  }
});

// node_modules/@babel/types/lib/validators/isScope.js
var require_isScope = __commonJS({
  "node_modules/@babel/types/lib/validators/isScope.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isScope;
    var _generated = require_generated();
    function isScope(node, parent) {
      if ((0, _generated.isBlockStatement)(node) && ((0, _generated.isFunction)(parent) || (0, _generated.isCatchClause)(parent))) {
        return false;
      }
      if ((0, _generated.isPattern)(node) && ((0, _generated.isFunction)(parent) || (0, _generated.isCatchClause)(parent))) {
        return true;
      }
      return (0, _generated.isScopable)(node);
    }
  }
});

// node_modules/@babel/types/lib/validators/isSpecifierDefault.js
var require_isSpecifierDefault = __commonJS({
  "node_modules/@babel/types/lib/validators/isSpecifierDefault.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isSpecifierDefault;
    var _generated = require_generated();
    function isSpecifierDefault(specifier) {
      return (0, _generated.isImportDefaultSpecifier)(specifier) || (0, _generated.isIdentifier)(specifier.imported || specifier.exported, {
        name: "default"
      });
    }
  }
});

// node_modules/@babel/types/lib/validators/isValidES3Identifier.js
var require_isValidES3Identifier = __commonJS({
  "node_modules/@babel/types/lib/validators/isValidES3Identifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isValidES3Identifier;
    var _isValidIdentifier = require_isValidIdentifier();
    var RESERVED_WORDS_ES3_ONLY = /* @__PURE__ */ new Set(["abstract", "boolean", "byte", "char", "double", "enum", "final", "float", "goto", "implements", "int", "interface", "long", "native", "package", "private", "protected", "public", "short", "static", "synchronized", "throws", "transient", "volatile"]);
    function isValidES3Identifier(name) {
      return (0, _isValidIdentifier.default)(name) && !RESERVED_WORDS_ES3_ONLY.has(name);
    }
  }
});

// node_modules/@babel/types/lib/validators/isVar.js
var require_isVar = __commonJS({
  "node_modules/@babel/types/lib/validators/isVar.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isVar;
    var _generated = require_generated();
    var _constants = require_constants2();
    function isVar(node) {
      return (0, _generated.isVariableDeclaration)(node, {
        kind: "var"
      }) && !node[_constants.BLOCK_SCOPED_SYMBOL];
    }
  }
});

// node_modules/@babel/types/lib/ast-types/generated/index.js
var require_generated5 = __commonJS({
  "node_modules/@babel/types/lib/ast-types/generated/index.js"() {
  }
});

// node_modules/@babel/types/lib/index.js
var require_lib11 = __commonJS({
  "node_modules/@babel/types/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    var _exportNames = {
      react: true,
      assertNode: true,
      createTypeAnnotationBasedOnTypeof: true,
      createUnionTypeAnnotation: true,
      createFlowUnionType: true,
      createTSUnionType: true,
      cloneNode: true,
      clone: true,
      cloneDeep: true,
      cloneDeepWithoutLoc: true,
      cloneWithoutLoc: true,
      addComment: true,
      addComments: true,
      inheritInnerComments: true,
      inheritLeadingComments: true,
      inheritsComments: true,
      inheritTrailingComments: true,
      removeComments: true,
      ensureBlock: true,
      toBindingIdentifierName: true,
      toBlock: true,
      toComputedKey: true,
      toExpression: true,
      toIdentifier: true,
      toKeyAlias: true,
      toSequenceExpression: true,
      toStatement: true,
      valueToNode: true,
      appendToMemberExpression: true,
      inherits: true,
      prependToMemberExpression: true,
      removeProperties: true,
      removePropertiesDeep: true,
      removeTypeDuplicates: true,
      getBindingIdentifiers: true,
      getOuterBindingIdentifiers: true,
      traverse: true,
      traverseFast: true,
      shallowEqual: true,
      is: true,
      isBinding: true,
      isBlockScoped: true,
      isImmutable: true,
      isLet: true,
      isNode: true,
      isNodesEquivalent: true,
      isPlaceholderType: true,
      isReferenced: true,
      isScope: true,
      isSpecifierDefault: true,
      isType: true,
      isValidES3Identifier: true,
      isValidIdentifier: true,
      isVar: true,
      matchesPattern: true,
      validate: true,
      buildMatchMemberExpression: true
    };
    Object.defineProperty(exports, "addComment", {
      enumerable: true,
      get: function() {
        return _addComment.default;
      }
    });
    Object.defineProperty(exports, "addComments", {
      enumerable: true,
      get: function() {
        return _addComments.default;
      }
    });
    Object.defineProperty(exports, "appendToMemberExpression", {
      enumerable: true,
      get: function() {
        return _appendToMemberExpression.default;
      }
    });
    Object.defineProperty(exports, "assertNode", {
      enumerable: true,
      get: function() {
        return _assertNode.default;
      }
    });
    Object.defineProperty(exports, "buildMatchMemberExpression", {
      enumerable: true,
      get: function() {
        return _buildMatchMemberExpression.default;
      }
    });
    Object.defineProperty(exports, "clone", {
      enumerable: true,
      get: function() {
        return _clone.default;
      }
    });
    Object.defineProperty(exports, "cloneDeep", {
      enumerable: true,
      get: function() {
        return _cloneDeep.default;
      }
    });
    Object.defineProperty(exports, "cloneDeepWithoutLoc", {
      enumerable: true,
      get: function() {
        return _cloneDeepWithoutLoc.default;
      }
    });
    Object.defineProperty(exports, "cloneNode", {
      enumerable: true,
      get: function() {
        return _cloneNode.default;
      }
    });
    Object.defineProperty(exports, "cloneWithoutLoc", {
      enumerable: true,
      get: function() {
        return _cloneWithoutLoc.default;
      }
    });
    Object.defineProperty(exports, "createFlowUnionType", {
      enumerable: true,
      get: function() {
        return _createFlowUnionType.default;
      }
    });
    Object.defineProperty(exports, "createTSUnionType", {
      enumerable: true,
      get: function() {
        return _createTSUnionType.default;
      }
    });
    Object.defineProperty(exports, "createTypeAnnotationBasedOnTypeof", {
      enumerable: true,
      get: function() {
        return _createTypeAnnotationBasedOnTypeof.default;
      }
    });
    Object.defineProperty(exports, "createUnionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _createFlowUnionType.default;
      }
    });
    Object.defineProperty(exports, "ensureBlock", {
      enumerable: true,
      get: function() {
        return _ensureBlock.default;
      }
    });
    Object.defineProperty(exports, "getBindingIdentifiers", {
      enumerable: true,
      get: function() {
        return _getBindingIdentifiers.default;
      }
    });
    Object.defineProperty(exports, "getOuterBindingIdentifiers", {
      enumerable: true,
      get: function() {
        return _getOuterBindingIdentifiers.default;
      }
    });
    Object.defineProperty(exports, "inheritInnerComments", {
      enumerable: true,
      get: function() {
        return _inheritInnerComments.default;
      }
    });
    Object.defineProperty(exports, "inheritLeadingComments", {
      enumerable: true,
      get: function() {
        return _inheritLeadingComments.default;
      }
    });
    Object.defineProperty(exports, "inheritTrailingComments", {
      enumerable: true,
      get: function() {
        return _inheritTrailingComments.default;
      }
    });
    Object.defineProperty(exports, "inherits", {
      enumerable: true,
      get: function() {
        return _inherits.default;
      }
    });
    Object.defineProperty(exports, "inheritsComments", {
      enumerable: true,
      get: function() {
        return _inheritsComments.default;
      }
    });
    Object.defineProperty(exports, "is", {
      enumerable: true,
      get: function() {
        return _is.default;
      }
    });
    Object.defineProperty(exports, "isBinding", {
      enumerable: true,
      get: function() {
        return _isBinding.default;
      }
    });
    Object.defineProperty(exports, "isBlockScoped", {
      enumerable: true,
      get: function() {
        return _isBlockScoped.default;
      }
    });
    Object.defineProperty(exports, "isImmutable", {
      enumerable: true,
      get: function() {
        return _isImmutable.default;
      }
    });
    Object.defineProperty(exports, "isLet", {
      enumerable: true,
      get: function() {
        return _isLet.default;
      }
    });
    Object.defineProperty(exports, "isNode", {
      enumerable: true,
      get: function() {
        return _isNode.default;
      }
    });
    Object.defineProperty(exports, "isNodesEquivalent", {
      enumerable: true,
      get: function() {
        return _isNodesEquivalent.default;
      }
    });
    Object.defineProperty(exports, "isPlaceholderType", {
      enumerable: true,
      get: function() {
        return _isPlaceholderType.default;
      }
    });
    Object.defineProperty(exports, "isReferenced", {
      enumerable: true,
      get: function() {
        return _isReferenced.default;
      }
    });
    Object.defineProperty(exports, "isScope", {
      enumerable: true,
      get: function() {
        return _isScope.default;
      }
    });
    Object.defineProperty(exports, "isSpecifierDefault", {
      enumerable: true,
      get: function() {
        return _isSpecifierDefault.default;
      }
    });
    Object.defineProperty(exports, "isType", {
      enumerable: true,
      get: function() {
        return _isType.default;
      }
    });
    Object.defineProperty(exports, "isValidES3Identifier", {
      enumerable: true,
      get: function() {
        return _isValidES3Identifier.default;
      }
    });
    Object.defineProperty(exports, "isValidIdentifier", {
      enumerable: true,
      get: function() {
        return _isValidIdentifier.default;
      }
    });
    Object.defineProperty(exports, "isVar", {
      enumerable: true,
      get: function() {
        return _isVar.default;
      }
    });
    Object.defineProperty(exports, "matchesPattern", {
      enumerable: true,
      get: function() {
        return _matchesPattern.default;
      }
    });
    Object.defineProperty(exports, "prependToMemberExpression", {
      enumerable: true,
      get: function() {
        return _prependToMemberExpression.default;
      }
    });
    exports.react = void 0;
    Object.defineProperty(exports, "removeComments", {
      enumerable: true,
      get: function() {
        return _removeComments.default;
      }
    });
    Object.defineProperty(exports, "removeProperties", {
      enumerable: true,
      get: function() {
        return _removeProperties.default;
      }
    });
    Object.defineProperty(exports, "removePropertiesDeep", {
      enumerable: true,
      get: function() {
        return _removePropertiesDeep.default;
      }
    });
    Object.defineProperty(exports, "removeTypeDuplicates", {
      enumerable: true,
      get: function() {
        return _removeTypeDuplicates.default;
      }
    });
    Object.defineProperty(exports, "shallowEqual", {
      enumerable: true,
      get: function() {
        return _shallowEqual.default;
      }
    });
    Object.defineProperty(exports, "toBindingIdentifierName", {
      enumerable: true,
      get: function() {
        return _toBindingIdentifierName.default;
      }
    });
    Object.defineProperty(exports, "toBlock", {
      enumerable: true,
      get: function() {
        return _toBlock.default;
      }
    });
    Object.defineProperty(exports, "toComputedKey", {
      enumerable: true,
      get: function() {
        return _toComputedKey.default;
      }
    });
    Object.defineProperty(exports, "toExpression", {
      enumerable: true,
      get: function() {
        return _toExpression.default;
      }
    });
    Object.defineProperty(exports, "toIdentifier", {
      enumerable: true,
      get: function() {
        return _toIdentifier.default;
      }
    });
    Object.defineProperty(exports, "toKeyAlias", {
      enumerable: true,
      get: function() {
        return _toKeyAlias.default;
      }
    });
    Object.defineProperty(exports, "toSequenceExpression", {
      enumerable: true,
      get: function() {
        return _toSequenceExpression.default;
      }
    });
    Object.defineProperty(exports, "toStatement", {
      enumerable: true,
      get: function() {
        return _toStatement.default;
      }
    });
    Object.defineProperty(exports, "traverse", {
      enumerable: true,
      get: function() {
        return _traverse.default;
      }
    });
    Object.defineProperty(exports, "traverseFast", {
      enumerable: true,
      get: function() {
        return _traverseFast.default;
      }
    });
    Object.defineProperty(exports, "validate", {
      enumerable: true,
      get: function() {
        return _validate.default;
      }
    });
    Object.defineProperty(exports, "valueToNode", {
      enumerable: true,
      get: function() {
        return _valueToNode.default;
      }
    });
    var _isReactComponent = require_isReactComponent();
    var _isCompatTag = require_isCompatTag();
    var _buildChildren = require_buildChildren();
    var _assertNode = require_assertNode();
    var _generated = require_generated3();
    Object.keys(_generated).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _generated[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _generated[key];
        }
      });
    });
    var _createTypeAnnotationBasedOnTypeof = require_createTypeAnnotationBasedOnTypeof();
    var _createFlowUnionType = require_createFlowUnionType();
    var _createTSUnionType = require_createTSUnionType();
    var _generated2 = require_generated2();
    Object.keys(_generated2).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _generated2[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _generated2[key];
        }
      });
    });
    var _uppercase = require_uppercase();
    Object.keys(_uppercase).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _uppercase[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _uppercase[key];
        }
      });
    });
    var _cloneNode = require_cloneNode();
    var _clone = require_clone3();
    var _cloneDeep = require_cloneDeep();
    var _cloneDeepWithoutLoc = require_cloneDeepWithoutLoc();
    var _cloneWithoutLoc = require_cloneWithoutLoc();
    var _addComment = require_addComment();
    var _addComments = require_addComments();
    var _inheritInnerComments = require_inheritInnerComments();
    var _inheritLeadingComments = require_inheritLeadingComments();
    var _inheritsComments = require_inheritsComments();
    var _inheritTrailingComments = require_inheritTrailingComments();
    var _removeComments = require_removeComments();
    var _generated3 = require_generated4();
    Object.keys(_generated3).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _generated3[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _generated3[key];
        }
      });
    });
    var _constants = require_constants2();
    Object.keys(_constants).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _constants[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _constants[key];
        }
      });
    });
    var _ensureBlock = require_ensureBlock();
    var _toBindingIdentifierName = require_toBindingIdentifierName();
    var _toBlock = require_toBlock();
    var _toComputedKey = require_toComputedKey();
    var _toExpression = require_toExpression();
    var _toIdentifier = require_toIdentifier();
    var _toKeyAlias = require_toKeyAlias();
    var _toSequenceExpression = require_toSequenceExpression();
    var _toStatement = require_toStatement();
    var _valueToNode = require_valueToNode();
    var _definitions = require_definitions();
    Object.keys(_definitions).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _definitions[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _definitions[key];
        }
      });
    });
    var _appendToMemberExpression = require_appendToMemberExpression();
    var _inherits = require_inherits2();
    var _prependToMemberExpression = require_prependToMemberExpression();
    var _removeProperties = require_removeProperties();
    var _removePropertiesDeep = require_removePropertiesDeep();
    var _removeTypeDuplicates = require_removeTypeDuplicates();
    var _getBindingIdentifiers = require_getBindingIdentifiers();
    var _getOuterBindingIdentifiers = require_getOuterBindingIdentifiers();
    var _traverse = require_traverse();
    Object.keys(_traverse).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _traverse[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _traverse[key];
        }
      });
    });
    var _traverseFast = require_traverseFast();
    var _shallowEqual = require_shallowEqual();
    var _is = require_is();
    var _isBinding = require_isBinding();
    var _isBlockScoped = require_isBlockScoped();
    var _isImmutable = require_isImmutable();
    var _isLet = require_isLet();
    var _isNode = require_isNode();
    var _isNodesEquivalent = require_isNodesEquivalent();
    var _isPlaceholderType = require_isPlaceholderType();
    var _isReferenced = require_isReferenced();
    var _isScope = require_isScope();
    var _isSpecifierDefault = require_isSpecifierDefault();
    var _isType = require_isType();
    var _isValidES3Identifier = require_isValidES3Identifier();
    var _isValidIdentifier = require_isValidIdentifier();
    var _isVar = require_isVar();
    var _matchesPattern = require_matchesPattern();
    var _validate = require_validate2();
    var _buildMatchMemberExpression = require_buildMatchMemberExpression();
    var _generated4 = require_generated();
    Object.keys(_generated4).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _generated4[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _generated4[key];
        }
      });
    });
    var _generated5 = require_generated5();
    Object.keys(_generated5).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _generated5[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _generated5[key];
        }
      });
    });
    var react = {
      isReactComponent: _isReactComponent.default,
      isCompatTag: _isCompatTag.default,
      buildChildren: _buildChildren.default
    };
    exports.react = react;
  }
});

// node_modules/@babel/traverse/lib/visitors.js
var require_visitors = __commonJS({
  "node_modules/@babel/traverse/lib/visitors.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.explode = explode;
    exports.merge = merge4;
    exports.verify = verify;
    var virtualTypes = require_virtual_types();
    var _t = require_lib11();
    var {
      DEPRECATED_KEYS,
      FLIPPED_ALIAS_KEYS,
      TYPES
    } = _t;
    function isVirtualType(type) {
      return type in virtualTypes;
    }
    function explode(visitor) {
      if (visitor._exploded)
        return visitor;
      visitor._exploded = true;
      for (const nodeType of Object.keys(visitor)) {
        if (shouldIgnoreKey(nodeType))
          continue;
        const parts = nodeType.split("|");
        if (parts.length === 1)
          continue;
        const fns = visitor[nodeType];
        delete visitor[nodeType];
        for (const part of parts) {
          visitor[part] = fns;
        }
      }
      verify(visitor);
      delete visitor.__esModule;
      ensureEntranceObjects(visitor);
      ensureCallbackArrays(visitor);
      for (const nodeType of Object.keys(visitor)) {
        if (shouldIgnoreKey(nodeType))
          continue;
        if (!isVirtualType(nodeType))
          continue;
        const fns = visitor[nodeType];
        for (const type of Object.keys(fns)) {
          fns[type] = wrapCheck(nodeType, fns[type]);
        }
        delete visitor[nodeType];
        const types = virtualTypes[nodeType];
        if (types !== null) {
          for (const type of types) {
            if (visitor[type]) {
              mergePair(visitor[type], fns);
            } else {
              visitor[type] = fns;
            }
          }
        } else {
          mergePair(visitor, fns);
        }
      }
      for (const nodeType of Object.keys(visitor)) {
        if (shouldIgnoreKey(nodeType))
          continue;
        const fns = visitor[nodeType];
        let aliases = FLIPPED_ALIAS_KEYS[nodeType];
        const deprecatedKey = DEPRECATED_KEYS[nodeType];
        if (deprecatedKey) {
          console.trace(`Visitor defined for ${nodeType} but it has been renamed to ${deprecatedKey}`);
          aliases = [deprecatedKey];
        }
        if (!aliases)
          continue;
        delete visitor[nodeType];
        for (const alias of aliases) {
          const existing = visitor[alias];
          if (existing) {
            mergePair(existing, fns);
          } else {
            visitor[alias] = Object.assign({}, fns);
          }
        }
      }
      for (const nodeType of Object.keys(visitor)) {
        if (shouldIgnoreKey(nodeType))
          continue;
        ensureCallbackArrays(visitor[nodeType]);
      }
      return visitor;
    }
    function verify(visitor) {
      if (visitor._verified)
        return;
      if (typeof visitor === "function") {
        throw new Error("You passed `traverse()` a function when it expected a visitor object, are you sure you didn't mean `{ enter: Function }`?");
      }
      for (const nodeType of Object.keys(visitor)) {
        if (nodeType === "enter" || nodeType === "exit") {
          validateVisitorMethods(nodeType, visitor[nodeType]);
        }
        if (shouldIgnoreKey(nodeType))
          continue;
        if (TYPES.indexOf(nodeType) < 0) {
          throw new Error(`You gave us a visitor for the node type ${nodeType} but it's not a valid type`);
        }
        const visitors = visitor[nodeType];
        if (typeof visitors === "object") {
          for (const visitorKey of Object.keys(visitors)) {
            if (visitorKey === "enter" || visitorKey === "exit") {
              validateVisitorMethods(`${nodeType}.${visitorKey}`, visitors[visitorKey]);
            } else {
              throw new Error(`You passed \`traverse()\` a visitor object with the property ${nodeType} that has the invalid property ${visitorKey}`);
            }
          }
        }
      }
      visitor._verified = true;
    }
    function validateVisitorMethods(path2, val) {
      const fns = [].concat(val);
      for (const fn of fns) {
        if (typeof fn !== "function") {
          throw new TypeError(`Non-function found defined in ${path2} with type ${typeof fn}`);
        }
      }
    }
    function merge4(visitors, states = [], wrapper) {
      const rootVisitor = {};
      for (let i = 0; i < visitors.length; i++) {
        const visitor = visitors[i];
        const state = states[i];
        explode(visitor);
        for (const type of Object.keys(visitor)) {
          let visitorType = visitor[type];
          if (state || wrapper) {
            visitorType = wrapWithStateOrWrapper(visitorType, state, wrapper);
          }
          const nodeVisitor = rootVisitor[type] || (rootVisitor[type] = {});
          mergePair(nodeVisitor, visitorType);
        }
      }
      return rootVisitor;
    }
    function wrapWithStateOrWrapper(oldVisitor, state, wrapper) {
      const newVisitor = {};
      for (const key of Object.keys(oldVisitor)) {
        let fns = oldVisitor[key];
        if (!Array.isArray(fns))
          continue;
        fns = fns.map(function(fn) {
          let newFn = fn;
          if (state) {
            newFn = function(path2) {
              return fn.call(state, path2, state);
            };
          }
          if (wrapper) {
            newFn = wrapper(state.key, key, newFn);
          }
          if (newFn !== fn) {
            newFn.toString = () => fn.toString();
          }
          return newFn;
        });
        newVisitor[key] = fns;
      }
      return newVisitor;
    }
    function ensureEntranceObjects(obj) {
      for (const key of Object.keys(obj)) {
        if (shouldIgnoreKey(key))
          continue;
        const fns = obj[key];
        if (typeof fns === "function") {
          obj[key] = {
            enter: fns
          };
        }
      }
    }
    function ensureCallbackArrays(obj) {
      if (obj.enter && !Array.isArray(obj.enter))
        obj.enter = [obj.enter];
      if (obj.exit && !Array.isArray(obj.exit))
        obj.exit = [obj.exit];
    }
    function wrapCheck(nodeType, fn) {
      const newFn = function(path2) {
        if (path2[`is${nodeType}`]()) {
          return fn.apply(this, arguments);
        }
      };
      newFn.toString = () => fn.toString();
      return newFn;
    }
    function shouldIgnoreKey(key) {
      if (key[0] === "_")
        return true;
      if (key === "enter" || key === "exit" || key === "shouldSkip")
        return true;
      if (key === "denylist" || key === "noScope" || key === "skipKeys" || key === "blacklist") {
        return true;
      }
      return false;
    }
    function mergePair(dest, src) {
      for (const key of Object.keys(src)) {
        dest[key] = [].concat(dest[key] || [], src[key]);
      }
    }
  }
});

// node_modules/@babel/traverse/lib/cache.js
var require_cache4 = __commonJS({
  "node_modules/@babel/traverse/lib/cache.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.clear = clear;
    exports.clearPath = clearPath;
    exports.clearScope = clearScope;
    exports.scope = exports.path = void 0;
    var path2 = /* @__PURE__ */ new WeakMap();
    exports.path = path2;
    var scope = /* @__PURE__ */ new WeakMap();
    exports.scope = scope;
    function clear() {
      clearPath();
      clearScope();
    }
    function clearPath() {
      exports.path = path2 = /* @__PURE__ */ new WeakMap();
    }
    function clearScope() {
      exports.scope = scope = /* @__PURE__ */ new WeakMap();
    }
  }
});

// node_modules/@babel/helper-split-export-declaration/lib/index.js
var require_lib12 = __commonJS({
  "node_modules/@babel/helper-split-export-declaration/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = splitExportDeclaration;
    var _t = require_lib11();
    var {
      cloneNode,
      exportNamedDeclaration,
      exportSpecifier,
      identifier: identifier3,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t;
    function splitExportDeclaration(exportDeclaration) {
      if (!exportDeclaration.isExportDeclaration() || exportDeclaration.isExportAllDeclaration()) {
        throw new Error("Only default and named export declarations can be split.");
      }
      if (exportDeclaration.isExportDefaultDeclaration()) {
        const declaration2 = exportDeclaration.get("declaration");
        const standaloneDeclaration = declaration2.isFunctionDeclaration() || declaration2.isClassDeclaration();
        const scope = declaration2.isScope() ? declaration2.scope.parent : declaration2.scope;
        let id = declaration2.node.id;
        let needBindingRegistration = false;
        if (!id) {
          needBindingRegistration = true;
          id = scope.generateUidIdentifier("default");
          if (standaloneDeclaration || declaration2.isFunctionExpression() || declaration2.isClassExpression()) {
            declaration2.node.id = cloneNode(id);
          }
        }
        const updatedDeclaration = standaloneDeclaration ? declaration2.node : variableDeclaration2("var", [variableDeclarator2(cloneNode(id), declaration2.node)]);
        const updatedExportDeclaration = exportNamedDeclaration(null, [exportSpecifier(cloneNode(id), identifier3("default"))]);
        exportDeclaration.insertAfter(updatedExportDeclaration);
        exportDeclaration.replaceWith(updatedDeclaration);
        if (needBindingRegistration) {
          scope.registerDeclaration(exportDeclaration);
        }
        return exportDeclaration;
      } else if (exportDeclaration.get("specifiers").length > 0) {
        throw new Error("It doesn't make sense to split exported specifiers.");
      }
      const declaration = exportDeclaration.get("declaration");
      const bindingIdentifiers = declaration.getOuterBindingIdentifiers();
      const specifiers = Object.keys(bindingIdentifiers).map((name) => {
        return exportSpecifier(identifier3(name), identifier3(name));
      });
      const aliasDeclar = exportNamedDeclaration(null, specifiers);
      exportDeclaration.insertAfter(aliasDeclar);
      exportDeclaration.replaceWith(declaration.node);
      return exportDeclaration;
    }
  }
});

// node_modules/@babel/helper-environment-visitor/lib/index.js
var require_lib13 = __commonJS({
  "node_modules/@babel/helper-environment-visitor/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    exports.requeueComputedKeyAndDecorators = requeueComputedKeyAndDecorators;
    exports.skipAllButComputedKey = skipAllButComputedKey;
    function skipAllButComputedKey(path2) {
      path2.skip();
      if (path2.node.computed) {
        path2.context.maybeQueue(path2.get("key"));
      }
    }
    function requeueComputedKeyAndDecorators(path2) {
      const {
        context,
        node
      } = path2;
      if (node.computed) {
        context.maybeQueue(path2.get("key"));
      }
      if (node.decorators) {
        for (const decorator of path2.get("decorators")) {
          context.maybeQueue(decorator);
        }
      }
    }
    var visitor = {
      FunctionParent(path2) {
        if (path2.isArrowFunctionExpression()) {
          return;
        } else {
          path2.skip();
          if (path2.isMethod()) {
            requeueComputedKeyAndDecorators(path2);
          }
        }
      },
      Property(path2) {
        if (path2.isObjectProperty()) {
          return;
        }
        path2.skip();
        requeueComputedKeyAndDecorators(path2);
      }
    };
    var _default = visitor;
    exports.default = _default;
  }
});

// node_modules/@babel/traverse/lib/scope/lib/renamer.js
var require_renamer = __commonJS({
  "node_modules/@babel/traverse/lib/scope/lib/renamer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _helperSplitExportDeclaration = require_lib12();
    var t3 = require_lib11();
    var _helperEnvironmentVisitor = require_lib13();
    var _traverseNode = require_traverse_node();
    var _visitors = require_visitors();
    var renameVisitor = {
      ReferencedIdentifier({
        node
      }, state) {
        if (node.name === state.oldName) {
          node.name = state.newName;
        }
      },
      Scope(path2, state) {
        if (!path2.scope.bindingIdentifierEquals(state.oldName, state.binding.identifier)) {
          path2.skip();
          if (path2.isMethod()) {
            (0, _helperEnvironmentVisitor.requeueComputedKeyAndDecorators)(path2);
          }
        }
      },
      "AssignmentExpression|Declaration|VariableDeclarator"(path2, state) {
        if (path2.isVariableDeclaration())
          return;
        const ids = path2.getOuterBindingIdentifiers();
        for (const name in ids) {
          if (name === state.oldName)
            ids[name].name = state.newName;
        }
      }
    };
    var Renamer = class {
      constructor(binding, oldName, newName) {
        this.newName = newName;
        this.oldName = oldName;
        this.binding = binding;
      }
      maybeConvertFromExportDeclaration(parentDeclar) {
        const maybeExportDeclar = parentDeclar.parentPath;
        if (!maybeExportDeclar.isExportDeclaration()) {
          return;
        }
        if (maybeExportDeclar.isExportDefaultDeclaration()) {
          const {
            declaration
          } = maybeExportDeclar.node;
          if (t3.isDeclaration(declaration) && !declaration.id) {
            return;
          }
        }
        if (maybeExportDeclar.isExportAllDeclaration()) {
          return;
        }
        (0, _helperSplitExportDeclaration.default)(maybeExportDeclar);
      }
      maybeConvertFromClassFunctionDeclaration(path2) {
        return path2;
      }
      maybeConvertFromClassFunctionExpression(path2) {
        return path2;
      }
      rename(block) {
        const {
          binding,
          oldName,
          newName
        } = this;
        const {
          scope,
          path: path2
        } = binding;
        const parentDeclar = path2.find((path3) => path3.isDeclaration() || path3.isFunctionExpression() || path3.isClassExpression());
        if (parentDeclar) {
          const bindingIds = parentDeclar.getOuterBindingIdentifiers();
          if (bindingIds[oldName] === binding.identifier) {
            this.maybeConvertFromExportDeclaration(parentDeclar);
          }
        }
        (0, _traverseNode.traverseNode)(block || scope.block, (0, _visitors.explode)(renameVisitor), scope, this, scope.path, {
          discriminant: true
        });
        if (!block) {
          scope.removeOwnBinding(oldName);
          scope.bindings[newName] = binding;
          this.binding.identifier.name = newName;
        }
        if (parentDeclar) {
          this.maybeConvertFromClassFunctionDeclaration(path2);
          this.maybeConvertFromClassFunctionExpression(path2);
        }
      }
    };
    exports.default = Renamer;
  }
});

// node_modules/@babel/traverse/lib/scope/binding.js
var require_binding = __commonJS({
  "node_modules/@babel/traverse/lib/scope/binding.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var Binding = class {
      constructor({
        identifier: identifier3,
        scope,
        path: path2,
        kind
      }) {
        this.identifier = void 0;
        this.scope = void 0;
        this.path = void 0;
        this.kind = void 0;
        this.constantViolations = [];
        this.constant = true;
        this.referencePaths = [];
        this.referenced = false;
        this.references = 0;
        this.identifier = identifier3;
        this.scope = scope;
        this.path = path2;
        this.kind = kind;
        if ((kind === "var" || kind === "hoisted") && isDeclaredInLoop(path2 || (() => {
          throw new Error("Internal Babel error: unreachable ");
        })())) {
          this.reassign(path2);
        }
        this.clearValue();
      }
      deoptValue() {
        this.clearValue();
        this.hasDeoptedValue = true;
      }
      setValue(value2) {
        if (this.hasDeoptedValue)
          return;
        this.hasValue = true;
        this.value = value2;
      }
      clearValue() {
        this.hasDeoptedValue = false;
        this.hasValue = false;
        this.value = null;
      }
      reassign(path2) {
        this.constant = false;
        if (this.constantViolations.indexOf(path2) !== -1) {
          return;
        }
        this.constantViolations.push(path2);
      }
      reference(path2) {
        if (this.referencePaths.indexOf(path2) !== -1) {
          return;
        }
        this.referenced = true;
        this.references++;
        this.referencePaths.push(path2);
      }
      dereference() {
        this.references--;
        this.referenced = !!this.references;
      }
    };
    exports.default = Binding;
    function isDeclaredInLoop(path2) {
      for (let {
        parentPath,
        key
      } = path2; parentPath; {
        parentPath,
        key
      } = parentPath) {
        if (parentPath.isFunctionParent())
          return false;
        if (parentPath.isWhile() || parentPath.isForXStatement() || parentPath.isForStatement() && key === "body") {
          return true;
        }
      }
      return false;
    }
  }
});

// node_modules/globals/globals.json
var require_globals6 = __commonJS({
  "node_modules/globals/globals.json"(exports, module2) {
    module2.exports = {
      builtin: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        BigInt: false,
        BigInt64Array: false,
        BigUint64Array: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        globalThis: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es5: {
        Array: false,
        Boolean: false,
        constructor: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        propertyIsEnumerable: false,
        RangeError: false,
        ReferenceError: false,
        RegExp: false,
        String: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false
      },
      es2015: {
        Array: false,
        ArrayBuffer: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      es2017: {
        Array: false,
        ArrayBuffer: false,
        Atomics: false,
        Boolean: false,
        constructor: false,
        DataView: false,
        Date: false,
        decodeURI: false,
        decodeURIComponent: false,
        encodeURI: false,
        encodeURIComponent: false,
        Error: false,
        escape: false,
        eval: false,
        EvalError: false,
        Float32Array: false,
        Float64Array: false,
        Function: false,
        hasOwnProperty: false,
        Infinity: false,
        Int16Array: false,
        Int32Array: false,
        Int8Array: false,
        isFinite: false,
        isNaN: false,
        isPrototypeOf: false,
        JSON: false,
        Map: false,
        Math: false,
        NaN: false,
        Number: false,
        Object: false,
        parseFloat: false,
        parseInt: false,
        Promise: false,
        propertyIsEnumerable: false,
        Proxy: false,
        RangeError: false,
        ReferenceError: false,
        Reflect: false,
        RegExp: false,
        Set: false,
        SharedArrayBuffer: false,
        String: false,
        Symbol: false,
        SyntaxError: false,
        toLocaleString: false,
        toString: false,
        TypeError: false,
        Uint16Array: false,
        Uint32Array: false,
        Uint8Array: false,
        Uint8ClampedArray: false,
        undefined: false,
        unescape: false,
        URIError: false,
        valueOf: false,
        WeakMap: false,
        WeakSet: false
      },
      browser: {
        AbortController: false,
        AbortSignal: false,
        addEventListener: false,
        alert: false,
        AnalyserNode: false,
        Animation: false,
        AnimationEffectReadOnly: false,
        AnimationEffectTiming: false,
        AnimationEffectTimingReadOnly: false,
        AnimationEvent: false,
        AnimationPlaybackEvent: false,
        AnimationTimeline: false,
        applicationCache: false,
        ApplicationCache: false,
        ApplicationCacheErrorEvent: false,
        atob: false,
        Attr: false,
        Audio: false,
        AudioBuffer: false,
        AudioBufferSourceNode: false,
        AudioContext: false,
        AudioDestinationNode: false,
        AudioListener: false,
        AudioNode: false,
        AudioParam: false,
        AudioProcessingEvent: false,
        AudioScheduledSourceNode: false,
        "AudioWorkletGlobalScope ": false,
        AudioWorkletNode: false,
        AudioWorkletProcessor: false,
        BarProp: false,
        BaseAudioContext: false,
        BatteryManager: false,
        BeforeUnloadEvent: false,
        BiquadFilterNode: false,
        Blob: false,
        BlobEvent: false,
        blur: false,
        BroadcastChannel: false,
        btoa: false,
        BudgetService: false,
        ByteLengthQueuingStrategy: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        cancelAnimationFrame: false,
        cancelIdleCallback: false,
        CanvasCaptureMediaStreamTrack: false,
        CanvasGradient: false,
        CanvasPattern: false,
        CanvasRenderingContext2D: false,
        ChannelMergerNode: false,
        ChannelSplitterNode: false,
        CharacterData: false,
        clearInterval: false,
        clearTimeout: false,
        clientInformation: false,
        ClipboardEvent: false,
        close: false,
        closed: false,
        CloseEvent: false,
        Comment: false,
        CompositionEvent: false,
        confirm: false,
        console: false,
        ConstantSourceNode: false,
        ConvolverNode: false,
        CountQueuingStrategy: false,
        createImageBitmap: false,
        Credential: false,
        CredentialsContainer: false,
        crypto: false,
        Crypto: false,
        CryptoKey: false,
        CSS: false,
        CSSConditionRule: false,
        CSSFontFaceRule: false,
        CSSGroupingRule: false,
        CSSImportRule: false,
        CSSKeyframeRule: false,
        CSSKeyframesRule: false,
        CSSMediaRule: false,
        CSSNamespaceRule: false,
        CSSPageRule: false,
        CSSRule: false,
        CSSRuleList: false,
        CSSStyleDeclaration: false,
        CSSStyleRule: false,
        CSSStyleSheet: false,
        CSSSupportsRule: false,
        CustomElementRegistry: false,
        customElements: false,
        CustomEvent: false,
        DataTransfer: false,
        DataTransferItem: false,
        DataTransferItemList: false,
        defaultstatus: false,
        defaultStatus: false,
        DelayNode: false,
        DeviceMotionEvent: false,
        DeviceOrientationEvent: false,
        devicePixelRatio: false,
        dispatchEvent: false,
        document: false,
        Document: false,
        DocumentFragment: false,
        DocumentType: false,
        DOMError: false,
        DOMException: false,
        DOMImplementation: false,
        DOMMatrix: false,
        DOMMatrixReadOnly: false,
        DOMParser: false,
        DOMPoint: false,
        DOMPointReadOnly: false,
        DOMQuad: false,
        DOMRect: false,
        DOMRectReadOnly: false,
        DOMStringList: false,
        DOMStringMap: false,
        DOMTokenList: false,
        DragEvent: false,
        DynamicsCompressorNode: false,
        Element: false,
        ErrorEvent: false,
        event: false,
        Event: false,
        EventSource: false,
        EventTarget: false,
        external: false,
        fetch: false,
        File: false,
        FileList: false,
        FileReader: false,
        find: false,
        focus: false,
        FocusEvent: false,
        FontFace: false,
        FontFaceSetLoadEvent: false,
        FormData: false,
        frameElement: false,
        frames: false,
        GainNode: false,
        Gamepad: false,
        GamepadButton: false,
        GamepadEvent: false,
        getComputedStyle: false,
        getSelection: false,
        HashChangeEvent: false,
        Headers: false,
        history: false,
        History: false,
        HTMLAllCollection: false,
        HTMLAnchorElement: false,
        HTMLAreaElement: false,
        HTMLAudioElement: false,
        HTMLBaseElement: false,
        HTMLBodyElement: false,
        HTMLBRElement: false,
        HTMLButtonElement: false,
        HTMLCanvasElement: false,
        HTMLCollection: false,
        HTMLContentElement: false,
        HTMLDataElement: false,
        HTMLDataListElement: false,
        HTMLDetailsElement: false,
        HTMLDialogElement: false,
        HTMLDirectoryElement: false,
        HTMLDivElement: false,
        HTMLDListElement: false,
        HTMLDocument: false,
        HTMLElement: false,
        HTMLEmbedElement: false,
        HTMLFieldSetElement: false,
        HTMLFontElement: false,
        HTMLFormControlsCollection: false,
        HTMLFormElement: false,
        HTMLFrameElement: false,
        HTMLFrameSetElement: false,
        HTMLHeadElement: false,
        HTMLHeadingElement: false,
        HTMLHRElement: false,
        HTMLHtmlElement: false,
        HTMLIFrameElement: false,
        HTMLImageElement: false,
        HTMLInputElement: false,
        HTMLLabelElement: false,
        HTMLLegendElement: false,
        HTMLLIElement: false,
        HTMLLinkElement: false,
        HTMLMapElement: false,
        HTMLMarqueeElement: false,
        HTMLMediaElement: false,
        HTMLMenuElement: false,
        HTMLMetaElement: false,
        HTMLMeterElement: false,
        HTMLModElement: false,
        HTMLObjectElement: false,
        HTMLOListElement: false,
        HTMLOptGroupElement: false,
        HTMLOptionElement: false,
        HTMLOptionsCollection: false,
        HTMLOutputElement: false,
        HTMLParagraphElement: false,
        HTMLParamElement: false,
        HTMLPictureElement: false,
        HTMLPreElement: false,
        HTMLProgressElement: false,
        HTMLQuoteElement: false,
        HTMLScriptElement: false,
        HTMLSelectElement: false,
        HTMLShadowElement: false,
        HTMLSlotElement: false,
        HTMLSourceElement: false,
        HTMLSpanElement: false,
        HTMLStyleElement: false,
        HTMLTableCaptionElement: false,
        HTMLTableCellElement: false,
        HTMLTableColElement: false,
        HTMLTableElement: false,
        HTMLTableRowElement: false,
        HTMLTableSectionElement: false,
        HTMLTemplateElement: false,
        HTMLTextAreaElement: false,
        HTMLTimeElement: false,
        HTMLTitleElement: false,
        HTMLTrackElement: false,
        HTMLUListElement: false,
        HTMLUnknownElement: false,
        HTMLVideoElement: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        IdleDeadline: false,
        IIRFilterNode: false,
        Image: false,
        ImageBitmap: false,
        ImageBitmapRenderingContext: false,
        ImageCapture: false,
        ImageData: false,
        indexedDB: false,
        innerHeight: false,
        innerWidth: false,
        InputEvent: false,
        IntersectionObserver: false,
        IntersectionObserverEntry: false,
        Intl: false,
        isSecureContext: false,
        KeyboardEvent: false,
        KeyframeEffect: false,
        KeyframeEffectReadOnly: false,
        length: false,
        localStorage: false,
        location: true,
        Location: false,
        locationbar: false,
        matchMedia: false,
        MediaDeviceInfo: false,
        MediaDevices: false,
        MediaElementAudioSourceNode: false,
        MediaEncryptedEvent: false,
        MediaError: false,
        MediaKeyMessageEvent: false,
        MediaKeySession: false,
        MediaKeyStatusMap: false,
        MediaKeySystemAccess: false,
        MediaList: false,
        MediaQueryList: false,
        MediaQueryListEvent: false,
        MediaRecorder: false,
        MediaSettingsRange: false,
        MediaSource: false,
        MediaStream: false,
        MediaStreamAudioDestinationNode: false,
        MediaStreamAudioSourceNode: false,
        MediaStreamEvent: false,
        MediaStreamTrack: false,
        MediaStreamTrackEvent: false,
        menubar: false,
        MessageChannel: false,
        MessageEvent: false,
        MessagePort: false,
        MIDIAccess: false,
        MIDIConnectionEvent: false,
        MIDIInput: false,
        MIDIInputMap: false,
        MIDIMessageEvent: false,
        MIDIOutput: false,
        MIDIOutputMap: false,
        MIDIPort: false,
        MimeType: false,
        MimeTypeArray: false,
        MouseEvent: false,
        moveBy: false,
        moveTo: false,
        MutationEvent: false,
        MutationObserver: false,
        MutationRecord: false,
        name: false,
        NamedNodeMap: false,
        NavigationPreloadManager: false,
        navigator: false,
        Navigator: false,
        NetworkInformation: false,
        Node: false,
        NodeFilter: false,
        NodeIterator: false,
        NodeList: false,
        Notification: false,
        OfflineAudioCompletionEvent: false,
        OfflineAudioContext: false,
        offscreenBuffering: false,
        OffscreenCanvas: true,
        onabort: true,
        onafterprint: true,
        onanimationend: true,
        onanimationiteration: true,
        onanimationstart: true,
        onappinstalled: true,
        onauxclick: true,
        onbeforeinstallprompt: true,
        onbeforeprint: true,
        onbeforeunload: true,
        onblur: true,
        oncancel: true,
        oncanplay: true,
        oncanplaythrough: true,
        onchange: true,
        onclick: true,
        onclose: true,
        oncontextmenu: true,
        oncuechange: true,
        ondblclick: true,
        ondevicemotion: true,
        ondeviceorientation: true,
        ondeviceorientationabsolute: true,
        ondrag: true,
        ondragend: true,
        ondragenter: true,
        ondragleave: true,
        ondragover: true,
        ondragstart: true,
        ondrop: true,
        ondurationchange: true,
        onemptied: true,
        onended: true,
        onerror: true,
        onfocus: true,
        ongotpointercapture: true,
        onhashchange: true,
        oninput: true,
        oninvalid: true,
        onkeydown: true,
        onkeypress: true,
        onkeyup: true,
        onlanguagechange: true,
        onload: true,
        onloadeddata: true,
        onloadedmetadata: true,
        onloadstart: true,
        onlostpointercapture: true,
        onmessage: true,
        onmessageerror: true,
        onmousedown: true,
        onmouseenter: true,
        onmouseleave: true,
        onmousemove: true,
        onmouseout: true,
        onmouseover: true,
        onmouseup: true,
        onmousewheel: true,
        onoffline: true,
        ononline: true,
        onpagehide: true,
        onpageshow: true,
        onpause: true,
        onplay: true,
        onplaying: true,
        onpointercancel: true,
        onpointerdown: true,
        onpointerenter: true,
        onpointerleave: true,
        onpointermove: true,
        onpointerout: true,
        onpointerover: true,
        onpointerup: true,
        onpopstate: true,
        onprogress: true,
        onratechange: true,
        onrejectionhandled: true,
        onreset: true,
        onresize: true,
        onscroll: true,
        onsearch: true,
        onseeked: true,
        onseeking: true,
        onselect: true,
        onstalled: true,
        onstorage: true,
        onsubmit: true,
        onsuspend: true,
        ontimeupdate: true,
        ontoggle: true,
        ontransitionend: true,
        onunhandledrejection: true,
        onunload: true,
        onvolumechange: true,
        onwaiting: true,
        onwheel: true,
        open: false,
        openDatabase: false,
        opener: false,
        Option: false,
        origin: false,
        OscillatorNode: false,
        outerHeight: false,
        outerWidth: false,
        PageTransitionEvent: false,
        pageXOffset: false,
        pageYOffset: false,
        PannerNode: false,
        parent: false,
        Path2D: false,
        PaymentAddress: false,
        PaymentRequest: false,
        PaymentRequestUpdateEvent: false,
        PaymentResponse: false,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceLongTaskTiming: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceNavigationTiming: false,
        PerformanceObserver: false,
        PerformanceObserverEntryList: false,
        PerformancePaintTiming: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        PeriodicWave: false,
        Permissions: false,
        PermissionStatus: false,
        personalbar: false,
        PhotoCapabilities: false,
        Plugin: false,
        PluginArray: false,
        PointerEvent: false,
        PopStateEvent: false,
        postMessage: false,
        Presentation: false,
        PresentationAvailability: false,
        PresentationConnection: false,
        PresentationConnectionAvailableEvent: false,
        PresentationConnectionCloseEvent: false,
        PresentationConnectionList: false,
        PresentationReceiver: false,
        PresentationRequest: false,
        print: false,
        ProcessingInstruction: false,
        ProgressEvent: false,
        PromiseRejectionEvent: false,
        prompt: false,
        PushManager: false,
        PushSubscription: false,
        PushSubscriptionOptions: false,
        queueMicrotask: false,
        RadioNodeList: false,
        Range: false,
        ReadableStream: false,
        registerProcessor: false,
        RemotePlayback: false,
        removeEventListener: false,
        Request: false,
        requestAnimationFrame: false,
        requestIdleCallback: false,
        resizeBy: false,
        ResizeObserver: false,
        ResizeObserverEntry: false,
        resizeTo: false,
        Response: false,
        RTCCertificate: false,
        RTCDataChannel: false,
        RTCDataChannelEvent: false,
        RTCDtlsTransport: false,
        RTCIceCandidate: false,
        RTCIceGatherer: false,
        RTCIceTransport: false,
        RTCPeerConnection: false,
        RTCPeerConnectionIceEvent: false,
        RTCRtpContributingSource: false,
        RTCRtpReceiver: false,
        RTCRtpSender: false,
        RTCSctpTransport: false,
        RTCSessionDescription: false,
        RTCStatsReport: false,
        RTCTrackEvent: false,
        screen: false,
        Screen: false,
        screenLeft: false,
        ScreenOrientation: false,
        screenTop: false,
        screenX: false,
        screenY: false,
        ScriptProcessorNode: false,
        scroll: false,
        scrollbars: false,
        scrollBy: false,
        scrollTo: false,
        scrollX: false,
        scrollY: false,
        SecurityPolicyViolationEvent: false,
        Selection: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerRegistration: false,
        sessionStorage: false,
        setInterval: false,
        setTimeout: false,
        ShadowRoot: false,
        SharedWorker: false,
        SourceBuffer: false,
        SourceBufferList: false,
        speechSynthesis: false,
        SpeechSynthesisEvent: false,
        SpeechSynthesisUtterance: false,
        StaticRange: false,
        status: false,
        statusbar: false,
        StereoPannerNode: false,
        stop: false,
        Storage: false,
        StorageEvent: false,
        StorageManager: false,
        styleMedia: false,
        StyleSheet: false,
        StyleSheetList: false,
        SubtleCrypto: false,
        SVGAElement: false,
        SVGAngle: false,
        SVGAnimatedAngle: false,
        SVGAnimatedBoolean: false,
        SVGAnimatedEnumeration: false,
        SVGAnimatedInteger: false,
        SVGAnimatedLength: false,
        SVGAnimatedLengthList: false,
        SVGAnimatedNumber: false,
        SVGAnimatedNumberList: false,
        SVGAnimatedPreserveAspectRatio: false,
        SVGAnimatedRect: false,
        SVGAnimatedString: false,
        SVGAnimatedTransformList: false,
        SVGAnimateElement: false,
        SVGAnimateMotionElement: false,
        SVGAnimateTransformElement: false,
        SVGAnimationElement: false,
        SVGCircleElement: false,
        SVGClipPathElement: false,
        SVGComponentTransferFunctionElement: false,
        SVGDefsElement: false,
        SVGDescElement: false,
        SVGDiscardElement: false,
        SVGElement: false,
        SVGEllipseElement: false,
        SVGFEBlendElement: false,
        SVGFEColorMatrixElement: false,
        SVGFEComponentTransferElement: false,
        SVGFECompositeElement: false,
        SVGFEConvolveMatrixElement: false,
        SVGFEDiffuseLightingElement: false,
        SVGFEDisplacementMapElement: false,
        SVGFEDistantLightElement: false,
        SVGFEDropShadowElement: false,
        SVGFEFloodElement: false,
        SVGFEFuncAElement: false,
        SVGFEFuncBElement: false,
        SVGFEFuncGElement: false,
        SVGFEFuncRElement: false,
        SVGFEGaussianBlurElement: false,
        SVGFEImageElement: false,
        SVGFEMergeElement: false,
        SVGFEMergeNodeElement: false,
        SVGFEMorphologyElement: false,
        SVGFEOffsetElement: false,
        SVGFEPointLightElement: false,
        SVGFESpecularLightingElement: false,
        SVGFESpotLightElement: false,
        SVGFETileElement: false,
        SVGFETurbulenceElement: false,
        SVGFilterElement: false,
        SVGForeignObjectElement: false,
        SVGGElement: false,
        SVGGeometryElement: false,
        SVGGradientElement: false,
        SVGGraphicsElement: false,
        SVGImageElement: false,
        SVGLength: false,
        SVGLengthList: false,
        SVGLinearGradientElement: false,
        SVGLineElement: false,
        SVGMarkerElement: false,
        SVGMaskElement: false,
        SVGMatrix: false,
        SVGMetadataElement: false,
        SVGMPathElement: false,
        SVGNumber: false,
        SVGNumberList: false,
        SVGPathElement: false,
        SVGPatternElement: false,
        SVGPoint: false,
        SVGPointList: false,
        SVGPolygonElement: false,
        SVGPolylineElement: false,
        SVGPreserveAspectRatio: false,
        SVGRadialGradientElement: false,
        SVGRect: false,
        SVGRectElement: false,
        SVGScriptElement: false,
        SVGSetElement: false,
        SVGStopElement: false,
        SVGStringList: false,
        SVGStyleElement: false,
        SVGSVGElement: false,
        SVGSwitchElement: false,
        SVGSymbolElement: false,
        SVGTextContentElement: false,
        SVGTextElement: false,
        SVGTextPathElement: false,
        SVGTextPositioningElement: false,
        SVGTitleElement: false,
        SVGTransform: false,
        SVGTransformList: false,
        SVGTSpanElement: false,
        SVGUnitTypes: false,
        SVGUseElement: false,
        SVGViewElement: false,
        TaskAttributionTiming: false,
        Text: false,
        TextDecoder: false,
        TextEncoder: false,
        TextEvent: false,
        TextMetrics: false,
        TextTrack: false,
        TextTrackCue: false,
        TextTrackCueList: false,
        TextTrackList: false,
        TimeRanges: false,
        toolbar: false,
        top: false,
        Touch: false,
        TouchEvent: false,
        TouchList: false,
        TrackEvent: false,
        TransitionEvent: false,
        TreeWalker: false,
        UIEvent: false,
        URL: false,
        URLSearchParams: false,
        ValidityState: false,
        visualViewport: false,
        VisualViewport: false,
        VTTCue: false,
        WaveShaperNode: false,
        WebAssembly: false,
        WebGL2RenderingContext: false,
        WebGLActiveInfo: false,
        WebGLBuffer: false,
        WebGLContextEvent: false,
        WebGLFramebuffer: false,
        WebGLProgram: false,
        WebGLQuery: false,
        WebGLRenderbuffer: false,
        WebGLRenderingContext: false,
        WebGLSampler: false,
        WebGLShader: false,
        WebGLShaderPrecisionFormat: false,
        WebGLSync: false,
        WebGLTexture: false,
        WebGLTransformFeedback: false,
        WebGLUniformLocation: false,
        WebGLVertexArrayObject: false,
        WebSocket: false,
        WheelEvent: false,
        window: false,
        Window: false,
        Worker: false,
        WritableStream: false,
        XMLDocument: false,
        XMLHttpRequest: false,
        XMLHttpRequestEventTarget: false,
        XMLHttpRequestUpload: false,
        XMLSerializer: false,
        XPathEvaluator: false,
        XPathExpression: false,
        XPathResult: false,
        XSLTProcessor: false
      },
      worker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        clearInterval: false,
        clearTimeout: false,
        close: true,
        console: false,
        fetch: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: true,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onlanguagechange: true,
        onmessage: true,
        onoffline: true,
        ononline: true,
        onrejectionhandled: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        removeEventListener: false,
        Request: false,
        Response: false,
        self: true,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      node: {
        __dirname: false,
        __filename: false,
        Buffer: false,
        clearImmediate: false,
        clearInterval: false,
        clearTimeout: false,
        console: false,
        exports: true,
        global: false,
        Intl: false,
        module: false,
        process: false,
        queueMicrotask: false,
        require: false,
        setImmediate: false,
        setInterval: false,
        setTimeout: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false
      },
      commonjs: {
        exports: true,
        global: false,
        module: false,
        require: false
      },
      amd: {
        define: false,
        require: false
      },
      mocha: {
        after: false,
        afterEach: false,
        before: false,
        beforeEach: false,
        context: false,
        describe: false,
        it: false,
        mocha: false,
        run: false,
        setup: false,
        specify: false,
        suite: false,
        suiteSetup: false,
        suiteTeardown: false,
        teardown: false,
        test: false,
        xcontext: false,
        xdescribe: false,
        xit: false,
        xspecify: false
      },
      jasmine: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        fail: false,
        fdescribe: false,
        fit: false,
        it: false,
        jasmine: false,
        pending: false,
        runs: false,
        spyOn: false,
        spyOnProperty: false,
        waits: false,
        waitsFor: false,
        xdescribe: false,
        xit: false
      },
      jest: {
        afterAll: false,
        afterEach: false,
        beforeAll: false,
        beforeEach: false,
        describe: false,
        expect: false,
        fdescribe: false,
        fit: false,
        it: false,
        jest: false,
        pit: false,
        require: false,
        test: false,
        xdescribe: false,
        xit: false,
        xtest: false
      },
      qunit: {
        asyncTest: false,
        deepEqual: false,
        equal: false,
        expect: false,
        module: false,
        notDeepEqual: false,
        notEqual: false,
        notOk: false,
        notPropEqual: false,
        notStrictEqual: false,
        ok: false,
        propEqual: false,
        QUnit: false,
        raises: false,
        start: false,
        stop: false,
        strictEqual: false,
        test: false,
        throws: false
      },
      phantomjs: {
        console: true,
        exports: true,
        phantom: true,
        require: true,
        WebPage: true
      },
      couch: {
        emit: false,
        exports: false,
        getRow: false,
        log: false,
        module: false,
        provides: false,
        require: false,
        respond: false,
        send: false,
        start: false,
        sum: false
      },
      rhino: {
        defineClass: false,
        deserialize: false,
        gc: false,
        help: false,
        importClass: false,
        importPackage: false,
        java: false,
        load: false,
        loadClass: false,
        Packages: false,
        print: false,
        quit: false,
        readFile: false,
        readUrl: false,
        runCommand: false,
        seal: false,
        serialize: false,
        spawn: false,
        sync: false,
        toint32: false,
        version: false
      },
      nashorn: {
        __DIR__: false,
        __FILE__: false,
        __LINE__: false,
        com: false,
        edu: false,
        exit: false,
        java: false,
        Java: false,
        javafx: false,
        JavaImporter: false,
        javax: false,
        JSAdapter: false,
        load: false,
        loadWithNewGlobal: false,
        org: false,
        Packages: false,
        print: false,
        quit: false
      },
      wsh: {
        ActiveXObject: true,
        Enumerator: true,
        GetObject: true,
        ScriptEngine: true,
        ScriptEngineBuildVersion: true,
        ScriptEngineMajorVersion: true,
        ScriptEngineMinorVersion: true,
        VBArray: true,
        WScript: true,
        WSH: true,
        XDomainRequest: true
      },
      jquery: {
        $: false,
        jQuery: false
      },
      yui: {
        YAHOO: false,
        YAHOO_config: false,
        YUI: false,
        YUI_config: false
      },
      shelljs: {
        cat: false,
        cd: false,
        chmod: false,
        config: false,
        cp: false,
        dirs: false,
        echo: false,
        env: false,
        error: false,
        exec: false,
        exit: false,
        find: false,
        grep: false,
        ln: false,
        ls: false,
        mkdir: false,
        mv: false,
        popd: false,
        pushd: false,
        pwd: false,
        rm: false,
        sed: false,
        set: false,
        target: false,
        tempdir: false,
        test: false,
        touch: false,
        which: false
      },
      prototypejs: {
        $: false,
        $$: false,
        $A: false,
        $break: false,
        $continue: false,
        $F: false,
        $H: false,
        $R: false,
        $w: false,
        Abstract: false,
        Ajax: false,
        Autocompleter: false,
        Builder: false,
        Class: false,
        Control: false,
        Draggable: false,
        Draggables: false,
        Droppables: false,
        Effect: false,
        Element: false,
        Enumerable: false,
        Event: false,
        Field: false,
        Form: false,
        Hash: false,
        Insertion: false,
        ObjectRange: false,
        PeriodicalExecuter: false,
        Position: false,
        Prototype: false,
        Scriptaculous: false,
        Selector: false,
        Sortable: false,
        SortableObserver: false,
        Sound: false,
        Template: false,
        Toggle: false,
        Try: false
      },
      meteor: {
        _: false,
        $: false,
        Accounts: false,
        AccountsClient: false,
        AccountsCommon: false,
        AccountsServer: false,
        App: false,
        Assets: false,
        Blaze: false,
        check: false,
        Cordova: false,
        DDP: false,
        DDPRateLimiter: false,
        DDPServer: false,
        Deps: false,
        EJSON: false,
        Email: false,
        HTTP: false,
        Log: false,
        Match: false,
        Meteor: false,
        Mongo: false,
        MongoInternals: false,
        Npm: false,
        Package: false,
        Plugin: false,
        process: false,
        Random: false,
        ReactiveDict: false,
        ReactiveVar: false,
        Router: false,
        ServiceConfiguration: false,
        Session: false,
        share: false,
        Spacebars: false,
        Template: false,
        Tinytest: false,
        Tracker: false,
        UI: false,
        Utils: false,
        WebApp: false,
        WebAppInternals: false
      },
      mongo: {
        _isWindows: false,
        _rand: false,
        BulkWriteResult: false,
        cat: false,
        cd: false,
        connect: false,
        db: false,
        getHostName: false,
        getMemInfo: false,
        hostname: false,
        ISODate: false,
        listFiles: false,
        load: false,
        ls: false,
        md5sumFile: false,
        mkdir: false,
        Mongo: false,
        NumberInt: false,
        NumberLong: false,
        ObjectId: false,
        PlanCache: false,
        print: false,
        printjson: false,
        pwd: false,
        quit: false,
        removeFile: false,
        rs: false,
        sh: false,
        UUID: false,
        version: false,
        WriteResult: false
      },
      applescript: {
        $: false,
        Application: false,
        Automation: false,
        console: false,
        delay: false,
        Library: false,
        ObjC: false,
        ObjectSpecifier: false,
        Path: false,
        Progress: false,
        Ref: false
      },
      serviceworker: {
        addEventListener: false,
        applicationCache: false,
        atob: false,
        Blob: false,
        BroadcastChannel: false,
        btoa: false,
        Cache: false,
        caches: false,
        CacheStorage: false,
        clearInterval: false,
        clearTimeout: false,
        Client: false,
        clients: false,
        Clients: false,
        close: true,
        console: false,
        ExtendableEvent: false,
        ExtendableMessageEvent: false,
        fetch: false,
        FetchEvent: false,
        FileReaderSync: false,
        FormData: false,
        Headers: false,
        IDBCursor: false,
        IDBCursorWithValue: false,
        IDBDatabase: false,
        IDBFactory: false,
        IDBIndex: false,
        IDBKeyRange: false,
        IDBObjectStore: false,
        IDBOpenDBRequest: false,
        IDBRequest: false,
        IDBTransaction: false,
        IDBVersionChangeEvent: false,
        ImageData: false,
        importScripts: false,
        indexedDB: false,
        location: false,
        MessageChannel: false,
        MessagePort: false,
        name: false,
        navigator: false,
        Notification: false,
        onclose: true,
        onconnect: true,
        onerror: true,
        onfetch: true,
        oninstall: true,
        onlanguagechange: true,
        onmessage: true,
        onmessageerror: true,
        onnotificationclick: true,
        onnotificationclose: true,
        onoffline: true,
        ononline: true,
        onpush: true,
        onpushsubscriptionchange: true,
        onrejectionhandled: true,
        onsync: true,
        onunhandledrejection: true,
        performance: false,
        Performance: false,
        PerformanceEntry: false,
        PerformanceMark: false,
        PerformanceMeasure: false,
        PerformanceNavigation: false,
        PerformanceResourceTiming: false,
        PerformanceTiming: false,
        postMessage: true,
        Promise: false,
        queueMicrotask: false,
        registration: false,
        removeEventListener: false,
        Request: false,
        Response: false,
        self: false,
        ServiceWorker: false,
        ServiceWorkerContainer: false,
        ServiceWorkerGlobalScope: false,
        ServiceWorkerMessageEvent: false,
        ServiceWorkerRegistration: false,
        setInterval: false,
        setTimeout: false,
        skipWaiting: false,
        TextDecoder: false,
        TextEncoder: false,
        URL: false,
        URLSearchParams: false,
        WebSocket: false,
        WindowClient: false,
        Worker: false,
        WorkerGlobalScope: false,
        XMLHttpRequest: false
      },
      atomtest: {
        advanceClock: false,
        fakeClearInterval: false,
        fakeClearTimeout: false,
        fakeSetInterval: false,
        fakeSetTimeout: false,
        resetTimeouts: false,
        waitsForPromise: false
      },
      embertest: {
        andThen: false,
        click: false,
        currentPath: false,
        currentRouteName: false,
        currentURL: false,
        fillIn: false,
        find: false,
        findAll: false,
        findWithAssert: false,
        keyEvent: false,
        pauseTest: false,
        resumeTest: false,
        triggerEvent: false,
        visit: false,
        wait: false
      },
      protractor: {
        $: false,
        $$: false,
        browser: false,
        by: false,
        By: false,
        DartObject: false,
        element: false,
        protractor: false
      },
      "shared-node-browser": {
        clearInterval: false,
        clearTimeout: false,
        console: false,
        setInterval: false,
        setTimeout: false,
        URL: false,
        URLSearchParams: false
      },
      webextensions: {
        browser: false,
        chrome: false,
        opr: false
      },
      greasemonkey: {
        cloneInto: false,
        createObjectIn: false,
        exportFunction: false,
        GM: false,
        GM_addStyle: false,
        GM_deleteValue: false,
        GM_getResourceText: false,
        GM_getResourceURL: false,
        GM_getValue: false,
        GM_info: false,
        GM_listValues: false,
        GM_log: false,
        GM_openInTab: false,
        GM_registerMenuCommand: false,
        GM_setClipboard: false,
        GM_setValue: false,
        GM_xmlhttpRequest: false,
        unsafeWindow: false
      },
      devtools: {
        $: false,
        $_: false,
        $$: false,
        $0: false,
        $1: false,
        $2: false,
        $3: false,
        $4: false,
        $x: false,
        chrome: false,
        clear: false,
        copy: false,
        debug: false,
        dir: false,
        dirxml: false,
        getEventListeners: false,
        inspect: false,
        keys: false,
        monitor: false,
        monitorEvents: false,
        profile: false,
        profileEnd: false,
        queryObjects: false,
        table: false,
        undebug: false,
        unmonitor: false,
        unmonitorEvents: false,
        values: false
      }
    };
  }
});

// node_modules/globals/index.js
var require_globals7 = __commonJS({
  "node_modules/globals/index.js"(exports, module2) {
    "use strict";
    module2.exports = require_globals6();
  }
});

// node_modules/@babel/traverse/lib/scope/index.js
var require_scope2 = __commonJS({
  "node_modules/@babel/traverse/lib/scope/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _renamer = require_renamer();
    var _index = require_lib20();
    var _binding = require_binding();
    var _globals = require_globals7();
    var _t = require_lib11();
    var _cache = require_cache4();
    var {
      NOT_LOCAL_BINDING,
      callExpression: callExpression3,
      cloneNode,
      getBindingIdentifiers,
      identifier: identifier3,
      isArrayExpression,
      isBinary,
      isClass,
      isClassBody,
      isClassDeclaration,
      isExportAllDeclaration,
      isExportDefaultDeclaration,
      isExportNamedDeclaration,
      isFunctionDeclaration,
      isIdentifier: isIdentifier2,
      isImportDeclaration,
      isLiteral,
      isMethod,
      isModuleSpecifier,
      isNullLiteral,
      isObjectExpression,
      isProperty,
      isPureish,
      isRegExpLiteral,
      isSuper,
      isTaggedTemplateExpression,
      isTemplateLiteral,
      isThisExpression,
      isUnaryExpression,
      isVariableDeclaration,
      matchesPattern,
      memberExpression,
      numericLiteral,
      toIdentifier,
      unaryExpression,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2,
      isRecordExpression,
      isTupleExpression,
      isObjectProperty,
      isTopicReference,
      isMetaProperty,
      isPrivateName,
      isExportDeclaration
    } = _t;
    function gatherNodeParts(node, parts) {
      switch (node == null ? void 0 : node.type) {
        default:
          if (isImportDeclaration(node) || isExportDeclaration(node)) {
            if ((isExportAllDeclaration(node) || isExportNamedDeclaration(node) || isImportDeclaration(node)) && node.source) {
              gatherNodeParts(node.source, parts);
            } else if ((isExportNamedDeclaration(node) || isImportDeclaration(node)) && node.specifiers && node.specifiers.length) {
              for (const e of node.specifiers)
                gatherNodeParts(e, parts);
            } else if ((isExportDefaultDeclaration(node) || isExportNamedDeclaration(node)) && node.declaration) {
              gatherNodeParts(node.declaration, parts);
            }
          } else if (isModuleSpecifier(node)) {
            gatherNodeParts(node.local, parts);
          } else if (isLiteral(node) && !isNullLiteral(node) && !isRegExpLiteral(node) && !isTemplateLiteral(node)) {
            parts.push(node.value);
          }
          break;
        case "MemberExpression":
        case "OptionalMemberExpression":
        case "JSXMemberExpression":
          gatherNodeParts(node.object, parts);
          gatherNodeParts(node.property, parts);
          break;
        case "Identifier":
        case "JSXIdentifier":
          parts.push(node.name);
          break;
        case "CallExpression":
        case "OptionalCallExpression":
        case "NewExpression":
          gatherNodeParts(node.callee, parts);
          break;
        case "ObjectExpression":
        case "ObjectPattern":
          for (const e of node.properties) {
            gatherNodeParts(e, parts);
          }
          break;
        case "SpreadElement":
        case "RestElement":
          gatherNodeParts(node.argument, parts);
          break;
        case "ObjectProperty":
        case "ObjectMethod":
        case "ClassProperty":
        case "ClassMethod":
        case "ClassPrivateProperty":
        case "ClassPrivateMethod":
          gatherNodeParts(node.key, parts);
          break;
        case "ThisExpression":
          parts.push("this");
          break;
        case "Super":
          parts.push("super");
          break;
        case "Import":
          parts.push("import");
          break;
        case "DoExpression":
          parts.push("do");
          break;
        case "YieldExpression":
          parts.push("yield");
          gatherNodeParts(node.argument, parts);
          break;
        case "AwaitExpression":
          parts.push("await");
          gatherNodeParts(node.argument, parts);
          break;
        case "AssignmentExpression":
          gatherNodeParts(node.left, parts);
          break;
        case "VariableDeclarator":
          gatherNodeParts(node.id, parts);
          break;
        case "FunctionExpression":
        case "FunctionDeclaration":
        case "ClassExpression":
        case "ClassDeclaration":
          gatherNodeParts(node.id, parts);
          break;
        case "PrivateName":
          gatherNodeParts(node.id, parts);
          break;
        case "ParenthesizedExpression":
          gatherNodeParts(node.expression, parts);
          break;
        case "UnaryExpression":
        case "UpdateExpression":
          gatherNodeParts(node.argument, parts);
          break;
        case "MetaProperty":
          gatherNodeParts(node.meta, parts);
          gatherNodeParts(node.property, parts);
          break;
        case "JSXElement":
          gatherNodeParts(node.openingElement, parts);
          break;
        case "JSXOpeningElement":
          gatherNodeParts(node.name, parts);
          break;
        case "JSXFragment":
          gatherNodeParts(node.openingFragment, parts);
          break;
        case "JSXOpeningFragment":
          parts.push("Fragment");
          break;
        case "JSXNamespacedName":
          gatherNodeParts(node.namespace, parts);
          gatherNodeParts(node.name, parts);
          break;
      }
    }
    var collectorVisitor = {
      ForStatement(path2) {
        const declar = path2.get("init");
        if (declar.isVar()) {
          const {
            scope
          } = path2;
          const parentScope = scope.getFunctionParent() || scope.getProgramParent();
          parentScope.registerBinding("var", declar);
        }
      },
      Declaration(path2) {
        if (path2.isBlockScoped())
          return;
        if (path2.isImportDeclaration())
          return;
        if (path2.isExportDeclaration())
          return;
        const parent = path2.scope.getFunctionParent() || path2.scope.getProgramParent();
        parent.registerDeclaration(path2);
      },
      ImportDeclaration(path2) {
        const parent = path2.scope.getBlockParent();
        parent.registerDeclaration(path2);
      },
      ReferencedIdentifier(path2, state) {
        state.references.push(path2);
      },
      ForXStatement(path2, state) {
        const left = path2.get("left");
        if (left.isPattern() || left.isIdentifier()) {
          state.constantViolations.push(path2);
        } else if (left.isVar()) {
          const {
            scope
          } = path2;
          const parentScope = scope.getFunctionParent() || scope.getProgramParent();
          parentScope.registerBinding("var", left);
        }
      },
      ExportDeclaration: {
        exit(path2) {
          const {
            node,
            scope
          } = path2;
          if (isExportAllDeclaration(node))
            return;
          const declar = node.declaration;
          if (isClassDeclaration(declar) || isFunctionDeclaration(declar)) {
            const id = declar.id;
            if (!id)
              return;
            const binding = scope.getBinding(id.name);
            binding == null ? void 0 : binding.reference(path2);
          } else if (isVariableDeclaration(declar)) {
            for (const decl of declar.declarations) {
              for (const name of Object.keys(getBindingIdentifiers(decl))) {
                const binding = scope.getBinding(name);
                binding == null ? void 0 : binding.reference(path2);
              }
            }
          }
        }
      },
      LabeledStatement(path2) {
        path2.scope.getBlockParent().registerDeclaration(path2);
      },
      AssignmentExpression(path2, state) {
        state.assignments.push(path2);
      },
      UpdateExpression(path2, state) {
        state.constantViolations.push(path2);
      },
      UnaryExpression(path2, state) {
        if (path2.node.operator === "delete") {
          state.constantViolations.push(path2);
        }
      },
      BlockScoped(path2) {
        let scope = path2.scope;
        if (scope.path === path2)
          scope = scope.parent;
        const parent = scope.getBlockParent();
        parent.registerDeclaration(path2);
        if (path2.isClassDeclaration() && path2.node.id) {
          const id = path2.node.id;
          const name = id.name;
          path2.scope.bindings[name] = path2.scope.parent.getBinding(name);
        }
      },
      CatchClause(path2) {
        path2.scope.registerBinding("let", path2);
      },
      Function(path2) {
        const params = path2.get("params");
        for (const param of params) {
          path2.scope.registerBinding("param", param);
        }
        if (path2.isFunctionExpression() && path2.has("id") && !path2.get("id").node[NOT_LOCAL_BINDING]) {
          path2.scope.registerBinding("local", path2.get("id"), path2);
        }
      },
      ClassExpression(path2) {
        if (path2.has("id") && !path2.get("id").node[NOT_LOCAL_BINDING]) {
          path2.scope.registerBinding("local", path2);
        }
      }
    };
    var uid = 0;
    var Scope = class _Scope {
      constructor(path2) {
        this.uid = void 0;
        this.path = void 0;
        this.block = void 0;
        this.labels = void 0;
        this.inited = void 0;
        this.bindings = void 0;
        this.references = void 0;
        this.globals = void 0;
        this.uids = void 0;
        this.data = void 0;
        this.crawling = void 0;
        const {
          node
        } = path2;
        const cached = _cache.scope.get(node);
        if ((cached == null ? void 0 : cached.path) === path2) {
          return cached;
        }
        _cache.scope.set(node, this);
        this.uid = uid++;
        this.block = node;
        this.path = path2;
        this.labels = /* @__PURE__ */ new Map();
        this.inited = false;
      }
      get parent() {
        var _parent;
        let parent, path2 = this.path;
        do {
          const shouldSkip = path2.key === "key" || path2.listKey === "decorators";
          path2 = path2.parentPath;
          if (shouldSkip && path2.isMethod())
            path2 = path2.parentPath;
          if (path2 && path2.isScope())
            parent = path2;
        } while (path2 && !parent);
        return (_parent = parent) == null ? void 0 : _parent.scope;
      }
      get parentBlock() {
        return this.path.parent;
      }
      get hub() {
        return this.path.hub;
      }
      traverse(node, opts, state) {
        (0, _index.default)(node, opts, this, state, this.path);
      }
      generateDeclaredUidIdentifier(name) {
        const id = this.generateUidIdentifier(name);
        this.push({
          id
        });
        return cloneNode(id);
      }
      generateUidIdentifier(name) {
        return identifier3(this.generateUid(name));
      }
      generateUid(name = "temp") {
        name = toIdentifier(name).replace(/^_+/, "").replace(/[0-9]+$/g, "");
        let uid2;
        let i = 1;
        do {
          uid2 = this._generateUid(name, i);
          i++;
        } while (this.hasLabel(uid2) || this.hasBinding(uid2) || this.hasGlobal(uid2) || this.hasReference(uid2));
        const program2 = this.getProgramParent();
        program2.references[uid2] = true;
        program2.uids[uid2] = true;
        return uid2;
      }
      _generateUid(name, i) {
        let id = name;
        if (i > 1)
          id += i;
        return `_${id}`;
      }
      generateUidBasedOnNode(node, defaultName) {
        const parts = [];
        gatherNodeParts(node, parts);
        let id = parts.join("$");
        id = id.replace(/^_/, "") || defaultName || "ref";
        return this.generateUid(id.slice(0, 20));
      }
      generateUidIdentifierBasedOnNode(node, defaultName) {
        return identifier3(this.generateUidBasedOnNode(node, defaultName));
      }
      isStatic(node) {
        if (isThisExpression(node) || isSuper(node) || isTopicReference(node)) {
          return true;
        }
        if (isIdentifier2(node)) {
          const binding = this.getBinding(node.name);
          if (binding) {
            return binding.constant;
          } else {
            return this.hasBinding(node.name);
          }
        }
        return false;
      }
      maybeGenerateMemoised(node, dontPush) {
        if (this.isStatic(node)) {
          return null;
        } else {
          const id = this.generateUidIdentifierBasedOnNode(node);
          if (!dontPush) {
            this.push({
              id
            });
            return cloneNode(id);
          }
          return id;
        }
      }
      checkBlockScopedCollisions(local, kind, name, id) {
        if (kind === "param")
          return;
        if (local.kind === "local")
          return;
        const duplicate = kind === "let" || local.kind === "let" || local.kind === "const" || local.kind === "module" || local.kind === "param" && kind === "const";
        if (duplicate) {
          throw this.hub.buildError(id, `Duplicate declaration "${name}"`, TypeError);
        }
      }
      rename(oldName, newName, block) {
        const binding = this.getBinding(oldName);
        if (binding) {
          newName = newName || this.generateUidIdentifier(oldName).name;
          return new _renamer.default(binding, oldName, newName).rename(block);
        }
      }
      _renameFromMap(map, oldName, newName, value2) {
        if (map[oldName]) {
          map[newName] = value2;
          map[oldName] = null;
        }
      }
      dump() {
        const sep = "-".repeat(60);
        console.log(sep);
        let scope = this;
        do {
          console.log("#", scope.block.type);
          for (const name of Object.keys(scope.bindings)) {
            const binding = scope.bindings[name];
            console.log(" -", name, {
              constant: binding.constant,
              references: binding.references,
              violations: binding.constantViolations.length,
              kind: binding.kind
            });
          }
        } while (scope = scope.parent);
        console.log(sep);
      }
      toArray(node, i, arrayLikeIsIterable) {
        if (isIdentifier2(node)) {
          const binding = this.getBinding(node.name);
          if (binding != null && binding.constant && binding.path.isGenericType("Array")) {
            return node;
          }
        }
        if (isArrayExpression(node)) {
          return node;
        }
        if (isIdentifier2(node, {
          name: "arguments"
        })) {
          return callExpression3(memberExpression(memberExpression(memberExpression(identifier3("Array"), identifier3("prototype")), identifier3("slice")), identifier3("call")), [node]);
        }
        let helperName;
        const args = [node];
        if (i === true) {
          helperName = "toConsumableArray";
        } else if (typeof i === "number") {
          args.push(numericLiteral(i));
          helperName = "slicedToArray";
        } else {
          helperName = "toArray";
        }
        if (arrayLikeIsIterable) {
          args.unshift(this.hub.addHelper(helperName));
          helperName = "maybeArrayLike";
        }
        return callExpression3(this.hub.addHelper(helperName), args);
      }
      hasLabel(name) {
        return !!this.getLabel(name);
      }
      getLabel(name) {
        return this.labels.get(name);
      }
      registerLabel(path2) {
        this.labels.set(path2.node.label.name, path2);
      }
      registerDeclaration(path2) {
        if (path2.isLabeledStatement()) {
          this.registerLabel(path2);
        } else if (path2.isFunctionDeclaration()) {
          this.registerBinding("hoisted", path2.get("id"), path2);
        } else if (path2.isVariableDeclaration()) {
          const declarations = path2.get("declarations");
          const {
            kind
          } = path2.node;
          for (const declar of declarations) {
            this.registerBinding(kind === "using" ? "const" : kind, declar);
          }
        } else if (path2.isClassDeclaration()) {
          if (path2.node.declare)
            return;
          this.registerBinding("let", path2);
        } else if (path2.isImportDeclaration()) {
          const isTypeDeclaration = path2.node.importKind === "type" || path2.node.importKind === "typeof";
          const specifiers = path2.get("specifiers");
          for (const specifier of specifiers) {
            const isTypeSpecifier = isTypeDeclaration || specifier.isImportSpecifier() && (specifier.node.importKind === "type" || specifier.node.importKind === "typeof");
            this.registerBinding(isTypeSpecifier ? "unknown" : "module", specifier);
          }
        } else if (path2.isExportDeclaration()) {
          const declar = path2.get("declaration");
          if (declar.isClassDeclaration() || declar.isFunctionDeclaration() || declar.isVariableDeclaration()) {
            this.registerDeclaration(declar);
          }
        } else {
          this.registerBinding("unknown", path2);
        }
      }
      buildUndefinedNode() {
        return unaryExpression("void", numericLiteral(0), true);
      }
      registerConstantViolation(path2) {
        const ids = path2.getBindingIdentifiers();
        for (const name of Object.keys(ids)) {
          const binding = this.getBinding(name);
          if (binding)
            binding.reassign(path2);
        }
      }
      registerBinding(kind, path2, bindingPath = path2) {
        if (!kind)
          throw new ReferenceError("no `kind`");
        if (path2.isVariableDeclaration()) {
          const declarators = path2.get("declarations");
          for (const declar of declarators) {
            this.registerBinding(kind, declar);
          }
          return;
        }
        const parent = this.getProgramParent();
        const ids = path2.getOuterBindingIdentifiers(true);
        for (const name of Object.keys(ids)) {
          parent.references[name] = true;
          for (const id of ids[name]) {
            const local = this.getOwnBinding(name);
            if (local) {
              if (local.identifier === id)
                continue;
              this.checkBlockScopedCollisions(local, kind, name, id);
            }
            if (local) {
              this.registerConstantViolation(bindingPath);
            } else {
              this.bindings[name] = new _binding.default({
                identifier: id,
                scope: this,
                path: bindingPath,
                kind
              });
            }
          }
        }
      }
      addGlobal(node) {
        this.globals[node.name] = node;
      }
      hasUid(name) {
        let scope = this;
        do {
          if (scope.uids[name])
            return true;
        } while (scope = scope.parent);
        return false;
      }
      hasGlobal(name) {
        let scope = this;
        do {
          if (scope.globals[name])
            return true;
        } while (scope = scope.parent);
        return false;
      }
      hasReference(name) {
        return !!this.getProgramParent().references[name];
      }
      isPure(node, constantsOnly) {
        if (isIdentifier2(node)) {
          const binding = this.getBinding(node.name);
          if (!binding)
            return false;
          if (constantsOnly)
            return binding.constant;
          return true;
        } else if (isThisExpression(node) || isMetaProperty(node) || isTopicReference(node) || isPrivateName(node)) {
          return true;
        } else if (isClass(node)) {
          var _node$decorators;
          if (node.superClass && !this.isPure(node.superClass, constantsOnly)) {
            return false;
          }
          if (((_node$decorators = node.decorators) == null ? void 0 : _node$decorators.length) > 0) {
            return false;
          }
          return this.isPure(node.body, constantsOnly);
        } else if (isClassBody(node)) {
          for (const method of node.body) {
            if (!this.isPure(method, constantsOnly))
              return false;
          }
          return true;
        } else if (isBinary(node)) {
          return this.isPure(node.left, constantsOnly) && this.isPure(node.right, constantsOnly);
        } else if (isArrayExpression(node) || isTupleExpression(node)) {
          for (const elem of node.elements) {
            if (elem !== null && !this.isPure(elem, constantsOnly))
              return false;
          }
          return true;
        } else if (isObjectExpression(node) || isRecordExpression(node)) {
          for (const prop of node.properties) {
            if (!this.isPure(prop, constantsOnly))
              return false;
          }
          return true;
        } else if (isMethod(node)) {
          var _node$decorators2;
          if (node.computed && !this.isPure(node.key, constantsOnly))
            return false;
          if (((_node$decorators2 = node.decorators) == null ? void 0 : _node$decorators2.length) > 0) {
            return false;
          }
          return true;
        } else if (isProperty(node)) {
          var _node$decorators3;
          if (node.computed && !this.isPure(node.key, constantsOnly))
            return false;
          if (((_node$decorators3 = node.decorators) == null ? void 0 : _node$decorators3.length) > 0) {
            return false;
          }
          if (isObjectProperty(node) || node.static) {
            if (node.value !== null && !this.isPure(node.value, constantsOnly)) {
              return false;
            }
          }
          return true;
        } else if (isUnaryExpression(node)) {
          return this.isPure(node.argument, constantsOnly);
        } else if (isTaggedTemplateExpression(node)) {
          return matchesPattern(node.tag, "String.raw") && !this.hasBinding("String", true) && this.isPure(node.quasi, constantsOnly);
        } else if (isTemplateLiteral(node)) {
          for (const expression of node.expressions) {
            if (!this.isPure(expression, constantsOnly))
              return false;
          }
          return true;
        } else {
          return isPureish(node);
        }
      }
      setData(key, val) {
        return this.data[key] = val;
      }
      getData(key) {
        let scope = this;
        do {
          const data = scope.data[key];
          if (data != null)
            return data;
        } while (scope = scope.parent);
      }
      removeData(key) {
        let scope = this;
        do {
          const data = scope.data[key];
          if (data != null)
            scope.data[key] = null;
        } while (scope = scope.parent);
      }
      init() {
        if (!this.inited) {
          this.inited = true;
          this.crawl();
        }
      }
      crawl() {
        const path2 = this.path;
        this.references = /* @__PURE__ */ Object.create(null);
        this.bindings = /* @__PURE__ */ Object.create(null);
        this.globals = /* @__PURE__ */ Object.create(null);
        this.uids = /* @__PURE__ */ Object.create(null);
        this.data = /* @__PURE__ */ Object.create(null);
        const programParent = this.getProgramParent();
        if (programParent.crawling)
          return;
        const state = {
          references: [],
          constantViolations: [],
          assignments: []
        };
        this.crawling = true;
        if (path2.type !== "Program" && collectorVisitor._exploded) {
          for (const visit of collectorVisitor.enter) {
            visit(path2, state);
          }
          const typeVisitors = collectorVisitor[path2.type];
          if (typeVisitors) {
            for (const visit of typeVisitors.enter) {
              visit(path2, state);
            }
          }
        }
        path2.traverse(collectorVisitor, state);
        this.crawling = false;
        for (const path3 of state.assignments) {
          const ids = path3.getBindingIdentifiers();
          for (const name of Object.keys(ids)) {
            if (path3.scope.getBinding(name))
              continue;
            programParent.addGlobal(ids[name]);
          }
          path3.scope.registerConstantViolation(path3);
        }
        for (const ref of state.references) {
          const binding = ref.scope.getBinding(ref.node.name);
          if (binding) {
            binding.reference(ref);
          } else {
            programParent.addGlobal(ref.node);
          }
        }
        for (const path3 of state.constantViolations) {
          path3.scope.registerConstantViolation(path3);
        }
      }
      push(opts) {
        let path2 = this.path;
        if (path2.isPattern()) {
          path2 = this.getPatternParent().path;
        } else if (!path2.isBlockStatement() && !path2.isProgram()) {
          path2 = this.getBlockParent().path;
        }
        if (path2.isSwitchStatement()) {
          path2 = (this.getFunctionParent() || this.getProgramParent()).path;
        }
        if (path2.isLoop() || path2.isCatchClause() || path2.isFunction()) {
          path2.ensureBlock();
          path2 = path2.get("body");
        }
        const unique = opts.unique;
        const kind = opts.kind || "var";
        const blockHoist = opts._blockHoist == null ? 2 : opts._blockHoist;
        const dataKey = `declaration:${kind}:${blockHoist}`;
        let declarPath = !unique && path2.getData(dataKey);
        if (!declarPath) {
          const declar = variableDeclaration2(kind, []);
          declar._blockHoist = blockHoist;
          [declarPath] = path2.unshiftContainer("body", [declar]);
          if (!unique)
            path2.setData(dataKey, declarPath);
        }
        const declarator = variableDeclarator2(opts.id, opts.init);
        const len = declarPath.node.declarations.push(declarator);
        path2.scope.registerBinding(kind, declarPath.get("declarations")[len - 1]);
      }
      getProgramParent() {
        let scope = this;
        do {
          if (scope.path.isProgram()) {
            return scope;
          }
        } while (scope = scope.parent);
        throw new Error("Couldn't find a Program");
      }
      getFunctionParent() {
        let scope = this;
        do {
          if (scope.path.isFunctionParent()) {
            return scope;
          }
        } while (scope = scope.parent);
        return null;
      }
      getBlockParent() {
        let scope = this;
        do {
          if (scope.path.isBlockParent()) {
            return scope;
          }
        } while (scope = scope.parent);
        throw new Error("We couldn't find a BlockStatement, For, Switch, Function, Loop or Program...");
      }
      getPatternParent() {
        let scope = this;
        do {
          if (!scope.path.isPattern()) {
            return scope.getBlockParent();
          }
        } while (scope = scope.parent.parent);
        throw new Error("We couldn't find a BlockStatement, For, Switch, Function, Loop or Program...");
      }
      getAllBindings() {
        const ids = /* @__PURE__ */ Object.create(null);
        let scope = this;
        do {
          for (const key of Object.keys(scope.bindings)) {
            if (key in ids === false) {
              ids[key] = scope.bindings[key];
            }
          }
          scope = scope.parent;
        } while (scope);
        return ids;
      }
      getAllBindingsOfKind(...kinds) {
        const ids = /* @__PURE__ */ Object.create(null);
        for (const kind of kinds) {
          let scope = this;
          do {
            for (const name of Object.keys(scope.bindings)) {
              const binding = scope.bindings[name];
              if (binding.kind === kind)
                ids[name] = binding;
            }
            scope = scope.parent;
          } while (scope);
        }
        return ids;
      }
      bindingIdentifierEquals(name, node) {
        return this.getBindingIdentifier(name) === node;
      }
      getBinding(name) {
        let scope = this;
        let previousPath;
        do {
          const binding = scope.getOwnBinding(name);
          if (binding) {
            var _previousPath;
            if ((_previousPath = previousPath) != null && _previousPath.isPattern() && binding.kind !== "param" && binding.kind !== "local") {
            } else {
              return binding;
            }
          } else if (!binding && name === "arguments" && scope.path.isFunction() && !scope.path.isArrowFunctionExpression()) {
            break;
          }
          previousPath = scope.path;
        } while (scope = scope.parent);
      }
      getOwnBinding(name) {
        return this.bindings[name];
      }
      getBindingIdentifier(name) {
        var _this$getBinding;
        return (_this$getBinding = this.getBinding(name)) == null ? void 0 : _this$getBinding.identifier;
      }
      getOwnBindingIdentifier(name) {
        const binding = this.bindings[name];
        return binding == null ? void 0 : binding.identifier;
      }
      hasOwnBinding(name) {
        return !!this.getOwnBinding(name);
      }
      hasBinding(name, opts) {
        var _opts, _opts2, _opts3;
        if (!name)
          return false;
        if (this.hasOwnBinding(name))
          return true;
        {
          if (typeof opts === "boolean")
            opts = {
              noGlobals: opts
            };
        }
        if (this.parentHasBinding(name, opts))
          return true;
        if (!((_opts = opts) != null && _opts.noUids) && this.hasUid(name))
          return true;
        if (!((_opts2 = opts) != null && _opts2.noGlobals) && _Scope.globals.includes(name))
          return true;
        if (!((_opts3 = opts) != null && _opts3.noGlobals) && _Scope.contextVariables.includes(name))
          return true;
        return false;
      }
      parentHasBinding(name, opts) {
        var _this$parent;
        return (_this$parent = this.parent) == null ? void 0 : _this$parent.hasBinding(name, opts);
      }
      moveBindingTo(name, scope) {
        const info = this.getBinding(name);
        if (info) {
          info.scope.removeOwnBinding(name);
          info.scope = scope;
          scope.bindings[name] = info;
        }
      }
      removeOwnBinding(name) {
        delete this.bindings[name];
      }
      removeBinding(name) {
        var _this$getBinding2;
        (_this$getBinding2 = this.getBinding(name)) == null ? void 0 : _this$getBinding2.scope.removeOwnBinding(name);
        let scope = this;
        do {
          if (scope.uids[name]) {
            scope.uids[name] = false;
          }
        } while (scope = scope.parent);
      }
    };
    exports.default = Scope;
    Scope.globals = Object.keys(_globals.builtin);
    Scope.contextVariables = ["arguments", "undefined", "Infinity", "NaN"];
  }
});

// node_modules/@jridgewell/set-array/dist/set-array.umd.js
var require_set_array_umd = __commonJS({
  "node_modules/@jridgewell/set-array/dist/set-array.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports) : typeof define === "function" && define.amd ? define(["exports"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, factory(global2.setArray = {}));
    })(exports, function(exports2) {
      "use strict";
      exports2.get = void 0;
      exports2.put = void 0;
      exports2.pop = void 0;
      class SetArray {
        constructor() {
          this._indexes = { __proto__: null };
          this.array = [];
        }
      }
      (() => {
        exports2.get = (strarr, key) => strarr._indexes[key];
        exports2.put = (strarr, key) => {
          const index = exports2.get(strarr, key);
          if (index !== void 0)
            return index;
          const { array, _indexes: indexes } = strarr;
          return indexes[key] = array.push(key) - 1;
        };
        exports2.pop = (strarr) => {
          const { array, _indexes: indexes } = strarr;
          if (array.length === 0)
            return;
          const last2 = array.pop();
          indexes[last2] = void 0;
        };
      })();
      exports2.SetArray = SetArray;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/@jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js
var require_sourcemap_codec_umd = __commonJS({
  "node_modules/@jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports) : typeof define === "function" && define.amd ? define(["exports"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, factory(global2.sourcemapCodec = {}));
    })(exports, function(exports2) {
      "use strict";
      const comma = ",".charCodeAt(0);
      const semicolon = ";".charCodeAt(0);
      const chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
      const intToChar = new Uint8Array(64);
      const charToInt = new Uint8Array(128);
      for (let i = 0; i < chars.length; i++) {
        const c = chars.charCodeAt(i);
        intToChar[i] = c;
        charToInt[c] = i;
      }
      const td = typeof TextDecoder !== "undefined" ? /* @__PURE__ */ new TextDecoder() : typeof Buffer !== "undefined" ? {
        decode(buf) {
          const out = Buffer.from(buf.buffer, buf.byteOffset, buf.byteLength);
          return out.toString();
        }
      } : {
        decode(buf) {
          let out = "";
          for (let i = 0; i < buf.length; i++) {
            out += String.fromCharCode(buf[i]);
          }
          return out;
        }
      };
      function decode(mappings) {
        const state = new Int32Array(5);
        const decoded = [];
        let index = 0;
        do {
          const semi = indexOf(mappings, index);
          const line = [];
          let sorted = true;
          let lastCol = 0;
          state[0] = 0;
          for (let i = index; i < semi; i++) {
            let seg;
            i = decodeInteger(mappings, i, state, 0);
            const col = state[0];
            if (col < lastCol)
              sorted = false;
            lastCol = col;
            if (hasMoreVlq(mappings, i, semi)) {
              i = decodeInteger(mappings, i, state, 1);
              i = decodeInteger(mappings, i, state, 2);
              i = decodeInteger(mappings, i, state, 3);
              if (hasMoreVlq(mappings, i, semi)) {
                i = decodeInteger(mappings, i, state, 4);
                seg = [col, state[1], state[2], state[3], state[4]];
              } else {
                seg = [col, state[1], state[2], state[3]];
              }
            } else {
              seg = [col];
            }
            line.push(seg);
          }
          if (!sorted)
            sort(line);
          decoded.push(line);
          index = semi + 1;
        } while (index <= mappings.length);
        return decoded;
      }
      function indexOf(mappings, index) {
        const idx = mappings.indexOf(";", index);
        return idx === -1 ? mappings.length : idx;
      }
      function decodeInteger(mappings, pos, state, j) {
        let value2 = 0;
        let shift = 0;
        let integer = 0;
        do {
          const c = mappings.charCodeAt(pos++);
          integer = charToInt[c];
          value2 |= (integer & 31) << shift;
          shift += 5;
        } while (integer & 32);
        const shouldNegate = value2 & 1;
        value2 >>>= 1;
        if (shouldNegate) {
          value2 = -2147483648 | -value2;
        }
        state[j] += value2;
        return pos;
      }
      function hasMoreVlq(mappings, i, length) {
        if (i >= length)
          return false;
        return mappings.charCodeAt(i) !== comma;
      }
      function sort(line) {
        line.sort(sortComparator);
      }
      function sortComparator(a, b) {
        return a[0] - b[0];
      }
      function encode(decoded) {
        const state = new Int32Array(5);
        const bufLength = 1024 * 16;
        const subLength = bufLength - 36;
        const buf = new Uint8Array(bufLength);
        const sub = buf.subarray(0, subLength);
        let pos = 0;
        let out = "";
        for (let i = 0; i < decoded.length; i++) {
          const line = decoded[i];
          if (i > 0) {
            if (pos === bufLength) {
              out += td.decode(buf);
              pos = 0;
            }
            buf[pos++] = semicolon;
          }
          if (line.length === 0)
            continue;
          state[0] = 0;
          for (let j = 0; j < line.length; j++) {
            const segment = line[j];
            if (pos > subLength) {
              out += td.decode(sub);
              buf.copyWithin(0, subLength, pos);
              pos -= subLength;
            }
            if (j > 0)
              buf[pos++] = comma;
            pos = encodeInteger(buf, pos, state, segment, 0);
            if (segment.length === 1)
              continue;
            pos = encodeInteger(buf, pos, state, segment, 1);
            pos = encodeInteger(buf, pos, state, segment, 2);
            pos = encodeInteger(buf, pos, state, segment, 3);
            if (segment.length === 4)
              continue;
            pos = encodeInteger(buf, pos, state, segment, 4);
          }
        }
        return out + td.decode(buf.subarray(0, pos));
      }
      function encodeInteger(buf, pos, state, segment, j) {
        const next = segment[j];
        let num = next - state[j];
        state[j] = next;
        num = num < 0 ? -num << 1 | 1 : num << 1;
        do {
          let clamped = num & 31;
          num >>>= 5;
          if (num > 0)
            clamped |= 32;
          buf[pos++] = intToChar[clamped];
        } while (num > 0);
        return pos;
      }
      exports2.decode = decode;
      exports2.encode = encode;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/@jridgewell/resolve-uri/dist/resolve-uri.umd.js
var require_resolve_uri_umd = __commonJS({
  "node_modules/@jridgewell/resolve-uri/dist/resolve-uri.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? module2.exports = factory() : typeof define === "function" && define.amd ? define(factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, global2.resolveURI = factory());
    })(exports, function() {
      "use strict";
      const schemeRegex = /^[\w+.-]+:\/\//;
      const urlRegex = /^([\w+.-]+:)\/\/([^@/#?]*@)?([^:/#?]*)(:\d+)?(\/[^#?]*)?(\?[^#]*)?(#.*)?/;
      const fileRegex = /^file:(?:\/\/((?![a-z]:)[^/#?]*)?)?(\/?[^#?]*)(\?[^#]*)?(#.*)?/i;
      var UrlType;
      (function(UrlType2) {
        UrlType2[UrlType2["Empty"] = 1] = "Empty";
        UrlType2[UrlType2["Hash"] = 2] = "Hash";
        UrlType2[UrlType2["Query"] = 3] = "Query";
        UrlType2[UrlType2["RelativePath"] = 4] = "RelativePath";
        UrlType2[UrlType2["AbsolutePath"] = 5] = "AbsolutePath";
        UrlType2[UrlType2["SchemeRelative"] = 6] = "SchemeRelative";
        UrlType2[UrlType2["Absolute"] = 7] = "Absolute";
      })(UrlType || (UrlType = {}));
      function isAbsoluteUrl(input) {
        return schemeRegex.test(input);
      }
      function isSchemeRelativeUrl(input) {
        return input.startsWith("//");
      }
      function isAbsolutePath(input) {
        return input.startsWith("/");
      }
      function isFileUrl(input) {
        return input.startsWith("file:");
      }
      function isRelative(input) {
        return /^[.?#]/.test(input);
      }
      function parseAbsoluteUrl(input) {
        const match = urlRegex.exec(input);
        return makeUrl(match[1], match[2] || "", match[3], match[4] || "", match[5] || "/", match[6] || "", match[7] || "");
      }
      function parseFileUrl(input) {
        const match = fileRegex.exec(input);
        const path2 = match[2];
        return makeUrl("file:", "", match[1] || "", "", isAbsolutePath(path2) ? path2 : "/" + path2, match[3] || "", match[4] || "");
      }
      function makeUrl(scheme, user, host, port, path2, query, hash) {
        return {
          scheme,
          user,
          host,
          port,
          path: path2,
          query,
          hash,
          type: UrlType.Absolute
        };
      }
      function parseUrl(input) {
        if (isSchemeRelativeUrl(input)) {
          const url2 = parseAbsoluteUrl("http:" + input);
          url2.scheme = "";
          url2.type = UrlType.SchemeRelative;
          return url2;
        }
        if (isAbsolutePath(input)) {
          const url2 = parseAbsoluteUrl("http://foo.com" + input);
          url2.scheme = "";
          url2.host = "";
          url2.type = UrlType.AbsolutePath;
          return url2;
        }
        if (isFileUrl(input))
          return parseFileUrl(input);
        if (isAbsoluteUrl(input))
          return parseAbsoluteUrl(input);
        const url = parseAbsoluteUrl("http://foo.com/" + input);
        url.scheme = "";
        url.host = "";
        url.type = input ? input.startsWith("?") ? UrlType.Query : input.startsWith("#") ? UrlType.Hash : UrlType.RelativePath : UrlType.Empty;
        return url;
      }
      function stripPathFilename(path2) {
        if (path2.endsWith("/.."))
          return path2;
        const index = path2.lastIndexOf("/");
        return path2.slice(0, index + 1);
      }
      function mergePaths(url, base) {
        normalizePath(base, base.type);
        if (url.path === "/") {
          url.path = base.path;
        } else {
          url.path = stripPathFilename(base.path) + url.path;
        }
      }
      function normalizePath(url, type) {
        const rel = type <= UrlType.RelativePath;
        const pieces = url.path.split("/");
        let pointer = 1;
        let positive = 0;
        let addTrailingSlash = false;
        for (let i = 1; i < pieces.length; i++) {
          const piece = pieces[i];
          if (!piece) {
            addTrailingSlash = true;
            continue;
          }
          addTrailingSlash = false;
          if (piece === ".")
            continue;
          if (piece === "..") {
            if (positive) {
              addTrailingSlash = true;
              positive--;
              pointer--;
            } else if (rel) {
              pieces[pointer++] = piece;
            }
            continue;
          }
          pieces[pointer++] = piece;
          positive++;
        }
        let path2 = "";
        for (let i = 1; i < pointer; i++) {
          path2 += "/" + pieces[i];
        }
        if (!path2 || addTrailingSlash && !path2.endsWith("/..")) {
          path2 += "/";
        }
        url.path = path2;
      }
      function resolve(input, base) {
        if (!input && !base)
          return "";
        const url = parseUrl(input);
        let inputType = url.type;
        if (base && inputType !== UrlType.Absolute) {
          const baseUrl = parseUrl(base);
          const baseType = baseUrl.type;
          switch (inputType) {
            case UrlType.Empty:
              url.hash = baseUrl.hash;
            case UrlType.Hash:
              url.query = baseUrl.query;
            case UrlType.Query:
            case UrlType.RelativePath:
              mergePaths(url, baseUrl);
            case UrlType.AbsolutePath:
              url.user = baseUrl.user;
              url.host = baseUrl.host;
              url.port = baseUrl.port;
            case UrlType.SchemeRelative:
              url.scheme = baseUrl.scheme;
          }
          if (baseType > inputType)
            inputType = baseType;
        }
        normalizePath(url, inputType);
        const queryHash = url.query + url.hash;
        switch (inputType) {
          case UrlType.Hash:
          case UrlType.Query:
            return queryHash;
          case UrlType.RelativePath: {
            const path2 = url.path.slice(1);
            if (!path2)
              return queryHash || ".";
            if (isRelative(base || input) && !isRelative(path2)) {
              return "./" + path2 + queryHash;
            }
            return path2 + queryHash;
          }
          case UrlType.AbsolutePath:
            return url.path + queryHash;
          default:
            return url.scheme + "//" + url.user + url.host + url.port + url.path + queryHash;
        }
      }
      return resolve;
    });
  }
});

// node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js
var require_trace_mapping_umd = __commonJS({
  "node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports, require_sourcemap_codec_umd(), require_resolve_uri_umd()) : typeof define === "function" && define.amd ? define(["exports", "@jridgewell/sourcemap-codec", "@jridgewell/resolve-uri"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, factory(global2.traceMapping = {}, global2.sourcemapCodec, global2.resolveURI));
    })(exports, function(exports2, sourcemapCodec, resolveUri) {
      "use strict";
      function _interopDefaultLegacy(e) {
        return e && typeof e === "object" && "default" in e ? e : { "default": e };
      }
      var resolveUri__default = /* @__PURE__ */ _interopDefaultLegacy(resolveUri);
      function resolve(input, base) {
        if (base && !base.endsWith("/"))
          base += "/";
        return resolveUri__default["default"](input, base);
      }
      function stripFilename(path2) {
        if (!path2)
          return "";
        const index = path2.lastIndexOf("/");
        return path2.slice(0, index + 1);
      }
      const COLUMN = 0;
      const SOURCES_INDEX = 1;
      const SOURCE_LINE = 2;
      const SOURCE_COLUMN = 3;
      const NAMES_INDEX = 4;
      const REV_GENERATED_LINE = 1;
      const REV_GENERATED_COLUMN = 2;
      function maybeSort(mappings, owned) {
        const unsortedIndex = nextUnsortedSegmentLine(mappings, 0);
        if (unsortedIndex === mappings.length)
          return mappings;
        if (!owned)
          mappings = mappings.slice();
        for (let i = unsortedIndex; i < mappings.length; i = nextUnsortedSegmentLine(mappings, i + 1)) {
          mappings[i] = sortSegments(mappings[i], owned);
        }
        return mappings;
      }
      function nextUnsortedSegmentLine(mappings, start) {
        for (let i = start; i < mappings.length; i++) {
          if (!isSorted(mappings[i]))
            return i;
        }
        return mappings.length;
      }
      function isSorted(line) {
        for (let j = 1; j < line.length; j++) {
          if (line[j][COLUMN] < line[j - 1][COLUMN]) {
            return false;
          }
        }
        return true;
      }
      function sortSegments(line, owned) {
        if (!owned)
          line = line.slice();
        return line.sort(sortComparator);
      }
      function sortComparator(a, b) {
        return a[COLUMN] - b[COLUMN];
      }
      let found = false;
      function binarySearch(haystack, needle, low, high) {
        while (low <= high) {
          const mid = low + (high - low >> 1);
          const cmp = haystack[mid][COLUMN] - needle;
          if (cmp === 0) {
            found = true;
            return mid;
          }
          if (cmp < 0) {
            low = mid + 1;
          } else {
            high = mid - 1;
          }
        }
        found = false;
        return low - 1;
      }
      function upperBound(haystack, needle, index) {
        for (let i = index + 1; i < haystack.length; index = i++) {
          if (haystack[i][COLUMN] !== needle)
            break;
        }
        return index;
      }
      function lowerBound(haystack, needle, index) {
        for (let i = index - 1; i >= 0; index = i--) {
          if (haystack[i][COLUMN] !== needle)
            break;
        }
        return index;
      }
      function memoizedState() {
        return {
          lastKey: -1,
          lastNeedle: -1,
          lastIndex: -1
        };
      }
      function memoizedBinarySearch(haystack, needle, state, key) {
        const { lastKey, lastNeedle, lastIndex } = state;
        let low = 0;
        let high = haystack.length - 1;
        if (key === lastKey) {
          if (needle === lastNeedle) {
            found = lastIndex !== -1 && haystack[lastIndex][COLUMN] === needle;
            return lastIndex;
          }
          if (needle >= lastNeedle) {
            low = lastIndex === -1 ? 0 : lastIndex;
          } else {
            high = lastIndex;
          }
        }
        state.lastKey = key;
        state.lastNeedle = needle;
        return state.lastIndex = binarySearch(haystack, needle, low, high);
      }
      function buildBySources(decoded, memos) {
        const sources = memos.map(buildNullArray);
        for (let i = 0; i < decoded.length; i++) {
          const line = decoded[i];
          for (let j = 0; j < line.length; j++) {
            const seg = line[j];
            if (seg.length === 1)
              continue;
            const sourceIndex = seg[SOURCES_INDEX];
            const sourceLine = seg[SOURCE_LINE];
            const sourceColumn = seg[SOURCE_COLUMN];
            const originalSource = sources[sourceIndex];
            const originalLine = originalSource[sourceLine] || (originalSource[sourceLine] = []);
            const memo = memos[sourceIndex];
            const index = upperBound(originalLine, sourceColumn, memoizedBinarySearch(originalLine, sourceColumn, memo, sourceLine));
            insert(originalLine, memo.lastIndex = index + 1, [sourceColumn, i, seg[COLUMN]]);
          }
        }
        return sources;
      }
      function insert(array, index, value2) {
        for (let i = array.length; i > index; i--) {
          array[i] = array[i - 1];
        }
        array[index] = value2;
      }
      function buildNullArray() {
        return { __proto__: null };
      }
      const AnyMap = function(map, mapUrl) {
        const parsed = typeof map === "string" ? JSON.parse(map) : map;
        if (!("sections" in parsed))
          return new TraceMap(parsed, mapUrl);
        const mappings = [];
        const sources = [];
        const sourcesContent = [];
        const names = [];
        recurse(parsed, mapUrl, mappings, sources, sourcesContent, names, 0, 0, Infinity, Infinity);
        const joined = {
          version: 3,
          file: parsed.file,
          names,
          sources,
          sourcesContent,
          mappings
        };
        return exports2.presortedDecodedMap(joined);
      };
      function recurse(input, mapUrl, mappings, sources, sourcesContent, names, lineOffset, columnOffset, stopLine, stopColumn) {
        const { sections } = input;
        for (let i = 0; i < sections.length; i++) {
          const { map, offset } = sections[i];
          let sl = stopLine;
          let sc = stopColumn;
          if (i + 1 < sections.length) {
            const nextOffset = sections[i + 1].offset;
            sl = Math.min(stopLine, lineOffset + nextOffset.line);
            if (sl === stopLine) {
              sc = Math.min(stopColumn, columnOffset + nextOffset.column);
            } else if (sl < stopLine) {
              sc = columnOffset + nextOffset.column;
            }
          }
          addSection(map, mapUrl, mappings, sources, sourcesContent, names, lineOffset + offset.line, columnOffset + offset.column, sl, sc);
        }
      }
      function addSection(input, mapUrl, mappings, sources, sourcesContent, names, lineOffset, columnOffset, stopLine, stopColumn) {
        if ("sections" in input)
          return recurse(...arguments);
        const map = new TraceMap(input, mapUrl);
        const sourcesOffset = sources.length;
        const namesOffset = names.length;
        const decoded = exports2.decodedMappings(map);
        const { resolvedSources, sourcesContent: contents } = map;
        append(sources, resolvedSources);
        append(names, map.names);
        if (contents)
          append(sourcesContent, contents);
        else
          for (let i = 0; i < resolvedSources.length; i++)
            sourcesContent.push(null);
        for (let i = 0; i < decoded.length; i++) {
          const lineI = lineOffset + i;
          if (lineI > stopLine)
            return;
          const out = getLine(mappings, lineI);
          const cOffset = i === 0 ? columnOffset : 0;
          const line = decoded[i];
          for (let j = 0; j < line.length; j++) {
            const seg = line[j];
            const column = cOffset + seg[COLUMN];
            if (lineI === stopLine && column >= stopColumn)
              return;
            if (seg.length === 1) {
              out.push([column]);
              continue;
            }
            const sourcesIndex = sourcesOffset + seg[SOURCES_INDEX];
            const sourceLine = seg[SOURCE_LINE];
            const sourceColumn = seg[SOURCE_COLUMN];
            out.push(seg.length === 4 ? [column, sourcesIndex, sourceLine, sourceColumn] : [column, sourcesIndex, sourceLine, sourceColumn, namesOffset + seg[NAMES_INDEX]]);
          }
        }
      }
      function append(arr, other) {
        for (let i = 0; i < other.length; i++)
          arr.push(other[i]);
      }
      function getLine(arr, index) {
        for (let i = arr.length; i <= index; i++)
          arr[i] = [];
        return arr[index];
      }
      const LINE_GTR_ZERO = "`line` must be greater than 0 (lines start at line 1)";
      const COL_GTR_EQ_ZERO = "`column` must be greater than or equal to 0 (columns start at column 0)";
      const LEAST_UPPER_BOUND = -1;
      const GREATEST_LOWER_BOUND = 1;
      exports2.encodedMappings = void 0;
      exports2.decodedMappings = void 0;
      exports2.traceSegment = void 0;
      exports2.originalPositionFor = void 0;
      exports2.generatedPositionFor = void 0;
      exports2.allGeneratedPositionsFor = void 0;
      exports2.eachMapping = void 0;
      exports2.sourceContentFor = void 0;
      exports2.presortedDecodedMap = void 0;
      exports2.decodedMap = void 0;
      exports2.encodedMap = void 0;
      class TraceMap {
        constructor(map, mapUrl) {
          const isString = typeof map === "string";
          if (!isString && map._decodedMemo)
            return map;
          const parsed = isString ? JSON.parse(map) : map;
          const { version: version2, file, names, sourceRoot, sources, sourcesContent } = parsed;
          this.version = version2;
          this.file = file;
          this.names = names;
          this.sourceRoot = sourceRoot;
          this.sources = sources;
          this.sourcesContent = sourcesContent;
          const from = resolve(sourceRoot || "", stripFilename(mapUrl));
          this.resolvedSources = sources.map((s) => resolve(s || "", from));
          const { mappings } = parsed;
          if (typeof mappings === "string") {
            this._encoded = mappings;
            this._decoded = void 0;
          } else {
            this._encoded = void 0;
            this._decoded = maybeSort(mappings, isString);
          }
          this._decodedMemo = memoizedState();
          this._bySources = void 0;
          this._bySourceMemos = void 0;
        }
      }
      (() => {
        exports2.encodedMappings = (map) => {
          var _a;
          return (_a = map._encoded) !== null && _a !== void 0 ? _a : map._encoded = sourcemapCodec.encode(map._decoded);
        };
        exports2.decodedMappings = (map) => {
          return map._decoded || (map._decoded = sourcemapCodec.decode(map._encoded));
        };
        exports2.traceSegment = (map, line, column) => {
          const decoded = exports2.decodedMappings(map);
          if (line >= decoded.length)
            return null;
          const segments = decoded[line];
          const index = traceSegmentInternal(segments, map._decodedMemo, line, column, GREATEST_LOWER_BOUND);
          return index === -1 ? null : segments[index];
        };
        exports2.originalPositionFor = (map, { line, column, bias }) => {
          line--;
          if (line < 0)
            throw new Error(LINE_GTR_ZERO);
          if (column < 0)
            throw new Error(COL_GTR_EQ_ZERO);
          const decoded = exports2.decodedMappings(map);
          if (line >= decoded.length)
            return OMapping(null, null, null, null);
          const segments = decoded[line];
          const index = traceSegmentInternal(segments, map._decodedMemo, line, column, bias || GREATEST_LOWER_BOUND);
          if (index === -1)
            return OMapping(null, null, null, null);
          const segment = segments[index];
          if (segment.length === 1)
            return OMapping(null, null, null, null);
          const { names, resolvedSources } = map;
          return OMapping(resolvedSources[segment[SOURCES_INDEX]], segment[SOURCE_LINE] + 1, segment[SOURCE_COLUMN], segment.length === 5 ? names[segment[NAMES_INDEX]] : null);
        };
        exports2.allGeneratedPositionsFor = (map, { source, line, column, bias }) => {
          return generatedPosition(map, source, line, column, bias || LEAST_UPPER_BOUND, true);
        };
        exports2.generatedPositionFor = (map, { source, line, column, bias }) => {
          return generatedPosition(map, source, line, column, bias || GREATEST_LOWER_BOUND, false);
        };
        exports2.eachMapping = (map, cb) => {
          const decoded = exports2.decodedMappings(map);
          const { names, resolvedSources } = map;
          for (let i = 0; i < decoded.length; i++) {
            const line = decoded[i];
            for (let j = 0; j < line.length; j++) {
              const seg = line[j];
              const generatedLine = i + 1;
              const generatedColumn = seg[0];
              let source = null;
              let originalLine = null;
              let originalColumn = null;
              let name = null;
              if (seg.length !== 1) {
                source = resolvedSources[seg[1]];
                originalLine = seg[2] + 1;
                originalColumn = seg[3];
              }
              if (seg.length === 5)
                name = names[seg[4]];
              cb({
                generatedLine,
                generatedColumn,
                source,
                originalLine,
                originalColumn,
                name
              });
            }
          }
        };
        exports2.sourceContentFor = (map, source) => {
          const { sources, resolvedSources, sourcesContent } = map;
          if (sourcesContent == null)
            return null;
          let index = sources.indexOf(source);
          if (index === -1)
            index = resolvedSources.indexOf(source);
          return index === -1 ? null : sourcesContent[index];
        };
        exports2.presortedDecodedMap = (map, mapUrl) => {
          const tracer = new TraceMap(clone(map, []), mapUrl);
          tracer._decoded = map.mappings;
          return tracer;
        };
        exports2.decodedMap = (map) => {
          return clone(map, exports2.decodedMappings(map));
        };
        exports2.encodedMap = (map) => {
          return clone(map, exports2.encodedMappings(map));
        };
        function generatedPosition(map, source, line, column, bias, all) {
          line--;
          if (line < 0)
            throw new Error(LINE_GTR_ZERO);
          if (column < 0)
            throw new Error(COL_GTR_EQ_ZERO);
          const { sources, resolvedSources } = map;
          let sourceIndex = sources.indexOf(source);
          if (sourceIndex === -1)
            sourceIndex = resolvedSources.indexOf(source);
          if (sourceIndex === -1)
            return all ? [] : GMapping(null, null);
          const generated = map._bySources || (map._bySources = buildBySources(exports2.decodedMappings(map), map._bySourceMemos = sources.map(memoizedState)));
          const segments = generated[sourceIndex][line];
          if (segments == null)
            return all ? [] : GMapping(null, null);
          const memo = map._bySourceMemos[sourceIndex];
          if (all)
            return sliceGeneratedPositions(segments, memo, line, column, bias);
          const index = traceSegmentInternal(segments, memo, line, column, bias);
          if (index === -1)
            return GMapping(null, null);
          const segment = segments[index];
          return GMapping(segment[REV_GENERATED_LINE] + 1, segment[REV_GENERATED_COLUMN]);
        }
      })();
      function clone(map, mappings) {
        return {
          version: map.version,
          file: map.file,
          names: map.names,
          sourceRoot: map.sourceRoot,
          sources: map.sources,
          sourcesContent: map.sourcesContent,
          mappings
        };
      }
      function OMapping(source, line, column, name) {
        return { source, line, column, name };
      }
      function GMapping(line, column) {
        return { line, column };
      }
      function traceSegmentInternal(segments, memo, line, column, bias) {
        let index = memoizedBinarySearch(segments, column, memo, line);
        if (found) {
          index = (bias === LEAST_UPPER_BOUND ? upperBound : lowerBound)(segments, column, index);
        } else if (bias === LEAST_UPPER_BOUND)
          index++;
        if (index === -1 || index === segments.length)
          return -1;
        return index;
      }
      function sliceGeneratedPositions(segments, memo, line, column, bias) {
        let min2 = traceSegmentInternal(segments, memo, line, column, GREATEST_LOWER_BOUND);
        if (!found && bias === LEAST_UPPER_BOUND)
          min2++;
        if (min2 === -1 || min2 === segments.length)
          return [];
        const matchedColumn = found ? column : segments[min2][COLUMN];
        if (!found)
          min2 = lowerBound(segments, matchedColumn, min2);
        const max2 = upperBound(segments, matchedColumn, min2);
        const result = [];
        for (; min2 <= max2; min2++) {
          const segment = segments[min2];
          result.push(GMapping(segment[REV_GENERATED_LINE] + 1, segment[REV_GENERATED_COLUMN]));
        }
        return result;
      }
      exports2.AnyMap = AnyMap;
      exports2.GREATEST_LOWER_BOUND = GREATEST_LOWER_BOUND;
      exports2.LEAST_UPPER_BOUND = LEAST_UPPER_BOUND;
      exports2.TraceMap = TraceMap;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js
var require_gen_mapping_umd = __commonJS({
  "node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports, require_set_array_umd(), require_sourcemap_codec_umd(), require_trace_mapping_umd()) : typeof define === "function" && define.amd ? define(["exports", "@jridgewell/set-array", "@jridgewell/sourcemap-codec", "@jridgewell/trace-mapping"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, factory(global2.genMapping = {}, global2.setArray, global2.sourcemapCodec, global2.traceMapping));
    })(exports, function(exports2, setArray, sourcemapCodec, traceMapping) {
      "use strict";
      const COLUMN = 0;
      const SOURCES_INDEX = 1;
      const SOURCE_LINE = 2;
      const SOURCE_COLUMN = 3;
      const NAMES_INDEX = 4;
      const NO_NAME = -1;
      exports2.addSegment = void 0;
      exports2.addMapping = void 0;
      exports2.maybeAddSegment = void 0;
      exports2.maybeAddMapping = void 0;
      exports2.setSourceContent = void 0;
      exports2.toDecodedMap = void 0;
      exports2.toEncodedMap = void 0;
      exports2.fromMap = void 0;
      exports2.allMappings = void 0;
      let addSegmentInternal;
      class GenMapping {
        constructor({ file, sourceRoot } = {}) {
          this._names = new setArray.SetArray();
          this._sources = new setArray.SetArray();
          this._sourcesContent = [];
          this._mappings = [];
          this.file = file;
          this.sourceRoot = sourceRoot;
        }
      }
      (() => {
        exports2.addSegment = (map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) => {
          return addSegmentInternal(false, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content);
        };
        exports2.maybeAddSegment = (map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) => {
          return addSegmentInternal(true, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content);
        };
        exports2.addMapping = (map, mapping) => {
          return addMappingInternal(false, map, mapping);
        };
        exports2.maybeAddMapping = (map, mapping) => {
          return addMappingInternal(true, map, mapping);
        };
        exports2.setSourceContent = (map, source, content) => {
          const { _sources: sources, _sourcesContent: sourcesContent } = map;
          sourcesContent[setArray.put(sources, source)] = content;
        };
        exports2.toDecodedMap = (map) => {
          const { file, sourceRoot, _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names } = map;
          removeEmptyFinalLines(mappings);
          return {
            version: 3,
            file: file || void 0,
            names: names.array,
            sourceRoot: sourceRoot || void 0,
            sources: sources.array,
            sourcesContent,
            mappings
          };
        };
        exports2.toEncodedMap = (map) => {
          const decoded = exports2.toDecodedMap(map);
          return Object.assign(Object.assign({}, decoded), { mappings: sourcemapCodec.encode(decoded.mappings) });
        };
        exports2.allMappings = (map) => {
          const out = [];
          const { _mappings: mappings, _sources: sources, _names: names } = map;
          for (let i = 0; i < mappings.length; i++) {
            const line = mappings[i];
            for (let j = 0; j < line.length; j++) {
              const seg = line[j];
              const generated = { line: i + 1, column: seg[COLUMN] };
              let source = void 0;
              let original = void 0;
              let name = void 0;
              if (seg.length !== 1) {
                source = sources.array[seg[SOURCES_INDEX]];
                original = { line: seg[SOURCE_LINE] + 1, column: seg[SOURCE_COLUMN] };
                if (seg.length === 5)
                  name = names.array[seg[NAMES_INDEX]];
              }
              out.push({ generated, source, original, name });
            }
          }
          return out;
        };
        exports2.fromMap = (input) => {
          const map = new traceMapping.TraceMap(input);
          const gen = new GenMapping({ file: map.file, sourceRoot: map.sourceRoot });
          putAll(gen._names, map.names);
          putAll(gen._sources, map.sources);
          gen._sourcesContent = map.sourcesContent || map.sources.map(() => null);
          gen._mappings = traceMapping.decodedMappings(map);
          return gen;
        };
        addSegmentInternal = (skipable, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) => {
          const { _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names } = map;
          const line = getLine(mappings, genLine);
          const index = getColumnIndex(line, genColumn);
          if (!source) {
            if (skipable && skipSourceless(line, index))
              return;
            return insert(line, index, [genColumn]);
          }
          const sourcesIndex = setArray.put(sources, source);
          const namesIndex = name ? setArray.put(names, name) : NO_NAME;
          if (sourcesIndex === sourcesContent.length)
            sourcesContent[sourcesIndex] = content !== null && content !== void 0 ? content : null;
          if (skipable && skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex)) {
            return;
          }
          return insert(line, index, name ? [genColumn, sourcesIndex, sourceLine, sourceColumn, namesIndex] : [genColumn, sourcesIndex, sourceLine, sourceColumn]);
        };
      })();
      function getLine(mappings, index) {
        for (let i = mappings.length; i <= index; i++) {
          mappings[i] = [];
        }
        return mappings[index];
      }
      function getColumnIndex(line, genColumn) {
        let index = line.length;
        for (let i = index - 1; i >= 0; index = i--) {
          const current = line[i];
          if (genColumn >= current[COLUMN])
            break;
        }
        return index;
      }
      function insert(array, index, value2) {
        for (let i = array.length; i > index; i--) {
          array[i] = array[i - 1];
        }
        array[index] = value2;
      }
      function removeEmptyFinalLines(mappings) {
        const { length } = mappings;
        let len = length;
        for (let i = len - 1; i >= 0; len = i, i--) {
          if (mappings[i].length > 0)
            break;
        }
        if (len < length)
          mappings.length = len;
      }
      function putAll(strarr, array) {
        for (let i = 0; i < array.length; i++)
          setArray.put(strarr, array[i]);
      }
      function skipSourceless(line, index) {
        if (index === 0)
          return true;
        const prev = line[index - 1];
        return prev.length === 1;
      }
      function skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex) {
        if (index === 0)
          return false;
        const prev = line[index - 1];
        if (prev.length === 1)
          return false;
        return sourcesIndex === prev[SOURCES_INDEX] && sourceLine === prev[SOURCE_LINE] && sourceColumn === prev[SOURCE_COLUMN] && namesIndex === (prev.length === 5 ? prev[NAMES_INDEX] : NO_NAME);
      }
      function addMappingInternal(skipable, map, mapping) {
        const { generated, source, original, name, content } = mapping;
        if (!source) {
          return addSegmentInternal(skipable, map, generated.line - 1, generated.column, null, null, null, null, null);
        }
        const s = source;
        return addSegmentInternal(skipable, map, generated.line - 1, generated.column, s, original.line - 1, original.column, name, content);
      }
      exports2.GenMapping = GenMapping;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/@babel/generator/lib/source-map.js
var require_source_map = __commonJS({
  "node_modules/@babel/generator/lib/source-map.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _genMapping = require_gen_mapping_umd();
    var SourceMap = class {
      constructor(opts, code) {
        var _opts$sourceFileName;
        this._map = void 0;
        this._rawMappings = void 0;
        this._sourceFileName = void 0;
        this._lastGenLine = 0;
        this._lastSourceLine = 0;
        this._lastSourceColumn = 0;
        const map = this._map = new _genMapping.GenMapping({
          sourceRoot: opts.sourceRoot
        });
        this._sourceFileName = (_opts$sourceFileName = opts.sourceFileName) == null ? void 0 : _opts$sourceFileName.replace(/\\/g, "/");
        this._rawMappings = void 0;
        if (typeof code === "string") {
          (0, _genMapping.setSourceContent)(map, this._sourceFileName, code);
        } else if (typeof code === "object") {
          Object.keys(code).forEach((sourceFileName) => {
            (0, _genMapping.setSourceContent)(map, sourceFileName.replace(/\\/g, "/"), code[sourceFileName]);
          });
        }
      }
      get() {
        return (0, _genMapping.toEncodedMap)(this._map);
      }
      getDecoded() {
        return (0, _genMapping.toDecodedMap)(this._map);
      }
      getRawMappings() {
        return this._rawMappings || (this._rawMappings = (0, _genMapping.allMappings)(this._map));
      }
      mark(generated, line, column, identifierName, filename) {
        this._rawMappings = void 0;
        (0, _genMapping.maybeAddMapping)(this._map, {
          name: identifierName,
          generated,
          source: line == null ? void 0 : (filename == null ? void 0 : filename.replace(/\\/g, "/")) || this._sourceFileName,
          original: line == null ? void 0 : {
            line,
            column
          }
        });
      }
    };
    exports.default = SourceMap;
  }
});

// node_modules/@babel/generator/lib/buffer.js
var require_buffer2 = __commonJS({
  "node_modules/@babel/generator/lib/buffer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var Buffer2 = class {
      constructor(map) {
        this._map = null;
        this._buf = "";
        this._str = "";
        this._appendCount = 0;
        this._last = 0;
        this._queue = [];
        this._queueCursor = 0;
        this._position = {
          line: 1,
          column: 0
        };
        this._sourcePosition = {
          identifierName: void 0,
          line: void 0,
          column: void 0,
          filename: void 0
        };
        this._map = map;
        this._allocQueue();
      }
      _allocQueue() {
        const queue = this._queue;
        for (let i = 0; i < 16; i++) {
          queue.push({
            char: 0,
            repeat: 1,
            line: void 0,
            column: void 0,
            identifierName: void 0,
            filename: ""
          });
        }
      }
      _pushQueue(char, repeat, line, column, identifierName, filename) {
        const cursor = this._queueCursor;
        if (cursor === this._queue.length) {
          this._allocQueue();
        }
        const item = this._queue[cursor];
        item.char = char;
        item.repeat = repeat;
        item.line = line;
        item.column = column;
        item.identifierName = identifierName;
        item.filename = filename;
        this._queueCursor++;
      }
      _popQueue() {
        if (this._queueCursor === 0) {
          throw new Error("Cannot pop from empty queue");
        }
        return this._queue[--this._queueCursor];
      }
      get() {
        this._flush();
        const map = this._map;
        const result = {
          code: (this._buf + this._str).trimRight(),
          decodedMap: map == null ? void 0 : map.getDecoded(),
          get map() {
            const resultMap = map ? map.get() : null;
            result.map = resultMap;
            return resultMap;
          },
          set map(value2) {
            Object.defineProperty(result, "map", {
              value: value2,
              writable: true
            });
          },
          get rawMappings() {
            const mappings = map == null ? void 0 : map.getRawMappings();
            result.rawMappings = mappings;
            return mappings;
          },
          set rawMappings(value2) {
            Object.defineProperty(result, "rawMappings", {
              value: value2,
              writable: true
            });
          }
        };
        return result;
      }
      append(str, maybeNewline) {
        this._flush();
        this._append(str, this._sourcePosition, maybeNewline);
      }
      appendChar(char) {
        this._flush();
        this._appendChar(char, 1, this._sourcePosition);
      }
      queue(char) {
        if (char === 10) {
          while (this._queueCursor !== 0) {
            const char2 = this._queue[this._queueCursor - 1].char;
            if (char2 !== 32 && char2 !== 9) {
              break;
            }
            this._queueCursor--;
          }
        }
        const sourcePosition = this._sourcePosition;
        this._pushQueue(char, 1, sourcePosition.line, sourcePosition.column, sourcePosition.identifierName, sourcePosition.filename);
      }
      queueIndentation(char, repeat) {
        this._pushQueue(char, repeat, void 0, void 0, void 0, void 0);
      }
      _flush() {
        const queueCursor = this._queueCursor;
        const queue = this._queue;
        for (let i = 0; i < queueCursor; i++) {
          const item = queue[i];
          this._appendChar(item.char, item.repeat, item);
        }
        this._queueCursor = 0;
      }
      _appendChar(char, repeat, sourcePos) {
        this._last = char;
        this._str += repeat > 1 ? String.fromCharCode(char).repeat(repeat) : String.fromCharCode(char);
        if (char !== 10) {
          this._mark(sourcePos.line, sourcePos.column, sourcePos.identifierName, sourcePos.filename);
          this._position.column += repeat;
        } else {
          this._position.line++;
          this._position.column = 0;
        }
      }
      _append(str, sourcePos, maybeNewline) {
        const len = str.length;
        const position = this._position;
        this._last = str.charCodeAt(len - 1);
        if (++this._appendCount > 4096) {
          +this._str;
          this._buf += this._str;
          this._str = str;
          this._appendCount = 0;
        } else {
          this._str += str;
        }
        if (!maybeNewline && !this._map) {
          position.column += len;
          return;
        }
        const {
          column,
          identifierName,
          filename
        } = sourcePos;
        let line = sourcePos.line;
        let i = str.indexOf("\n");
        let last2 = 0;
        if (i !== 0) {
          this._mark(line, column, identifierName, filename);
        }
        while (i !== -1) {
          position.line++;
          position.column = 0;
          last2 = i + 1;
          if (last2 < len) {
            this._mark(++line, 0, identifierName, filename);
          }
          i = str.indexOf("\n", last2);
        }
        position.column += len - last2;
      }
      _mark(line, column, identifierName, filename) {
        var _this$_map;
        (_this$_map = this._map) == null ? void 0 : _this$_map.mark(this._position, line, column, identifierName, filename);
      }
      removeTrailingNewline() {
        const queueCursor = this._queueCursor;
        if (queueCursor !== 0 && this._queue[queueCursor - 1].char === 10) {
          this._queueCursor--;
        }
      }
      removeLastSemicolon() {
        const queueCursor = this._queueCursor;
        if (queueCursor !== 0 && this._queue[queueCursor - 1].char === 59) {
          this._queueCursor--;
        }
      }
      getLastChar() {
        const queueCursor = this._queueCursor;
        return queueCursor !== 0 ? this._queue[queueCursor - 1].char : this._last;
      }
      getNewlineCount() {
        const queueCursor = this._queueCursor;
        let count = 0;
        if (queueCursor === 0)
          return this._last === 10 ? 1 : 0;
        for (let i = queueCursor - 1; i >= 0; i--) {
          if (this._queue[i].char !== 10) {
            break;
          }
          count++;
        }
        return count === queueCursor && this._last === 10 ? count + 1 : count;
      }
      endsWithCharAndNewline() {
        const queue = this._queue;
        const queueCursor = this._queueCursor;
        if (queueCursor !== 0) {
          const lastCp = queue[queueCursor - 1].char;
          if (lastCp !== 10)
            return;
          if (queueCursor > 1) {
            return queue[queueCursor - 2].char;
          } else {
            return this._last;
          }
        }
      }
      hasContent() {
        return this._queueCursor !== 0 || !!this._last;
      }
      exactSource(loc, cb) {
        if (!this._map)
          return cb();
        this.source("start", loc);
        cb();
        this.source("end", loc);
      }
      source(prop, loc) {
        if (!this._map)
          return;
        this._normalizePosition(prop, loc, 0, 0);
      }
      sourceWithOffset(prop, loc, lineOffset, columnOffset) {
        if (!this._map)
          return;
        this._normalizePosition(prop, loc, lineOffset, columnOffset);
      }
      withSource(prop, loc, cb) {
        if (!this._map)
          return cb();
        this.source(prop, loc);
        cb();
      }
      _normalizePosition(prop, loc, lineOffset, columnOffset) {
        const pos = loc[prop];
        const target = this._sourcePosition;
        target.identifierName = prop === "start" && loc.identifierName || void 0;
        if (pos) {
          target.line = pos.line + lineOffset;
          target.column = pos.column + columnOffset;
          target.filename = loc.filename;
        }
      }
      getCurrentColumn() {
        const queue = this._queue;
        const queueCursor = this._queueCursor;
        let lastIndex = -1;
        let len = 0;
        for (let i = 0; i < queueCursor; i++) {
          const item = queue[i];
          if (item.char === 10) {
            lastIndex = len;
          }
          len += item.repeat;
        }
        return lastIndex === -1 ? this._position.column + len : len - 1 - lastIndex;
      }
      getCurrentLine() {
        let count = 0;
        const queue = this._queue;
        for (let i = 0; i < this._queueCursor; i++) {
          if (queue[i].char === 10) {
            count++;
          }
        }
        return this._position.line + count;
      }
    };
    exports.default = Buffer2;
  }
});

// node_modules/@babel/generator/lib/node/whitespace.js
var require_whitespace = __commonJS({
  "node_modules/@babel/generator/lib/node/whitespace.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.nodes = void 0;
    var _t = require_lib11();
    var {
      FLIPPED_ALIAS_KEYS,
      isArrayExpression,
      isAssignmentExpression,
      isBinary,
      isBlockStatement: isBlockStatement2,
      isCallExpression: isCallExpression2,
      isFunction,
      isIdentifier: isIdentifier2,
      isLiteral,
      isMemberExpression,
      isObjectExpression,
      isOptionalCallExpression,
      isOptionalMemberExpression,
      isStringLiteral: isStringLiteral3
    } = _t;
    function crawlInternal(node, state) {
      if (!node)
        return state;
      if (isMemberExpression(node) || isOptionalMemberExpression(node)) {
        crawlInternal(node.object, state);
        if (node.computed)
          crawlInternal(node.property, state);
      } else if (isBinary(node) || isAssignmentExpression(node)) {
        crawlInternal(node.left, state);
        crawlInternal(node.right, state);
      } else if (isCallExpression2(node) || isOptionalCallExpression(node)) {
        state.hasCall = true;
        crawlInternal(node.callee, state);
      } else if (isFunction(node)) {
        state.hasFunction = true;
      } else if (isIdentifier2(node)) {
        state.hasHelper = state.hasHelper || node.callee && isHelper(node.callee);
      }
      return state;
    }
    function crawl(node) {
      return crawlInternal(node, {
        hasCall: false,
        hasFunction: false,
        hasHelper: false
      });
    }
    function isHelper(node) {
      if (!node)
        return false;
      if (isMemberExpression(node)) {
        return isHelper(node.object) || isHelper(node.property);
      } else if (isIdentifier2(node)) {
        return node.name === "require" || node.name.charCodeAt(0) === 95;
      } else if (isCallExpression2(node)) {
        return isHelper(node.callee);
      } else if (isBinary(node) || isAssignmentExpression(node)) {
        return isIdentifier2(node.left) && isHelper(node.left) || isHelper(node.right);
      } else {
        return false;
      }
    }
    function isType(node) {
      return isLiteral(node) || isObjectExpression(node) || isArrayExpression(node) || isIdentifier2(node) || isMemberExpression(node);
    }
    var nodes = {
      AssignmentExpression(node) {
        const state = crawl(node.right);
        if (state.hasCall && state.hasHelper || state.hasFunction) {
          return state.hasFunction ? 1 | 2 : 2;
        }
      },
      SwitchCase(node, parent) {
        return (!!node.consequent.length || parent.cases[0] === node ? 1 : 0) | (!node.consequent.length && parent.cases[parent.cases.length - 1] === node ? 2 : 0);
      },
      LogicalExpression(node) {
        if (isFunction(node.left) || isFunction(node.right)) {
          return 2;
        }
      },
      Literal(node) {
        if (isStringLiteral3(node) && node.value === "use strict") {
          return 2;
        }
      },
      CallExpression(node) {
        if (isFunction(node.callee) || isHelper(node)) {
          return 1 | 2;
        }
      },
      OptionalCallExpression(node) {
        if (isFunction(node.callee)) {
          return 1 | 2;
        }
      },
      VariableDeclaration(node) {
        for (let i = 0; i < node.declarations.length; i++) {
          const declar = node.declarations[i];
          let enabled = isHelper(declar.id) && !isType(declar.init);
          if (!enabled && declar.init) {
            const state = crawl(declar.init);
            enabled = isHelper(declar.init) && state.hasCall || state.hasFunction;
          }
          if (enabled) {
            return 1 | 2;
          }
        }
      },
      IfStatement(node) {
        if (isBlockStatement2(node.consequent)) {
          return 1 | 2;
        }
      }
    };
    exports.nodes = nodes;
    nodes.ObjectProperty = nodes.ObjectTypeProperty = nodes.ObjectMethod = function(node, parent) {
      if (parent.properties[0] === node) {
        return 1;
      }
    };
    nodes.ObjectTypeCallProperty = function(node, parent) {
      var _parent$properties;
      if (parent.callProperties[0] === node && !((_parent$properties = parent.properties) != null && _parent$properties.length)) {
        return 1;
      }
    };
    nodes.ObjectTypeIndexer = function(node, parent) {
      var _parent$properties2, _parent$callPropertie;
      if (parent.indexers[0] === node && !((_parent$properties2 = parent.properties) != null && _parent$properties2.length) && !((_parent$callPropertie = parent.callProperties) != null && _parent$callPropertie.length)) {
        return 1;
      }
    };
    nodes.ObjectTypeInternalSlot = function(node, parent) {
      var _parent$properties3, _parent$callPropertie2, _parent$indexers;
      if (parent.internalSlots[0] === node && !((_parent$properties3 = parent.properties) != null && _parent$properties3.length) && !((_parent$callPropertie2 = parent.callProperties) != null && _parent$callPropertie2.length) && !((_parent$indexers = parent.indexers) != null && _parent$indexers.length)) {
        return 1;
      }
    };
    [["Function", true], ["Class", true], ["Loop", true], ["LabeledStatement", true], ["SwitchStatement", true], ["TryStatement", true]].forEach(function([type, amounts]) {
      [type].concat(FLIPPED_ALIAS_KEYS[type] || []).forEach(function(type2) {
        const ret = amounts ? 1 | 2 : 0;
        nodes[type2] = () => ret;
      });
    });
  }
});

// node_modules/@babel/generator/lib/node/parentheses.js
var require_parentheses = __commonJS({
  "node_modules/@babel/generator/lib/node/parentheses.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ArrowFunctionExpression = ArrowFunctionExpression;
    exports.AssignmentExpression = AssignmentExpression;
    exports.Binary = Binary;
    exports.BinaryExpression = BinaryExpression;
    exports.ClassExpression = ClassExpression;
    exports.ConditionalExpression = ConditionalExpression;
    exports.DoExpression = DoExpression;
    exports.FunctionExpression = FunctionExpression;
    exports.FunctionTypeAnnotation = FunctionTypeAnnotation;
    exports.Identifier = Identifier;
    exports.LogicalExpression = LogicalExpression;
    exports.NullableTypeAnnotation = NullableTypeAnnotation;
    exports.ObjectExpression = ObjectExpression;
    exports.OptionalIndexedAccessType = OptionalIndexedAccessType;
    exports.OptionalCallExpression = exports.OptionalMemberExpression = OptionalMemberExpression;
    exports.SequenceExpression = SequenceExpression;
    exports.TSTypeAssertion = exports.TSSatisfiesExpression = exports.TSAsExpression = TSAsExpression;
    exports.TSInferType = TSInferType;
    exports.TSInstantiationExpression = TSInstantiationExpression;
    exports.TSIntersectionType = exports.TSUnionType = TSUnionType;
    exports.UnaryLike = UnaryLike;
    exports.IntersectionTypeAnnotation = exports.UnionTypeAnnotation = UnionTypeAnnotation;
    exports.UpdateExpression = UpdateExpression;
    exports.AwaitExpression = exports.YieldExpression = YieldExpression;
    var _t = require_lib11();
    var {
      isArrayTypeAnnotation,
      isArrowFunctionExpression,
      isAssignmentExpression,
      isAwaitExpression,
      isBinary,
      isBinaryExpression,
      isUpdateExpression,
      isCallExpression: isCallExpression2,
      isClass,
      isClassExpression,
      isConditional,
      isConditionalExpression,
      isExportDeclaration,
      isExportDefaultDeclaration,
      isExpressionStatement,
      isFor,
      isForInStatement,
      isForOfStatement,
      isForStatement,
      isFunctionExpression,
      isIfStatement,
      isIndexedAccessType,
      isIntersectionTypeAnnotation,
      isLogicalExpression,
      isMemberExpression,
      isNewExpression,
      isNullableTypeAnnotation,
      isObjectPattern,
      isOptionalCallExpression,
      isOptionalMemberExpression,
      isReturnStatement: isReturnStatement2,
      isSequenceExpression,
      isSwitchStatement,
      isTSArrayType,
      isTSAsExpression,
      isTSInstantiationExpression,
      isTSIntersectionType,
      isTSNonNullExpression,
      isTSOptionalType,
      isTSRestType,
      isTSTypeAssertion,
      isTSUnionType,
      isTaggedTemplateExpression,
      isThrowStatement,
      isTypeAnnotation,
      isUnaryLike,
      isUnionTypeAnnotation,
      isVariableDeclarator: isVariableDeclarator2,
      isWhileStatement,
      isYieldExpression,
      isTSSatisfiesExpression
    } = _t;
    var PRECEDENCE = {
      "||": 0,
      "??": 0,
      "|>": 0,
      "&&": 1,
      "|": 2,
      "^": 3,
      "&": 4,
      "==": 5,
      "===": 5,
      "!=": 5,
      "!==": 5,
      "<": 6,
      ">": 6,
      "<=": 6,
      ">=": 6,
      in: 6,
      instanceof: 6,
      ">>": 7,
      "<<": 7,
      ">>>": 7,
      "+": 8,
      "-": 8,
      "*": 9,
      "/": 9,
      "%": 9,
      "**": 10
    };
    function isTSTypeExpression(node) {
      return isTSAsExpression(node) || isTSSatisfiesExpression(node) || isTSTypeAssertion(node);
    }
    var isClassExtendsClause = (node, parent) => isClass(parent, {
      superClass: node
    });
    var hasPostfixPart = (node, parent) => (isMemberExpression(parent) || isOptionalMemberExpression(parent)) && parent.object === node || (isCallExpression2(parent) || isOptionalCallExpression(parent) || isNewExpression(parent)) && parent.callee === node || isTaggedTemplateExpression(parent) && parent.tag === node || isTSNonNullExpression(parent);
    function NullableTypeAnnotation(node, parent) {
      return isArrayTypeAnnotation(parent);
    }
    function FunctionTypeAnnotation(node, parent, printStack) {
      if (printStack.length < 3)
        return;
      return isUnionTypeAnnotation(parent) || isIntersectionTypeAnnotation(parent) || isArrayTypeAnnotation(parent) || isTypeAnnotation(parent) && isArrowFunctionExpression(printStack[printStack.length - 3]);
    }
    function UpdateExpression(node, parent) {
      return hasPostfixPart(node, parent) || isClassExtendsClause(node, parent);
    }
    function ObjectExpression(node, parent, printStack) {
      return isFirstInContext(printStack, 1 | 2);
    }
    function DoExpression(node, parent, printStack) {
      return !node.async && isFirstInContext(printStack, 1);
    }
    function Binary(node, parent) {
      if (node.operator === "**" && isBinaryExpression(parent, {
        operator: "**"
      })) {
        return parent.left === node;
      }
      if (isClassExtendsClause(node, parent)) {
        return true;
      }
      if (hasPostfixPart(node, parent) || isUnaryLike(parent) || isAwaitExpression(parent)) {
        return true;
      }
      if (isBinary(parent)) {
        const parentOp = parent.operator;
        const parentPos = PRECEDENCE[parentOp];
        const nodeOp = node.operator;
        const nodePos = PRECEDENCE[nodeOp];
        if (parentPos === nodePos && parent.right === node && !isLogicalExpression(parent) || parentPos > nodePos) {
          return true;
        }
      }
    }
    function UnionTypeAnnotation(node, parent) {
      return isArrayTypeAnnotation(parent) || isNullableTypeAnnotation(parent) || isIntersectionTypeAnnotation(parent) || isUnionTypeAnnotation(parent);
    }
    function OptionalIndexedAccessType(node, parent) {
      return isIndexedAccessType(parent, {
        objectType: node
      });
    }
    function TSAsExpression() {
      return true;
    }
    function TSUnionType(node, parent) {
      return isTSArrayType(parent) || isTSOptionalType(parent) || isTSIntersectionType(parent) || isTSUnionType(parent) || isTSRestType(parent);
    }
    function TSInferType(node, parent) {
      return isTSArrayType(parent) || isTSOptionalType(parent);
    }
    function TSInstantiationExpression(node, parent) {
      return (isCallExpression2(parent) || isOptionalCallExpression(parent) || isNewExpression(parent) || isTSInstantiationExpression(parent)) && !!parent.typeParameters;
    }
    function BinaryExpression(node, parent) {
      return node.operator === "in" && (isVariableDeclarator2(parent) || isFor(parent));
    }
    function SequenceExpression(node, parent) {
      if (isForStatement(parent) || isThrowStatement(parent) || isReturnStatement2(parent) || isIfStatement(parent) && parent.test === node || isWhileStatement(parent) && parent.test === node || isForInStatement(parent) && parent.right === node || isSwitchStatement(parent) && parent.discriminant === node || isExpressionStatement(parent) && parent.expression === node) {
        return false;
      }
      return true;
    }
    function YieldExpression(node, parent) {
      return isBinary(parent) || isUnaryLike(parent) || hasPostfixPart(node, parent) || isAwaitExpression(parent) && isYieldExpression(node) || isConditionalExpression(parent) && node === parent.test || isClassExtendsClause(node, parent);
    }
    function ClassExpression(node, parent, printStack) {
      return isFirstInContext(printStack, 1 | 4);
    }
    function UnaryLike(node, parent) {
      return hasPostfixPart(node, parent) || isBinaryExpression(parent, {
        operator: "**",
        left: node
      }) || isClassExtendsClause(node, parent);
    }
    function FunctionExpression(node, parent, printStack) {
      return isFirstInContext(printStack, 1 | 4);
    }
    function ArrowFunctionExpression(node, parent) {
      return isExportDeclaration(parent) || ConditionalExpression(node, parent);
    }
    function ConditionalExpression(node, parent) {
      if (isUnaryLike(parent) || isBinary(parent) || isConditionalExpression(parent, {
        test: node
      }) || isAwaitExpression(parent) || isTSTypeExpression(parent)) {
        return true;
      }
      return UnaryLike(node, parent);
    }
    function OptionalMemberExpression(node, parent) {
      return isCallExpression2(parent, {
        callee: node
      }) || isMemberExpression(parent, {
        object: node
      });
    }
    function AssignmentExpression(node, parent) {
      if (isObjectPattern(node.left)) {
        return true;
      } else {
        return ConditionalExpression(node, parent);
      }
    }
    function LogicalExpression(node, parent) {
      if (isTSTypeExpression(parent))
        return true;
      switch (node.operator) {
        case "||":
          if (!isLogicalExpression(parent))
            return false;
          return parent.operator === "??" || parent.operator === "&&";
        case "&&":
          return isLogicalExpression(parent, {
            operator: "??"
          });
        case "??":
          return isLogicalExpression(parent) && parent.operator !== "??";
      }
    }
    function Identifier(node, parent, printStack) {
      var _node$extra;
      if ((_node$extra = node.extra) != null && _node$extra.parenthesized && isAssignmentExpression(parent, {
        left: node
      }) && (isFunctionExpression(parent.right) || isClassExpression(parent.right)) && parent.right.id == null) {
        return true;
      }
      if (node.name === "let") {
        const isFollowedByBracket = isMemberExpression(parent, {
          object: node,
          computed: true
        }) || isOptionalMemberExpression(parent, {
          object: node,
          computed: true,
          optional: false
        });
        return isFirstInContext(printStack, isFollowedByBracket ? 1 | 8 | 16 | 32 : 32);
      }
      return node.name === "async" && isForOfStatement(parent) && node === parent.left;
    }
    function isFirstInContext(printStack, checkParam) {
      const expressionStatement = checkParam & 1;
      const arrowBody = checkParam & 2;
      const exportDefault = checkParam & 4;
      const forHead = checkParam & 8;
      const forInHead = checkParam & 16;
      const forOfHead = checkParam & 32;
      let i = printStack.length - 1;
      if (i <= 0)
        return;
      let node = printStack[i];
      i--;
      let parent = printStack[i];
      while (i >= 0) {
        if (expressionStatement && isExpressionStatement(parent, {
          expression: node
        }) || exportDefault && isExportDefaultDeclaration(parent, {
          declaration: node
        }) || arrowBody && isArrowFunctionExpression(parent, {
          body: node
        }) || forHead && isForStatement(parent, {
          init: node
        }) || forInHead && isForInStatement(parent, {
          left: node
        }) || forOfHead && isForOfStatement(parent, {
          left: node
        })) {
          return true;
        }
        if (i > 0 && (hasPostfixPart(node, parent) && !isNewExpression(parent) || isSequenceExpression(parent) && parent.expressions[0] === node || isUpdateExpression(parent) && !parent.prefix || isConditional(parent, {
          test: node
        }) || isBinary(parent, {
          left: node
        }) || isAssignmentExpression(parent, {
          left: node
        }))) {
          node = parent;
          i--;
          parent = printStack[i];
        } else {
          return false;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/generator/lib/node/index.js
var require_node3 = __commonJS({
  "node_modules/@babel/generator/lib/node/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.needsParens = needsParens;
    exports.needsWhitespace = needsWhitespace;
    exports.needsWhitespaceAfter = needsWhitespaceAfter;
    exports.needsWhitespaceBefore = needsWhitespaceBefore;
    var whitespace = require_whitespace();
    var parens = require_parentheses();
    var _t = require_lib11();
    var {
      FLIPPED_ALIAS_KEYS,
      isCallExpression: isCallExpression2,
      isExpressionStatement,
      isMemberExpression,
      isNewExpression
    } = _t;
    function expandAliases(obj) {
      const newObj = {};
      function add(type, func) {
        const fn = newObj[type];
        newObj[type] = fn ? function(node, parent, stack) {
          const result = fn(node, parent, stack);
          return result == null ? func(node, parent, stack) : result;
        } : func;
      }
      for (const type of Object.keys(obj)) {
        const aliases = FLIPPED_ALIAS_KEYS[type];
        if (aliases) {
          for (const alias of aliases) {
            add(alias, obj[type]);
          }
        } else {
          add(type, obj[type]);
        }
      }
      return newObj;
    }
    var expandedParens = expandAliases(parens);
    var expandedWhitespaceNodes = expandAliases(whitespace.nodes);
    function find(obj, node, parent, printStack) {
      const fn = obj[node.type];
      return fn ? fn(node, parent, printStack) : null;
    }
    function isOrHasCallExpression(node) {
      if (isCallExpression2(node)) {
        return true;
      }
      return isMemberExpression(node) && isOrHasCallExpression(node.object);
    }
    function needsWhitespace(node, parent, type) {
      if (!node)
        return false;
      if (isExpressionStatement(node)) {
        node = node.expression;
      }
      const flag = find(expandedWhitespaceNodes, node, parent);
      if (typeof flag === "number") {
        return (flag & type) !== 0;
      }
      return false;
    }
    function needsWhitespaceBefore(node, parent) {
      return needsWhitespace(node, parent, 1);
    }
    function needsWhitespaceAfter(node, parent) {
      return needsWhitespace(node, parent, 2);
    }
    function needsParens(node, parent, printStack) {
      if (!parent)
        return false;
      if (isNewExpression(parent) && parent.callee === node) {
        if (isOrHasCallExpression(node))
          return true;
      }
      return find(expandedParens, node, parent, printStack);
    }
  }
});

// node_modules/@babel/generator/lib/generators/template-literals.js
var require_template_literals = __commonJS({
  "node_modules/@babel/generator/lib/generators/template-literals.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.TaggedTemplateExpression = TaggedTemplateExpression;
    exports.TemplateElement = TemplateElement;
    exports.TemplateLiteral = TemplateLiteral;
    function TaggedTemplateExpression(node) {
      this.print(node.tag, node);
      this.print(node.typeParameters, node);
      this.print(node.quasi, node);
    }
    function TemplateElement(node, parent) {
      const isFirst = parent.quasis[0] === node;
      const isLast = parent.quasis[parent.quasis.length - 1] === node;
      const value2 = (isFirst ? "`" : "}") + node.value.raw + (isLast ? "`" : "${");
      this.token(value2, true);
    }
    function TemplateLiteral(node) {
      const quasis = node.quasis;
      for (let i = 0; i < quasis.length; i++) {
        this.print(quasis[i], node);
        if (i + 1 < quasis.length) {
          this.print(node.expressions[i], node);
        }
      }
    }
  }
});

// node_modules/@babel/generator/lib/generators/expressions.js
var require_expressions = __commonJS({
  "node_modules/@babel/generator/lib/generators/expressions.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.LogicalExpression = exports.BinaryExpression = exports.AssignmentExpression = AssignmentExpression;
    exports.AssignmentPattern = AssignmentPattern;
    exports.AwaitExpression = AwaitExpression;
    exports.BindExpression = BindExpression;
    exports.CallExpression = CallExpression;
    exports.ConditionalExpression = ConditionalExpression;
    exports.Decorator = Decorator;
    exports.DoExpression = DoExpression;
    exports.EmptyStatement = EmptyStatement;
    exports.ExpressionStatement = ExpressionStatement;
    exports.Import = Import;
    exports.MemberExpression = MemberExpression;
    exports.MetaProperty = MetaProperty;
    exports.ModuleExpression = ModuleExpression;
    exports.NewExpression = NewExpression;
    exports.OptionalCallExpression = OptionalCallExpression;
    exports.OptionalMemberExpression = OptionalMemberExpression;
    exports.ParenthesizedExpression = ParenthesizedExpression;
    exports.PrivateName = PrivateName;
    exports.SequenceExpression = SequenceExpression;
    exports.Super = Super;
    exports.ThisExpression = ThisExpression;
    exports.UnaryExpression = UnaryExpression;
    exports.UpdateExpression = UpdateExpression;
    exports.V8IntrinsicIdentifier = V8IntrinsicIdentifier;
    exports.YieldExpression = YieldExpression;
    var _t = require_lib11();
    var n = require_node3();
    var {
      isCallExpression: isCallExpression2,
      isLiteral,
      isMemberExpression,
      isNewExpression
    } = _t;
    function UnaryExpression(node) {
      if (node.operator === "void" || node.operator === "delete" || node.operator === "typeof" || node.operator === "throw") {
        this.word(node.operator);
        this.space();
      } else {
        this.token(node.operator);
      }
      this.print(node.argument, node);
    }
    function DoExpression(node) {
      if (node.async) {
        this.word("async", true);
        this.space();
      }
      this.word("do");
      this.space();
      this.print(node.body, node);
    }
    function ParenthesizedExpression(node) {
      this.tokenChar(40);
      this.print(node.expression, node);
      this.tokenChar(41);
    }
    function UpdateExpression(node) {
      if (node.prefix) {
        this.token(node.operator);
        this.print(node.argument, node);
      } else {
        this.printTerminatorless(node.argument, node, true);
        this.token(node.operator);
      }
    }
    function ConditionalExpression(node) {
      this.print(node.test, node);
      this.space();
      this.tokenChar(63);
      this.space();
      this.print(node.consequent, node);
      this.space();
      this.tokenChar(58);
      this.space();
      this.print(node.alternate, node);
    }
    function NewExpression(node, parent) {
      this.word("new");
      this.space();
      this.print(node.callee, node);
      if (this.format.minified && node.arguments.length === 0 && !node.optional && !isCallExpression2(parent, {
        callee: node
      }) && !isMemberExpression(parent) && !isNewExpression(parent)) {
        return;
      }
      this.print(node.typeArguments, node);
      this.print(node.typeParameters, node);
      if (node.optional) {
        this.token("?.");
      }
      this.tokenChar(40);
      this.printList(node.arguments, node);
      this.tokenChar(41);
    }
    function SequenceExpression(node) {
      this.printList(node.expressions, node);
    }
    function ThisExpression() {
      this.word("this");
    }
    function Super() {
      this.word("super");
    }
    function isDecoratorMemberExpression(node) {
      switch (node.type) {
        case "Identifier":
          return true;
        case "MemberExpression":
          return !node.computed && node.property.type === "Identifier" && isDecoratorMemberExpression(node.object);
        default:
          return false;
      }
    }
    function shouldParenthesizeDecoratorExpression(node) {
      if (node.type === "ParenthesizedExpression") {
        return false;
      }
      return !isDecoratorMemberExpression(node.type === "CallExpression" ? node.callee : node);
    }
    function Decorator(node) {
      this.tokenChar(64);
      const {
        expression
      } = node;
      if (shouldParenthesizeDecoratorExpression(expression)) {
        this.tokenChar(40);
        this.print(expression, node);
        this.tokenChar(41);
      } else {
        this.print(expression, node);
      }
      this.newline();
    }
    function OptionalMemberExpression(node) {
      this.print(node.object, node);
      if (!node.computed && isMemberExpression(node.property)) {
        throw new TypeError("Got a MemberExpression for MemberExpression property");
      }
      let computed = node.computed;
      if (isLiteral(node.property) && typeof node.property.value === "number") {
        computed = true;
      }
      if (node.optional) {
        this.token("?.");
      }
      if (computed) {
        this.tokenChar(91);
        this.print(node.property, node);
        this.tokenChar(93);
      } else {
        if (!node.optional) {
          this.tokenChar(46);
        }
        this.print(node.property, node);
      }
    }
    function OptionalCallExpression(node) {
      this.print(node.callee, node);
      this.print(node.typeParameters, node);
      if (node.optional) {
        this.token("?.");
      }
      this.print(node.typeArguments, node);
      this.tokenChar(40);
      this.printList(node.arguments, node);
      this.tokenChar(41);
    }
    function CallExpression(node) {
      this.print(node.callee, node);
      this.print(node.typeArguments, node);
      this.print(node.typeParameters, node);
      this.tokenChar(40);
      this.printList(node.arguments, node);
      this.tokenChar(41);
    }
    function Import() {
      this.word("import");
    }
    function AwaitExpression(node) {
      this.word("await");
      if (node.argument) {
        this.space();
        this.printTerminatorless(node.argument, node, false);
      }
    }
    function YieldExpression(node) {
      this.word("yield", true);
      if (node.delegate) {
        this.tokenChar(42);
        if (node.argument) {
          this.space();
          this.print(node.argument, node);
        }
      } else {
        if (node.argument) {
          this.space();
          this.printTerminatorless(node.argument, node, false);
        }
      }
    }
    function EmptyStatement() {
      this.semicolon(true);
    }
    function ExpressionStatement(node) {
      this.print(node.expression, node);
      this.semicolon();
    }
    function AssignmentPattern(node) {
      this.print(node.left, node);
      if (node.left.optional)
        this.tokenChar(63);
      this.print(node.left.typeAnnotation, node);
      this.space();
      this.tokenChar(61);
      this.space();
      this.print(node.right, node);
    }
    function AssignmentExpression(node, parent) {
      const parens = this.inForStatementInitCounter && node.operator === "in" && !n.needsParens(node, parent);
      if (parens) {
        this.tokenChar(40);
      }
      this.print(node.left, node);
      this.space();
      if (node.operator === "in" || node.operator === "instanceof") {
        this.word(node.operator);
      } else {
        this.token(node.operator);
      }
      this.space();
      this.print(node.right, node);
      if (parens) {
        this.tokenChar(41);
      }
    }
    function BindExpression(node) {
      this.print(node.object, node);
      this.token("::");
      this.print(node.callee, node);
    }
    function MemberExpression(node) {
      this.print(node.object, node);
      if (!node.computed && isMemberExpression(node.property)) {
        throw new TypeError("Got a MemberExpression for MemberExpression property");
      }
      let computed = node.computed;
      if (isLiteral(node.property) && typeof node.property.value === "number") {
        computed = true;
      }
      if (computed) {
        this.tokenChar(91);
        this.print(node.property, node);
        this.tokenChar(93);
      } else {
        this.tokenChar(46);
        this.print(node.property, node);
      }
    }
    function MetaProperty(node) {
      this.print(node.meta, node);
      this.tokenChar(46);
      this.print(node.property, node);
    }
    function PrivateName(node) {
      this.tokenChar(35);
      this.print(node.id, node);
    }
    function V8IntrinsicIdentifier(node) {
      this.tokenChar(37);
      this.word(node.name);
    }
    function ModuleExpression(node) {
      this.word("module", true);
      this.space();
      this.tokenChar(123);
      this.indent();
      const {
        body
      } = node;
      if (body.body.length || body.directives.length) {
        this.newline();
      }
      this.print(body, node);
      this.dedent();
      this.sourceWithOffset("end", node.loc, 0, -1);
      this.rightBrace();
    }
  }
});

// node_modules/@babel/generator/lib/generators/statements.js
var require_statements = __commonJS({
  "node_modules/@babel/generator/lib/generators/statements.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.BreakStatement = BreakStatement;
    exports.CatchClause = CatchClause;
    exports.ContinueStatement = ContinueStatement;
    exports.DebuggerStatement = DebuggerStatement;
    exports.DoWhileStatement = DoWhileStatement;
    exports.ForOfStatement = exports.ForInStatement = void 0;
    exports.ForStatement = ForStatement;
    exports.IfStatement = IfStatement;
    exports.LabeledStatement = LabeledStatement;
    exports.ReturnStatement = ReturnStatement;
    exports.SwitchCase = SwitchCase;
    exports.SwitchStatement = SwitchStatement;
    exports.ThrowStatement = ThrowStatement;
    exports.TryStatement = TryStatement;
    exports.VariableDeclaration = VariableDeclaration;
    exports.VariableDeclarator = VariableDeclarator;
    exports.WhileStatement = WhileStatement;
    exports.WithStatement = WithStatement;
    var _t = require_lib11();
    var {
      isFor,
      isForStatement,
      isIfStatement,
      isStatement
    } = _t;
    function WithStatement(node) {
      this.word("with");
      this.space();
      this.tokenChar(40);
      this.print(node.object, node);
      this.tokenChar(41);
      this.printBlock(node);
    }
    function IfStatement(node) {
      this.word("if");
      this.space();
      this.tokenChar(40);
      this.print(node.test, node);
      this.tokenChar(41);
      this.space();
      const needsBlock = node.alternate && isIfStatement(getLastStatement(node.consequent));
      if (needsBlock) {
        this.tokenChar(123);
        this.newline();
        this.indent();
      }
      this.printAndIndentOnComments(node.consequent, node);
      if (needsBlock) {
        this.dedent();
        this.newline();
        this.tokenChar(125);
      }
      if (node.alternate) {
        if (this.endsWith(125))
          this.space();
        this.word("else");
        this.space();
        this.printAndIndentOnComments(node.alternate, node);
      }
    }
    function getLastStatement(statement) {
      const {
        body
      } = statement;
      if (isStatement(body) === false) {
        return statement;
      }
      return getLastStatement(body);
    }
    function ForStatement(node) {
      this.word("for");
      this.space();
      this.tokenChar(40);
      this.inForStatementInitCounter++;
      this.print(node.init, node);
      this.inForStatementInitCounter--;
      this.tokenChar(59);
      if (node.test) {
        this.space();
        this.print(node.test, node);
      }
      this.tokenChar(59);
      if (node.update) {
        this.space();
        this.print(node.update, node);
      }
      this.tokenChar(41);
      this.printBlock(node);
    }
    function WhileStatement(node) {
      this.word("while");
      this.space();
      this.tokenChar(40);
      this.print(node.test, node);
      this.tokenChar(41);
      this.printBlock(node);
    }
    function ForXStatement(node) {
      this.word("for");
      this.space();
      const isForOf = node.type === "ForOfStatement";
      if (isForOf && node.await) {
        this.word("await");
        this.space();
      }
      this.noIndentInnerCommentsHere();
      this.tokenChar(40);
      this.print(node.left, node);
      this.space();
      this.word(isForOf ? "of" : "in");
      this.space();
      this.print(node.right, node);
      this.tokenChar(41);
      this.printBlock(node);
    }
    var ForInStatement = ForXStatement;
    exports.ForInStatement = ForInStatement;
    var ForOfStatement = ForXStatement;
    exports.ForOfStatement = ForOfStatement;
    function DoWhileStatement(node) {
      this.word("do");
      this.space();
      this.print(node.body, node);
      this.space();
      this.word("while");
      this.space();
      this.tokenChar(40);
      this.print(node.test, node);
      this.tokenChar(41);
      this.semicolon();
    }
    function printStatementAfterKeyword(printer, node, parent, isLabel) {
      if (node) {
        printer.space();
        printer.printTerminatorless(node, parent, isLabel);
      }
      printer.semicolon();
    }
    function BreakStatement(node) {
      this.word("break");
      printStatementAfterKeyword(this, node.label, node, true);
    }
    function ContinueStatement(node) {
      this.word("continue");
      printStatementAfterKeyword(this, node.label, node, true);
    }
    function ReturnStatement(node) {
      this.word("return");
      printStatementAfterKeyword(this, node.argument, node, false);
    }
    function ThrowStatement(node) {
      this.word("throw");
      printStatementAfterKeyword(this, node.argument, node, false);
    }
    function LabeledStatement(node) {
      this.print(node.label, node);
      this.tokenChar(58);
      this.space();
      this.print(node.body, node);
    }
    function TryStatement(node) {
      this.word("try");
      this.space();
      this.print(node.block, node);
      this.space();
      if (node.handlers) {
        this.print(node.handlers[0], node);
      } else {
        this.print(node.handler, node);
      }
      if (node.finalizer) {
        this.space();
        this.word("finally");
        this.space();
        this.print(node.finalizer, node);
      }
    }
    function CatchClause(node) {
      this.word("catch");
      this.space();
      if (node.param) {
        this.tokenChar(40);
        this.print(node.param, node);
        this.print(node.param.typeAnnotation, node);
        this.tokenChar(41);
        this.space();
      }
      this.print(node.body, node);
    }
    function SwitchStatement(node) {
      this.word("switch");
      this.space();
      this.tokenChar(40);
      this.print(node.discriminant, node);
      this.tokenChar(41);
      this.space();
      this.tokenChar(123);
      this.printSequence(node.cases, node, {
        indent: true,
        addNewlines(leading, cas) {
          if (!leading && node.cases[node.cases.length - 1] === cas)
            return -1;
        }
      });
      this.tokenChar(125);
    }
    function SwitchCase(node) {
      if (node.test) {
        this.word("case");
        this.space();
        this.print(node.test, node);
        this.tokenChar(58);
      } else {
        this.word("default");
        this.tokenChar(58);
      }
      if (node.consequent.length) {
        this.newline();
        this.printSequence(node.consequent, node, {
          indent: true
        });
      }
    }
    function DebuggerStatement() {
      this.word("debugger");
      this.semicolon();
    }
    function VariableDeclaration(node, parent) {
      if (node.declare) {
        this.word("declare");
        this.space();
      }
      const {
        kind
      } = node;
      this.word(kind, kind === "using");
      this.space();
      let hasInits = false;
      if (!isFor(parent)) {
        for (const declar of node.declarations) {
          if (declar.init) {
            hasInits = true;
          }
        }
      }
      this.printList(node.declarations, node, {
        separator: hasInits ? function() {
          this.tokenChar(44);
          this.newline();
        } : void 0,
        indent: node.declarations.length > 1 ? true : false
      });
      if (isFor(parent)) {
        if (isForStatement(parent)) {
          if (parent.init === node)
            return;
        } else {
          if (parent.left === node)
            return;
        }
      }
      this.semicolon();
    }
    function VariableDeclarator(node) {
      this.print(node.id, node);
      if (node.definite)
        this.tokenChar(33);
      this.print(node.id.typeAnnotation, node);
      if (node.init) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.init, node);
      }
    }
  }
});

// node_modules/@babel/generator/lib/generators/classes.js
var require_classes = __commonJS({
  "node_modules/@babel/generator/lib/generators/classes.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ClassAccessorProperty = ClassAccessorProperty;
    exports.ClassBody = ClassBody;
    exports.ClassExpression = exports.ClassDeclaration = ClassDeclaration;
    exports.ClassMethod = ClassMethod;
    exports.ClassPrivateMethod = ClassPrivateMethod;
    exports.ClassPrivateProperty = ClassPrivateProperty;
    exports.ClassProperty = ClassProperty;
    exports.StaticBlock = StaticBlock;
    exports._classMethodHead = _classMethodHead;
    var _t = require_lib11();
    var {
      isExportDefaultDeclaration,
      isExportNamedDeclaration
    } = _t;
    function ClassDeclaration(node, parent) {
      {
        if (!this.format.decoratorsBeforeExport || !isExportDefaultDeclaration(parent) && !isExportNamedDeclaration(parent)) {
          this.printJoin(node.decorators, node);
        }
      }
      if (node.declare) {
        this.word("declare");
        this.space();
      }
      if (node.abstract) {
        this.word("abstract");
        this.space();
      }
      this.word("class");
      if (node.id) {
        this.space();
        this.print(node.id, node);
      }
      this.print(node.typeParameters, node);
      if (node.superClass) {
        this.space();
        this.word("extends");
        this.space();
        this.print(node.superClass, node);
        this.print(node.superTypeParameters, node);
      }
      if (node.implements) {
        this.space();
        this.word("implements");
        this.space();
        this.printList(node.implements, node);
      }
      this.space();
      this.print(node.body, node);
    }
    function ClassBody(node) {
      this.tokenChar(123);
      if (node.body.length === 0) {
        this.tokenChar(125);
      } else {
        this.newline();
        this.indent();
        this.printSequence(node.body, node);
        this.dedent();
        if (!this.endsWith(10))
          this.newline();
        this.sourceWithOffset("end", node.loc, 0, -1);
        this.rightBrace();
      }
    }
    function ClassProperty(node) {
      var _node$key$loc, _node$key$loc$end;
      this.printJoin(node.decorators, node);
      const endLine = (_node$key$loc = node.key.loc) == null ? void 0 : (_node$key$loc$end = _node$key$loc.end) == null ? void 0 : _node$key$loc$end.line;
      if (endLine)
        this.catchUp(endLine);
      this.tsPrintClassMemberModifiers(node);
      if (node.computed) {
        this.tokenChar(91);
        this.print(node.key, node);
        this.tokenChar(93);
      } else {
        this._variance(node);
        this.print(node.key, node);
      }
      if (node.optional) {
        this.tokenChar(63);
      }
      if (node.definite) {
        this.tokenChar(33);
      }
      this.print(node.typeAnnotation, node);
      if (node.value) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.value, node);
      }
      this.semicolon();
    }
    function ClassAccessorProperty(node) {
      var _node$key$loc2, _node$key$loc2$end;
      this.printJoin(node.decorators, node);
      const endLine = (_node$key$loc2 = node.key.loc) == null ? void 0 : (_node$key$loc2$end = _node$key$loc2.end) == null ? void 0 : _node$key$loc2$end.line;
      if (endLine)
        this.catchUp(endLine);
      this.tsPrintClassMemberModifiers(node);
      this.word("accessor", true);
      this.space();
      if (node.computed) {
        this.tokenChar(91);
        this.print(node.key, node);
        this.tokenChar(93);
      } else {
        this._variance(node);
        this.print(node.key, node);
      }
      if (node.optional) {
        this.tokenChar(63);
      }
      if (node.definite) {
        this.tokenChar(33);
      }
      this.print(node.typeAnnotation, node);
      if (node.value) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.value, node);
      }
      this.semicolon();
    }
    function ClassPrivateProperty(node) {
      this.printJoin(node.decorators, node);
      if (node.static) {
        this.word("static");
        this.space();
      }
      this.print(node.key, node);
      this.print(node.typeAnnotation, node);
      if (node.value) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.value, node);
      }
      this.semicolon();
    }
    function ClassMethod(node) {
      this._classMethodHead(node);
      this.space();
      this.print(node.body, node);
    }
    function ClassPrivateMethod(node) {
      this._classMethodHead(node);
      this.space();
      this.print(node.body, node);
    }
    function _classMethodHead(node) {
      var _node$key$loc3, _node$key$loc3$end;
      this.printJoin(node.decorators, node);
      const endLine = (_node$key$loc3 = node.key.loc) == null ? void 0 : (_node$key$loc3$end = _node$key$loc3.end) == null ? void 0 : _node$key$loc3$end.line;
      if (endLine)
        this.catchUp(endLine);
      this.tsPrintClassMemberModifiers(node);
      this._methodHead(node);
    }
    function StaticBlock(node) {
      this.word("static");
      this.space();
      this.tokenChar(123);
      if (node.body.length === 0) {
        this.tokenChar(125);
      } else {
        this.newline();
        this.printSequence(node.body, node, {
          indent: true
        });
        this.sourceWithOffset("end", node.loc, 0, -1);
        this.rightBrace();
      }
    }
  }
});

// node_modules/@babel/generator/lib/generators/methods.js
var require_methods = __commonJS({
  "node_modules/@babel/generator/lib/generators/methods.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ArrowFunctionExpression = ArrowFunctionExpression;
    exports.FunctionDeclaration = exports.FunctionExpression = FunctionExpression;
    exports._functionHead = _functionHead;
    exports._methodHead = _methodHead;
    exports._param = _param;
    exports._parameters = _parameters;
    exports._params = _params;
    exports._predicate = _predicate;
    var _t = require_lib11();
    var {
      isIdentifier: isIdentifier2
    } = _t;
    function _params(node) {
      this.print(node.typeParameters, node);
      this.tokenChar(40);
      this._parameters(node.params, node);
      this.tokenChar(41);
      const noLineTerminator = node.type === "ArrowFunctionExpression";
      this.print(node.returnType, node, noLineTerminator);
      this._noLineTerminator = noLineTerminator;
    }
    function _parameters(parameters, parent) {
      const paramLength = parameters.length;
      for (let i = 0; i < paramLength; i++) {
        this._param(parameters[i], parent);
        if (i < parameters.length - 1) {
          this.tokenChar(44);
          this.space();
        }
      }
    }
    function _param(parameter, parent) {
      this.printJoin(parameter.decorators, parameter);
      this.print(parameter, parent);
      if (parameter.optional) {
        this.tokenChar(63);
      }
      this.print(
        parameter.typeAnnotation,
        parameter
      );
    }
    function _methodHead(node) {
      const kind = node.kind;
      const key = node.key;
      if (kind === "get" || kind === "set") {
        this.word(kind);
        this.space();
      }
      if (node.async) {
        this.word("async", true);
        this.space();
      }
      if (kind === "method" || kind === "init") {
        if (node.generator) {
          this.tokenChar(42);
        }
      }
      if (node.computed) {
        this.tokenChar(91);
        this.print(key, node);
        this.tokenChar(93);
      } else {
        this.print(key, node);
      }
      if (node.optional) {
        this.tokenChar(63);
      }
      this._params(node);
    }
    function _predicate(node, noLineTerminatorAfter) {
      if (node.predicate) {
        if (!node.returnType) {
          this.tokenChar(58);
        }
        this.space();
        this.print(node.predicate, node, noLineTerminatorAfter);
      }
    }
    function _functionHead(node) {
      if (node.async) {
        this.word("async");
        this._endsWithInnerRaw = false;
        this.space();
      }
      this.word("function");
      if (node.generator) {
        this._endsWithInnerRaw = false;
        this.tokenChar(42);
      }
      this.space();
      if (node.id) {
        this.print(node.id, node);
      }
      this._params(node);
      if (node.type !== "TSDeclareFunction") {
        this._predicate(node);
      }
    }
    function FunctionExpression(node) {
      this._functionHead(node);
      this.space();
      this.print(node.body, node);
    }
    function ArrowFunctionExpression(node) {
      if (node.async) {
        this.word("async", true);
        this.space();
      }
      let firstParam;
      if (!this.format.retainLines && node.params.length === 1 && isIdentifier2(firstParam = node.params[0]) && !hasTypesOrComments(node, firstParam)) {
        this.print(firstParam, node, true);
      } else {
        this._params(node);
      }
      this._predicate(node, true);
      this.space();
      this.printInnerComments();
      this.token("=>");
      this.space();
      this.print(node.body, node);
    }
    function hasTypesOrComments(node, param) {
      var _param$leadingComment, _param$trailingCommen;
      return !!(node.typeParameters || node.returnType || node.predicate || param.typeAnnotation || param.optional || (_param$leadingComment = param.leadingComments) != null && _param$leadingComment.length || (_param$trailingCommen = param.trailingComments) != null && _param$trailingCommen.length);
    }
  }
});

// node_modules/@babel/generator/lib/generators/modules.js
var require_modules = __commonJS({
  "node_modules/@babel/generator/lib/generators/modules.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ExportAllDeclaration = ExportAllDeclaration;
    exports.ExportDefaultDeclaration = ExportDefaultDeclaration;
    exports.ExportDefaultSpecifier = ExportDefaultSpecifier;
    exports.ExportNamedDeclaration = ExportNamedDeclaration;
    exports.ExportNamespaceSpecifier = ExportNamespaceSpecifier;
    exports.ExportSpecifier = ExportSpecifier;
    exports.ImportAttribute = ImportAttribute;
    exports.ImportDeclaration = ImportDeclaration;
    exports.ImportDefaultSpecifier = ImportDefaultSpecifier;
    exports.ImportNamespaceSpecifier = ImportNamespaceSpecifier;
    exports.ImportSpecifier = ImportSpecifier;
    exports._printAssertions = _printAssertions;
    var _t = require_lib11();
    var {
      isClassDeclaration,
      isExportDefaultSpecifier,
      isExportNamespaceSpecifier,
      isImportDefaultSpecifier,
      isImportNamespaceSpecifier,
      isStatement
    } = _t;
    function ImportSpecifier(node) {
      if (node.importKind === "type" || node.importKind === "typeof") {
        this.word(node.importKind);
        this.space();
      }
      this.print(node.imported, node);
      if (node.local && node.local.name !== node.imported.name) {
        this.space();
        this.word("as");
        this.space();
        this.print(node.local, node);
      }
    }
    function ImportDefaultSpecifier(node) {
      this.print(node.local, node);
    }
    function ExportDefaultSpecifier(node) {
      this.print(node.exported, node);
    }
    function ExportSpecifier(node) {
      if (node.exportKind === "type") {
        this.word("type");
        this.space();
      }
      this.print(node.local, node);
      if (node.exported && node.local.name !== node.exported.name) {
        this.space();
        this.word("as");
        this.space();
        this.print(node.exported, node);
      }
    }
    function ExportNamespaceSpecifier(node) {
      this.tokenChar(42);
      this.space();
      this.word("as");
      this.space();
      this.print(node.exported, node);
    }
    function _printAssertions(node) {
      this.word("assert");
      this.space();
      this.tokenChar(123);
      this.space();
      this.printList(node.assertions, node);
      this.space();
      this.tokenChar(125);
    }
    function ExportAllDeclaration(node) {
      var _node$assertions;
      this.word("export");
      this.space();
      if (node.exportKind === "type") {
        this.word("type");
        this.space();
      }
      this.tokenChar(42);
      this.space();
      this.word("from");
      this.space();
      if ((_node$assertions = node.assertions) != null && _node$assertions.length) {
        this.print(node.source, node, true);
        this.space();
        this._printAssertions(node);
      } else {
        this.print(node.source, node);
      }
      this.semicolon();
    }
    function ExportNamedDeclaration(node) {
      {
        if (this.format.decoratorsBeforeExport && isClassDeclaration(node.declaration)) {
          this.printJoin(node.declaration.decorators, node);
        }
      }
      this.word("export");
      this.space();
      if (node.declaration) {
        const declar = node.declaration;
        this.print(declar, node);
        if (!isStatement(declar))
          this.semicolon();
      } else {
        if (node.exportKind === "type") {
          this.word("type");
          this.space();
        }
        const specifiers = node.specifiers.slice(0);
        let hasSpecial = false;
        for (; ; ) {
          const first2 = specifiers[0];
          if (isExportDefaultSpecifier(first2) || isExportNamespaceSpecifier(first2)) {
            hasSpecial = true;
            this.print(specifiers.shift(), node);
            if (specifiers.length) {
              this.tokenChar(44);
              this.space();
            }
          } else {
            break;
          }
        }
        if (specifiers.length || !specifiers.length && !hasSpecial) {
          this.tokenChar(123);
          if (specifiers.length) {
            this.space();
            this.printList(specifiers, node);
            this.space();
          }
          this.tokenChar(125);
        }
        if (node.source) {
          var _node$assertions2;
          this.space();
          this.word("from");
          this.space();
          if ((_node$assertions2 = node.assertions) != null && _node$assertions2.length) {
            this.print(node.source, node, true);
            this.space();
            this._printAssertions(node);
          } else {
            this.print(node.source, node);
          }
        }
        this.semicolon();
      }
    }
    function ExportDefaultDeclaration(node) {
      {
        if (this.format.decoratorsBeforeExport && isClassDeclaration(node.declaration)) {
          this.printJoin(node.declaration.decorators, node);
        }
      }
      this.word("export");
      this.noIndentInnerCommentsHere();
      this.space();
      this.word("default");
      this.space();
      const declar = node.declaration;
      this.print(declar, node);
      if (!isStatement(declar))
        this.semicolon();
    }
    function ImportDeclaration(node) {
      var _node$assertions3;
      this.word("import");
      this.space();
      const isTypeKind = node.importKind === "type" || node.importKind === "typeof";
      if (isTypeKind) {
        this.noIndentInnerCommentsHere();
        this.word(node.importKind);
        this.space();
      } else if (node.module) {
        this.noIndentInnerCommentsHere();
        this.word("module");
        this.space();
      }
      const specifiers = node.specifiers.slice(0);
      const hasSpecifiers = !!specifiers.length;
      while (hasSpecifiers) {
        const first2 = specifiers[0];
        if (isImportDefaultSpecifier(first2) || isImportNamespaceSpecifier(first2)) {
          this.print(specifiers.shift(), node);
          if (specifiers.length) {
            this.tokenChar(44);
            this.space();
          }
        } else {
          break;
        }
      }
      if (specifiers.length) {
        this.tokenChar(123);
        this.space();
        this.printList(specifiers, node);
        this.space();
        this.tokenChar(125);
      } else if (isTypeKind && !hasSpecifiers) {
        this.tokenChar(123);
        this.tokenChar(125);
      }
      if (hasSpecifiers || isTypeKind) {
        this.space();
        this.word("from");
        this.space();
      }
      if ((_node$assertions3 = node.assertions) != null && _node$assertions3.length) {
        this.print(node.source, node, true);
        this.space();
        this._printAssertions(node);
      } else {
        this.print(node.source, node);
      }
      {
        var _node$attributes;
        if ((_node$attributes = node.attributes) != null && _node$attributes.length) {
          this.space();
          this.word("with");
          this.space();
          this.printList(node.attributes, node);
        }
      }
      this.semicolon();
    }
    function ImportAttribute(node) {
      this.print(node.key);
      this.tokenChar(58);
      this.space();
      this.print(node.value);
    }
    function ImportNamespaceSpecifier(node) {
      this.tokenChar(42);
      this.space();
      this.word("as");
      this.space();
      this.print(node.local, node);
    }
  }
});

// node_modules/jsesc/jsesc.js
var require_jsesc = __commonJS({
  "node_modules/jsesc/jsesc.js"(exports, module2) {
    "use strict";
    var object = {};
    var hasOwnProperty = object.hasOwnProperty;
    var forOwn = (object2, callback) => {
      for (const key in object2) {
        if (hasOwnProperty.call(object2, key)) {
          callback(key, object2[key]);
        }
      }
    };
    var extend = (destination, source) => {
      if (!source) {
        return destination;
      }
      forOwn(source, (key, value2) => {
        destination[key] = value2;
      });
      return destination;
    };
    var forEach = (array, callback) => {
      const length = array.length;
      let index = -1;
      while (++index < length) {
        callback(array[index]);
      }
    };
    var toString = object.toString;
    var isArray2 = Array.isArray;
    var isBuffer = Buffer.isBuffer;
    var isObject = (value2) => {
      return toString.call(value2) == "[object Object]";
    };
    var isString = (value2) => {
      return typeof value2 == "string" || toString.call(value2) == "[object String]";
    };
    var isNumber = (value2) => {
      return typeof value2 == "number" || toString.call(value2) == "[object Number]";
    };
    var isFunction = (value2) => {
      return typeof value2 == "function";
    };
    var isMap = (value2) => {
      return toString.call(value2) == "[object Map]";
    };
    var isSet = (value2) => {
      return toString.call(value2) == "[object Set]";
    };
    var singleEscapes = {
      '"': '\\"',
      "'": "\\'",
      "\\": "\\\\",
      "\b": "\\b",
      "\f": "\\f",
      "\n": "\\n",
      "\r": "\\r",
      "	": "\\t"
      // `\v` is omitted intentionally, because in IE < 9, '\v' == 'v'.
      // '\v': '\\x0B'
    };
    var regexSingleEscape = /["'\\\b\f\n\r\t]/;
    var regexDigit = /[0-9]/;
    var regexWhitelist = /[ !#-&\(-\[\]-_a-~]/;
    var jsesc = (argument, options) => {
      const increaseIndentation = () => {
        oldIndent = indent;
        ++options.indentLevel;
        indent = options.indent.repeat(options.indentLevel);
      };
      const defaults = {
        "escapeEverything": false,
        "minimal": false,
        "isScriptContext": false,
        "quotes": "single",
        "wrap": false,
        "es6": false,
        "json": false,
        "compact": true,
        "lowercaseHex": false,
        "numbers": "decimal",
        "indent": "	",
        "indentLevel": 0,
        "__inline1__": false,
        "__inline2__": false
      };
      const json = options && options.json;
      if (json) {
        defaults.quotes = "double";
        defaults.wrap = true;
      }
      options = extend(defaults, options);
      if (options.quotes != "single" && options.quotes != "double" && options.quotes != "backtick") {
        options.quotes = "single";
      }
      const quote = options.quotes == "double" ? '"' : options.quotes == "backtick" ? "`" : "'";
      const compact = options.compact;
      const lowercaseHex = options.lowercaseHex;
      let indent = options.indent.repeat(options.indentLevel);
      let oldIndent = "";
      const inline1 = options.__inline1__;
      const inline2 = options.__inline2__;
      const newLine = compact ? "" : "\n";
      let result;
      let isEmpty2 = true;
      const useBinNumbers = options.numbers == "binary";
      const useOctNumbers = options.numbers == "octal";
      const useDecNumbers = options.numbers == "decimal";
      const useHexNumbers = options.numbers == "hexadecimal";
      if (json && argument && isFunction(argument.toJSON)) {
        argument = argument.toJSON();
      }
      if (!isString(argument)) {
        if (isMap(argument)) {
          if (argument.size == 0) {
            return "new Map()";
          }
          if (!compact) {
            options.__inline1__ = true;
            options.__inline2__ = false;
          }
          return "new Map(" + jsesc(Array.from(argument), options) + ")";
        }
        if (isSet(argument)) {
          if (argument.size == 0) {
            return "new Set()";
          }
          return "new Set(" + jsesc(Array.from(argument), options) + ")";
        }
        if (isBuffer(argument)) {
          if (argument.length == 0) {
            return "Buffer.from([])";
          }
          return "Buffer.from(" + jsesc(Array.from(argument), options) + ")";
        }
        if (isArray2(argument)) {
          result = [];
          options.wrap = true;
          if (inline1) {
            options.__inline1__ = false;
            options.__inline2__ = true;
          }
          if (!inline2) {
            increaseIndentation();
          }
          forEach(argument, (value2) => {
            isEmpty2 = false;
            if (inline2) {
              options.__inline2__ = false;
            }
            result.push(
              (compact || inline2 ? "" : indent) + jsesc(value2, options)
            );
          });
          if (isEmpty2) {
            return "[]";
          }
          if (inline2) {
            return "[" + result.join(", ") + "]";
          }
          return "[" + newLine + result.join("," + newLine) + newLine + (compact ? "" : oldIndent) + "]";
        } else if (isNumber(argument)) {
          if (json) {
            return JSON.stringify(argument);
          }
          if (useDecNumbers) {
            return String(argument);
          }
          if (useHexNumbers) {
            let hexadecimal = argument.toString(16);
            if (!lowercaseHex) {
              hexadecimal = hexadecimal.toUpperCase();
            }
            return "0x" + hexadecimal;
          }
          if (useBinNumbers) {
            return "0b" + argument.toString(2);
          }
          if (useOctNumbers) {
            return "0o" + argument.toString(8);
          }
        } else if (!isObject(argument)) {
          if (json) {
            return JSON.stringify(argument) || "null";
          }
          return String(argument);
        } else {
          result = [];
          options.wrap = true;
          increaseIndentation();
          forOwn(argument, (key, value2) => {
            isEmpty2 = false;
            result.push(
              (compact ? "" : indent) + jsesc(key, options) + ":" + (compact ? "" : " ") + jsesc(value2, options)
            );
          });
          if (isEmpty2) {
            return "{}";
          }
          return "{" + newLine + result.join("," + newLine) + newLine + (compact ? "" : oldIndent) + "}";
        }
      }
      const string = argument;
      let index = -1;
      const length = string.length;
      result = "";
      while (++index < length) {
        const character = string.charAt(index);
        if (options.es6) {
          const first2 = string.charCodeAt(index);
          if (
            // check if it’s the start of a surrogate pair
            first2 >= 55296 && first2 <= 56319 && // high surrogate
            length > index + 1
          ) {
            const second = string.charCodeAt(index + 1);
            if (second >= 56320 && second <= 57343) {
              const codePoint = (first2 - 55296) * 1024 + second - 56320 + 65536;
              let hexadecimal2 = codePoint.toString(16);
              if (!lowercaseHex) {
                hexadecimal2 = hexadecimal2.toUpperCase();
              }
              result += "\\u{" + hexadecimal2 + "}";
              ++index;
              continue;
            }
          }
        }
        if (!options.escapeEverything) {
          if (regexWhitelist.test(character)) {
            result += character;
            continue;
          }
          if (character == '"') {
            result += quote == character ? '\\"' : character;
            continue;
          }
          if (character == "`") {
            result += quote == character ? "\\`" : character;
            continue;
          }
          if (character == "'") {
            result += quote == character ? "\\'" : character;
            continue;
          }
        }
        if (character == "\0" && !json && !regexDigit.test(string.charAt(index + 1))) {
          result += "\\0";
          continue;
        }
        if (regexSingleEscape.test(character)) {
          result += singleEscapes[character];
          continue;
        }
        const charCode = character.charCodeAt(0);
        if (options.minimal && charCode != 8232 && charCode != 8233) {
          result += character;
          continue;
        }
        let hexadecimal = charCode.toString(16);
        if (!lowercaseHex) {
          hexadecimal = hexadecimal.toUpperCase();
        }
        const longhand = hexadecimal.length > 2 || json;
        const escaped = "\\" + (longhand ? "u" : "x") + ("0000" + hexadecimal).slice(longhand ? -4 : -2);
        result += escaped;
        continue;
      }
      if (options.wrap) {
        result = quote + result + quote;
      }
      if (quote == "`") {
        result = result.replace(/\$\{/g, "\\${");
      }
      if (options.isScriptContext) {
        return result.replace(/<\/(script|style)/gi, "<\\/$1").replace(/<!--/g, json ? "\\u003C!--" : "\\x3C!--");
      }
      return result;
    };
    jsesc.version = "2.5.2";
    module2.exports = jsesc;
  }
});

// node_modules/@babel/generator/lib/generators/types.js
var require_types2 = __commonJS({
  "node_modules/@babel/generator/lib/generators/types.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ArgumentPlaceholder = ArgumentPlaceholder;
    exports.ArrayPattern = exports.ArrayExpression = ArrayExpression;
    exports.BigIntLiteral = BigIntLiteral;
    exports.BooleanLiteral = BooleanLiteral;
    exports.DecimalLiteral = DecimalLiteral;
    exports.Identifier = Identifier;
    exports.NullLiteral = NullLiteral;
    exports.NumericLiteral = NumericLiteral;
    exports.ObjectPattern = exports.ObjectExpression = ObjectExpression;
    exports.ObjectMethod = ObjectMethod;
    exports.ObjectProperty = ObjectProperty;
    exports.PipelineBareFunction = PipelineBareFunction;
    exports.PipelinePrimaryTopicReference = PipelinePrimaryTopicReference;
    exports.PipelineTopicExpression = PipelineTopicExpression;
    exports.RecordExpression = RecordExpression;
    exports.RegExpLiteral = RegExpLiteral;
    exports.SpreadElement = exports.RestElement = RestElement;
    exports.StringLiteral = StringLiteral;
    exports.TopicReference = TopicReference;
    exports.TupleExpression = TupleExpression;
    var _t = require_lib11();
    var _jsesc = require_jsesc();
    var {
      isAssignmentPattern,
      isIdentifier: isIdentifier2
    } = _t;
    function Identifier(node) {
      this.word(node.name);
    }
    function ArgumentPlaceholder() {
      this.tokenChar(63);
    }
    function RestElement(node) {
      this.token("...");
      this.print(node.argument, node);
    }
    function ObjectExpression(node) {
      const props = node.properties;
      this.tokenChar(123);
      if (props.length) {
        this.space();
        this.printList(props, node, {
          indent: true,
          statement: true
        });
        this.space();
      }
      this.sourceWithOffset("end", node.loc, 0, -1);
      this.tokenChar(125);
    }
    function ObjectMethod(node) {
      this.printJoin(node.decorators, node);
      this._methodHead(node);
      this.space();
      this.print(node.body, node);
    }
    function ObjectProperty(node) {
      this.printJoin(node.decorators, node);
      if (node.computed) {
        this.tokenChar(91);
        this.print(node.key, node);
        this.tokenChar(93);
      } else {
        if (isAssignmentPattern(node.value) && isIdentifier2(node.key) && node.key.name === node.value.left.name) {
          this.print(node.value, node);
          return;
        }
        this.print(node.key, node);
        if (node.shorthand && isIdentifier2(node.key) && isIdentifier2(node.value) && node.key.name === node.value.name) {
          return;
        }
      }
      this.tokenChar(58);
      this.space();
      this.print(node.value, node);
    }
    function ArrayExpression(node) {
      const elems = node.elements;
      const len = elems.length;
      this.tokenChar(91);
      for (let i = 0; i < elems.length; i++) {
        const elem = elems[i];
        if (elem) {
          if (i > 0)
            this.space();
          this.print(elem, node);
          if (i < len - 1)
            this.tokenChar(44);
        } else {
          this.tokenChar(44);
        }
      }
      this.tokenChar(93);
    }
    function RecordExpression(node) {
      const props = node.properties;
      let startToken;
      let endToken;
      if (this.format.recordAndTupleSyntaxType === "bar") {
        startToken = "{|";
        endToken = "|}";
      } else if (this.format.recordAndTupleSyntaxType !== "hash" && this.format.recordAndTupleSyntaxType != null) {
        throw new Error(`The "recordAndTupleSyntaxType" generator option must be "bar" or "hash" (${JSON.stringify(this.format.recordAndTupleSyntaxType)} received).`);
      } else {
        startToken = "#{";
        endToken = "}";
      }
      this.token(startToken);
      if (props.length) {
        this.space();
        this.printList(props, node, {
          indent: true,
          statement: true
        });
        this.space();
      }
      this.token(endToken);
    }
    function TupleExpression(node) {
      const elems = node.elements;
      const len = elems.length;
      let startToken;
      let endToken;
      if (this.format.recordAndTupleSyntaxType === "bar") {
        startToken = "[|";
        endToken = "|]";
      } else if (this.format.recordAndTupleSyntaxType === "hash") {
        startToken = "#[";
        endToken = "]";
      } else {
        throw new Error(`${this.format.recordAndTupleSyntaxType} is not a valid recordAndTuple syntax type`);
      }
      this.token(startToken);
      for (let i = 0; i < elems.length; i++) {
        const elem = elems[i];
        if (elem) {
          if (i > 0)
            this.space();
          this.print(elem, node);
          if (i < len - 1)
            this.tokenChar(44);
        }
      }
      this.token(endToken);
    }
    function RegExpLiteral(node) {
      this.word(`/${node.pattern}/${node.flags}`);
    }
    function BooleanLiteral(node) {
      this.word(node.value ? "true" : "false");
    }
    function NullLiteral() {
      this.word("null");
    }
    function NumericLiteral(node) {
      const raw = this.getPossibleRaw(node);
      const opts = this.format.jsescOption;
      const value2 = node.value + "";
      if (opts.numbers) {
        this.number(_jsesc(node.value, opts));
      } else if (raw == null) {
        this.number(value2);
      } else if (this.format.minified) {
        this.number(raw.length < value2.length ? raw : value2);
      } else {
        this.number(raw);
      }
    }
    function StringLiteral(node) {
      const raw = this.getPossibleRaw(node);
      if (!this.format.minified && raw !== void 0) {
        this.token(raw);
        return;
      }
      const val = _jsesc(node.value, Object.assign(this.format.jsescOption, this.format.jsonCompatibleStrings && {
        json: true
      }));
      return this.token(val);
    }
    function BigIntLiteral(node) {
      const raw = this.getPossibleRaw(node);
      if (!this.format.minified && raw !== void 0) {
        this.word(raw);
        return;
      }
      this.word(node.value + "n");
    }
    function DecimalLiteral(node) {
      const raw = this.getPossibleRaw(node);
      if (!this.format.minified && raw !== void 0) {
        this.word(raw);
        return;
      }
      this.word(node.value + "m");
    }
    var validTopicTokenSet = /* @__PURE__ */ new Set(["^^", "@@", "^", "%", "#"]);
    function TopicReference() {
      const {
        topicToken
      } = this.format;
      if (validTopicTokenSet.has(topicToken)) {
        this.token(topicToken);
      } else {
        const givenTopicTokenJSON = JSON.stringify(topicToken);
        const validTopics = Array.from(validTopicTokenSet, (v) => JSON.stringify(v));
        throw new Error(`The "topicToken" generator option must be one of ${validTopics.join(", ")} (${givenTopicTokenJSON} received instead).`);
      }
    }
    function PipelineTopicExpression(node) {
      this.print(node.expression, node);
    }
    function PipelineBareFunction(node) {
      this.print(node.callee, node);
    }
    function PipelinePrimaryTopicReference() {
      this.tokenChar(35);
    }
  }
});

// node_modules/@babel/generator/lib/generators/flow.js
var require_flow2 = __commonJS({
  "node_modules/@babel/generator/lib/generators/flow.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.AnyTypeAnnotation = AnyTypeAnnotation;
    exports.ArrayTypeAnnotation = ArrayTypeAnnotation;
    exports.BooleanLiteralTypeAnnotation = BooleanLiteralTypeAnnotation;
    exports.BooleanTypeAnnotation = BooleanTypeAnnotation;
    exports.DeclareClass = DeclareClass;
    exports.DeclareExportAllDeclaration = DeclareExportAllDeclaration;
    exports.DeclareExportDeclaration = DeclareExportDeclaration;
    exports.DeclareFunction = DeclareFunction;
    exports.DeclareInterface = DeclareInterface;
    exports.DeclareModule = DeclareModule;
    exports.DeclareModuleExports = DeclareModuleExports;
    exports.DeclareOpaqueType = DeclareOpaqueType;
    exports.DeclareTypeAlias = DeclareTypeAlias;
    exports.DeclareVariable = DeclareVariable;
    exports.DeclaredPredicate = DeclaredPredicate;
    exports.EmptyTypeAnnotation = EmptyTypeAnnotation;
    exports.EnumBooleanBody = EnumBooleanBody;
    exports.EnumBooleanMember = EnumBooleanMember;
    exports.EnumDeclaration = EnumDeclaration;
    exports.EnumDefaultedMember = EnumDefaultedMember;
    exports.EnumNumberBody = EnumNumberBody;
    exports.EnumNumberMember = EnumNumberMember;
    exports.EnumStringBody = EnumStringBody;
    exports.EnumStringMember = EnumStringMember;
    exports.EnumSymbolBody = EnumSymbolBody;
    exports.ExistsTypeAnnotation = ExistsTypeAnnotation;
    exports.FunctionTypeAnnotation = FunctionTypeAnnotation;
    exports.FunctionTypeParam = FunctionTypeParam;
    exports.IndexedAccessType = IndexedAccessType;
    exports.InferredPredicate = InferredPredicate;
    exports.InterfaceDeclaration = InterfaceDeclaration;
    exports.GenericTypeAnnotation = exports.ClassImplements = exports.InterfaceExtends = InterfaceExtends;
    exports.InterfaceTypeAnnotation = InterfaceTypeAnnotation;
    exports.IntersectionTypeAnnotation = IntersectionTypeAnnotation;
    exports.MixedTypeAnnotation = MixedTypeAnnotation;
    exports.NullLiteralTypeAnnotation = NullLiteralTypeAnnotation;
    exports.NullableTypeAnnotation = NullableTypeAnnotation;
    Object.defineProperty(exports, "NumberLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _types2.NumericLiteral;
      }
    });
    exports.NumberTypeAnnotation = NumberTypeAnnotation;
    exports.ObjectTypeAnnotation = ObjectTypeAnnotation;
    exports.ObjectTypeCallProperty = ObjectTypeCallProperty;
    exports.ObjectTypeIndexer = ObjectTypeIndexer;
    exports.ObjectTypeInternalSlot = ObjectTypeInternalSlot;
    exports.ObjectTypeProperty = ObjectTypeProperty;
    exports.ObjectTypeSpreadProperty = ObjectTypeSpreadProperty;
    exports.OpaqueType = OpaqueType;
    exports.OptionalIndexedAccessType = OptionalIndexedAccessType;
    exports.QualifiedTypeIdentifier = QualifiedTypeIdentifier;
    Object.defineProperty(exports, "StringLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _types2.StringLiteral;
      }
    });
    exports.StringTypeAnnotation = StringTypeAnnotation;
    exports.SymbolTypeAnnotation = SymbolTypeAnnotation;
    exports.ThisTypeAnnotation = ThisTypeAnnotation;
    exports.TupleTypeAnnotation = TupleTypeAnnotation;
    exports.TypeAlias = TypeAlias;
    exports.TypeAnnotation = TypeAnnotation;
    exports.TypeCastExpression = TypeCastExpression;
    exports.TypeParameter = TypeParameter;
    exports.TypeParameterDeclaration = exports.TypeParameterInstantiation = TypeParameterInstantiation;
    exports.TypeofTypeAnnotation = TypeofTypeAnnotation;
    exports.UnionTypeAnnotation = UnionTypeAnnotation;
    exports.Variance = Variance;
    exports.VoidTypeAnnotation = VoidTypeAnnotation;
    exports._interfaceish = _interfaceish;
    exports._variance = _variance;
    var _t = require_lib11();
    var _modules = require_modules();
    var _types2 = require_types2();
    var {
      isDeclareExportDeclaration,
      isStatement
    } = _t;
    function AnyTypeAnnotation() {
      this.word("any");
    }
    function ArrayTypeAnnotation(node) {
      this.print(node.elementType, node, true);
      this.tokenChar(91);
      this.tokenChar(93);
    }
    function BooleanTypeAnnotation() {
      this.word("boolean");
    }
    function BooleanLiteralTypeAnnotation(node) {
      this.word(node.value ? "true" : "false");
    }
    function NullLiteralTypeAnnotation() {
      this.word("null");
    }
    function DeclareClass(node, parent) {
      if (!isDeclareExportDeclaration(parent)) {
        this.word("declare");
        this.space();
      }
      this.word("class");
      this.space();
      this._interfaceish(node);
    }
    function DeclareFunction(node, parent) {
      if (!isDeclareExportDeclaration(parent)) {
        this.word("declare");
        this.space();
      }
      this.word("function");
      this.space();
      this.print(node.id, node);
      this.print(node.id.typeAnnotation.typeAnnotation, node);
      if (node.predicate) {
        this.space();
        this.print(node.predicate, node);
      }
      this.semicolon();
    }
    function InferredPredicate() {
      this.tokenChar(37);
      this.word("checks");
    }
    function DeclaredPredicate(node) {
      this.tokenChar(37);
      this.word("checks");
      this.tokenChar(40);
      this.print(node.value, node);
      this.tokenChar(41);
    }
    function DeclareInterface(node) {
      this.word("declare");
      this.space();
      this.InterfaceDeclaration(node);
    }
    function DeclareModule(node) {
      this.word("declare");
      this.space();
      this.word("module");
      this.space();
      this.print(node.id, node);
      this.space();
      this.print(node.body, node);
    }
    function DeclareModuleExports(node) {
      this.word("declare");
      this.space();
      this.word("module");
      this.tokenChar(46);
      this.word("exports");
      this.print(node.typeAnnotation, node);
    }
    function DeclareTypeAlias(node) {
      this.word("declare");
      this.space();
      this.TypeAlias(node);
    }
    function DeclareOpaqueType(node, parent) {
      if (!isDeclareExportDeclaration(parent)) {
        this.word("declare");
        this.space();
      }
      this.OpaqueType(node);
    }
    function DeclareVariable(node, parent) {
      if (!isDeclareExportDeclaration(parent)) {
        this.word("declare");
        this.space();
      }
      this.word("var");
      this.space();
      this.print(node.id, node);
      this.print(node.id.typeAnnotation, node);
      this.semicolon();
    }
    function DeclareExportDeclaration(node) {
      this.word("declare");
      this.space();
      this.word("export");
      this.space();
      if (node.default) {
        this.word("default");
        this.space();
      }
      FlowExportDeclaration.call(this, node);
    }
    function DeclareExportAllDeclaration(node) {
      this.word("declare");
      this.space();
      _modules.ExportAllDeclaration.call(this, node);
    }
    function EnumDeclaration(node) {
      const {
        id,
        body
      } = node;
      this.word("enum");
      this.space();
      this.print(id, node);
      this.print(body, node);
    }
    function enumExplicitType(context, name, hasExplicitType) {
      if (hasExplicitType) {
        context.space();
        context.word("of");
        context.space();
        context.word(name);
      }
      context.space();
    }
    function enumBody(context, node) {
      const {
        members
      } = node;
      context.token("{");
      context.indent();
      context.newline();
      for (const member of members) {
        context.print(member, node);
        context.newline();
      }
      if (node.hasUnknownMembers) {
        context.token("...");
        context.newline();
      }
      context.dedent();
      context.token("}");
    }
    function EnumBooleanBody(node) {
      const {
        explicitType
      } = node;
      enumExplicitType(this, "boolean", explicitType);
      enumBody(this, node);
    }
    function EnumNumberBody(node) {
      const {
        explicitType
      } = node;
      enumExplicitType(this, "number", explicitType);
      enumBody(this, node);
    }
    function EnumStringBody(node) {
      const {
        explicitType
      } = node;
      enumExplicitType(this, "string", explicitType);
      enumBody(this, node);
    }
    function EnumSymbolBody(node) {
      enumExplicitType(this, "symbol", true);
      enumBody(this, node);
    }
    function EnumDefaultedMember(node) {
      const {
        id
      } = node;
      this.print(id, node);
      this.tokenChar(44);
    }
    function enumInitializedMember(context, node) {
      const {
        id,
        init
      } = node;
      context.print(id, node);
      context.space();
      context.token("=");
      context.space();
      context.print(init, node);
      context.token(",");
    }
    function EnumBooleanMember(node) {
      enumInitializedMember(this, node);
    }
    function EnumNumberMember(node) {
      enumInitializedMember(this, node);
    }
    function EnumStringMember(node) {
      enumInitializedMember(this, node);
    }
    function FlowExportDeclaration(node) {
      if (node.declaration) {
        const declar = node.declaration;
        this.print(declar, node);
        if (!isStatement(declar))
          this.semicolon();
      } else {
        this.tokenChar(123);
        if (node.specifiers.length) {
          this.space();
          this.printList(node.specifiers, node);
          this.space();
        }
        this.tokenChar(125);
        if (node.source) {
          this.space();
          this.word("from");
          this.space();
          this.print(node.source, node);
        }
        this.semicolon();
      }
    }
    function ExistsTypeAnnotation() {
      this.tokenChar(42);
    }
    function FunctionTypeAnnotation(node, parent) {
      this.print(node.typeParameters, node);
      this.tokenChar(40);
      if (node.this) {
        this.word("this");
        this.tokenChar(58);
        this.space();
        this.print(node.this.typeAnnotation, node);
        if (node.params.length || node.rest) {
          this.tokenChar(44);
          this.space();
        }
      }
      this.printList(node.params, node);
      if (node.rest) {
        if (node.params.length) {
          this.tokenChar(44);
          this.space();
        }
        this.token("...");
        this.print(node.rest, node);
      }
      this.tokenChar(41);
      if (parent && (parent.type === "ObjectTypeCallProperty" || parent.type === "ObjectTypeInternalSlot" || parent.type === "DeclareFunction" || parent.type === "ObjectTypeProperty" && parent.method)) {
        this.tokenChar(58);
      } else {
        this.space();
        this.token("=>");
      }
      this.space();
      this.print(node.returnType, node);
    }
    function FunctionTypeParam(node) {
      this.print(node.name, node);
      if (node.optional)
        this.tokenChar(63);
      if (node.name) {
        this.tokenChar(58);
        this.space();
      }
      this.print(node.typeAnnotation, node);
    }
    function InterfaceExtends(node) {
      this.print(node.id, node);
      this.print(node.typeParameters, node, true);
    }
    function _interfaceish(node) {
      var _node$extends;
      this.print(node.id, node);
      this.print(node.typeParameters, node);
      if ((_node$extends = node.extends) != null && _node$extends.length) {
        this.space();
        this.word("extends");
        this.space();
        this.printList(node.extends, node);
      }
      if (node.mixins && node.mixins.length) {
        this.space();
        this.word("mixins");
        this.space();
        this.printList(node.mixins, node);
      }
      if (node.implements && node.implements.length) {
        this.space();
        this.word("implements");
        this.space();
        this.printList(node.implements, node);
      }
      this.space();
      this.print(node.body, node);
    }
    function _variance(node) {
      if (node.variance) {
        if (node.variance.kind === "plus") {
          this.tokenChar(43);
        } else if (node.variance.kind === "minus") {
          this.tokenChar(45);
        }
      }
    }
    function InterfaceDeclaration(node) {
      this.word("interface");
      this.space();
      this._interfaceish(node);
    }
    function andSeparator() {
      this.space();
      this.tokenChar(38);
      this.space();
    }
    function InterfaceTypeAnnotation(node) {
      this.word("interface");
      if (node.extends && node.extends.length) {
        this.space();
        this.word("extends");
        this.space();
        this.printList(node.extends, node);
      }
      this.space();
      this.print(node.body, node);
    }
    function IntersectionTypeAnnotation(node) {
      this.printJoin(node.types, node, {
        separator: andSeparator
      });
    }
    function MixedTypeAnnotation() {
      this.word("mixed");
    }
    function EmptyTypeAnnotation() {
      this.word("empty");
    }
    function NullableTypeAnnotation(node) {
      this.tokenChar(63);
      this.print(node.typeAnnotation, node);
    }
    function NumberTypeAnnotation() {
      this.word("number");
    }
    function StringTypeAnnotation() {
      this.word("string");
    }
    function ThisTypeAnnotation() {
      this.word("this");
    }
    function TupleTypeAnnotation(node) {
      this.tokenChar(91);
      this.printList(node.types, node);
      this.tokenChar(93);
    }
    function TypeofTypeAnnotation(node) {
      this.word("typeof");
      this.space();
      this.print(node.argument, node);
    }
    function TypeAlias(node) {
      this.word("type");
      this.space();
      this.print(node.id, node);
      this.print(node.typeParameters, node);
      this.space();
      this.tokenChar(61);
      this.space();
      this.print(node.right, node);
      this.semicolon();
    }
    function TypeAnnotation(node) {
      this.tokenChar(58);
      this.space();
      if (node.optional)
        this.tokenChar(63);
      this.print(node.typeAnnotation, node);
    }
    function TypeParameterInstantiation(node) {
      this.tokenChar(60);
      this.printList(node.params, node, {});
      this.tokenChar(62);
    }
    function TypeParameter(node) {
      this._variance(node);
      this.word(node.name);
      if (node.bound) {
        this.print(node.bound, node);
      }
      if (node.default) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.default, node);
      }
    }
    function OpaqueType(node) {
      this.word("opaque");
      this.space();
      this.word("type");
      this.space();
      this.print(node.id, node);
      this.print(node.typeParameters, node);
      if (node.supertype) {
        this.tokenChar(58);
        this.space();
        this.print(node.supertype, node);
      }
      if (node.impltype) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.impltype, node);
      }
      this.semicolon();
    }
    function ObjectTypeAnnotation(node) {
      if (node.exact) {
        this.token("{|");
      } else {
        this.tokenChar(123);
      }
      const props = [...node.properties, ...node.callProperties || [], ...node.indexers || [], ...node.internalSlots || []];
      if (props.length) {
        this.newline();
        this.space();
        this.printJoin(props, node, {
          addNewlines(leading) {
            if (leading && !props[0])
              return 1;
          },
          indent: true,
          statement: true,
          iterator: () => {
            if (props.length !== 1 || node.inexact) {
              this.tokenChar(44);
              this.space();
            }
          }
        });
        this.space();
      }
      if (node.inexact) {
        this.indent();
        this.token("...");
        if (props.length) {
          this.newline();
        }
        this.dedent();
      }
      if (node.exact) {
        this.token("|}");
      } else {
        this.tokenChar(125);
      }
    }
    function ObjectTypeInternalSlot(node) {
      if (node.static) {
        this.word("static");
        this.space();
      }
      this.tokenChar(91);
      this.tokenChar(91);
      this.print(node.id, node);
      this.tokenChar(93);
      this.tokenChar(93);
      if (node.optional)
        this.tokenChar(63);
      if (!node.method) {
        this.tokenChar(58);
        this.space();
      }
      this.print(node.value, node);
    }
    function ObjectTypeCallProperty(node) {
      if (node.static) {
        this.word("static");
        this.space();
      }
      this.print(node.value, node);
    }
    function ObjectTypeIndexer(node) {
      if (node.static) {
        this.word("static");
        this.space();
      }
      this._variance(node);
      this.tokenChar(91);
      if (node.id) {
        this.print(node.id, node);
        this.tokenChar(58);
        this.space();
      }
      this.print(node.key, node);
      this.tokenChar(93);
      this.tokenChar(58);
      this.space();
      this.print(node.value, node);
    }
    function ObjectTypeProperty(node) {
      if (node.proto) {
        this.word("proto");
        this.space();
      }
      if (node.static) {
        this.word("static");
        this.space();
      }
      if (node.kind === "get" || node.kind === "set") {
        this.word(node.kind);
        this.space();
      }
      this._variance(node);
      this.print(node.key, node);
      if (node.optional)
        this.tokenChar(63);
      if (!node.method) {
        this.tokenChar(58);
        this.space();
      }
      this.print(node.value, node);
    }
    function ObjectTypeSpreadProperty(node) {
      this.token("...");
      this.print(node.argument, node);
    }
    function QualifiedTypeIdentifier(node) {
      this.print(node.qualification, node);
      this.tokenChar(46);
      this.print(node.id, node);
    }
    function SymbolTypeAnnotation() {
      this.word("symbol");
    }
    function orSeparator() {
      this.space();
      this.tokenChar(124);
      this.space();
    }
    function UnionTypeAnnotation(node) {
      this.printJoin(node.types, node, {
        separator: orSeparator
      });
    }
    function TypeCastExpression(node) {
      this.tokenChar(40);
      this.print(node.expression, node);
      this.print(node.typeAnnotation, node);
      this.tokenChar(41);
    }
    function Variance(node) {
      if (node.kind === "plus") {
        this.tokenChar(43);
      } else {
        this.tokenChar(45);
      }
    }
    function VoidTypeAnnotation() {
      this.word("void");
    }
    function IndexedAccessType(node) {
      this.print(node.objectType, node, true);
      this.tokenChar(91);
      this.print(node.indexType, node);
      this.tokenChar(93);
    }
    function OptionalIndexedAccessType(node) {
      this.print(node.objectType, node);
      if (node.optional) {
        this.token("?.");
      }
      this.tokenChar(91);
      this.print(node.indexType, node);
      this.tokenChar(93);
    }
  }
});

// node_modules/@babel/generator/lib/generators/base.js
var require_base2 = __commonJS({
  "node_modules/@babel/generator/lib/generators/base.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.BlockStatement = BlockStatement;
    exports.Directive = Directive;
    exports.DirectiveLiteral = DirectiveLiteral;
    exports.File = File2;
    exports.InterpreterDirective = InterpreterDirective;
    exports.Placeholder = Placeholder;
    exports.Program = Program;
    function File2(node) {
      if (node.program) {
        this.print(node.program.interpreter, node);
      }
      this.print(node.program, node);
    }
    function Program(node) {
      var _node$directives;
      this.noIndentInnerCommentsHere();
      this.printInnerComments();
      const directivesLen = (_node$directives = node.directives) == null ? void 0 : _node$directives.length;
      if (directivesLen) {
        var _node$directives$trai;
        const newline = node.body.length ? 2 : 1;
        this.printSequence(node.directives, node, {
          trailingCommentsLineOffset: newline
        });
        if (!((_node$directives$trai = node.directives[directivesLen - 1].trailingComments) != null && _node$directives$trai.length)) {
          this.newline(newline);
        }
      }
      this.printSequence(node.body, node);
    }
    function BlockStatement(node) {
      var _node$directives2;
      this.tokenChar(123);
      const directivesLen = (_node$directives2 = node.directives) == null ? void 0 : _node$directives2.length;
      if (directivesLen) {
        var _node$directives$trai2;
        const newline = node.body.length ? 2 : 1;
        this.printSequence(node.directives, node, {
          indent: true,
          trailingCommentsLineOffset: newline
        });
        if (!((_node$directives$trai2 = node.directives[directivesLen - 1].trailingComments) != null && _node$directives$trai2.length)) {
          this.newline(newline);
        }
      }
      this.printSequence(node.body, node, {
        indent: true
      });
      this.sourceWithOffset("end", node.loc, 0, -1);
      this.rightBrace();
    }
    function Directive(node) {
      this.print(node.value, node);
      this.semicolon();
    }
    var unescapedSingleQuoteRE = /(?:^|[^\\])(?:\\\\)*'/;
    var unescapedDoubleQuoteRE = /(?:^|[^\\])(?:\\\\)*"/;
    function DirectiveLiteral(node) {
      const raw = this.getPossibleRaw(node);
      if (!this.format.minified && raw !== void 0) {
        this.token(raw);
        return;
      }
      const {
        value: value2
      } = node;
      if (!unescapedDoubleQuoteRE.test(value2)) {
        this.token(`"${value2}"`);
      } else if (!unescapedSingleQuoteRE.test(value2)) {
        this.token(`'${value2}'`);
      } else {
        throw new Error("Malformed AST: it is not possible to print a directive containing both unescaped single and double quotes.");
      }
    }
    function InterpreterDirective(node) {
      this.token(`#!${node.value}`);
      this.newline(1, true);
    }
    function Placeholder(node) {
      this.token("%%");
      this.print(node.name);
      this.token("%%");
      if (node.expectedNode === "Statement") {
        this.semicolon();
      }
    }
  }
});

// node_modules/@babel/generator/lib/generators/jsx.js
var require_jsx2 = __commonJS({
  "node_modules/@babel/generator/lib/generators/jsx.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.JSXAttribute = JSXAttribute;
    exports.JSXClosingElement = JSXClosingElement;
    exports.JSXClosingFragment = JSXClosingFragment;
    exports.JSXElement = JSXElement;
    exports.JSXEmptyExpression = JSXEmptyExpression;
    exports.JSXExpressionContainer = JSXExpressionContainer;
    exports.JSXFragment = JSXFragment;
    exports.JSXIdentifier = JSXIdentifier;
    exports.JSXMemberExpression = JSXMemberExpression;
    exports.JSXNamespacedName = JSXNamespacedName;
    exports.JSXOpeningElement = JSXOpeningElement;
    exports.JSXOpeningFragment = JSXOpeningFragment;
    exports.JSXSpreadAttribute = JSXSpreadAttribute;
    exports.JSXSpreadChild = JSXSpreadChild;
    exports.JSXText = JSXText;
    function JSXAttribute(node) {
      this.print(node.name, node);
      if (node.value) {
        this.tokenChar(61);
        this.print(node.value, node);
      }
    }
    function JSXIdentifier(node) {
      this.word(node.name);
    }
    function JSXNamespacedName(node) {
      this.print(node.namespace, node);
      this.tokenChar(58);
      this.print(node.name, node);
    }
    function JSXMemberExpression(node) {
      this.print(node.object, node);
      this.tokenChar(46);
      this.print(node.property, node);
    }
    function JSXSpreadAttribute(node) {
      this.tokenChar(123);
      this.token("...");
      this.print(node.argument, node);
      this.tokenChar(125);
    }
    function JSXExpressionContainer(node) {
      this.tokenChar(123);
      this.print(node.expression, node);
      this.tokenChar(125);
    }
    function JSXSpreadChild(node) {
      this.tokenChar(123);
      this.token("...");
      this.print(node.expression, node);
      this.tokenChar(125);
    }
    function JSXText(node) {
      const raw = this.getPossibleRaw(node);
      if (raw !== void 0) {
        this.token(raw, true);
      } else {
        this.token(node.value, true);
      }
    }
    function JSXElement(node) {
      const open = node.openingElement;
      this.print(open, node);
      if (open.selfClosing)
        return;
      this.indent();
      for (const child of node.children) {
        this.print(child, node);
      }
      this.dedent();
      this.print(node.closingElement, node);
    }
    function spaceSeparator() {
      this.space();
    }
    function JSXOpeningElement(node) {
      this.tokenChar(60);
      this.print(node.name, node);
      this.print(node.typeParameters, node);
      if (node.attributes.length > 0) {
        this.space();
        this.printJoin(node.attributes, node, {
          separator: spaceSeparator
        });
      }
      if (node.selfClosing) {
        this.space();
        this.token("/>");
      } else {
        this.tokenChar(62);
      }
    }
    function JSXClosingElement(node) {
      this.token("</");
      this.print(node.name, node);
      this.tokenChar(62);
    }
    function JSXEmptyExpression() {
      this.printInnerComments();
    }
    function JSXFragment(node) {
      this.print(node.openingFragment, node);
      this.indent();
      for (const child of node.children) {
        this.print(child, node);
      }
      this.dedent();
      this.print(node.closingFragment, node);
    }
    function JSXOpeningFragment() {
      this.tokenChar(60);
      this.tokenChar(62);
    }
    function JSXClosingFragment() {
      this.token("</");
      this.tokenChar(62);
    }
  }
});

// node_modules/@babel/generator/lib/generators/typescript.js
var require_typescript2 = __commonJS({
  "node_modules/@babel/generator/lib/generators/typescript.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.TSAnyKeyword = TSAnyKeyword;
    exports.TSArrayType = TSArrayType;
    exports.TSSatisfiesExpression = exports.TSAsExpression = TSTypeExpression;
    exports.TSBigIntKeyword = TSBigIntKeyword;
    exports.TSBooleanKeyword = TSBooleanKeyword;
    exports.TSCallSignatureDeclaration = TSCallSignatureDeclaration;
    exports.TSConditionalType = TSConditionalType;
    exports.TSConstructSignatureDeclaration = TSConstructSignatureDeclaration;
    exports.TSConstructorType = TSConstructorType;
    exports.TSDeclareFunction = TSDeclareFunction;
    exports.TSDeclareMethod = TSDeclareMethod;
    exports.TSEnumDeclaration = TSEnumDeclaration;
    exports.TSEnumMember = TSEnumMember;
    exports.TSExportAssignment = TSExportAssignment;
    exports.TSExpressionWithTypeArguments = TSExpressionWithTypeArguments;
    exports.TSExternalModuleReference = TSExternalModuleReference;
    exports.TSFunctionType = TSFunctionType;
    exports.TSImportEqualsDeclaration = TSImportEqualsDeclaration;
    exports.TSImportType = TSImportType;
    exports.TSIndexSignature = TSIndexSignature;
    exports.TSIndexedAccessType = TSIndexedAccessType;
    exports.TSInferType = TSInferType;
    exports.TSInstantiationExpression = TSInstantiationExpression;
    exports.TSInterfaceBody = TSInterfaceBody;
    exports.TSInterfaceDeclaration = TSInterfaceDeclaration;
    exports.TSIntersectionType = TSIntersectionType;
    exports.TSIntrinsicKeyword = TSIntrinsicKeyword;
    exports.TSLiteralType = TSLiteralType;
    exports.TSMappedType = TSMappedType;
    exports.TSMethodSignature = TSMethodSignature;
    exports.TSModuleBlock = TSModuleBlock;
    exports.TSModuleDeclaration = TSModuleDeclaration;
    exports.TSNamedTupleMember = TSNamedTupleMember;
    exports.TSNamespaceExportDeclaration = TSNamespaceExportDeclaration;
    exports.TSNeverKeyword = TSNeverKeyword;
    exports.TSNonNullExpression = TSNonNullExpression;
    exports.TSNullKeyword = TSNullKeyword;
    exports.TSNumberKeyword = TSNumberKeyword;
    exports.TSObjectKeyword = TSObjectKeyword;
    exports.TSOptionalType = TSOptionalType;
    exports.TSParameterProperty = TSParameterProperty;
    exports.TSParenthesizedType = TSParenthesizedType;
    exports.TSPropertySignature = TSPropertySignature;
    exports.TSQualifiedName = TSQualifiedName;
    exports.TSRestType = TSRestType;
    exports.TSStringKeyword = TSStringKeyword;
    exports.TSSymbolKeyword = TSSymbolKeyword;
    exports.TSThisType = TSThisType;
    exports.TSTupleType = TSTupleType;
    exports.TSTypeAliasDeclaration = TSTypeAliasDeclaration;
    exports.TSTypeAnnotation = TSTypeAnnotation;
    exports.TSTypeAssertion = TSTypeAssertion;
    exports.TSTypeLiteral = TSTypeLiteral;
    exports.TSTypeOperator = TSTypeOperator;
    exports.TSTypeParameter = TSTypeParameter;
    exports.TSTypeParameterDeclaration = exports.TSTypeParameterInstantiation = TSTypeParameterInstantiation;
    exports.TSTypePredicate = TSTypePredicate;
    exports.TSTypeQuery = TSTypeQuery;
    exports.TSTypeReference = TSTypeReference;
    exports.TSUndefinedKeyword = TSUndefinedKeyword;
    exports.TSUnionType = TSUnionType;
    exports.TSUnknownKeyword = TSUnknownKeyword;
    exports.TSVoidKeyword = TSVoidKeyword;
    exports.tsPrintClassMemberModifiers = tsPrintClassMemberModifiers;
    exports.tsPrintFunctionOrConstructorType = tsPrintFunctionOrConstructorType;
    exports.tsPrintPropertyOrMethodName = tsPrintPropertyOrMethodName;
    exports.tsPrintSignatureDeclarationBase = tsPrintSignatureDeclarationBase;
    exports.tsPrintTypeLiteralOrInterfaceBody = tsPrintTypeLiteralOrInterfaceBody;
    function TSTypeAnnotation(node) {
      this.tokenChar(58);
      this.space();
      if (node.optional)
        this.tokenChar(63);
      this.print(node.typeAnnotation, node);
    }
    function TSTypeParameterInstantiation(node, parent) {
      this.tokenChar(60);
      this.printList(node.params, node, {});
      if (parent.type === "ArrowFunctionExpression" && node.params.length === 1) {
        this.tokenChar(44);
      }
      this.tokenChar(62);
    }
    function TSTypeParameter(node) {
      if (node.in) {
        this.word("in");
        this.space();
      }
      if (node.out) {
        this.word("out");
        this.space();
      }
      this.word(node.name);
      if (node.constraint) {
        this.space();
        this.word("extends");
        this.space();
        this.print(node.constraint, node);
      }
      if (node.default) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(node.default, node);
      }
    }
    function TSParameterProperty(node) {
      if (node.accessibility) {
        this.word(node.accessibility);
        this.space();
      }
      if (node.readonly) {
        this.word("readonly");
        this.space();
      }
      this._param(node.parameter);
    }
    function TSDeclareFunction(node) {
      if (node.declare) {
        this.word("declare");
        this.space();
      }
      this._functionHead(node);
      this.tokenChar(59);
    }
    function TSDeclareMethod(node) {
      this._classMethodHead(node);
      this.tokenChar(59);
    }
    function TSQualifiedName(node) {
      this.print(node.left, node);
      this.tokenChar(46);
      this.print(node.right, node);
    }
    function TSCallSignatureDeclaration(node) {
      this.tsPrintSignatureDeclarationBase(node);
      this.tokenChar(59);
    }
    function TSConstructSignatureDeclaration(node) {
      this.word("new");
      this.space();
      this.tsPrintSignatureDeclarationBase(node);
      this.tokenChar(59);
    }
    function TSPropertySignature(node) {
      const {
        readonly,
        initializer
      } = node;
      if (readonly) {
        this.word("readonly");
        this.space();
      }
      this.tsPrintPropertyOrMethodName(node);
      this.print(node.typeAnnotation, node);
      if (initializer) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(initializer, node);
      }
      this.tokenChar(59);
    }
    function tsPrintPropertyOrMethodName(node) {
      if (node.computed) {
        this.tokenChar(91);
      }
      this.print(node.key, node);
      if (node.computed) {
        this.tokenChar(93);
      }
      if (node.optional) {
        this.tokenChar(63);
      }
    }
    function TSMethodSignature(node) {
      const {
        kind
      } = node;
      if (kind === "set" || kind === "get") {
        this.word(kind);
        this.space();
      }
      this.tsPrintPropertyOrMethodName(node);
      this.tsPrintSignatureDeclarationBase(node);
      this.tokenChar(59);
    }
    function TSIndexSignature(node) {
      const {
        readonly,
        static: isStatic
      } = node;
      if (isStatic) {
        this.word("static");
        this.space();
      }
      if (readonly) {
        this.word("readonly");
        this.space();
      }
      this.tokenChar(91);
      this._parameters(node.parameters, node);
      this.tokenChar(93);
      this.print(node.typeAnnotation, node);
      this.tokenChar(59);
    }
    function TSAnyKeyword() {
      this.word("any");
    }
    function TSBigIntKeyword() {
      this.word("bigint");
    }
    function TSUnknownKeyword() {
      this.word("unknown");
    }
    function TSNumberKeyword() {
      this.word("number");
    }
    function TSObjectKeyword() {
      this.word("object");
    }
    function TSBooleanKeyword() {
      this.word("boolean");
    }
    function TSStringKeyword() {
      this.word("string");
    }
    function TSSymbolKeyword() {
      this.word("symbol");
    }
    function TSVoidKeyword() {
      this.word("void");
    }
    function TSUndefinedKeyword() {
      this.word("undefined");
    }
    function TSNullKeyword() {
      this.word("null");
    }
    function TSNeverKeyword() {
      this.word("never");
    }
    function TSIntrinsicKeyword() {
      this.word("intrinsic");
    }
    function TSThisType() {
      this.word("this");
    }
    function TSFunctionType(node) {
      this.tsPrintFunctionOrConstructorType(node);
    }
    function TSConstructorType(node) {
      if (node.abstract) {
        this.word("abstract");
        this.space();
      }
      this.word("new");
      this.space();
      this.tsPrintFunctionOrConstructorType(node);
    }
    function tsPrintFunctionOrConstructorType(node) {
      const {
        typeParameters
      } = node;
      const parameters = node.parameters;
      this.print(typeParameters, node);
      this.tokenChar(40);
      this._parameters(parameters, node);
      this.tokenChar(41);
      this.space();
      this.token("=>");
      this.space();
      const returnType = node.typeAnnotation;
      this.print(returnType.typeAnnotation, node);
    }
    function TSTypeReference(node) {
      this.print(node.typeName, node, true);
      this.print(node.typeParameters, node, true);
    }
    function TSTypePredicate(node) {
      if (node.asserts) {
        this.word("asserts");
        this.space();
      }
      this.print(node.parameterName);
      if (node.typeAnnotation) {
        this.space();
        this.word("is");
        this.space();
        this.print(node.typeAnnotation.typeAnnotation);
      }
    }
    function TSTypeQuery(node) {
      this.word("typeof");
      this.space();
      this.print(node.exprName);
      if (node.typeParameters) {
        this.print(node.typeParameters, node);
      }
    }
    function TSTypeLiteral(node) {
      this.tsPrintTypeLiteralOrInterfaceBody(node.members, node);
    }
    function tsPrintTypeLiteralOrInterfaceBody(members, node) {
      tsPrintBraced(this, members, node);
    }
    function tsPrintBraced(printer, members, node) {
      printer.token("{");
      if (members.length) {
        printer.indent();
        printer.newline();
        for (const member of members) {
          printer.print(member, node);
          printer.newline();
        }
        printer.dedent();
      }
      printer.sourceWithOffset("end", node.loc, 0, -1);
      printer.rightBrace();
    }
    function TSArrayType(node) {
      this.print(node.elementType, node, true);
      this.token("[]");
    }
    function TSTupleType(node) {
      this.tokenChar(91);
      this.printList(node.elementTypes, node);
      this.tokenChar(93);
    }
    function TSOptionalType(node) {
      this.print(node.typeAnnotation, node);
      this.tokenChar(63);
    }
    function TSRestType(node) {
      this.token("...");
      this.print(node.typeAnnotation, node);
    }
    function TSNamedTupleMember(node) {
      this.print(node.label, node);
      if (node.optional)
        this.tokenChar(63);
      this.tokenChar(58);
      this.space();
      this.print(node.elementType, node);
    }
    function TSUnionType(node) {
      tsPrintUnionOrIntersectionType(this, node, "|");
    }
    function TSIntersectionType(node) {
      tsPrintUnionOrIntersectionType(this, node, "&");
    }
    function tsPrintUnionOrIntersectionType(printer, node, sep) {
      printer.printJoin(node.types, node, {
        separator() {
          this.space();
          this.token(sep);
          this.space();
        }
      });
    }
    function TSConditionalType(node) {
      this.print(node.checkType);
      this.space();
      this.word("extends");
      this.space();
      this.print(node.extendsType);
      this.space();
      this.tokenChar(63);
      this.space();
      this.print(node.trueType);
      this.space();
      this.tokenChar(58);
      this.space();
      this.print(node.falseType);
    }
    function TSInferType(node) {
      this.token("infer");
      this.space();
      this.print(node.typeParameter);
    }
    function TSParenthesizedType(node) {
      this.tokenChar(40);
      this.print(node.typeAnnotation, node);
      this.tokenChar(41);
    }
    function TSTypeOperator(node) {
      this.word(node.operator);
      this.space();
      this.print(node.typeAnnotation, node);
    }
    function TSIndexedAccessType(node) {
      this.print(node.objectType, node, true);
      this.tokenChar(91);
      this.print(node.indexType, node);
      this.tokenChar(93);
    }
    function TSMappedType(node) {
      const {
        nameType,
        optional,
        readonly,
        typeParameter
      } = node;
      this.tokenChar(123);
      this.space();
      if (readonly) {
        tokenIfPlusMinus(this, readonly);
        this.word("readonly");
        this.space();
      }
      this.tokenChar(91);
      this.word(typeParameter.name);
      this.space();
      this.word("in");
      this.space();
      this.print(typeParameter.constraint, typeParameter);
      if (nameType) {
        this.space();
        this.word("as");
        this.space();
        this.print(nameType, node);
      }
      this.tokenChar(93);
      if (optional) {
        tokenIfPlusMinus(this, optional);
        this.tokenChar(63);
      }
      this.tokenChar(58);
      this.space();
      this.print(node.typeAnnotation, node);
      this.space();
      this.tokenChar(125);
    }
    function tokenIfPlusMinus(self2, tok) {
      if (tok !== true) {
        self2.token(tok);
      }
    }
    function TSLiteralType(node) {
      this.print(node.literal, node);
    }
    function TSExpressionWithTypeArguments(node) {
      this.print(node.expression, node);
      this.print(node.typeParameters, node);
    }
    function TSInterfaceDeclaration(node) {
      const {
        declare,
        id,
        typeParameters,
        extends: extendz,
        body
      } = node;
      if (declare) {
        this.word("declare");
        this.space();
      }
      this.word("interface");
      this.space();
      this.print(id, node);
      this.print(typeParameters, node);
      if (extendz != null && extendz.length) {
        this.space();
        this.word("extends");
        this.space();
        this.printList(extendz, node);
      }
      this.space();
      this.print(body, node);
    }
    function TSInterfaceBody(node) {
      this.tsPrintTypeLiteralOrInterfaceBody(node.body, node);
    }
    function TSTypeAliasDeclaration(node) {
      const {
        declare,
        id,
        typeParameters,
        typeAnnotation
      } = node;
      if (declare) {
        this.word("declare");
        this.space();
      }
      this.word("type");
      this.space();
      this.print(id, node);
      this.print(typeParameters, node);
      this.space();
      this.tokenChar(61);
      this.space();
      this.print(typeAnnotation, node);
      this.tokenChar(59);
    }
    function TSTypeExpression(node) {
      var _expression$trailingC;
      const {
        type,
        expression,
        typeAnnotation
      } = node;
      const forceParens = !!((_expression$trailingC = expression.trailingComments) != null && _expression$trailingC.length);
      this.print(expression, node, true, void 0, forceParens);
      this.space();
      this.word(type === "TSAsExpression" ? "as" : "satisfies");
      this.space();
      this.print(typeAnnotation, node);
    }
    function TSTypeAssertion(node) {
      const {
        typeAnnotation,
        expression
      } = node;
      this.tokenChar(60);
      this.print(typeAnnotation, node);
      this.tokenChar(62);
      this.space();
      this.print(expression, node);
    }
    function TSInstantiationExpression(node) {
      this.print(node.expression, node);
      this.print(node.typeParameters, node);
    }
    function TSEnumDeclaration(node) {
      const {
        declare,
        const: isConst,
        id,
        members
      } = node;
      if (declare) {
        this.word("declare");
        this.space();
      }
      if (isConst) {
        this.word("const");
        this.space();
      }
      this.word("enum");
      this.space();
      this.print(id, node);
      this.space();
      tsPrintBraced(this, members, node);
    }
    function TSEnumMember(node) {
      const {
        id,
        initializer
      } = node;
      this.print(id, node);
      if (initializer) {
        this.space();
        this.tokenChar(61);
        this.space();
        this.print(initializer, node);
      }
      this.tokenChar(44);
    }
    function TSModuleDeclaration(node) {
      const {
        declare,
        id
      } = node;
      if (declare) {
        this.word("declare");
        this.space();
      }
      if (!node.global) {
        this.word(id.type === "Identifier" ? "namespace" : "module");
        this.space();
      }
      this.print(id, node);
      if (!node.body) {
        this.tokenChar(59);
        return;
      }
      let body = node.body;
      while (body.type === "TSModuleDeclaration") {
        this.tokenChar(46);
        this.print(body.id, body);
        body = body.body;
      }
      this.space();
      this.print(body, node);
    }
    function TSModuleBlock(node) {
      tsPrintBraced(this, node.body, node);
    }
    function TSImportType(node) {
      const {
        argument,
        qualifier,
        typeParameters
      } = node;
      this.word("import");
      this.tokenChar(40);
      this.print(argument, node);
      this.tokenChar(41);
      if (qualifier) {
        this.tokenChar(46);
        this.print(qualifier, node);
      }
      if (typeParameters) {
        this.print(typeParameters, node);
      }
    }
    function TSImportEqualsDeclaration(node) {
      const {
        isExport,
        id,
        moduleReference
      } = node;
      if (isExport) {
        this.word("export");
        this.space();
      }
      this.word("import");
      this.space();
      this.print(id, node);
      this.space();
      this.tokenChar(61);
      this.space();
      this.print(moduleReference, node);
      this.tokenChar(59);
    }
    function TSExternalModuleReference(node) {
      this.token("require(");
      this.print(node.expression, node);
      this.tokenChar(41);
    }
    function TSNonNullExpression(node) {
      this.print(node.expression, node);
      this.tokenChar(33);
    }
    function TSExportAssignment(node) {
      this.word("export");
      this.space();
      this.tokenChar(61);
      this.space();
      this.print(node.expression, node);
      this.tokenChar(59);
    }
    function TSNamespaceExportDeclaration(node) {
      this.word("export");
      this.space();
      this.word("as");
      this.space();
      this.word("namespace");
      this.space();
      this.print(node.id, node);
    }
    function tsPrintSignatureDeclarationBase(node) {
      const {
        typeParameters
      } = node;
      const parameters = node.parameters;
      this.print(typeParameters, node);
      this.tokenChar(40);
      this._parameters(parameters, node);
      this.tokenChar(41);
      const returnType = node.typeAnnotation;
      this.print(returnType, node);
    }
    function tsPrintClassMemberModifiers(node) {
      const isField = node.type === "ClassAccessorProperty" || node.type === "ClassProperty";
      if (isField && node.declare) {
        this.word("declare");
        this.space();
      }
      if (node.accessibility) {
        this.word(node.accessibility);
        this.space();
      }
      if (node.static) {
        this.word("static");
        this.space();
      }
      if (node.override) {
        this.word("override");
        this.space();
      }
      if (node.abstract) {
        this.word("abstract");
        this.space();
      }
      if (isField && node.readonly) {
        this.word("readonly");
        this.space();
      }
    }
  }
});

// node_modules/@babel/generator/lib/generators/index.js
var require_generators = __commonJS({
  "node_modules/@babel/generator/lib/generators/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    var _templateLiterals = require_template_literals();
    Object.keys(_templateLiterals).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _templateLiterals[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _templateLiterals[key];
        }
      });
    });
    var _expressions = require_expressions();
    Object.keys(_expressions).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _expressions[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _expressions[key];
        }
      });
    });
    var _statements = require_statements();
    Object.keys(_statements).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _statements[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _statements[key];
        }
      });
    });
    var _classes = require_classes();
    Object.keys(_classes).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _classes[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _classes[key];
        }
      });
    });
    var _methods = require_methods();
    Object.keys(_methods).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _methods[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _methods[key];
        }
      });
    });
    var _modules = require_modules();
    Object.keys(_modules).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _modules[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _modules[key];
        }
      });
    });
    var _types = require_types2();
    Object.keys(_types).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _types[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _types[key];
        }
      });
    });
    var _flow = require_flow2();
    Object.keys(_flow).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _flow[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _flow[key];
        }
      });
    });
    var _base = require_base2();
    Object.keys(_base).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _base[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _base[key];
        }
      });
    });
    var _jsx = require_jsx2();
    Object.keys(_jsx).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _jsx[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _jsx[key];
        }
      });
    });
    var _typescript = require_typescript2();
    Object.keys(_typescript).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (key in exports && exports[key] === _typescript[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _typescript[key];
        }
      });
    });
  }
});

// node_modules/@babel/generator/lib/printer.js
var require_printer = __commonJS({
  "node_modules/@babel/generator/lib/printer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _buffer = require_buffer2();
    var n = require_node3();
    var _t = require_lib11();
    var generatorFunctions = require_generators();
    var {
      isFunction,
      isStatement,
      isClassBody,
      isTSInterfaceBody,
      isTSEnumDeclaration
    } = _t;
    var SCIENTIFIC_NOTATION = /e/i;
    var ZERO_DECIMAL_INTEGER = /\.0+$/;
    var NON_DECIMAL_LITERAL = /^0[box]/;
    var PURE_ANNOTATION_RE = /^\s*[@#]__PURE__\s*$/;
    var HAS_NEWLINE = /[\n\r\u2028\u2029]/;
    var HAS_BlOCK_COMMENT_END = /\*\//;
    var {
      needsParens
    } = n;
    var Printer = class {
      constructor(format2, map) {
        this.inForStatementInitCounter = 0;
        this._printStack = [];
        this._indent = 0;
        this._indentChar = 0;
        this._indentRepeat = 0;
        this._insideAux = false;
        this._parenPushNewlineState = null;
        this._noLineTerminator = false;
        this._printAuxAfterOnNextUserNode = false;
        this._printedComments = /* @__PURE__ */ new Set();
        this._endsWithInteger = false;
        this._endsWithWord = false;
        this._lastCommentLine = 0;
        this._endsWithInnerRaw = false;
        this._indentInnerComments = true;
        this.format = format2;
        this._buf = new _buffer.default(map);
        this._indentChar = format2.indent.style.charCodeAt(0);
        this._indentRepeat = format2.indent.style.length;
      }
      generate(ast) {
        this.print(ast);
        this._maybeAddAuxComment();
        return this._buf.get();
      }
      indent() {
        if (this.format.compact || this.format.concise)
          return;
        this._indent++;
      }
      dedent() {
        if (this.format.compact || this.format.concise)
          return;
        this._indent--;
      }
      semicolon(force = false) {
        this._maybeAddAuxComment();
        if (force) {
          this._appendChar(59);
        } else {
          this._queue(59);
        }
        this._noLineTerminator = false;
      }
      rightBrace() {
        if (this.format.minified) {
          this._buf.removeLastSemicolon();
        }
        this.tokenChar(125);
      }
      space(force = false) {
        if (this.format.compact)
          return;
        if (force) {
          this._space();
        } else if (this._buf.hasContent()) {
          const lastCp = this.getLastChar();
          if (lastCp !== 32 && lastCp !== 10) {
            this._space();
          }
        }
      }
      word(str, noLineTerminatorAfter = false) {
        this._maybePrintInnerComments();
        if (this._endsWithWord || str.charCodeAt(0) === 47 && this.endsWith(47)) {
          this._space();
        }
        this._maybeAddAuxComment();
        this._append(str, false);
        this._endsWithWord = true;
        this._noLineTerminator = noLineTerminatorAfter;
      }
      number(str) {
        this.word(str);
        this._endsWithInteger = Number.isInteger(+str) && !NON_DECIMAL_LITERAL.test(str) && !SCIENTIFIC_NOTATION.test(str) && !ZERO_DECIMAL_INTEGER.test(str) && str.charCodeAt(str.length - 1) !== 46;
      }
      token(str, maybeNewline = false) {
        this._maybePrintInnerComments();
        const lastChar = this.getLastChar();
        const strFirst = str.charCodeAt(0);
        if (lastChar === 33 && str === "--" || strFirst === 43 && lastChar === 43 || strFirst === 45 && lastChar === 45 || strFirst === 46 && this._endsWithInteger) {
          this._space();
        }
        this._maybeAddAuxComment();
        this._append(str, maybeNewline);
        this._noLineTerminator = false;
      }
      tokenChar(char) {
        this._maybePrintInnerComments();
        const lastChar = this.getLastChar();
        if (char === 43 && lastChar === 43 || char === 45 && lastChar === 45 || char === 46 && this._endsWithInteger) {
          this._space();
        }
        this._maybeAddAuxComment();
        this._appendChar(char);
        this._noLineTerminator = false;
      }
      newline(i = 1, force) {
        if (i <= 0)
          return;
        if (!force) {
          if (this.format.retainLines || this.format.compact)
            return;
          if (this.format.concise) {
            this.space();
            return;
          }
        }
        if (i > 2)
          i = 2;
        i -= this._buf.getNewlineCount();
        for (let j = 0; j < i; j++) {
          this._newline();
        }
        return;
      }
      endsWith(char) {
        return this.getLastChar() === char;
      }
      getLastChar() {
        return this._buf.getLastChar();
      }
      endsWithCharAndNewline() {
        return this._buf.endsWithCharAndNewline();
      }
      removeTrailingNewline() {
        this._buf.removeTrailingNewline();
      }
      exactSource(loc, cb) {
        if (!loc)
          return cb();
        this._catchUp("start", loc);
        this._buf.exactSource(loc, cb);
      }
      source(prop, loc) {
        if (!loc)
          return;
        this._catchUp(prop, loc);
        this._buf.source(prop, loc);
      }
      sourceWithOffset(prop, loc, lineOffset, columnOffset) {
        if (!loc)
          return;
        this._catchUp(prop, loc);
        this._buf.sourceWithOffset(prop, loc, lineOffset, columnOffset);
      }
      withSource(prop, loc, cb) {
        if (!loc)
          return cb();
        this._catchUp(prop, loc);
        this._buf.withSource(prop, loc, cb);
      }
      _space() {
        this._queue(32);
      }
      _newline() {
        this._queue(10);
      }
      _append(str, maybeNewline) {
        this._maybeAddParen(str);
        this._maybeIndent(str.charCodeAt(0));
        this._buf.append(str, maybeNewline);
        this._endsWithWord = false;
        this._endsWithInteger = false;
      }
      _appendChar(char) {
        this._maybeAddParenChar(char);
        this._maybeIndent(char);
        this._buf.appendChar(char);
        this._endsWithWord = false;
        this._endsWithInteger = false;
      }
      _queue(char) {
        this._maybeAddParenChar(char);
        this._maybeIndent(char);
        this._buf.queue(char);
        this._endsWithWord = false;
        this._endsWithInteger = false;
      }
      _maybeIndent(firstChar) {
        if (this._indent && firstChar !== 10 && this.endsWith(10)) {
          this._buf.queueIndentation(this._indentChar, this._getIndent());
        }
      }
      _shouldIndent(firstChar) {
        if (this._indent && firstChar !== 10 && this.endsWith(10)) {
          return true;
        }
      }
      _maybeAddParenChar(char) {
        const parenPushNewlineState = this._parenPushNewlineState;
        if (!parenPushNewlineState)
          return;
        if (char === 32) {
          return;
        }
        if (char !== 10) {
          this._parenPushNewlineState = null;
          return;
        }
        this.tokenChar(40);
        this.indent();
        parenPushNewlineState.printed = true;
      }
      _maybeAddParen(str) {
        const parenPushNewlineState = this._parenPushNewlineState;
        if (!parenPushNewlineState)
          return;
        const len = str.length;
        let i;
        for (i = 0; i < len && str.charCodeAt(i) === 32; i++)
          continue;
        if (i === len) {
          return;
        }
        const cha = str.charCodeAt(i);
        if (cha !== 10) {
          if (cha !== 47 || i + 1 === len) {
            this._parenPushNewlineState = null;
            return;
          }
          const chaPost = str.charCodeAt(i + 1);
          if (chaPost === 42) {
            if (PURE_ANNOTATION_RE.test(str.slice(i + 2, len - 2))) {
              return;
            }
          } else if (chaPost !== 47) {
            this._parenPushNewlineState = null;
            return;
          }
        }
        this.tokenChar(40);
        this.indent();
        parenPushNewlineState.printed = true;
      }
      catchUp(line) {
        if (!this.format.retainLines)
          return;
        const count = line - this._buf.getCurrentLine();
        for (let i = 0; i < count; i++) {
          this._newline();
        }
      }
      _catchUp(prop, loc) {
        if (!this.format.retainLines)
          return;
        const pos = loc ? loc[prop] : null;
        if ((pos == null ? void 0 : pos.line) != null) {
          const count = pos.line - this._buf.getCurrentLine();
          for (let i = 0; i < count; i++) {
            this._newline();
          }
        }
      }
      _getIndent() {
        return this._indentRepeat * this._indent;
      }
      printTerminatorless(node, parent, isLabel) {
        if (isLabel) {
          this._noLineTerminator = true;
          this.print(node, parent);
        } else {
          const terminatorState = {
            printed: false
          };
          this._parenPushNewlineState = terminatorState;
          this.print(node, parent);
          if (terminatorState.printed) {
            this.dedent();
            this.newline();
            this.tokenChar(41);
          }
        }
      }
      print(node, parent, noLineTerminatorAfter, trailingCommentsLineOffset, forceParens) {
        if (!node)
          return;
        this._endsWithInnerRaw = false;
        const nodeType = node.type;
        const format2 = this.format;
        const oldConcise = format2.concise;
        if (node._compact) {
          format2.concise = true;
        }
        const printMethod = this[nodeType];
        if (printMethod === void 0) {
          throw new ReferenceError(`unknown node of type ${JSON.stringify(nodeType)} with constructor ${JSON.stringify(node.constructor.name)}`);
        }
        this._printStack.push(node);
        const oldInAux = this._insideAux;
        this._insideAux = node.loc == void 0;
        this._maybeAddAuxComment(this._insideAux && !oldInAux);
        let shouldPrintParens = false;
        if (forceParens) {
          shouldPrintParens = true;
        } else if (format2.retainFunctionParens && nodeType === "FunctionExpression" && node.extra && node.extra.parenthesized) {
          shouldPrintParens = true;
        } else {
          shouldPrintParens = needsParens(node, parent, this._printStack);
        }
        if (shouldPrintParens) {
          this.tokenChar(40);
          this._endsWithInnerRaw = false;
        }
        this._lastCommentLine = 0;
        this._printLeadingComments(node, parent);
        const loc = nodeType === "Program" || nodeType === "File" ? null : node.loc;
        this.exactSource(loc, printMethod.bind(this, node, parent));
        if (shouldPrintParens) {
          this._printTrailingComments(node, parent);
          this.tokenChar(41);
          this._noLineTerminator = noLineTerminatorAfter;
        } else if (noLineTerminatorAfter && !this._noLineTerminator) {
          this._noLineTerminator = true;
          this._printTrailingComments(node, parent);
        } else {
          this._printTrailingComments(node, parent, trailingCommentsLineOffset);
        }
        this._printStack.pop();
        format2.concise = oldConcise;
        this._insideAux = oldInAux;
        this._endsWithInnerRaw = false;
      }
      _maybeAddAuxComment(enteredPositionlessNode) {
        if (enteredPositionlessNode)
          this._printAuxBeforeComment();
        if (!this._insideAux)
          this._printAuxAfterComment();
      }
      _printAuxBeforeComment() {
        if (this._printAuxAfterOnNextUserNode)
          return;
        this._printAuxAfterOnNextUserNode = true;
        const comment = this.format.auxiliaryCommentBefore;
        if (comment) {
          this._printComment({
            type: "CommentBlock",
            value: comment
          }, 0);
        }
      }
      _printAuxAfterComment() {
        if (!this._printAuxAfterOnNextUserNode)
          return;
        this._printAuxAfterOnNextUserNode = false;
        const comment = this.format.auxiliaryCommentAfter;
        if (comment) {
          this._printComment({
            type: "CommentBlock",
            value: comment
          }, 0);
        }
      }
      getPossibleRaw(node) {
        const extra = node.extra;
        if (extra && extra.raw != null && extra.rawValue != null && node.value === extra.rawValue) {
          return extra.raw;
        }
      }
      printJoin(nodes, parent, opts = {}) {
        if (!(nodes != null && nodes.length))
          return;
        if (opts.indent)
          this.indent();
        const newlineOpts = {
          addNewlines: opts.addNewlines,
          nextNodeStartLine: 0
        };
        const separator = opts.separator ? opts.separator.bind(this) : null;
        const len = nodes.length;
        for (let i = 0; i < len; i++) {
          const node = nodes[i];
          if (!node)
            continue;
          if (opts.statement)
            this._printNewline(i === 0, newlineOpts);
          this.print(node, parent, void 0, opts.trailingCommentsLineOffset || 0);
          opts.iterator == null ? void 0 : opts.iterator(node, i);
          if (i < len - 1)
            separator == null ? void 0 : separator();
          if (opts.statement) {
            if (i + 1 === len) {
              this.newline(1);
            } else {
              var _nextNode$loc;
              const nextNode = nodes[i + 1];
              newlineOpts.nextNodeStartLine = ((_nextNode$loc = nextNode.loc) == null ? void 0 : _nextNode$loc.start.line) || 0;
              this._printNewline(true, newlineOpts);
            }
          }
        }
        if (opts.indent)
          this.dedent();
      }
      printAndIndentOnComments(node, parent) {
        const indent = node.leadingComments && node.leadingComments.length > 0;
        if (indent)
          this.indent();
        this.print(node, parent);
        if (indent)
          this.dedent();
      }
      printBlock(parent) {
        const node = parent.body;
        if (node.type !== "EmptyStatement") {
          this.space();
        }
        this.print(node, parent);
      }
      _printTrailingComments(node, parent, lineOffset) {
        const {
          innerComments,
          trailingComments
        } = node;
        if (innerComments != null && innerComments.length) {
          this._printComments(2, innerComments, node, parent, lineOffset);
        }
        if (trailingComments != null && trailingComments.length) {
          this._printComments(2, trailingComments, node, parent, lineOffset);
        }
      }
      _printLeadingComments(node, parent) {
        const comments = node.leadingComments;
        if (!(comments != null && comments.length))
          return;
        this._printComments(0, comments, node, parent);
      }
      _maybePrintInnerComments() {
        if (this._endsWithInnerRaw)
          this.printInnerComments();
        this._endsWithInnerRaw = true;
        this._indentInnerComments = true;
      }
      printInnerComments() {
        const node = this._printStack[this._printStack.length - 1];
        const comments = node.innerComments;
        if (!(comments != null && comments.length))
          return;
        const hasSpace = this.endsWith(32);
        const indent = this._indentInnerComments;
        const printedCommentsCount = this._printedComments.size;
        if (indent)
          this.indent();
        this._printComments(1, comments, node);
        if (hasSpace && printedCommentsCount !== this._printedComments.size) {
          this.space();
        }
        if (indent)
          this.dedent();
      }
      noIndentInnerCommentsHere() {
        this._indentInnerComments = false;
      }
      printSequence(nodes, parent, opts = {}) {
        opts.statement = true;
        return this.printJoin(nodes, parent, opts);
      }
      printList(items, parent, opts = {}) {
        if (opts.separator == null) {
          opts.separator = commaSeparator;
        }
        return this.printJoin(items, parent, opts);
      }
      _printNewline(newLine, opts) {
        if (this.format.retainLines || this.format.compact)
          return;
        if (this.format.concise) {
          this.space();
          return;
        }
        if (!newLine) {
          return;
        }
        const startLine = opts.nextNodeStartLine;
        const lastCommentLine = this._lastCommentLine;
        if (startLine > 0 && lastCommentLine > 0) {
          const offset = startLine - lastCommentLine;
          if (offset >= 0) {
            this.newline(offset || 1);
            return;
          }
        }
        if (this._buf.hasContent()) {
          this.newline(1);
        }
      }
      _shouldPrintComment(comment) {
        if (comment.ignore)
          return 0;
        if (this._printedComments.has(comment))
          return 0;
        if (this._noLineTerminator && (HAS_NEWLINE.test(comment.value) || HAS_BlOCK_COMMENT_END.test(comment.value))) {
          return 2;
        }
        this._printedComments.add(comment);
        if (!this.format.shouldPrintComment(comment.value)) {
          return 0;
        }
        return 1;
      }
      _printComment(comment, skipNewLines) {
        const noLineTerminator = this._noLineTerminator;
        const isBlockComment = comment.type === "CommentBlock";
        const printNewLines = isBlockComment && skipNewLines !== 1 && !this._noLineTerminator;
        if (printNewLines && this._buf.hasContent() && skipNewLines !== 2) {
          this.newline(1);
        }
        const lastCharCode = this.getLastChar();
        if (lastCharCode !== 91 && lastCharCode !== 123) {
          this.space();
        }
        let val;
        if (isBlockComment) {
          val = `/*${comment.value}*/`;
          if (this.format.indent.adjustMultilineComment) {
            var _comment$loc;
            const offset = (_comment$loc = comment.loc) == null ? void 0 : _comment$loc.start.column;
            if (offset) {
              const newlineRegex = new RegExp("\\n\\s{1," + offset + "}", "g");
              val = val.replace(newlineRegex, "\n");
            }
            let indentSize = this.format.retainLines ? 0 : this._buf.getCurrentColumn();
            if (this._shouldIndent(47) || this.format.retainLines) {
              indentSize += this._getIndent();
            }
            val = val.replace(/\n(?!$)/g, `
${" ".repeat(indentSize)}`);
          }
        } else if (!noLineTerminator) {
          val = `//${comment.value}`;
        } else {
          val = `/*${comment.value}*/`;
        }
        if (this.endsWith(47))
          this._space();
        this.source("start", comment.loc);
        this._append(val, isBlockComment);
        if (!isBlockComment && !noLineTerminator) {
          this.newline(1, true);
        }
        if (printNewLines && skipNewLines !== 3) {
          this.newline(1);
        }
      }
      _printComments(type, comments, node, parent, lineOffset = 0) {
        const nodeLoc = node.loc;
        const len = comments.length;
        let hasLoc = !!nodeLoc;
        const nodeStartLine = hasLoc ? nodeLoc.start.line : 0;
        const nodeEndLine = hasLoc ? nodeLoc.end.line : 0;
        let lastLine = 0;
        let leadingCommentNewline = 0;
        const maybeNewline = this._noLineTerminator ? function() {
        } : this.newline.bind(this);
        for (let i = 0; i < len; i++) {
          const comment = comments[i];
          const shouldPrint = this._shouldPrintComment(comment);
          if (shouldPrint === 2) {
            hasLoc = false;
            break;
          }
          if (hasLoc && comment.loc && shouldPrint === 1) {
            const commentStartLine = comment.loc.start.line;
            const commentEndLine = comment.loc.end.line;
            if (type === 0) {
              let offset = 0;
              if (i === 0) {
                if (this._buf.hasContent() && (comment.type === "CommentLine" || commentStartLine != commentEndLine)) {
                  offset = leadingCommentNewline = 1;
                }
              } else {
                offset = commentStartLine - lastLine;
              }
              lastLine = commentEndLine;
              maybeNewline(offset);
              this._printComment(comment, 1);
              if (i + 1 === len) {
                maybeNewline(Math.max(nodeStartLine - lastLine, leadingCommentNewline));
                lastLine = nodeStartLine;
              }
            } else if (type === 1) {
              const offset = commentStartLine - (i === 0 ? nodeStartLine : lastLine);
              lastLine = commentEndLine;
              maybeNewline(offset);
              this._printComment(comment, 1);
              if (i + 1 === len) {
                maybeNewline(Math.min(1, nodeEndLine - lastLine));
                lastLine = nodeEndLine;
              }
            } else {
              const offset = commentStartLine - (i === 0 ? nodeEndLine - lineOffset : lastLine);
              lastLine = commentEndLine;
              maybeNewline(offset);
              this._printComment(comment, 1);
            }
          } else {
            hasLoc = false;
            if (shouldPrint !== 1) {
              continue;
            }
            if (len === 1) {
              const singleLine = comment.loc ? comment.loc.start.line === comment.loc.end.line : !HAS_NEWLINE.test(comment.value);
              const shouldSkipNewline = singleLine && !isStatement(node) && !isClassBody(parent) && !isTSInterfaceBody(parent) && !isTSEnumDeclaration(parent);
              if (type === 0) {
                this._printComment(comment, shouldSkipNewline && node.type !== "ObjectExpression" || singleLine && isFunction(parent, {
                  body: node
                }) ? 1 : 0);
              } else if (shouldSkipNewline && type === 2) {
                this._printComment(comment, 1);
              } else {
                this._printComment(comment, 0);
              }
            } else if (type === 1 && !(node.type === "ObjectExpression" && node.properties.length > 1) && node.type !== "ClassBody" && node.type !== "TSInterfaceBody") {
              this._printComment(comment, i === 0 ? 2 : i === len - 1 ? 3 : 0);
            } else {
              this._printComment(comment, 0);
            }
          }
        }
        if (type === 2 && hasLoc && lastLine) {
          this._lastCommentLine = lastLine;
        }
      }
    };
    Object.assign(Printer.prototype, generatorFunctions);
    {
      Printer.prototype.Noop = function Noop() {
      };
    }
    var _default = Printer;
    exports.default = _default;
    function commaSeparator() {
      this.tokenChar(44);
      this.space();
    }
  }
});

// node_modules/@babel/generator/lib/index.js
var require_lib14 = __commonJS({
  "node_modules/@babel/generator/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.CodeGenerator = void 0;
    exports.default = generate2;
    var _sourceMap = require_source_map();
    var _printer = require_printer();
    var Generator = class extends _printer.default {
      constructor(ast, opts = {}, code) {
        const format2 = normalizeOptions(code, opts);
        const map = opts.sourceMaps ? new _sourceMap.default(opts, code) : null;
        super(format2, map);
        this.ast = void 0;
        this.ast = ast;
      }
      generate() {
        return super.generate(this.ast);
      }
    };
    function normalizeOptions(code, opts) {
      const format2 = {
        auxiliaryCommentBefore: opts.auxiliaryCommentBefore,
        auxiliaryCommentAfter: opts.auxiliaryCommentAfter,
        shouldPrintComment: opts.shouldPrintComment,
        retainLines: opts.retainLines,
        retainFunctionParens: opts.retainFunctionParens,
        comments: opts.comments == null || opts.comments,
        compact: opts.compact,
        minified: opts.minified,
        concise: opts.concise,
        indent: {
          adjustMultilineComment: true,
          style: "  "
        },
        jsescOption: Object.assign({
          quotes: "double",
          wrap: true,
          minimal: false
        }, opts.jsescOption),
        recordAndTupleSyntaxType: opts.recordAndTupleSyntaxType,
        topicToken: opts.topicToken
      };
      {
        format2.decoratorsBeforeExport = !!opts.decoratorsBeforeExport;
        format2.jsonCompatibleStrings = opts.jsonCompatibleStrings;
      }
      if (format2.minified) {
        format2.compact = true;
        format2.shouldPrintComment = format2.shouldPrintComment || (() => format2.comments);
      } else {
        format2.shouldPrintComment = format2.shouldPrintComment || ((value2) => format2.comments || value2.includes("@license") || value2.includes("@preserve"));
      }
      if (format2.compact === "auto") {
        format2.compact = code.length > 5e5;
        if (format2.compact) {
          console.error(`[BABEL] Note: The code generator has deoptimised the styling of ${opts.filename} as it exceeds the max of ${"500KB"}.`);
        }
      }
      if (format2.compact) {
        format2.indent.adjustMultilineComment = false;
      }
      const {
        auxiliaryCommentBefore,
        auxiliaryCommentAfter,
        shouldPrintComment
      } = format2;
      if (auxiliaryCommentBefore && !shouldPrintComment(auxiliaryCommentBefore)) {
        format2.auxiliaryCommentBefore = void 0;
      }
      if (auxiliaryCommentAfter && !shouldPrintComment(auxiliaryCommentAfter)) {
        format2.auxiliaryCommentAfter = void 0;
      }
      return format2;
    }
    var CodeGenerator = class {
      constructor(ast, opts, code) {
        this._generator = void 0;
        this._generator = new Generator(ast, opts, code);
      }
      generate() {
        return this._generator.generate();
      }
    };
    exports.CodeGenerator = CodeGenerator;
    function generate2(ast, opts, code) {
      const gen = new Generator(ast, opts, code);
      return gen.generate();
    }
  }
});

// node_modules/@babel/traverse/lib/path/ancestry.js
var require_ancestry = __commonJS({
  "node_modules/@babel/traverse/lib/path/ancestry.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.find = find;
    exports.findParent = findParent;
    exports.getAncestry = getAncestry;
    exports.getDeepestCommonAncestorFrom = getDeepestCommonAncestorFrom;
    exports.getEarliestCommonAncestorFrom = getEarliestCommonAncestorFrom;
    exports.getFunctionParent = getFunctionParent;
    exports.getStatementParent = getStatementParent;
    exports.inType = inType;
    exports.isAncestor = isAncestor;
    exports.isDescendant = isDescendant;
    var _t = require_lib11();
    var {
      VISITOR_KEYS
    } = _t;
    function findParent(callback) {
      let path2 = this;
      while (path2 = path2.parentPath) {
        if (callback(path2))
          return path2;
      }
      return null;
    }
    function find(callback) {
      let path2 = this;
      do {
        if (callback(path2))
          return path2;
      } while (path2 = path2.parentPath);
      return null;
    }
    function getFunctionParent() {
      return this.findParent((p) => p.isFunction());
    }
    function getStatementParent() {
      let path2 = this;
      do {
        if (!path2.parentPath || Array.isArray(path2.container) && path2.isStatement()) {
          break;
        } else {
          path2 = path2.parentPath;
        }
      } while (path2);
      if (path2 && (path2.isProgram() || path2.isFile())) {
        throw new Error("File/Program node, we can't possibly find a statement parent to this");
      }
      return path2;
    }
    function getEarliestCommonAncestorFrom(paths) {
      return this.getDeepestCommonAncestorFrom(paths, function(deepest, i, ancestries) {
        let earliest;
        const keys3 = VISITOR_KEYS[deepest.type];
        for (const ancestry of ancestries) {
          const path2 = ancestry[i + 1];
          if (!earliest) {
            earliest = path2;
            continue;
          }
          if (path2.listKey && earliest.listKey === path2.listKey) {
            if (path2.key < earliest.key) {
              earliest = path2;
              continue;
            }
          }
          const earliestKeyIndex = keys3.indexOf(earliest.parentKey);
          const currentKeyIndex = keys3.indexOf(path2.parentKey);
          if (earliestKeyIndex > currentKeyIndex) {
            earliest = path2;
          }
        }
        return earliest;
      });
    }
    function getDeepestCommonAncestorFrom(paths, filter) {
      if (!paths.length) {
        return this;
      }
      if (paths.length === 1) {
        return paths[0];
      }
      let minDepth = Infinity;
      let lastCommonIndex, lastCommon;
      const ancestries = paths.map((path2) => {
        const ancestry = [];
        do {
          ancestry.unshift(path2);
        } while ((path2 = path2.parentPath) && path2 !== this);
        if (ancestry.length < minDepth) {
          minDepth = ancestry.length;
        }
        return ancestry;
      });
      const first2 = ancestries[0];
      depthLoop:
        for (let i = 0; i < minDepth; i++) {
          const shouldMatch = first2[i];
          for (const ancestry of ancestries) {
            if (ancestry[i] !== shouldMatch) {
              break depthLoop;
            }
          }
          lastCommonIndex = i;
          lastCommon = shouldMatch;
        }
      if (lastCommon) {
        if (filter) {
          return filter(lastCommon, lastCommonIndex, ancestries);
        } else {
          return lastCommon;
        }
      } else {
        throw new Error("Couldn't find intersection");
      }
    }
    function getAncestry() {
      let path2 = this;
      const paths = [];
      do {
        paths.push(path2);
      } while (path2 = path2.parentPath);
      return paths;
    }
    function isAncestor(maybeDescendant) {
      return maybeDescendant.isDescendant(this);
    }
    function isDescendant(maybeAncestor) {
      return !!this.findParent((parent) => parent === maybeAncestor);
    }
    function inType(...candidateTypes) {
      let path2 = this;
      while (path2) {
        for (const type of candidateTypes) {
          if (path2.node.type === type)
            return true;
        }
        path2 = path2.parentPath;
      }
      return false;
    }
  }
});

// node_modules/@babel/traverse/lib/path/inference/util.js
var require_util3 = __commonJS({
  "node_modules/@babel/traverse/lib/path/inference/util.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.createUnionType = createUnionType;
    var _t = require_lib11();
    var {
      createFlowUnionType,
      createTSUnionType,
      createUnionTypeAnnotation,
      isFlowType,
      isTSType: isTSType2
    } = _t;
    function createUnionType(types) {
      {
        if (isFlowType(types[0])) {
          if (createFlowUnionType) {
            return createFlowUnionType(types);
          }
          return createUnionTypeAnnotation(types);
        } else {
          if (createTSUnionType) {
            return createTSUnionType(types);
          }
        }
      }
    }
  }
});

// node_modules/@babel/traverse/lib/path/inference/inferer-reference.js
var require_inferer_reference = __commonJS({
  "node_modules/@babel/traverse/lib/path/inference/inferer-reference.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;
    var _t = require_lib11();
    var _util = require_util3();
    var {
      BOOLEAN_NUMBER_BINARY_OPERATORS,
      createTypeAnnotationBasedOnTypeof,
      numberTypeAnnotation,
      voidTypeAnnotation
    } = _t;
    function _default(node) {
      if (!this.isReferenced())
        return;
      const binding = this.scope.getBinding(node.name);
      if (binding) {
        if (binding.identifier.typeAnnotation) {
          return binding.identifier.typeAnnotation;
        } else {
          return getTypeAnnotationBindingConstantViolations(binding, this, node.name);
        }
      }
      if (node.name === "undefined") {
        return voidTypeAnnotation();
      } else if (node.name === "NaN" || node.name === "Infinity") {
        return numberTypeAnnotation();
      } else if (node.name === "arguments") {
      }
    }
    function getTypeAnnotationBindingConstantViolations(binding, path2, name) {
      const types = [];
      const functionConstantViolations = [];
      let constantViolations = getConstantViolationsBefore(binding, path2, functionConstantViolations);
      const testType = getConditionalAnnotation(binding, path2, name);
      if (testType) {
        const testConstantViolations = getConstantViolationsBefore(binding, testType.ifStatement);
        constantViolations = constantViolations.filter((path3) => testConstantViolations.indexOf(path3) < 0);
        types.push(testType.typeAnnotation);
      }
      if (constantViolations.length) {
        constantViolations.push(...functionConstantViolations);
        for (const violation of constantViolations) {
          types.push(violation.getTypeAnnotation());
        }
      }
      if (!types.length) {
        return;
      }
      return (0, _util.createUnionType)(types);
    }
    function getConstantViolationsBefore(binding, path2, functions) {
      const violations = binding.constantViolations.slice();
      violations.unshift(binding.path);
      return violations.filter((violation) => {
        violation = violation.resolve();
        const status = violation._guessExecutionStatusRelativeTo(path2);
        if (functions && status === "unknown")
          functions.push(violation);
        return status === "before";
      });
    }
    function inferAnnotationFromBinaryExpression(name, path2) {
      const operator = path2.node.operator;
      const right = path2.get("right").resolve();
      const left = path2.get("left").resolve();
      let target;
      if (left.isIdentifier({
        name
      })) {
        target = right;
      } else if (right.isIdentifier({
        name
      })) {
        target = left;
      }
      if (target) {
        if (operator === "===") {
          return target.getTypeAnnotation();
        }
        if (BOOLEAN_NUMBER_BINARY_OPERATORS.indexOf(operator) >= 0) {
          return numberTypeAnnotation();
        }
        return;
      }
      if (operator !== "===" && operator !== "==")
        return;
      let typeofPath;
      let typePath;
      if (left.isUnaryExpression({
        operator: "typeof"
      })) {
        typeofPath = left;
        typePath = right;
      } else if (right.isUnaryExpression({
        operator: "typeof"
      })) {
        typeofPath = right;
        typePath = left;
      }
      if (!typeofPath)
        return;
      if (!typeofPath.get("argument").isIdentifier({
        name
      }))
        return;
      typePath = typePath.resolve();
      if (!typePath.isLiteral())
        return;
      const typeValue = typePath.node.value;
      if (typeof typeValue !== "string")
        return;
      return createTypeAnnotationBasedOnTypeof(typeValue);
    }
    function getParentConditionalPath(binding, path2, name) {
      let parentPath;
      while (parentPath = path2.parentPath) {
        if (parentPath.isIfStatement() || parentPath.isConditionalExpression()) {
          if (path2.key === "test") {
            return;
          }
          return parentPath;
        }
        if (parentPath.isFunction()) {
          if (parentPath.parentPath.scope.getBinding(name) !== binding)
            return;
        }
        path2 = parentPath;
      }
    }
    function getConditionalAnnotation(binding, path2, name) {
      const ifStatement = getParentConditionalPath(binding, path2, name);
      if (!ifStatement)
        return;
      const test = ifStatement.get("test");
      const paths = [test];
      const types = [];
      for (let i = 0; i < paths.length; i++) {
        const path3 = paths[i];
        if (path3.isLogicalExpression()) {
          if (path3.node.operator === "&&") {
            paths.push(path3.get("left"));
            paths.push(path3.get("right"));
          }
        } else if (path3.isBinaryExpression()) {
          const type = inferAnnotationFromBinaryExpression(name, path3);
          if (type)
            types.push(type);
        }
      }
      if (types.length) {
        return {
          typeAnnotation: (0, _util.createUnionType)(types),
          ifStatement
        };
      }
      return getConditionalAnnotation(binding, ifStatement, name);
    }
  }
});

// node_modules/@babel/traverse/lib/path/inference/inferers.js
var require_inferers = __commonJS({
  "node_modules/@babel/traverse/lib/path/inference/inferers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ArrayExpression = ArrayExpression;
    exports.AssignmentExpression = AssignmentExpression;
    exports.BinaryExpression = BinaryExpression;
    exports.BooleanLiteral = BooleanLiteral;
    exports.CallExpression = CallExpression;
    exports.ConditionalExpression = ConditionalExpression;
    exports.ClassDeclaration = exports.ClassExpression = exports.FunctionDeclaration = exports.ArrowFunctionExpression = exports.FunctionExpression = Func;
    Object.defineProperty(exports, "Identifier", {
      enumerable: true,
      get: function() {
        return _infererReference.default;
      }
    });
    exports.LogicalExpression = LogicalExpression;
    exports.NewExpression = NewExpression;
    exports.NullLiteral = NullLiteral;
    exports.NumericLiteral = NumericLiteral;
    exports.ObjectExpression = ObjectExpression;
    exports.ParenthesizedExpression = ParenthesizedExpression;
    exports.RegExpLiteral = RegExpLiteral;
    exports.RestElement = RestElement;
    exports.SequenceExpression = SequenceExpression;
    exports.StringLiteral = StringLiteral;
    exports.TSAsExpression = TSAsExpression;
    exports.TSNonNullExpression = TSNonNullExpression;
    exports.TaggedTemplateExpression = TaggedTemplateExpression;
    exports.TemplateLiteral = TemplateLiteral;
    exports.TypeCastExpression = TypeCastExpression;
    exports.UnaryExpression = UnaryExpression;
    exports.UpdateExpression = UpdateExpression;
    exports.VariableDeclarator = VariableDeclarator;
    var _t = require_lib11();
    var _infererReference = require_inferer_reference();
    var _util = require_util3();
    var {
      BOOLEAN_BINARY_OPERATORS,
      BOOLEAN_UNARY_OPERATORS,
      NUMBER_BINARY_OPERATORS,
      NUMBER_UNARY_OPERATORS,
      STRING_UNARY_OPERATORS,
      anyTypeAnnotation,
      arrayTypeAnnotation,
      booleanTypeAnnotation,
      buildMatchMemberExpression,
      genericTypeAnnotation,
      identifier: identifier3,
      nullLiteralTypeAnnotation,
      numberTypeAnnotation,
      stringTypeAnnotation,
      tupleTypeAnnotation,
      unionTypeAnnotation,
      voidTypeAnnotation,
      isIdentifier: isIdentifier2
    } = _t;
    function VariableDeclarator() {
      if (!this.get("id").isIdentifier())
        return;
      return this.get("init").getTypeAnnotation();
    }
    function TypeCastExpression(node) {
      return node.typeAnnotation;
    }
    TypeCastExpression.validParent = true;
    function TSAsExpression(node) {
      return node.typeAnnotation;
    }
    TSAsExpression.validParent = true;
    function TSNonNullExpression() {
      return this.get("expression").getTypeAnnotation();
    }
    function NewExpression(node) {
      if (node.callee.type === "Identifier") {
        return genericTypeAnnotation(node.callee);
      }
    }
    function TemplateLiteral() {
      return stringTypeAnnotation();
    }
    function UnaryExpression(node) {
      const operator = node.operator;
      if (operator === "void") {
        return voidTypeAnnotation();
      } else if (NUMBER_UNARY_OPERATORS.indexOf(operator) >= 0) {
        return numberTypeAnnotation();
      } else if (STRING_UNARY_OPERATORS.indexOf(operator) >= 0) {
        return stringTypeAnnotation();
      } else if (BOOLEAN_UNARY_OPERATORS.indexOf(operator) >= 0) {
        return booleanTypeAnnotation();
      }
    }
    function BinaryExpression(node) {
      const operator = node.operator;
      if (NUMBER_BINARY_OPERATORS.indexOf(operator) >= 0) {
        return numberTypeAnnotation();
      } else if (BOOLEAN_BINARY_OPERATORS.indexOf(operator) >= 0) {
        return booleanTypeAnnotation();
      } else if (operator === "+") {
        const right = this.get("right");
        const left = this.get("left");
        if (left.isBaseType("number") && right.isBaseType("number")) {
          return numberTypeAnnotation();
        } else if (left.isBaseType("string") || right.isBaseType("string")) {
          return stringTypeAnnotation();
        }
        return unionTypeAnnotation([stringTypeAnnotation(), numberTypeAnnotation()]);
      }
    }
    function LogicalExpression() {
      const argumentTypes = [this.get("left").getTypeAnnotation(), this.get("right").getTypeAnnotation()];
      return (0, _util.createUnionType)(argumentTypes);
    }
    function ConditionalExpression() {
      const argumentTypes = [this.get("consequent").getTypeAnnotation(), this.get("alternate").getTypeAnnotation()];
      return (0, _util.createUnionType)(argumentTypes);
    }
    function SequenceExpression() {
      return this.get("expressions").pop().getTypeAnnotation();
    }
    function ParenthesizedExpression() {
      return this.get("expression").getTypeAnnotation();
    }
    function AssignmentExpression() {
      return this.get("right").getTypeAnnotation();
    }
    function UpdateExpression(node) {
      const operator = node.operator;
      if (operator === "++" || operator === "--") {
        return numberTypeAnnotation();
      }
    }
    function StringLiteral() {
      return stringTypeAnnotation();
    }
    function NumericLiteral() {
      return numberTypeAnnotation();
    }
    function BooleanLiteral() {
      return booleanTypeAnnotation();
    }
    function NullLiteral() {
      return nullLiteralTypeAnnotation();
    }
    function RegExpLiteral() {
      return genericTypeAnnotation(identifier3("RegExp"));
    }
    function ObjectExpression() {
      return genericTypeAnnotation(identifier3("Object"));
    }
    function ArrayExpression() {
      return genericTypeAnnotation(identifier3("Array"));
    }
    function RestElement() {
      return ArrayExpression();
    }
    RestElement.validParent = true;
    function Func() {
      return genericTypeAnnotation(identifier3("Function"));
    }
    var isArrayFrom = buildMatchMemberExpression("Array.from");
    var isObjectKeys = buildMatchMemberExpression("Object.keys");
    var isObjectValues = buildMatchMemberExpression("Object.values");
    var isObjectEntries = buildMatchMemberExpression("Object.entries");
    function CallExpression() {
      const {
        callee
      } = this.node;
      if (isObjectKeys(callee)) {
        return arrayTypeAnnotation(stringTypeAnnotation());
      } else if (isArrayFrom(callee) || isObjectValues(callee) || isIdentifier2(callee, {
        name: "Array"
      })) {
        return arrayTypeAnnotation(anyTypeAnnotation());
      } else if (isObjectEntries(callee)) {
        return arrayTypeAnnotation(tupleTypeAnnotation([stringTypeAnnotation(), anyTypeAnnotation()]));
      }
      return resolveCall(this.get("callee"));
    }
    function TaggedTemplateExpression() {
      return resolveCall(this.get("tag"));
    }
    function resolveCall(callee) {
      callee = callee.resolve();
      if (callee.isFunction()) {
        const {
          node
        } = callee;
        if (node.async) {
          if (node.generator) {
            return genericTypeAnnotation(identifier3("AsyncIterator"));
          } else {
            return genericTypeAnnotation(identifier3("Promise"));
          }
        } else {
          if (node.generator) {
            return genericTypeAnnotation(identifier3("Iterator"));
          } else if (callee.node.returnType) {
            return callee.node.returnType;
          } else {
          }
        }
      }
    }
  }
});

// node_modules/@babel/traverse/lib/path/inference/index.js
var require_inference = __commonJS({
  "node_modules/@babel/traverse/lib/path/inference/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._getTypeAnnotation = _getTypeAnnotation;
    exports.baseTypeStrictlyMatches = baseTypeStrictlyMatches;
    exports.couldBeBaseType = couldBeBaseType;
    exports.getTypeAnnotation = getTypeAnnotation;
    exports.isBaseType = isBaseType;
    exports.isGenericType = isGenericType;
    var inferers = require_inferers();
    var _t = require_lib11();
    var {
      anyTypeAnnotation,
      isAnyTypeAnnotation,
      isArrayTypeAnnotation,
      isBooleanTypeAnnotation,
      isEmptyTypeAnnotation,
      isFlowBaseAnnotation,
      isGenericTypeAnnotation,
      isIdentifier: isIdentifier2,
      isMixedTypeAnnotation,
      isNumberTypeAnnotation,
      isStringTypeAnnotation,
      isTSArrayType,
      isTSTypeAnnotation,
      isTSTypeReference,
      isTupleTypeAnnotation,
      isTypeAnnotation,
      isUnionTypeAnnotation,
      isVoidTypeAnnotation,
      stringTypeAnnotation,
      voidTypeAnnotation
    } = _t;
    function getTypeAnnotation() {
      let type = this.getData("typeAnnotation");
      if (type != null) {
        return type;
      }
      type = this._getTypeAnnotation() || anyTypeAnnotation();
      if (isTypeAnnotation(type) || isTSTypeAnnotation(type)) {
        type = type.typeAnnotation;
      }
      this.setData("typeAnnotation", type);
      return type;
    }
    var typeAnnotationInferringNodes = /* @__PURE__ */ new WeakSet();
    function _getTypeAnnotation() {
      const node = this.node;
      if (!node) {
        if (this.key === "init" && this.parentPath.isVariableDeclarator()) {
          const declar = this.parentPath.parentPath;
          const declarParent = declar.parentPath;
          if (declar.key === "left" && declarParent.isForInStatement()) {
            return stringTypeAnnotation();
          }
          if (declar.key === "left" && declarParent.isForOfStatement()) {
            return anyTypeAnnotation();
          }
          return voidTypeAnnotation();
        } else {
          return;
        }
      }
      if (node.typeAnnotation) {
        return node.typeAnnotation;
      }
      if (typeAnnotationInferringNodes.has(node)) {
        return;
      }
      typeAnnotationInferringNodes.add(node);
      try {
        var _inferer;
        let inferer = inferers[node.type];
        if (inferer) {
          return inferer.call(this, node);
        }
        inferer = inferers[this.parentPath.type];
        if ((_inferer = inferer) != null && _inferer.validParent) {
          return this.parentPath.getTypeAnnotation();
        }
      } finally {
        typeAnnotationInferringNodes.delete(node);
      }
    }
    function isBaseType(baseName, soft) {
      return _isBaseType(baseName, this.getTypeAnnotation(), soft);
    }
    function _isBaseType(baseName, type, soft) {
      if (baseName === "string") {
        return isStringTypeAnnotation(type);
      } else if (baseName === "number") {
        return isNumberTypeAnnotation(type);
      } else if (baseName === "boolean") {
        return isBooleanTypeAnnotation(type);
      } else if (baseName === "any") {
        return isAnyTypeAnnotation(type);
      } else if (baseName === "mixed") {
        return isMixedTypeAnnotation(type);
      } else if (baseName === "empty") {
        return isEmptyTypeAnnotation(type);
      } else if (baseName === "void") {
        return isVoidTypeAnnotation(type);
      } else {
        if (soft) {
          return false;
        } else {
          throw new Error(`Unknown base type ${baseName}`);
        }
      }
    }
    function couldBeBaseType(name) {
      const type = this.getTypeAnnotation();
      if (isAnyTypeAnnotation(type))
        return true;
      if (isUnionTypeAnnotation(type)) {
        for (const type2 of type.types) {
          if (isAnyTypeAnnotation(type2) || _isBaseType(name, type2, true)) {
            return true;
          }
        }
        return false;
      } else {
        return _isBaseType(name, type, true);
      }
    }
    function baseTypeStrictlyMatches(rightArg) {
      const left = this.getTypeAnnotation();
      const right = rightArg.getTypeAnnotation();
      if (!isAnyTypeAnnotation(left) && isFlowBaseAnnotation(left)) {
        return right.type === left.type;
      }
      return false;
    }
    function isGenericType(genericName) {
      const type = this.getTypeAnnotation();
      if (genericName === "Array") {
        if (isTSArrayType(type) || isArrayTypeAnnotation(type) || isTupleTypeAnnotation(type)) {
          return true;
        }
      }
      return isGenericTypeAnnotation(type) && isIdentifier2(type.id, {
        name: genericName
      }) || isTSTypeReference(type) && isIdentifier2(type.typeName, {
        name: genericName
      });
    }
  }
});

// node_modules/js-tokens/index.js
var require_js_tokens = __commonJS({
  "node_modules/js-tokens/index.js"(exports) {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = /((['"])(?:(?!\2|\\).|\\(?:\r\n|[\s\S]))*(\2)?|`(?:[^`\\$]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{[^}]*\}?)*\}?)*(`)?)|(\/\/.*)|(\/\*(?:[^*]|\*(?!\/))*(\*\/)?)|(\/(?!\*)(?:\[(?:(?![\]\\]).|\\.)*\]|(?![\/\]\\]).|\\.)+\/(?:(?!\s*(?:\b|[\u0080-\uFFFF$\\'"~({]|[+\-!](?!=)|\.?\d))|[gmiyus]{1,6}\b(?![\u0080-\uFFFF$\\]|\s*(?:[+\-*%&|^<>!=?({]|\/(?![\/*])))))|(0[xX][\da-fA-F]+|0[oO][0-7]+|0[bB][01]+|(?:\d*\.\d+|\d+\.?)(?:[eE][+-]?\d+)?)|((?!\d)(?:(?!\s)[$\w\u0080-\uFFFF]|\\u[\da-fA-F]{4}|\\u\{[\da-fA-F]+\})+)|(--|\+\+|&&|\|\||=>|\.{3}|(?:[+\-\/%&|^]|\*{1,2}|<{1,2}|>{1,3}|!=?|={1,2})=?|[?~.,:;[\](){}])|(\s+)|(^$|[\s\S])/g;
    exports.matchToToken = function(match) {
      var token = { type: "invalid", value: match[0], closed: void 0 };
      if (match[1])
        token.type = "string", token.closed = !!(match[3] || match[4]);
      else if (match[5])
        token.type = "comment";
      else if (match[6])
        token.type = "comment", token.closed = !!match[7];
      else if (match[8])
        token.type = "regex";
      else if (match[9])
        token.type = "number";
      else if (match[10])
        token.type = "name";
      else if (match[11])
        token.type = "punctuator";
      else if (match[12])
        token.type = "whitespace";
      return token;
    };
  }
});

// node_modules/@babel/highlight/node_modules/color-name/index.js
var require_color_name2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/color-name/index.js"(exports, module2) {
    "use strict";
    module2.exports = {
      "aliceblue": [240, 248, 255],
      "antiquewhite": [250, 235, 215],
      "aqua": [0, 255, 255],
      "aquamarine": [127, 255, 212],
      "azure": [240, 255, 255],
      "beige": [245, 245, 220],
      "bisque": [255, 228, 196],
      "black": [0, 0, 0],
      "blanchedalmond": [255, 235, 205],
      "blue": [0, 0, 255],
      "blueviolet": [138, 43, 226],
      "brown": [165, 42, 42],
      "burlywood": [222, 184, 135],
      "cadetblue": [95, 158, 160],
      "chartreuse": [127, 255, 0],
      "chocolate": [210, 105, 30],
      "coral": [255, 127, 80],
      "cornflowerblue": [100, 149, 237],
      "cornsilk": [255, 248, 220],
      "crimson": [220, 20, 60],
      "cyan": [0, 255, 255],
      "darkblue": [0, 0, 139],
      "darkcyan": [0, 139, 139],
      "darkgoldenrod": [184, 134, 11],
      "darkgray": [169, 169, 169],
      "darkgreen": [0, 100, 0],
      "darkgrey": [169, 169, 169],
      "darkkhaki": [189, 183, 107],
      "darkmagenta": [139, 0, 139],
      "darkolivegreen": [85, 107, 47],
      "darkorange": [255, 140, 0],
      "darkorchid": [153, 50, 204],
      "darkred": [139, 0, 0],
      "darksalmon": [233, 150, 122],
      "darkseagreen": [143, 188, 143],
      "darkslateblue": [72, 61, 139],
      "darkslategray": [47, 79, 79],
      "darkslategrey": [47, 79, 79],
      "darkturquoise": [0, 206, 209],
      "darkviolet": [148, 0, 211],
      "deeppink": [255, 20, 147],
      "deepskyblue": [0, 191, 255],
      "dimgray": [105, 105, 105],
      "dimgrey": [105, 105, 105],
      "dodgerblue": [30, 144, 255],
      "firebrick": [178, 34, 34],
      "floralwhite": [255, 250, 240],
      "forestgreen": [34, 139, 34],
      "fuchsia": [255, 0, 255],
      "gainsboro": [220, 220, 220],
      "ghostwhite": [248, 248, 255],
      "gold": [255, 215, 0],
      "goldenrod": [218, 165, 32],
      "gray": [128, 128, 128],
      "green": [0, 128, 0],
      "greenyellow": [173, 255, 47],
      "grey": [128, 128, 128],
      "honeydew": [240, 255, 240],
      "hotpink": [255, 105, 180],
      "indianred": [205, 92, 92],
      "indigo": [75, 0, 130],
      "ivory": [255, 255, 240],
      "khaki": [240, 230, 140],
      "lavender": [230, 230, 250],
      "lavenderblush": [255, 240, 245],
      "lawngreen": [124, 252, 0],
      "lemonchiffon": [255, 250, 205],
      "lightblue": [173, 216, 230],
      "lightcoral": [240, 128, 128],
      "lightcyan": [224, 255, 255],
      "lightgoldenrodyellow": [250, 250, 210],
      "lightgray": [211, 211, 211],
      "lightgreen": [144, 238, 144],
      "lightgrey": [211, 211, 211],
      "lightpink": [255, 182, 193],
      "lightsalmon": [255, 160, 122],
      "lightseagreen": [32, 178, 170],
      "lightskyblue": [135, 206, 250],
      "lightslategray": [119, 136, 153],
      "lightslategrey": [119, 136, 153],
      "lightsteelblue": [176, 196, 222],
      "lightyellow": [255, 255, 224],
      "lime": [0, 255, 0],
      "limegreen": [50, 205, 50],
      "linen": [250, 240, 230],
      "magenta": [255, 0, 255],
      "maroon": [128, 0, 0],
      "mediumaquamarine": [102, 205, 170],
      "mediumblue": [0, 0, 205],
      "mediumorchid": [186, 85, 211],
      "mediumpurple": [147, 112, 219],
      "mediumseagreen": [60, 179, 113],
      "mediumslateblue": [123, 104, 238],
      "mediumspringgreen": [0, 250, 154],
      "mediumturquoise": [72, 209, 204],
      "mediumvioletred": [199, 21, 133],
      "midnightblue": [25, 25, 112],
      "mintcream": [245, 255, 250],
      "mistyrose": [255, 228, 225],
      "moccasin": [255, 228, 181],
      "navajowhite": [255, 222, 173],
      "navy": [0, 0, 128],
      "oldlace": [253, 245, 230],
      "olive": [128, 128, 0],
      "olivedrab": [107, 142, 35],
      "orange": [255, 165, 0],
      "orangered": [255, 69, 0],
      "orchid": [218, 112, 214],
      "palegoldenrod": [238, 232, 170],
      "palegreen": [152, 251, 152],
      "paleturquoise": [175, 238, 238],
      "palevioletred": [219, 112, 147],
      "papayawhip": [255, 239, 213],
      "peachpuff": [255, 218, 185],
      "peru": [205, 133, 63],
      "pink": [255, 192, 203],
      "plum": [221, 160, 221],
      "powderblue": [176, 224, 230],
      "purple": [128, 0, 128],
      "rebeccapurple": [102, 51, 153],
      "red": [255, 0, 0],
      "rosybrown": [188, 143, 143],
      "royalblue": [65, 105, 225],
      "saddlebrown": [139, 69, 19],
      "salmon": [250, 128, 114],
      "sandybrown": [244, 164, 96],
      "seagreen": [46, 139, 87],
      "seashell": [255, 245, 238],
      "sienna": [160, 82, 45],
      "silver": [192, 192, 192],
      "skyblue": [135, 206, 235],
      "slateblue": [106, 90, 205],
      "slategray": [112, 128, 144],
      "slategrey": [112, 128, 144],
      "snow": [255, 250, 250],
      "springgreen": [0, 255, 127],
      "steelblue": [70, 130, 180],
      "tan": [210, 180, 140],
      "teal": [0, 128, 128],
      "thistle": [216, 191, 216],
      "tomato": [255, 99, 71],
      "turquoise": [64, 224, 208],
      "violet": [238, 130, 238],
      "wheat": [245, 222, 179],
      "white": [255, 255, 255],
      "whitesmoke": [245, 245, 245],
      "yellow": [255, 255, 0],
      "yellowgreen": [154, 205, 50]
    };
  }
});

// node_modules/@babel/highlight/node_modules/color-convert/conversions.js
var require_conversions2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/color-convert/conversions.js"(exports, module2) {
    var cssKeywords = require_color_name2();
    var reverseKeywords = {};
    for (key in cssKeywords) {
      if (cssKeywords.hasOwnProperty(key)) {
        reverseKeywords[cssKeywords[key]] = key;
      }
    }
    var key;
    var convert = module2.exports = {
      rgb: { channels: 3, labels: "rgb" },
      hsl: { channels: 3, labels: "hsl" },
      hsv: { channels: 3, labels: "hsv" },
      hwb: { channels: 3, labels: "hwb" },
      cmyk: { channels: 4, labels: "cmyk" },
      xyz: { channels: 3, labels: "xyz" },
      lab: { channels: 3, labels: "lab" },
      lch: { channels: 3, labels: "lch" },
      hex: { channels: 1, labels: ["hex"] },
      keyword: { channels: 1, labels: ["keyword"] },
      ansi16: { channels: 1, labels: ["ansi16"] },
      ansi256: { channels: 1, labels: ["ansi256"] },
      hcg: { channels: 3, labels: ["h", "c", "g"] },
      apple: { channels: 3, labels: ["r16", "g16", "b16"] },
      gray: { channels: 1, labels: ["gray"] }
    };
    for (model in convert) {
      if (convert.hasOwnProperty(model)) {
        if (!("channels" in convert[model])) {
          throw new Error("missing channels property: " + model);
        }
        if (!("labels" in convert[model])) {
          throw new Error("missing channel labels property: " + model);
        }
        if (convert[model].labels.length !== convert[model].channels) {
          throw new Error("channel and label counts mismatch: " + model);
        }
        channels = convert[model].channels;
        labels = convert[model].labels;
        delete convert[model].channels;
        delete convert[model].labels;
        Object.defineProperty(convert[model], "channels", { value: channels });
        Object.defineProperty(convert[model], "labels", { value: labels });
      }
    }
    var channels;
    var labels;
    var model;
    convert.rgb.hsl = function(rgb) {
      var r = rgb[0] / 255;
      var g = rgb[1] / 255;
      var b = rgb[2] / 255;
      var min2 = Math.min(r, g, b);
      var max2 = Math.max(r, g, b);
      var delta = max2 - min2;
      var h;
      var s;
      var l;
      if (max2 === min2) {
        h = 0;
      } else if (r === max2) {
        h = (g - b) / delta;
      } else if (g === max2) {
        h = 2 + (b - r) / delta;
      } else if (b === max2) {
        h = 4 + (r - g) / delta;
      }
      h = Math.min(h * 60, 360);
      if (h < 0) {
        h += 360;
      }
      l = (min2 + max2) / 2;
      if (max2 === min2) {
        s = 0;
      } else if (l <= 0.5) {
        s = delta / (max2 + min2);
      } else {
        s = delta / (2 - max2 - min2);
      }
      return [h, s * 100, l * 100];
    };
    convert.rgb.hsv = function(rgb) {
      var rdif;
      var gdif;
      var bdif;
      var h;
      var s;
      var r = rgb[0] / 255;
      var g = rgb[1] / 255;
      var b = rgb[2] / 255;
      var v = Math.max(r, g, b);
      var diff = v - Math.min(r, g, b);
      var diffc = function(c) {
        return (v - c) / 6 / diff + 1 / 2;
      };
      if (diff === 0) {
        h = s = 0;
      } else {
        s = diff / v;
        rdif = diffc(r);
        gdif = diffc(g);
        bdif = diffc(b);
        if (r === v) {
          h = bdif - gdif;
        } else if (g === v) {
          h = 1 / 3 + rdif - bdif;
        } else if (b === v) {
          h = 2 / 3 + gdif - rdif;
        }
        if (h < 0) {
          h += 1;
        } else if (h > 1) {
          h -= 1;
        }
      }
      return [
        h * 360,
        s * 100,
        v * 100
      ];
    };
    convert.rgb.hwb = function(rgb) {
      var r = rgb[0];
      var g = rgb[1];
      var b = rgb[2];
      var h = convert.rgb.hsl(rgb)[0];
      var w = 1 / 255 * Math.min(r, Math.min(g, b));
      b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
      return [h, w * 100, b * 100];
    };
    convert.rgb.cmyk = function(rgb) {
      var r = rgb[0] / 255;
      var g = rgb[1] / 255;
      var b = rgb[2] / 255;
      var c;
      var m;
      var y;
      var k;
      k = Math.min(1 - r, 1 - g, 1 - b);
      c = (1 - r - k) / (1 - k) || 0;
      m = (1 - g - k) / (1 - k) || 0;
      y = (1 - b - k) / (1 - k) || 0;
      return [c * 100, m * 100, y * 100, k * 100];
    };
    function comparativeDistance(x, y) {
      return Math.pow(x[0] - y[0], 2) + Math.pow(x[1] - y[1], 2) + Math.pow(x[2] - y[2], 2);
    }
    convert.rgb.keyword = function(rgb) {
      var reversed = reverseKeywords[rgb];
      if (reversed) {
        return reversed;
      }
      var currentClosestDistance = Infinity;
      var currentClosestKeyword;
      for (var keyword in cssKeywords) {
        if (cssKeywords.hasOwnProperty(keyword)) {
          var value2 = cssKeywords[keyword];
          var distance = comparativeDistance(rgb, value2);
          if (distance < currentClosestDistance) {
            currentClosestDistance = distance;
            currentClosestKeyword = keyword;
          }
        }
      }
      return currentClosestKeyword;
    };
    convert.keyword.rgb = function(keyword) {
      return cssKeywords[keyword];
    };
    convert.rgb.xyz = function(rgb) {
      var r = rgb[0] / 255;
      var g = rgb[1] / 255;
      var b = rgb[2] / 255;
      r = r > 0.04045 ? Math.pow((r + 0.055) / 1.055, 2.4) : r / 12.92;
      g = g > 0.04045 ? Math.pow((g + 0.055) / 1.055, 2.4) : g / 12.92;
      b = b > 0.04045 ? Math.pow((b + 0.055) / 1.055, 2.4) : b / 12.92;
      var x = r * 0.4124 + g * 0.3576 + b * 0.1805;
      var y = r * 0.2126 + g * 0.7152 + b * 0.0722;
      var z = r * 0.0193 + g * 0.1192 + b * 0.9505;
      return [x * 100, y * 100, z * 100];
    };
    convert.rgb.lab = function(rgb) {
      var xyz = convert.rgb.xyz(rgb);
      var x = xyz[0];
      var y = xyz[1];
      var z = xyz[2];
      var l;
      var a;
      var b;
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
      l = 116 * y - 16;
      a = 500 * (x - y);
      b = 200 * (y - z);
      return [l, a, b];
    };
    convert.hsl.rgb = function(hsl) {
      var h = hsl[0] / 360;
      var s = hsl[1] / 100;
      var l = hsl[2] / 100;
      var t1;
      var t22;
      var t3;
      var rgb;
      var val;
      if (s === 0) {
        val = l * 255;
        return [val, val, val];
      }
      if (l < 0.5) {
        t22 = l * (1 + s);
      } else {
        t22 = l + s - l * s;
      }
      t1 = 2 * l - t22;
      rgb = [0, 0, 0];
      for (var i = 0; i < 3; i++) {
        t3 = h + 1 / 3 * -(i - 1);
        if (t3 < 0) {
          t3++;
        }
        if (t3 > 1) {
          t3--;
        }
        if (6 * t3 < 1) {
          val = t1 + (t22 - t1) * 6 * t3;
        } else if (2 * t3 < 1) {
          val = t22;
        } else if (3 * t3 < 2) {
          val = t1 + (t22 - t1) * (2 / 3 - t3) * 6;
        } else {
          val = t1;
        }
        rgb[i] = val * 255;
      }
      return rgb;
    };
    convert.hsl.hsv = function(hsl) {
      var h = hsl[0];
      var s = hsl[1] / 100;
      var l = hsl[2] / 100;
      var smin = s;
      var lmin = Math.max(l, 0.01);
      var sv;
      var v;
      l *= 2;
      s *= l <= 1 ? l : 2 - l;
      smin *= lmin <= 1 ? lmin : 2 - lmin;
      v = (l + s) / 2;
      sv = l === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l + s);
      return [h, sv * 100, v * 100];
    };
    convert.hsv.rgb = function(hsv) {
      var h = hsv[0] / 60;
      var s = hsv[1] / 100;
      var v = hsv[2] / 100;
      var hi = Math.floor(h) % 6;
      var f = h - Math.floor(h);
      var p = 255 * v * (1 - s);
      var q = 255 * v * (1 - s * f);
      var t3 = 255 * v * (1 - s * (1 - f));
      v *= 255;
      switch (hi) {
        case 0:
          return [v, t3, p];
        case 1:
          return [q, v, p];
        case 2:
          return [p, v, t3];
        case 3:
          return [p, q, v];
        case 4:
          return [t3, p, v];
        case 5:
          return [v, p, q];
      }
    };
    convert.hsv.hsl = function(hsv) {
      var h = hsv[0];
      var s = hsv[1] / 100;
      var v = hsv[2] / 100;
      var vmin = Math.max(v, 0.01);
      var lmin;
      var sl;
      var l;
      l = (2 - s) * v;
      lmin = (2 - s) * vmin;
      sl = s * vmin;
      sl /= lmin <= 1 ? lmin : 2 - lmin;
      sl = sl || 0;
      l /= 2;
      return [h, sl * 100, l * 100];
    };
    convert.hwb.rgb = function(hwb) {
      var h = hwb[0] / 360;
      var wh = hwb[1] / 100;
      var bl = hwb[2] / 100;
      var ratio = wh + bl;
      var i;
      var v;
      var f;
      var n;
      if (ratio > 1) {
        wh /= ratio;
        bl /= ratio;
      }
      i = Math.floor(6 * h);
      v = 1 - bl;
      f = 6 * h - i;
      if ((i & 1) !== 0) {
        f = 1 - f;
      }
      n = wh + f * (v - wh);
      var r;
      var g;
      var b;
      switch (i) {
        default:
        case 6:
        case 0:
          r = v;
          g = n;
          b = wh;
          break;
        case 1:
          r = n;
          g = v;
          b = wh;
          break;
        case 2:
          r = wh;
          g = v;
          b = n;
          break;
        case 3:
          r = wh;
          g = n;
          b = v;
          break;
        case 4:
          r = n;
          g = wh;
          b = v;
          break;
        case 5:
          r = v;
          g = wh;
          b = n;
          break;
      }
      return [r * 255, g * 255, b * 255];
    };
    convert.cmyk.rgb = function(cmyk) {
      var c = cmyk[0] / 100;
      var m = cmyk[1] / 100;
      var y = cmyk[2] / 100;
      var k = cmyk[3] / 100;
      var r;
      var g;
      var b;
      r = 1 - Math.min(1, c * (1 - k) + k);
      g = 1 - Math.min(1, m * (1 - k) + k);
      b = 1 - Math.min(1, y * (1 - k) + k);
      return [r * 255, g * 255, b * 255];
    };
    convert.xyz.rgb = function(xyz) {
      var x = xyz[0] / 100;
      var y = xyz[1] / 100;
      var z = xyz[2] / 100;
      var r;
      var g;
      var b;
      r = x * 3.2406 + y * -1.5372 + z * -0.4986;
      g = x * -0.9689 + y * 1.8758 + z * 0.0415;
      b = x * 0.0557 + y * -0.204 + z * 1.057;
      r = r > 31308e-7 ? 1.055 * Math.pow(r, 1 / 2.4) - 0.055 : r * 12.92;
      g = g > 31308e-7 ? 1.055 * Math.pow(g, 1 / 2.4) - 0.055 : g * 12.92;
      b = b > 31308e-7 ? 1.055 * Math.pow(b, 1 / 2.4) - 0.055 : b * 12.92;
      r = Math.min(Math.max(0, r), 1);
      g = Math.min(Math.max(0, g), 1);
      b = Math.min(Math.max(0, b), 1);
      return [r * 255, g * 255, b * 255];
    };
    convert.xyz.lab = function(xyz) {
      var x = xyz[0];
      var y = xyz[1];
      var z = xyz[2];
      var l;
      var a;
      var b;
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
      l = 116 * y - 16;
      a = 500 * (x - y);
      b = 200 * (y - z);
      return [l, a, b];
    };
    convert.lab.xyz = function(lab) {
      var l = lab[0];
      var a = lab[1];
      var b = lab[2];
      var x;
      var y;
      var z;
      y = (l + 16) / 116;
      x = a / 500 + y;
      z = y - b / 200;
      var y2 = Math.pow(y, 3);
      var x2 = Math.pow(x, 3);
      var z2 = Math.pow(z, 3);
      y = y2 > 8856e-6 ? y2 : (y - 16 / 116) / 7.787;
      x = x2 > 8856e-6 ? x2 : (x - 16 / 116) / 7.787;
      z = z2 > 8856e-6 ? z2 : (z - 16 / 116) / 7.787;
      x *= 95.047;
      y *= 100;
      z *= 108.883;
      return [x, y, z];
    };
    convert.lab.lch = function(lab) {
      var l = lab[0];
      var a = lab[1];
      var b = lab[2];
      var hr;
      var h;
      var c;
      hr = Math.atan2(b, a);
      h = hr * 360 / 2 / Math.PI;
      if (h < 0) {
        h += 360;
      }
      c = Math.sqrt(a * a + b * b);
      return [l, c, h];
    };
    convert.lch.lab = function(lch) {
      var l = lch[0];
      var c = lch[1];
      var h = lch[2];
      var a;
      var b;
      var hr;
      hr = h / 360 * 2 * Math.PI;
      a = c * Math.cos(hr);
      b = c * Math.sin(hr);
      return [l, a, b];
    };
    convert.rgb.ansi16 = function(args) {
      var r = args[0];
      var g = args[1];
      var b = args[2];
      var value2 = 1 in arguments ? arguments[1] : convert.rgb.hsv(args)[2];
      value2 = Math.round(value2 / 50);
      if (value2 === 0) {
        return 30;
      }
      var ansi = 30 + (Math.round(b / 255) << 2 | Math.round(g / 255) << 1 | Math.round(r / 255));
      if (value2 === 2) {
        ansi += 60;
      }
      return ansi;
    };
    convert.hsv.ansi16 = function(args) {
      return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
    };
    convert.rgb.ansi256 = function(args) {
      var r = args[0];
      var g = args[1];
      var b = args[2];
      if (r === g && g === b) {
        if (r < 8) {
          return 16;
        }
        if (r > 248) {
          return 231;
        }
        return Math.round((r - 8) / 247 * 24) + 232;
      }
      var ansi = 16 + 36 * Math.round(r / 255 * 5) + 6 * Math.round(g / 255 * 5) + Math.round(b / 255 * 5);
      return ansi;
    };
    convert.ansi16.rgb = function(args) {
      var color = args % 10;
      if (color === 0 || color === 7) {
        if (args > 50) {
          color += 3.5;
        }
        color = color / 10.5 * 255;
        return [color, color, color];
      }
      var mult = (~~(args > 50) + 1) * 0.5;
      var r = (color & 1) * mult * 255;
      var g = (color >> 1 & 1) * mult * 255;
      var b = (color >> 2 & 1) * mult * 255;
      return [r, g, b];
    };
    convert.ansi256.rgb = function(args) {
      if (args >= 232) {
        var c = (args - 232) * 10 + 8;
        return [c, c, c];
      }
      args -= 16;
      var rem;
      var r = Math.floor(args / 36) / 5 * 255;
      var g = Math.floor((rem = args % 36) / 6) / 5 * 255;
      var b = rem % 6 / 5 * 255;
      return [r, g, b];
    };
    convert.rgb.hex = function(args) {
      var integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
      var string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.hex.rgb = function(args) {
      var match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
      if (!match) {
        return [0, 0, 0];
      }
      var colorString = match[0];
      if (match[0].length === 3) {
        colorString = colorString.split("").map(function(char) {
          return char + char;
        }).join("");
      }
      var integer = parseInt(colorString, 16);
      var r = integer >> 16 & 255;
      var g = integer >> 8 & 255;
      var b = integer & 255;
      return [r, g, b];
    };
    convert.rgb.hcg = function(rgb) {
      var r = rgb[0] / 255;
      var g = rgb[1] / 255;
      var b = rgb[2] / 255;
      var max2 = Math.max(Math.max(r, g), b);
      var min2 = Math.min(Math.min(r, g), b);
      var chroma = max2 - min2;
      var grayscale;
      var hue;
      if (chroma < 1) {
        grayscale = min2 / (1 - chroma);
      } else {
        grayscale = 0;
      }
      if (chroma <= 0) {
        hue = 0;
      } else if (max2 === r) {
        hue = (g - b) / chroma % 6;
      } else if (max2 === g) {
        hue = 2 + (b - r) / chroma;
      } else {
        hue = 4 + (r - g) / chroma + 4;
      }
      hue /= 6;
      hue %= 1;
      return [hue * 360, chroma * 100, grayscale * 100];
    };
    convert.hsl.hcg = function(hsl) {
      var s = hsl[1] / 100;
      var l = hsl[2] / 100;
      var c = 1;
      var f = 0;
      if (l < 0.5) {
        c = 2 * s * l;
      } else {
        c = 2 * s * (1 - l);
      }
      if (c < 1) {
        f = (l - 0.5 * c) / (1 - c);
      }
      return [hsl[0], c * 100, f * 100];
    };
    convert.hsv.hcg = function(hsv) {
      var s = hsv[1] / 100;
      var v = hsv[2] / 100;
      var c = s * v;
      var f = 0;
      if (c < 1) {
        f = (v - c) / (1 - c);
      }
      return [hsv[0], c * 100, f * 100];
    };
    convert.hcg.rgb = function(hcg) {
      var h = hcg[0] / 360;
      var c = hcg[1] / 100;
      var g = hcg[2] / 100;
      if (c === 0) {
        return [g * 255, g * 255, g * 255];
      }
      var pure = [0, 0, 0];
      var hi = h % 1 * 6;
      var v = hi % 1;
      var w = 1 - v;
      var mg = 0;
      switch (Math.floor(hi)) {
        case 0:
          pure[0] = 1;
          pure[1] = v;
          pure[2] = 0;
          break;
        case 1:
          pure[0] = w;
          pure[1] = 1;
          pure[2] = 0;
          break;
        case 2:
          pure[0] = 0;
          pure[1] = 1;
          pure[2] = v;
          break;
        case 3:
          pure[0] = 0;
          pure[1] = w;
          pure[2] = 1;
          break;
        case 4:
          pure[0] = v;
          pure[1] = 0;
          pure[2] = 1;
          break;
        default:
          pure[0] = 1;
          pure[1] = 0;
          pure[2] = w;
      }
      mg = (1 - c) * g;
      return [
        (c * pure[0] + mg) * 255,
        (c * pure[1] + mg) * 255,
        (c * pure[2] + mg) * 255
      ];
    };
    convert.hcg.hsv = function(hcg) {
      var c = hcg[1] / 100;
      var g = hcg[2] / 100;
      var v = c + g * (1 - c);
      var f = 0;
      if (v > 0) {
        f = c / v;
      }
      return [hcg[0], f * 100, v * 100];
    };
    convert.hcg.hsl = function(hcg) {
      var c = hcg[1] / 100;
      var g = hcg[2] / 100;
      var l = g * (1 - c) + 0.5 * c;
      var s = 0;
      if (l > 0 && l < 0.5) {
        s = c / (2 * l);
      } else if (l >= 0.5 && l < 1) {
        s = c / (2 * (1 - l));
      }
      return [hcg[0], s * 100, l * 100];
    };
    convert.hcg.hwb = function(hcg) {
      var c = hcg[1] / 100;
      var g = hcg[2] / 100;
      var v = c + g * (1 - c);
      return [hcg[0], (v - c) * 100, (1 - v) * 100];
    };
    convert.hwb.hcg = function(hwb) {
      var w = hwb[1] / 100;
      var b = hwb[2] / 100;
      var v = 1 - b;
      var c = v - w;
      var g = 0;
      if (c < 1) {
        g = (v - c) / (1 - c);
      }
      return [hwb[0], c * 100, g * 100];
    };
    convert.apple.rgb = function(apple) {
      return [apple[0] / 65535 * 255, apple[1] / 65535 * 255, apple[2] / 65535 * 255];
    };
    convert.rgb.apple = function(rgb) {
      return [rgb[0] / 255 * 65535, rgb[1] / 255 * 65535, rgb[2] / 255 * 65535];
    };
    convert.gray.rgb = function(args) {
      return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
    };
    convert.gray.hsl = convert.gray.hsv = function(args) {
      return [0, 0, args[0]];
    };
    convert.gray.hwb = function(gray) {
      return [0, 100, gray[0]];
    };
    convert.gray.cmyk = function(gray) {
      return [0, 0, 0, gray[0]];
    };
    convert.gray.lab = function(gray) {
      return [gray[0], 0, 0];
    };
    convert.gray.hex = function(gray) {
      var val = Math.round(gray[0] / 100 * 255) & 255;
      var integer = (val << 16) + (val << 8) + val;
      var string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.rgb.gray = function(rgb) {
      var val = (rgb[0] + rgb[1] + rgb[2]) / 3;
      return [val / 255 * 100];
    };
  }
});

// node_modules/@babel/highlight/node_modules/color-convert/route.js
var require_route2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/color-convert/route.js"(exports, module2) {
    var conversions = require_conversions2();
    function buildGraph() {
      var graph = {};
      var models = Object.keys(conversions);
      for (var len = models.length, i = 0; i < len; i++) {
        graph[models[i]] = {
          // http://jsperf.com/1-vs-infinity
          // micro-opt, but this is simple.
          distance: -1,
          parent: null
        };
      }
      return graph;
    }
    function deriveBFS(fromModel) {
      var graph = buildGraph();
      var queue = [fromModel];
      graph[fromModel].distance = 0;
      while (queue.length) {
        var current = queue.pop();
        var adjacents = Object.keys(conversions[current]);
        for (var len = adjacents.length, i = 0; i < len; i++) {
          var adjacent = adjacents[i];
          var node = graph[adjacent];
          if (node.distance === -1) {
            node.distance = graph[current].distance + 1;
            node.parent = current;
            queue.unshift(adjacent);
          }
        }
      }
      return graph;
    }
    function link(from, to) {
      return function(args) {
        return to(from(args));
      };
    }
    function wrapConversion(toModel, graph) {
      var path2 = [graph[toModel].parent, toModel];
      var fn = conversions[graph[toModel].parent][toModel];
      var cur = graph[toModel].parent;
      while (graph[cur].parent) {
        path2.unshift(graph[cur].parent);
        fn = link(conversions[graph[cur].parent][cur], fn);
        cur = graph[cur].parent;
      }
      fn.conversion = path2;
      return fn;
    }
    module2.exports = function(fromModel) {
      var graph = deriveBFS(fromModel);
      var conversion = {};
      var models = Object.keys(graph);
      for (var len = models.length, i = 0; i < len; i++) {
        var toModel = models[i];
        var node = graph[toModel];
        if (node.parent === null) {
          continue;
        }
        conversion[toModel] = wrapConversion(toModel, graph);
      }
      return conversion;
    };
  }
});

// node_modules/@babel/highlight/node_modules/color-convert/index.js
var require_color_convert2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/color-convert/index.js"(exports, module2) {
    var conversions = require_conversions2();
    var route = require_route2();
    var convert = {};
    var models = Object.keys(conversions);
    function wrapRaw(fn) {
      var wrappedFn = function(args) {
        if (args === void 0 || args === null) {
          return args;
        }
        if (arguments.length > 1) {
          args = Array.prototype.slice.call(arguments);
        }
        return fn(args);
      };
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    function wrapRounded(fn) {
      var wrappedFn = function(args) {
        if (args === void 0 || args === null) {
          return args;
        }
        if (arguments.length > 1) {
          args = Array.prototype.slice.call(arguments);
        }
        var result = fn(args);
        if (typeof result === "object") {
          for (var len = result.length, i = 0; i < len; i++) {
            result[i] = Math.round(result[i]);
          }
        }
        return result;
      };
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    models.forEach(function(fromModel) {
      convert[fromModel] = {};
      Object.defineProperty(convert[fromModel], "channels", { value: conversions[fromModel].channels });
      Object.defineProperty(convert[fromModel], "labels", { value: conversions[fromModel].labels });
      var routes = route(fromModel);
      var routeModels = Object.keys(routes);
      routeModels.forEach(function(toModel) {
        var fn = routes[toModel];
        convert[fromModel][toModel] = wrapRounded(fn);
        convert[fromModel][toModel].raw = wrapRaw(fn);
      });
    });
    module2.exports = convert;
  }
});

// node_modules/@babel/highlight/node_modules/ansi-styles/index.js
var require_ansi_styles2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/ansi-styles/index.js"(exports, module2) {
    "use strict";
    var colorConvert = require_color_convert2();
    var wrapAnsi16 = (fn, offset) => function() {
      const code = fn.apply(colorConvert, arguments);
      return `\x1B[${code + offset}m`;
    };
    var wrapAnsi256 = (fn, offset) => function() {
      const code = fn.apply(colorConvert, arguments);
      return `\x1B[${38 + offset};5;${code}m`;
    };
    var wrapAnsi16m = (fn, offset) => function() {
      const rgb = fn.apply(colorConvert, arguments);
      return `\x1B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
    };
    function assembleStyles() {
      const codes = /* @__PURE__ */ new Map();
      const styles = {
        modifier: {
          reset: [0, 0],
          // 21 isn't widely supported and 22 does the same thing
          bold: [1, 22],
          dim: [2, 22],
          italic: [3, 23],
          underline: [4, 24],
          inverse: [7, 27],
          hidden: [8, 28],
          strikethrough: [9, 29]
        },
        color: {
          black: [30, 39],
          red: [31, 39],
          green: [32, 39],
          yellow: [33, 39],
          blue: [34, 39],
          magenta: [35, 39],
          cyan: [36, 39],
          white: [37, 39],
          gray: [90, 39],
          // Bright color
          redBright: [91, 39],
          greenBright: [92, 39],
          yellowBright: [93, 39],
          blueBright: [94, 39],
          magentaBright: [95, 39],
          cyanBright: [96, 39],
          whiteBright: [97, 39]
        },
        bgColor: {
          bgBlack: [40, 49],
          bgRed: [41, 49],
          bgGreen: [42, 49],
          bgYellow: [43, 49],
          bgBlue: [44, 49],
          bgMagenta: [45, 49],
          bgCyan: [46, 49],
          bgWhite: [47, 49],
          // Bright color
          bgBlackBright: [100, 49],
          bgRedBright: [101, 49],
          bgGreenBright: [102, 49],
          bgYellowBright: [103, 49],
          bgBlueBright: [104, 49],
          bgMagentaBright: [105, 49],
          bgCyanBright: [106, 49],
          bgWhiteBright: [107, 49]
        }
      };
      styles.color.grey = styles.color.gray;
      for (const groupName of Object.keys(styles)) {
        const group = styles[groupName];
        for (const styleName of Object.keys(group)) {
          const style = group[styleName];
          styles[styleName] = {
            open: `\x1B[${style[0]}m`,
            close: `\x1B[${style[1]}m`
          };
          group[styleName] = styles[styleName];
          codes.set(style[0], style[1]);
        }
        Object.defineProperty(styles, groupName, {
          value: group,
          enumerable: false
        });
        Object.defineProperty(styles, "codes", {
          value: codes,
          enumerable: false
        });
      }
      const ansi2ansi = (n) => n;
      const rgb2rgb = (r, g, b) => [r, g, b];
      styles.color.close = "\x1B[39m";
      styles.bgColor.close = "\x1B[49m";
      styles.color.ansi = {
        ansi: wrapAnsi16(ansi2ansi, 0)
      };
      styles.color.ansi256 = {
        ansi256: wrapAnsi256(ansi2ansi, 0)
      };
      styles.color.ansi16m = {
        rgb: wrapAnsi16m(rgb2rgb, 0)
      };
      styles.bgColor.ansi = {
        ansi: wrapAnsi16(ansi2ansi, 10)
      };
      styles.bgColor.ansi256 = {
        ansi256: wrapAnsi256(ansi2ansi, 10)
      };
      styles.bgColor.ansi16m = {
        rgb: wrapAnsi16m(rgb2rgb, 10)
      };
      for (let key of Object.keys(colorConvert)) {
        if (typeof colorConvert[key] !== "object") {
          continue;
        }
        const suite = colorConvert[key];
        if (key === "ansi16") {
          key = "ansi";
        }
        if ("ansi16" in suite) {
          styles.color.ansi[key] = wrapAnsi16(suite.ansi16, 0);
          styles.bgColor.ansi[key] = wrapAnsi16(suite.ansi16, 10);
        }
        if ("ansi256" in suite) {
          styles.color.ansi256[key] = wrapAnsi256(suite.ansi256, 0);
          styles.bgColor.ansi256[key] = wrapAnsi256(suite.ansi256, 10);
        }
        if ("rgb" in suite) {
          styles.color.ansi16m[key] = wrapAnsi16m(suite.rgb, 0);
          styles.bgColor.ansi16m[key] = wrapAnsi16m(suite.rgb, 10);
        }
      }
      return styles;
    }
    Object.defineProperty(module2, "exports", {
      enumerable: true,
      get: assembleStyles
    });
  }
});

// node_modules/@babel/highlight/node_modules/has-flag/index.js
var require_has_flag2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/has-flag/index.js"(exports, module2) {
    "use strict";
    module2.exports = (flag, argv) => {
      argv = argv || process.argv;
      const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
      const pos = argv.indexOf(prefix + flag);
      const terminatorPos = argv.indexOf("--");
      return pos !== -1 && (terminatorPos === -1 ? true : pos < terminatorPos);
    };
  }
});

// node_modules/@babel/highlight/node_modules/supports-color/index.js
var require_supports_color2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/supports-color/index.js"(exports, module2) {
    "use strict";
    var os = require("os");
    var hasFlag = require_has_flag2();
    var env = process.env;
    var forceColor;
    if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false")) {
      forceColor = false;
    } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
      forceColor = true;
    }
    if ("FORCE_COLOR" in env) {
      forceColor = env.FORCE_COLOR.length === 0 || parseInt(env.FORCE_COLOR, 10) !== 0;
    }
    function translateLevel(level) {
      if (level === 0) {
        return false;
      }
      return {
        level,
        hasBasic: true,
        has256: level >= 2,
        has16m: level >= 3
      };
    }
    function supportsColor(stream) {
      if (forceColor === false) {
        return 0;
      }
      if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
        return 3;
      }
      if (hasFlag("color=256")) {
        return 2;
      }
      if (stream && !stream.isTTY && forceColor !== true) {
        return 0;
      }
      const min2 = forceColor ? 1 : 0;
      if (process.platform === "win32") {
        const osRelease = os.release().split(".");
        if (Number(process.versions.node.split(".")[0]) >= 8 && Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
          return Number(osRelease[2]) >= 14931 ? 3 : 2;
        }
        return 1;
      }
      if ("CI" in env) {
        if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
          return 1;
        }
        return min2;
      }
      if ("TEAMCITY_VERSION" in env) {
        return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
      }
      if (env.COLORTERM === "truecolor") {
        return 3;
      }
      if ("TERM_PROGRAM" in env) {
        const version2 = parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
        switch (env.TERM_PROGRAM) {
          case "iTerm.app":
            return version2 >= 3 ? 3 : 2;
          case "Apple_Terminal":
            return 2;
        }
      }
      if (/-256(color)?$/i.test(env.TERM)) {
        return 2;
      }
      if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
        return 1;
      }
      if ("COLORTERM" in env) {
        return 1;
      }
      if (env.TERM === "dumb") {
        return min2;
      }
      return min2;
    }
    function getSupportLevel(stream) {
      const level = supportsColor(stream);
      return translateLevel(level);
    }
    module2.exports = {
      supportsColor: getSupportLevel,
      stdout: getSupportLevel(process.stdout),
      stderr: getSupportLevel(process.stderr)
    };
  }
});

// node_modules/@babel/highlight/node_modules/chalk/templates.js
var require_templates2 = __commonJS({
  "node_modules/@babel/highlight/node_modules/chalk/templates.js"(exports, module2) {
    "use strict";
    var TEMPLATE_REGEX = /(?:\\(u[a-f\d]{4}|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
    var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
    var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
    var ESCAPE_REGEX = /\\(u[a-f\d]{4}|x[a-f\d]{2}|.)|([^\\])/gi;
    var ESCAPES = /* @__PURE__ */ new Map([
      ["n", "\n"],
      ["r", "\r"],
      ["t", "	"],
      ["b", "\b"],
      ["f", "\f"],
      ["v", "\v"],
      ["0", "\0"],
      ["\\", "\\"],
      ["e", "\x1B"],
      ["a", "\x07"]
    ]);
    function unescape2(c) {
      if (c[0] === "u" && c.length === 5 || c[0] === "x" && c.length === 3) {
        return String.fromCharCode(parseInt(c.slice(1), 16));
      }
      return ESCAPES.get(c) || c;
    }
    function parseArguments(name, args) {
      const results = [];
      const chunks = args.trim().split(/\s*,\s*/g);
      let matches;
      for (const chunk of chunks) {
        if (!isNaN(chunk)) {
          results.push(Number(chunk));
        } else if (matches = chunk.match(STRING_REGEX)) {
          results.push(matches[2].replace(ESCAPE_REGEX, (m, escape2, chr) => escape2 ? unescape2(escape2) : chr));
        } else {
          throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
        }
      }
      return results;
    }
    function parseStyle(style) {
      STYLE_REGEX.lastIndex = 0;
      const results = [];
      let matches;
      while ((matches = STYLE_REGEX.exec(style)) !== null) {
        const name = matches[1];
        if (matches[2]) {
          const args = parseArguments(name, matches[2]);
          results.push([name].concat(args));
        } else {
          results.push([name]);
        }
      }
      return results;
    }
    function buildStyle(chalk3, styles) {
      const enabled = {};
      for (const layer of styles) {
        for (const style of layer.styles) {
          enabled[style[0]] = layer.inverse ? null : style.slice(1);
        }
      }
      let current = chalk3;
      for (const styleName of Object.keys(enabled)) {
        if (Array.isArray(enabled[styleName])) {
          if (!(styleName in current)) {
            throw new Error(`Unknown Chalk style: ${styleName}`);
          }
          if (enabled[styleName].length > 0) {
            current = current[styleName].apply(current, enabled[styleName]);
          } else {
            current = current[styleName];
          }
        }
      }
      return current;
    }
    module2.exports = (chalk3, tmp) => {
      const styles = [];
      const chunks = [];
      let chunk = [];
      tmp.replace(TEMPLATE_REGEX, (m, escapeChar, inverse, style, close, chr) => {
        if (escapeChar) {
          chunk.push(unescape2(escapeChar));
        } else if (style) {
          const str = chunk.join("");
          chunk = [];
          chunks.push(styles.length === 0 ? str : buildStyle(chalk3, styles)(str));
          styles.push({ inverse, styles: parseStyle(style) });
        } else if (close) {
          if (styles.length === 0) {
            throw new Error("Found extraneous } in Chalk template literal");
          }
          chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
          chunk = [];
          styles.pop();
        } else {
          chunk.push(chr);
        }
      });
      chunks.push(chunk.join(""));
      if (styles.length > 0) {
        const errMsg = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
        throw new Error(errMsg);
      }
      return chunks.join("");
    };
  }
});

// node_modules/@babel/highlight/node_modules/chalk/index.js
var require_chalk = __commonJS({
  "node_modules/@babel/highlight/node_modules/chalk/index.js"(exports, module2) {
    "use strict";
    var escapeStringRegexp = require_escape_string_regexp();
    var ansiStyles = require_ansi_styles2();
    var stdoutColor = require_supports_color2().stdout;
    var template = require_templates2();
    var isSimpleWindowsTerm = process.platform === "win32" && !(process.env.TERM || "").toLowerCase().startsWith("xterm");
    var levelMapping = ["ansi", "ansi", "ansi256", "ansi16m"];
    var skipModels = /* @__PURE__ */ new Set(["gray"]);
    var styles = /* @__PURE__ */ Object.create(null);
    function applyOptions(obj, options) {
      options = options || {};
      const scLevel = stdoutColor ? stdoutColor.level : 0;
      obj.level = options.level === void 0 ? scLevel : options.level;
      obj.enabled = "enabled" in options ? options.enabled : obj.level > 0;
    }
    function Chalk(options) {
      if (!this || !(this instanceof Chalk) || this.template) {
        const chalk3 = {};
        applyOptions(chalk3, options);
        chalk3.template = function() {
          const args = [].slice.call(arguments);
          return chalkTag.apply(null, [chalk3.template].concat(args));
        };
        Object.setPrototypeOf(chalk3, Chalk.prototype);
        Object.setPrototypeOf(chalk3.template, chalk3);
        chalk3.template.constructor = Chalk;
        return chalk3.template;
      }
      applyOptions(this, options);
    }
    if (isSimpleWindowsTerm) {
      ansiStyles.blue.open = "\x1B[94m";
    }
    for (const key of Object.keys(ansiStyles)) {
      ansiStyles[key].closeRe = new RegExp(escapeStringRegexp(ansiStyles[key].close), "g");
      styles[key] = {
        get() {
          const codes = ansiStyles[key];
          return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, key);
        }
      };
    }
    styles.visible = {
      get() {
        return build.call(this, this._styles || [], true, "visible");
      }
    };
    ansiStyles.color.closeRe = new RegExp(escapeStringRegexp(ansiStyles.color.close), "g");
    for (const model of Object.keys(ansiStyles.color.ansi)) {
      if (skipModels.has(model)) {
        continue;
      }
      styles[model] = {
        get() {
          const level = this.level;
          return function() {
            const open = ansiStyles.color[levelMapping[level]][model].apply(null, arguments);
            const codes = {
              open,
              close: ansiStyles.color.close,
              closeRe: ansiStyles.color.closeRe
            };
            return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
          };
        }
      };
    }
    ansiStyles.bgColor.closeRe = new RegExp(escapeStringRegexp(ansiStyles.bgColor.close), "g");
    for (const model of Object.keys(ansiStyles.bgColor.ansi)) {
      if (skipModels.has(model)) {
        continue;
      }
      const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
      styles[bgModel] = {
        get() {
          const level = this.level;
          return function() {
            const open = ansiStyles.bgColor[levelMapping[level]][model].apply(null, arguments);
            const codes = {
              open,
              close: ansiStyles.bgColor.close,
              closeRe: ansiStyles.bgColor.closeRe
            };
            return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
          };
        }
      };
    }
    var proto = Object.defineProperties(() => {
    }, styles);
    function build(_styles, _empty, key) {
      const builder = function() {
        return applyStyle.apply(builder, arguments);
      };
      builder._styles = _styles;
      builder._empty = _empty;
      const self2 = this;
      Object.defineProperty(builder, "level", {
        enumerable: true,
        get() {
          return self2.level;
        },
        set(level) {
          self2.level = level;
        }
      });
      Object.defineProperty(builder, "enabled", {
        enumerable: true,
        get() {
          return self2.enabled;
        },
        set(enabled) {
          self2.enabled = enabled;
        }
      });
      builder.hasGrey = this.hasGrey || key === "gray" || key === "grey";
      builder.__proto__ = proto;
      return builder;
    }
    function applyStyle() {
      const args = arguments;
      const argsLen = args.length;
      let str = String(arguments[0]);
      if (argsLen === 0) {
        return "";
      }
      if (argsLen > 1) {
        for (let a = 1; a < argsLen; a++) {
          str += " " + args[a];
        }
      }
      if (!this.enabled || this.level <= 0 || !str) {
        return this._empty ? "" : str;
      }
      const originalDim = ansiStyles.dim.open;
      if (isSimpleWindowsTerm && this.hasGrey) {
        ansiStyles.dim.open = "";
      }
      for (const code of this._styles.slice().reverse()) {
        str = code.open + str.replace(code.closeRe, code.open) + code.close;
        str = str.replace(/\r?\n/g, `${code.close}$&${code.open}`);
      }
      ansiStyles.dim.open = originalDim;
      return str;
    }
    function chalkTag(chalk3, strings) {
      if (!Array.isArray(strings)) {
        return [].slice.call(arguments, 1).join(" ");
      }
      const args = [].slice.call(arguments, 2);
      const parts = [strings.raw[0]];
      for (let i = 1; i < strings.length; i++) {
        parts.push(String(args[i - 1]).replace(/[{}\\]/g, "\\$&"));
        parts.push(String(strings.raw[i]));
      }
      return template(chalk3, parts.join(""));
    }
    Object.defineProperties(Chalk.prototype, styles);
    module2.exports = Chalk();
    module2.exports.supportsColor = stdoutColor;
    module2.exports.default = module2.exports;
  }
});

// node_modules/@babel/highlight/lib/index.js
var require_lib15 = __commonJS({
  "node_modules/@babel/highlight/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = highlight;
    exports.getChalk = getChalk;
    exports.shouldHighlight = shouldHighlight;
    var _jsTokens = require_js_tokens();
    var _helperValidatorIdentifier = require_lib9();
    var _chalk = require_chalk();
    var sometimesKeywords = /* @__PURE__ */ new Set(["as", "async", "from", "get", "of", "set"]);
    function getDefs(chalk3) {
      return {
        keyword: chalk3.cyan,
        capitalized: chalk3.yellow,
        jsxIdentifier: chalk3.yellow,
        punctuator: chalk3.yellow,
        number: chalk3.magenta,
        string: chalk3.green,
        regex: chalk3.magenta,
        comment: chalk3.grey,
        invalid: chalk3.white.bgRed.bold
      };
    }
    var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
    var BRACKET = /^[()[\]{}]$/;
    var tokenize;
    {
      const JSX_TAG = /^[a-z][\w-]*$/i;
      const getTokenType = function(token, offset, text) {
        if (token.type === "name") {
          if ((0, _helperValidatorIdentifier.isKeyword)(token.value) || (0, _helperValidatorIdentifier.isStrictReservedWord)(token.value, true) || sometimesKeywords.has(token.value)) {
            return "keyword";
          }
          if (JSX_TAG.test(token.value) && (text[offset - 1] === "<" || text.slice(offset - 2, offset) == "</")) {
            return "jsxIdentifier";
          }
          if (token.value[0] !== token.value[0].toLowerCase()) {
            return "capitalized";
          }
        }
        if (token.type === "punctuator" && BRACKET.test(token.value)) {
          return "bracket";
        }
        if (token.type === "invalid" && (token.value === "@" || token.value === "#")) {
          return "punctuator";
        }
        return token.type;
      };
      tokenize = function* (text) {
        let match;
        while (match = _jsTokens.default.exec(text)) {
          const token = _jsTokens.matchToToken(match);
          yield {
            type: getTokenType(token, match.index, text),
            value: token.value
          };
        }
      };
    }
    function highlightTokens(defs, text) {
      let highlighted = "";
      for (const {
        type,
        value: value2
      } of tokenize(text)) {
        const colorize = defs[type];
        if (colorize) {
          highlighted += value2.split(NEWLINE).map((str) => colorize(str)).join("\n");
        } else {
          highlighted += value2;
        }
      }
      return highlighted;
    }
    function shouldHighlight(options) {
      return !!_chalk.supportsColor || options.forceColor;
    }
    function getChalk(options) {
      return options.forceColor ? new _chalk.constructor({
        enabled: true,
        level: 1
      }) : _chalk;
    }
    function highlight(code, options = {}) {
      if (code !== "" && shouldHighlight(options)) {
        const chalk3 = getChalk(options);
        const defs = getDefs(chalk3);
        return highlightTokens(defs, code);
      } else {
        return code;
      }
    }
  }
});

// node_modules/@babel/code-frame/lib/index.js
var require_lib16 = __commonJS({
  "node_modules/@babel/code-frame/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.codeFrameColumns = codeFrameColumns;
    exports.default = _default;
    var _highlight = require_lib15();
    var deprecationWarningShown = false;
    function getDefs(chalk3) {
      return {
        gutter: chalk3.grey,
        marker: chalk3.red.bold,
        message: chalk3.red.bold
      };
    }
    var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
    function getMarkerLines(loc, source, opts) {
      const startLoc = Object.assign({
        column: 0,
        line: -1
      }, loc.start);
      const endLoc = Object.assign({}, startLoc, loc.end);
      const {
        linesAbove = 2,
        linesBelow = 3
      } = opts || {};
      const startLine = startLoc.line;
      const startColumn = startLoc.column;
      const endLine = endLoc.line;
      const endColumn = endLoc.column;
      let start = Math.max(startLine - (linesAbove + 1), 0);
      let end = Math.min(source.length, endLine + linesBelow);
      if (startLine === -1) {
        start = 0;
      }
      if (endLine === -1) {
        end = source.length;
      }
      const lineDiff = endLine - startLine;
      const markerLines = {};
      if (lineDiff) {
        for (let i = 0; i <= lineDiff; i++) {
          const lineNumber = i + startLine;
          if (!startColumn) {
            markerLines[lineNumber] = true;
          } else if (i === 0) {
            const sourceLength = source[lineNumber - 1].length;
            markerLines[lineNumber] = [startColumn, sourceLength - startColumn + 1];
          } else if (i === lineDiff) {
            markerLines[lineNumber] = [0, endColumn];
          } else {
            const sourceLength = source[lineNumber - i].length;
            markerLines[lineNumber] = [0, sourceLength];
          }
        }
      } else {
        if (startColumn === endColumn) {
          if (startColumn) {
            markerLines[startLine] = [startColumn, 0];
          } else {
            markerLines[startLine] = true;
          }
        } else {
          markerLines[startLine] = [startColumn, endColumn - startColumn];
        }
      }
      return {
        start,
        end,
        markerLines
      };
    }
    function codeFrameColumns(rawLines, loc, opts = {}) {
      const highlighted = (opts.highlightCode || opts.forceColor) && (0, _highlight.shouldHighlight)(opts);
      const chalk3 = (0, _highlight.getChalk)(opts);
      const defs = getDefs(chalk3);
      const maybeHighlight = (chalkFn, string) => {
        return highlighted ? chalkFn(string) : string;
      };
      const lines = rawLines.split(NEWLINE);
      const {
        start,
        end,
        markerLines
      } = getMarkerLines(loc, lines, opts);
      const hasColumns = loc.start && typeof loc.start.column === "number";
      const numberMaxWidth = String(end).length;
      const highlightedLines = highlighted ? (0, _highlight.default)(rawLines, opts) : rawLines;
      let frame = highlightedLines.split(NEWLINE, end).slice(start, end).map((line, index) => {
        const number = start + 1 + index;
        const paddedNumber = ` ${number}`.slice(-numberMaxWidth);
        const gutter = ` ${paddedNumber} |`;
        const hasMarker = markerLines[number];
        const lastMarkerLine = !markerLines[number + 1];
        if (hasMarker) {
          let markerLine = "";
          if (Array.isArray(hasMarker)) {
            const markerSpacing = line.slice(0, Math.max(hasMarker[0] - 1, 0)).replace(/[^\t]/g, " ");
            const numberOfMarkers = hasMarker[1] || 1;
            markerLine = ["\n ", maybeHighlight(defs.gutter, gutter.replace(/\d/g, " ")), " ", markerSpacing, maybeHighlight(defs.marker, "^").repeat(numberOfMarkers)].join("");
            if (lastMarkerLine && opts.message) {
              markerLine += " " + maybeHighlight(defs.message, opts.message);
            }
          }
          return [maybeHighlight(defs.marker, ">"), maybeHighlight(defs.gutter, gutter), line.length > 0 ? ` ${line}` : "", markerLine].join("");
        } else {
          return ` ${maybeHighlight(defs.gutter, gutter)}${line.length > 0 ? ` ${line}` : ""}`;
        }
      }).join("\n");
      if (opts.message && !hasColumns) {
        frame = `${" ".repeat(numberMaxWidth + 1)}${opts.message}
${frame}`;
      }
      if (highlighted) {
        return chalk3.reset(frame);
      } else {
        return frame;
      }
    }
    function _default(rawLines, lineNumber, colNumber, opts = {}) {
      if (!deprecationWarningShown) {
        deprecationWarningShown = true;
        const message = "Passing lineNumber and colNumber is deprecated to @babel/code-frame. Please use `codeFrameColumns`.";
        if (process.emitWarning) {
          process.emitWarning(message, "DeprecationWarning");
        } else {
          const deprecationError = new Error(message);
          deprecationError.name = "DeprecationWarning";
          console.warn(new Error(message));
        }
      }
      colNumber = Math.max(colNumber, 0);
      const location = {
        start: {
          column: colNumber,
          line: lineNumber
        }
      };
      return codeFrameColumns(rawLines, location, opts);
    }
  }
});

// node_modules/@babel/helper-hoist-variables/lib/index.js
var require_lib17 = __commonJS({
  "node_modules/@babel/helper-hoist-variables/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = hoistVariables;
    var _t = require_lib11();
    var {
      assignmentExpression,
      expressionStatement,
      identifier: identifier3
    } = _t;
    var visitor = {
      Scope(path2, state) {
        if (state.kind === "let")
          path2.skip();
      },
      FunctionParent(path2) {
        path2.skip();
      },
      VariableDeclaration(path2, state) {
        if (state.kind && path2.node.kind !== state.kind)
          return;
        const nodes = [];
        const declarations = path2.get("declarations");
        let firstId;
        for (const declar of declarations) {
          firstId = declar.node.id;
          if (declar.node.init) {
            nodes.push(expressionStatement(assignmentExpression("=", declar.node.id, declar.node.init)));
          }
          for (const name of Object.keys(declar.getBindingIdentifiers())) {
            state.emit(identifier3(name), name, declar.node.init !== null);
          }
        }
        if (path2.parentPath.isFor({
          left: path2.node
        })) {
          path2.replaceWith(firstId);
        } else {
          path2.replaceWithMultiple(nodes);
        }
      }
    };
    function hoistVariables(path2, emit, kind = "var") {
      path2.traverse(visitor, {
        kind,
        emit
      });
    }
  }
});

// node_modules/@babel/traverse/lib/path/replacement.js
var require_replacement = __commonJS({
  "node_modules/@babel/traverse/lib/path/replacement.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._replaceWith = _replaceWith;
    exports.replaceExpressionWithStatements = replaceExpressionWithStatements;
    exports.replaceInline = replaceInline;
    exports.replaceWith = replaceWith;
    exports.replaceWithMultiple = replaceWithMultiple;
    exports.replaceWithSourceString = replaceWithSourceString;
    var _codeFrame = require_lib16();
    var _index = require_lib20();
    var _index2 = require_path();
    var _cache = require_cache4();
    var _parser = require_lib2();
    var _t = require_lib11();
    var _helperHoistVariables = require_lib17();
    var {
      FUNCTION_TYPES,
      arrowFunctionExpression,
      assignmentExpression,
      awaitExpression,
      blockStatement: blockStatement2,
      callExpression: callExpression3,
      cloneNode,
      expressionStatement,
      identifier: identifier3,
      inheritLeadingComments,
      inheritTrailingComments,
      inheritsComments,
      isExpression: isExpression2,
      isProgram,
      isStatement,
      removeComments,
      returnStatement: returnStatement2,
      toSequenceExpression,
      validate,
      yieldExpression
    } = _t;
    function replaceWithMultiple(nodes) {
      var _pathCache$get;
      this.resync();
      nodes = this._verifyNodeList(nodes);
      inheritLeadingComments(nodes[0], this.node);
      inheritTrailingComments(nodes[nodes.length - 1], this.node);
      (_pathCache$get = _cache.path.get(this.parent)) == null ? void 0 : _pathCache$get.delete(this.node);
      this.node = this.container[this.key] = null;
      const paths = this.insertAfter(nodes);
      if (this.node) {
        this.requeue();
      } else {
        this.remove();
      }
      return paths;
    }
    function replaceWithSourceString(replacement) {
      this.resync();
      let ast;
      try {
        replacement = `(${replacement})`;
        ast = (0, _parser.parse)(replacement);
      } catch (err) {
        const loc = err.loc;
        if (loc) {
          err.message += " - make sure this is an expression.\n" + (0, _codeFrame.codeFrameColumns)(replacement, {
            start: {
              line: loc.line,
              column: loc.column + 1
            }
          });
          err.code = "BABEL_REPLACE_SOURCE_ERROR";
        }
        throw err;
      }
      const expressionAST = ast.program.body[0].expression;
      _index.default.removeProperties(expressionAST);
      return this.replaceWith(expressionAST);
    }
    function replaceWith(replacementPath) {
      this.resync();
      if (this.removed) {
        throw new Error("You can't replace this node, we've already removed it");
      }
      let replacement = replacementPath instanceof _index2.default ? replacementPath.node : replacementPath;
      if (!replacement) {
        throw new Error("You passed `path.replaceWith()` a falsy node, use `path.remove()` instead");
      }
      if (this.node === replacement) {
        return [this];
      }
      if (this.isProgram() && !isProgram(replacement)) {
        throw new Error("You can only replace a Program root node with another Program node");
      }
      if (Array.isArray(replacement)) {
        throw new Error("Don't use `path.replaceWith()` with an array of nodes, use `path.replaceWithMultiple()`");
      }
      if (typeof replacement === "string") {
        throw new Error("Don't use `path.replaceWith()` with a source string, use `path.replaceWithSourceString()`");
      }
      let nodePath = "";
      if (this.isNodeType("Statement") && isExpression2(replacement)) {
        if (!this.canHaveVariableDeclarationOrExpression() && !this.canSwapBetweenExpressionAndStatement(replacement) && !this.parentPath.isExportDefaultDeclaration()) {
          replacement = expressionStatement(replacement);
          nodePath = "expression";
        }
      }
      if (this.isNodeType("Expression") && isStatement(replacement)) {
        if (!this.canHaveVariableDeclarationOrExpression() && !this.canSwapBetweenExpressionAndStatement(replacement)) {
          return this.replaceExpressionWithStatements([replacement]);
        }
      }
      const oldNode = this.node;
      if (oldNode) {
        inheritsComments(replacement, oldNode);
        removeComments(oldNode);
      }
      this._replaceWith(replacement);
      this.type = replacement.type;
      this.setScope();
      this.requeue();
      return [nodePath ? this.get(nodePath) : this];
    }
    function _replaceWith(node) {
      var _pathCache$get2;
      if (!this.container) {
        throw new ReferenceError("Container is falsy");
      }
      if (this.inList) {
        validate(this.parent, this.key, [node]);
      } else {
        validate(this.parent, this.key, node);
      }
      this.debug(`Replace with ${node == null ? void 0 : node.type}`);
      (_pathCache$get2 = _cache.path.get(this.parent)) == null ? void 0 : _pathCache$get2.set(node, this).delete(this.node);
      this.node = this.container[this.key] = node;
    }
    function replaceExpressionWithStatements(nodes) {
      this.resync();
      const nodesAsSequenceExpression = toSequenceExpression(nodes, this.scope);
      if (nodesAsSequenceExpression) {
        return this.replaceWith(nodesAsSequenceExpression)[0].get("expressions");
      }
      const functionParent = this.getFunctionParent();
      const isParentAsync = functionParent == null ? void 0 : functionParent.is("async");
      const isParentGenerator = functionParent == null ? void 0 : functionParent.is("generator");
      const container = arrowFunctionExpression([], blockStatement2(nodes));
      this.replaceWith(callExpression3(container, []));
      const callee = this.get("callee");
      (0, _helperHoistVariables.default)(callee.get("body"), (id) => {
        this.scope.push({
          id
        });
      }, "var");
      const completionRecords = this.get("callee").getCompletionRecords();
      for (const path2 of completionRecords) {
        if (!path2.isExpressionStatement())
          continue;
        const loop = path2.findParent((path3) => path3.isLoop());
        if (loop) {
          let uid = loop.getData("expressionReplacementReturnUid");
          if (!uid) {
            uid = callee.scope.generateDeclaredUidIdentifier("ret");
            callee.get("body").pushContainer("body", returnStatement2(cloneNode(uid)));
            loop.setData("expressionReplacementReturnUid", uid);
          } else {
            uid = identifier3(uid.name);
          }
          path2.get("expression").replaceWith(assignmentExpression("=", cloneNode(uid), path2.node.expression));
        } else {
          path2.replaceWith(returnStatement2(path2.node.expression));
        }
      }
      callee.arrowFunctionToExpression();
      const newCallee = callee;
      const needToAwaitFunction = isParentAsync && _index.default.hasType(this.get("callee.body").node, "AwaitExpression", FUNCTION_TYPES);
      const needToYieldFunction = isParentGenerator && _index.default.hasType(this.get("callee.body").node, "YieldExpression", FUNCTION_TYPES);
      if (needToAwaitFunction) {
        newCallee.set("async", true);
        if (!needToYieldFunction) {
          this.replaceWith(awaitExpression(this.node));
        }
      }
      if (needToYieldFunction) {
        newCallee.set("generator", true);
        this.replaceWith(yieldExpression(this.node, true));
      }
      return newCallee.get("body.body");
    }
    function replaceInline(nodes) {
      this.resync();
      if (Array.isArray(nodes)) {
        if (Array.isArray(this.container)) {
          nodes = this._verifyNodeList(nodes);
          const paths = this._containerInsertAfter(nodes);
          this.remove();
          return paths;
        } else {
          return this.replaceWithMultiple(nodes);
        }
      } else {
        return this.replaceWith(nodes);
      }
    }
  }
});

// node_modules/@babel/traverse/lib/path/evaluation.js
var require_evaluation = __commonJS({
  "node_modules/@babel/traverse/lib/path/evaluation.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.evaluate = evaluate;
    exports.evaluateTruthy = evaluateTruthy;
    var VALID_CALLEES = ["String", "Number", "Math"];
    var INVALID_METHODS = ["random"];
    function isValidCallee(val) {
      return VALID_CALLEES.includes(val);
    }
    function isInvalidMethod(val) {
      return INVALID_METHODS.includes(val);
    }
    function evaluateTruthy() {
      const res = this.evaluate();
      if (res.confident)
        return !!res.value;
    }
    function deopt(path2, state) {
      if (!state.confident)
        return;
      state.deoptPath = path2;
      state.confident = false;
    }
    function evaluateCached(path2, state) {
      const {
        node
      } = path2;
      const {
        seen
      } = state;
      if (seen.has(node)) {
        const existing = seen.get(node);
        if (existing.resolved) {
          return existing.value;
        } else {
          deopt(path2, state);
          return;
        }
      } else {
        const item = {
          resolved: false
        };
        seen.set(node, item);
        const val = _evaluate(path2, state);
        if (state.confident) {
          item.resolved = true;
          item.value = val;
        }
        return val;
      }
    }
    function _evaluate(path2, state) {
      if (!state.confident)
        return;
      if (path2.isSequenceExpression()) {
        const exprs = path2.get("expressions");
        return evaluateCached(exprs[exprs.length - 1], state);
      }
      if (path2.isStringLiteral() || path2.isNumericLiteral() || path2.isBooleanLiteral()) {
        return path2.node.value;
      }
      if (path2.isNullLiteral()) {
        return null;
      }
      if (path2.isTemplateLiteral()) {
        return evaluateQuasis(path2, path2.node.quasis, state);
      }
      if (path2.isTaggedTemplateExpression() && path2.get("tag").isMemberExpression()) {
        const object = path2.get("tag.object");
        const {
          node: {
            name
          }
        } = object;
        const property = path2.get("tag.property");
        if (object.isIdentifier() && name === "String" && !path2.scope.getBinding(name) && property.isIdentifier() && property.node.name === "raw") {
          return evaluateQuasis(path2, path2.node.quasi.quasis, state, true);
        }
      }
      if (path2.isConditionalExpression()) {
        const testResult = evaluateCached(path2.get("test"), state);
        if (!state.confident)
          return;
        if (testResult) {
          return evaluateCached(path2.get("consequent"), state);
        } else {
          return evaluateCached(path2.get("alternate"), state);
        }
      }
      if (path2.isExpressionWrapper()) {
        return evaluateCached(path2.get("expression"), state);
      }
      if (path2.isMemberExpression() && !path2.parentPath.isCallExpression({
        callee: path2.node
      })) {
        const property = path2.get("property");
        const object = path2.get("object");
        if (object.isLiteral()) {
          const value2 = object.node.value;
          const type = typeof value2;
          let key = null;
          if (path2.node.computed) {
            key = evaluateCached(property, state);
            if (!state.confident)
              return;
          } else if (property.isIdentifier()) {
            key = property.node.name;
          }
          if ((type === "number" || type === "string") && key != null && (typeof key === "number" || typeof key === "string")) {
            return value2[key];
          }
        }
      }
      if (path2.isReferencedIdentifier()) {
        const binding = path2.scope.getBinding(path2.node.name);
        if (binding && binding.constantViolations.length > 0) {
          return deopt(binding.path, state);
        }
        if (binding && path2.node.start < binding.path.node.end) {
          return deopt(binding.path, state);
        }
        if (binding != null && binding.hasValue) {
          return binding.value;
        } else {
          if (path2.node.name === "undefined") {
            return binding ? deopt(binding.path, state) : void 0;
          } else if (path2.node.name === "Infinity") {
            return binding ? deopt(binding.path, state) : Infinity;
          } else if (path2.node.name === "NaN") {
            return binding ? deopt(binding.path, state) : NaN;
          }
          const resolved = path2.resolve();
          if (resolved === path2) {
            return deopt(path2, state);
          } else {
            return evaluateCached(resolved, state);
          }
        }
      }
      if (path2.isUnaryExpression({
        prefix: true
      })) {
        if (path2.node.operator === "void") {
          return void 0;
        }
        const argument = path2.get("argument");
        if (path2.node.operator === "typeof" && (argument.isFunction() || argument.isClass())) {
          return "function";
        }
        const arg = evaluateCached(argument, state);
        if (!state.confident)
          return;
        switch (path2.node.operator) {
          case "!":
            return !arg;
          case "+":
            return +arg;
          case "-":
            return -arg;
          case "~":
            return ~arg;
          case "typeof":
            return typeof arg;
        }
      }
      if (path2.isArrayExpression()) {
        const arr = [];
        const elems = path2.get("elements");
        for (const elem of elems) {
          const elemValue = elem.evaluate();
          if (elemValue.confident) {
            arr.push(elemValue.value);
          } else {
            return deopt(elemValue.deopt, state);
          }
        }
        return arr;
      }
      if (path2.isObjectExpression()) {
        const obj = {};
        const props = path2.get("properties");
        for (const prop of props) {
          if (prop.isObjectMethod() || prop.isSpreadElement()) {
            return deopt(prop, state);
          }
          const keyPath = prop.get("key");
          let key;
          if (prop.node.computed) {
            key = keyPath.evaluate();
            if (!key.confident) {
              return deopt(key.deopt, state);
            }
            key = key.value;
          } else if (keyPath.isIdentifier()) {
            key = keyPath.node.name;
          } else {
            key = keyPath.node.value;
          }
          const valuePath = prop.get("value");
          let value2 = valuePath.evaluate();
          if (!value2.confident) {
            return deopt(value2.deopt, state);
          }
          value2 = value2.value;
          obj[key] = value2;
        }
        return obj;
      }
      if (path2.isLogicalExpression()) {
        const wasConfident = state.confident;
        const left = evaluateCached(path2.get("left"), state);
        const leftConfident = state.confident;
        state.confident = wasConfident;
        const right = evaluateCached(path2.get("right"), state);
        const rightConfident = state.confident;
        switch (path2.node.operator) {
          case "||":
            state.confident = leftConfident && (!!left || rightConfident);
            if (!state.confident)
              return;
            return left || right;
          case "&&":
            state.confident = leftConfident && (!left || rightConfident);
            if (!state.confident)
              return;
            return left && right;
          case "??":
            state.confident = leftConfident && (left != null || rightConfident);
            if (!state.confident)
              return;
            return left != null ? left : right;
        }
      }
      if (path2.isBinaryExpression()) {
        const left = evaluateCached(path2.get("left"), state);
        if (!state.confident)
          return;
        const right = evaluateCached(path2.get("right"), state);
        if (!state.confident)
          return;
        switch (path2.node.operator) {
          case "-":
            return left - right;
          case "+":
            return left + right;
          case "/":
            return left / right;
          case "*":
            return left * right;
          case "%":
            return left % right;
          case "**":
            return Math.pow(left, right);
          case "<":
            return left < right;
          case ">":
            return left > right;
          case "<=":
            return left <= right;
          case ">=":
            return left >= right;
          case "==":
            return left == right;
          case "!=":
            return left != right;
          case "===":
            return left === right;
          case "!==":
            return left !== right;
          case "|":
            return left | right;
          case "&":
            return left & right;
          case "^":
            return left ^ right;
          case "<<":
            return left << right;
          case ">>":
            return left >> right;
          case ">>>":
            return left >>> right;
        }
      }
      if (path2.isCallExpression()) {
        const callee = path2.get("callee");
        let context;
        let func;
        if (callee.isIdentifier() && !path2.scope.getBinding(callee.node.name) && isValidCallee(callee.node.name)) {
          func = global[callee.node.name];
        }
        if (callee.isMemberExpression()) {
          const object = callee.get("object");
          const property = callee.get("property");
          if (object.isIdentifier() && property.isIdentifier() && isValidCallee(object.node.name) && !isInvalidMethod(property.node.name)) {
            context = global[object.node.name];
            func = context[property.node.name];
          }
          if (object.isLiteral() && property.isIdentifier()) {
            const type = typeof object.node.value;
            if (type === "string" || type === "number") {
              context = object.node.value;
              func = context[property.node.name];
            }
          }
        }
        if (func) {
          const args = path2.get("arguments").map((arg) => evaluateCached(arg, state));
          if (!state.confident)
            return;
          return func.apply(context, args);
        }
      }
      deopt(path2, state);
    }
    function evaluateQuasis(path2, quasis, state, raw = false) {
      let str = "";
      let i = 0;
      const exprs = path2.isTemplateLiteral() ? path2.get("expressions") : path2.get("quasi.expressions");
      for (const elem of quasis) {
        if (!state.confident)
          break;
        str += raw ? elem.value.raw : elem.value.cooked;
        const expr = exprs[i++];
        if (expr)
          str += String(evaluateCached(expr, state));
      }
      if (!state.confident)
        return;
      return str;
    }
    function evaluate() {
      const state = {
        confident: true,
        deoptPath: null,
        seen: /* @__PURE__ */ new Map()
      };
      let value2 = evaluateCached(this, state);
      if (!state.confident)
        value2 = void 0;
      return {
        confident: state.confident,
        deopt: state.deoptPath,
        value: value2
      };
    }
  }
});

// node_modules/@babel/template/lib/formatters.js
var require_formatters = __commonJS({
  "node_modules/@babel/template/lib/formatters.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.statements = exports.statement = exports.smart = exports.program = exports.expression = void 0;
    var _t = require_lib11();
    var {
      assertExpressionStatement
    } = _t;
    function makeStatementFormatter(fn) {
      return {
        code: (str) => `/* @babel/template */;
${str}`,
        validate: () => {
        },
        unwrap: (ast) => {
          return fn(ast.program.body.slice(1));
        }
      };
    }
    var smart = makeStatementFormatter((body) => {
      if (body.length > 1) {
        return body;
      } else {
        return body[0];
      }
    });
    exports.smart = smart;
    var statements = makeStatementFormatter((body) => body);
    exports.statements = statements;
    var statement = makeStatementFormatter((body) => {
      if (body.length === 0) {
        throw new Error("Found nothing to return.");
      }
      if (body.length > 1) {
        throw new Error("Found multiple statements but wanted one");
      }
      return body[0];
    });
    exports.statement = statement;
    var expression = {
      code: (str) => `(
${str}
)`,
      validate: (ast) => {
        if (ast.program.body.length > 1) {
          throw new Error("Found multiple statements but wanted one");
        }
        if (expression.unwrap(ast).start === 0) {
          throw new Error("Parse result included parens.");
        }
      },
      unwrap: ({
        program: program3
      }) => {
        const [stmt] = program3.body;
        assertExpressionStatement(stmt);
        return stmt.expression;
      }
    };
    exports.expression = expression;
    var program2 = {
      code: (str) => str,
      validate: () => {
      },
      unwrap: (ast) => ast.program
    };
    exports.program = program2;
  }
});

// node_modules/@babel/template/lib/options.js
var require_options = __commonJS({
  "node_modules/@babel/template/lib/options.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.merge = merge4;
    exports.normalizeReplacements = normalizeReplacements;
    exports.validate = validate;
    var _excluded = ["placeholderWhitelist", "placeholderPattern", "preserveComments", "syntacticPlaceholders"];
    function _objectWithoutPropertiesLoose(source, excluded) {
      if (source == null)
        return {};
      var target = {};
      var sourceKeys = Object.keys(source);
      var key, i;
      for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0)
          continue;
        target[key] = source[key];
      }
      return target;
    }
    function merge4(a, b) {
      const {
        placeholderWhitelist = a.placeholderWhitelist,
        placeholderPattern = a.placeholderPattern,
        preserveComments = a.preserveComments,
        syntacticPlaceholders = a.syntacticPlaceholders
      } = b;
      return {
        parser: Object.assign({}, a.parser, b.parser),
        placeholderWhitelist,
        placeholderPattern,
        preserveComments,
        syntacticPlaceholders
      };
    }
    function validate(opts) {
      if (opts != null && typeof opts !== "object") {
        throw new Error("Unknown template options.");
      }
      const _ref = opts || {}, {
        placeholderWhitelist,
        placeholderPattern,
        preserveComments,
        syntacticPlaceholders
      } = _ref, parser = _objectWithoutPropertiesLoose(_ref, _excluded);
      if (placeholderWhitelist != null && !(placeholderWhitelist instanceof Set)) {
        throw new Error("'.placeholderWhitelist' must be a Set, null, or undefined");
      }
      if (placeholderPattern != null && !(placeholderPattern instanceof RegExp) && placeholderPattern !== false) {
        throw new Error("'.placeholderPattern' must be a RegExp, false, null, or undefined");
      }
      if (preserveComments != null && typeof preserveComments !== "boolean") {
        throw new Error("'.preserveComments' must be a boolean, null, or undefined");
      }
      if (syntacticPlaceholders != null && typeof syntacticPlaceholders !== "boolean") {
        throw new Error("'.syntacticPlaceholders' must be a boolean, null, or undefined");
      }
      if (syntacticPlaceholders === true && (placeholderWhitelist != null || placeholderPattern != null)) {
        throw new Error("'.placeholderWhitelist' and '.placeholderPattern' aren't compatible with '.syntacticPlaceholders: true'");
      }
      return {
        parser,
        placeholderWhitelist: placeholderWhitelist || void 0,
        placeholderPattern: placeholderPattern == null ? void 0 : placeholderPattern,
        preserveComments: preserveComments == null ? void 0 : preserveComments,
        syntacticPlaceholders: syntacticPlaceholders == null ? void 0 : syntacticPlaceholders
      };
    }
    function normalizeReplacements(replacements) {
      if (Array.isArray(replacements)) {
        return replacements.reduce((acc, replacement, i) => {
          acc["$" + i] = replacement;
          return acc;
        }, {});
      } else if (typeof replacements === "object" || replacements == null) {
        return replacements || void 0;
      }
      throw new Error("Template replacements must be an array, object, null, or undefined");
    }
  }
});

// node_modules/@babel/template/lib/parse.js
var require_parse = __commonJS({
  "node_modules/@babel/template/lib/parse.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = parseAndBuildMetadata;
    var _t = require_lib11();
    var _parser = require_lib2();
    var _codeFrame = require_lib16();
    var {
      isCallExpression: isCallExpression2,
      isExpressionStatement,
      isFunction,
      isIdentifier: isIdentifier2,
      isJSXIdentifier,
      isNewExpression,
      isPlaceholder,
      isStatement,
      isStringLiteral: isStringLiteral3,
      removePropertiesDeep,
      traverse: traverse3
    } = _t;
    var PATTERN = /^[_$A-Z0-9]+$/;
    function parseAndBuildMetadata(formatter, code, opts) {
      const {
        placeholderWhitelist,
        placeholderPattern,
        preserveComments,
        syntacticPlaceholders
      } = opts;
      const ast = parseWithCodeFrame(code, opts.parser, syntacticPlaceholders);
      removePropertiesDeep(ast, {
        preserveComments
      });
      formatter.validate(ast);
      const syntactic = {
        placeholders: [],
        placeholderNames: /* @__PURE__ */ new Set()
      };
      const legacy = {
        placeholders: [],
        placeholderNames: /* @__PURE__ */ new Set()
      };
      const isLegacyRef = {
        value: void 0
      };
      traverse3(ast, placeholderVisitorHandler, {
        syntactic,
        legacy,
        isLegacyRef,
        placeholderWhitelist,
        placeholderPattern,
        syntacticPlaceholders
      });
      return Object.assign({
        ast
      }, isLegacyRef.value ? legacy : syntactic);
    }
    function placeholderVisitorHandler(node, ancestors, state) {
      var _state$placeholderWhi;
      let name;
      if (isPlaceholder(node)) {
        if (state.syntacticPlaceholders === false) {
          throw new Error("%%foo%%-style placeholders can't be used when '.syntacticPlaceholders' is false.");
        } else {
          name = node.name.name;
          state.isLegacyRef.value = false;
        }
      } else if (state.isLegacyRef.value === false || state.syntacticPlaceholders) {
        return;
      } else if (isIdentifier2(node) || isJSXIdentifier(node)) {
        name = node.name;
        state.isLegacyRef.value = true;
      } else if (isStringLiteral3(node)) {
        name = node.value;
        state.isLegacyRef.value = true;
      } else {
        return;
      }
      if (!state.isLegacyRef.value && (state.placeholderPattern != null || state.placeholderWhitelist != null)) {
        throw new Error("'.placeholderWhitelist' and '.placeholderPattern' aren't compatible with '.syntacticPlaceholders: true'");
      }
      if (state.isLegacyRef.value && (state.placeholderPattern === false || !(state.placeholderPattern || PATTERN).test(name)) && !((_state$placeholderWhi = state.placeholderWhitelist) != null && _state$placeholderWhi.has(name))) {
        return;
      }
      ancestors = ancestors.slice();
      const {
        node: parent,
        key
      } = ancestors[ancestors.length - 1];
      let type;
      if (isStringLiteral3(node) || isPlaceholder(node, {
        expectedNode: "StringLiteral"
      })) {
        type = "string";
      } else if (isNewExpression(parent) && key === "arguments" || isCallExpression2(parent) && key === "arguments" || isFunction(parent) && key === "params") {
        type = "param";
      } else if (isExpressionStatement(parent) && !isPlaceholder(node)) {
        type = "statement";
        ancestors = ancestors.slice(0, -1);
      } else if (isStatement(node) && isPlaceholder(node)) {
        type = "statement";
      } else {
        type = "other";
      }
      const {
        placeholders,
        placeholderNames
      } = state.isLegacyRef.value ? state.legacy : state.syntactic;
      placeholders.push({
        name,
        type,
        resolve: (ast) => resolveAncestors(ast, ancestors),
        isDuplicate: placeholderNames.has(name)
      });
      placeholderNames.add(name);
    }
    function resolveAncestors(ast, ancestors) {
      let parent = ast;
      for (let i = 0; i < ancestors.length - 1; i++) {
        const {
          key: key2,
          index: index2
        } = ancestors[i];
        if (index2 === void 0) {
          parent = parent[key2];
        } else {
          parent = parent[key2][index2];
        }
      }
      const {
        key,
        index
      } = ancestors[ancestors.length - 1];
      return {
        parent,
        key,
        index
      };
    }
    function parseWithCodeFrame(code, parserOpts, syntacticPlaceholders) {
      const plugins = (parserOpts.plugins || []).slice();
      if (syntacticPlaceholders !== false) {
        plugins.push("placeholders");
      }
      parserOpts = Object.assign({
        allowReturnOutsideFunction: true,
        allowSuperOutsideMethod: true,
        sourceType: "module"
      }, parserOpts, {
        plugins
      });
      try {
        return (0, _parser.parse)(code, parserOpts);
      } catch (err) {
        const loc = err.loc;
        if (loc) {
          err.message += "\n" + (0, _codeFrame.codeFrameColumns)(code, {
            start: loc
          });
          err.code = "BABEL_TEMPLATE_PARSE_ERROR";
        }
        throw err;
      }
    }
  }
});

// node_modules/@babel/template/lib/populate.js
var require_populate = __commonJS({
  "node_modules/@babel/template/lib/populate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = populatePlaceholders;
    var _t = require_lib11();
    var {
      blockStatement: blockStatement2,
      cloneNode,
      emptyStatement,
      expressionStatement,
      identifier: identifier3,
      isStatement,
      isStringLiteral: isStringLiteral3,
      stringLiteral: stringLiteral2,
      validate
    } = _t;
    function populatePlaceholders(metadata, replacements) {
      const ast = cloneNode(metadata.ast);
      if (replacements) {
        metadata.placeholders.forEach((placeholder) => {
          if (!Object.prototype.hasOwnProperty.call(replacements, placeholder.name)) {
            const placeholderName = placeholder.name;
            throw new Error(`Error: No substitution given for "${placeholderName}". If this is not meant to be a
            placeholder you may want to consider passing one of the following options to @babel/template:
            - { placeholderPattern: false, placeholderWhitelist: new Set(['${placeholderName}'])}
            - { placeholderPattern: /^${placeholderName}$/ }`);
          }
        });
        Object.keys(replacements).forEach((key) => {
          if (!metadata.placeholderNames.has(key)) {
            throw new Error(`Unknown substitution "${key}" given`);
          }
        });
      }
      metadata.placeholders.slice().reverse().forEach((placeholder) => {
        try {
          applyReplacement(placeholder, ast, replacements && replacements[placeholder.name] || null);
        } catch (e) {
          e.message = `@babel/template placeholder "${placeholder.name}": ${e.message}`;
          throw e;
        }
      });
      return ast;
    }
    function applyReplacement(placeholder, ast, replacement) {
      if (placeholder.isDuplicate) {
        if (Array.isArray(replacement)) {
          replacement = replacement.map((node) => cloneNode(node));
        } else if (typeof replacement === "object") {
          replacement = cloneNode(replacement);
        }
      }
      const {
        parent,
        key,
        index
      } = placeholder.resolve(ast);
      if (placeholder.type === "string") {
        if (typeof replacement === "string") {
          replacement = stringLiteral2(replacement);
        }
        if (!replacement || !isStringLiteral3(replacement)) {
          throw new Error("Expected string substitution");
        }
      } else if (placeholder.type === "statement") {
        if (index === void 0) {
          if (!replacement) {
            replacement = emptyStatement();
          } else if (Array.isArray(replacement)) {
            replacement = blockStatement2(replacement);
          } else if (typeof replacement === "string") {
            replacement = expressionStatement(identifier3(replacement));
          } else if (!isStatement(replacement)) {
            replacement = expressionStatement(replacement);
          }
        } else {
          if (replacement && !Array.isArray(replacement)) {
            if (typeof replacement === "string") {
              replacement = identifier3(replacement);
            }
            if (!isStatement(replacement)) {
              replacement = expressionStatement(replacement);
            }
          }
        }
      } else if (placeholder.type === "param") {
        if (typeof replacement === "string") {
          replacement = identifier3(replacement);
        }
        if (index === void 0)
          throw new Error("Assertion failure.");
      } else {
        if (typeof replacement === "string") {
          replacement = identifier3(replacement);
        }
        if (Array.isArray(replacement)) {
          throw new Error("Cannot replace single expression with an array.");
        }
      }
      if (index === void 0) {
        validate(parent, key, replacement);
        parent[key] = replacement;
      } else {
        const items = parent[key].slice();
        if (placeholder.type === "statement" || placeholder.type === "param") {
          if (replacement == null) {
            items.splice(index, 1);
          } else if (Array.isArray(replacement)) {
            items.splice(index, 1, ...replacement);
          } else {
            items[index] = replacement;
          }
        } else {
          items[index] = replacement;
        }
        validate(parent, key, items);
        parent[key] = items;
      }
    }
  }
});

// node_modules/@babel/template/lib/string.js
var require_string = __commonJS({
  "node_modules/@babel/template/lib/string.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = stringTemplate;
    var _options = require_options();
    var _parse = require_parse();
    var _populate = require_populate();
    function stringTemplate(formatter, code, opts) {
      code = formatter.code(code);
      let metadata;
      return (arg) => {
        const replacements = (0, _options.normalizeReplacements)(arg);
        if (!metadata)
          metadata = (0, _parse.default)(formatter, code, opts);
        return formatter.unwrap((0, _populate.default)(metadata, replacements));
      };
    }
  }
});

// node_modules/@babel/template/lib/literal.js
var require_literal = __commonJS({
  "node_modules/@babel/template/lib/literal.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = literalTemplate;
    var _options = require_options();
    var _parse = require_parse();
    var _populate = require_populate();
    function literalTemplate(formatter, tpl, opts) {
      const {
        metadata,
        names
      } = buildLiteralData(formatter, tpl, opts);
      return (arg) => {
        const defaultReplacements = {};
        arg.forEach((replacement, i) => {
          defaultReplacements[names[i]] = replacement;
        });
        return (arg2) => {
          const replacements = (0, _options.normalizeReplacements)(arg2);
          if (replacements) {
            Object.keys(replacements).forEach((key) => {
              if (Object.prototype.hasOwnProperty.call(defaultReplacements, key)) {
                throw new Error("Unexpected replacement overlap.");
              }
            });
          }
          return formatter.unwrap((0, _populate.default)(metadata, replacements ? Object.assign(replacements, defaultReplacements) : defaultReplacements));
        };
      };
    }
    function buildLiteralData(formatter, tpl, opts) {
      let names;
      let nameSet;
      let metadata;
      let prefix = "";
      do {
        prefix += "$";
        const result = buildTemplateCode(tpl, prefix);
        names = result.names;
        nameSet = new Set(names);
        metadata = (0, _parse.default)(formatter, formatter.code(result.code), {
          parser: opts.parser,
          placeholderWhitelist: new Set(result.names.concat(opts.placeholderWhitelist ? Array.from(opts.placeholderWhitelist) : [])),
          placeholderPattern: opts.placeholderPattern,
          preserveComments: opts.preserveComments,
          syntacticPlaceholders: opts.syntacticPlaceholders
        });
      } while (metadata.placeholders.some((placeholder) => placeholder.isDuplicate && nameSet.has(placeholder.name)));
      return {
        metadata,
        names
      };
    }
    function buildTemplateCode(tpl, prefix) {
      const names = [];
      let code = tpl[0];
      for (let i = 1; i < tpl.length; i++) {
        const value2 = `${prefix}${i - 1}`;
        names.push(value2);
        code += value2 + tpl[i];
      }
      return {
        names,
        code
      };
    }
  }
});

// node_modules/@babel/template/lib/builder.js
var require_builder = __commonJS({
  "node_modules/@babel/template/lib/builder.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = createTemplateBuilder;
    var _options = require_options();
    var _string = require_string();
    var _literal = require_literal();
    var NO_PLACEHOLDER = (0, _options.validate)({
      placeholderPattern: false
    });
    function createTemplateBuilder(formatter, defaultOpts) {
      const templateFnCache = /* @__PURE__ */ new WeakMap();
      const templateAstCache = /* @__PURE__ */ new WeakMap();
      const cachedOpts = defaultOpts || (0, _options.validate)(null);
      return Object.assign((tpl, ...args) => {
        if (typeof tpl === "string") {
          if (args.length > 1)
            throw new Error("Unexpected extra params.");
          return extendedTrace((0, _string.default)(formatter, tpl, (0, _options.merge)(cachedOpts, (0, _options.validate)(args[0]))));
        } else if (Array.isArray(tpl)) {
          let builder = templateFnCache.get(tpl);
          if (!builder) {
            builder = (0, _literal.default)(formatter, tpl, cachedOpts);
            templateFnCache.set(tpl, builder);
          }
          return extendedTrace(builder(args));
        } else if (typeof tpl === "object" && tpl) {
          if (args.length > 0)
            throw new Error("Unexpected extra params.");
          return createTemplateBuilder(formatter, (0, _options.merge)(cachedOpts, (0, _options.validate)(tpl)));
        }
        throw new Error(`Unexpected template param ${typeof tpl}`);
      }, {
        ast: (tpl, ...args) => {
          if (typeof tpl === "string") {
            if (args.length > 1)
              throw new Error("Unexpected extra params.");
            return (0, _string.default)(formatter, tpl, (0, _options.merge)((0, _options.merge)(cachedOpts, (0, _options.validate)(args[0])), NO_PLACEHOLDER))();
          } else if (Array.isArray(tpl)) {
            let builder = templateAstCache.get(tpl);
            if (!builder) {
              builder = (0, _literal.default)(formatter, tpl, (0, _options.merge)(cachedOpts, NO_PLACEHOLDER));
              templateAstCache.set(tpl, builder);
            }
            return builder(args)();
          }
          throw new Error(`Unexpected template param ${typeof tpl}`);
        }
      });
    }
    function extendedTrace(fn) {
      let rootStack = "";
      try {
        throw new Error();
      } catch (error) {
        if (error.stack) {
          rootStack = error.stack.split("\n").slice(3).join("\n");
        }
      }
      return (arg) => {
        try {
          return fn(arg);
        } catch (err) {
          err.stack += `
    =============
${rootStack}`;
          throw err;
        }
      };
    }
  }
});

// node_modules/@babel/template/lib/index.js
var require_lib18 = __commonJS({
  "node_modules/@babel/template/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.statements = exports.statement = exports.smart = exports.program = exports.expression = exports.default = void 0;
    var formatters = require_formatters();
    var _builder = require_builder();
    var smart = (0, _builder.default)(formatters.smart);
    exports.smart = smart;
    var statement = (0, _builder.default)(formatters.statement);
    exports.statement = statement;
    var statements = (0, _builder.default)(formatters.statements);
    exports.statements = statements;
    var expression = (0, _builder.default)(formatters.expression);
    exports.expression = expression;
    var program2 = (0, _builder.default)(formatters.program);
    exports.program = program2;
    var _default = Object.assign(smart.bind(void 0), {
      smart,
      statement,
      statements,
      expression,
      program: program2,
      ast: smart.ast
    });
    exports.default = _default;
  }
});

// node_modules/@babel/helper-function-name/lib/index.js
var require_lib19 = __commonJS({
  "node_modules/@babel/helper-function-name/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;
    var _template = require_lib18();
    var _t = require_lib11();
    var {
      NOT_LOCAL_BINDING,
      cloneNode,
      identifier: identifier3,
      isAssignmentExpression,
      isAssignmentPattern,
      isFunction,
      isIdentifier: isIdentifier2,
      isLiteral,
      isNullLiteral,
      isObjectMethod,
      isObjectProperty,
      isRegExpLiteral,
      isRestElement,
      isTemplateLiteral,
      isVariableDeclarator: isVariableDeclarator2,
      toBindingIdentifierName
    } = _t;
    function getFunctionArity(node) {
      const count = node.params.findIndex((param) => isAssignmentPattern(param) || isRestElement(param));
      return count === -1 ? node.params.length : count;
    }
    var buildPropertyMethodAssignmentWrapper = _template.default.statement(`
  (function (FUNCTION_KEY) {
    function FUNCTION_ID() {
      return FUNCTION_KEY.apply(this, arguments);
    }

    FUNCTION_ID.toString = function () {
      return FUNCTION_KEY.toString();
    }

    return FUNCTION_ID;
  })(FUNCTION)
`);
    var buildGeneratorPropertyMethodAssignmentWrapper = _template.default.statement(`
  (function (FUNCTION_KEY) {
    function* FUNCTION_ID() {
      return yield* FUNCTION_KEY.apply(this, arguments);
    }

    FUNCTION_ID.toString = function () {
      return FUNCTION_KEY.toString();
    };

    return FUNCTION_ID;
  })(FUNCTION)
`);
    var visitor = {
      "ReferencedIdentifier|BindingIdentifier"(path2, state) {
        if (path2.node.name !== state.name)
          return;
        const localDeclar = path2.scope.getBindingIdentifier(state.name);
        if (localDeclar !== state.outerDeclar)
          return;
        state.selfReference = true;
        path2.stop();
      }
    };
    function getNameFromLiteralId(id) {
      if (isNullLiteral(id)) {
        return "null";
      }
      if (isRegExpLiteral(id)) {
        return `_${id.pattern}_${id.flags}`;
      }
      if (isTemplateLiteral(id)) {
        return id.quasis.map((quasi) => quasi.value.raw).join("");
      }
      if (id.value !== void 0) {
        return id.value + "";
      }
      return "";
    }
    function wrap(state, method, id, scope) {
      if (state.selfReference) {
        if (scope.hasBinding(id.name) && !scope.hasGlobal(id.name)) {
          scope.rename(id.name);
        } else {
          if (!isFunction(method))
            return;
          let build = buildPropertyMethodAssignmentWrapper;
          if (method.generator) {
            build = buildGeneratorPropertyMethodAssignmentWrapper;
          }
          const template = build({
            FUNCTION: method,
            FUNCTION_ID: id,
            FUNCTION_KEY: scope.generateUidIdentifier(id.name)
          }).expression;
          const params = template.callee.body.body[0].params;
          for (let i = 0, len = getFunctionArity(method); i < len; i++) {
            params.push(scope.generateUidIdentifier("x"));
          }
          return template;
        }
      }
      method.id = id;
      scope.getProgramParent().references[id.name] = true;
    }
    function visit(node, name, scope) {
      const state = {
        selfAssignment: false,
        selfReference: false,
        outerDeclar: scope.getBindingIdentifier(name),
        name
      };
      const binding = scope.getOwnBinding(name);
      if (binding) {
        if (binding.kind === "param") {
          state.selfReference = true;
        } else {
        }
      } else if (state.outerDeclar || scope.hasGlobal(name)) {
        scope.traverse(node, visitor, state);
      }
      return state;
    }
    function _default({
      node,
      parent,
      scope,
      id
    }, localBinding = false, supportUnicodeId = false) {
      if (node.id)
        return;
      if ((isObjectProperty(parent) || isObjectMethod(parent, {
        kind: "method"
      })) && (!parent.computed || isLiteral(parent.key))) {
        id = parent.key;
      } else if (isVariableDeclarator2(parent)) {
        id = parent.id;
        if (isIdentifier2(id) && !localBinding) {
          const binding = scope.parent.getBinding(id.name);
          if (binding && binding.constant && scope.getBinding(id.name) === binding) {
            node.id = cloneNode(id);
            node.id[NOT_LOCAL_BINDING] = true;
            return;
          }
        }
      } else if (isAssignmentExpression(parent, {
        operator: "="
      })) {
        id = parent.left;
      } else if (!id) {
        return;
      }
      let name;
      if (id && isLiteral(id)) {
        name = getNameFromLiteralId(id);
      } else if (id && isIdentifier2(id)) {
        name = id.name;
      }
      if (name === void 0) {
        return;
      }
      if (!supportUnicodeId && isFunction(node) && /[\uD800-\uDFFF]/.test(name)) {
        return;
      }
      name = toBindingIdentifierName(name);
      const newId = identifier3(name);
      newId[NOT_LOCAL_BINDING] = true;
      const state = visit(node, name, scope);
      return wrap(state, node, newId, scope) || node;
    }
  }
});

// node_modules/@babel/traverse/lib/path/conversion.js
var require_conversion = __commonJS({
  "node_modules/@babel/traverse/lib/path/conversion.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.arrowFunctionToExpression = arrowFunctionToExpression;
    exports.arrowFunctionToShadowed = arrowFunctionToShadowed;
    exports.ensureBlock = ensureBlock;
    exports.toComputedKey = toComputedKey;
    exports.unwrapFunctionEnvironment = unwrapFunctionEnvironment;
    var _t = require_lib11();
    var _helperEnvironmentVisitor = require_lib13();
    var _helperFunctionName = require_lib19();
    var _visitors = require_visitors();
    var {
      arrowFunctionExpression,
      assignmentExpression,
      binaryExpression,
      blockStatement: blockStatement2,
      callExpression: callExpression3,
      conditionalExpression,
      expressionStatement,
      identifier: identifier3,
      isIdentifier: isIdentifier2,
      jsxIdentifier,
      logicalExpression,
      LOGICAL_OPERATORS,
      memberExpression,
      metaProperty,
      numericLiteral,
      objectExpression,
      restElement,
      returnStatement: returnStatement2,
      sequenceExpression,
      spreadElement,
      stringLiteral: stringLiteral2,
      super: _super,
      thisExpression,
      toExpression,
      unaryExpression
    } = _t;
    function toComputedKey() {
      let key;
      if (this.isMemberExpression()) {
        key = this.node.property;
      } else if (this.isProperty() || this.isMethod()) {
        key = this.node.key;
      } else {
        throw new ReferenceError("todo");
      }
      if (!this.node.computed) {
        if (isIdentifier2(key))
          key = stringLiteral2(key.name);
      }
      return key;
    }
    function ensureBlock() {
      const body = this.get("body");
      const bodyNode = body.node;
      if (Array.isArray(body)) {
        throw new Error("Can't convert array path to a block statement");
      }
      if (!bodyNode) {
        throw new Error("Can't convert node without a body");
      }
      if (body.isBlockStatement()) {
        return bodyNode;
      }
      const statements = [];
      let stringPath = "body";
      let key;
      let listKey;
      if (body.isStatement()) {
        listKey = "body";
        key = 0;
        statements.push(body.node);
      } else {
        stringPath += ".body.0";
        if (this.isFunction()) {
          key = "argument";
          statements.push(returnStatement2(body.node));
        } else {
          key = "expression";
          statements.push(expressionStatement(body.node));
        }
      }
      this.node.body = blockStatement2(statements);
      const parentPath = this.get(stringPath);
      body.setup(parentPath, listKey ? parentPath.node[listKey] : parentPath.node, listKey, key);
      return this.node;
    }
    function arrowFunctionToShadowed() {
      if (!this.isArrowFunctionExpression())
        return;
      this.arrowFunctionToExpression();
    }
    function unwrapFunctionEnvironment() {
      if (!this.isArrowFunctionExpression() && !this.isFunctionExpression() && !this.isFunctionDeclaration()) {
        throw this.buildCodeFrameError("Can only unwrap the environment of a function.");
      }
      hoistFunctionEnvironment(this);
    }
    function setType(path2, type) {
      path2.node.type = type;
    }
    function arrowFunctionToExpression({
      allowInsertArrow = true,
      allowInsertArrowWithRest = allowInsertArrow,
      specCompliant = false,
      noNewArrows = !specCompliant
    } = {}) {
      if (!this.isArrowFunctionExpression()) {
        throw this.buildCodeFrameError("Cannot convert non-arrow function to a function expression.");
      }
      const {
        thisBinding,
        fnPath: fn
      } = hoistFunctionEnvironment(this, noNewArrows, allowInsertArrow, allowInsertArrowWithRest);
      fn.ensureBlock();
      setType(fn, "FunctionExpression");
      if (!noNewArrows) {
        const checkBinding = thisBinding ? null : fn.scope.generateUidIdentifier("arrowCheckId");
        if (checkBinding) {
          fn.parentPath.scope.push({
            id: checkBinding,
            init: objectExpression([])
          });
        }
        fn.get("body").unshiftContainer("body", expressionStatement(callExpression3(this.hub.addHelper("newArrowCheck"), [thisExpression(), checkBinding ? identifier3(checkBinding.name) : identifier3(thisBinding)])));
        fn.replaceWith(callExpression3(memberExpression((0, _helperFunctionName.default)(this, true) || fn.node, identifier3("bind")), [checkBinding ? identifier3(checkBinding.name) : thisExpression()]));
        return fn.get("callee.object");
      }
      return fn;
    }
    var getSuperCallsVisitor = (0, _visitors.merge)([{
      CallExpression(child, {
        allSuperCalls
      }) {
        if (!child.get("callee").isSuper())
          return;
        allSuperCalls.push(child);
      }
    }, _helperEnvironmentVisitor.default]);
    function hoistFunctionEnvironment(fnPath, noNewArrows = true, allowInsertArrow = true, allowInsertArrowWithRest = true) {
      let arrowParent;
      let thisEnvFn = fnPath.findParent((p) => {
        if (p.isArrowFunctionExpression()) {
          var _arrowParent;
          (_arrowParent = arrowParent) != null ? _arrowParent : arrowParent = p;
          return false;
        }
        return p.isFunction() || p.isProgram() || p.isClassProperty({
          static: false
        }) || p.isClassPrivateProperty({
          static: false
        });
      });
      const inConstructor = thisEnvFn.isClassMethod({
        kind: "constructor"
      });
      if (thisEnvFn.isClassProperty() || thisEnvFn.isClassPrivateProperty()) {
        if (arrowParent) {
          thisEnvFn = arrowParent;
        } else if (allowInsertArrow) {
          fnPath.replaceWith(callExpression3(arrowFunctionExpression([], toExpression(fnPath.node)), []));
          thisEnvFn = fnPath.get("callee");
          fnPath = thisEnvFn.get("body");
        } else {
          throw fnPath.buildCodeFrameError("Unable to transform arrow inside class property");
        }
      }
      const {
        thisPaths,
        argumentsPaths,
        newTargetPaths,
        superProps,
        superCalls
      } = getScopeInformation(fnPath);
      if (inConstructor && superCalls.length > 0) {
        if (!allowInsertArrow) {
          throw superCalls[0].buildCodeFrameError("When using '@babel/plugin-transform-arrow-functions', it's not possible to compile `super()` in an arrow function without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
        }
        if (!allowInsertArrowWithRest) {
          throw superCalls[0].buildCodeFrameError("When using '@babel/plugin-transform-parameters', it's not possible to compile `super()` in an arrow function with default or rest parameters without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
        }
        const allSuperCalls = [];
        thisEnvFn.traverse(getSuperCallsVisitor, {
          allSuperCalls
        });
        const superBinding = getSuperBinding(thisEnvFn);
        allSuperCalls.forEach((superCall) => {
          const callee = identifier3(superBinding);
          callee.loc = superCall.node.callee.loc;
          superCall.get("callee").replaceWith(callee);
        });
      }
      if (argumentsPaths.length > 0) {
        const argumentsBinding = getBinding(thisEnvFn, "arguments", () => {
          const args = () => identifier3("arguments");
          if (thisEnvFn.scope.path.isProgram()) {
            return conditionalExpression(binaryExpression("===", unaryExpression("typeof", args()), stringLiteral2("undefined")), thisEnvFn.scope.buildUndefinedNode(), args());
          } else {
            return args();
          }
        });
        argumentsPaths.forEach((argumentsChild) => {
          const argsRef = identifier3(argumentsBinding);
          argsRef.loc = argumentsChild.node.loc;
          argumentsChild.replaceWith(argsRef);
        });
      }
      if (newTargetPaths.length > 0) {
        const newTargetBinding = getBinding(thisEnvFn, "newtarget", () => metaProperty(identifier3("new"), identifier3("target")));
        newTargetPaths.forEach((targetChild) => {
          const targetRef = identifier3(newTargetBinding);
          targetRef.loc = targetChild.node.loc;
          targetChild.replaceWith(targetRef);
        });
      }
      if (superProps.length > 0) {
        if (!allowInsertArrow) {
          throw superProps[0].buildCodeFrameError("When using '@babel/plugin-transform-arrow-functions', it's not possible to compile `super.prop` in an arrow function without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
        }
        const flatSuperProps = superProps.reduce((acc, superProp) => acc.concat(standardizeSuperProperty(superProp)), []);
        flatSuperProps.forEach((superProp) => {
          const key = superProp.node.computed ? "" : superProp.get("property").node.name;
          const superParentPath = superProp.parentPath;
          const isAssignment = superParentPath.isAssignmentExpression({
            left: superProp.node
          });
          const isCall = superParentPath.isCallExpression({
            callee: superProp.node
          });
          const isTaggedTemplate = superParentPath.isTaggedTemplateExpression({
            tag: superProp.node
          });
          const superBinding = getSuperPropBinding(thisEnvFn, isAssignment, key);
          const args = [];
          if (superProp.node.computed) {
            args.push(superProp.get("property").node);
          }
          if (isAssignment) {
            const value2 = superParentPath.node.right;
            args.push(value2);
          }
          const call = callExpression3(identifier3(superBinding), args);
          if (isCall) {
            superParentPath.unshiftContainer("arguments", thisExpression());
            superProp.replaceWith(memberExpression(call, identifier3("call")));
            thisPaths.push(superParentPath.get("arguments.0"));
          } else if (isAssignment) {
            superParentPath.replaceWith(call);
          } else if (isTaggedTemplate) {
            superProp.replaceWith(callExpression3(memberExpression(call, identifier3("bind"), false), [thisExpression()]));
            thisPaths.push(superProp.get("arguments.0"));
          } else {
            superProp.replaceWith(call);
          }
        });
      }
      let thisBinding;
      if (thisPaths.length > 0 || !noNewArrows) {
        thisBinding = getThisBinding(thisEnvFn, inConstructor);
        if (noNewArrows || inConstructor && hasSuperClass(thisEnvFn)) {
          thisPaths.forEach((thisChild) => {
            const thisRef = thisChild.isJSX() ? jsxIdentifier(thisBinding) : identifier3(thisBinding);
            thisRef.loc = thisChild.node.loc;
            thisChild.replaceWith(thisRef);
          });
          if (!noNewArrows)
            thisBinding = null;
        }
      }
      return {
        thisBinding,
        fnPath
      };
    }
    function isLogicalOp(op) {
      return LOGICAL_OPERATORS.includes(op);
    }
    function standardizeSuperProperty(superProp) {
      if (superProp.parentPath.isAssignmentExpression() && superProp.parentPath.node.operator !== "=") {
        const assignmentPath = superProp.parentPath;
        const op = assignmentPath.node.operator.slice(0, -1);
        const value2 = assignmentPath.node.right;
        const isLogicalAssignment = isLogicalOp(op);
        if (superProp.node.computed) {
          const tmp = superProp.scope.generateDeclaredUidIdentifier("tmp");
          const object = superProp.node.object;
          const property = superProp.node.property;
          assignmentPath.get("left").replaceWith(memberExpression(object, assignmentExpression("=", tmp, property), true));
          assignmentPath.get("right").replaceWith(rightExpression(isLogicalAssignment ? "=" : op, memberExpression(object, identifier3(tmp.name), true), value2));
        } else {
          const object = superProp.node.object;
          const property = superProp.node.property;
          assignmentPath.get("left").replaceWith(memberExpression(object, property));
          assignmentPath.get("right").replaceWith(rightExpression(isLogicalAssignment ? "=" : op, memberExpression(object, identifier3(property.name)), value2));
        }
        if (isLogicalAssignment) {
          assignmentPath.replaceWith(logicalExpression(op, assignmentPath.node.left, assignmentPath.node.right));
        } else {
          assignmentPath.node.operator = "=";
        }
        return [assignmentPath.get("left"), assignmentPath.get("right").get("left")];
      } else if (superProp.parentPath.isUpdateExpression()) {
        const updateExpr = superProp.parentPath;
        const tmp = superProp.scope.generateDeclaredUidIdentifier("tmp");
        const computedKey = superProp.node.computed ? superProp.scope.generateDeclaredUidIdentifier("prop") : null;
        const parts = [assignmentExpression("=", tmp, memberExpression(superProp.node.object, computedKey ? assignmentExpression("=", computedKey, superProp.node.property) : superProp.node.property, superProp.node.computed)), assignmentExpression("=", memberExpression(superProp.node.object, computedKey ? identifier3(computedKey.name) : superProp.node.property, superProp.node.computed), binaryExpression(superProp.parentPath.node.operator[0], identifier3(tmp.name), numericLiteral(1)))];
        if (!superProp.parentPath.node.prefix) {
          parts.push(identifier3(tmp.name));
        }
        updateExpr.replaceWith(sequenceExpression(parts));
        const left = updateExpr.get("expressions.0.right");
        const right = updateExpr.get("expressions.1.left");
        return [left, right];
      }
      return [superProp];
      function rightExpression(op, left, right) {
        if (op === "=") {
          return assignmentExpression("=", left, right);
        } else {
          return binaryExpression(op, left, right);
        }
      }
    }
    function hasSuperClass(thisEnvFn) {
      return thisEnvFn.isClassMethod() && !!thisEnvFn.parentPath.parentPath.node.superClass;
    }
    var assignSuperThisVisitor = (0, _visitors.merge)([{
      CallExpression(child, {
        supers,
        thisBinding
      }) {
        if (!child.get("callee").isSuper())
          return;
        if (supers.has(child.node))
          return;
        supers.add(child.node);
        child.replaceWithMultiple([child.node, assignmentExpression("=", identifier3(thisBinding), identifier3("this"))]);
      }
    }, _helperEnvironmentVisitor.default]);
    function getThisBinding(thisEnvFn, inConstructor) {
      return getBinding(thisEnvFn, "this", (thisBinding) => {
        if (!inConstructor || !hasSuperClass(thisEnvFn))
          return thisExpression();
        thisEnvFn.traverse(assignSuperThisVisitor, {
          supers: /* @__PURE__ */ new WeakSet(),
          thisBinding
        });
      });
    }
    function getSuperBinding(thisEnvFn) {
      return getBinding(thisEnvFn, "supercall", () => {
        const argsBinding = thisEnvFn.scope.generateUidIdentifier("args");
        return arrowFunctionExpression([restElement(argsBinding)], callExpression3(_super(), [spreadElement(identifier3(argsBinding.name))]));
      });
    }
    function getSuperPropBinding(thisEnvFn, isAssignment, propName) {
      const op = isAssignment ? "set" : "get";
      return getBinding(thisEnvFn, `superprop_${op}:${propName || ""}`, () => {
        const argsList = [];
        let fnBody;
        if (propName) {
          fnBody = memberExpression(_super(), identifier3(propName));
        } else {
          const method = thisEnvFn.scope.generateUidIdentifier("prop");
          argsList.unshift(method);
          fnBody = memberExpression(_super(), identifier3(method.name), true);
        }
        if (isAssignment) {
          const valueIdent = thisEnvFn.scope.generateUidIdentifier("value");
          argsList.push(valueIdent);
          fnBody = assignmentExpression("=", fnBody, identifier3(valueIdent.name));
        }
        return arrowFunctionExpression(argsList, fnBody);
      });
    }
    function getBinding(thisEnvFn, key, init) {
      const cacheKey = "binding:" + key;
      let data = thisEnvFn.getData(cacheKey);
      if (!data) {
        const id = thisEnvFn.scope.generateUidIdentifier(key);
        data = id.name;
        thisEnvFn.setData(cacheKey, data);
        thisEnvFn.scope.push({
          id,
          init: init(data)
        });
      }
      return data;
    }
    var getScopeInformationVisitor = (0, _visitors.merge)([{
      ThisExpression(child, {
        thisPaths
      }) {
        thisPaths.push(child);
      },
      JSXIdentifier(child, {
        thisPaths
      }) {
        if (child.node.name !== "this")
          return;
        if (!child.parentPath.isJSXMemberExpression({
          object: child.node
        }) && !child.parentPath.isJSXOpeningElement({
          name: child.node
        })) {
          return;
        }
        thisPaths.push(child);
      },
      CallExpression(child, {
        superCalls
      }) {
        if (child.get("callee").isSuper())
          superCalls.push(child);
      },
      MemberExpression(child, {
        superProps
      }) {
        if (child.get("object").isSuper())
          superProps.push(child);
      },
      Identifier(child, {
        argumentsPaths
      }) {
        if (!child.isReferencedIdentifier({
          name: "arguments"
        }))
          return;
        let curr = child.scope;
        do {
          if (curr.hasOwnBinding("arguments")) {
            curr.rename("arguments");
            return;
          }
          if (curr.path.isFunction() && !curr.path.isArrowFunctionExpression()) {
            break;
          }
        } while (curr = curr.parent);
        argumentsPaths.push(child);
      },
      MetaProperty(child, {
        newTargetPaths
      }) {
        if (!child.get("meta").isIdentifier({
          name: "new"
        }))
          return;
        if (!child.get("property").isIdentifier({
          name: "target"
        }))
          return;
        newTargetPaths.push(child);
      }
    }, _helperEnvironmentVisitor.default]);
    function getScopeInformation(fnPath) {
      const thisPaths = [];
      const argumentsPaths = [];
      const newTargetPaths = [];
      const superProps = [];
      const superCalls = [];
      fnPath.traverse(getScopeInformationVisitor, {
        thisPaths,
        argumentsPaths,
        newTargetPaths,
        superProps,
        superCalls
      });
      return {
        thisPaths,
        argumentsPaths,
        newTargetPaths,
        superProps,
        superCalls
      };
    }
  }
});

// node_modules/@babel/traverse/lib/path/introspection.js
var require_introspection = __commonJS({
  "node_modules/@babel/traverse/lib/path/introspection.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._guessExecutionStatusRelativeTo = _guessExecutionStatusRelativeTo;
    exports._resolve = _resolve;
    exports.canHaveVariableDeclarationOrExpression = canHaveVariableDeclarationOrExpression;
    exports.canSwapBetweenExpressionAndStatement = canSwapBetweenExpressionAndStatement;
    exports.equals = equals;
    exports.getSource = getSource;
    exports.has = has;
    exports.is = void 0;
    exports.isCompletionRecord = isCompletionRecord;
    exports.isConstantExpression = isConstantExpression;
    exports.isInStrictMode = isInStrictMode;
    exports.isNodeType = isNodeType;
    exports.isStatementOrBlock = isStatementOrBlock;
    exports.isStatic = isStatic;
    exports.isnt = isnt;
    exports.matchesPattern = matchesPattern;
    exports.referencesImport = referencesImport;
    exports.resolve = resolve;
    exports.willIMaybeExecuteBefore = willIMaybeExecuteBefore;
    var _t = require_lib11();
    var {
      STATEMENT_OR_BLOCK_KEYS,
      VISITOR_KEYS,
      isBlockStatement: isBlockStatement2,
      isExpression: isExpression2,
      isIdentifier: isIdentifier2,
      isLiteral,
      isStringLiteral: isStringLiteral3,
      isType,
      matchesPattern: _matchesPattern
    } = _t;
    function matchesPattern(pattern, allowPartial) {
      return _matchesPattern(this.node, pattern, allowPartial);
    }
    function has(key) {
      const val = this.node && this.node[key];
      if (val && Array.isArray(val)) {
        return !!val.length;
      } else {
        return !!val;
      }
    }
    function isStatic() {
      return this.scope.isStatic(this.node);
    }
    var is = has;
    exports.is = is;
    function isnt(key) {
      return !this.has(key);
    }
    function equals(key, value2) {
      return this.node[key] === value2;
    }
    function isNodeType(type) {
      return isType(this.type, type);
    }
    function canHaveVariableDeclarationOrExpression() {
      return (this.key === "init" || this.key === "left") && this.parentPath.isFor();
    }
    function canSwapBetweenExpressionAndStatement(replacement) {
      if (this.key !== "body" || !this.parentPath.isArrowFunctionExpression()) {
        return false;
      }
      if (this.isExpression()) {
        return isBlockStatement2(replacement);
      } else if (this.isBlockStatement()) {
        return isExpression2(replacement);
      }
      return false;
    }
    function isCompletionRecord(allowInsideFunction) {
      let path2 = this;
      let first2 = true;
      do {
        const {
          type,
          container
        } = path2;
        if (!first2 && (path2.isFunction() || type === "StaticBlock")) {
          return !!allowInsideFunction;
        }
        first2 = false;
        if (Array.isArray(container) && path2.key !== container.length - 1) {
          return false;
        }
      } while ((path2 = path2.parentPath) && !path2.isProgram() && !path2.isDoExpression());
      return true;
    }
    function isStatementOrBlock() {
      if (this.parentPath.isLabeledStatement() || isBlockStatement2(this.container)) {
        return false;
      } else {
        return STATEMENT_OR_BLOCK_KEYS.includes(this.key);
      }
    }
    function referencesImport(moduleSource, importName) {
      if (!this.isReferencedIdentifier()) {
        if (this.isJSXMemberExpression() && this.node.property.name === importName || (this.isMemberExpression() || this.isOptionalMemberExpression()) && (this.node.computed ? isStringLiteral3(this.node.property, {
          value: importName
        }) : this.node.property.name === importName)) {
          const object = this.get("object");
          return object.isReferencedIdentifier() && object.referencesImport(moduleSource, "*");
        }
        return false;
      }
      const binding = this.scope.getBinding(this.node.name);
      if (!binding || binding.kind !== "module")
        return false;
      const path2 = binding.path;
      const parent = path2.parentPath;
      if (!parent.isImportDeclaration())
        return false;
      if (parent.node.source.value === moduleSource) {
        if (!importName)
          return true;
      } else {
        return false;
      }
      if (path2.isImportDefaultSpecifier() && importName === "default") {
        return true;
      }
      if (path2.isImportNamespaceSpecifier() && importName === "*") {
        return true;
      }
      if (path2.isImportSpecifier() && isIdentifier2(path2.node.imported, {
        name: importName
      })) {
        return true;
      }
      return false;
    }
    function getSource() {
      const node = this.node;
      if (node.end) {
        const code = this.hub.getCode();
        if (code)
          return code.slice(node.start, node.end);
      }
      return "";
    }
    function willIMaybeExecuteBefore(target) {
      return this._guessExecutionStatusRelativeTo(target) !== "after";
    }
    function getOuterFunction(path2) {
      return path2.isProgram() ? path2 : (path2.parentPath.scope.getFunctionParent() || path2.parentPath.scope.getProgramParent()).path;
    }
    function isExecutionUncertain(type, key) {
      switch (type) {
        case "LogicalExpression":
          return key === "right";
        case "ConditionalExpression":
        case "IfStatement":
          return key === "consequent" || key === "alternate";
        case "WhileStatement":
        case "DoWhileStatement":
        case "ForInStatement":
        case "ForOfStatement":
          return key === "body";
        case "ForStatement":
          return key === "body" || key === "update";
        case "SwitchStatement":
          return key === "cases";
        case "TryStatement":
          return key === "handler";
        case "AssignmentPattern":
          return key === "right";
        case "OptionalMemberExpression":
          return key === "property";
        case "OptionalCallExpression":
          return key === "arguments";
        default:
          return false;
      }
    }
    function isExecutionUncertainInList(paths, maxIndex) {
      for (let i = 0; i < maxIndex; i++) {
        const path2 = paths[i];
        if (isExecutionUncertain(path2.parent.type, path2.parentKey)) {
          return true;
        }
      }
      return false;
    }
    var SYMBOL_CHECKING = Symbol();
    function _guessExecutionStatusRelativeTo(target) {
      return _guessExecutionStatusRelativeToCached(this, target, /* @__PURE__ */ new Map());
    }
    function _guessExecutionStatusRelativeToCached(base, target, cache) {
      const funcParent = {
        this: getOuterFunction(base),
        target: getOuterFunction(target)
      };
      if (funcParent.target.node !== funcParent.this.node) {
        return _guessExecutionStatusRelativeToDifferentFunctionsCached(base, funcParent.target, cache);
      }
      const paths = {
        target: target.getAncestry(),
        this: base.getAncestry()
      };
      if (paths.target.indexOf(base) >= 0)
        return "after";
      if (paths.this.indexOf(target) >= 0)
        return "before";
      let commonPath;
      const commonIndex = {
        target: 0,
        this: 0
      };
      while (!commonPath && commonIndex.this < paths.this.length) {
        const path2 = paths.this[commonIndex.this];
        commonIndex.target = paths.target.indexOf(path2);
        if (commonIndex.target >= 0) {
          commonPath = path2;
        } else {
          commonIndex.this++;
        }
      }
      if (!commonPath) {
        throw new Error("Internal Babel error - The two compared nodes don't appear to belong to the same program.");
      }
      if (isExecutionUncertainInList(paths.this, commonIndex.this - 1) || isExecutionUncertainInList(paths.target, commonIndex.target - 1)) {
        return "unknown";
      }
      const divergence = {
        this: paths.this[commonIndex.this - 1],
        target: paths.target[commonIndex.target - 1]
      };
      if (divergence.target.listKey && divergence.this.listKey && divergence.target.container === divergence.this.container) {
        return divergence.target.key > divergence.this.key ? "before" : "after";
      }
      const keys3 = VISITOR_KEYS[commonPath.type];
      const keyPosition = {
        this: keys3.indexOf(divergence.this.parentKey),
        target: keys3.indexOf(divergence.target.parentKey)
      };
      return keyPosition.target > keyPosition.this ? "before" : "after";
    }
    function _guessExecutionStatusRelativeToDifferentFunctionsInternal(base, target, cache) {
      if (!target.isFunctionDeclaration()) {
        if (_guessExecutionStatusRelativeToCached(base, target, cache) === "before") {
          return "before";
        }
        return "unknown";
      } else if (target.parentPath.isExportDeclaration()) {
        return "unknown";
      }
      const binding = target.scope.getBinding(target.node.id.name);
      if (!binding.references)
        return "before";
      const referencePaths = binding.referencePaths;
      let allStatus;
      for (const path2 of referencePaths) {
        const childOfFunction = !!path2.find((path3) => path3.node === target.node);
        if (childOfFunction)
          continue;
        if (path2.key !== "callee" || !path2.parentPath.isCallExpression()) {
          return "unknown";
        }
        const status = _guessExecutionStatusRelativeToCached(base, path2, cache);
        if (allStatus && allStatus !== status) {
          return "unknown";
        } else {
          allStatus = status;
        }
      }
      return allStatus;
    }
    function _guessExecutionStatusRelativeToDifferentFunctionsCached(base, target, cache) {
      let nodeMap = cache.get(base.node);
      let cached;
      if (!nodeMap) {
        cache.set(base.node, nodeMap = /* @__PURE__ */ new Map());
      } else if (cached = nodeMap.get(target.node)) {
        if (cached === SYMBOL_CHECKING) {
          return "unknown";
        }
        return cached;
      }
      nodeMap.set(target.node, SYMBOL_CHECKING);
      const result = _guessExecutionStatusRelativeToDifferentFunctionsInternal(base, target, cache);
      nodeMap.set(target.node, result);
      return result;
    }
    function resolve(dangerous, resolved) {
      return this._resolve(dangerous, resolved) || this;
    }
    function _resolve(dangerous, resolved) {
      if (resolved && resolved.indexOf(this) >= 0)
        return;
      resolved = resolved || [];
      resolved.push(this);
      if (this.isVariableDeclarator()) {
        if (this.get("id").isIdentifier()) {
          return this.get("init").resolve(dangerous, resolved);
        } else {
        }
      } else if (this.isReferencedIdentifier()) {
        const binding = this.scope.getBinding(this.node.name);
        if (!binding)
          return;
        if (!binding.constant)
          return;
        if (binding.kind === "module")
          return;
        if (binding.path !== this) {
          const ret = binding.path.resolve(dangerous, resolved);
          if (this.find((parent) => parent.node === ret.node))
            return;
          return ret;
        }
      } else if (this.isTypeCastExpression()) {
        return this.get("expression").resolve(dangerous, resolved);
      } else if (dangerous && this.isMemberExpression()) {
        const targetKey = this.toComputedKey();
        if (!isLiteral(targetKey))
          return;
        const targetName = targetKey.value;
        const target = this.get("object").resolve(dangerous, resolved);
        if (target.isObjectExpression()) {
          const props = target.get("properties");
          for (const prop of props) {
            if (!prop.isProperty())
              continue;
            const key = prop.get("key");
            let match = prop.isnt("computed") && key.isIdentifier({
              name: targetName
            });
            match = match || key.isLiteral({
              value: targetName
            });
            if (match)
              return prop.get("value").resolve(dangerous, resolved);
          }
        } else if (target.isArrayExpression() && !isNaN(+targetName)) {
          const elems = target.get("elements");
          const elem = elems[targetName];
          if (elem)
            return elem.resolve(dangerous, resolved);
        }
      }
    }
    function isConstantExpression() {
      if (this.isIdentifier()) {
        const binding = this.scope.getBinding(this.node.name);
        if (!binding)
          return false;
        return binding.constant;
      }
      if (this.isLiteral()) {
        if (this.isRegExpLiteral()) {
          return false;
        }
        if (this.isTemplateLiteral()) {
          return this.get("expressions").every((expression) => expression.isConstantExpression());
        }
        return true;
      }
      if (this.isUnaryExpression()) {
        if (this.node.operator !== "void") {
          return false;
        }
        return this.get("argument").isConstantExpression();
      }
      if (this.isBinaryExpression()) {
        const {
          operator
        } = this.node;
        return operator !== "in" && operator !== "instanceof" && this.get("left").isConstantExpression() && this.get("right").isConstantExpression();
      }
      return false;
    }
    function isInStrictMode() {
      const start = this.isProgram() ? this : this.parentPath;
      const strictParent = start.find((path2) => {
        if (path2.isProgram({
          sourceType: "module"
        }))
          return true;
        if (path2.isClass())
          return true;
        if (path2.isArrowFunctionExpression() && !path2.get("body").isBlockStatement()) {
          return false;
        }
        let body;
        if (path2.isFunction()) {
          body = path2.node.body;
        } else if (path2.isProgram()) {
          body = path2.node;
        } else {
          return false;
        }
        for (const directive of body.directives) {
          if (directive.value.value === "use strict") {
            return true;
          }
        }
      });
      return !!strictParent;
    }
  }
});

// node_modules/@babel/traverse/lib/path/context.js
var require_context = __commonJS({
  "node_modules/@babel/traverse/lib/path/context.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._call = _call;
    exports._getQueueContexts = _getQueueContexts;
    exports._resyncKey = _resyncKey;
    exports._resyncList = _resyncList;
    exports._resyncParent = _resyncParent;
    exports._resyncRemoved = _resyncRemoved;
    exports.call = call;
    exports.isBlacklisted = exports.isDenylisted = isDenylisted;
    exports.popContext = popContext;
    exports.pushContext = pushContext;
    exports.requeue = requeue;
    exports.resync = resync;
    exports.setContext = setContext;
    exports.setKey = setKey;
    exports.setScope = setScope;
    exports.setup = setup;
    exports.skip = skip;
    exports.skipKey = skipKey;
    exports.stop = stop;
    exports.visit = visit;
    var _traverseNode = require_traverse_node();
    var _index = require_path();
    function call(key) {
      const opts = this.opts;
      this.debug(key);
      if (this.node) {
        if (this._call(opts[key]))
          return true;
      }
      if (this.node) {
        return this._call(opts[this.node.type] && opts[this.node.type][key]);
      }
      return false;
    }
    function _call(fns) {
      if (!fns)
        return false;
      for (const fn of fns) {
        if (!fn)
          continue;
        const node = this.node;
        if (!node)
          return true;
        const ret = fn.call(this.state, this, this.state);
        if (ret && typeof ret === "object" && typeof ret.then === "function") {
          throw new Error(`You appear to be using a plugin with an async traversal visitor, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.`);
        }
        if (ret) {
          throw new Error(`Unexpected return value from visitor method ${fn}`);
        }
        if (this.node !== node)
          return true;
        if (this._traverseFlags > 0)
          return true;
      }
      return false;
    }
    function isDenylisted() {
      var _this$opts$denylist;
      const denylist = (_this$opts$denylist = this.opts.denylist) != null ? _this$opts$denylist : this.opts.blacklist;
      return denylist && denylist.indexOf(this.node.type) > -1;
    }
    function restoreContext(path2, context) {
      if (path2.context !== context) {
        path2.context = context;
        path2.state = context.state;
        path2.opts = context.opts;
      }
    }
    function visit() {
      if (!this.node) {
        return false;
      }
      if (this.isDenylisted()) {
        return false;
      }
      if (this.opts.shouldSkip && this.opts.shouldSkip(this)) {
        return false;
      }
      const currentContext = this.context;
      if (this.shouldSkip || this.call("enter")) {
        this.debug("Skip...");
        return this.shouldStop;
      }
      restoreContext(this, currentContext);
      this.debug("Recursing into...");
      this.shouldStop = (0, _traverseNode.traverseNode)(this.node, this.opts, this.scope, this.state, this, this.skipKeys);
      restoreContext(this, currentContext);
      this.call("exit");
      return this.shouldStop;
    }
    function skip() {
      this.shouldSkip = true;
    }
    function skipKey(key) {
      if (this.skipKeys == null) {
        this.skipKeys = {};
      }
      this.skipKeys[key] = true;
    }
    function stop() {
      this._traverseFlags |= _index.SHOULD_SKIP | _index.SHOULD_STOP;
    }
    function setScope() {
      if (this.opts && this.opts.noScope)
        return;
      let path2 = this.parentPath;
      if ((this.key === "key" || this.listKey === "decorators") && path2.isMethod() || this.key === "discriminant" && path2.isSwitchStatement()) {
        path2 = path2.parentPath;
      }
      let target;
      while (path2 && !target) {
        if (path2.opts && path2.opts.noScope)
          return;
        target = path2.scope;
        path2 = path2.parentPath;
      }
      this.scope = this.getScope(target);
      if (this.scope)
        this.scope.init();
    }
    function setContext(context) {
      if (this.skipKeys != null) {
        this.skipKeys = {};
      }
      this._traverseFlags = 0;
      if (context) {
        this.context = context;
        this.state = context.state;
        this.opts = context.opts;
      }
      this.setScope();
      return this;
    }
    function resync() {
      if (this.removed)
        return;
      this._resyncParent();
      this._resyncList();
      this._resyncKey();
    }
    function _resyncParent() {
      if (this.parentPath) {
        this.parent = this.parentPath.node;
      }
    }
    function _resyncKey() {
      if (!this.container)
        return;
      if (this.node === this.container[this.key]) {
        return;
      }
      if (Array.isArray(this.container)) {
        for (let i = 0; i < this.container.length; i++) {
          if (this.container[i] === this.node) {
            return this.setKey(i);
          }
        }
      } else {
        for (const key of Object.keys(this.container)) {
          if (this.container[key] === this.node) {
            return this.setKey(key);
          }
        }
      }
      this.key = null;
    }
    function _resyncList() {
      if (!this.parent || !this.inList)
        return;
      const newContainer = this.parent[this.listKey];
      if (this.container === newContainer)
        return;
      this.container = newContainer || null;
    }
    function _resyncRemoved() {
      if (this.key == null || !this.container || this.container[this.key] !== this.node) {
        this._markRemoved();
      }
    }
    function popContext() {
      this.contexts.pop();
      if (this.contexts.length > 0) {
        this.setContext(this.contexts[this.contexts.length - 1]);
      } else {
        this.setContext(void 0);
      }
    }
    function pushContext(context) {
      this.contexts.push(context);
      this.setContext(context);
    }
    function setup(parentPath, container, listKey, key) {
      this.listKey = listKey;
      this.container = container;
      this.parentPath = parentPath || this.parentPath;
      this.setKey(key);
    }
    function setKey(key) {
      var _this$node;
      this.key = key;
      this.node = this.container[this.key];
      this.type = (_this$node = this.node) == null ? void 0 : _this$node.type;
    }
    function requeue(pathToQueue = this) {
      if (pathToQueue.removed)
        return;
      ;
      const contexts = this.contexts;
      for (const context of contexts) {
        context.maybeQueue(pathToQueue);
      }
    }
    function _getQueueContexts() {
      let path2 = this;
      let contexts = this.contexts;
      while (!contexts.length) {
        path2 = path2.parentPath;
        if (!path2)
          break;
        contexts = path2.contexts;
      }
      return contexts;
    }
  }
});

// node_modules/@babel/traverse/lib/path/lib/removal-hooks.js
var require_removal_hooks = __commonJS({
  "node_modules/@babel/traverse/lib/path/lib/removal-hooks.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.hooks = void 0;
    var hooks = [function(self2, parent) {
      const removeParent = self2.key === "test" && (parent.isWhile() || parent.isSwitchCase()) || self2.key === "declaration" && parent.isExportDeclaration() || self2.key === "body" && parent.isLabeledStatement() || self2.listKey === "declarations" && parent.isVariableDeclaration() && parent.node.declarations.length === 1 || self2.key === "expression" && parent.isExpressionStatement();
      if (removeParent) {
        parent.remove();
        return true;
      }
    }, function(self2, parent) {
      if (parent.isSequenceExpression() && parent.node.expressions.length === 1) {
        parent.replaceWith(parent.node.expressions[0]);
        return true;
      }
    }, function(self2, parent) {
      if (parent.isBinary()) {
        if (self2.key === "left") {
          parent.replaceWith(parent.node.right);
        } else {
          parent.replaceWith(parent.node.left);
        }
        return true;
      }
    }, function(self2, parent) {
      if (parent.isIfStatement() && self2.key === "consequent" || self2.key === "body" && (parent.isLoop() || parent.isArrowFunctionExpression())) {
        self2.replaceWith({
          type: "BlockStatement",
          body: []
        });
        return true;
      }
    }];
    exports.hooks = hooks;
  }
});

// node_modules/@babel/traverse/lib/path/removal.js
var require_removal = __commonJS({
  "node_modules/@babel/traverse/lib/path/removal.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._assertUnremoved = _assertUnremoved;
    exports._callRemovalHooks = _callRemovalHooks;
    exports._markRemoved = _markRemoved;
    exports._remove = _remove;
    exports._removeFromScope = _removeFromScope;
    exports.remove = remove;
    var _removalHooks = require_removal_hooks();
    var _cache = require_cache4();
    var _index = require_path();
    function remove() {
      var _this$opts;
      this._assertUnremoved();
      this.resync();
      if (!((_this$opts = this.opts) != null && _this$opts.noScope)) {
        this._removeFromScope();
      }
      if (this._callRemovalHooks()) {
        this._markRemoved();
        return;
      }
      this.shareCommentsWithSiblings();
      this._remove();
      this._markRemoved();
    }
    function _removeFromScope() {
      const bindings = this.getBindingIdentifiers();
      Object.keys(bindings).forEach((name) => this.scope.removeBinding(name));
    }
    function _callRemovalHooks() {
      for (const fn of _removalHooks.hooks) {
        if (fn(this, this.parentPath))
          return true;
      }
    }
    function _remove() {
      if (Array.isArray(this.container)) {
        this.container.splice(this.key, 1);
        this.updateSiblingKeys(this.key, -1);
      } else {
        this._replaceWith(null);
      }
    }
    function _markRemoved() {
      this._traverseFlags |= _index.SHOULD_SKIP | _index.REMOVED;
      if (this.parent)
        _cache.path.get(this.parent).delete(this.node);
      this.node = null;
    }
    function _assertUnremoved() {
      if (this.removed) {
        throw this.buildCodeFrameError("NodePath has been removed so is read-only.");
      }
    }
  }
});

// node_modules/@babel/traverse/lib/path/lib/hoister.js
var require_hoister = __commonJS({
  "node_modules/@babel/traverse/lib/path/lib/hoister.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _t = require_lib11();
    var _t2 = _t;
    var {
      react
    } = _t;
    var {
      cloneNode,
      jsxExpressionContainer,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t2;
    var referenceVisitor = {
      ReferencedIdentifier(path2, state) {
        if (path2.isJSXIdentifier() && react.isCompatTag(path2.node.name) && !path2.parentPath.isJSXMemberExpression()) {
          return;
        }
        if (path2.node.name === "this") {
          let scope = path2.scope;
          do {
            if (scope.path.isFunction() && !scope.path.isArrowFunctionExpression()) {
              break;
            }
          } while (scope = scope.parent);
          if (scope)
            state.breakOnScopePaths.push(scope.path);
        }
        const binding = path2.scope.getBinding(path2.node.name);
        if (!binding)
          return;
        for (const violation of binding.constantViolations) {
          if (violation.scope !== binding.path.scope) {
            state.mutableBinding = true;
            path2.stop();
            return;
          }
        }
        if (binding !== state.scope.getBinding(path2.node.name))
          return;
        state.bindings[path2.node.name] = binding;
      }
    };
    var PathHoister = class {
      constructor(path2, scope) {
        this.breakOnScopePaths = void 0;
        this.bindings = void 0;
        this.mutableBinding = void 0;
        this.scopes = void 0;
        this.scope = void 0;
        this.path = void 0;
        this.attachAfter = void 0;
        this.breakOnScopePaths = [];
        this.bindings = {};
        this.mutableBinding = false;
        this.scopes = [];
        this.scope = scope;
        this.path = path2;
        this.attachAfter = false;
      }
      isCompatibleScope(scope) {
        for (const key of Object.keys(this.bindings)) {
          const binding = this.bindings[key];
          if (!scope.bindingIdentifierEquals(key, binding.identifier)) {
            return false;
          }
        }
        return true;
      }
      getCompatibleScopes() {
        let scope = this.path.scope;
        do {
          if (this.isCompatibleScope(scope)) {
            this.scopes.push(scope);
          } else {
            break;
          }
          if (this.breakOnScopePaths.indexOf(scope.path) >= 0) {
            break;
          }
        } while (scope = scope.parent);
      }
      getAttachmentPath() {
        let path2 = this._getAttachmentPath();
        if (!path2)
          return;
        let targetScope = path2.scope;
        if (targetScope.path === path2) {
          targetScope = path2.scope.parent;
        }
        if (targetScope.path.isProgram() || targetScope.path.isFunction()) {
          for (const name of Object.keys(this.bindings)) {
            if (!targetScope.hasOwnBinding(name))
              continue;
            const binding = this.bindings[name];
            if (binding.kind === "param" || binding.path.parentKey === "params") {
              continue;
            }
            const bindingParentPath = this.getAttachmentParentForPath(binding.path);
            if (bindingParentPath.key >= path2.key) {
              this.attachAfter = true;
              path2 = binding.path;
              for (const violationPath of binding.constantViolations) {
                if (this.getAttachmentParentForPath(violationPath).key > path2.key) {
                  path2 = violationPath;
                }
              }
            }
          }
        }
        return path2;
      }
      _getAttachmentPath() {
        const scopes = this.scopes;
        const scope = scopes.pop();
        if (!scope)
          return;
        if (scope.path.isFunction()) {
          if (this.hasOwnParamBindings(scope)) {
            if (this.scope === scope)
              return;
            const bodies = scope.path.get("body").get("body");
            for (let i = 0; i < bodies.length; i++) {
              if (bodies[i].node._blockHoist)
                continue;
              return bodies[i];
            }
          } else {
            return this.getNextScopeAttachmentParent();
          }
        } else if (scope.path.isProgram()) {
          return this.getNextScopeAttachmentParent();
        }
      }
      getNextScopeAttachmentParent() {
        const scope = this.scopes.pop();
        if (scope)
          return this.getAttachmentParentForPath(scope.path);
      }
      getAttachmentParentForPath(path2) {
        do {
          if (!path2.parentPath || Array.isArray(path2.container) && path2.isStatement()) {
            return path2;
          }
        } while (path2 = path2.parentPath);
      }
      hasOwnParamBindings(scope) {
        for (const name of Object.keys(this.bindings)) {
          if (!scope.hasOwnBinding(name))
            continue;
          const binding = this.bindings[name];
          if (binding.kind === "param" && binding.constant)
            return true;
        }
        return false;
      }
      run() {
        this.path.traverse(referenceVisitor, this);
        if (this.mutableBinding)
          return;
        this.getCompatibleScopes();
        const attachTo = this.getAttachmentPath();
        if (!attachTo)
          return;
        if (attachTo.getFunctionParent() === this.path.getFunctionParent())
          return;
        let uid = attachTo.scope.generateUidIdentifier("ref");
        const declarator = variableDeclarator2(uid, this.path.node);
        const insertFn = this.attachAfter ? "insertAfter" : "insertBefore";
        const [attached] = attachTo[insertFn]([attachTo.isVariableDeclarator() ? declarator : variableDeclaration2("var", [declarator])]);
        const parent = this.path.parentPath;
        if (parent.isJSXElement() && this.path.container === parent.node.children) {
          uid = jsxExpressionContainer(uid);
        }
        this.path.replaceWith(cloneNode(uid));
        return attachTo.isVariableDeclarator() ? attached.get("init") : attached.get("declarations.0.init");
      }
    };
    exports.default = PathHoister;
  }
});

// node_modules/@babel/traverse/lib/path/modification.js
var require_modification = __commonJS({
  "node_modules/@babel/traverse/lib/path/modification.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._containerInsert = _containerInsert;
    exports._containerInsertAfter = _containerInsertAfter;
    exports._containerInsertBefore = _containerInsertBefore;
    exports._verifyNodeList = _verifyNodeList;
    exports.hoist = hoist;
    exports.insertAfter = insertAfter;
    exports.insertBefore = insertBefore;
    exports.pushContainer = pushContainer;
    exports.unshiftContainer = unshiftContainer;
    exports.updateSiblingKeys = updateSiblingKeys;
    var _cache = require_cache4();
    var _hoister = require_hoister();
    var _index = require_path();
    var _t = require_lib11();
    var {
      arrowFunctionExpression,
      assertExpression,
      assignmentExpression,
      blockStatement: blockStatement2,
      callExpression: callExpression3,
      cloneNode,
      expressionStatement,
      isAssignmentExpression,
      isCallExpression: isCallExpression2,
      isExportNamedDeclaration,
      isExpression: isExpression2,
      isIdentifier: isIdentifier2,
      isSequenceExpression,
      isSuper,
      thisExpression
    } = _t;
    function insertBefore(nodes_) {
      this._assertUnremoved();
      const nodes = this._verifyNodeList(nodes_);
      const {
        parentPath,
        parent
      } = this;
      if (parentPath.isExpressionStatement() || parentPath.isLabeledStatement() || isExportNamedDeclaration(parent) || parentPath.isExportDefaultDeclaration() && this.isDeclaration()) {
        return parentPath.insertBefore(nodes);
      } else if (this.isNodeType("Expression") && !this.isJSXElement() || parentPath.isForStatement() && this.key === "init") {
        if (this.node)
          nodes.push(this.node);
        return this.replaceExpressionWithStatements(nodes);
      } else if (Array.isArray(this.container)) {
        return this._containerInsertBefore(nodes);
      } else if (this.isStatementOrBlock()) {
        const node = this.node;
        const shouldInsertCurrentNode = node && (!this.isExpressionStatement() || node.expression != null);
        this.replaceWith(blockStatement2(shouldInsertCurrentNode ? [node] : []));
        return this.unshiftContainer("body", nodes);
      } else {
        throw new Error("We don't know what to do with this node type. We were previously a Statement but we can't fit in here?");
      }
    }
    function _containerInsert(from, nodes) {
      this.updateSiblingKeys(from, nodes.length);
      const paths = [];
      this.container.splice(from, 0, ...nodes);
      for (let i = 0; i < nodes.length; i++) {
        const to = from + i;
        const path2 = this.getSibling(to);
        paths.push(path2);
        if (this.context && this.context.queue) {
          path2.pushContext(this.context);
        }
      }
      const contexts = this._getQueueContexts();
      for (const path2 of paths) {
        path2.setScope();
        path2.debug("Inserted.");
        for (const context of contexts) {
          context.maybeQueue(path2, true);
        }
      }
      return paths;
    }
    function _containerInsertBefore(nodes) {
      return this._containerInsert(this.key, nodes);
    }
    function _containerInsertAfter(nodes) {
      return this._containerInsert(this.key + 1, nodes);
    }
    var last2 = (arr) => arr[arr.length - 1];
    function isHiddenInSequenceExpression(path2) {
      return isSequenceExpression(path2.parent) && (last2(path2.parent.expressions) !== path2.node || isHiddenInSequenceExpression(path2.parentPath));
    }
    function isAlmostConstantAssignment(node, scope) {
      if (!isAssignmentExpression(node) || !isIdentifier2(node.left)) {
        return false;
      }
      const blockScope = scope.getBlockParent();
      return blockScope.hasOwnBinding(node.left.name) && blockScope.getOwnBinding(node.left.name).constantViolations.length <= 1;
    }
    function insertAfter(nodes_) {
      this._assertUnremoved();
      if (this.isSequenceExpression()) {
        return last2(this.get("expressions")).insertAfter(nodes_);
      }
      const nodes = this._verifyNodeList(nodes_);
      const {
        parentPath,
        parent
      } = this;
      if (parentPath.isExpressionStatement() || parentPath.isLabeledStatement() || isExportNamedDeclaration(parent) || parentPath.isExportDefaultDeclaration() && this.isDeclaration()) {
        return parentPath.insertAfter(nodes.map((node) => {
          return isExpression2(node) ? expressionStatement(node) : node;
        }));
      } else if (this.isNodeType("Expression") && !this.isJSXElement() && !parentPath.isJSXElement() || parentPath.isForStatement() && this.key === "init") {
        if (this.node) {
          const node = this.node;
          let {
            scope
          } = this;
          if (scope.path.isPattern()) {
            assertExpression(node);
            this.replaceWith(callExpression3(arrowFunctionExpression([], node), []));
            this.get("callee.body").insertAfter(nodes);
            return [this];
          }
          if (isHiddenInSequenceExpression(this)) {
            nodes.unshift(node);
          } else if (isCallExpression2(node) && isSuper(node.callee)) {
            nodes.unshift(node);
            nodes.push(thisExpression());
          } else if (isAlmostConstantAssignment(node, scope)) {
            nodes.unshift(node);
            nodes.push(cloneNode(node.left));
          } else if (scope.isPure(node, true)) {
            nodes.push(node);
          } else {
            if (parentPath.isMethod({
              computed: true,
              key: node
            })) {
              scope = scope.parent;
            }
            const temp = scope.generateDeclaredUidIdentifier();
            nodes.unshift(expressionStatement(assignmentExpression("=", cloneNode(temp), node)));
            nodes.push(expressionStatement(cloneNode(temp)));
          }
        }
        return this.replaceExpressionWithStatements(nodes);
      } else if (Array.isArray(this.container)) {
        return this._containerInsertAfter(nodes);
      } else if (this.isStatementOrBlock()) {
        const node = this.node;
        const shouldInsertCurrentNode = node && (!this.isExpressionStatement() || node.expression != null);
        this.replaceWith(blockStatement2(shouldInsertCurrentNode ? [node] : []));
        return this.pushContainer("body", nodes);
      } else {
        throw new Error("We don't know what to do with this node type. We were previously a Statement but we can't fit in here?");
      }
    }
    function updateSiblingKeys(fromIndex, incrementBy) {
      if (!this.parent)
        return;
      const paths = _cache.path.get(this.parent);
      for (const [, path2] of paths) {
        if (path2.key >= fromIndex) {
          path2.key += incrementBy;
        }
      }
    }
    function _verifyNodeList(nodes) {
      if (!nodes) {
        return [];
      }
      if (!Array.isArray(nodes)) {
        nodes = [nodes];
      }
      for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        let msg;
        if (!node) {
          msg = "has falsy node";
        } else if (typeof node !== "object") {
          msg = "contains a non-object node";
        } else if (!node.type) {
          msg = "without a type";
        } else if (node instanceof _index.default) {
          msg = "has a NodePath when it expected a raw object";
        }
        if (msg) {
          const type = Array.isArray(node) ? "array" : typeof node;
          throw new Error(`Node list ${msg} with the index of ${i} and type of ${type}`);
        }
      }
      return nodes;
    }
    function unshiftContainer(listKey, nodes) {
      this._assertUnremoved();
      nodes = this._verifyNodeList(nodes);
      const path2 = _index.default.get({
        parentPath: this,
        parent: this.node,
        container: this.node[listKey],
        listKey,
        key: 0
      }).setContext(this.context);
      return path2._containerInsertBefore(nodes);
    }
    function pushContainer(listKey, nodes) {
      this._assertUnremoved();
      const verifiedNodes = this._verifyNodeList(nodes);
      const container = this.node[listKey];
      const path2 = _index.default.get({
        parentPath: this,
        parent: this.node,
        container,
        listKey,
        key: container.length
      }).setContext(this.context);
      return path2.replaceWithMultiple(verifiedNodes);
    }
    function hoist(scope = this.scope) {
      const hoister = new _hoister.default(this, scope);
      return hoister.run();
    }
  }
});

// node_modules/@babel/traverse/lib/path/family.js
var require_family = __commonJS({
  "node_modules/@babel/traverse/lib/path/family.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports._getKey = _getKey;
    exports._getPattern = _getPattern;
    exports.get = get;
    exports.getAllNextSiblings = getAllNextSiblings;
    exports.getAllPrevSiblings = getAllPrevSiblings;
    exports.getBindingIdentifierPaths = getBindingIdentifierPaths;
    exports.getBindingIdentifiers = getBindingIdentifiers;
    exports.getCompletionRecords = getCompletionRecords;
    exports.getNextSibling = getNextSibling;
    exports.getOpposite = getOpposite;
    exports.getOuterBindingIdentifierPaths = getOuterBindingIdentifierPaths;
    exports.getOuterBindingIdentifiers = getOuterBindingIdentifiers;
    exports.getPrevSibling = getPrevSibling;
    exports.getSibling = getSibling;
    var _index = require_path();
    var _t = require_lib11();
    var {
      getBindingIdentifiers: _getBindingIdentifiers,
      getOuterBindingIdentifiers: _getOuterBindingIdentifiers,
      isDeclaration,
      numericLiteral,
      unaryExpression
    } = _t;
    var NORMAL_COMPLETION = 0;
    var BREAK_COMPLETION = 1;
    function NormalCompletion(path2) {
      return {
        type: NORMAL_COMPLETION,
        path: path2
      };
    }
    function BreakCompletion(path2) {
      return {
        type: BREAK_COMPLETION,
        path: path2
      };
    }
    function getOpposite() {
      if (this.key === "left") {
        return this.getSibling("right");
      } else if (this.key === "right") {
        return this.getSibling("left");
      }
      return null;
    }
    function addCompletionRecords(path2, records, context) {
      if (path2) {
        records.push(..._getCompletionRecords(path2, context));
      }
      return records;
    }
    function completionRecordForSwitch(cases, records, context) {
      let lastNormalCompletions = [];
      for (let i = 0; i < cases.length; i++) {
        const casePath = cases[i];
        const caseCompletions = _getCompletionRecords(casePath, context);
        const normalCompletions = [];
        const breakCompletions = [];
        for (const c of caseCompletions) {
          if (c.type === NORMAL_COMPLETION) {
            normalCompletions.push(c);
          }
          if (c.type === BREAK_COMPLETION) {
            breakCompletions.push(c);
          }
        }
        if (normalCompletions.length) {
          lastNormalCompletions = normalCompletions;
        }
        records.push(...breakCompletions);
      }
      records.push(...lastNormalCompletions);
      return records;
    }
    function normalCompletionToBreak(completions) {
      completions.forEach((c) => {
        c.type = BREAK_COMPLETION;
      });
    }
    function replaceBreakStatementInBreakCompletion(completions, reachable) {
      completions.forEach((c) => {
        if (c.path.isBreakStatement({
          label: null
        })) {
          if (reachable) {
            c.path.replaceWith(unaryExpression("void", numericLiteral(0)));
          } else {
            c.path.remove();
          }
        }
      });
    }
    function getStatementListCompletion(paths, context) {
      const completions = [];
      if (context.canHaveBreak) {
        let lastNormalCompletions = [];
        for (let i = 0; i < paths.length; i++) {
          const path2 = paths[i];
          const newContext = Object.assign({}, context, {
            inCaseClause: false
          });
          if (path2.isBlockStatement() && (context.inCaseClause || context.shouldPopulateBreak)) {
            newContext.shouldPopulateBreak = true;
          } else {
            newContext.shouldPopulateBreak = false;
          }
          const statementCompletions = _getCompletionRecords(path2, newContext);
          if (statementCompletions.length > 0 && statementCompletions.every((c) => c.type === BREAK_COMPLETION)) {
            if (lastNormalCompletions.length > 0 && statementCompletions.every((c) => c.path.isBreakStatement({
              label: null
            }))) {
              normalCompletionToBreak(lastNormalCompletions);
              completions.push(...lastNormalCompletions);
              if (lastNormalCompletions.some((c) => c.path.isDeclaration())) {
                completions.push(...statementCompletions);
                replaceBreakStatementInBreakCompletion(statementCompletions, true);
              }
              replaceBreakStatementInBreakCompletion(statementCompletions, false);
            } else {
              completions.push(...statementCompletions);
              if (!context.shouldPopulateBreak) {
                replaceBreakStatementInBreakCompletion(statementCompletions, true);
              }
            }
            break;
          }
          if (i === paths.length - 1) {
            completions.push(...statementCompletions);
          } else {
            lastNormalCompletions = [];
            for (let i2 = 0; i2 < statementCompletions.length; i2++) {
              const c = statementCompletions[i2];
              if (c.type === BREAK_COMPLETION) {
                completions.push(c);
              }
              if (c.type === NORMAL_COMPLETION) {
                lastNormalCompletions.push(c);
              }
            }
          }
        }
      } else if (paths.length) {
        for (let i = paths.length - 1; i >= 0; i--) {
          const pathCompletions = _getCompletionRecords(paths[i], context);
          if (pathCompletions.length > 1 || pathCompletions.length === 1 && !pathCompletions[0].path.isVariableDeclaration()) {
            completions.push(...pathCompletions);
            break;
          }
        }
      }
      return completions;
    }
    function _getCompletionRecords(path2, context) {
      let records = [];
      if (path2.isIfStatement()) {
        records = addCompletionRecords(path2.get("consequent"), records, context);
        records = addCompletionRecords(path2.get("alternate"), records, context);
      } else if (path2.isDoExpression() || path2.isFor() || path2.isWhile() || path2.isLabeledStatement()) {
        return addCompletionRecords(path2.get("body"), records, context);
      } else if (path2.isProgram() || path2.isBlockStatement()) {
        return getStatementListCompletion(path2.get("body"), context);
      } else if (path2.isFunction()) {
        return _getCompletionRecords(path2.get("body"), context);
      } else if (path2.isTryStatement()) {
        records = addCompletionRecords(path2.get("block"), records, context);
        records = addCompletionRecords(path2.get("handler"), records, context);
      } else if (path2.isCatchClause()) {
        return addCompletionRecords(path2.get("body"), records, context);
      } else if (path2.isSwitchStatement()) {
        return completionRecordForSwitch(path2.get("cases"), records, context);
      } else if (path2.isSwitchCase()) {
        return getStatementListCompletion(path2.get("consequent"), {
          canHaveBreak: true,
          shouldPopulateBreak: false,
          inCaseClause: true
        });
      } else if (path2.isBreakStatement()) {
        records.push(BreakCompletion(path2));
      } else {
        records.push(NormalCompletion(path2));
      }
      return records;
    }
    function getCompletionRecords() {
      const records = _getCompletionRecords(this, {
        canHaveBreak: false,
        shouldPopulateBreak: false,
        inCaseClause: false
      });
      return records.map((r) => r.path);
    }
    function getSibling(key) {
      return _index.default.get({
        parentPath: this.parentPath,
        parent: this.parent,
        container: this.container,
        listKey: this.listKey,
        key
      }).setContext(this.context);
    }
    function getPrevSibling() {
      return this.getSibling(this.key - 1);
    }
    function getNextSibling() {
      return this.getSibling(this.key + 1);
    }
    function getAllNextSiblings() {
      let _key = this.key;
      let sibling = this.getSibling(++_key);
      const siblings = [];
      while (sibling.node) {
        siblings.push(sibling);
        sibling = this.getSibling(++_key);
      }
      return siblings;
    }
    function getAllPrevSiblings() {
      let _key = this.key;
      let sibling = this.getSibling(--_key);
      const siblings = [];
      while (sibling.node) {
        siblings.push(sibling);
        sibling = this.getSibling(--_key);
      }
      return siblings;
    }
    function get(key, context = true) {
      if (context === true)
        context = this.context;
      const parts = key.split(".");
      if (parts.length === 1) {
        return this._getKey(key, context);
      } else {
        return this._getPattern(parts, context);
      }
    }
    function _getKey(key, context) {
      const node = this.node;
      const container = node[key];
      if (Array.isArray(container)) {
        return container.map((_, i) => {
          return _index.default.get({
            listKey: key,
            parentPath: this,
            parent: node,
            container,
            key: i
          }).setContext(context);
        });
      } else {
        return _index.default.get({
          parentPath: this,
          parent: node,
          container: node,
          key
        }).setContext(context);
      }
    }
    function _getPattern(parts, context) {
      let path2 = this;
      for (const part of parts) {
        if (part === ".") {
          path2 = path2.parentPath;
        } else {
          if (Array.isArray(path2)) {
            path2 = path2[part];
          } else {
            path2 = path2.get(part, context);
          }
        }
      }
      return path2;
    }
    function getBindingIdentifiers(duplicates) {
      return _getBindingIdentifiers(this.node, duplicates);
    }
    function getOuterBindingIdentifiers(duplicates) {
      return _getOuterBindingIdentifiers(this.node, duplicates);
    }
    function getBindingIdentifierPaths(duplicates = false, outerOnly = false) {
      const path2 = this;
      const search = [path2];
      const ids = /* @__PURE__ */ Object.create(null);
      while (search.length) {
        const id = search.shift();
        if (!id)
          continue;
        if (!id.node)
          continue;
        const keys3 = _getBindingIdentifiers.keys[id.node.type];
        if (id.isIdentifier()) {
          if (duplicates) {
            const _ids = ids[id.node.name] = ids[id.node.name] || [];
            _ids.push(id);
          } else {
            ids[id.node.name] = id;
          }
          continue;
        }
        if (id.isExportDeclaration()) {
          const declaration = id.get("declaration");
          if (isDeclaration(declaration)) {
            search.push(declaration);
          }
          continue;
        }
        if (outerOnly) {
          if (id.isFunctionDeclaration()) {
            search.push(id.get("id"));
            continue;
          }
          if (id.isFunctionExpression()) {
            continue;
          }
        }
        if (keys3) {
          for (let i = 0; i < keys3.length; i++) {
            const key = keys3[i];
            const child = id.get(key);
            if (Array.isArray(child)) {
              search.push(...child);
            } else if (child.node) {
              search.push(child);
            }
          }
        }
      }
      return ids;
    }
    function getOuterBindingIdentifierPaths(duplicates = false) {
      return this.getBindingIdentifierPaths(duplicates, true);
    }
  }
});

// node_modules/@babel/traverse/lib/path/comments.js
var require_comments = __commonJS({
  "node_modules/@babel/traverse/lib/path/comments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.addComment = addComment;
    exports.addComments = addComments;
    exports.shareCommentsWithSiblings = shareCommentsWithSiblings;
    var _t = require_lib11();
    var {
      addComment: _addComment,
      addComments: _addComments
    } = _t;
    function shareCommentsWithSiblings() {
      if (typeof this.key === "string")
        return;
      const node = this.node;
      if (!node)
        return;
      const trailing = node.trailingComments;
      const leading = node.leadingComments;
      if (!trailing && !leading)
        return;
      const prev = this.getSibling(this.key - 1);
      const next = this.getSibling(this.key + 1);
      const hasPrev = Boolean(prev.node);
      const hasNext = Boolean(next.node);
      if (hasPrev && !hasNext) {
        prev.addComments("trailing", trailing);
      } else if (hasNext && !hasPrev) {
        next.addComments("leading", leading);
      }
    }
    function addComment(type, content, line) {
      _addComment(this.node, type, content, line);
    }
    function addComments(type, comments) {
      _addComments(this.node, type, comments);
    }
  }
});

// node_modules/@babel/traverse/lib/path/lib/virtual-types-validator.js
var require_virtual_types_validator = __commonJS({
  "node_modules/@babel/traverse/lib/path/lib/virtual-types-validator.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isBindingIdentifier = isBindingIdentifier;
    exports.isBlockScoped = isBlockScoped;
    exports.isExistentialTypeParam = isExistentialTypeParam;
    exports.isExpression = isExpression2;
    exports.isFlow = isFlow;
    exports.isForAwaitStatement = isForAwaitStatement;
    exports.isGenerated = isGenerated;
    exports.isNumericLiteralTypeAnnotation = isNumericLiteralTypeAnnotation;
    exports.isPure = isPure;
    exports.isReferenced = isReferenced;
    exports.isReferencedIdentifier = isReferencedIdentifier;
    exports.isReferencedMemberExpression = isReferencedMemberExpression;
    exports.isRestProperty = isRestProperty;
    exports.isScope = isScope;
    exports.isSpreadProperty = isSpreadProperty;
    exports.isStatement = isStatement;
    exports.isUser = isUser;
    exports.isVar = isVar;
    var _t = require_lib11();
    var {
      isBinding,
      isBlockScoped: nodeIsBlockScoped,
      isExportDeclaration,
      isExpression: nodeIsExpression,
      isFlow: nodeIsFlow,
      isForStatement,
      isForXStatement,
      isIdentifier: isIdentifier2,
      isImportDeclaration,
      isImportSpecifier: isImportSpecifier2,
      isJSXIdentifier,
      isJSXMemberExpression,
      isMemberExpression,
      isRestElement: nodeIsRestElement,
      isReferenced: nodeIsReferenced,
      isScope: nodeIsScope,
      isStatement: nodeIsStatement,
      isVar: nodeIsVar,
      isVariableDeclaration,
      react,
      isForOfStatement
    } = _t;
    var {
      isCompatTag
    } = react;
    function isReferencedIdentifier(opts) {
      const {
        node,
        parent
      } = this;
      if (!isIdentifier2(node, opts) && !isJSXMemberExpression(parent, opts)) {
        if (isJSXIdentifier(node, opts)) {
          if (isCompatTag(node.name))
            return false;
        } else {
          return false;
        }
      }
      return nodeIsReferenced(node, parent, this.parentPath.parent);
    }
    function isReferencedMemberExpression() {
      const {
        node,
        parent
      } = this;
      return isMemberExpression(node) && nodeIsReferenced(node, parent);
    }
    function isBindingIdentifier() {
      const {
        node,
        parent
      } = this;
      const grandparent = this.parentPath.parent;
      return isIdentifier2(node) && isBinding(node, parent, grandparent);
    }
    function isStatement() {
      const {
        node,
        parent
      } = this;
      if (nodeIsStatement(node)) {
        if (isVariableDeclaration(node)) {
          if (isForXStatement(parent, {
            left: node
          }))
            return false;
          if (isForStatement(parent, {
            init: node
          }))
            return false;
        }
        return true;
      } else {
        return false;
      }
    }
    function isExpression2() {
      if (this.isIdentifier()) {
        return this.isReferencedIdentifier();
      } else {
        return nodeIsExpression(this.node);
      }
    }
    function isScope() {
      return nodeIsScope(this.node, this.parent);
    }
    function isReferenced() {
      return nodeIsReferenced(this.node, this.parent);
    }
    function isBlockScoped() {
      return nodeIsBlockScoped(this.node);
    }
    function isVar() {
      return nodeIsVar(this.node);
    }
    function isUser() {
      return this.node && !!this.node.loc;
    }
    function isGenerated() {
      return !this.isUser();
    }
    function isPure(constantsOnly) {
      return this.scope.isPure(this.node, constantsOnly);
    }
    function isFlow() {
      const {
        node
      } = this;
      if (nodeIsFlow(node)) {
        return true;
      } else if (isImportDeclaration(node)) {
        return node.importKind === "type" || node.importKind === "typeof";
      } else if (isExportDeclaration(node)) {
        return node.exportKind === "type";
      } else if (isImportSpecifier2(node)) {
        return node.importKind === "type" || node.importKind === "typeof";
      } else {
        return false;
      }
    }
    function isRestProperty() {
      return nodeIsRestElement(this.node) && this.parentPath && this.parentPath.isObjectPattern();
    }
    function isSpreadProperty() {
      return nodeIsRestElement(this.node) && this.parentPath && this.parentPath.isObjectExpression();
    }
    function isForAwaitStatement() {
      return isForOfStatement(this.node, {
        await: true
      });
    }
    function isExistentialTypeParam() {
      throw new Error("`path.isExistentialTypeParam` has been renamed to `path.isExistsTypeAnnotation()` in Babel 7.");
    }
    function isNumericLiteralTypeAnnotation() {
      throw new Error("`path.isNumericLiteralTypeAnnotation()` has been renamed to `path.isNumberLiteralTypeAnnotation()` in Babel 7.");
    }
  }
});

// node_modules/@babel/traverse/lib/path/index.js
var require_path = __commonJS({
  "node_modules/@babel/traverse/lib/path/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = exports.SHOULD_STOP = exports.SHOULD_SKIP = exports.REMOVED = void 0;
    var virtualTypes = require_virtual_types();
    var _debug = require_src();
    var _index = require_lib20();
    var _scope = require_scope2();
    var _t = require_lib11();
    var t3 = _t;
    var _cache = require_cache4();
    var _generator = require_lib14();
    var NodePath_ancestry = require_ancestry();
    var NodePath_inference = require_inference();
    var NodePath_replacement = require_replacement();
    var NodePath_evaluation = require_evaluation();
    var NodePath_conversion = require_conversion();
    var NodePath_introspection = require_introspection();
    var NodePath_context = require_context();
    var NodePath_removal = require_removal();
    var NodePath_modification = require_modification();
    var NodePath_family = require_family();
    var NodePath_comments = require_comments();
    var NodePath_virtual_types_validator = require_virtual_types_validator();
    var {
      validate
    } = _t;
    var debug = _debug("babel");
    var REMOVED = 1 << 0;
    exports.REMOVED = REMOVED;
    var SHOULD_STOP = 1 << 1;
    exports.SHOULD_STOP = SHOULD_STOP;
    var SHOULD_SKIP = 1 << 2;
    exports.SHOULD_SKIP = SHOULD_SKIP;
    var NodePath2 = class _NodePath {
      constructor(hub, parent) {
        this.contexts = [];
        this.state = null;
        this.opts = null;
        this._traverseFlags = 0;
        this.skipKeys = null;
        this.parentPath = null;
        this.container = null;
        this.listKey = null;
        this.key = null;
        this.node = null;
        this.type = null;
        this.parent = parent;
        this.hub = hub;
        this.data = null;
        this.context = null;
        this.scope = null;
      }
      static get({
        hub,
        parentPath,
        parent,
        container,
        listKey,
        key
      }) {
        if (!hub && parentPath) {
          hub = parentPath.hub;
        }
        if (!parent) {
          throw new Error("To get a node path the parent needs to exist");
        }
        const targetNode = container[key];
        let paths = _cache.path.get(parent);
        if (!paths) {
          paths = /* @__PURE__ */ new Map();
          _cache.path.set(parent, paths);
        }
        let path2 = paths.get(targetNode);
        if (!path2) {
          path2 = new _NodePath(hub, parent);
          if (targetNode)
            paths.set(targetNode, path2);
        }
        path2.setup(parentPath, container, listKey, key);
        return path2;
      }
      getScope(scope) {
        return this.isScope() ? new _scope.default(this) : scope;
      }
      setData(key, val) {
        if (this.data == null) {
          this.data = /* @__PURE__ */ Object.create(null);
        }
        return this.data[key] = val;
      }
      getData(key, def) {
        if (this.data == null) {
          this.data = /* @__PURE__ */ Object.create(null);
        }
        let val = this.data[key];
        if (val === void 0 && def !== void 0)
          val = this.data[key] = def;
        return val;
      }
      hasNode() {
        return this.node != null;
      }
      buildCodeFrameError(msg, Error2 = SyntaxError) {
        return this.hub.buildError(this.node, msg, Error2);
      }
      traverse(visitor, state) {
        (0, _index.default)(this.node, visitor, this.scope, state, this);
      }
      set(key, node) {
        validate(this.node, key, node);
        this.node[key] = node;
      }
      getPathLocation() {
        const parts = [];
        let path2 = this;
        do {
          let key = path2.key;
          if (path2.inList)
            key = `${path2.listKey}[${key}]`;
          parts.unshift(key);
        } while (path2 = path2.parentPath);
        return parts.join(".");
      }
      debug(message) {
        if (!debug.enabled)
          return;
        debug(`${this.getPathLocation()} ${this.type}: ${message}`);
      }
      toString() {
        return (0, _generator.default)(this.node).code;
      }
      get inList() {
        return !!this.listKey;
      }
      set inList(inList) {
        if (!inList) {
          this.listKey = null;
        }
      }
      get parentKey() {
        return this.listKey || this.key;
      }
      get shouldSkip() {
        return !!(this._traverseFlags & SHOULD_SKIP);
      }
      set shouldSkip(v) {
        if (v) {
          this._traverseFlags |= SHOULD_SKIP;
        } else {
          this._traverseFlags &= ~SHOULD_SKIP;
        }
      }
      get shouldStop() {
        return !!(this._traverseFlags & SHOULD_STOP);
      }
      set shouldStop(v) {
        if (v) {
          this._traverseFlags |= SHOULD_STOP;
        } else {
          this._traverseFlags &= ~SHOULD_STOP;
        }
      }
      get removed() {
        return !!(this._traverseFlags & REMOVED);
      }
      set removed(v) {
        if (v) {
          this._traverseFlags |= REMOVED;
        } else {
          this._traverseFlags &= ~REMOVED;
        }
      }
    };
    Object.assign(NodePath2.prototype, NodePath_ancestry, NodePath_inference, NodePath_replacement, NodePath_evaluation, NodePath_conversion, NodePath_introspection, NodePath_context, NodePath_removal, NodePath_modification, NodePath_family, NodePath_comments);
    {
      NodePath2.prototype._guessExecutionStatusRelativeToDifferentFunctions = NodePath_introspection._guessExecutionStatusRelativeTo;
    }
    for (const type of t3.TYPES) {
      const typeKey = `is${type}`;
      const fn = t3[typeKey];
      NodePath2.prototype[typeKey] = function(opts) {
        return fn(this.node, opts);
      };
      NodePath2.prototype[`assert${type}`] = function(opts) {
        if (!fn(this.node, opts)) {
          throw new TypeError(`Expected node path of type ${type}`);
        }
      };
    }
    Object.assign(NodePath2.prototype, NodePath_virtual_types_validator);
    for (const type of Object.keys(virtualTypes)) {
      if (type[0] === "_")
        continue;
      if (!t3.TYPES.includes(type))
        t3.TYPES.push(type);
    }
    var _default = NodePath2;
    exports.default = _default;
  }
});

// node_modules/@babel/traverse/lib/context.js
var require_context2 = __commonJS({
  "node_modules/@babel/traverse/lib/context.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _path = require_path();
    var _t = require_lib11();
    var {
      VISITOR_KEYS
    } = _t;
    var TraversalContext = class {
      constructor(scope, opts, state, parentPath) {
        this.queue = null;
        this.priorityQueue = null;
        this.parentPath = parentPath;
        this.scope = scope;
        this.state = state;
        this.opts = opts;
      }
      shouldVisit(node) {
        const opts = this.opts;
        if (opts.enter || opts.exit)
          return true;
        if (opts[node.type])
          return true;
        const keys3 = VISITOR_KEYS[node.type];
        if (!(keys3 != null && keys3.length))
          return false;
        for (const key of keys3) {
          if (node[key]) {
            return true;
          }
        }
        return false;
      }
      create(node, container, key, listKey) {
        return _path.default.get({
          parentPath: this.parentPath,
          parent: node,
          container,
          key,
          listKey
        });
      }
      maybeQueue(path2, notPriority) {
        if (this.queue) {
          if (notPriority) {
            this.queue.push(path2);
          } else {
            this.priorityQueue.push(path2);
          }
        }
      }
      visitMultiple(container, parent, listKey) {
        if (container.length === 0)
          return false;
        const queue = [];
        for (let key = 0; key < container.length; key++) {
          const node = container[key];
          if (node && this.shouldVisit(node)) {
            queue.push(this.create(parent, container, key, listKey));
          }
        }
        return this.visitQueue(queue);
      }
      visitSingle(node, key) {
        if (this.shouldVisit(node[key])) {
          return this.visitQueue([this.create(node, node, key)]);
        } else {
          return false;
        }
      }
      visitQueue(queue) {
        this.queue = queue;
        this.priorityQueue = [];
        const visited = /* @__PURE__ */ new WeakSet();
        let stop = false;
        for (const path2 of queue) {
          path2.resync();
          if (path2.contexts.length === 0 || path2.contexts[path2.contexts.length - 1] !== this) {
            path2.pushContext(this);
          }
          if (path2.key === null)
            continue;
          const {
            node
          } = path2;
          if (visited.has(node))
            continue;
          if (node)
            visited.add(node);
          if (path2.visit()) {
            stop = true;
            break;
          }
          if (this.priorityQueue.length) {
            stop = this.visitQueue(this.priorityQueue);
            this.priorityQueue = [];
            this.queue = queue;
            if (stop)
              break;
          }
        }
        for (const path2 of queue) {
          path2.popContext();
        }
        this.queue = null;
        return stop;
      }
      visit(node, key) {
        const nodes = node[key];
        if (!nodes)
          return false;
        if (Array.isArray(nodes)) {
          return this.visitMultiple(nodes, node, key);
        } else {
          return this.visitSingle(node, key);
        }
      }
    };
    exports.default = TraversalContext;
  }
});

// node_modules/@babel/traverse/lib/traverse-node.js
var require_traverse_node = __commonJS({
  "node_modules/@babel/traverse/lib/traverse-node.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.traverseNode = traverseNode;
    var _context = require_context2();
    var _t = require_lib11();
    var {
      VISITOR_KEYS
    } = _t;
    function traverseNode(node, opts, scope, state, path2, skipKeys) {
      const keys3 = VISITOR_KEYS[node.type];
      if (!keys3)
        return false;
      const context = new _context.default(scope, opts, state, path2);
      for (const key of keys3) {
        if (skipKeys && skipKeys[key])
          continue;
        if (context.visit(node, key)) {
          return true;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/traverse/lib/hub.js
var require_hub = __commonJS({
  "node_modules/@babel/traverse/lib/hub.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var Hub = class {
      getCode() {
      }
      getScope() {
      }
      addHelper() {
        throw new Error("Helpers are not supported by the default hub.");
      }
      buildError(node, msg, Error2 = TypeError) {
        return new Error2(msg);
      }
    };
    exports.default = Hub;
  }
});

// node_modules/@babel/traverse/lib/index.js
var require_lib20 = __commonJS({
  "node_modules/@babel/traverse/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "Hub", {
      enumerable: true,
      get: function() {
        return _hub.default;
      }
    });
    Object.defineProperty(exports, "NodePath", {
      enumerable: true,
      get: function() {
        return _path.default;
      }
    });
    Object.defineProperty(exports, "Scope", {
      enumerable: true,
      get: function() {
        return _scope.default;
      }
    });
    exports.visitors = exports.default = void 0;
    var visitors = require_visitors();
    exports.visitors = visitors;
    var _t = require_lib11();
    var cache = require_cache4();
    var _traverseNode = require_traverse_node();
    var _path = require_path();
    var _scope = require_scope2();
    var _hub = require_hub();
    var {
      VISITOR_KEYS,
      removeProperties,
      traverseFast
    } = _t;
    function traverse3(parent, opts = {}, scope, state, parentPath) {
      if (!parent)
        return;
      if (!opts.noScope && !scope) {
        if (parent.type !== "Program" && parent.type !== "File") {
          throw new Error(`You must pass a scope and parentPath unless traversing a Program/File. Instead of that you tried to traverse a ${parent.type} node without passing scope and parentPath.`);
        }
      }
      if (!VISITOR_KEYS[parent.type]) {
        return;
      }
      visitors.explode(opts);
      (0, _traverseNode.traverseNode)(parent, opts, scope, state, parentPath);
    }
    var _default = traverse3;
    exports.default = _default;
    traverse3.visitors = visitors;
    traverse3.verify = visitors.verify;
    traverse3.explode = visitors.explode;
    traverse3.cheap = function(node, enter) {
      return traverseFast(node, enter);
    };
    traverse3.node = function(node, opts, scope, state, path2, skipKeys) {
      (0, _traverseNode.traverseNode)(node, opts, scope, state, path2, skipKeys);
    };
    traverse3.clearNode = function(node, opts) {
      removeProperties(node, opts);
      cache.path.delete(node);
    };
    traverse3.removeProperties = function(tree, opts) {
      traverseFast(tree, traverse3.clearNode, opts);
      return tree;
    };
    function hasDenylistedType(path2, state) {
      if (path2.node.type === state.type) {
        state.has = true;
        path2.stop();
      }
    }
    traverse3.hasType = function(tree, type, denylistTypes) {
      if (denylistTypes != null && denylistTypes.includes(tree.type))
        return false;
      if (tree.type === type)
        return true;
      const state = {
        has: false,
        type
      };
      traverse3(tree, {
        noScope: true,
        denylist: denylistTypes,
        enter: hasDenylistedType
      }, null, state);
      return state.has;
    };
    traverse3.cache = cache;
  }
});

// node_modules/@babel/helpers/lib/helpers-generated.js
var require_helpers_generated = __commonJS({
  "node_modules/@babel/helpers/lib/helpers-generated.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _template = require_lib18();
    function helper(minVersion, source) {
      return Object.freeze({
        minVersion,
        ast: () => _template.default.program.ast(source, {
          preserveComments: true
        })
      });
    }
    var _default = Object.freeze({
      AsyncGenerator: helper("7.0.0-beta.0", 'import OverloadYield from"OverloadYield";export default function AsyncGenerator(gen){var front,back;function resume(key,arg){try{var result=gen[key](arg),value=result.value,overloaded=value instanceof OverloadYield;Promise.resolve(overloaded?value.v:value).then((function(arg){if(overloaded){var nextKey="return"===key?"return":"next";if(!value.k||arg.done)return resume(nextKey,arg);arg=gen[nextKey](arg).value}settle(result.done?"return":"normal",arg)}),(function(err){resume("throw",err)}))}catch(err){settle("throw",err)}}function settle(type,value){switch(type){case"return":front.resolve({value:value,done:!0});break;case"throw":front.reject(value);break;default:front.resolve({value:value,done:!1})}(front=front.next)?resume(front.key,front.arg):back=null}this._invoke=function(key,arg){return new Promise((function(resolve,reject){var request={key:key,arg:arg,resolve:resolve,reject:reject,next:null};back?back=back.next=request:(front=back=request,resume(key,arg))}))},"function"!=typeof gen.return&&(this.return=void 0)}AsyncGenerator.prototype["function"==typeof Symbol&&Symbol.asyncIterator||"@@asyncIterator"]=function(){return this},AsyncGenerator.prototype.next=function(arg){return this._invoke("next",arg)},AsyncGenerator.prototype.throw=function(arg){return this._invoke("throw",arg)},AsyncGenerator.prototype.return=function(arg){return this._invoke("return",arg)};'),
      OverloadYield: helper("7.18.14", "export default function _OverloadYield(value,kind){this.v=value,this.k=kind}"),
      applyDecs: helper("7.17.8", 'function old_createMetadataMethodsForProperty(metadataMap,kind,property,decoratorFinishedRef){return{getMetadata:function(key){old_assertNotFinished(decoratorFinishedRef,"getMetadata"),old_assertMetadataKey(key);var metadataForKey=metadataMap[key];if(void 0!==metadataForKey)if(1===kind){var pub=metadataForKey.public;if(void 0!==pub)return pub[property]}else if(2===kind){var priv=metadataForKey.private;if(void 0!==priv)return priv.get(property)}else if(Object.hasOwnProperty.call(metadataForKey,"constructor"))return metadataForKey.constructor},setMetadata:function(key,value){old_assertNotFinished(decoratorFinishedRef,"setMetadata"),old_assertMetadataKey(key);var metadataForKey=metadataMap[key];if(void 0===metadataForKey&&(metadataForKey=metadataMap[key]={}),1===kind){var pub=metadataForKey.public;void 0===pub&&(pub=metadataForKey.public={}),pub[property]=value}else if(2===kind){var priv=metadataForKey.priv;void 0===priv&&(priv=metadataForKey.private=new Map),priv.set(property,value)}else metadataForKey.constructor=value}}}function old_convertMetadataMapToFinal(obj,metadataMap){var parentMetadataMap=obj[Symbol.metadata||Symbol.for("Symbol.metadata")],metadataKeys=Object.getOwnPropertySymbols(metadataMap);if(0!==metadataKeys.length){for(var i=0;i<metadataKeys.length;i++){var key=metadataKeys[i],metaForKey=metadataMap[key],parentMetaForKey=parentMetadataMap?parentMetadataMap[key]:null,pub=metaForKey.public,parentPub=parentMetaForKey?parentMetaForKey.public:null;pub&&parentPub&&Object.setPrototypeOf(pub,parentPub);var priv=metaForKey.private;if(priv){var privArr=Array.from(priv.values()),parentPriv=parentMetaForKey?parentMetaForKey.private:null;parentPriv&&(privArr=privArr.concat(parentPriv)),metaForKey.private=privArr}parentMetaForKey&&Object.setPrototypeOf(metaForKey,parentMetaForKey)}parentMetadataMap&&Object.setPrototypeOf(metadataMap,parentMetadataMap),obj[Symbol.metadata||Symbol.for("Symbol.metadata")]=metadataMap}}function old_createAddInitializerMethod(initializers,decoratorFinishedRef){return function(initializer){old_assertNotFinished(decoratorFinishedRef,"addInitializer"),old_assertCallable(initializer,"An initializer"),initializers.push(initializer)}}function old_memberDec(dec,name,desc,metadataMap,initializers,kind,isStatic,isPrivate,value){var kindStr;switch(kind){case 1:kindStr="accessor";break;case 2:kindStr="method";break;case 3:kindStr="getter";break;case 4:kindStr="setter";break;default:kindStr="field"}var metadataKind,metadataName,ctx={kind:kindStr,name:isPrivate?"#"+name:name,isStatic:isStatic,isPrivate:isPrivate},decoratorFinishedRef={v:!1};if(0!==kind&&(ctx.addInitializer=old_createAddInitializerMethod(initializers,decoratorFinishedRef)),isPrivate){metadataKind=2,metadataName=Symbol(name);var access={};0===kind?(access.get=desc.get,access.set=desc.set):2===kind?access.get=function(){return desc.value}:(1!==kind&&3!==kind||(access.get=function(){return desc.get.call(this)}),1!==kind&&4!==kind||(access.set=function(v){desc.set.call(this,v)})),ctx.access=access}else metadataKind=1,metadataName=name;try{return dec(value,Object.assign(ctx,old_createMetadataMethodsForProperty(metadataMap,metadataKind,metadataName,decoratorFinishedRef)))}finally{decoratorFinishedRef.v=!0}}function old_assertNotFinished(decoratorFinishedRef,fnName){if(decoratorFinishedRef.v)throw new Error("attempted to call "+fnName+" after decoration was finished")}function old_assertMetadataKey(key){if("symbol"!=typeof key)throw new TypeError("Metadata keys must be symbols, received: "+key)}function old_assertCallable(fn,hint){if("function"!=typeof fn)throw new TypeError(hint+" must be a function")}function old_assertValidReturnValue(kind,value){var type=typeof value;if(1===kind){if("object"!==type||null===value)throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");void 0!==value.get&&old_assertCallable(value.get,"accessor.get"),void 0!==value.set&&old_assertCallable(value.set,"accessor.set"),void 0!==value.init&&old_assertCallable(value.init,"accessor.init"),void 0!==value.initializer&&old_assertCallable(value.initializer,"accessor.initializer")}else if("function"!==type){var hint;throw hint=0===kind?"field":10===kind?"class":"method",new TypeError(hint+" decorators must return a function or void 0")}}function old_getInit(desc){var initializer;return null==(initializer=desc.init)&&(initializer=desc.initializer)&&"undefined"!=typeof console&&console.warn(".initializer has been renamed to .init as of March 2022"),initializer}function old_applyMemberDec(ret,base,decInfo,name,kind,isStatic,isPrivate,metadataMap,initializers){var desc,initializer,value,newValue,get,set,decs=decInfo[0];if(isPrivate?desc=0===kind||1===kind?{get:decInfo[3],set:decInfo[4]}:3===kind?{get:decInfo[3]}:4===kind?{set:decInfo[3]}:{value:decInfo[3]}:0!==kind&&(desc=Object.getOwnPropertyDescriptor(base,name)),1===kind?value={get:desc.get,set:desc.set}:2===kind?value=desc.value:3===kind?value=desc.get:4===kind&&(value=desc.set),"function"==typeof decs)void 0!==(newValue=old_memberDec(decs,name,desc,metadataMap,initializers,kind,isStatic,isPrivate,value))&&(old_assertValidReturnValue(kind,newValue),0===kind?initializer=newValue:1===kind?(initializer=old_getInit(newValue),get=newValue.get||value.get,set=newValue.set||value.set,value={get:get,set:set}):value=newValue);else for(var i=decs.length-1;i>=0;i--){var newInit;if(void 0!==(newValue=old_memberDec(decs[i],name,desc,metadataMap,initializers,kind,isStatic,isPrivate,value)))old_assertValidReturnValue(kind,newValue),0===kind?newInit=newValue:1===kind?(newInit=old_getInit(newValue),get=newValue.get||value.get,set=newValue.set||value.set,value={get:get,set:set}):value=newValue,void 0!==newInit&&(void 0===initializer?initializer=newInit:"function"==typeof initializer?initializer=[initializer,newInit]:initializer.push(newInit))}if(0===kind||1===kind){if(void 0===initializer)initializer=function(instance,init){return init};else if("function"!=typeof initializer){var ownInitializers=initializer;initializer=function(instance,init){for(var value=init,i=0;i<ownInitializers.length;i++)value=ownInitializers[i].call(instance,value);return value}}else{var originalInitializer=initializer;initializer=function(instance,init){return originalInitializer.call(instance,init)}}ret.push(initializer)}0!==kind&&(1===kind?(desc.get=value.get,desc.set=value.set):2===kind?desc.value=value:3===kind?desc.get=value:4===kind&&(desc.set=value),isPrivate?1===kind?(ret.push((function(instance,args){return value.get.call(instance,args)})),ret.push((function(instance,args){return value.set.call(instance,args)}))):2===kind?ret.push(value):ret.push((function(instance,args){return value.call(instance,args)})):Object.defineProperty(base,name,desc))}function old_applyMemberDecs(ret,Class,protoMetadataMap,staticMetadataMap,decInfos){for(var protoInitializers,staticInitializers,existingProtoNonFields=new Map,existingStaticNonFields=new Map,i=0;i<decInfos.length;i++){var decInfo=decInfos[i];if(Array.isArray(decInfo)){var base,metadataMap,initializers,kind=decInfo[1],name=decInfo[2],isPrivate=decInfo.length>3,isStatic=kind>=5;if(isStatic?(base=Class,metadataMap=staticMetadataMap,0!==(kind-=5)&&(initializers=staticInitializers=staticInitializers||[])):(base=Class.prototype,metadataMap=protoMetadataMap,0!==kind&&(initializers=protoInitializers=protoInitializers||[])),0!==kind&&!isPrivate){var existingNonFields=isStatic?existingStaticNonFields:existingProtoNonFields,existingKind=existingNonFields.get(name)||0;if(!0===existingKind||3===existingKind&&4!==kind||4===existingKind&&3!==kind)throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: "+name);!existingKind&&kind>2?existingNonFields.set(name,kind):existingNonFields.set(name,!0)}old_applyMemberDec(ret,base,decInfo,name,kind,isStatic,isPrivate,metadataMap,initializers)}}old_pushInitializers(ret,protoInitializers),old_pushInitializers(ret,staticInitializers)}function old_pushInitializers(ret,initializers){initializers&&ret.push((function(instance){for(var i=0;i<initializers.length;i++)initializers[i].call(instance);return instance}))}function old_applyClassDecs(ret,targetClass,metadataMap,classDecs){if(classDecs.length>0){for(var initializers=[],newClass=targetClass,name=targetClass.name,i=classDecs.length-1;i>=0;i--){var decoratorFinishedRef={v:!1};try{var ctx=Object.assign({kind:"class",name:name,addInitializer:old_createAddInitializerMethod(initializers,decoratorFinishedRef)},old_createMetadataMethodsForProperty(metadataMap,0,name,decoratorFinishedRef)),nextNewClass=classDecs[i](newClass,ctx)}finally{decoratorFinishedRef.v=!0}void 0!==nextNewClass&&(old_assertValidReturnValue(10,nextNewClass),newClass=nextNewClass)}ret.push(newClass,(function(){for(var i=0;i<initializers.length;i++)initializers[i].call(newClass)}))}}export default function applyDecs(targetClass,memberDecs,classDecs){var ret=[],staticMetadataMap={},protoMetadataMap={};return old_applyMemberDecs(ret,targetClass,protoMetadataMap,staticMetadataMap,memberDecs),old_convertMetadataMapToFinal(targetClass.prototype,protoMetadataMap),old_applyClassDecs(ret,targetClass,staticMetadataMap,classDecs),old_convertMetadataMapToFinal(targetClass,staticMetadataMap),ret}'),
      applyDecs2203: helper("7.19.0", 'function createAddInitializerMethod(initializers,decoratorFinishedRef){return function(initializer){assertNotFinished(decoratorFinishedRef,"addInitializer"),assertCallable(initializer,"An initializer"),initializers.push(initializer)}}function memberDec(dec,name,desc,initializers,kind,isStatic,isPrivate,value){var kindStr;switch(kind){case 1:kindStr="accessor";break;case 2:kindStr="method";break;case 3:kindStr="getter";break;case 4:kindStr="setter";break;default:kindStr="field"}var get,set,ctx={kind:kindStr,name:isPrivate?"#"+name:name,static:isStatic,private:isPrivate},decoratorFinishedRef={v:!1};0!==kind&&(ctx.addInitializer=createAddInitializerMethod(initializers,decoratorFinishedRef)),0===kind?isPrivate?(get=desc.get,set=desc.set):(get=function(){return this[name]},set=function(v){this[name]=v}):2===kind?get=function(){return desc.value}:(1!==kind&&3!==kind||(get=function(){return desc.get.call(this)}),1!==kind&&4!==kind||(set=function(v){desc.set.call(this,v)})),ctx.access=get&&set?{get:get,set:set}:get?{get:get}:{set:set};try{return dec(value,ctx)}finally{decoratorFinishedRef.v=!0}}function assertNotFinished(decoratorFinishedRef,fnName){if(decoratorFinishedRef.v)throw new Error("attempted to call "+fnName+" after decoration was finished")}function assertCallable(fn,hint){if("function"!=typeof fn)throw new TypeError(hint+" must be a function")}function assertValidReturnValue(kind,value){var type=typeof value;if(1===kind){if("object"!==type||null===value)throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");void 0!==value.get&&assertCallable(value.get,"accessor.get"),void 0!==value.set&&assertCallable(value.set,"accessor.set"),void 0!==value.init&&assertCallable(value.init,"accessor.init")}else if("function"!==type){var hint;throw hint=0===kind?"field":10===kind?"class":"method",new TypeError(hint+" decorators must return a function or void 0")}}function applyMemberDec(ret,base,decInfo,name,kind,isStatic,isPrivate,initializers){var desc,init,value,newValue,get,set,decs=decInfo[0];if(isPrivate?desc=0===kind||1===kind?{get:decInfo[3],set:decInfo[4]}:3===kind?{get:decInfo[3]}:4===kind?{set:decInfo[3]}:{value:decInfo[3]}:0!==kind&&(desc=Object.getOwnPropertyDescriptor(base,name)),1===kind?value={get:desc.get,set:desc.set}:2===kind?value=desc.value:3===kind?value=desc.get:4===kind&&(value=desc.set),"function"==typeof decs)void 0!==(newValue=memberDec(decs,name,desc,initializers,kind,isStatic,isPrivate,value))&&(assertValidReturnValue(kind,newValue),0===kind?init=newValue:1===kind?(init=newValue.init,get=newValue.get||value.get,set=newValue.set||value.set,value={get:get,set:set}):value=newValue);else for(var i=decs.length-1;i>=0;i--){var newInit;if(void 0!==(newValue=memberDec(decs[i],name,desc,initializers,kind,isStatic,isPrivate,value)))assertValidReturnValue(kind,newValue),0===kind?newInit=newValue:1===kind?(newInit=newValue.init,get=newValue.get||value.get,set=newValue.set||value.set,value={get:get,set:set}):value=newValue,void 0!==newInit&&(void 0===init?init=newInit:"function"==typeof init?init=[init,newInit]:init.push(newInit))}if(0===kind||1===kind){if(void 0===init)init=function(instance,init){return init};else if("function"!=typeof init){var ownInitializers=init;init=function(instance,init){for(var value=init,i=0;i<ownInitializers.length;i++)value=ownInitializers[i].call(instance,value);return value}}else{var originalInitializer=init;init=function(instance,init){return originalInitializer.call(instance,init)}}ret.push(init)}0!==kind&&(1===kind?(desc.get=value.get,desc.set=value.set):2===kind?desc.value=value:3===kind?desc.get=value:4===kind&&(desc.set=value),isPrivate?1===kind?(ret.push((function(instance,args){return value.get.call(instance,args)})),ret.push((function(instance,args){return value.set.call(instance,args)}))):2===kind?ret.push(value):ret.push((function(instance,args){return value.call(instance,args)})):Object.defineProperty(base,name,desc))}function applyMemberDecs(ret,Class,decInfos){for(var protoInitializers,staticInitializers,existingProtoNonFields=new Map,existingStaticNonFields=new Map,i=0;i<decInfos.length;i++){var decInfo=decInfos[i];if(Array.isArray(decInfo)){var base,initializers,kind=decInfo[1],name=decInfo[2],isPrivate=decInfo.length>3,isStatic=kind>=5;if(isStatic?(base=Class,0!==(kind-=5)&&(initializers=staticInitializers=staticInitializers||[])):(base=Class.prototype,0!==kind&&(initializers=protoInitializers=protoInitializers||[])),0!==kind&&!isPrivate){var existingNonFields=isStatic?existingStaticNonFields:existingProtoNonFields,existingKind=existingNonFields.get(name)||0;if(!0===existingKind||3===existingKind&&4!==kind||4===existingKind&&3!==kind)throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: "+name);!existingKind&&kind>2?existingNonFields.set(name,kind):existingNonFields.set(name,!0)}applyMemberDec(ret,base,decInfo,name,kind,isStatic,isPrivate,initializers)}}pushInitializers(ret,protoInitializers),pushInitializers(ret,staticInitializers)}function pushInitializers(ret,initializers){initializers&&ret.push((function(instance){for(var i=0;i<initializers.length;i++)initializers[i].call(instance);return instance}))}function applyClassDecs(ret,targetClass,classDecs){if(classDecs.length>0){for(var initializers=[],newClass=targetClass,name=targetClass.name,i=classDecs.length-1;i>=0;i--){var decoratorFinishedRef={v:!1};try{var nextNewClass=classDecs[i](newClass,{kind:"class",name:name,addInitializer:createAddInitializerMethod(initializers,decoratorFinishedRef)})}finally{decoratorFinishedRef.v=!0}void 0!==nextNewClass&&(assertValidReturnValue(10,nextNewClass),newClass=nextNewClass)}ret.push(newClass,(function(){for(var i=0;i<initializers.length;i++)initializers[i].call(newClass)}))}}export default function applyDecs2203(targetClass,memberDecs,classDecs){var ret=[];return applyMemberDecs(ret,targetClass,memberDecs),applyClassDecs(ret,targetClass,classDecs),ret}'),
      asyncGeneratorDelegate: helper("7.0.0-beta.0", 'import OverloadYield from"OverloadYield";export default function _asyncGeneratorDelegate(inner){var iter={},waiting=!1;function pump(key,value){return waiting=!0,value=new Promise((function(resolve){resolve(inner[key](value))})),{done:!1,value:new OverloadYield(value,1)}}return iter["undefined"!=typeof Symbol&&Symbol.iterator||"@@iterator"]=function(){return this},iter.next=function(value){return waiting?(waiting=!1,value):pump("next",value)},"function"==typeof inner.throw&&(iter.throw=function(value){if(waiting)throw waiting=!1,value;return pump("throw",value)}),"function"==typeof inner.return&&(iter.return=function(value){return waiting?(waiting=!1,value):pump("return",value)}),iter}'),
      asyncIterator: helper("7.15.9", 'export default function _asyncIterator(iterable){var method,async,sync,retry=2;for("undefined"!=typeof Symbol&&(async=Symbol.asyncIterator,sync=Symbol.iterator);retry--;){if(async&&null!=(method=iterable[async]))return method.call(iterable);if(sync&&null!=(method=iterable[sync]))return new AsyncFromSyncIterator(method.call(iterable));async="@@asyncIterator",sync="@@iterator"}throw new TypeError("Object is not async iterable")}function AsyncFromSyncIterator(s){function AsyncFromSyncIteratorContinuation(r){if(Object(r)!==r)return Promise.reject(new TypeError(r+" is not an object."));var done=r.done;return Promise.resolve(r.value).then((function(value){return{value:value,done:done}}))}return AsyncFromSyncIterator=function(s){this.s=s,this.n=s.next},AsyncFromSyncIterator.prototype={s:null,n:null,next:function(){return AsyncFromSyncIteratorContinuation(this.n.apply(this.s,arguments))},return:function(value){var ret=this.s.return;return void 0===ret?Promise.resolve({value:value,done:!0}):AsyncFromSyncIteratorContinuation(ret.apply(this.s,arguments))},throw:function(value){var thr=this.s.return;return void 0===thr?Promise.reject(value):AsyncFromSyncIteratorContinuation(thr.apply(this.s,arguments))}},new AsyncFromSyncIterator(s)}'),
      awaitAsyncGenerator: helper("7.0.0-beta.0", 'import OverloadYield from"OverloadYield";export default function _awaitAsyncGenerator(value){return new OverloadYield(value,0)}'),
      checkInRHS: helper("7.20.5", `export default function _checkInRHS(value){if(Object(value)!==value)throw TypeError("right-hand side of 'in' should be an object, got "+(null!==value?typeof value:"null"));return value}`),
      defineAccessor: helper("7.20.7", "export default function _defineAccessor(type,obj,key,fn){var desc={configurable:!0,enumerable:!0};return desc[type]=fn,Object.defineProperty(obj,key,desc)}"),
      iterableToArrayLimit: helper("7.0.0-beta.0", 'export default function _iterableToArrayLimit(arr,i){var _i=null==arr?null:"undefined"!=typeof Symbol&&arr[Symbol.iterator]||arr["@@iterator"];if(null!=_i){var _s,_e,_x,_r,_arr=[],_n=!0,_d=!1;try{if(_x=(_i=_i.call(arr)).next,0===i){if(Object(_i)!==_i)return;_n=!1}else for(;!(_n=(_s=_x.call(_i)).done)&&(_arr.push(_s.value),_arr.length!==i);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=_i.return&&(_r=_i.return(),Object(_r)!==_r))return}finally{if(_d)throw _e}}return _arr}}'),
      iterableToArrayLimitLoose: helper("7.0.0-beta.0", 'export default function _iterableToArrayLimitLoose(arr,i){var _i=arr&&("undefined"!=typeof Symbol&&arr[Symbol.iterator]||arr["@@iterator"]);if(null!=_i){var _s,_arr=[];for(_i=_i.call(arr);arr.length<i&&!(_s=_i.next()).done;)_arr.push(_s.value);return _arr}}'),
      jsx: helper("7.0.0-beta.0", 'var REACT_ELEMENT_TYPE;export default function _createRawReactElement(type,props,key,children){REACT_ELEMENT_TYPE||(REACT_ELEMENT_TYPE="function"==typeof Symbol&&Symbol.for&&Symbol.for("react.element")||60103);var defaultProps=type&&type.defaultProps,childrenLength=arguments.length-3;if(props||0===childrenLength||(props={children:void 0}),1===childrenLength)props.children=children;else if(childrenLength>1){for(var childArray=new Array(childrenLength),i=0;i<childrenLength;i++)childArray[i]=arguments[i+3];props.children=childArray}if(props&&defaultProps)for(var propName in defaultProps)void 0===props[propName]&&(props[propName]=defaultProps[propName]);else props||(props=defaultProps||{});return{$$typeof:REACT_ELEMENT_TYPE,type:type,key:void 0===key?null:""+key,ref:null,props:props,_owner:null}}'),
      objectSpread2: helper("7.5.0", 'import defineProperty from"defineProperty";function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter((function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}))),keys.push.apply(keys,symbols)}return keys}export default function _objectSpread2(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach((function(key){defineProperty(target,key,source[key])})):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach((function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))}))}return target}'),
      regeneratorRuntime: helper("7.18.0", `export default function _regeneratorRuntime(){"use strict";
/*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/facebook/regenerator/blob/main/LICENSE */_regeneratorRuntime=function(){return exports};var exports={},Op=Object.prototype,hasOwn=Op.hasOwnProperty,defineProperty=Object.defineProperty||function(obj,key,desc){obj[key]=desc.value},$Symbol="function"==typeof Symbol?Symbol:{},iteratorSymbol=$Symbol.iterator||"@@iterator",asyncIteratorSymbol=$Symbol.asyncIterator||"@@asyncIterator",toStringTagSymbol=$Symbol.toStringTag||"@@toStringTag";function define(obj,key,value){return Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}),obj[key]}try{define({},"")}catch(err){define=function(obj,key,value){return obj[key]=value}}function wrap(innerFn,outerFn,self,tryLocsList){var protoGenerator=outerFn&&outerFn.prototype instanceof Generator?outerFn:Generator,generator=Object.create(protoGenerator.prototype),context=new Context(tryLocsList||[]);return defineProperty(generator,"_invoke",{value:makeInvokeMethod(innerFn,self,context)}),generator}function tryCatch(fn,obj,arg){try{return{type:"normal",arg:fn.call(obj,arg)}}catch(err){return{type:"throw",arg:err}}}exports.wrap=wrap;var ContinueSentinel={};function Generator(){}function GeneratorFunction(){}function GeneratorFunctionPrototype(){}var IteratorPrototype={};define(IteratorPrototype,iteratorSymbol,(function(){return this}));var getProto=Object.getPrototypeOf,NativeIteratorPrototype=getProto&&getProto(getProto(values([])));NativeIteratorPrototype&&NativeIteratorPrototype!==Op&&hasOwn.call(NativeIteratorPrototype,iteratorSymbol)&&(IteratorPrototype=NativeIteratorPrototype);var Gp=GeneratorFunctionPrototype.prototype=Generator.prototype=Object.create(IteratorPrototype);function defineIteratorMethods(prototype){["next","throw","return"].forEach((function(method){define(prototype,method,(function(arg){return this._invoke(method,arg)}))}))}function AsyncIterator(generator,PromiseImpl){function invoke(method,arg,resolve,reject){var record=tryCatch(generator[method],generator,arg);if("throw"!==record.type){var result=record.arg,value=result.value;return value&&"object"==typeof value&&hasOwn.call(value,"__await")?PromiseImpl.resolve(value.__await).then((function(value){invoke("next",value,resolve,reject)}),(function(err){invoke("throw",err,resolve,reject)})):PromiseImpl.resolve(value).then((function(unwrapped){result.value=unwrapped,resolve(result)}),(function(error){return invoke("throw",error,resolve,reject)}))}reject(record.arg)}var previousPromise;defineProperty(this,"_invoke",{value:function(method,arg){function callInvokeWithMethodAndArg(){return new PromiseImpl((function(resolve,reject){invoke(method,arg,resolve,reject)}))}return previousPromise=previousPromise?previousPromise.then(callInvokeWithMethodAndArg,callInvokeWithMethodAndArg):callInvokeWithMethodAndArg()}})}function makeInvokeMethod(innerFn,self,context){var state="suspendedStart";return function(method,arg){if("executing"===state)throw new Error("Generator is already running");if("completed"===state){if("throw"===method)throw arg;return doneResult()}for(context.method=method,context.arg=arg;;){var delegate=context.delegate;if(delegate){var delegateResult=maybeInvokeDelegate(delegate,context);if(delegateResult){if(delegateResult===ContinueSentinel)continue;return delegateResult}}if("next"===context.method)context.sent=context._sent=context.arg;else if("throw"===context.method){if("suspendedStart"===state)throw state="completed",context.arg;context.dispatchException(context.arg)}else"return"===context.method&&context.abrupt("return",context.arg);state="executing";var record=tryCatch(innerFn,self,context);if("normal"===record.type){if(state=context.done?"completed":"suspendedYield",record.arg===ContinueSentinel)continue;return{value:record.arg,done:context.done}}"throw"===record.type&&(state="completed",context.method="throw",context.arg=record.arg)}}}function maybeInvokeDelegate(delegate,context){var methodName=context.method,method=delegate.iterator[methodName];if(undefined===method)return context.delegate=null,"throw"===methodName&&delegate.iterator.return&&(context.method="return",context.arg=undefined,maybeInvokeDelegate(delegate,context),"throw"===context.method)||"return"!==methodName&&(context.method="throw",context.arg=new TypeError("The iterator does not provide a '"+methodName+"' method")),ContinueSentinel;var record=tryCatch(method,delegate.iterator,context.arg);if("throw"===record.type)return context.method="throw",context.arg=record.arg,context.delegate=null,ContinueSentinel;var info=record.arg;return info?info.done?(context[delegate.resultName]=info.value,context.next=delegate.nextLoc,"return"!==context.method&&(context.method="next",context.arg=undefined),context.delegate=null,ContinueSentinel):info:(context.method="throw",context.arg=new TypeError("iterator result is not an object"),context.delegate=null,ContinueSentinel)}function pushTryEntry(locs){var entry={tryLoc:locs[0]};1 in locs&&(entry.catchLoc=locs[1]),2 in locs&&(entry.finallyLoc=locs[2],entry.afterLoc=locs[3]),this.tryEntries.push(entry)}function resetTryEntry(entry){var record=entry.completion||{};record.type="normal",delete record.arg,entry.completion=record}function Context(tryLocsList){this.tryEntries=[{tryLoc:"root"}],tryLocsList.forEach(pushTryEntry,this),this.reset(!0)}function values(iterable){if(iterable){var iteratorMethod=iterable[iteratorSymbol];if(iteratorMethod)return iteratorMethod.call(iterable);if("function"==typeof iterable.next)return iterable;if(!isNaN(iterable.length)){var i=-1,next=function next(){for(;++i<iterable.length;)if(hasOwn.call(iterable,i))return next.value=iterable[i],next.done=!1,next;return next.value=undefined,next.done=!0,next};return next.next=next}}return{next:doneResult}}function doneResult(){return{value:undefined,done:!0}}return GeneratorFunction.prototype=GeneratorFunctionPrototype,defineProperty(Gp,"constructor",{value:GeneratorFunctionPrototype,configurable:!0}),defineProperty(GeneratorFunctionPrototype,"constructor",{value:GeneratorFunction,configurable:!0}),GeneratorFunction.displayName=define(GeneratorFunctionPrototype,toStringTagSymbol,"GeneratorFunction"),exports.isGeneratorFunction=function(genFun){var ctor="function"==typeof genFun&&genFun.constructor;return!!ctor&&(ctor===GeneratorFunction||"GeneratorFunction"===(ctor.displayName||ctor.name))},exports.mark=function(genFun){return Object.setPrototypeOf?Object.setPrototypeOf(genFun,GeneratorFunctionPrototype):(genFun.__proto__=GeneratorFunctionPrototype,define(genFun,toStringTagSymbol,"GeneratorFunction")),genFun.prototype=Object.create(Gp),genFun},exports.awrap=function(arg){return{__await:arg}},defineIteratorMethods(AsyncIterator.prototype),define(AsyncIterator.prototype,asyncIteratorSymbol,(function(){return this})),exports.AsyncIterator=AsyncIterator,exports.async=function(innerFn,outerFn,self,tryLocsList,PromiseImpl){void 0===PromiseImpl&&(PromiseImpl=Promise);var iter=new AsyncIterator(wrap(innerFn,outerFn,self,tryLocsList),PromiseImpl);return exports.isGeneratorFunction(outerFn)?iter:iter.next().then((function(result){return result.done?result.value:iter.next()}))},defineIteratorMethods(Gp),define(Gp,toStringTagSymbol,"Generator"),define(Gp,iteratorSymbol,(function(){return this})),define(Gp,"toString",(function(){return"[object Generator]"})),exports.keys=function(val){var object=Object(val),keys=[];for(var key in object)keys.push(key);return keys.reverse(),function next(){for(;keys.length;){var key=keys.pop();if(key in object)return next.value=key,next.done=!1,next}return next.done=!0,next}},exports.values=values,Context.prototype={constructor:Context,reset:function(skipTempReset){if(this.prev=0,this.next=0,this.sent=this._sent=undefined,this.done=!1,this.delegate=null,this.method="next",this.arg=undefined,this.tryEntries.forEach(resetTryEntry),!skipTempReset)for(var name in this)"t"===name.charAt(0)&&hasOwn.call(this,name)&&!isNaN(+name.slice(1))&&(this[name]=undefined)},stop:function(){this.done=!0;var rootRecord=this.tryEntries[0].completion;if("throw"===rootRecord.type)throw rootRecord.arg;return this.rval},dispatchException:function(exception){if(this.done)throw exception;var context=this;function handle(loc,caught){return record.type="throw",record.arg=exception,context.next=loc,caught&&(context.method="next",context.arg=undefined),!!caught}for(var i=this.tryEntries.length-1;i>=0;--i){var entry=this.tryEntries[i],record=entry.completion;if("root"===entry.tryLoc)return handle("end");if(entry.tryLoc<=this.prev){var hasCatch=hasOwn.call(entry,"catchLoc"),hasFinally=hasOwn.call(entry,"finallyLoc");if(hasCatch&&hasFinally){if(this.prev<entry.catchLoc)return handle(entry.catchLoc,!0);if(this.prev<entry.finallyLoc)return handle(entry.finallyLoc)}else if(hasCatch){if(this.prev<entry.catchLoc)return handle(entry.catchLoc,!0)}else{if(!hasFinally)throw new Error("try statement without catch or finally");if(this.prev<entry.finallyLoc)return handle(entry.finallyLoc)}}}},abrupt:function(type,arg){for(var i=this.tryEntries.length-1;i>=0;--i){var entry=this.tryEntries[i];if(entry.tryLoc<=this.prev&&hasOwn.call(entry,"finallyLoc")&&this.prev<entry.finallyLoc){var finallyEntry=entry;break}}finallyEntry&&("break"===type||"continue"===type)&&finallyEntry.tryLoc<=arg&&arg<=finallyEntry.finallyLoc&&(finallyEntry=null);var record=finallyEntry?finallyEntry.completion:{};return record.type=type,record.arg=arg,finallyEntry?(this.method="next",this.next=finallyEntry.finallyLoc,ContinueSentinel):this.complete(record)},complete:function(record,afterLoc){if("throw"===record.type)throw record.arg;return"break"===record.type||"continue"===record.type?this.next=record.arg:"return"===record.type?(this.rval=this.arg=record.arg,this.method="return",this.next="end"):"normal"===record.type&&afterLoc&&(this.next=afterLoc),ContinueSentinel},finish:function(finallyLoc){for(var i=this.tryEntries.length-1;i>=0;--i){var entry=this.tryEntries[i];if(entry.finallyLoc===finallyLoc)return this.complete(entry.completion,entry.afterLoc),resetTryEntry(entry),ContinueSentinel}},catch:function(tryLoc){for(var i=this.tryEntries.length-1;i>=0;--i){var entry=this.tryEntries[i];if(entry.tryLoc===tryLoc){var record=entry.completion;if("throw"===record.type){var thrown=record.arg;resetTryEntry(entry)}return thrown}}throw new Error("illegal catch attempt")},delegateYield:function(iterable,resultName,nextLoc){return this.delegate={iterator:values(iterable),resultName:resultName,nextLoc:nextLoc},"next"===this.method&&(this.arg=undefined),ContinueSentinel}},exports}`),
      typeof: helper("7.0.0-beta.0", 'export default function _typeof(obj){"@babel/helpers - typeof";return _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"==typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj},_typeof(obj)}'),
      wrapRegExp: helper("7.19.0", 'import setPrototypeOf from"setPrototypeOf";import inherits from"inherits";export default function _wrapRegExp(){_wrapRegExp=function(re,groups){return new BabelRegExp(re,void 0,groups)};var _super=RegExp.prototype,_groups=new WeakMap;function BabelRegExp(re,flags,groups){var _this=new RegExp(re,flags);return _groups.set(_this,groups||_groups.get(re)),setPrototypeOf(_this,BabelRegExp.prototype)}function buildGroups(result,re){var g=_groups.get(re);return Object.keys(g).reduce((function(groups,name){var i=g[name];if("number"==typeof i)groups[name]=result[i];else{for(var k=0;void 0===result[i[k]]&&k+1<i.length;)k++;groups[name]=result[i[k]]}return groups}),Object.create(null))}return inherits(BabelRegExp,RegExp),BabelRegExp.prototype.exec=function(str){var result=_super.exec.call(this,str);if(result){result.groups=buildGroups(result,this);var indices=result.indices;indices&&(indices.groups=buildGroups(indices,this))}return result},BabelRegExp.prototype[Symbol.replace]=function(str,substitution){if("string"==typeof substitution){var groups=_groups.get(this);return _super[Symbol.replace].call(this,str,substitution.replace(/\\$<([^>]+)>/g,(function(_,name){var group=groups[name];return"$"+(Array.isArray(group)?group.join("$"):group)})))}if("function"==typeof substitution){var _this=this;return _super[Symbol.replace].call(this,str,(function(){var args=arguments;return"object"!=typeof args[args.length-1]&&(args=[].slice.call(args)).push(buildGroups(args,_this)),substitution.apply(this,args)}))}return _super[Symbol.replace].call(this,str,substitution)},_wrapRegExp.apply(this,arguments)}')
    });
    exports.default = _default;
  }
});

// node_modules/@babel/helpers/lib/helpers.js
var require_helpers = __commonJS({
  "node_modules/@babel/helpers/lib/helpers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _template = require_lib18();
    var _helpersGenerated = require_helpers_generated();
    var helpers = Object.assign({
      __proto__: null
    }, _helpersGenerated.default);
    var _default = helpers;
    exports.default = _default;
    var helper = (minVersion) => (tpl) => ({
      minVersion,
      ast: () => _template.default.program.ast(tpl)
    });
    {
      helpers.AwaitValue = helper("7.0.0-beta.0")`
    export default function _AwaitValue(value) {
      this.wrapped = value;
    }
  `;
    }
    helpers.wrapAsyncGenerator = helper("7.0.0-beta.0")`
  import AsyncGenerator from "AsyncGenerator";

  export default function _wrapAsyncGenerator(fn) {
    return function () {
      return new AsyncGenerator(fn.apply(this, arguments));
    };
  }
`;
    helpers.asyncToGenerator = helper("7.0.0-beta.0")`
  function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
      var info = gen[key](arg);
      var value = info.value;
    } catch (error) {
      reject(error);
      return;
    }

    if (info.done) {
      resolve(value);
    } else {
      Promise.resolve(value).then(_next, _throw);
    }
  }

  export default function _asyncToGenerator(fn) {
    return function () {
      var self = this, args = arguments;
      return new Promise(function (resolve, reject) {
        var gen = fn.apply(self, args);
        function _next(value) {
          asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
        }
        function _throw(err) {
          asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
        }

        _next(undefined);
      });
    };
  }
`;
    helpers.classCallCheck = helper("7.0.0-beta.0")`
  export default function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }
`;
    helpers.createClass = helper("7.0.0-beta.0")`
  import toPropertyKey from "toPropertyKey";
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i ++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, toPropertyKey(descriptor.key), descriptor);
    }
  }

  export default function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", { writable: false });
    return Constructor;
  }
`;
    helpers.defineEnumerableProperties = helper("7.0.0-beta.0")`
  export default function _defineEnumerableProperties(obj, descs) {
    for (var key in descs) {
      var desc = descs[key];
      desc.configurable = desc.enumerable = true;
      if ("value" in desc) desc.writable = true;
      Object.defineProperty(obj, key, desc);
    }

    // Symbols are not enumerated over by for-in loops. If native
    // Symbols are available, fetch all of the descs object's own
    // symbol properties and define them on our target object too.
    if (Object.getOwnPropertySymbols) {
      var objectSymbols = Object.getOwnPropertySymbols(descs);
      for (var i = 0; i < objectSymbols.length; i++) {
        var sym = objectSymbols[i];
        var desc = descs[sym];
        desc.configurable = desc.enumerable = true;
        if ("value" in desc) desc.writable = true;
        Object.defineProperty(obj, sym, desc);
      }
    }
    return obj;
  }
`;
    helpers.defaults = helper("7.0.0-beta.0")`
  export default function _defaults(obj, defaults) {
    var keys = Object.getOwnPropertyNames(defaults);
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];
      var value = Object.getOwnPropertyDescriptor(defaults, key);
      if (value && value.configurable && obj[key] === undefined) {
        Object.defineProperty(obj, key, value);
      }
    }
    return obj;
  }
`;
    helpers.defineProperty = helper("7.0.0-beta.0")`
  import toPropertyKey from "toPropertyKey";
  export default function _defineProperty(obj, key, value) {
    key = toPropertyKey(key);
    // Shortcircuit the slow defineProperty path when possible.
    // We are trying to avoid issues where setters defined on the
    // prototype cause side effects under the fast path of simple
    // assignment. By checking for existence of the property with
    // the in operator, we can optimize most of this overhead away.
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }
    return obj;
  }
`;
    helpers.extends = helper("7.0.0-beta.0")`
  export default function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];
        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }
      return target;
    };

    return _extends.apply(this, arguments);
  }
`;
    helpers.objectSpread = helper("7.0.0-beta.0")`
  import defineProperty from "defineProperty";

  export default function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = (arguments[i] != null) ? Object(arguments[i]) : {};
      var ownKeys = Object.keys(source);
      if (typeof Object.getOwnPropertySymbols === 'function') {
        ownKeys.push.apply(ownKeys, Object.getOwnPropertySymbols(source).filter(function(sym) {
          return Object.getOwnPropertyDescriptor(source, sym).enumerable;
        }));
      }
      ownKeys.forEach(function(key) {
        defineProperty(target, key, source[key]);
      });
    }
    return target;
  }
`;
    helpers.inherits = helper("7.0.0-beta.0")`
  import setPrototypeOf from "setPrototypeOf";

  export default function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }
    // We can't use defineProperty to set the prototype in a single step because it
    // doesn't work in Chrome <= 36. https://github.com/babel/babel/issues/14056
    // V8 bug: https://bugs.chromium.org/p/v8/issues/detail?id=3334
    subClass.prototype = Object.create(superClass && superClass.prototype, {
      constructor: {
        value: subClass,
        writable: true,
        configurable: true
      }
    });
    Object.defineProperty(subClass, "prototype", { writable: false });
    if (superClass) setPrototypeOf(subClass, superClass);
  }
`;
    helpers.inheritsLoose = helper("7.0.0-beta.0")`
  import setPrototypeOf from "setPrototypeOf";

  export default function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    setPrototypeOf(subClass, superClass);
  }
`;
    helpers.getPrototypeOf = helper("7.0.0-beta.0")`
  export default function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf
      ? Object.getPrototypeOf.bind()
      : function _getPrototypeOf(o) {
          return o.__proto__ || Object.getPrototypeOf(o);
        };
    return _getPrototypeOf(o);
  }
`;
    helpers.setPrototypeOf = helper("7.0.0-beta.0")`
  export default function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf
      ? Object.setPrototypeOf.bind()
      : function _setPrototypeOf(o, p) {
          o.__proto__ = p;
          return o;
        };
    return _setPrototypeOf(o, p);
  }
`;
    helpers.isNativeReflectConstruct = helper("7.9.0")`
  export default function _isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;

    // core-js@3
    if (Reflect.construct.sham) return false;

    // Proxy can't be polyfilled. Every browser implemented
    // proxies before or at the same time as Reflect.construct,
    // so if they support Proxy they also support Reflect.construct.
    if (typeof Proxy === "function") return true;

    // Since Reflect.construct can't be properly polyfilled, some
    // implementations (e.g. core-js@2) don't set the correct internal slots.
    // Those polyfills don't allow us to subclass built-ins, so we need to
    // use our fallback implementation.
    try {
      // If the internal slots aren't set, this throws an error similar to
      //   TypeError: this is not a Boolean object.

      Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function() {}));
      return true;
    } catch (e) {
      return false;
    }
  }
`;
    helpers.construct = helper("7.0.0-beta.0")`
  import setPrototypeOf from "setPrototypeOf";
  import isNativeReflectConstruct from "isNativeReflectConstruct";

  export default function _construct(Parent, args, Class) {
    if (isNativeReflectConstruct()) {
      _construct = Reflect.construct.bind();
    } else {
      // NOTE: If Parent !== Class, the correct __proto__ is set *after*
      //       calling the constructor.
      _construct = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) setPrototypeOf(instance, Class.prototype);
        return instance;
      };
    }
    // Avoid issues with Class being present but undefined when it wasn't
    // present in the original call.
    return _construct.apply(null, arguments);
  }
`;
    helpers.isNativeFunction = helper("7.0.0-beta.0")`
  export default function _isNativeFunction(fn) {
    // Note: This function returns "true" for core-js functions.
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
  }
`;
    helpers.wrapNativeSuper = helper("7.0.0-beta.0")`
  import getPrototypeOf from "getPrototypeOf";
  import setPrototypeOf from "setPrototypeOf";
  import isNativeFunction from "isNativeFunction";
  import construct from "construct";

  export default function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;

    _wrapNativeSuper = function _wrapNativeSuper(Class) {
      if (Class === null || !isNativeFunction(Class)) return Class;
      if (typeof Class !== "function") {
        throw new TypeError("Super expression must either be null or a function");
      }
      if (typeof _cache !== "undefined") {
        if (_cache.has(Class)) return _cache.get(Class);
        _cache.set(Class, Wrapper);
      }
      function Wrapper() {
        return construct(Class, arguments, getPrototypeOf(this).constructor)
      }
      Wrapper.prototype = Object.create(Class.prototype, {
        constructor: {
          value: Wrapper,
          enumerable: false,
          writable: true,
          configurable: true,
        }
      });

      return setPrototypeOf(Wrapper, Class);
    }

    return _wrapNativeSuper(Class)
  }
`;
    helpers.instanceof = helper("7.0.0-beta.0")`
  export default function _instanceof(left, right) {
    if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) {
      return !!right[Symbol.hasInstance](left);
    } else {
      return left instanceof right;
    }
  }
`;
    helpers.interopRequireDefault = helper("7.0.0-beta.0")`
  export default function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }
`;
    helpers.interopRequireWildcard = helper("7.14.0")`
  function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;

    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function (nodeInterop) {
      return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
  }

  export default function _interopRequireWildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
      return obj;
    }

    if (obj === null || (typeof obj !== "object" && typeof obj !== "function")) {
      return { default: obj }
    }

    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
      return cache.get(obj);
    }

    var newObj = {};
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for (var key in obj) {
      if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor
          ? Object.getOwnPropertyDescriptor(obj, key)
          : null;
        if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }
    newObj.default = obj;
    if (cache) {
      cache.set(obj, newObj);
    }
    return newObj;
  }
`;
    helpers.newArrowCheck = helper("7.0.0-beta.0")`
  export default function _newArrowCheck(innerThis, boundThis) {
    if (innerThis !== boundThis) {
      throw new TypeError("Cannot instantiate an arrow function");
    }
  }
`;
    helpers.objectDestructuringEmpty = helper("7.0.0-beta.0")`
  export default function _objectDestructuringEmpty(obj) {
    if (obj == null) throw new TypeError("Cannot destructure " + obj);
  }
`;
    helpers.objectWithoutPropertiesLoose = helper("7.0.0-beta.0")`
  export default function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};

    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }
`;
    helpers.objectWithoutProperties = helper("7.0.0-beta.0")`
  import objectWithoutPropertiesLoose from "objectWithoutPropertiesLoose";

  export default function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};

    var target = objectWithoutPropertiesLoose(source, excluded);
    var key, i;

    if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
      for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
        target[key] = source[key];
      }
    }

    return target;
  }
`;
    helpers.assertThisInitialized = helper("7.0.0-beta.0")`
  export default function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }
    return self;
  }
`;
    helpers.possibleConstructorReturn = helper("7.0.0-beta.0")`
  import assertThisInitialized from "assertThisInitialized";

  export default function _possibleConstructorReturn(self, call) {
    if (call && (typeof call === "object" || typeof call === "function")) {
      return call;
    } else if (call !== void 0) {
      throw new TypeError("Derived constructors may only return object or undefined");
    }

    return assertThisInitialized(self);
  }
`;
    helpers.createSuper = helper("7.9.0")`
  import getPrototypeOf from "getPrototypeOf";
  import isNativeReflectConstruct from "isNativeReflectConstruct";
  import possibleConstructorReturn from "possibleConstructorReturn";

  export default function _createSuper(Derived) {
    var hasNativeReflectConstruct = isNativeReflectConstruct();

    return function _createSuperInternal() {
      var Super = getPrototypeOf(Derived), result;
      if (hasNativeReflectConstruct) {
        // NOTE: This doesn't work if this.__proto__.constructor has been modified.
        var NewTarget = getPrototypeOf(this).constructor;
        result = Reflect.construct(Super, arguments, NewTarget);
      } else {
        result = Super.apply(this, arguments);
      }
      return possibleConstructorReturn(this, result);
    }
  }
 `;
    helpers.superPropBase = helper("7.0.0-beta.0")`
  import getPrototypeOf from "getPrototypeOf";

  export default function _superPropBase(object, property) {
    // Yes, this throws if object is null to being with, that's on purpose.
    while (!Object.prototype.hasOwnProperty.call(object, property)) {
      object = getPrototypeOf(object);
      if (object === null) break;
    }
    return object;
  }
`;
    helpers.get = helper("7.0.0-beta.0")`
  import superPropBase from "superPropBase";

  export default function _get() {
    if (typeof Reflect !== "undefined" && Reflect.get) {
      _get = Reflect.get.bind();
    } else {
      _get = function _get(target, property, receiver) {
        var base = superPropBase(target, property);

        if (!base) return;

        var desc = Object.getOwnPropertyDescriptor(base, property);
        if (desc.get) {
          // STEP 3. If receiver is not present, then set receiver to target.
          return desc.get.call(arguments.length < 3 ? target : receiver);
        }

        return desc.value;
      };
    }
    return _get.apply(this, arguments);
  }
`;
    helpers.set = helper("7.0.0-beta.0")`
  import superPropBase from "superPropBase";
  import defineProperty from "defineProperty";

  function set(target, property, value, receiver) {
    if (typeof Reflect !== "undefined" && Reflect.set) {
      set = Reflect.set;
    } else {
      set = function set(target, property, value, receiver) {
        var base = superPropBase(target, property);
        var desc;

        if (base) {
          desc = Object.getOwnPropertyDescriptor(base, property);
          if (desc.set) {
            desc.set.call(receiver, value);
            return true;
          } else if (!desc.writable) {
            // Both getter and non-writable fall into this.
            return false;
          }
        }

        // Without a super that defines the property, spec boils down to
        // "define on receiver" for some reason.
        desc = Object.getOwnPropertyDescriptor(receiver, property);
        if (desc) {
          if (!desc.writable) {
            // Setter, getter, and non-writable fall into this.
            return false;
          }

          desc.value = value;
          Object.defineProperty(receiver, property, desc);
        } else {
          // Avoid setters that may be defined on Sub's prototype, but not on
          // the instance.
          defineProperty(receiver, property, value);
        }

        return true;
      };
    }

    return set(target, property, value, receiver);
  }

  export default function _set(target, property, value, receiver, isStrict) {
    var s = set(target, property, value, receiver || target);
    if (!s && isStrict) {
      throw new TypeError('failed to set property');
    }

    return value;
  }
`;
    helpers.taggedTemplateLiteral = helper("7.0.0-beta.0")`
  export default function _taggedTemplateLiteral(strings, raw) {
    if (!raw) { raw = strings.slice(0); }
    return Object.freeze(Object.defineProperties(strings, {
        raw: { value: Object.freeze(raw) }
    }));
  }
`;
    helpers.taggedTemplateLiteralLoose = helper("7.0.0-beta.0")`
  export default function _taggedTemplateLiteralLoose(strings, raw) {
    if (!raw) { raw = strings.slice(0); }
    strings.raw = raw;
    return strings;
  }
`;
    helpers.readOnlyError = helper("7.0.0-beta.0")`
  export default function _readOnlyError(name) {
    throw new TypeError("\\"" + name + "\\" is read-only");
  }
`;
    helpers.writeOnlyError = helper("7.12.13")`
  export default function _writeOnlyError(name) {
    throw new TypeError("\\"" + name + "\\" is write-only");
  }
`;
    helpers.classNameTDZError = helper("7.0.0-beta.0")`
  export default function _classNameTDZError(name) {
    throw new ReferenceError("Class \\"" + name + "\\" cannot be referenced in computed property keys.");
  }
`;
    helpers.temporalUndefined = helper("7.0.0-beta.0")`
  // This function isn't mean to be called, but to be used as a reference.
  // We can't use a normal object because it isn't hoisted.
  export default function _temporalUndefined() {}
`;
    helpers.tdz = helper("7.5.5")`
  export default function _tdzError(name) {
    throw new ReferenceError(name + " is not defined - temporal dead zone");
  }
`;
    helpers.temporalRef = helper("7.0.0-beta.0")`
  import undef from "temporalUndefined";
  import err from "tdz";

  export default function _temporalRef(val, name) {
    return val === undef ? err(name) : val;
  }
`;
    helpers.slicedToArray = helper("7.0.0-beta.0")`
  import arrayWithHoles from "arrayWithHoles";
  import iterableToArrayLimit from "iterableToArrayLimit";
  import unsupportedIterableToArray from "unsupportedIterableToArray";
  import nonIterableRest from "nonIterableRest";

  export default function _slicedToArray(arr, i) {
    return (
      arrayWithHoles(arr) ||
      iterableToArrayLimit(arr, i) ||
      unsupportedIterableToArray(arr, i) ||
      nonIterableRest()
    );
  }
`;
    helpers.slicedToArrayLoose = helper("7.0.0-beta.0")`
  import arrayWithHoles from "arrayWithHoles";
  import iterableToArrayLimitLoose from "iterableToArrayLimitLoose";
  import unsupportedIterableToArray from "unsupportedIterableToArray";
  import nonIterableRest from "nonIterableRest";

  export default function _slicedToArrayLoose(arr, i) {
    return (
      arrayWithHoles(arr) ||
      iterableToArrayLimitLoose(arr, i) ||
      unsupportedIterableToArray(arr, i) ||
      nonIterableRest()
    );
  }
`;
    helpers.toArray = helper("7.0.0-beta.0")`
  import arrayWithHoles from "arrayWithHoles";
  import iterableToArray from "iterableToArray";
  import unsupportedIterableToArray from "unsupportedIterableToArray";
  import nonIterableRest from "nonIterableRest";

  export default function _toArray(arr) {
    return (
      arrayWithHoles(arr) ||
      iterableToArray(arr) ||
      unsupportedIterableToArray(arr) ||
      nonIterableRest()
    );
  }
`;
    helpers.toConsumableArray = helper("7.0.0-beta.0")`
  import arrayWithoutHoles from "arrayWithoutHoles";
  import iterableToArray from "iterableToArray";
  import unsupportedIterableToArray from "unsupportedIterableToArray";
  import nonIterableSpread from "nonIterableSpread";

  export default function _toConsumableArray(arr) {
    return (
      arrayWithoutHoles(arr) ||
      iterableToArray(arr) ||
      unsupportedIterableToArray(arr) ||
      nonIterableSpread()
    );
  }
`;
    helpers.arrayWithoutHoles = helper("7.0.0-beta.0")`
  import arrayLikeToArray from "arrayLikeToArray";

  export default function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return arrayLikeToArray(arr);
  }
`;
    helpers.arrayWithHoles = helper("7.0.0-beta.0")`
  export default function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }
`;
    helpers.maybeArrayLike = helper("7.9.0")`
  import arrayLikeToArray from "arrayLikeToArray";

  export default function _maybeArrayLike(next, arr, i) {
    if (arr && !Array.isArray(arr) && typeof arr.length === "number") {
      var len = arr.length;
      return arrayLikeToArray(arr, i !== void 0 && i < len ? i : len);
    }
    return next(arr, i);
  }
`;
    helpers.iterableToArray = helper("7.0.0-beta.0")`
  export default function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }
`;
    helpers.unsupportedIterableToArray = helper("7.9.0")`
  import arrayLikeToArray from "arrayLikeToArray";

  export default function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))
      return arrayLikeToArray(o, minLen);
  }
`;
    helpers.arrayLikeToArray = helper("7.9.0")`
  export default function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;
    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
    return arr2;
  }
`;
    helpers.nonIterableSpread = helper("7.0.0-beta.0")`
  export default function _nonIterableSpread() {
    throw new TypeError(
      "Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."
    );
  }
`;
    helpers.nonIterableRest = helper("7.0.0-beta.0")`
  export default function _nonIterableRest() {
    throw new TypeError(
      "Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."
    );
  }
`;
    helpers.createForOfIteratorHelper = helper("7.9.0")`
  import unsupportedIterableToArray from "unsupportedIterableToArray";

  // s: start (create the iterator)
  // n: next
  // e: error (called whenever something throws)
  // f: finish (always called at the end)

  export default function _createForOfIteratorHelper(o, allowArrayLike) {
    var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];

    if (!it) {
      // Fallback for engines without symbol support
      if (
        Array.isArray(o) ||
        (it = unsupportedIterableToArray(o)) ||
        (allowArrayLike && o && typeof o.length === "number")
      ) {
        if (it) o = it;
        var i = 0;
        var F = function(){};
        return {
          s: F,
          n: function() {
            if (i >= o.length) return { done: true };
            return { done: false, value: o[i++] };
          },
          e: function(e) { throw e; },
          f: F,
        };
      }

      throw new TypeError("Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }

    var normalCompletion = true, didErr = false, err;

    return {
      s: function() {
        it = it.call(o);
      },
      n: function() {
        var step = it.next();
        normalCompletion = step.done;
        return step;
      },
      e: function(e) {
        didErr = true;
        err = e;
      },
      f: function() {
        try {
          if (!normalCompletion && it.return != null) it.return();
        } finally {
          if (didErr) throw err;
        }
      }
    };
  }
`;
    helpers.createForOfIteratorHelperLoose = helper("7.9.0")`
  import unsupportedIterableToArray from "unsupportedIterableToArray";

  export default function _createForOfIteratorHelperLoose(o, allowArrayLike) {
    var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];

    if (it) return (it = it.call(o)).next.bind(it);

    // Fallback for engines without symbol support
    if (
      Array.isArray(o) ||
      (it = unsupportedIterableToArray(o)) ||
      (allowArrayLike && o && typeof o.length === "number")
    ) {
      if (it) o = it;
      var i = 0;
      return function() {
        if (i >= o.length) return { done: true };
        return { done: false, value: o[i++] };
      }
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
`;
    helpers.skipFirstGeneratorNext = helper("7.0.0-beta.0")`
  export default function _skipFirstGeneratorNext(fn) {
    return function () {
      var it = fn.apply(this, arguments);
      it.next();
      return it;
    }
  }
`;
    helpers.toPrimitive = helper("7.1.5")`
  export default function _toPrimitive(
    input,
    hint /*: "default" | "string" | "number" | void */
  ) {
    if (typeof input !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (typeof res !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
`;
    helpers.toPropertyKey = helper("7.1.5")`
  import toPrimitive from "toPrimitive";

  export default function _toPropertyKey(arg) {
    var key = toPrimitive(arg, "string");
    return typeof key === "symbol" ? key : String(key);
  }
`;
    helpers.initializerWarningHelper = helper("7.0.0-beta.0")`
    export default function _initializerWarningHelper(descriptor, context){
        throw new Error(
          'Decorating class property failed. Please ensure that ' +
          'proposal-class-properties is enabled and runs after the decorators transform.'
        );
    }
`;
    helpers.initializerDefineProperty = helper("7.0.0-beta.0")`
    export default function _initializerDefineProperty(target, property, descriptor, context){
        if (!descriptor) return;

        Object.defineProperty(target, property, {
            enumerable: descriptor.enumerable,
            configurable: descriptor.configurable,
            writable: descriptor.writable,
            value: descriptor.initializer ? descriptor.initializer.call(context) : void 0,
        });
    }
`;
    helpers.applyDecoratedDescriptor = helper("7.0.0-beta.0")`
    export default function _applyDecoratedDescriptor(target, property, decorators, descriptor, context){
        var desc = {};
        Object.keys(descriptor).forEach(function(key){
            desc[key] = descriptor[key];
        });
        desc.enumerable = !!desc.enumerable;
        desc.configurable = !!desc.configurable;
        if ('value' in desc || desc.initializer){
            desc.writable = true;
        }

        desc = decorators.slice().reverse().reduce(function(desc, decorator){
            return decorator(target, property, desc) || desc;
        }, desc);

        if (context && desc.initializer !== void 0){
            desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
            desc.initializer = undefined;
        }

        if (desc.initializer === void 0){
            Object.defineProperty(target, property, desc);
            desc = null;
        }

        return desc;
    }
`;
    helpers.classPrivateFieldLooseKey = helper("7.0.0-beta.0")`
  var id = 0;
  export default function _classPrivateFieldKey(name) {
    return "__private_" + (id++) + "_" + name;
  }
`;
    helpers.classPrivateFieldLooseBase = helper("7.0.0-beta.0")`
  export default function _classPrivateFieldBase(receiver, privateKey) {
    if (!Object.prototype.hasOwnProperty.call(receiver, privateKey)) {
      throw new TypeError("attempted to use private field on non-instance");
    }
    return receiver;
  }
`;
    helpers.classPrivateFieldGet = helper("7.0.0-beta.0")`
  import classApplyDescriptorGet from "classApplyDescriptorGet";
  import classExtractFieldDescriptor from "classExtractFieldDescriptor";
  export default function _classPrivateFieldGet(receiver, privateMap) {
    var descriptor = classExtractFieldDescriptor(receiver, privateMap, "get");
    return classApplyDescriptorGet(receiver, descriptor);
  }
`;
    helpers.classPrivateFieldSet = helper("7.0.0-beta.0")`
  import classApplyDescriptorSet from "classApplyDescriptorSet";
  import classExtractFieldDescriptor from "classExtractFieldDescriptor";
  export default function _classPrivateFieldSet(receiver, privateMap, value) {
    var descriptor = classExtractFieldDescriptor(receiver, privateMap, "set");
    classApplyDescriptorSet(receiver, descriptor, value);
    return value;
  }
`;
    helpers.classPrivateFieldDestructureSet = helper("7.4.4")`
  import classApplyDescriptorDestructureSet from "classApplyDescriptorDestructureSet";
  import classExtractFieldDescriptor from "classExtractFieldDescriptor";
  export default function _classPrivateFieldDestructureSet(receiver, privateMap) {
    var descriptor = classExtractFieldDescriptor(receiver, privateMap, "set");
    return classApplyDescriptorDestructureSet(receiver, descriptor);
  }
`;
    helpers.classExtractFieldDescriptor = helper("7.13.10")`
  export default function _classExtractFieldDescriptor(receiver, privateMap, action) {
    if (!privateMap.has(receiver)) {
      throw new TypeError("attempted to " + action + " private field on non-instance");
    }
    return privateMap.get(receiver);
  }
`;
    helpers.classStaticPrivateFieldSpecGet = helper("7.0.2")`
  import classApplyDescriptorGet from "classApplyDescriptorGet";
  import classCheckPrivateStaticAccess from "classCheckPrivateStaticAccess";
  import classCheckPrivateStaticFieldDescriptor from "classCheckPrivateStaticFieldDescriptor";
  export default function _classStaticPrivateFieldSpecGet(receiver, classConstructor, descriptor) {
    classCheckPrivateStaticAccess(receiver, classConstructor);
    classCheckPrivateStaticFieldDescriptor(descriptor, "get");
    return classApplyDescriptorGet(receiver, descriptor);
  }
`;
    helpers.classStaticPrivateFieldSpecSet = helper("7.0.2")`
  import classApplyDescriptorSet from "classApplyDescriptorSet";
  import classCheckPrivateStaticAccess from "classCheckPrivateStaticAccess";
  import classCheckPrivateStaticFieldDescriptor from "classCheckPrivateStaticFieldDescriptor";
  export default function _classStaticPrivateFieldSpecSet(receiver, classConstructor, descriptor, value) {
    classCheckPrivateStaticAccess(receiver, classConstructor);
    classCheckPrivateStaticFieldDescriptor(descriptor, "set");
    classApplyDescriptorSet(receiver, descriptor, value);
    return value;
  }
`;
    helpers.classStaticPrivateMethodGet = helper("7.3.2")`
  import classCheckPrivateStaticAccess from "classCheckPrivateStaticAccess";
  export default function _classStaticPrivateMethodGet(receiver, classConstructor, method) {
    classCheckPrivateStaticAccess(receiver, classConstructor);
    return method;
  }
`;
    helpers.classStaticPrivateMethodSet = helper("7.3.2")`
  export default function _classStaticPrivateMethodSet() {
    throw new TypeError("attempted to set read only static private field");
  }
`;
    helpers.classApplyDescriptorGet = helper("7.13.10")`
  export default function _classApplyDescriptorGet(receiver, descriptor) {
    if (descriptor.get) {
      return descriptor.get.call(receiver);
    }
    return descriptor.value;
  }
`;
    helpers.classApplyDescriptorSet = helper("7.13.10")`
  export default function _classApplyDescriptorSet(receiver, descriptor, value) {
    if (descriptor.set) {
      descriptor.set.call(receiver, value);
    } else {
      if (!descriptor.writable) {
        // This should only throw in strict mode, but class bodies are
        // always strict and private fields can only be used inside
        // class bodies.
        throw new TypeError("attempted to set read only private field");
      }
      descriptor.value = value;
    }
  }
`;
    helpers.classApplyDescriptorDestructureSet = helper("7.13.10")`
  export default function _classApplyDescriptorDestructureSet(receiver, descriptor) {
    if (descriptor.set) {
      if (!("__destrObj" in descriptor)) {
        descriptor.__destrObj = {
          set value(v) {
            descriptor.set.call(receiver, v)
          },
        };
      }
      return descriptor.__destrObj;
    } else {
      if (!descriptor.writable) {
        // This should only throw in strict mode, but class bodies are
        // always strict and private fields can only be used inside
        // class bodies.
        throw new TypeError("attempted to set read only private field");
      }

      return descriptor;
    }
  }
`;
    helpers.classStaticPrivateFieldDestructureSet = helper("7.13.10")`
  import classApplyDescriptorDestructureSet from "classApplyDescriptorDestructureSet";
  import classCheckPrivateStaticAccess from "classCheckPrivateStaticAccess";
  import classCheckPrivateStaticFieldDescriptor from "classCheckPrivateStaticFieldDescriptor";
  export default function _classStaticPrivateFieldDestructureSet(receiver, classConstructor, descriptor) {
    classCheckPrivateStaticAccess(receiver, classConstructor);
    classCheckPrivateStaticFieldDescriptor(descriptor, "set");
    return classApplyDescriptorDestructureSet(receiver, descriptor);
  }
`;
    helpers.classCheckPrivateStaticAccess = helper("7.13.10")`
  export default function _classCheckPrivateStaticAccess(receiver, classConstructor) {
    if (receiver !== classConstructor) {
      throw new TypeError("Private static access of wrong provenance");
    }
  }
`;
    helpers.classCheckPrivateStaticFieldDescriptor = helper("7.13.10")`
  export default function _classCheckPrivateStaticFieldDescriptor(descriptor, action) {
    if (descriptor === undefined) {
      throw new TypeError("attempted to " + action + " private static field before its declaration");
    }
  }
`;
    helpers.decorate = helper("7.1.5")`
  import toArray from "toArray";
  import toPropertyKey from "toPropertyKey";

  // These comments are stripped by @babel/template
  /*::
  type PropertyDescriptor =
    | {
        value: any,
        writable: boolean,
        configurable: boolean,
        enumerable: boolean,
      }
    | {
        get?: () => any,
        set?: (v: any) => void,
        configurable: boolean,
        enumerable: boolean,
      };

  type FieldDescriptor ={
    writable: boolean,
    configurable: boolean,
    enumerable: boolean,
  };

  type Placement = "static" | "prototype" | "own";
  type Key = string | symbol; // PrivateName is not supported yet.

  type ElementDescriptor =
    | {
        kind: "method",
        key: Key,
        placement: Placement,
        descriptor: PropertyDescriptor
      }
    | {
        kind: "field",
        key: Key,
        placement: Placement,
        descriptor: FieldDescriptor,
        initializer?: () => any,
      };

  // This is exposed to the user code
  type ElementObjectInput = ElementDescriptor & {
    [@@toStringTag]?: "Descriptor"
  };

  // This is exposed to the user code
  type ElementObjectOutput = ElementDescriptor & {
    [@@toStringTag]?: "Descriptor"
    extras?: ElementDescriptor[],
    finisher?: ClassFinisher,
  };

  // This is exposed to the user code
  type ClassObject = {
    [@@toStringTag]?: "Descriptor",
    kind: "class",
    elements: ElementDescriptor[],
  };

  type ElementDecorator = (descriptor: ElementObjectInput) => ?ElementObjectOutput;
  type ClassDecorator = (descriptor: ClassObject) => ?ClassObject;
  type ClassFinisher = <A, B>(cl: Class<A>) => Class<B>;

  // Only used by Babel in the transform output, not part of the spec.
  type ElementDefinition =
    | {
        kind: "method",
        value: any,
        key: Key,
        static?: boolean,
        decorators?: ElementDecorator[],
      }
    | {
        kind: "field",
        value: () => any,
        key: Key,
        static?: boolean,
        decorators?: ElementDecorator[],
    };

  declare function ClassFactory<C>(initialize: (instance: C) => void): {
    F: Class<C>,
    d: ElementDefinition[]
  }

  */

  /*::
  // Various combinations with/without extras and with one or many finishers

  type ElementFinisherExtras = {
    element: ElementDescriptor,
    finisher?: ClassFinisher,
    extras?: ElementDescriptor[],
  };

  type ElementFinishersExtras = {
    element: ElementDescriptor,
    finishers: ClassFinisher[],
    extras: ElementDescriptor[],
  };

  type ElementsFinisher = {
    elements: ElementDescriptor[],
    finisher?: ClassFinisher,
  };

  type ElementsFinishers = {
    elements: ElementDescriptor[],
    finishers: ClassFinisher[],
  };

  */

  /*::

  type Placements = {
    static: Key[],
    prototype: Key[],
    own: Key[],
  };

  */

  // ClassDefinitionEvaluation (Steps 26-*)
  export default function _decorate(
    decorators /*: ClassDecorator[] */,
    factory /*: ClassFactory */,
    superClass /*: ?Class<*> */,
    mixins /*: ?Array<Function> */,
  ) /*: Class<*> */ {
    var api = _getDecoratorsApi();
    if (mixins) {
      for (var i = 0; i < mixins.length; i++) {
        api = mixins[i](api);
      }
    }

    var r = factory(function initialize(O) {
      api.initializeInstanceElements(O, decorated.elements);
    }, superClass);
    var decorated = api.decorateClass(
      _coalesceClassElements(r.d.map(_createElementDescriptor)),
      decorators,
    );

    api.initializeClassElements(r.F, decorated.elements);

    return api.runClassFinishers(r.F, decorated.finishers);
  }

  function _getDecoratorsApi() {
    _getDecoratorsApi = function() {
      return api;
    };

    var api = {
      elementsDefinitionOrder: [["method"], ["field"]],

      // InitializeInstanceElements
      initializeInstanceElements: function(
        /*::<C>*/ O /*: C */,
        elements /*: ElementDescriptor[] */,
      ) {
        ["method", "field"].forEach(function(kind) {
          elements.forEach(function(element /*: ElementDescriptor */) {
            if (element.kind === kind && element.placement === "own") {
              this.defineClassElement(O, element);
            }
          }, this);
        }, this);
      },

      // InitializeClassElements
      initializeClassElements: function(
        /*::<C>*/ F /*: Class<C> */,
        elements /*: ElementDescriptor[] */,
      ) {
        var proto = F.prototype;

        ["method", "field"].forEach(function(kind) {
          elements.forEach(function(element /*: ElementDescriptor */) {
            var placement = element.placement;
            if (
              element.kind === kind &&
              (placement === "static" || placement === "prototype")
            ) {
              var receiver = placement === "static" ? F : proto;
              this.defineClassElement(receiver, element);
            }
          }, this);
        }, this);
      },

      // DefineClassElement
      defineClassElement: function(
        /*::<C>*/ receiver /*: C | Class<C> */,
        element /*: ElementDescriptor */,
      ) {
        var descriptor /*: PropertyDescriptor */ = element.descriptor;
        if (element.kind === "field") {
          var initializer = element.initializer;
          descriptor = {
            enumerable: descriptor.enumerable,
            writable: descriptor.writable,
            configurable: descriptor.configurable,
            value: initializer === void 0 ? void 0 : initializer.call(receiver),
          };
        }
        Object.defineProperty(receiver, element.key, descriptor);
      },

      // DecorateClass
      decorateClass: function(
        elements /*: ElementDescriptor[] */,
        decorators /*: ClassDecorator[] */,
      ) /*: ElementsFinishers */ {
        var newElements /*: ElementDescriptor[] */ = [];
        var finishers /*: ClassFinisher[] */ = [];
        var placements /*: Placements */ = {
          static: [],
          prototype: [],
          own: [],
        };

        elements.forEach(function(element /*: ElementDescriptor */) {
          this.addElementPlacement(element, placements);
        }, this);

        elements.forEach(function(element /*: ElementDescriptor */) {
          if (!_hasDecorators(element)) return newElements.push(element);

          var elementFinishersExtras /*: ElementFinishersExtras */ = this.decorateElement(
            element,
            placements,
          );
          newElements.push(elementFinishersExtras.element);
          newElements.push.apply(newElements, elementFinishersExtras.extras);
          finishers.push.apply(finishers, elementFinishersExtras.finishers);
        }, this);

        if (!decorators) {
          return { elements: newElements, finishers: finishers };
        }

        var result /*: ElementsFinishers */ = this.decorateConstructor(
          newElements,
          decorators,
        );
        finishers.push.apply(finishers, result.finishers);
        result.finishers = finishers;

        return result;
      },

      // AddElementPlacement
      addElementPlacement: function(
        element /*: ElementDescriptor */,
        placements /*: Placements */,
        silent /*: boolean */,
      ) {
        var keys = placements[element.placement];
        if (!silent && keys.indexOf(element.key) !== -1) {
          throw new TypeError("Duplicated element (" + element.key + ")");
        }
        keys.push(element.key);
      },

      // DecorateElement
      decorateElement: function(
        element /*: ElementDescriptor */,
        placements /*: Placements */,
      ) /*: ElementFinishersExtras */ {
        var extras /*: ElementDescriptor[] */ = [];
        var finishers /*: ClassFinisher[] */ = [];

        for (
          var decorators = element.decorators, i = decorators.length - 1;
          i >= 0;
          i--
        ) {
          // (inlined) RemoveElementPlacement
          var keys = placements[element.placement];
          keys.splice(keys.indexOf(element.key), 1);

          var elementObject /*: ElementObjectInput */ = this.fromElementDescriptor(
            element,
          );
          var elementFinisherExtras /*: ElementFinisherExtras */ = this.toElementFinisherExtras(
            (0, decorators[i])(elementObject) /*: ElementObjectOutput */ ||
              elementObject,
          );

          element = elementFinisherExtras.element;
          this.addElementPlacement(element, placements);

          if (elementFinisherExtras.finisher) {
            finishers.push(elementFinisherExtras.finisher);
          }

          var newExtras /*: ElementDescriptor[] | void */ =
            elementFinisherExtras.extras;
          if (newExtras) {
            for (var j = 0; j < newExtras.length; j++) {
              this.addElementPlacement(newExtras[j], placements);
            }
            extras.push.apply(extras, newExtras);
          }
        }

        return { element: element, finishers: finishers, extras: extras };
      },

      // DecorateConstructor
      decorateConstructor: function(
        elements /*: ElementDescriptor[] */,
        decorators /*: ClassDecorator[] */,
      ) /*: ElementsFinishers */ {
        var finishers /*: ClassFinisher[] */ = [];

        for (var i = decorators.length - 1; i >= 0; i--) {
          var obj /*: ClassObject */ = this.fromClassDescriptor(elements);
          var elementsAndFinisher /*: ElementsFinisher */ = this.toClassDescriptor(
            (0, decorators[i])(obj) /*: ClassObject */ || obj,
          );

          if (elementsAndFinisher.finisher !== undefined) {
            finishers.push(elementsAndFinisher.finisher);
          }

          if (elementsAndFinisher.elements !== undefined) {
            elements = elementsAndFinisher.elements;

            for (var j = 0; j < elements.length - 1; j++) {
              for (var k = j + 1; k < elements.length; k++) {
                if (
                  elements[j].key === elements[k].key &&
                  elements[j].placement === elements[k].placement
                ) {
                  throw new TypeError(
                    "Duplicated element (" + elements[j].key + ")",
                  );
                }
              }
            }
          }
        }

        return { elements: elements, finishers: finishers };
      },

      // FromElementDescriptor
      fromElementDescriptor: function(
        element /*: ElementDescriptor */,
      ) /*: ElementObject */ {
        var obj /*: ElementObject */ = {
          kind: element.kind,
          key: element.key,
          placement: element.placement,
          descriptor: element.descriptor,
        };

        var desc = {
          value: "Descriptor",
          configurable: true,
        };
        Object.defineProperty(obj, Symbol.toStringTag, desc);

        if (element.kind === "field") obj.initializer = element.initializer;

        return obj;
      },

      // ToElementDescriptors
      toElementDescriptors: function(
        elementObjects /*: ElementObject[] */,
      ) /*: ElementDescriptor[] */ {
        if (elementObjects === undefined) return;
        return toArray(elementObjects).map(function(elementObject) {
          var element = this.toElementDescriptor(elementObject);
          this.disallowProperty(elementObject, "finisher", "An element descriptor");
          this.disallowProperty(elementObject, "extras", "An element descriptor");
          return element;
        }, this);
      },

      // ToElementDescriptor
      toElementDescriptor: function(
        elementObject /*: ElementObject */,
      ) /*: ElementDescriptor */ {
        var kind = String(elementObject.kind);
        if (kind !== "method" && kind !== "field") {
          throw new TypeError(
            'An element descriptor\\'s .kind property must be either "method" or' +
              ' "field", but a decorator created an element descriptor with' +
              ' .kind "' +
              kind +
              '"',
          );
        }

        var key = toPropertyKey(elementObject.key);

        var placement = String(elementObject.placement);
        if (
          placement !== "static" &&
          placement !== "prototype" &&
          placement !== "own"
        ) {
          throw new TypeError(
            'An element descriptor\\'s .placement property must be one of "static",' +
              ' "prototype" or "own", but a decorator created an element descriptor' +
              ' with .placement "' +
              placement +
              '"',
          );
        }

        var descriptor /*: PropertyDescriptor */ = elementObject.descriptor;

        this.disallowProperty(elementObject, "elements", "An element descriptor");

        var element /*: ElementDescriptor */ = {
          kind: kind,
          key: key,
          placement: placement,
          descriptor: Object.assign({}, descriptor),
        };

        if (kind !== "field") {
          this.disallowProperty(elementObject, "initializer", "A method descriptor");
        } else {
          this.disallowProperty(
            descriptor,
            "get",
            "The property descriptor of a field descriptor",
          );
          this.disallowProperty(
            descriptor,
            "set",
            "The property descriptor of a field descriptor",
          );
          this.disallowProperty(
            descriptor,
            "value",
            "The property descriptor of a field descriptor",
          );

          element.initializer = elementObject.initializer;
        }

        return element;
      },

      toElementFinisherExtras: function(
        elementObject /*: ElementObject */,
      ) /*: ElementFinisherExtras */ {
        var element /*: ElementDescriptor */ = this.toElementDescriptor(
          elementObject,
        );
        var finisher /*: ClassFinisher */ = _optionalCallableProperty(
          elementObject,
          "finisher",
        );
        var extras /*: ElementDescriptors[] */ = this.toElementDescriptors(
          elementObject.extras,
        );

        return { element: element, finisher: finisher, extras: extras };
      },

      // FromClassDescriptor
      fromClassDescriptor: function(
        elements /*: ElementDescriptor[] */,
      ) /*: ClassObject */ {
        var obj = {
          kind: "class",
          elements: elements.map(this.fromElementDescriptor, this),
        };

        var desc = { value: "Descriptor", configurable: true };
        Object.defineProperty(obj, Symbol.toStringTag, desc);

        return obj;
      },

      // ToClassDescriptor
      toClassDescriptor: function(
        obj /*: ClassObject */,
      ) /*: ElementsFinisher */ {
        var kind = String(obj.kind);
        if (kind !== "class") {
          throw new TypeError(
            'A class descriptor\\'s .kind property must be "class", but a decorator' +
              ' created a class descriptor with .kind "' +
              kind +
              '"',
          );
        }

        this.disallowProperty(obj, "key", "A class descriptor");
        this.disallowProperty(obj, "placement", "A class descriptor");
        this.disallowProperty(obj, "descriptor", "A class descriptor");
        this.disallowProperty(obj, "initializer", "A class descriptor");
        this.disallowProperty(obj, "extras", "A class descriptor");

        var finisher = _optionalCallableProperty(obj, "finisher");
        var elements = this.toElementDescriptors(obj.elements);

        return { elements: elements, finisher: finisher };
      },

      // RunClassFinishers
      runClassFinishers: function(
        constructor /*: Class<*> */,
        finishers /*: ClassFinisher[] */,
      ) /*: Class<*> */ {
        for (var i = 0; i < finishers.length; i++) {
          var newConstructor /*: ?Class<*> */ = (0, finishers[i])(constructor);
          if (newConstructor !== undefined) {
            // NOTE: This should check if IsConstructor(newConstructor) is false.
            if (typeof newConstructor !== "function") {
              throw new TypeError("Finishers must return a constructor.");
            }
            constructor = newConstructor;
          }
        }
        return constructor;
      },

      disallowProperty: function(obj, name, objectType) {
        if (obj[name] !== undefined) {
          throw new TypeError(objectType + " can't have a ." + name + " property.");
        }
      }
    };

    return api;
  }

  // ClassElementEvaluation
  function _createElementDescriptor(
    def /*: ElementDefinition */,
  ) /*: ElementDescriptor */ {
    var key = toPropertyKey(def.key);

    var descriptor /*: PropertyDescriptor */;
    if (def.kind === "method") {
      descriptor = {
        value: def.value,
        writable: true,
        configurable: true,
        enumerable: false,
      };
    } else if (def.kind === "get") {
      descriptor = { get: def.value, configurable: true, enumerable: false };
    } else if (def.kind === "set") {
      descriptor = { set: def.value, configurable: true, enumerable: false };
    } else if (def.kind === "field") {
      descriptor = { configurable: true, writable: true, enumerable: true };
    }

    var element /*: ElementDescriptor */ = {
      kind: def.kind === "field" ? "field" : "method",
      key: key,
      placement: def.static
        ? "static"
        : def.kind === "field"
        ? "own"
        : "prototype",
      descriptor: descriptor,
    };
    if (def.decorators) element.decorators = def.decorators;
    if (def.kind === "field") element.initializer = def.value;

    return element;
  }

  // CoalesceGetterSetter
  function _coalesceGetterSetter(
    element /*: ElementDescriptor */,
    other /*: ElementDescriptor */,
  ) {
    if (element.descriptor.get !== undefined) {
      other.descriptor.get = element.descriptor.get;
    } else {
      other.descriptor.set = element.descriptor.set;
    }
  }

  // CoalesceClassElements
  function _coalesceClassElements(
    elements /*: ElementDescriptor[] */,
  ) /*: ElementDescriptor[] */ {
    var newElements /*: ElementDescriptor[] */ = [];

    var isSameElement = function(
      other /*: ElementDescriptor */,
    ) /*: boolean */ {
      return (
        other.kind === "method" &&
        other.key === element.key &&
        other.placement === element.placement
      );
    };

    for (var i = 0; i < elements.length; i++) {
      var element /*: ElementDescriptor */ = elements[i];
      var other /*: ElementDescriptor */;

      if (
        element.kind === "method" &&
        (other = newElements.find(isSameElement))
      ) {
        if (
          _isDataDescriptor(element.descriptor) ||
          _isDataDescriptor(other.descriptor)
        ) {
          if (_hasDecorators(element) || _hasDecorators(other)) {
            throw new ReferenceError(
              "Duplicated methods (" + element.key + ") can't be decorated.",
            );
          }
          other.descriptor = element.descriptor;
        } else {
          if (_hasDecorators(element)) {
            if (_hasDecorators(other)) {
              throw new ReferenceError(
                "Decorators can't be placed on different accessors with for " +
                  "the same property (" +
                  element.key +
                  ").",
              );
            }
            other.decorators = element.decorators;
          }
          _coalesceGetterSetter(element, other);
        }
      } else {
        newElements.push(element);
      }
    }

    return newElements;
  }

  function _hasDecorators(element /*: ElementDescriptor */) /*: boolean */ {
    return element.decorators && element.decorators.length;
  }

  function _isDataDescriptor(desc /*: PropertyDescriptor */) /*: boolean */ {
    return (
      desc !== undefined &&
      !(desc.value === undefined && desc.writable === undefined)
    );
  }

  function _optionalCallableProperty /*::<T>*/(
    obj /*: T */,
    name /*: $Keys<T> */,
  ) /*: ?Function */ {
    var value = obj[name];
    if (value !== undefined && typeof value !== "function") {
      throw new TypeError("Expected '" + name + "' to be a function");
    }
    return value;
  }

`;
    helpers.classPrivateMethodGet = helper("7.1.6")`
  export default function _classPrivateMethodGet(receiver, privateSet, fn) {
    if (!privateSet.has(receiver)) {
      throw new TypeError("attempted to get private field on non-instance");
    }
    return fn;
  }
`;
    helpers.checkPrivateRedeclaration = helper("7.14.1")`
  export default function _checkPrivateRedeclaration(obj, privateCollection) {
    if (privateCollection.has(obj)) {
      throw new TypeError("Cannot initialize the same private elements twice on an object");
    }
  }
`;
    helpers.classPrivateFieldInitSpec = helper("7.14.1")`
  import checkPrivateRedeclaration from "checkPrivateRedeclaration";

  export default function _classPrivateFieldInitSpec(obj, privateMap, value) {
    checkPrivateRedeclaration(obj, privateMap);
    privateMap.set(obj, value);
  }
`;
    helpers.classPrivateMethodInitSpec = helper("7.14.1")`
  import checkPrivateRedeclaration from "checkPrivateRedeclaration";

  export default function _classPrivateMethodInitSpec(obj, privateSet) {
    checkPrivateRedeclaration(obj, privateSet);
    privateSet.add(obj);
  }
`;
    {
      helpers.classPrivateMethodSet = helper("7.1.6")`
    export default function _classPrivateMethodSet() {
      throw new TypeError("attempted to reassign private method");
    }
  `;
    }
    helpers.identity = helper("7.17.0")`
  export default function _identity(x) {
    return x;
  }
`;
  }
});

// node_modules/@babel/helpers/lib/index.js
var require_lib21 = __commonJS({
  "node_modules/@babel/helpers/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    exports.ensure = ensure;
    exports.get = get;
    exports.getDependencies = getDependencies;
    exports.list = void 0;
    exports.minVersion = minVersion;
    var _traverse = require_lib20();
    var _t = require_lib11();
    var _helpers = require_helpers();
    var {
      assignmentExpression,
      cloneNode,
      expressionStatement,
      file,
      identifier: identifier3
    } = _t;
    function makePath(path2) {
      const parts = [];
      for (; path2.parentPath; path2 = path2.parentPath) {
        parts.push(path2.key);
        if (path2.inList)
          parts.push(path2.listKey);
      }
      return parts.reverse().join(".");
    }
    var FileClass = void 0;
    function getHelperMetadata(file2) {
      const globals = /* @__PURE__ */ new Set();
      const localBindingNames = /* @__PURE__ */ new Set();
      const dependencies = /* @__PURE__ */ new Map();
      let exportName;
      let exportPath;
      const exportBindingAssignments = [];
      const importPaths = [];
      const importBindingsReferences = [];
      const dependencyVisitor = {
        ImportDeclaration(child) {
          const name = child.node.source.value;
          if (!_helpers.default[name]) {
            throw child.buildCodeFrameError(`Unknown helper ${name}`);
          }
          if (child.get("specifiers").length !== 1 || !child.get("specifiers.0").isImportDefaultSpecifier()) {
            throw child.buildCodeFrameError("Helpers can only import a default value");
          }
          const bindingIdentifier = child.node.specifiers[0].local;
          dependencies.set(bindingIdentifier, name);
          importPaths.push(makePath(child));
        },
        ExportDefaultDeclaration(child) {
          const decl = child.get("declaration");
          if (!decl.isFunctionDeclaration() || !decl.node.id) {
            throw decl.buildCodeFrameError("Helpers can only export named function declarations");
          }
          exportName = decl.node.id.name;
          exportPath = makePath(child);
        },
        ExportAllDeclaration(child) {
          throw child.buildCodeFrameError("Helpers can only export default");
        },
        ExportNamedDeclaration(child) {
          throw child.buildCodeFrameError("Helpers can only export default");
        },
        Statement(child) {
          if (child.isImportDeclaration() || child.isExportDeclaration())
            return;
          child.skip();
        }
      };
      const referenceVisitor = {
        Program(path2) {
          const bindings = path2.scope.getAllBindings();
          Object.keys(bindings).forEach((name) => {
            if (name === exportName)
              return;
            if (dependencies.has(bindings[name].identifier))
              return;
            localBindingNames.add(name);
          });
        },
        ReferencedIdentifier(child) {
          const name = child.node.name;
          const binding = child.scope.getBinding(name);
          if (!binding) {
            globals.add(name);
          } else if (dependencies.has(binding.identifier)) {
            importBindingsReferences.push(makePath(child));
          }
        },
        AssignmentExpression(child) {
          const left = child.get("left");
          if (!(exportName in left.getBindingIdentifiers()))
            return;
          if (!left.isIdentifier()) {
            throw left.buildCodeFrameError("Only simple assignments to exports are allowed in helpers");
          }
          const binding = child.scope.getBinding(exportName);
          if (binding != null && binding.scope.path.isProgram()) {
            exportBindingAssignments.push(makePath(child));
          }
        }
      };
      (0, _traverse.default)(file2.ast, dependencyVisitor, file2.scope);
      (0, _traverse.default)(file2.ast, referenceVisitor, file2.scope);
      if (!exportPath)
        throw new Error("Helpers must have a default export.");
      exportBindingAssignments.reverse();
      return {
        globals: Array.from(globals),
        localBindingNames: Array.from(localBindingNames),
        dependencies,
        exportBindingAssignments,
        exportPath,
        exportName,
        importBindingsReferences,
        importPaths
      };
    }
    function permuteHelperAST(file2, metadata, id, localBindings, getDependency) {
      if (localBindings && !id) {
        throw new Error("Unexpected local bindings for module-based helpers.");
      }
      if (!id)
        return;
      const {
        localBindingNames,
        dependencies,
        exportBindingAssignments,
        exportPath,
        exportName,
        importBindingsReferences,
        importPaths
      } = metadata;
      const dependenciesRefs = {};
      dependencies.forEach((name, id2) => {
        dependenciesRefs[id2.name] = typeof getDependency === "function" && getDependency(name) || id2;
      });
      const toRename = {};
      const bindings = new Set(localBindings || []);
      localBindingNames.forEach((name) => {
        let newName = name;
        while (bindings.has(newName))
          newName = "_" + newName;
        if (newName !== name)
          toRename[name] = newName;
      });
      if (id.type === "Identifier" && exportName !== id.name) {
        toRename[exportName] = id.name;
      }
      const {
        path: path2
      } = file2;
      const exp = path2.get(exportPath);
      const imps = importPaths.map((p) => path2.get(p));
      const impsBindingRefs = importBindingsReferences.map((p) => path2.get(p));
      const decl = exp.get("declaration");
      if (id.type === "Identifier") {
        exp.replaceWith(decl);
      } else if (id.type === "MemberExpression") {
        exportBindingAssignments.forEach((assignPath) => {
          const assign = path2.get(assignPath);
          assign.replaceWith(assignmentExpression("=", id, assign.node));
        });
        exp.replaceWith(decl);
        path2.pushContainer("body", expressionStatement(assignmentExpression("=", id, identifier3(exportName))));
      } else {
        throw new Error("Unexpected helper format.");
      }
      Object.keys(toRename).forEach((name) => {
        path2.scope.rename(name, toRename[name]);
      });
      for (const path3 of imps)
        path3.remove();
      for (const path3 of impsBindingRefs) {
        const node = cloneNode(dependenciesRefs[path3.node.name]);
        path3.replaceWith(node);
      }
    }
    var helperData = /* @__PURE__ */ Object.create(null);
    function loadHelper(name) {
      if (!helperData[name]) {
        const helper = _helpers.default[name];
        if (!helper) {
          throw Object.assign(new ReferenceError(`Unknown helper ${name}`), {
            code: "BABEL_HELPER_UNKNOWN",
            helper: name
          });
        }
        const fn = () => {
          {
            if (!FileClass) {
              const fakeFile = {
                ast: file(helper.ast()),
                path: null
              };
              (0, _traverse.default)(fakeFile.ast, {
                Program: (path2) => (fakeFile.path = path2).stop()
              });
              return fakeFile;
            }
          }
          return new FileClass({
            filename: `babel-helper://${name}`
          }, {
            ast: file(helper.ast()),
            code: "[internal Babel helper code]",
            inputMap: null
          });
        };
        let metadata = null;
        helperData[name] = {
          minVersion: helper.minVersion,
          build(getDependency, id, localBindings) {
            const file2 = fn();
            metadata || (metadata = getHelperMetadata(file2));
            permuteHelperAST(file2, metadata, id, localBindings, getDependency);
            return {
              nodes: file2.ast.program.body,
              globals: metadata.globals
            };
          },
          getDependencies() {
            metadata || (metadata = getHelperMetadata(fn()));
            return Array.from(metadata.dependencies.values());
          }
        };
      }
      return helperData[name];
    }
    function get(name, getDependency, id, localBindings) {
      return loadHelper(name).build(getDependency, id, localBindings);
    }
    function minVersion(name) {
      return loadHelper(name).minVersion;
    }
    function getDependencies(name) {
      return loadHelper(name).getDependencies();
    }
    function ensure(name, newFileClass) {
      FileClass || (FileClass = newFileClass);
      loadHelper(name);
    }
    var list = Object.keys(_helpers.default).map((name) => name.replace(/^_/, ""));
    exports.list = list;
    var _default = get;
    exports.default = _default;
  }
});

// node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/import-builder.js
var require_import_builder = __commonJS({
  "node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/import-builder.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _assert = require("assert");
    var _t = require_lib11();
    var {
      callExpression: callExpression3,
      cloneNode,
      expressionStatement,
      identifier: identifier3,
      importDeclaration,
      importDefaultSpecifier,
      importNamespaceSpecifier,
      importSpecifier: importSpecifier2,
      memberExpression,
      stringLiteral: stringLiteral2,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t;
    var ImportBuilder = class {
      constructor(importedSource, scope, hub) {
        this._statements = [];
        this._resultName = null;
        this._importedSource = void 0;
        this._scope = scope;
        this._hub = hub;
        this._importedSource = importedSource;
      }
      done() {
        return {
          statements: this._statements,
          resultName: this._resultName
        };
      }
      import() {
        this._statements.push(importDeclaration([], stringLiteral2(this._importedSource)));
        return this;
      }
      require() {
        this._statements.push(expressionStatement(callExpression3(identifier3("require"), [stringLiteral2(this._importedSource)])));
        return this;
      }
      namespace(name = "namespace") {
        const local = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importNamespaceSpecifier(local)];
        this._resultName = cloneNode(local);
        return this;
      }
      default(name) {
        const id = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importDefaultSpecifier(id)];
        this._resultName = cloneNode(id);
        return this;
      }
      named(name, importName) {
        if (importName === "default")
          return this.default(name);
        const id = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importSpecifier2(id, identifier3(importName))];
        this._resultName = cloneNode(id);
        return this;
      }
      var(name) {
        const id = this._scope.generateUidIdentifier(name);
        let statement = this._statements[this._statements.length - 1];
        if (statement.type !== "ExpressionStatement") {
          _assert(this._resultName);
          statement = expressionStatement(this._resultName);
          this._statements.push(statement);
        }
        this._statements[this._statements.length - 1] = variableDeclaration2("var", [variableDeclarator2(id, statement.expression)]);
        this._resultName = cloneNode(id);
        return this;
      }
      defaultInterop() {
        return this._interop(this._hub.addHelper("interopRequireDefault"));
      }
      wildcardInterop() {
        return this._interop(this._hub.addHelper("interopRequireWildcard"));
      }
      _interop(callee) {
        const statement = this._statements[this._statements.length - 1];
        if (statement.type === "ExpressionStatement") {
          statement.expression = callExpression3(callee, [statement.expression]);
        } else if (statement.type === "VariableDeclaration") {
          _assert(statement.declarations.length === 1);
          statement.declarations[0].init = callExpression3(callee, [statement.declarations[0].init]);
        } else {
          _assert.fail("Unexpected type.");
        }
        return this;
      }
      prop(name) {
        const statement = this._statements[this._statements.length - 1];
        if (statement.type === "ExpressionStatement") {
          statement.expression = memberExpression(statement.expression, identifier3(name));
        } else if (statement.type === "VariableDeclaration") {
          _assert(statement.declarations.length === 1);
          statement.declarations[0].init = memberExpression(statement.declarations[0].init, identifier3(name));
        } else {
          _assert.fail("Unexpected type:" + statement.type);
        }
        return this;
      }
      read(name) {
        this._resultName = memberExpression(this._resultName, identifier3(name));
      }
    };
    exports.default = ImportBuilder;
  }
});

// node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/is-module.js
var require_is_module = __commonJS({
  "node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/is-module.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isModule;
    function isModule(path2) {
      const {
        sourceType
      } = path2.node;
      if (sourceType !== "module" && sourceType !== "script") {
        throw path2.buildCodeFrameError(`Unknown sourceType "${sourceType}", cannot transform.`);
      }
      return path2.node.sourceType === "module";
    }
  }
});

// node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/import-injector.js
var require_import_injector = __commonJS({
  "node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/import-injector.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _assert = require("assert");
    var _t = require_lib11();
    var _importBuilder = require_import_builder();
    var _isModule = require_is_module();
    var {
      numericLiteral,
      sequenceExpression
    } = _t;
    var ImportInjector = class {
      constructor(path2, importedSource, opts) {
        this._defaultOpts = {
          importedSource: null,
          importedType: "commonjs",
          importedInterop: "babel",
          importingInterop: "babel",
          ensureLiveReference: false,
          ensureNoContext: false,
          importPosition: "before"
        };
        const programPath = path2.find((p) => p.isProgram());
        this._programPath = programPath;
        this._programScope = programPath.scope;
        this._hub = programPath.hub;
        this._defaultOpts = this._applyDefaults(importedSource, opts, true);
      }
      addDefault(importedSourceIn, opts) {
        return this.addNamed("default", importedSourceIn, opts);
      }
      addNamed(importName, importedSourceIn, opts) {
        _assert(typeof importName === "string");
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), importName);
      }
      addNamespace(importedSourceIn, opts) {
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), null);
      }
      addSideEffect(importedSourceIn, opts) {
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), void 0);
      }
      _applyDefaults(importedSource, opts, isInit = false) {
        let newOpts;
        if (typeof importedSource === "string") {
          newOpts = Object.assign({}, this._defaultOpts, {
            importedSource
          }, opts);
        } else {
          _assert(!opts, "Unexpected secondary arguments.");
          newOpts = Object.assign({}, this._defaultOpts, importedSource);
        }
        if (!isInit && opts) {
          if (opts.nameHint !== void 0)
            newOpts.nameHint = opts.nameHint;
          if (opts.blockHoist !== void 0)
            newOpts.blockHoist = opts.blockHoist;
        }
        return newOpts;
      }
      _generateImport(opts, importName) {
        const isDefault = importName === "default";
        const isNamed = !!importName && !isDefault;
        const isNamespace = importName === null;
        const {
          importedSource,
          importedType,
          importedInterop,
          importingInterop,
          ensureLiveReference,
          ensureNoContext,
          nameHint,
          importPosition,
          blockHoist
        } = opts;
        let name = nameHint || importName;
        const isMod = (0, _isModule.default)(this._programPath);
        const isModuleForNode = isMod && importingInterop === "node";
        const isModuleForBabel = isMod && importingInterop === "babel";
        if (importPosition === "after" && !isMod) {
          throw new Error(`"importPosition": "after" is only supported in modules`);
        }
        const builder = new _importBuilder.default(importedSource, this._programScope, this._hub);
        if (importedType === "es6") {
          if (!isModuleForNode && !isModuleForBabel) {
            throw new Error("Cannot import an ES6 module from CommonJS");
          }
          builder.import();
          if (isNamespace) {
            builder.namespace(nameHint || importedSource);
          } else if (isDefault || isNamed) {
            builder.named(name, importName);
          }
        } else if (importedType !== "commonjs") {
          throw new Error(`Unexpected interopType "${importedType}"`);
        } else if (importedInterop === "babel") {
          if (isModuleForNode) {
            name = name !== "default" ? name : importedSource;
            const es6Default = `${importedSource}$es6Default`;
            builder.import();
            if (isNamespace) {
              builder.default(es6Default).var(name || importedSource).wildcardInterop();
            } else if (isDefault) {
              if (ensureLiveReference) {
                builder.default(es6Default).var(name || importedSource).defaultInterop().read("default");
              } else {
                builder.default(es6Default).var(name).defaultInterop().prop(importName);
              }
            } else if (isNamed) {
              builder.default(es6Default).read(importName);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.namespace(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource).wildcardInterop();
            } else if ((isDefault || isNamed) && ensureLiveReference) {
              if (isDefault) {
                name = name !== "default" ? name : importedSource;
                builder.var(name).read(importName);
                builder.defaultInterop();
              } else {
                builder.var(importedSource).read(importName);
              }
            } else if (isDefault) {
              builder.var(name).defaultInterop().prop(importName);
            } else if (isNamed) {
              builder.var(name).prop(importName);
            }
          }
        } else if (importedInterop === "compiled") {
          if (isModuleForNode) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.default(importedSource).read(name);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.namespace(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource);
            } else if (isDefault || isNamed) {
              if (ensureLiveReference) {
                builder.var(importedSource).read(name);
              } else {
                builder.prop(importName).var(name);
              }
            }
          }
        } else if (importedInterop === "uncompiled") {
          if (isDefault && ensureLiveReference) {
            throw new Error("No live reference for commonjs default");
          }
          if (isModuleForNode) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault) {
              builder.default(name);
            } else if (isNamed) {
              builder.default(importedSource).read(name);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault) {
              builder.default(name);
            } else if (isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource);
            } else if (isDefault) {
              builder.var(name);
            } else if (isNamed) {
              if (ensureLiveReference) {
                builder.var(importedSource).read(name);
              } else {
                builder.var(name).prop(importName);
              }
            }
          }
        } else {
          throw new Error(`Unknown importedInterop "${importedInterop}".`);
        }
        const {
          statements,
          resultName
        } = builder.done();
        this._insertStatements(statements, importPosition, blockHoist);
        if ((isDefault || isNamed) && ensureNoContext && resultName.type !== "Identifier") {
          return sequenceExpression([numericLiteral(0), resultName]);
        }
        return resultName;
      }
      _insertStatements(statements, importPosition = "before", blockHoist = 3) {
        const body = this._programPath.get("body");
        if (importPosition === "after") {
          for (let i = body.length - 1; i >= 0; i--) {
            if (body[i].isImportDeclaration()) {
              body[i].insertAfter(statements);
              return;
            }
          }
        } else {
          statements.forEach((node) => {
            node._blockHoist = blockHoist;
          });
          const targetPath = body.find((p) => {
            const val = p.node._blockHoist;
            return Number.isFinite(val) && val < 4;
          });
          if (targetPath) {
            targetPath.insertBefore(statements);
            return;
          }
        }
        this._programPath.unshiftContainer("body", statements);
      }
    };
    exports.default = ImportInjector;
  }
});

// node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/index.js
var require_lib22 = __commonJS({
  "node_modules/@babel/helper-module-transforms/node_modules/@babel/helper-module-imports/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "ImportInjector", {
      enumerable: true,
      get: function() {
        return _importInjector.default;
      }
    });
    exports.addDefault = addDefault;
    exports.addNamed = addNamed2;
    exports.addNamespace = addNamespace;
    exports.addSideEffect = addSideEffect;
    Object.defineProperty(exports, "isModule", {
      enumerable: true,
      get: function() {
        return _isModule.default;
      }
    });
    var _importInjector = require_import_injector();
    var _isModule = require_is_module();
    function addDefault(path2, importedSource, opts) {
      return new _importInjector.default(path2).addDefault(importedSource, opts);
    }
    function addNamed2(path2, name, importedSource, opts) {
      return new _importInjector.default(path2).addNamed(name, importedSource, opts);
    }
    function addNamespace(path2, importedSource, opts) {
      return new _importInjector.default(path2).addNamespace(importedSource, opts);
    }
    function addSideEffect(path2, importedSource, opts) {
      return new _importInjector.default(path2).addSideEffect(importedSource, opts);
    }
  }
});

// node_modules/@babel/helper-module-transforms/lib/rewrite-this.js
var require_rewrite_this = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/rewrite-this.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = rewriteThis;
    var _helperEnvironmentVisitor = require_lib13();
    var _traverse = require_lib20();
    var _t = require_lib11();
    var {
      numericLiteral,
      unaryExpression
    } = _t;
    var rewriteThisVisitor = _traverse.default.visitors.merge([_helperEnvironmentVisitor.default, {
      ThisExpression(path2) {
        path2.replaceWith(unaryExpression("void", numericLiteral(0), true));
      }
    }]);
    function rewriteThis(programPath) {
      (0, _traverse.default)(programPath.node, Object.assign({}, rewriteThisVisitor, {
        noScope: true
      }));
    }
  }
});

// node_modules/@babel/helper-simple-access/lib/index.js
var require_lib23 = __commonJS({
  "node_modules/@babel/helper-simple-access/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = simplifyAccess;
    var _t = require_lib11();
    var {
      LOGICAL_OPERATORS,
      assignmentExpression,
      binaryExpression,
      cloneNode,
      identifier: identifier3,
      logicalExpression,
      numericLiteral,
      sequenceExpression,
      unaryExpression
    } = _t;
    var simpleAssignmentVisitor = {
      UpdateExpression: {
        exit(path2) {
          const {
            scope,
            bindingNames,
            includeUpdateExpression
          } = this;
          if (!includeUpdateExpression) {
            return;
          }
          const arg = path2.get("argument");
          if (!arg.isIdentifier())
            return;
          const localName = arg.node.name;
          if (!bindingNames.has(localName))
            return;
          if (scope.getBinding(localName) !== path2.scope.getBinding(localName)) {
            return;
          }
          if (path2.parentPath.isExpressionStatement() && !path2.isCompletionRecord()) {
            const operator = path2.node.operator == "++" ? "+=" : "-=";
            path2.replaceWith(assignmentExpression(operator, arg.node, numericLiteral(1)));
          } else if (path2.node.prefix) {
            path2.replaceWith(assignmentExpression("=", identifier3(localName), binaryExpression(path2.node.operator[0], unaryExpression("+", arg.node), numericLiteral(1))));
          } else {
            const old = path2.scope.generateUidIdentifierBasedOnNode(arg.node, "old");
            const varName = old.name;
            path2.scope.push({
              id: old
            });
            const binary = binaryExpression(
              path2.node.operator[0],
              identifier3(varName),
              numericLiteral(1)
            );
            path2.replaceWith(sequenceExpression([assignmentExpression("=", identifier3(varName), unaryExpression("+", arg.node)), assignmentExpression("=", cloneNode(arg.node), binary), identifier3(varName)]));
          }
        }
      },
      AssignmentExpression: {
        exit(path2) {
          const {
            scope,
            seen,
            bindingNames
          } = this;
          if (path2.node.operator === "=")
            return;
          if (seen.has(path2.node))
            return;
          seen.add(path2.node);
          const left = path2.get("left");
          if (!left.isIdentifier())
            return;
          const localName = left.node.name;
          if (!bindingNames.has(localName))
            return;
          if (scope.getBinding(localName) !== path2.scope.getBinding(localName)) {
            return;
          }
          const operator = path2.node.operator.slice(0, -1);
          if (LOGICAL_OPERATORS.includes(operator)) {
            path2.replaceWith(logicalExpression(
              operator,
              path2.node.left,
              assignmentExpression("=", cloneNode(path2.node.left), path2.node.right)
            ));
          } else {
            path2.node.right = binaryExpression(
              operator,
              cloneNode(path2.node.left),
              path2.node.right
            );
            path2.node.operator = "=";
          }
        }
      }
    };
    function simplifyAccess(path2, bindingNames, includeUpdateExpression = true) {
      path2.traverse(simpleAssignmentVisitor, {
        scope: path2.scope,
        bindingNames,
        seen: /* @__PURE__ */ new WeakSet(),
        includeUpdateExpression
      });
    }
  }
});

// node_modules/@babel/helper-module-transforms/lib/rewrite-live-references.js
var require_rewrite_live_references = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/rewrite-live-references.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = rewriteLiveReferences;
    var _assert = require("assert");
    var _t = require_lib11();
    var _template = require_lib18();
    var _helperSimpleAccess = require_lib23();
    var {
      assignmentExpression,
      callExpression: callExpression3,
      cloneNode,
      expressionStatement,
      getOuterBindingIdentifiers,
      identifier: identifier3,
      isMemberExpression,
      isVariableDeclaration,
      jsxIdentifier,
      jsxMemberExpression,
      memberExpression,
      numericLiteral,
      sequenceExpression,
      stringLiteral: stringLiteral2,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t;
    function isInType(path2) {
      do {
        switch (path2.parent.type) {
          case "TSTypeAnnotation":
          case "TSTypeAliasDeclaration":
          case "TSTypeReference":
          case "TypeAnnotation":
          case "TypeAlias":
            return true;
          case "ExportSpecifier":
            return path2.parentPath.parent.exportKind === "type";
          default:
            if (path2.parentPath.isStatement() || path2.parentPath.isExpression()) {
              return false;
            }
        }
      } while (path2 = path2.parentPath);
    }
    function rewriteLiveReferences(programPath, metadata) {
      const imported = /* @__PURE__ */ new Map();
      const exported = /* @__PURE__ */ new Map();
      const requeueInParent = (path2) => {
        programPath.requeue(path2);
      };
      for (const [source, data] of metadata.source) {
        for (const [localName, importName] of data.imports) {
          imported.set(localName, [source, importName, null]);
        }
        for (const localName of data.importsNamespace) {
          imported.set(localName, [source, null, localName]);
        }
      }
      for (const [local, data] of metadata.local) {
        let exportMeta = exported.get(local);
        if (!exportMeta) {
          exportMeta = [];
          exported.set(local, exportMeta);
        }
        exportMeta.push(...data.names);
      }
      const rewriteBindingInitVisitorState = {
        metadata,
        requeueInParent,
        scope: programPath.scope,
        exported
      };
      programPath.traverse(
        rewriteBindingInitVisitor,
        rewriteBindingInitVisitorState
      );
      (0, _helperSimpleAccess.default)(
        programPath,
        /* @__PURE__ */ new Set([...Array.from(imported.keys()), ...Array.from(exported.keys())]),
        false
      );
      const rewriteReferencesVisitorState = {
        seen: /* @__PURE__ */ new WeakSet(),
        metadata,
        requeueInParent,
        scope: programPath.scope,
        imported,
        exported,
        buildImportReference: ([source, importName, localName], identNode) => {
          const meta = metadata.source.get(source);
          if (localName) {
            if (meta.lazy) {
              identNode = callExpression3(
                identNode,
                []
              );
            }
            return identNode;
          }
          let namespace = identifier3(meta.name);
          if (meta.lazy)
            namespace = callExpression3(namespace, []);
          if (importName === "default" && meta.interop === "node-default") {
            return namespace;
          }
          const computed = metadata.stringSpecifiers.has(importName);
          return memberExpression(namespace, computed ? stringLiteral2(importName) : identifier3(importName), computed);
        }
      };
      programPath.traverse(rewriteReferencesVisitor, rewriteReferencesVisitorState);
    }
    var rewriteBindingInitVisitor = {
      Scope(path2) {
        path2.skip();
      },
      ClassDeclaration(path2) {
        const {
          requeueInParent,
          exported,
          metadata
        } = this;
        const {
          id
        } = path2.node;
        if (!id)
          throw new Error("Expected class to have a name");
        const localName = id.name;
        const exportNames = exported.get(localName) || [];
        if (exportNames.length > 0) {
          const statement = expressionStatement(
            buildBindingExportAssignmentExpression(metadata, exportNames, identifier3(localName), path2.scope)
          );
          statement._blockHoist = path2.node._blockHoist;
          requeueInParent(path2.insertAfter(statement)[0]);
        }
      },
      VariableDeclaration(path2) {
        const {
          requeueInParent,
          exported,
          metadata
        } = this;
        Object.keys(path2.getOuterBindingIdentifiers()).forEach((localName) => {
          const exportNames = exported.get(localName) || [];
          if (exportNames.length > 0) {
            const statement = expressionStatement(
              buildBindingExportAssignmentExpression(metadata, exportNames, identifier3(localName), path2.scope)
            );
            statement._blockHoist = path2.node._blockHoist;
            requeueInParent(path2.insertAfter(statement)[0]);
          }
        });
      }
    };
    var buildBindingExportAssignmentExpression = (metadata, exportNames, localExpr, scope) => {
      const exportsObjectName = metadata.exportName;
      for (let currentScope = scope; currentScope != null; currentScope = currentScope.parent) {
        if (currentScope.hasOwnBinding(exportsObjectName)) {
          currentScope.rename(exportsObjectName);
        }
      }
      return (exportNames || []).reduce((expr, exportName) => {
        const {
          stringSpecifiers
        } = metadata;
        const computed = stringSpecifiers.has(exportName);
        return assignmentExpression("=", memberExpression(identifier3(exportsObjectName), computed ? stringLiteral2(exportName) : identifier3(exportName), computed), expr);
      }, localExpr);
    };
    var buildImportThrow = (localName) => {
      return _template.default.expression.ast`
    (function() {
      throw new Error('"' + '${localName}' + '" is read-only.');
    })()
  `;
    };
    var rewriteReferencesVisitor = {
      ReferencedIdentifier(path2) {
        const {
          seen,
          buildImportReference,
          scope,
          imported,
          requeueInParent
        } = this;
        if (seen.has(path2.node))
          return;
        seen.add(path2.node);
        const localName = path2.node.name;
        const importData = imported.get(localName);
        if (importData) {
          if (isInType(path2)) {
            throw path2.buildCodeFrameError(`Cannot transform the imported binding "${localName}" since it's also used in a type annotation. Please strip type annotations using @babel/preset-typescript or @babel/preset-flow.`);
          }
          const localBinding = path2.scope.getBinding(localName);
          const rootBinding = scope.getBinding(localName);
          if (rootBinding !== localBinding)
            return;
          const ref = buildImportReference(importData, path2.node);
          ref.loc = path2.node.loc;
          if ((path2.parentPath.isCallExpression({
            callee: path2.node
          }) || path2.parentPath.isOptionalCallExpression({
            callee: path2.node
          }) || path2.parentPath.isTaggedTemplateExpression({
            tag: path2.node
          })) && isMemberExpression(ref)) {
            path2.replaceWith(sequenceExpression([numericLiteral(0), ref]));
          } else if (path2.isJSXIdentifier() && isMemberExpression(ref)) {
            const {
              object,
              property
            } = ref;
            path2.replaceWith(jsxMemberExpression(
              jsxIdentifier(object.name),
              jsxIdentifier(property.name)
            ));
          } else {
            path2.replaceWith(ref);
          }
          requeueInParent(path2);
          path2.skip();
        }
      },
      UpdateExpression(path2) {
        const {
          scope,
          seen,
          imported,
          exported,
          requeueInParent,
          buildImportReference
        } = this;
        if (seen.has(path2.node))
          return;
        seen.add(path2.node);
        const arg = path2.get("argument");
        if (arg.isMemberExpression())
          return;
        const update = path2.node;
        if (arg.isIdentifier()) {
          const localName = arg.node.name;
          if (scope.getBinding(localName) !== path2.scope.getBinding(localName)) {
            return;
          }
          const exportedNames = exported.get(localName);
          const importData = imported.get(localName);
          if ((exportedNames == null ? void 0 : exportedNames.length) > 0 || importData) {
            if (importData) {
              path2.replaceWith(assignmentExpression(update.operator[0] + "=", buildImportReference(importData, arg.node), buildImportThrow(localName)));
            } else if (update.prefix) {
              path2.replaceWith(buildBindingExportAssignmentExpression(this.metadata, exportedNames, cloneNode(update), path2.scope));
            } else {
              const ref = scope.generateDeclaredUidIdentifier(localName);
              path2.replaceWith(sequenceExpression([assignmentExpression("=", cloneNode(ref), cloneNode(update)), buildBindingExportAssignmentExpression(this.metadata, exportedNames, identifier3(localName), path2.scope), cloneNode(ref)]));
            }
          }
        }
        requeueInParent(path2);
        path2.skip();
      },
      AssignmentExpression: {
        exit(path2) {
          const {
            scope,
            seen,
            imported,
            exported,
            requeueInParent,
            buildImportReference
          } = this;
          if (seen.has(path2.node))
            return;
          seen.add(path2.node);
          const left = path2.get("left");
          if (left.isMemberExpression())
            return;
          if (left.isIdentifier()) {
            const localName = left.node.name;
            if (scope.getBinding(localName) !== path2.scope.getBinding(localName)) {
              return;
            }
            const exportedNames = exported.get(localName);
            const importData = imported.get(localName);
            if ((exportedNames == null ? void 0 : exportedNames.length) > 0 || importData) {
              _assert(path2.node.operator === "=", "Path was not simplified");
              const assignment = path2.node;
              if (importData) {
                assignment.left = buildImportReference(importData, left.node);
                assignment.right = sequenceExpression([assignment.right, buildImportThrow(localName)]);
              }
              path2.replaceWith(buildBindingExportAssignmentExpression(this.metadata, exportedNames, assignment, path2.scope));
              requeueInParent(path2);
            }
          } else {
            const ids = left.getOuterBindingIdentifiers();
            const programScopeIds = Object.keys(ids).filter((localName) => scope.getBinding(localName) === path2.scope.getBinding(localName));
            const id = programScopeIds.find((localName) => imported.has(localName));
            if (id) {
              path2.node.right = sequenceExpression([path2.node.right, buildImportThrow(id)]);
            }
            const items = [];
            programScopeIds.forEach((localName) => {
              const exportedNames = exported.get(localName) || [];
              if (exportedNames.length > 0) {
                items.push(buildBindingExportAssignmentExpression(this.metadata, exportedNames, identifier3(localName), path2.scope));
              }
            });
            if (items.length > 0) {
              let node = sequenceExpression(items);
              if (path2.parentPath.isExpressionStatement()) {
                node = expressionStatement(node);
                node._blockHoist = path2.parentPath.node._blockHoist;
              }
              const statement = path2.insertAfter(node)[0];
              requeueInParent(statement);
            }
          }
        }
      },
      "ForOfStatement|ForInStatement"(path2) {
        const {
          scope,
          node
        } = path2;
        const {
          left
        } = node;
        const {
          exported,
          imported,
          scope: programScope
        } = this;
        if (!isVariableDeclaration(left)) {
          let didTransformExport = false, importConstViolationName;
          const loopBodyScope = path2.get("body").scope;
          for (const name of Object.keys(getOuterBindingIdentifiers(left))) {
            if (programScope.getBinding(name) === scope.getBinding(name)) {
              if (exported.has(name)) {
                didTransformExport = true;
                if (loopBodyScope.hasOwnBinding(name)) {
                  loopBodyScope.rename(name);
                }
              }
              if (imported.has(name) && !importConstViolationName) {
                importConstViolationName = name;
              }
            }
          }
          if (!didTransformExport && !importConstViolationName) {
            return;
          }
          path2.ensureBlock();
          const bodyPath = path2.get("body");
          const newLoopId = scope.generateUidIdentifierBasedOnNode(left);
          path2.get("left").replaceWith(variableDeclaration2("let", [variableDeclarator2(cloneNode(newLoopId))]));
          scope.registerDeclaration(path2.get("left"));
          if (didTransformExport) {
            bodyPath.unshiftContainer("body", expressionStatement(assignmentExpression("=", left, newLoopId)));
          }
          if (importConstViolationName) {
            bodyPath.unshiftContainer("body", expressionStatement(buildImportThrow(importConstViolationName)));
          }
        }
      }
    };
  }
});

// node_modules/@babel/helper-module-transforms/lib/normalize-and-load-metadata.js
var require_normalize_and_load_metadata = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/normalize-and-load-metadata.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = normalizeModuleAndLoadMetadata;
    exports.hasExports = hasExports;
    exports.isSideEffectImport = isSideEffectImport;
    exports.validateImportInteropOption = validateImportInteropOption;
    var _path = require("path");
    var _helperValidatorIdentifier = require_lib9();
    var _helperSplitExportDeclaration = require_lib12();
    function hasExports(metadata) {
      return metadata.hasExports;
    }
    function isSideEffectImport(source) {
      return source.imports.size === 0 && source.importsNamespace.size === 0 && source.reexports.size === 0 && source.reexportNamespace.size === 0 && !source.reexportAll;
    }
    function validateImportInteropOption(importInterop) {
      if (typeof importInterop !== "function" && importInterop !== "none" && importInterop !== "babel" && importInterop !== "node") {
        throw new Error(`.importInterop must be one of "none", "babel", "node", or a function returning one of those values (received ${importInterop}).`);
      }
      return importInterop;
    }
    function resolveImportInterop(importInterop, source, filename) {
      if (typeof importInterop === "function") {
        return validateImportInteropOption(importInterop(source, filename));
      }
      return importInterop;
    }
    function normalizeModuleAndLoadMetadata(programPath, exportName, {
      importInterop,
      initializeReexports = false,
      lazy = false,
      esNamespaceOnly = false,
      filename
    }) {
      if (!exportName) {
        exportName = programPath.scope.generateUidIdentifier("exports").name;
      }
      const stringSpecifiers = /* @__PURE__ */ new Set();
      nameAnonymousExports(programPath);
      const {
        local,
        source,
        hasExports: hasExports2
      } = getModuleMetadata(programPath, {
        initializeReexports,
        lazy
      }, stringSpecifiers);
      removeImportExportDeclarations(programPath);
      for (const [, metadata] of source) {
        if (metadata.importsNamespace.size > 0) {
          metadata.name = metadata.importsNamespace.values().next().value;
        }
        const resolvedInterop = resolveImportInterop(importInterop, metadata.source, filename);
        if (resolvedInterop === "none") {
          metadata.interop = "none";
        } else if (resolvedInterop === "node" && metadata.interop === "namespace") {
          metadata.interop = "node-namespace";
        } else if (resolvedInterop === "node" && metadata.interop === "default") {
          metadata.interop = "node-default";
        } else if (esNamespaceOnly && metadata.interop === "namespace") {
          metadata.interop = "default";
        }
      }
      return {
        exportName,
        exportNameListName: null,
        hasExports: hasExports2,
        local,
        source,
        stringSpecifiers
      };
    }
    function getExportSpecifierName(path2, stringSpecifiers) {
      if (path2.isIdentifier()) {
        return path2.node.name;
      } else if (path2.isStringLiteral()) {
        const stringValue = path2.node.value;
        if (!(0, _helperValidatorIdentifier.isIdentifierName)(stringValue)) {
          stringSpecifiers.add(stringValue);
        }
        return stringValue;
      } else {
        throw new Error(`Expected export specifier to be either Identifier or StringLiteral, got ${path2.node.type}`);
      }
    }
    function assertExportSpecifier(path2) {
      if (path2.isExportSpecifier()) {
        return;
      } else if (path2.isExportNamespaceSpecifier()) {
        throw path2.buildCodeFrameError("Export namespace should be first transformed by `@babel/plugin-proposal-export-namespace-from`.");
      } else {
        throw path2.buildCodeFrameError("Unexpected export specifier type");
      }
    }
    function getModuleMetadata(programPath, {
      lazy,
      initializeReexports
    }, stringSpecifiers) {
      const localData = getLocalExportMetadata(programPath, initializeReexports, stringSpecifiers);
      const sourceData = /* @__PURE__ */ new Map();
      const getData = (sourceNode) => {
        const source = sourceNode.value;
        let data = sourceData.get(source);
        if (!data) {
          data = {
            name: programPath.scope.generateUidIdentifier((0, _path.basename)(source, (0, _path.extname)(source))).name,
            interop: "none",
            loc: null,
            imports: /* @__PURE__ */ new Map(),
            importsNamespace: /* @__PURE__ */ new Set(),
            reexports: /* @__PURE__ */ new Map(),
            reexportNamespace: /* @__PURE__ */ new Set(),
            reexportAll: null,
            lazy: false,
            source
          };
          sourceData.set(source, data);
        }
        return data;
      };
      let hasExports2 = false;
      programPath.get("body").forEach((child) => {
        if (child.isImportDeclaration()) {
          const data = getData(child.node.source);
          if (!data.loc)
            data.loc = child.node.loc;
          child.get("specifiers").forEach((spec) => {
            if (spec.isImportDefaultSpecifier()) {
              const localName = spec.get("local").node.name;
              data.imports.set(localName, "default");
              const reexport = localData.get(localName);
              if (reexport) {
                localData.delete(localName);
                reexport.names.forEach((name) => {
                  data.reexports.set(name, "default");
                });
              }
            } else if (spec.isImportNamespaceSpecifier()) {
              const localName = spec.get("local").node.name;
              data.importsNamespace.add(localName);
              const reexport = localData.get(localName);
              if (reexport) {
                localData.delete(localName);
                reexport.names.forEach((name) => {
                  data.reexportNamespace.add(name);
                });
              }
            } else if (spec.isImportSpecifier()) {
              const importName = getExportSpecifierName(spec.get("imported"), stringSpecifiers);
              const localName = spec.get("local").node.name;
              data.imports.set(localName, importName);
              const reexport = localData.get(localName);
              if (reexport) {
                localData.delete(localName);
                reexport.names.forEach((name) => {
                  data.reexports.set(name, importName);
                });
              }
            }
          });
        } else if (child.isExportAllDeclaration()) {
          hasExports2 = true;
          const data = getData(child.node.source);
          if (!data.loc)
            data.loc = child.node.loc;
          data.reexportAll = {
            loc: child.node.loc
          };
        } else if (child.isExportNamedDeclaration() && child.node.source) {
          hasExports2 = true;
          const data = getData(child.node.source);
          if (!data.loc)
            data.loc = child.node.loc;
          child.get("specifiers").forEach((spec) => {
            assertExportSpecifier(spec);
            const importName = getExportSpecifierName(spec.get("local"), stringSpecifiers);
            const exportName = getExportSpecifierName(spec.get("exported"), stringSpecifiers);
            data.reexports.set(exportName, importName);
            if (exportName === "__esModule") {
              throw spec.get("exported").buildCodeFrameError('Illegal export "__esModule".');
            }
          });
        } else if (child.isExportNamedDeclaration() || child.isExportDefaultDeclaration()) {
          hasExports2 = true;
        }
      });
      for (const metadata of sourceData.values()) {
        let needsDefault = false;
        let needsNamed = false;
        if (metadata.importsNamespace.size > 0) {
          needsDefault = true;
          needsNamed = true;
        }
        if (metadata.reexportAll) {
          needsNamed = true;
        }
        for (const importName of metadata.imports.values()) {
          if (importName === "default")
            needsDefault = true;
          else
            needsNamed = true;
        }
        for (const importName of metadata.reexports.values()) {
          if (importName === "default")
            needsDefault = true;
          else
            needsNamed = true;
        }
        if (needsDefault && needsNamed) {
          metadata.interop = "namespace";
        } else if (needsDefault) {
          metadata.interop = "default";
        }
      }
      for (const [source, metadata] of sourceData) {
        if (lazy !== false && !(isSideEffectImport(metadata) || metadata.reexportAll)) {
          if (lazy === true) {
            metadata.lazy = !/\./.test(source);
          } else if (Array.isArray(lazy)) {
            metadata.lazy = lazy.indexOf(source) !== -1;
          } else if (typeof lazy === "function") {
            metadata.lazy = lazy(source);
          } else {
            throw new Error(`.lazy must be a boolean, string array, or function`);
          }
        }
      }
      return {
        hasExports: hasExports2,
        local: localData,
        source: sourceData
      };
    }
    function getLocalExportMetadata(programPath, initializeReexports, stringSpecifiers) {
      const bindingKindLookup = /* @__PURE__ */ new Map();
      programPath.get("body").forEach((child) => {
        let kind;
        if (child.isImportDeclaration()) {
          kind = "import";
        } else {
          if (child.isExportDefaultDeclaration()) {
            child = child.get("declaration");
          }
          if (child.isExportNamedDeclaration()) {
            if (child.node.declaration) {
              child = child.get("declaration");
            } else if (initializeReexports && child.node.source && child.get("source").isStringLiteral()) {
              child.get("specifiers").forEach((spec) => {
                assertExportSpecifier(spec);
                bindingKindLookup.set(spec.get("local").node.name, "block");
              });
              return;
            }
          }
          if (child.isFunctionDeclaration()) {
            kind = "hoisted";
          } else if (child.isClassDeclaration()) {
            kind = "block";
          } else if (child.isVariableDeclaration({
            kind: "var"
          })) {
            kind = "var";
          } else if (child.isVariableDeclaration()) {
            kind = "block";
          } else {
            return;
          }
        }
        Object.keys(child.getOuterBindingIdentifiers()).forEach((name) => {
          bindingKindLookup.set(name, kind);
        });
      });
      const localMetadata = /* @__PURE__ */ new Map();
      const getLocalMetadata = (idPath) => {
        const localName = idPath.node.name;
        let metadata = localMetadata.get(localName);
        if (!metadata) {
          const kind = bindingKindLookup.get(localName);
          if (kind === void 0) {
            throw idPath.buildCodeFrameError(`Exporting local "${localName}", which is not declared.`);
          }
          metadata = {
            names: [],
            kind
          };
          localMetadata.set(localName, metadata);
        }
        return metadata;
      };
      programPath.get("body").forEach((child) => {
        if (child.isExportNamedDeclaration() && (initializeReexports || !child.node.source)) {
          if (child.node.declaration) {
            const declaration = child.get("declaration");
            const ids = declaration.getOuterBindingIdentifierPaths();
            Object.keys(ids).forEach((name) => {
              if (name === "__esModule") {
                throw declaration.buildCodeFrameError('Illegal export "__esModule".');
              }
              getLocalMetadata(ids[name]).names.push(name);
            });
          } else {
            child.get("specifiers").forEach((spec) => {
              const local = spec.get("local");
              const exported = spec.get("exported");
              const localMetadata2 = getLocalMetadata(local);
              const exportName = getExportSpecifierName(exported, stringSpecifiers);
              if (exportName === "__esModule") {
                throw exported.buildCodeFrameError('Illegal export "__esModule".');
              }
              localMetadata2.names.push(exportName);
            });
          }
        } else if (child.isExportDefaultDeclaration()) {
          const declaration = child.get("declaration");
          if (declaration.isFunctionDeclaration() || declaration.isClassDeclaration()) {
            getLocalMetadata(declaration.get("id")).names.push("default");
          } else {
            throw declaration.buildCodeFrameError("Unexpected default expression export.");
          }
        }
      });
      return localMetadata;
    }
    function nameAnonymousExports(programPath) {
      programPath.get("body").forEach((child) => {
        if (!child.isExportDefaultDeclaration())
          return;
        (0, _helperSplitExportDeclaration.default)(child);
      });
    }
    function removeImportExportDeclarations(programPath) {
      programPath.get("body").forEach((child) => {
        if (child.isImportDeclaration()) {
          child.remove();
        } else if (child.isExportNamedDeclaration()) {
          if (child.node.declaration) {
            child.node.declaration._blockHoist = child.node._blockHoist;
            child.replaceWith(child.node.declaration);
          } else {
            child.remove();
          }
        } else if (child.isExportDefaultDeclaration()) {
          const declaration = child.get("declaration");
          if (declaration.isFunctionDeclaration() || declaration.isClassDeclaration()) {
            declaration._blockHoist = child.node._blockHoist;
            child.replaceWith(declaration);
          } else {
            throw declaration.buildCodeFrameError("Unexpected default expression export.");
          }
        } else if (child.isExportAllDeclaration()) {
          child.remove();
        }
      });
    }
  }
});

// node_modules/@babel/helper-module-transforms/lib/dynamic-import.js
var require_dynamic_import = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/dynamic-import.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.buildDynamicImport = buildDynamicImport;
    exports.getDynamicImportSource = getDynamicImportSource;
    var t3 = require_lib11();
    var _template = require_lib18();
    function getDynamicImportSource(node) {
      const [source] = node.arguments;
      return t3.isStringLiteral(source) || t3.isTemplateLiteral(source) ? source : _template.default.expression.ast`\`\${${source}}\``;
    }
    function buildDynamicImport(node, deferToThen, wrapWithPromise, builder) {
      const [specifier] = node.arguments;
      if (t3.isStringLiteral(specifier) || t3.isTemplateLiteral(specifier) && specifier.quasis.length === 0) {
        if (deferToThen) {
          return _template.default.expression.ast`
        Promise.resolve().then(() => ${builder(specifier)})
      `;
        } else
          return builder(specifier);
      }
      const specifierToString = t3.isTemplateLiteral(specifier) ? t3.identifier("specifier") : t3.templateLiteral([t3.templateElement({
        raw: ""
      }), t3.templateElement({
        raw: ""
      })], [t3.identifier("specifier")]);
      if (deferToThen) {
        return _template.default.expression.ast`
      (specifier =>
        new Promise(r => r(${specifierToString}))
          .then(s => ${builder(t3.identifier("s"))})
      )(${specifier})
    `;
      } else if (wrapWithPromise) {
        return _template.default.expression.ast`
      (specifier =>
        new Promise(r => r(${builder(specifierToString)}))
      )(${specifier})
    `;
      } else {
        return _template.default.expression.ast`
      (specifier => ${builder(specifierToString)})(${specifier})
    `;
      }
    }
  }
});

// node_modules/@babel/helper-module-transforms/lib/get-module-name.js
var require_get_module_name = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/get-module-name.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = getModuleName;
    {
      const originalGetModuleName = getModuleName;
      exports.default = getModuleName = function getModuleName2(rootOpts, pluginOpts) {
        var _pluginOpts$moduleId, _pluginOpts$moduleIds, _pluginOpts$getModule, _pluginOpts$moduleRoo;
        return originalGetModuleName(rootOpts, {
          moduleId: (_pluginOpts$moduleId = pluginOpts.moduleId) != null ? _pluginOpts$moduleId : rootOpts.moduleId,
          moduleIds: (_pluginOpts$moduleIds = pluginOpts.moduleIds) != null ? _pluginOpts$moduleIds : rootOpts.moduleIds,
          getModuleId: (_pluginOpts$getModule = pluginOpts.getModuleId) != null ? _pluginOpts$getModule : rootOpts.getModuleId,
          moduleRoot: (_pluginOpts$moduleRoo = pluginOpts.moduleRoot) != null ? _pluginOpts$moduleRoo : rootOpts.moduleRoot
        });
      };
    }
    function getModuleName(rootOpts, pluginOpts) {
      const {
        filename,
        filenameRelative = filename,
        sourceRoot = pluginOpts.moduleRoot
      } = rootOpts;
      const {
        moduleId,
        moduleIds = !!moduleId,
        getModuleId,
        moduleRoot = sourceRoot
      } = pluginOpts;
      if (!moduleIds)
        return null;
      if (moduleId != null && !getModuleId) {
        return moduleId;
      }
      let moduleName = moduleRoot != null ? moduleRoot + "/" : "";
      if (filenameRelative) {
        const sourceRootReplacer = sourceRoot != null ? new RegExp("^" + sourceRoot + "/?") : "";
        moduleName += filenameRelative.replace(sourceRootReplacer, "").replace(/\.(\w*?)$/, "");
      }
      moduleName = moduleName.replace(/\\/g, "/");
      if (getModuleId) {
        return getModuleId(moduleName) || moduleName;
      } else {
        return moduleName;
      }
    }
  }
});

// node_modules/@babel/helper-module-transforms/lib/index.js
var require_lib24 = __commonJS({
  "node_modules/@babel/helper-module-transforms/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "buildDynamicImport", {
      enumerable: true,
      get: function() {
        return _dynamicImport.buildDynamicImport;
      }
    });
    exports.buildNamespaceInitStatements = buildNamespaceInitStatements;
    exports.ensureStatementsHoisted = ensureStatementsHoisted;
    Object.defineProperty(exports, "getDynamicImportSource", {
      enumerable: true,
      get: function() {
        return _dynamicImport.getDynamicImportSource;
      }
    });
    Object.defineProperty(exports, "getModuleName", {
      enumerable: true,
      get: function() {
        return _getModuleName.default;
      }
    });
    Object.defineProperty(exports, "hasExports", {
      enumerable: true,
      get: function() {
        return _normalizeAndLoadMetadata.hasExports;
      }
    });
    Object.defineProperty(exports, "isModule", {
      enumerable: true,
      get: function() {
        return _helperModuleImports.isModule;
      }
    });
    Object.defineProperty(exports, "isSideEffectImport", {
      enumerable: true,
      get: function() {
        return _normalizeAndLoadMetadata.isSideEffectImport;
      }
    });
    exports.rewriteModuleStatementsAndPrepareHeader = rewriteModuleStatementsAndPrepareHeader;
    Object.defineProperty(exports, "rewriteThis", {
      enumerable: true,
      get: function() {
        return _rewriteThis.default;
      }
    });
    exports.wrapInterop = wrapInterop;
    var _assert = require("assert");
    var _t = require_lib11();
    var _template = require_lib18();
    var _helperModuleImports = require_lib22();
    var _rewriteThis = require_rewrite_this();
    var _rewriteLiveReferences = require_rewrite_live_references();
    var _normalizeAndLoadMetadata = require_normalize_and_load_metadata();
    var _dynamicImport = require_dynamic_import();
    var _getModuleName = require_get_module_name();
    var {
      booleanLiteral,
      callExpression: callExpression3,
      cloneNode,
      directive,
      directiveLiteral,
      expressionStatement,
      identifier: identifier3,
      isIdentifier: isIdentifier2,
      memberExpression,
      stringLiteral: stringLiteral2,
      valueToNode,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t;
    function rewriteModuleStatementsAndPrepareHeader(path2, {
      loose,
      exportName,
      strict,
      allowTopLevelThis,
      strictMode,
      noInterop,
      importInterop = noInterop ? "none" : "babel",
      lazy,
      esNamespaceOnly,
      filename,
      constantReexports = loose,
      enumerableModuleMeta = loose,
      noIncompleteNsImportDetection
    }) {
      (0, _normalizeAndLoadMetadata.validateImportInteropOption)(importInterop);
      _assert((0, _helperModuleImports.isModule)(path2), "Cannot process module statements in a script");
      path2.node.sourceType = "script";
      const meta = (0, _normalizeAndLoadMetadata.default)(path2, exportName, {
        importInterop,
        initializeReexports: constantReexports,
        lazy,
        esNamespaceOnly,
        filename
      });
      if (!allowTopLevelThis) {
        (0, _rewriteThis.default)(path2);
      }
      (0, _rewriteLiveReferences.default)(path2, meta);
      if (strictMode !== false) {
        const hasStrict = path2.node.directives.some((directive2) => {
          return directive2.value.value === "use strict";
        });
        if (!hasStrict) {
          path2.unshiftContainer("directives", directive(directiveLiteral("use strict")));
        }
      }
      const headers = [];
      if ((0, _normalizeAndLoadMetadata.hasExports)(meta) && !strict) {
        headers.push(buildESModuleHeader(meta, enumerableModuleMeta));
      }
      const nameList = buildExportNameListDeclaration(path2, meta);
      if (nameList) {
        meta.exportNameListName = nameList.name;
        headers.push(nameList.statement);
      }
      headers.push(...buildExportInitializationStatements(path2, meta, constantReexports, noIncompleteNsImportDetection));
      return {
        meta,
        headers
      };
    }
    function ensureStatementsHoisted(statements) {
      statements.forEach((header) => {
        header._blockHoist = 3;
      });
    }
    function wrapInterop(programPath, expr, type) {
      if (type === "none") {
        return null;
      }
      if (type === "node-namespace") {
        return callExpression3(programPath.hub.addHelper("interopRequireWildcard"), [expr, booleanLiteral(true)]);
      } else if (type === "node-default") {
        return null;
      }
      let helper;
      if (type === "default") {
        helper = "interopRequireDefault";
      } else if (type === "namespace") {
        helper = "interopRequireWildcard";
      } else {
        throw new Error(`Unknown interop: ${type}`);
      }
      return callExpression3(programPath.hub.addHelper(helper), [expr]);
    }
    function buildNamespaceInitStatements(metadata, sourceMetadata, constantReexports = false) {
      const statements = [];
      let srcNamespace = identifier3(sourceMetadata.name);
      if (sourceMetadata.lazy)
        srcNamespace = callExpression3(srcNamespace, []);
      for (const localName of sourceMetadata.importsNamespace) {
        if (localName === sourceMetadata.name)
          continue;
        statements.push(_template.default.statement`var NAME = SOURCE;`({
          NAME: localName,
          SOURCE: cloneNode(srcNamespace)
        }));
      }
      if (constantReexports) {
        statements.push(...buildReexportsFromMeta(metadata, sourceMetadata, true));
      }
      for (const exportName of sourceMetadata.reexportNamespace) {
        statements.push((sourceMetadata.lazy ? _template.default.statement`
            Object.defineProperty(EXPORTS, "NAME", {
              enumerable: true,
              get: function() {
                return NAMESPACE;
              }
            });
          ` : _template.default.statement`EXPORTS.NAME = NAMESPACE;`)({
          EXPORTS: metadata.exportName,
          NAME: exportName,
          NAMESPACE: cloneNode(srcNamespace)
        }));
      }
      if (sourceMetadata.reexportAll) {
        const statement = buildNamespaceReexport(metadata, cloneNode(srcNamespace), constantReexports);
        statement.loc = sourceMetadata.reexportAll.loc;
        statements.push(statement);
      }
      return statements;
    }
    var ReexportTemplate = {
      constant: _template.default.statement`EXPORTS.EXPORT_NAME = NAMESPACE_IMPORT;`,
      constantComputed: _template.default.statement`EXPORTS["EXPORT_NAME"] = NAMESPACE_IMPORT;`,
      spec: _template.default.statement`
    Object.defineProperty(EXPORTS, "EXPORT_NAME", {
      enumerable: true,
      get: function() {
        return NAMESPACE_IMPORT;
      },
    });
    `
    };
    function buildReexportsFromMeta(meta, metadata, constantReexports) {
      const namespace = metadata.lazy ? callExpression3(identifier3(metadata.name), []) : identifier3(metadata.name);
      const {
        stringSpecifiers
      } = meta;
      return Array.from(metadata.reexports, ([exportName, importName]) => {
        let NAMESPACE_IMPORT = cloneNode(namespace);
        if (importName === "default" && metadata.interop === "node-default") {
        } else if (stringSpecifiers.has(importName)) {
          NAMESPACE_IMPORT = memberExpression(NAMESPACE_IMPORT, stringLiteral2(importName), true);
        } else {
          NAMESPACE_IMPORT = memberExpression(NAMESPACE_IMPORT, identifier3(importName));
        }
        const astNodes = {
          EXPORTS: meta.exportName,
          EXPORT_NAME: exportName,
          NAMESPACE_IMPORT
        };
        if (constantReexports || isIdentifier2(NAMESPACE_IMPORT)) {
          if (stringSpecifiers.has(exportName)) {
            return ReexportTemplate.constantComputed(astNodes);
          } else {
            return ReexportTemplate.constant(astNodes);
          }
        } else {
          return ReexportTemplate.spec(astNodes);
        }
      });
    }
    function buildESModuleHeader(metadata, enumerableModuleMeta = false) {
      return (enumerableModuleMeta ? _template.default.statement`
        EXPORTS.__esModule = true;
      ` : _template.default.statement`
        Object.defineProperty(EXPORTS, "__esModule", {
          value: true,
        });
      `)({
        EXPORTS: metadata.exportName
      });
    }
    function buildNamespaceReexport(metadata, namespace, constantReexports) {
      return (constantReexports ? _template.default.statement`
        Object.keys(NAMESPACE).forEach(function(key) {
          if (key === "default" || key === "__esModule") return;
          VERIFY_NAME_LIST;
          if (key in EXPORTS && EXPORTS[key] === NAMESPACE[key]) return;

          EXPORTS[key] = NAMESPACE[key];
        });
      ` : _template.default.statement`
        Object.keys(NAMESPACE).forEach(function(key) {
          if (key === "default" || key === "__esModule") return;
          VERIFY_NAME_LIST;
          if (key in EXPORTS && EXPORTS[key] === NAMESPACE[key]) return;

          Object.defineProperty(EXPORTS, key, {
            enumerable: true,
            get: function() {
              return NAMESPACE[key];
            },
          });
        });
    `)({
        NAMESPACE: namespace,
        EXPORTS: metadata.exportName,
        VERIFY_NAME_LIST: metadata.exportNameListName ? (0, _template.default)`
            if (Object.prototype.hasOwnProperty.call(EXPORTS_LIST, key)) return;
          `({
          EXPORTS_LIST: metadata.exportNameListName
        }) : null
      });
    }
    function buildExportNameListDeclaration(programPath, metadata) {
      const exportedVars = /* @__PURE__ */ Object.create(null);
      for (const data of metadata.local.values()) {
        for (const name2 of data.names) {
          exportedVars[name2] = true;
        }
      }
      let hasReexport = false;
      for (const data of metadata.source.values()) {
        for (const exportName of data.reexports.keys()) {
          exportedVars[exportName] = true;
        }
        for (const exportName of data.reexportNamespace) {
          exportedVars[exportName] = true;
        }
        hasReexport = hasReexport || !!data.reexportAll;
      }
      if (!hasReexport || Object.keys(exportedVars).length === 0)
        return null;
      const name = programPath.scope.generateUidIdentifier("exportNames");
      delete exportedVars.default;
      return {
        name: name.name,
        statement: variableDeclaration2("var", [variableDeclarator2(name, valueToNode(exportedVars))])
      };
    }
    function buildExportInitializationStatements(programPath, metadata, constantReexports = false, noIncompleteNsImportDetection = false) {
      const initStatements = [];
      for (const [localName, data] of metadata.local) {
        if (data.kind === "import") {
        } else if (data.kind === "hoisted") {
          initStatements.push([
            data.names[0],
            buildInitStatement(metadata, data.names, identifier3(localName))
          ]);
        } else if (!noIncompleteNsImportDetection) {
          for (const exportName of data.names) {
            initStatements.push([exportName, null]);
          }
        }
      }
      for (const data of metadata.source.values()) {
        if (!constantReexports) {
          const reexportsStatements = buildReexportsFromMeta(metadata, data, false);
          const reexports = [...data.reexports.keys()];
          for (let i = 0; i < reexportsStatements.length; i++) {
            initStatements.push([reexports[i], reexportsStatements[i]]);
          }
        }
        if (!noIncompleteNsImportDetection) {
          for (const exportName of data.reexportNamespace) {
            initStatements.push([exportName, null]);
          }
        }
      }
      initStatements.sort(([a], [b]) => {
        if (a < b)
          return -1;
        if (b < a)
          return 1;
        return 0;
      });
      const results = [];
      if (noIncompleteNsImportDetection) {
        for (const [, initStatement] of initStatements) {
          results.push(initStatement);
        }
      } else {
        const chunkSize = 100;
        for (let i = 0; i < initStatements.length; i += chunkSize) {
          let uninitializedExportNames = [];
          for (let j = 0; j < chunkSize && i + j < initStatements.length; j++) {
            const [exportName, initStatement] = initStatements[i + j];
            if (initStatement !== null) {
              if (uninitializedExportNames.length > 0) {
                results.push(buildInitStatement(metadata, uninitializedExportNames, programPath.scope.buildUndefinedNode()));
                uninitializedExportNames = [];
              }
              results.push(initStatement);
            } else {
              uninitializedExportNames.push(exportName);
            }
          }
          if (uninitializedExportNames.length > 0) {
            results.push(buildInitStatement(metadata, uninitializedExportNames, programPath.scope.buildUndefinedNode()));
          }
        }
      }
      return results;
    }
    var InitTemplate = {
      computed: _template.default.expression`EXPORTS["NAME"] = VALUE`,
      default: _template.default.expression`EXPORTS.NAME = VALUE`
    };
    function buildInitStatement(metadata, exportNames, initExpr) {
      const {
        stringSpecifiers,
        exportName: EXPORTS
      } = metadata;
      return expressionStatement(exportNames.reduce((acc, exportName) => {
        const params = {
          EXPORTS,
          NAME: exportName,
          VALUE: acc
        };
        if (stringSpecifiers.has(exportName)) {
          return InitTemplate.computed(params);
        } else {
          return InitTemplate.default(params);
        }
      }, initExpr));
    }
  }
});

// node_modules/@babel/core/lib/transformation/file/file.js
var require_file = __commonJS({
  "node_modules/@babel/core/lib/transformation/file/file.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    function helpers() {
      const data = require_lib21();
      helpers = function() {
        return data;
      };
      return data;
    }
    function _traverse() {
      const data = require_lib20();
      _traverse = function() {
        return data;
      };
      return data;
    }
    function _codeFrame() {
      const data = require_lib16();
      _codeFrame = function() {
        return data;
      };
      return data;
    }
    function _t() {
      const data = require_lib11();
      _t = function() {
        return data;
      };
      return data;
    }
    function _helperModuleTransforms() {
      const data = require_lib24();
      _helperModuleTransforms = function() {
        return data;
      };
      return data;
    }
    function _semver() {
      const data = require_semver();
      _semver = function() {
        return data;
      };
      return data;
    }
    var {
      cloneNode,
      interpreterDirective
    } = _t();
    var errorVisitor = {
      enter(path2, state) {
        const loc = path2.node.loc;
        if (loc) {
          state.loc = loc;
          path2.stop();
        }
      }
    };
    var File2 = class _File {
      constructor(options, {
        code,
        ast,
        inputMap
      }) {
        this._map = /* @__PURE__ */ new Map();
        this.opts = void 0;
        this.declarations = {};
        this.path = void 0;
        this.ast = void 0;
        this.scope = void 0;
        this.metadata = {};
        this.code = "";
        this.inputMap = void 0;
        this.hub = {
          file: this,
          getCode: () => this.code,
          getScope: () => this.scope,
          addHelper: this.addHelper.bind(this),
          buildError: this.buildCodeFrameError.bind(this)
        };
        this.opts = options;
        this.code = code;
        this.ast = ast;
        this.inputMap = inputMap;
        this.path = _traverse().NodePath.get({
          hub: this.hub,
          parentPath: null,
          parent: this.ast,
          container: this.ast,
          key: "program"
        }).setContext();
        this.scope = this.path.scope;
      }
      get shebang() {
        const {
          interpreter
        } = this.path.node;
        return interpreter ? interpreter.value : "";
      }
      set shebang(value2) {
        if (value2) {
          this.path.get("interpreter").replaceWith(interpreterDirective(value2));
        } else {
          this.path.get("interpreter").remove();
        }
      }
      set(key, val) {
        if (key === "helpersNamespace") {
          throw new Error("Babel 7.0.0-beta.56 has dropped support for the 'helpersNamespace' utility.If you are using @babel/plugin-external-helpers you will need to use a newer version than the one you currently have installed. If you have your own implementation, you'll want to explore using 'helperGenerator' alongside 'file.availableHelper()'.");
        }
        this._map.set(key, val);
      }
      get(key) {
        return this._map.get(key);
      }
      has(key) {
        return this._map.has(key);
      }
      getModuleName() {
        return (0, _helperModuleTransforms().getModuleName)(this.opts, this.opts);
      }
      addImport() {
        throw new Error("This API has been removed. If you're looking for this functionality in Babel 7, you should import the '@babel/helper-module-imports' module and use the functions exposed  from that module, such as 'addNamed' or 'addDefault'.");
      }
      availableHelper(name, versionRange) {
        let minVersion;
        try {
          minVersion = helpers().minVersion(name);
        } catch (err) {
          if (err.code !== "BABEL_HELPER_UNKNOWN")
            throw err;
          return false;
        }
        if (typeof versionRange !== "string")
          return true;
        if (_semver().valid(versionRange))
          versionRange = `^${versionRange}`;
        return !_semver().intersects(`<${minVersion}`, versionRange) && !_semver().intersects(`>=8.0.0`, versionRange);
      }
      addHelper(name) {
        const declar = this.declarations[name];
        if (declar)
          return cloneNode(declar);
        const generator = this.get("helperGenerator");
        if (generator) {
          const res = generator(name);
          if (res)
            return res;
        }
        helpers().ensure(name, _File);
        const uid = this.declarations[name] = this.scope.generateUidIdentifier(name);
        const dependencies = {};
        for (const dep of helpers().getDependencies(name)) {
          dependencies[dep] = this.addHelper(dep);
        }
        const {
          nodes,
          globals
        } = helpers().get(name, (dep) => dependencies[dep], uid, Object.keys(this.scope.getAllBindings()));
        globals.forEach((name2) => {
          if (this.path.scope.hasBinding(name2, true)) {
            this.path.scope.rename(name2);
          }
        });
        nodes.forEach((node) => {
          node._compact = true;
        });
        this.path.unshiftContainer("body", nodes);
        this.path.get("body").forEach((path2) => {
          if (nodes.indexOf(path2.node) === -1)
            return;
          if (path2.isVariableDeclaration())
            this.scope.registerDeclaration(path2);
        });
        return uid;
      }
      addTemplateObject() {
        throw new Error("This function has been moved into the template literal transform itself.");
      }
      buildCodeFrameError(node, msg, _Error = SyntaxError) {
        let loc = node && (node.loc || node._loc);
        if (!loc && node) {
          const state = {
            loc: null
          };
          (0, _traverse().default)(node, errorVisitor, this.scope, state);
          loc = state.loc;
          let txt = "This is an error on an internal node. Probably an internal error.";
          if (loc)
            txt += " Location has been estimated.";
          msg += ` (${txt})`;
        }
        if (loc) {
          const {
            highlightCode = true
          } = this.opts;
          msg += "\n" + (0, _codeFrame().codeFrameColumns)(this.code, {
            start: {
              line: loc.start.line,
              column: loc.start.column + 1
            },
            end: loc.end && loc.start.line === loc.end.line ? {
              line: loc.end.line,
              column: loc.end.column + 1
            } : void 0
          }, {
            highlightCode
          });
        }
        return new _Error(msg);
      }
    };
    exports.default = File2;
  }
});

// node_modules/@babel/core/lib/tools/build-external-helpers.js
var require_build_external_helpers = __commonJS({
  "node_modules/@babel/core/lib/tools/build-external-helpers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;
    function helpers() {
      const data = require_lib21();
      helpers = function() {
        return data;
      };
      return data;
    }
    function _generator() {
      const data = require_lib14();
      _generator = function() {
        return data;
      };
      return data;
    }
    function _template() {
      const data = require_lib18();
      _template = function() {
        return data;
      };
      return data;
    }
    function _t() {
      const data = require_lib11();
      _t = function() {
        return data;
      };
      return data;
    }
    var _file = require_file();
    var {
      arrayExpression,
      assignmentExpression,
      binaryExpression,
      blockStatement: blockStatement2,
      callExpression: callExpression3,
      cloneNode,
      conditionalExpression,
      exportNamedDeclaration,
      exportSpecifier,
      expressionStatement,
      functionExpression,
      identifier: identifier3,
      memberExpression,
      objectExpression,
      program: program2,
      stringLiteral: stringLiteral2,
      unaryExpression,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t();
    var buildUmdWrapper = (replacements) => _template().default.statement`
    (function (root, factory) {
      if (typeof define === "function" && define.amd) {
        define(AMD_ARGUMENTS, factory);
      } else if (typeof exports === "object") {
        factory(COMMON_ARGUMENTS);
      } else {
        factory(BROWSER_ARGUMENTS);
      }
    })(UMD_ROOT, function (FACTORY_PARAMETERS) {
      FACTORY_BODY
    });
  `(replacements);
    function buildGlobal(allowlist) {
      const namespace = identifier3("babelHelpers");
      const body = [];
      const container = functionExpression(null, [identifier3("global")], blockStatement2(body));
      const tree = program2([expressionStatement(callExpression3(container, [conditionalExpression(binaryExpression("===", unaryExpression("typeof", identifier3("global")), stringLiteral2("undefined")), identifier3("self"), identifier3("global"))]))]);
      body.push(variableDeclaration2("var", [variableDeclarator2(namespace, assignmentExpression("=", memberExpression(identifier3("global"), namespace), objectExpression([])))]));
      buildHelpers(body, namespace, allowlist);
      return tree;
    }
    function buildModule(allowlist) {
      const body = [];
      const refs = buildHelpers(body, null, allowlist);
      body.unshift(exportNamedDeclaration(null, Object.keys(refs).map((name) => {
        return exportSpecifier(cloneNode(refs[name]), identifier3(name));
      })));
      return program2(body, [], "module");
    }
    function buildUmd(allowlist) {
      const namespace = identifier3("babelHelpers");
      const body = [];
      body.push(variableDeclaration2("var", [variableDeclarator2(namespace, identifier3("global"))]));
      buildHelpers(body, namespace, allowlist);
      return program2([buildUmdWrapper({
        FACTORY_PARAMETERS: identifier3("global"),
        BROWSER_ARGUMENTS: assignmentExpression("=", memberExpression(identifier3("root"), namespace), objectExpression([])),
        COMMON_ARGUMENTS: identifier3("exports"),
        AMD_ARGUMENTS: arrayExpression([stringLiteral2("exports")]),
        FACTORY_BODY: body,
        UMD_ROOT: identifier3("this")
      })]);
    }
    function buildVar(allowlist) {
      const namespace = identifier3("babelHelpers");
      const body = [];
      body.push(variableDeclaration2("var", [variableDeclarator2(namespace, objectExpression([]))]));
      const tree = program2(body);
      buildHelpers(body, namespace, allowlist);
      body.push(expressionStatement(namespace));
      return tree;
    }
    function buildHelpers(body, namespace, allowlist) {
      const getHelperReference = (name) => {
        return namespace ? memberExpression(namespace, identifier3(name)) : identifier3(`_${name}`);
      };
      const refs = {};
      helpers().list.forEach(function(name) {
        if (allowlist && allowlist.indexOf(name) < 0)
          return;
        const ref = refs[name] = getHelperReference(name);
        helpers().ensure(name, _file.default);
        const {
          nodes
        } = helpers().get(name, getHelperReference, ref);
        body.push(...nodes);
      });
      return refs;
    }
    function _default(allowlist, outputType = "global") {
      let tree;
      const build = {
        global: buildGlobal,
        module: buildModule,
        umd: buildUmd,
        var: buildVar
      }[outputType];
      if (build) {
        tree = build(allowlist);
      } else {
        throw new Error(`Unsupported output type ${outputType}`);
      }
      return (0, _generator().default)(tree).code;
    }
  }
});

// node_modules/gensync/index.js
var require_gensync = __commonJS({
  "node_modules/gensync/index.js"(exports, module2) {
    "use strict";
    var GENSYNC_START = Symbol.for("gensync:v1:start");
    var GENSYNC_SUSPEND = Symbol.for("gensync:v1:suspend");
    var GENSYNC_EXPECTED_START = "GENSYNC_EXPECTED_START";
    var GENSYNC_EXPECTED_SUSPEND = "GENSYNC_EXPECTED_SUSPEND";
    var GENSYNC_OPTIONS_ERROR = "GENSYNC_OPTIONS_ERROR";
    var GENSYNC_RACE_NONEMPTY = "GENSYNC_RACE_NONEMPTY";
    var GENSYNC_ERRBACK_NO_CALLBACK = "GENSYNC_ERRBACK_NO_CALLBACK";
    module2.exports = Object.assign(
      function gensync(optsOrFn) {
        let genFn = optsOrFn;
        if (typeof optsOrFn !== "function") {
          genFn = newGenerator(optsOrFn);
        } else {
          genFn = wrapGenerator(optsOrFn);
        }
        return Object.assign(genFn, makeFunctionAPI(genFn));
      },
      {
        all: buildOperation({
          name: "all",
          arity: 1,
          sync: function(args) {
            const items = Array.from(args[0]);
            return items.map((item) => evaluateSync(item));
          },
          async: function(args, resolve, reject) {
            const items = Array.from(args[0]);
            if (items.length === 0) {
              Promise.resolve().then(() => resolve([]));
              return;
            }
            let count = 0;
            const results = items.map(() => void 0);
            items.forEach((item, i) => {
              evaluateAsync(
                item,
                (val) => {
                  results[i] = val;
                  count += 1;
                  if (count === results.length)
                    resolve(results);
                },
                reject
              );
            });
          }
        }),
        race: buildOperation({
          name: "race",
          arity: 1,
          sync: function(args) {
            const items = Array.from(args[0]);
            if (items.length === 0) {
              throw makeError("Must race at least 1 item", GENSYNC_RACE_NONEMPTY);
            }
            return evaluateSync(items[0]);
          },
          async: function(args, resolve, reject) {
            const items = Array.from(args[0]);
            if (items.length === 0) {
              throw makeError("Must race at least 1 item", GENSYNC_RACE_NONEMPTY);
            }
            for (const item of items) {
              evaluateAsync(item, resolve, reject);
            }
          }
        })
      }
    );
    function makeFunctionAPI(genFn) {
      const fns = {
        sync: function(...args) {
          return evaluateSync(genFn.apply(this, args));
        },
        async: function(...args) {
          return new Promise((resolve, reject) => {
            evaluateAsync(genFn.apply(this, args), resolve, reject);
          });
        },
        errback: function(...args) {
          const cb = args.pop();
          if (typeof cb !== "function") {
            throw makeError(
              "Asynchronous function called without callback",
              GENSYNC_ERRBACK_NO_CALLBACK
            );
          }
          let gen;
          try {
            gen = genFn.apply(this, args);
          } catch (err) {
            cb(err);
            return;
          }
          evaluateAsync(gen, (val) => cb(void 0, val), (err) => cb(err));
        }
      };
      return fns;
    }
    function assertTypeof(type, name, value2, allowUndefined) {
      if (typeof value2 === type || allowUndefined && typeof value2 === "undefined") {
        return;
      }
      let msg;
      if (allowUndefined) {
        msg = `Expected opts.${name} to be either a ${type}, or undefined.`;
      } else {
        msg = `Expected opts.${name} to be a ${type}.`;
      }
      throw makeError(msg, GENSYNC_OPTIONS_ERROR);
    }
    function makeError(msg, code) {
      return Object.assign(new Error(msg), { code });
    }
    function newGenerator({ name, arity, sync, async, errback }) {
      assertTypeof(
        "string",
        "name",
        name,
        true
        /* allowUndefined */
      );
      assertTypeof(
        "number",
        "arity",
        arity,
        true
        /* allowUndefined */
      );
      assertTypeof("function", "sync", sync);
      assertTypeof(
        "function",
        "async",
        async,
        true
        /* allowUndefined */
      );
      assertTypeof(
        "function",
        "errback",
        errback,
        true
        /* allowUndefined */
      );
      if (async && errback) {
        throw makeError(
          "Expected one of either opts.async or opts.errback, but got _both_.",
          GENSYNC_OPTIONS_ERROR
        );
      }
      if (typeof name !== "string") {
        let fnName;
        if (errback && errback.name && errback.name !== "errback") {
          fnName = errback.name;
        }
        if (async && async.name && async.name !== "async") {
          fnName = async.name.replace(/Async$/, "");
        }
        if (sync && sync.name && sync.name !== "sync") {
          fnName = sync.name.replace(/Sync$/, "");
        }
        if (typeof fnName === "string") {
          name = fnName;
        }
      }
      if (typeof arity !== "number") {
        arity = sync.length;
      }
      return buildOperation({
        name,
        arity,
        sync: function(args) {
          return sync.apply(this, args);
        },
        async: function(args, resolve, reject) {
          if (async) {
            async.apply(this, args).then(resolve, reject);
          } else if (errback) {
            errback.call(this, ...args, (err, value2) => {
              if (err == null)
                resolve(value2);
              else
                reject(err);
            });
          } else {
            resolve(sync.apply(this, args));
          }
        }
      });
    }
    function wrapGenerator(genFn) {
      return setFunctionMetadata(genFn.name, genFn.length, function(...args) {
        return genFn.apply(this, args);
      });
    }
    function buildOperation({ name, arity, sync, async }) {
      return setFunctionMetadata(name, arity, function* (...args) {
        const resume = yield GENSYNC_START;
        if (!resume) {
          const res = sync.call(this, args);
          return res;
        }
        let result;
        try {
          async.call(
            this,
            args,
            (value2) => {
              if (result)
                return;
              result = { value: value2 };
              resume();
            },
            (err) => {
              if (result)
                return;
              result = { err };
              resume();
            }
          );
        } catch (err) {
          result = { err };
          resume();
        }
        yield GENSYNC_SUSPEND;
        if (result.hasOwnProperty("err")) {
          throw result.err;
        }
        return result.value;
      });
    }
    function evaluateSync(gen) {
      let value2;
      while (!({ value: value2 } = gen.next()).done) {
        assertStart(value2, gen);
      }
      return value2;
    }
    function evaluateAsync(gen, resolve, reject) {
      (function step() {
        try {
          let value2;
          while (!({ value: value2 } = gen.next()).done) {
            assertStart(value2, gen);
            let sync = true;
            let didSyncResume = false;
            const out = gen.next(() => {
              if (sync) {
                didSyncResume = true;
              } else {
                step();
              }
            });
            sync = false;
            assertSuspend(out, gen);
            if (!didSyncResume) {
              return;
            }
          }
          return resolve(value2);
        } catch (err) {
          return reject(err);
        }
      })();
    }
    function assertStart(value2, gen) {
      if (value2 === GENSYNC_START)
        return;
      throwError(
        gen,
        makeError(
          `Got unexpected yielded value in gensync generator: ${JSON.stringify(
            value2
          )}. Did you perhaps mean to use 'yield*' instead of 'yield'?`,
          GENSYNC_EXPECTED_START
        )
      );
    }
    function assertSuspend({ value: value2, done }, gen) {
      if (!done && value2 === GENSYNC_SUSPEND)
        return;
      throwError(
        gen,
        makeError(
          done ? "Unexpected generator completion. If you get this, it is probably a gensync bug." : `Expected GENSYNC_SUSPEND, got ${JSON.stringify(
            value2
          )}. If you get this, it is probably a gensync bug.`,
          GENSYNC_EXPECTED_SUSPEND
        )
      );
    }
    function throwError(gen, err) {
      if (gen.throw)
        gen.throw(err);
      throw err;
    }
    function setFunctionMetadata(name, arity, fn) {
      if (typeof name === "string") {
        const nameDesc = Object.getOwnPropertyDescriptor(fn, "name");
        if (!nameDesc || nameDesc.configurable) {
          Object.defineProperty(
            fn,
            "name",
            Object.assign(nameDesc || {}, {
              configurable: true,
              value: name
            })
          );
        }
      }
      if (typeof arity === "number") {
        const lengthDesc = Object.getOwnPropertyDescriptor(fn, "length");
        if (!lengthDesc || lengthDesc.configurable) {
          Object.defineProperty(
            fn,
            "length",
            Object.assign(lengthDesc || {}, {
              configurable: true,
              value: arity
            })
          );
        }
      }
      return fn;
    }
  }
});

// node_modules/@babel/core/lib/gensync-utils/async.js
var require_async7 = __commonJS({
  "node_modules/@babel/core/lib/gensync-utils/async.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.forwardAsync = forwardAsync;
    exports.isAsync = void 0;
    exports.isThenable = isThenable;
    exports.maybeAsync = maybeAsync;
    exports.waitFor = exports.onFirstPause = void 0;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    var runGenerator = _gensync()(function* (item) {
      return yield* item;
    });
    var isAsync = _gensync()({
      sync: () => false,
      errback: (cb) => cb(null, true)
    });
    exports.isAsync = isAsync;
    function maybeAsync(fn, message) {
      return _gensync()({
        sync(...args) {
          const result = fn.apply(this, args);
          if (isThenable(result))
            throw new Error(message);
          return result;
        },
        async(...args) {
          return Promise.resolve(fn.apply(this, args));
        }
      });
    }
    var withKind = _gensync()({
      sync: (cb) => cb("sync"),
      async: function() {
        var _ref = _asyncToGenerator(function* (cb) {
          return cb("async");
        });
        return function async(_x) {
          return _ref.apply(this, arguments);
        };
      }()
    });
    function forwardAsync(action, cb) {
      const g = _gensync()(action);
      return withKind((kind) => {
        const adapted = g[kind];
        return cb(adapted);
      });
    }
    var onFirstPause = _gensync()({
      name: "onFirstPause",
      arity: 2,
      sync: function(item) {
        return runGenerator.sync(item);
      },
      errback: function(item, firstPause, cb) {
        let completed = false;
        runGenerator.errback(item, (err, value2) => {
          completed = true;
          cb(err, value2);
        });
        if (!completed) {
          firstPause();
        }
      }
    });
    exports.onFirstPause = onFirstPause;
    var waitFor = _gensync()({
      sync: (x) => x,
      async: function() {
        var _ref2 = _asyncToGenerator(function* (x) {
          return x;
        });
        return function async(_x2) {
          return _ref2.apply(this, arguments);
        };
      }()
    });
    exports.waitFor = waitFor;
    function isThenable(val) {
      return !!val && (typeof val === "object" || typeof val === "function") && !!val.then && typeof val.then === "function";
    }
  }
});

// node_modules/@babel/core/lib/config/util.js
var require_util4 = __commonJS({
  "node_modules/@babel/core/lib/config/util.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isIterableIterator = isIterableIterator;
    exports.mergeOptions = mergeOptions;
    function mergeOptions(target, source) {
      for (const k of Object.keys(source)) {
        if ((k === "parserOpts" || k === "generatorOpts" || k === "assumptions") && source[k]) {
          const parserOpts = source[k];
          const targetObj = target[k] || (target[k] = {});
          mergeDefaultFields(targetObj, parserOpts);
        } else {
          const val = source[k];
          if (val !== void 0)
            target[k] = val;
        }
      }
    }
    function mergeDefaultFields(target, source) {
      for (const k of Object.keys(source)) {
        const val = source[k];
        if (val !== void 0)
          target[k] = val;
      }
    }
    function isIterableIterator(value2) {
      return !!value2 && typeof value2.next === "function" && typeof value2[Symbol.iterator] === "function";
    }
  }
});

// node_modules/@babel/core/lib/config/caching.js
var require_caching = __commonJS({
  "node_modules/@babel/core/lib/config/caching.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.assertSimpleType = assertSimpleType;
    exports.makeStrongCache = makeStrongCache;
    exports.makeStrongCacheSync = makeStrongCacheSync;
    exports.makeWeakCache = makeWeakCache;
    exports.makeWeakCacheSync = makeWeakCacheSync;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _async = require_async7();
    var _util = require_util4();
    var synchronize = (gen) => {
      return _gensync()(gen).sync;
    };
    function* genTrue() {
      return true;
    }
    function makeWeakCache(handler) {
      return makeCachedFunction(WeakMap, handler);
    }
    function makeWeakCacheSync(handler) {
      return synchronize(makeWeakCache(handler));
    }
    function makeStrongCache(handler) {
      return makeCachedFunction(Map, handler);
    }
    function makeStrongCacheSync(handler) {
      return synchronize(makeStrongCache(handler));
    }
    function makeCachedFunction(CallCache, handler) {
      const callCacheSync = new CallCache();
      const callCacheAsync = new CallCache();
      const futureCache = new CallCache();
      return function* cachedFunction(arg, data) {
        const asyncContext = yield* (0, _async.isAsync)();
        const callCache = asyncContext ? callCacheAsync : callCacheSync;
        const cached = yield* getCachedValueOrWait(asyncContext, callCache, futureCache, arg, data);
        if (cached.valid)
          return cached.value;
        const cache = new CacheConfigurator(data);
        const handlerResult = handler(arg, cache);
        let finishLock;
        let value2;
        if ((0, _util.isIterableIterator)(handlerResult)) {
          value2 = yield* (0, _async.onFirstPause)(handlerResult, () => {
            finishLock = setupAsyncLocks(cache, futureCache, arg);
          });
        } else {
          value2 = handlerResult;
        }
        updateFunctionCache(callCache, cache, arg, value2);
        if (finishLock) {
          futureCache.delete(arg);
          finishLock.release(value2);
        }
        return value2;
      };
    }
    function* getCachedValue(cache, arg, data) {
      const cachedValue = cache.get(arg);
      if (cachedValue) {
        for (const {
          value: value2,
          valid
        } of cachedValue) {
          if (yield* valid(data))
            return {
              valid: true,
              value: value2
            };
        }
      }
      return {
        valid: false,
        value: null
      };
    }
    function* getCachedValueOrWait(asyncContext, callCache, futureCache, arg, data) {
      const cached = yield* getCachedValue(callCache, arg, data);
      if (cached.valid) {
        return cached;
      }
      if (asyncContext) {
        const cached2 = yield* getCachedValue(futureCache, arg, data);
        if (cached2.valid) {
          const value2 = yield* (0, _async.waitFor)(cached2.value.promise);
          return {
            valid: true,
            value: value2
          };
        }
      }
      return {
        valid: false,
        value: null
      };
    }
    function setupAsyncLocks(config, futureCache, arg) {
      const finishLock = new Lock();
      updateFunctionCache(futureCache, config, arg, finishLock);
      return finishLock;
    }
    function updateFunctionCache(cache, config, arg, value2) {
      if (!config.configured())
        config.forever();
      let cachedValue = cache.get(arg);
      config.deactivate();
      switch (config.mode()) {
        case "forever":
          cachedValue = [{
            value: value2,
            valid: genTrue
          }];
          cache.set(arg, cachedValue);
          break;
        case "invalidate":
          cachedValue = [{
            value: value2,
            valid: config.validator()
          }];
          cache.set(arg, cachedValue);
          break;
        case "valid":
          if (cachedValue) {
            cachedValue.push({
              value: value2,
              valid: config.validator()
            });
          } else {
            cachedValue = [{
              value: value2,
              valid: config.validator()
            }];
            cache.set(arg, cachedValue);
          }
      }
    }
    var CacheConfigurator = class {
      constructor(data) {
        this._active = true;
        this._never = false;
        this._forever = false;
        this._invalidate = false;
        this._configured = false;
        this._pairs = [];
        this._data = void 0;
        this._data = data;
      }
      simple() {
        return makeSimpleConfigurator(this);
      }
      mode() {
        if (this._never)
          return "never";
        if (this._forever)
          return "forever";
        if (this._invalidate)
          return "invalidate";
        return "valid";
      }
      forever() {
        if (!this._active) {
          throw new Error("Cannot change caching after evaluation has completed.");
        }
        if (this._never) {
          throw new Error("Caching has already been configured with .never()");
        }
        this._forever = true;
        this._configured = true;
      }
      never() {
        if (!this._active) {
          throw new Error("Cannot change caching after evaluation has completed.");
        }
        if (this._forever) {
          throw new Error("Caching has already been configured with .forever()");
        }
        this._never = true;
        this._configured = true;
      }
      using(handler) {
        if (!this._active) {
          throw new Error("Cannot change caching after evaluation has completed.");
        }
        if (this._never || this._forever) {
          throw new Error("Caching has already been configured with .never or .forever()");
        }
        this._configured = true;
        const key = handler(this._data);
        const fn = (0, _async.maybeAsync)(handler, `You appear to be using an async cache handler, but Babel has been called synchronously`);
        if ((0, _async.isThenable)(key)) {
          return key.then((key2) => {
            this._pairs.push([key2, fn]);
            return key2;
          });
        }
        this._pairs.push([key, fn]);
        return key;
      }
      invalidate(handler) {
        this._invalidate = true;
        return this.using(handler);
      }
      validator() {
        const pairs = this._pairs;
        return function* (data) {
          for (const [key, fn] of pairs) {
            if (key !== (yield* fn(data)))
              return false;
          }
          return true;
        };
      }
      deactivate() {
        this._active = false;
      }
      configured() {
        return this._configured;
      }
    };
    function makeSimpleConfigurator(cache) {
      function cacheFn(val) {
        if (typeof val === "boolean") {
          if (val)
            cache.forever();
          else
            cache.never();
          return;
        }
        return cache.using(() => assertSimpleType(val()));
      }
      cacheFn.forever = () => cache.forever();
      cacheFn.never = () => cache.never();
      cacheFn.using = (cb) => cache.using(() => assertSimpleType(cb()));
      cacheFn.invalidate = (cb) => cache.invalidate(() => assertSimpleType(cb()));
      return cacheFn;
    }
    function assertSimpleType(value2) {
      if ((0, _async.isThenable)(value2)) {
        throw new Error(`You appear to be using an async cache handler, which your current version of Babel does not support. We may add support for this in the future, but if you're on the most recent version of @babel/core and still seeing this error, then you'll need to synchronously handle your caching logic.`);
      }
      if (value2 != null && typeof value2 !== "string" && typeof value2 !== "boolean" && typeof value2 !== "number") {
        throw new Error("Cache keys must be either string, boolean, number, null, or undefined.");
      }
      return value2;
    }
    var Lock = class {
      constructor() {
        this.released = false;
        this.promise = void 0;
        this._resolve = void 0;
        this.promise = new Promise((resolve) => {
          this._resolve = resolve;
        });
      }
      release(value2) {
        this.released = true;
        this._resolve(value2);
      }
    };
  }
});

// node_modules/@babel/core/lib/gensync-utils/fs.js
var require_fs5 = __commonJS({
  "node_modules/@babel/core/lib/gensync-utils/fs.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.stat = exports.readFile = void 0;
    function _fs() {
      const data = require("fs");
      _fs = function() {
        return data;
      };
      return data;
    }
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var readFile = _gensync()({
      sync: _fs().readFileSync,
      errback: _fs().readFile
    });
    exports.readFile = readFile;
    var stat = _gensync()({
      sync: _fs().statSync,
      errback: _fs().stat
    });
    exports.stat = stat;
  }
});

// node_modules/@babel/core/lib/config/files/utils.js
var require_utils7 = __commonJS({
  "node_modules/@babel/core/lib/config/files/utils.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.makeStaticFileCache = makeStaticFileCache;
    var _caching = require_caching();
    var fs2 = require_fs5();
    function _fs2() {
      const data = require("fs");
      _fs2 = function() {
        return data;
      };
      return data;
    }
    function makeStaticFileCache(fn) {
      return (0, _caching.makeStrongCache)(function* (filepath, cache) {
        const cached = cache.invalidate(() => fileMtime(filepath));
        if (cached === null) {
          return null;
        }
        return fn(filepath, yield* fs2.readFile(filepath, "utf8"));
      });
    }
    function fileMtime(filepath) {
      if (!_fs2().existsSync(filepath))
        return null;
      try {
        return +_fs2().statSync(filepath).mtime;
      } catch (e) {
        if (e.code !== "ENOENT" && e.code !== "ENOTDIR")
          throw e;
      }
      return null;
    }
  }
});

// node_modules/@babel/core/lib/errors/rewrite-stack-trace.js
var require_rewrite_stack_trace = __commonJS({
  "node_modules/@babel/core/lib/errors/rewrite-stack-trace.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.beginHiddenCallStack = beginHiddenCallStack;
    exports.endHiddenCallStack = endHiddenCallStack;
    exports.expectedError = expectedError;
    exports.injcectVirtualStackFrame = injcectVirtualStackFrame;
    var ErrorToString = Function.call.bind(Error.prototype.toString);
    var SUPPORTED = !!Error.captureStackTrace;
    var START_HIDNG = "startHiding - secret - don't use this - v1";
    var STOP_HIDNG = "stopHiding - secret - don't use this - v1";
    var expectedErrors = /* @__PURE__ */ new WeakSet();
    var virtualFrames = /* @__PURE__ */ new WeakMap();
    function CallSite(filename) {
      return /* @__PURE__ */ Object.create({
        isNative: () => false,
        isConstructor: () => false,
        isToplevel: () => true,
        getFileName: () => filename,
        getLineNumber: () => void 0,
        getColumnNumber: () => void 0,
        getFunctionName: () => void 0,
        getMethodName: () => void 0,
        getTypeName: () => void 0,
        toString: () => filename
      });
    }
    function injcectVirtualStackFrame(error, filename) {
      if (!SUPPORTED)
        return;
      let frames = virtualFrames.get(error);
      if (!frames)
        virtualFrames.set(error, frames = []);
      frames.push(CallSite(filename));
      return error;
    }
    function expectedError(error) {
      if (!SUPPORTED)
        return;
      expectedErrors.add(error);
      return error;
    }
    function beginHiddenCallStack(fn) {
      if (!SUPPORTED)
        return fn;
      return Object.defineProperty(function(...args) {
        setupPrepareStackTrace();
        return fn(...args);
      }, "name", {
        value: STOP_HIDNG
      });
    }
    function endHiddenCallStack(fn) {
      if (!SUPPORTED)
        return fn;
      return Object.defineProperty(function(...args) {
        return fn(...args);
      }, "name", {
        value: START_HIDNG
      });
    }
    function setupPrepareStackTrace() {
      setupPrepareStackTrace = () => {
      };
      const {
        prepareStackTrace = defaultPrepareStackTrace
      } = Error;
      const MIN_STACK_TRACE_LIMIT = 50;
      Error.stackTraceLimit && (Error.stackTraceLimit = Math.max(Error.stackTraceLimit, MIN_STACK_TRACE_LIMIT));
      Error.prepareStackTrace = function stackTraceRewriter(err, trace) {
        let newTrace = [];
        const isExpected = expectedErrors.has(err);
        let status = isExpected ? "hiding" : "unknown";
        for (let i = 0; i < trace.length; i++) {
          const name = trace[i].getFunctionName();
          if (name === START_HIDNG) {
            status = "hiding";
          } else if (name === STOP_HIDNG) {
            if (status === "hiding") {
              status = "showing";
              if (virtualFrames.has(err)) {
                newTrace.unshift(...virtualFrames.get(err));
              }
            } else if (status === "unknown") {
              newTrace = trace;
              break;
            }
          } else if (status !== "hiding") {
            newTrace.push(trace[i]);
          }
        }
        return prepareStackTrace(err, newTrace);
      };
    }
    function defaultPrepareStackTrace(err, trace) {
      if (trace.length === 0)
        return ErrorToString(err);
      return `${ErrorToString(err)}
    at ${trace.join("\n    at ")}`;
    }
  }
});

// node_modules/@babel/core/lib/errors/config-error.js
var require_config_error = __commonJS({
  "node_modules/@babel/core/lib/errors/config-error.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var ConfigError = class extends Error {
      constructor(message, filename) {
        super(message);
        (0, _rewriteStackTrace.expectedError)(this);
        if (filename)
          (0, _rewriteStackTrace.injcectVirtualStackFrame)(this, filename);
      }
    };
    exports.default = ConfigError;
  }
});

// node_modules/@babel/core/lib/config/files/package.js
var require_package6 = __commonJS({
  "node_modules/@babel/core/lib/config/files/package.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.findPackageData = findPackageData;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    var _utils = require_utils7();
    var _configError = require_config_error();
    var PACKAGE_FILENAME = "package.json";
    var readConfigPackage = (0, _utils.makeStaticFileCache)((filepath, content) => {
      let options;
      try {
        options = JSON.parse(content);
      } catch (err) {
        throw new _configError.default(`Error while parsing JSON - ${err.message}`, filepath);
      }
      if (!options)
        throw new Error(`${filepath}: No config detected`);
      if (typeof options !== "object") {
        throw new _configError.default(`Config returned typeof ${typeof options}`, filepath);
      }
      if (Array.isArray(options)) {
        throw new _configError.default(`Expected config object but found array`, filepath);
      }
      return {
        filepath,
        dirname: _path().dirname(filepath),
        options
      };
    });
    function* findPackageData(filepath) {
      let pkg = null;
      const directories = [];
      let isPackage = true;
      let dirname = _path().dirname(filepath);
      while (!pkg && _path().basename(dirname) !== "node_modules") {
        directories.push(dirname);
        pkg = yield* readConfigPackage(_path().join(dirname, PACKAGE_FILENAME));
        const nextLoc = _path().dirname(dirname);
        if (dirname === nextLoc) {
          isPackage = false;
          break;
        }
        dirname = nextLoc;
      }
      return {
        filepath,
        directories,
        pkg,
        isPackage
      };
    }
  }
});

// node_modules/json5/lib/unicode.js
var require_unicode3 = __commonJS({
  "node_modules/json5/lib/unicode.js"(exports, module2) {
    module2.exports.Space_Separator = /[\u1680\u2000-\u200A\u202F\u205F\u3000]/;
    module2.exports.ID_Start = /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]/;
    module2.exports.ID_Continue = /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u09FC\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9-\u0AFF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D00-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF9\u1D00-\u1DF9\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDE00-\uDE3E\uDE47\uDE50-\uDE83\uDE86-\uDE99\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD36\uDD3A\uDD3C\uDD3D\uDD3F-\uDD47\uDD50-\uDD59]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/;
  }
});

// node_modules/json5/lib/util.js
var require_util5 = __commonJS({
  "node_modules/json5/lib/util.js"(exports, module2) {
    var unicode = require_unicode3();
    module2.exports = {
      isSpaceSeparator(c) {
        return typeof c === "string" && unicode.Space_Separator.test(c);
      },
      isIdStartChar(c) {
        return typeof c === "string" && (c >= "a" && c <= "z" || c >= "A" && c <= "Z" || c === "$" || c === "_" || unicode.ID_Start.test(c));
      },
      isIdContinueChar(c) {
        return typeof c === "string" && (c >= "a" && c <= "z" || c >= "A" && c <= "Z" || c >= "0" && c <= "9" || c === "$" || c === "_" || c === "\u200C" || c === "\u200D" || unicode.ID_Continue.test(c));
      },
      isDigit(c) {
        return typeof c === "string" && /[0-9]/.test(c);
      },
      isHexDigit(c) {
        return typeof c === "string" && /[0-9A-Fa-f]/.test(c);
      }
    };
  }
});

// node_modules/json5/lib/parse.js
var require_parse2 = __commonJS({
  "node_modules/json5/lib/parse.js"(exports, module2) {
    var util = require_util5();
    var source;
    var parseState;
    var stack;
    var pos;
    var line;
    var column;
    var token;
    var key;
    var root2;
    module2.exports = function parse3(text, reviver) {
      source = String(text);
      parseState = "start";
      stack = [];
      pos = 0;
      line = 1;
      column = 0;
      token = void 0;
      key = void 0;
      root2 = void 0;
      do {
        token = lex();
        parseStates[parseState]();
      } while (token.type !== "eof");
      if (typeof reviver === "function") {
        return internalize({ "": root2 }, "", reviver);
      }
      return root2;
    };
    function internalize(holder, name, reviver) {
      const value2 = holder[name];
      if (value2 != null && typeof value2 === "object") {
        if (Array.isArray(value2)) {
          for (let i = 0; i < value2.length; i++) {
            const key2 = String(i);
            const replacement = internalize(value2, key2, reviver);
            if (replacement === void 0) {
              delete value2[key2];
            } else {
              Object.defineProperty(value2, key2, {
                value: replacement,
                writable: true,
                enumerable: true,
                configurable: true
              });
            }
          }
        } else {
          for (const key2 in value2) {
            const replacement = internalize(value2, key2, reviver);
            if (replacement === void 0) {
              delete value2[key2];
            } else {
              Object.defineProperty(value2, key2, {
                value: replacement,
                writable: true,
                enumerable: true,
                configurable: true
              });
            }
          }
        }
      }
      return reviver.call(holder, name, value2);
    }
    var lexState;
    var buffer;
    var doubleQuote;
    var sign;
    var c;
    function lex() {
      lexState = "default";
      buffer = "";
      doubleQuote = false;
      sign = 1;
      for (; ; ) {
        c = peek();
        const token2 = lexStates[lexState]();
        if (token2) {
          return token2;
        }
      }
    }
    function peek() {
      if (source[pos]) {
        return String.fromCodePoint(source.codePointAt(pos));
      }
    }
    function read() {
      const c2 = peek();
      if (c2 === "\n") {
        line++;
        column = 0;
      } else if (c2) {
        column += c2.length;
      } else {
        column++;
      }
      if (c2) {
        pos += c2.length;
      }
      return c2;
    }
    var lexStates = {
      default() {
        switch (c) {
          case "	":
          case "\v":
          case "\f":
          case " ":
          case "\xA0":
          case "\uFEFF":
          case "\n":
          case "\r":
          case "\u2028":
          case "\u2029":
            read();
            return;
          case "/":
            read();
            lexState = "comment";
            return;
          case void 0:
            read();
            return newToken("eof");
        }
        if (util.isSpaceSeparator(c)) {
          read();
          return;
        }
        return lexStates[parseState]();
      },
      comment() {
        switch (c) {
          case "*":
            read();
            lexState = "multiLineComment";
            return;
          case "/":
            read();
            lexState = "singleLineComment";
            return;
        }
        throw invalidChar(read());
      },
      multiLineComment() {
        switch (c) {
          case "*":
            read();
            lexState = "multiLineCommentAsterisk";
            return;
          case void 0:
            throw invalidChar(read());
        }
        read();
      },
      multiLineCommentAsterisk() {
        switch (c) {
          case "*":
            read();
            return;
          case "/":
            read();
            lexState = "default";
            return;
          case void 0:
            throw invalidChar(read());
        }
        read();
        lexState = "multiLineComment";
      },
      singleLineComment() {
        switch (c) {
          case "\n":
          case "\r":
          case "\u2028":
          case "\u2029":
            read();
            lexState = "default";
            return;
          case void 0:
            read();
            return newToken("eof");
        }
        read();
      },
      value() {
        switch (c) {
          case "{":
          case "[":
            return newToken("punctuator", read());
          case "n":
            read();
            literal("ull");
            return newToken("null", null);
          case "t":
            read();
            literal("rue");
            return newToken("boolean", true);
          case "f":
            read();
            literal("alse");
            return newToken("boolean", false);
          case "-":
          case "+":
            if (read() === "-") {
              sign = -1;
            }
            lexState = "sign";
            return;
          case ".":
            buffer = read();
            lexState = "decimalPointLeading";
            return;
          case "0":
            buffer = read();
            lexState = "zero";
            return;
          case "1":
          case "2":
          case "3":
          case "4":
          case "5":
          case "6":
          case "7":
          case "8":
          case "9":
            buffer = read();
            lexState = "decimalInteger";
            return;
          case "I":
            read();
            literal("nfinity");
            return newToken("numeric", Infinity);
          case "N":
            read();
            literal("aN");
            return newToken("numeric", NaN);
          case '"':
          case "'":
            doubleQuote = read() === '"';
            buffer = "";
            lexState = "string";
            return;
        }
        throw invalidChar(read());
      },
      identifierNameStartEscape() {
        if (c !== "u") {
          throw invalidChar(read());
        }
        read();
        const u = unicodeEscape();
        switch (u) {
          case "$":
          case "_":
            break;
          default:
            if (!util.isIdStartChar(u)) {
              throw invalidIdentifier();
            }
            break;
        }
        buffer += u;
        lexState = "identifierName";
      },
      identifierName() {
        switch (c) {
          case "$":
          case "_":
          case "\u200C":
          case "\u200D":
            buffer += read();
            return;
          case "\\":
            read();
            lexState = "identifierNameEscape";
            return;
        }
        if (util.isIdContinueChar(c)) {
          buffer += read();
          return;
        }
        return newToken("identifier", buffer);
      },
      identifierNameEscape() {
        if (c !== "u") {
          throw invalidChar(read());
        }
        read();
        const u = unicodeEscape();
        switch (u) {
          case "$":
          case "_":
          case "\u200C":
          case "\u200D":
            break;
          default:
            if (!util.isIdContinueChar(u)) {
              throw invalidIdentifier();
            }
            break;
        }
        buffer += u;
        lexState = "identifierName";
      },
      sign() {
        switch (c) {
          case ".":
            buffer = read();
            lexState = "decimalPointLeading";
            return;
          case "0":
            buffer = read();
            lexState = "zero";
            return;
          case "1":
          case "2":
          case "3":
          case "4":
          case "5":
          case "6":
          case "7":
          case "8":
          case "9":
            buffer = read();
            lexState = "decimalInteger";
            return;
          case "I":
            read();
            literal("nfinity");
            return newToken("numeric", sign * Infinity);
          case "N":
            read();
            literal("aN");
            return newToken("numeric", NaN);
        }
        throw invalidChar(read());
      },
      zero() {
        switch (c) {
          case ".":
            buffer += read();
            lexState = "decimalPoint";
            return;
          case "e":
          case "E":
            buffer += read();
            lexState = "decimalExponent";
            return;
          case "x":
          case "X":
            buffer += read();
            lexState = "hexadecimal";
            return;
        }
        return newToken("numeric", sign * 0);
      },
      decimalInteger() {
        switch (c) {
          case ".":
            buffer += read();
            lexState = "decimalPoint";
            return;
          case "e":
          case "E":
            buffer += read();
            lexState = "decimalExponent";
            return;
        }
        if (util.isDigit(c)) {
          buffer += read();
          return;
        }
        return newToken("numeric", sign * Number(buffer));
      },
      decimalPointLeading() {
        if (util.isDigit(c)) {
          buffer += read();
          lexState = "decimalFraction";
          return;
        }
        throw invalidChar(read());
      },
      decimalPoint() {
        switch (c) {
          case "e":
          case "E":
            buffer += read();
            lexState = "decimalExponent";
            return;
        }
        if (util.isDigit(c)) {
          buffer += read();
          lexState = "decimalFraction";
          return;
        }
        return newToken("numeric", sign * Number(buffer));
      },
      decimalFraction() {
        switch (c) {
          case "e":
          case "E":
            buffer += read();
            lexState = "decimalExponent";
            return;
        }
        if (util.isDigit(c)) {
          buffer += read();
          return;
        }
        return newToken("numeric", sign * Number(buffer));
      },
      decimalExponent() {
        switch (c) {
          case "+":
          case "-":
            buffer += read();
            lexState = "decimalExponentSign";
            return;
        }
        if (util.isDigit(c)) {
          buffer += read();
          lexState = "decimalExponentInteger";
          return;
        }
        throw invalidChar(read());
      },
      decimalExponentSign() {
        if (util.isDigit(c)) {
          buffer += read();
          lexState = "decimalExponentInteger";
          return;
        }
        throw invalidChar(read());
      },
      decimalExponentInteger() {
        if (util.isDigit(c)) {
          buffer += read();
          return;
        }
        return newToken("numeric", sign * Number(buffer));
      },
      hexadecimal() {
        if (util.isHexDigit(c)) {
          buffer += read();
          lexState = "hexadecimalInteger";
          return;
        }
        throw invalidChar(read());
      },
      hexadecimalInteger() {
        if (util.isHexDigit(c)) {
          buffer += read();
          return;
        }
        return newToken("numeric", sign * Number(buffer));
      },
      string() {
        switch (c) {
          case "\\":
            read();
            buffer += escape2();
            return;
          case '"':
            if (doubleQuote) {
              read();
              return newToken("string", buffer);
            }
            buffer += read();
            return;
          case "'":
            if (!doubleQuote) {
              read();
              return newToken("string", buffer);
            }
            buffer += read();
            return;
          case "\n":
          case "\r":
            throw invalidChar(read());
          case "\u2028":
          case "\u2029":
            separatorChar(c);
            break;
          case void 0:
            throw invalidChar(read());
        }
        buffer += read();
      },
      start() {
        switch (c) {
          case "{":
          case "[":
            return newToken("punctuator", read());
        }
        lexState = "value";
      },
      beforePropertyName() {
        switch (c) {
          case "$":
          case "_":
            buffer = read();
            lexState = "identifierName";
            return;
          case "\\":
            read();
            lexState = "identifierNameStartEscape";
            return;
          case "}":
            return newToken("punctuator", read());
          case '"':
          case "'":
            doubleQuote = read() === '"';
            lexState = "string";
            return;
        }
        if (util.isIdStartChar(c)) {
          buffer += read();
          lexState = "identifierName";
          return;
        }
        throw invalidChar(read());
      },
      afterPropertyName() {
        if (c === ":") {
          return newToken("punctuator", read());
        }
        throw invalidChar(read());
      },
      beforePropertyValue() {
        lexState = "value";
      },
      afterPropertyValue() {
        switch (c) {
          case ",":
          case "}":
            return newToken("punctuator", read());
        }
        throw invalidChar(read());
      },
      beforeArrayValue() {
        if (c === "]") {
          return newToken("punctuator", read());
        }
        lexState = "value";
      },
      afterArrayValue() {
        switch (c) {
          case ",":
          case "]":
            return newToken("punctuator", read());
        }
        throw invalidChar(read());
      },
      end() {
        throw invalidChar(read());
      }
    };
    function newToken(type, value2) {
      return {
        type,
        value: value2,
        line,
        column
      };
    }
    function literal(s) {
      for (const c2 of s) {
        const p = peek();
        if (p !== c2) {
          throw invalidChar(read());
        }
        read();
      }
    }
    function escape2() {
      const c2 = peek();
      switch (c2) {
        case "b":
          read();
          return "\b";
        case "f":
          read();
          return "\f";
        case "n":
          read();
          return "\n";
        case "r":
          read();
          return "\r";
        case "t":
          read();
          return "	";
        case "v":
          read();
          return "\v";
        case "0":
          read();
          if (util.isDigit(peek())) {
            throw invalidChar(read());
          }
          return "\0";
        case "x":
          read();
          return hexEscape();
        case "u":
          read();
          return unicodeEscape();
        case "\n":
        case "\u2028":
        case "\u2029":
          read();
          return "";
        case "\r":
          read();
          if (peek() === "\n") {
            read();
          }
          return "";
        case "1":
        case "2":
        case "3":
        case "4":
        case "5":
        case "6":
        case "7":
        case "8":
        case "9":
          throw invalidChar(read());
        case void 0:
          throw invalidChar(read());
      }
      return read();
    }
    function hexEscape() {
      let buffer2 = "";
      let c2 = peek();
      if (!util.isHexDigit(c2)) {
        throw invalidChar(read());
      }
      buffer2 += read();
      c2 = peek();
      if (!util.isHexDigit(c2)) {
        throw invalidChar(read());
      }
      buffer2 += read();
      return String.fromCodePoint(parseInt(buffer2, 16));
    }
    function unicodeEscape() {
      let buffer2 = "";
      let count = 4;
      while (count-- > 0) {
        const c2 = peek();
        if (!util.isHexDigit(c2)) {
          throw invalidChar(read());
        }
        buffer2 += read();
      }
      return String.fromCodePoint(parseInt(buffer2, 16));
    }
    var parseStates = {
      start() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        push();
      },
      beforePropertyName() {
        switch (token.type) {
          case "identifier":
          case "string":
            key = token.value;
            parseState = "afterPropertyName";
            return;
          case "punctuator":
            pop();
            return;
          case "eof":
            throw invalidEOF();
        }
      },
      afterPropertyName() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        parseState = "beforePropertyValue";
      },
      beforePropertyValue() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        push();
      },
      beforeArrayValue() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        if (token.type === "punctuator" && token.value === "]") {
          pop();
          return;
        }
        push();
      },
      afterPropertyValue() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        switch (token.value) {
          case ",":
            parseState = "beforePropertyName";
            return;
          case "}":
            pop();
        }
      },
      afterArrayValue() {
        if (token.type === "eof") {
          throw invalidEOF();
        }
        switch (token.value) {
          case ",":
            parseState = "beforeArrayValue";
            return;
          case "]":
            pop();
        }
      },
      end() {
      }
    };
    function push() {
      let value2;
      switch (token.type) {
        case "punctuator":
          switch (token.value) {
            case "{":
              value2 = {};
              break;
            case "[":
              value2 = [];
              break;
          }
          break;
        case "null":
        case "boolean":
        case "numeric":
        case "string":
          value2 = token.value;
          break;
      }
      if (root2 === void 0) {
        root2 = value2;
      } else {
        const parent = stack[stack.length - 1];
        if (Array.isArray(parent)) {
          parent.push(value2);
        } else {
          Object.defineProperty(parent, key, {
            value: value2,
            writable: true,
            enumerable: true,
            configurable: true
          });
        }
      }
      if (value2 !== null && typeof value2 === "object") {
        stack.push(value2);
        if (Array.isArray(value2)) {
          parseState = "beforeArrayValue";
        } else {
          parseState = "beforePropertyName";
        }
      } else {
        const current = stack[stack.length - 1];
        if (current == null) {
          parseState = "end";
        } else if (Array.isArray(current)) {
          parseState = "afterArrayValue";
        } else {
          parseState = "afterPropertyValue";
        }
      }
    }
    function pop() {
      stack.pop();
      const current = stack[stack.length - 1];
      if (current == null) {
        parseState = "end";
      } else if (Array.isArray(current)) {
        parseState = "afterArrayValue";
      } else {
        parseState = "afterPropertyValue";
      }
    }
    function invalidChar(c2) {
      if (c2 === void 0) {
        return syntaxError(`JSON5: invalid end of input at ${line}:${column}`);
      }
      return syntaxError(`JSON5: invalid character '${formatChar(c2)}' at ${line}:${column}`);
    }
    function invalidEOF() {
      return syntaxError(`JSON5: invalid end of input at ${line}:${column}`);
    }
    function invalidIdentifier() {
      column -= 5;
      return syntaxError(`JSON5: invalid identifier character at ${line}:${column}`);
    }
    function separatorChar(c2) {
      console.warn(`JSON5: '${formatChar(c2)}' in strings is not valid ECMAScript; consider escaping`);
    }
    function formatChar(c2) {
      const replacements = {
        "'": "\\'",
        '"': '\\"',
        "\\": "\\\\",
        "\b": "\\b",
        "\f": "\\f",
        "\n": "\\n",
        "\r": "\\r",
        "	": "\\t",
        "\v": "\\v",
        "\0": "\\0",
        "\u2028": "\\u2028",
        "\u2029": "\\u2029"
      };
      if (replacements[c2]) {
        return replacements[c2];
      }
      if (c2 < " ") {
        const hexString = c2.charCodeAt(0).toString(16);
        return "\\x" + ("00" + hexString).substring(hexString.length);
      }
      return c2;
    }
    function syntaxError(message) {
      const err = new SyntaxError(message);
      err.lineNumber = line;
      err.columnNumber = column;
      return err;
    }
  }
});

// node_modules/json5/lib/stringify.js
var require_stringify = __commonJS({
  "node_modules/json5/lib/stringify.js"(exports, module2) {
    var util = require_util5();
    module2.exports = function stringify(value2, replacer, space) {
      const stack = [];
      let indent = "";
      let propertyList;
      let replacerFunc;
      let gap = "";
      let quote;
      if (replacer != null && typeof replacer === "object" && !Array.isArray(replacer)) {
        space = replacer.space;
        quote = replacer.quote;
        replacer = replacer.replacer;
      }
      if (typeof replacer === "function") {
        replacerFunc = replacer;
      } else if (Array.isArray(replacer)) {
        propertyList = [];
        for (const v of replacer) {
          let item;
          if (typeof v === "string") {
            item = v;
          } else if (typeof v === "number" || v instanceof String || v instanceof Number) {
            item = String(v);
          }
          if (item !== void 0 && propertyList.indexOf(item) < 0) {
            propertyList.push(item);
          }
        }
      }
      if (space instanceof Number) {
        space = Number(space);
      } else if (space instanceof String) {
        space = String(space);
      }
      if (typeof space === "number") {
        if (space > 0) {
          space = Math.min(10, Math.floor(space));
          gap = "          ".substr(0, space);
        }
      } else if (typeof space === "string") {
        gap = space.substr(0, 10);
      }
      return serializeProperty("", { "": value2 });
      function serializeProperty(key, holder) {
        let value3 = holder[key];
        if (value3 != null) {
          if (typeof value3.toJSON5 === "function") {
            value3 = value3.toJSON5(key);
          } else if (typeof value3.toJSON === "function") {
            value3 = value3.toJSON(key);
          }
        }
        if (replacerFunc) {
          value3 = replacerFunc.call(holder, key, value3);
        }
        if (value3 instanceof Number) {
          value3 = Number(value3);
        } else if (value3 instanceof String) {
          value3 = String(value3);
        } else if (value3 instanceof Boolean) {
          value3 = value3.valueOf();
        }
        switch (value3) {
          case null:
            return "null";
          case true:
            return "true";
          case false:
            return "false";
        }
        if (typeof value3 === "string") {
          return quoteString(value3, false);
        }
        if (typeof value3 === "number") {
          return String(value3);
        }
        if (typeof value3 === "object") {
          return Array.isArray(value3) ? serializeArray(value3) : serializeObject(value3);
        }
        return void 0;
      }
      function quoteString(value3) {
        const quotes = {
          "'": 0.1,
          '"': 0.2
        };
        const replacements = {
          "'": "\\'",
          '"': '\\"',
          "\\": "\\\\",
          "\b": "\\b",
          "\f": "\\f",
          "\n": "\\n",
          "\r": "\\r",
          "	": "\\t",
          "\v": "\\v",
          "\0": "\\0",
          "\u2028": "\\u2028",
          "\u2029": "\\u2029"
        };
        let product = "";
        for (let i = 0; i < value3.length; i++) {
          const c = value3[i];
          switch (c) {
            case "'":
            case '"':
              quotes[c]++;
              product += c;
              continue;
            case "\0":
              if (util.isDigit(value3[i + 1])) {
                product += "\\x00";
                continue;
              }
          }
          if (replacements[c]) {
            product += replacements[c];
            continue;
          }
          if (c < " ") {
            let hexString = c.charCodeAt(0).toString(16);
            product += "\\x" + ("00" + hexString).substring(hexString.length);
            continue;
          }
          product += c;
        }
        const quoteChar = quote || Object.keys(quotes).reduce((a, b) => quotes[a] < quotes[b] ? a : b);
        product = product.replace(new RegExp(quoteChar, "g"), replacements[quoteChar]);
        return quoteChar + product + quoteChar;
      }
      function serializeObject(value3) {
        if (stack.indexOf(value3) >= 0) {
          throw TypeError("Converting circular structure to JSON5");
        }
        stack.push(value3);
        let stepback = indent;
        indent = indent + gap;
        let keys3 = propertyList || Object.keys(value3);
        let partial = [];
        for (const key of keys3) {
          const propertyString = serializeProperty(key, value3);
          if (propertyString !== void 0) {
            let member = serializeKey(key) + ":";
            if (gap !== "") {
              member += " ";
            }
            member += propertyString;
            partial.push(member);
          }
        }
        let final;
        if (partial.length === 0) {
          final = "{}";
        } else {
          let properties;
          if (gap === "") {
            properties = partial.join(",");
            final = "{" + properties + "}";
          } else {
            let separator = ",\n" + indent;
            properties = partial.join(separator);
            final = "{\n" + indent + properties + ",\n" + stepback + "}";
          }
        }
        stack.pop();
        indent = stepback;
        return final;
      }
      function serializeKey(key) {
        if (key.length === 0) {
          return quoteString(key, true);
        }
        const firstChar = String.fromCodePoint(key.codePointAt(0));
        if (!util.isIdStartChar(firstChar)) {
          return quoteString(key, true);
        }
        for (let i = firstChar.length; i < key.length; i++) {
          if (!util.isIdContinueChar(String.fromCodePoint(key.codePointAt(i)))) {
            return quoteString(key, true);
          }
        }
        return key;
      }
      function serializeArray(value3) {
        if (stack.indexOf(value3) >= 0) {
          throw TypeError("Converting circular structure to JSON5");
        }
        stack.push(value3);
        let stepback = indent;
        indent = indent + gap;
        let partial = [];
        for (let i = 0; i < value3.length; i++) {
          const propertyString = serializeProperty(String(i), value3);
          partial.push(propertyString !== void 0 ? propertyString : "null");
        }
        let final;
        if (partial.length === 0) {
          final = "[]";
        } else {
          if (gap === "") {
            let properties = partial.join(",");
            final = "[" + properties + "]";
          } else {
            let separator = ",\n" + indent;
            let properties = partial.join(separator);
            final = "[\n" + indent + properties + ",\n" + stepback + "]";
          }
        }
        stack.pop();
        indent = stepback;
        return final;
      }
    };
  }
});

// node_modules/json5/lib/index.js
var require_lib25 = __commonJS({
  "node_modules/json5/lib/index.js"(exports, module2) {
    var parse3 = require_parse2();
    var stringify = require_stringify();
    var JSON5 = {
      parse: parse3,
      stringify
    };
    module2.exports = JSON5;
  }
});

// node_modules/@babel/core/lib/config/helpers/config-api.js
var require_config_api = __commonJS({
  "node_modules/@babel/core/lib/config/helpers/config-api.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.makeConfigAPI = makeConfigAPI;
    exports.makePluginAPI = makePluginAPI;
    exports.makePresetAPI = makePresetAPI;
    function _semver() {
      const data = require_semver();
      _semver = function() {
        return data;
      };
      return data;
    }
    var _ = require_lib28();
    var _caching = require_caching();
    function makeConfigAPI(cache) {
      const env = (value2) => cache.using((data) => {
        if (typeof value2 === "undefined")
          return data.envName;
        if (typeof value2 === "function") {
          return (0, _caching.assertSimpleType)(value2(data.envName));
        }
        return (Array.isArray(value2) ? value2 : [value2]).some((entry) => {
          if (typeof entry !== "string") {
            throw new Error("Unexpected non-string value");
          }
          return entry === data.envName;
        });
      });
      const caller = (cb) => cache.using((data) => (0, _caching.assertSimpleType)(cb(data.caller)));
      return {
        version: _.version,
        cache: cache.simple(),
        env,
        async: () => false,
        caller,
        assertVersion
      };
    }
    function makePresetAPI(cache, externalDependencies) {
      const targets = () => JSON.parse(cache.using((data) => JSON.stringify(data.targets)));
      const addExternalDependency = (ref) => {
        externalDependencies.push(ref);
      };
      return Object.assign({}, makeConfigAPI(cache), {
        targets,
        addExternalDependency
      });
    }
    function makePluginAPI(cache, externalDependencies) {
      const assumption = (name) => cache.using((data) => data.assumptions[name]);
      return Object.assign({}, makePresetAPI(cache, externalDependencies), {
        assumption
      });
    }
    function assertVersion(range) {
      if (typeof range === "number") {
        if (!Number.isInteger(range)) {
          throw new Error("Expected string or integer value.");
        }
        range = `^${range}.0.0-0`;
      }
      if (typeof range !== "string") {
        throw new Error("Expected string or integer value.");
      }
      if (_semver().satisfies(_.version, range))
        return;
      const limit = Error.stackTraceLimit;
      if (typeof limit === "number" && limit < 25) {
        Error.stackTraceLimit = 25;
      }
      const err = new Error(`Requires Babel "${range}", but was loaded with "${_.version}". If you are sure you have a compatible version of @babel/core, it is likely that something in your build process is loading the wrong version. Inspect the stack trace of this error to look for the first entry that doesn't mention "@babel/core" or "babel-core" to see what is calling Babel.`);
      if (typeof limit === "number") {
        Error.stackTraceLimit = limit;
      }
      throw Object.assign(err, {
        code: "BABEL_VERSION_UNSUPPORTED",
        version: _.version,
        range
      });
    }
  }
});

// node_modules/@babel/core/lib/config/files/import.cjs
var require_import = __commonJS({
  "node_modules/@babel/core/lib/config/files/import.cjs"(exports, module2) {
    module2.exports = function import_(filepath) {
      return import(filepath);
    };
  }
});

// node_modules/@babel/core/lib/config/files/module-types.js
var require_module_types = __commonJS({
  "node_modules/@babel/core/lib/config/files/module-types.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = loadCjsOrMjsDefault;
    exports.supportsESM = void 0;
    var _async = require_async7();
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _url() {
      const data = require("url");
      _url = function() {
        return data;
      };
      return data;
    }
    function _semver() {
      const data = require_semver();
      _semver = function() {
        return data;
      };
      return data;
    }
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var _configError = require_config_error();
    function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    var import_;
    try {
      import_ = require_import();
    } catch (_unused) {
    }
    var supportsESM = _semver().satisfies(process.versions.node, "^12.17 || >=13.2");
    exports.supportsESM = supportsESM;
    function* loadCjsOrMjsDefault(filepath, asyncError, fallbackToTranspiledModule = false) {
      switch (guessJSModuleType(filepath)) {
        case "cjs":
          return loadCjsDefault(filepath, fallbackToTranspiledModule);
        case "unknown":
          try {
            return loadCjsDefault(filepath, fallbackToTranspiledModule);
          } catch (e) {
            if (e.code !== "ERR_REQUIRE_ESM")
              throw e;
          }
        case "mjs":
          if (yield* (0, _async.isAsync)()) {
            return yield* (0, _async.waitFor)(loadMjsDefault(filepath));
          }
          throw new _configError.default(asyncError, filepath);
      }
    }
    function guessJSModuleType(filename) {
      switch (_path().extname(filename)) {
        case ".cjs":
          return "cjs";
        case ".mjs":
          return "mjs";
        default:
          return "unknown";
      }
    }
    function loadCjsDefault(filepath, fallbackToTranspiledModule) {
      const module3 = (0, _rewriteStackTrace.endHiddenCallStack)(require)(filepath);
      return module3 != null && module3.__esModule ? module3.default || (fallbackToTranspiledModule ? module3 : void 0) : module3;
    }
    function loadMjsDefault(_x) {
      return _loadMjsDefault.apply(this, arguments);
    }
    function _loadMjsDefault() {
      _loadMjsDefault = _asyncToGenerator(function* (filepath) {
        if (!import_) {
          throw new _configError.default("Internal error: Native ECMAScript modules aren't supported by this platform.\n", filepath);
        }
        const module3 = yield (0, _rewriteStackTrace.endHiddenCallStack)(import_)((0, _url().pathToFileURL)(filepath));
        return module3.default;
      });
      return _loadMjsDefault.apply(this, arguments);
    }
  }
});

// node_modules/@babel/core/lib/config/pattern-to-regex.js
var require_pattern_to_regex = __commonJS({
  "node_modules/@babel/core/lib/config/pattern-to-regex.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = pathToPattern;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    var sep = `\\${_path().sep}`;
    var endSep = `(?:${sep}|$)`;
    var substitution = `[^${sep}]+`;
    var starPat = `(?:${substitution}${sep})`;
    var starPatLast = `(?:${substitution}${endSep})`;
    var starStarPat = `${starPat}*?`;
    var starStarPatLast = `${starPat}*?${starPatLast}?`;
    function escapeRegExp(string) {
      return string.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&");
    }
    function pathToPattern(pattern, dirname) {
      const parts = _path().resolve(dirname, pattern).split(_path().sep);
      return new RegExp(["^", ...parts.map((part, i) => {
        const last2 = i === parts.length - 1;
        if (part === "**")
          return last2 ? starStarPatLast : starStarPat;
        if (part === "*")
          return last2 ? starPatLast : starPat;
        if (part.indexOf("*.") === 0) {
          return substitution + escapeRegExp(part.slice(1)) + (last2 ? endSep : sep);
        }
        return escapeRegExp(part) + (last2 ? endSep : sep);
      })].join(""));
    }
  }
});

// node_modules/@babel/core/lib/config/files/configuration.js
var require_configuration = __commonJS({
  "node_modules/@babel/core/lib/config/files/configuration.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ROOT_CONFIG_FILENAMES = void 0;
    exports.findConfigUpwards = findConfigUpwards;
    exports.findRelativeConfig = findRelativeConfig;
    exports.findRootConfig = findRootConfig;
    exports.loadConfig = loadConfig;
    exports.resolveShowConfigPath = resolveShowConfigPath;
    function _debug() {
      const data = require_src();
      _debug = function() {
        return data;
      };
      return data;
    }
    function _fs() {
      const data = require("fs");
      _fs = function() {
        return data;
      };
      return data;
    }
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _json() {
      const data = require_lib25();
      _json = function() {
        return data;
      };
      return data;
    }
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _caching = require_caching();
    var _configApi = require_config_api();
    var _utils = require_utils7();
    var _moduleTypes = require_module_types();
    var _patternToRegex = require_pattern_to_regex();
    var _configError = require_config_error();
    var fs2 = require_fs5();
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var debug = _debug()("babel:config:loading:files:configuration");
    var ROOT_CONFIG_FILENAMES = ["babel.config.js", "babel.config.cjs", "babel.config.mjs", "babel.config.json"];
    exports.ROOT_CONFIG_FILENAMES = ROOT_CONFIG_FILENAMES;
    var RELATIVE_CONFIG_FILENAMES = [".babelrc", ".babelrc.js", ".babelrc.cjs", ".babelrc.mjs", ".babelrc.json"];
    var BABELIGNORE_FILENAME = ".babelignore";
    var LOADING_CONFIGS = /* @__PURE__ */ new Set();
    var readConfigJS = (0, _caching.makeStrongCache)(function* readConfigJS2(filepath, cache) {
      if (!_fs().existsSync(filepath)) {
        cache.never();
        return null;
      }
      if (LOADING_CONFIGS.has(filepath)) {
        cache.never();
        debug("Auto-ignoring usage of config %o.", filepath);
        return {
          filepath,
          dirname: _path().dirname(filepath),
          options: {}
        };
      }
      let options;
      try {
        LOADING_CONFIGS.add(filepath);
        options = yield* (0, _moduleTypes.default)(filepath, "You appear to be using a native ECMAScript module configuration file, which is only supported when running Babel asynchronously.");
      } finally {
        LOADING_CONFIGS.delete(filepath);
      }
      let assertCache = false;
      if (typeof options === "function") {
        yield* [];
        options = (0, _rewriteStackTrace.endHiddenCallStack)(options)((0, _configApi.makeConfigAPI)(cache));
        assertCache = true;
      }
      if (!options || typeof options !== "object" || Array.isArray(options)) {
        throw new _configError.default(`Configuration should be an exported JavaScript object.`, filepath);
      }
      if (typeof options.then === "function") {
        throw new _configError.default(`You appear to be using an async configuration, which your current version of Babel does not support. We may add support for this in the future, but if you're on the most recent version of @babel/core and still seeing this error, then you'll need to synchronously return your config.`, filepath);
      }
      if (assertCache && !cache.configured())
        throwConfigError(filepath);
      return {
        filepath,
        dirname: _path().dirname(filepath),
        options
      };
    });
    var packageToBabelConfig = (0, _caching.makeWeakCacheSync)((file) => {
      const babel = file.options["babel"];
      if (typeof babel === "undefined")
        return null;
      if (typeof babel !== "object" || Array.isArray(babel) || babel === null) {
        throw new _configError.default(`.babel property must be an object`, file.filepath);
      }
      return {
        filepath: file.filepath,
        dirname: file.dirname,
        options: babel
      };
    });
    var readConfigJSON5 = (0, _utils.makeStaticFileCache)((filepath, content) => {
      let options;
      try {
        options = _json().parse(content);
      } catch (err) {
        throw new _configError.default(`Error while parsing config - ${err.message}`, filepath);
      }
      if (!options)
        throw new _configError.default(`No config detected`, filepath);
      if (typeof options !== "object") {
        throw new _configError.default(`Config returned typeof ${typeof options}`, filepath);
      }
      if (Array.isArray(options)) {
        throw new _configError.default(`Expected config object but found array`, filepath);
      }
      delete options["$schema"];
      return {
        filepath,
        dirname: _path().dirname(filepath),
        options
      };
    });
    var readIgnoreConfig = (0, _utils.makeStaticFileCache)((filepath, content) => {
      const ignoreDir = _path().dirname(filepath);
      const ignorePatterns = content.split("\n").map((line) => line.replace(/#(.*?)$/, "").trim()).filter((line) => !!line);
      for (const pattern of ignorePatterns) {
        if (pattern[0] === "!") {
          throw new _configError.default(`Negation of file paths is not supported.`, filepath);
        }
      }
      return {
        filepath,
        dirname: _path().dirname(filepath),
        ignore: ignorePatterns.map((pattern) => (0, _patternToRegex.default)(pattern, ignoreDir))
      };
    });
    function findConfigUpwards(rootDir) {
      let dirname = rootDir;
      for (; ; ) {
        for (const filename of ROOT_CONFIG_FILENAMES) {
          if (_fs().existsSync(_path().join(dirname, filename))) {
            return dirname;
          }
        }
        const nextDir = _path().dirname(dirname);
        if (dirname === nextDir)
          break;
        dirname = nextDir;
      }
      return null;
    }
    function* findRelativeConfig(packageData, envName, caller) {
      let config = null;
      let ignore = null;
      const dirname = _path().dirname(packageData.filepath);
      for (const loc of packageData.directories) {
        if (!config) {
          var _packageData$pkg;
          config = yield* loadOneConfig(RELATIVE_CONFIG_FILENAMES, loc, envName, caller, ((_packageData$pkg = packageData.pkg) == null ? void 0 : _packageData$pkg.dirname) === loc ? packageToBabelConfig(packageData.pkg) : null);
        }
        if (!ignore) {
          const ignoreLoc = _path().join(loc, BABELIGNORE_FILENAME);
          ignore = yield* readIgnoreConfig(ignoreLoc);
          if (ignore) {
            debug("Found ignore %o from %o.", ignore.filepath, dirname);
          }
        }
      }
      return {
        config,
        ignore
      };
    }
    function findRootConfig(dirname, envName, caller) {
      return loadOneConfig(ROOT_CONFIG_FILENAMES, dirname, envName, caller);
    }
    function* loadOneConfig(names, dirname, envName, caller, previousConfig = null) {
      const configs = yield* _gensync().all(names.map((filename) => readConfig(_path().join(dirname, filename), envName, caller)));
      const config = configs.reduce((previousConfig2, config2) => {
        if (config2 && previousConfig2) {
          throw new _configError.default(`Multiple configuration files found. Please remove one:
 - ${_path().basename(previousConfig2.filepath)}
 - ${config2.filepath}
from ${dirname}`);
        }
        return config2 || previousConfig2;
      }, previousConfig);
      if (config) {
        debug("Found configuration %o from %o.", config.filepath, dirname);
      }
      return config;
    }
    function* loadConfig(name, dirname, envName, caller) {
      const filepath = (((v, w) => (v = v.split("."), w = w.split("."), +v[0] > +w[0] || v[0] == w[0] && +v[1] >= +w[1]))(process.versions.node, "8.9") ? require.resolve : (r, {
        paths: [b]
      }, M = require("module")) => {
        let f = M._findPath(r, M._nodeModulePaths(b).concat(b));
        if (f)
          return f;
        f = new Error(`Cannot resolve module '${r}'`);
        f.code = "MODULE_NOT_FOUND";
        throw f;
      })(name, {
        paths: [dirname]
      });
      const conf = yield* readConfig(filepath, envName, caller);
      if (!conf) {
        throw new _configError.default(`Config file contains no configuration data`, filepath);
      }
      debug("Loaded config %o from %o.", name, dirname);
      return conf;
    }
    function readConfig(filepath, envName, caller) {
      const ext = _path().extname(filepath);
      return ext === ".js" || ext === ".cjs" || ext === ".mjs" ? readConfigJS(filepath, {
        envName,
        caller
      }) : readConfigJSON5(filepath);
    }
    function* resolveShowConfigPath(dirname) {
      const targetPath = process.env.BABEL_SHOW_CONFIG_FOR;
      if (targetPath != null) {
        const absolutePath = _path().resolve(dirname, targetPath);
        const stats = yield* fs2.stat(absolutePath);
        if (!stats.isFile()) {
          throw new Error(`${absolutePath}: BABEL_SHOW_CONFIG_FOR must refer to a regular file, directories are not supported.`);
        }
        return absolutePath;
      }
      return null;
    }
    function throwConfigError(filepath) {
      throw new _configError.default(`Caching was left unconfigured. Babel's plugins, presets, and .babelrc.js files can be configured
for various types of caching, using the first param of their handler functions:

module.exports = function(api) {
  // The API exposes the following:

  // Cache the returned value forever and don't call this function again.
  api.cache(true);

  // Don't cache at all. Not recommended because it will be very slow.
  api.cache(false);

  // Cached based on the value of some function. If this function returns a value different from
  // a previously-encountered value, the plugins will re-evaluate.
  var env = api.cache(() => process.env.NODE_ENV);

  // If testing for a specific env, we recommend specifics to avoid instantiating a plugin for
  // any possible NODE_ENV value that might come up during plugin execution.
  var isProd = api.cache(() => process.env.NODE_ENV === "production");

  // .cache(fn) will perform a linear search though instances to find the matching plugin based
  // based on previous instantiated plugins. If you want to recreate the plugin and discard the
  // previous instance whenever something changes, you may use:
  var isProd = api.cache.invalidate(() => process.env.NODE_ENV === "production");

  // Note, we also expose the following more-verbose versions of the above examples:
  api.cache.forever(); // api.cache(true)
  api.cache.never();   // api.cache(false)
  api.cache.using(fn); // api.cache(fn)

  // Return the value that will be cached.
  return { };
};`, filepath);
    }
  }
});

// node_modules/@babel/core/lib/vendor/import-meta-resolve.js
var require_import_meta_resolve = __commonJS({
  "node_modules/@babel/core/lib/vendor/import-meta-resolve.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.moduleResolve = moduleResolve;
    exports.resolve = resolve;
    function _url() {
      const data = require("url");
      _url = function() {
        return data;
      };
      return data;
    }
    function _fs() {
      const data = _interopRequireWildcard(require("fs"), true);
      _fs = function() {
        return data;
      };
      return data;
    }
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _assert() {
      const data = require("assert");
      _assert = function() {
        return data;
      };
      return data;
    }
    function _util() {
      const data = require("util");
      _util = function() {
        return data;
      };
      return data;
    }
    function _getRequireWildcardCache(nodeInterop) {
      if (typeof WeakMap !== "function")
        return null;
      var cacheBabelInterop = /* @__PURE__ */ new WeakMap();
      var cacheNodeInterop = /* @__PURE__ */ new WeakMap();
      return (_getRequireWildcardCache = function(nodeInterop2) {
        return nodeInterop2 ? cacheNodeInterop : cacheBabelInterop;
      })(nodeInterop);
    }
    function _interopRequireWildcard(obj, nodeInterop) {
      if (!nodeInterop && obj && obj.__esModule) {
        return obj;
      }
      if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return { default: obj };
      }
      var cache = _getRequireWildcardCache(nodeInterop);
      if (cache && cache.has(obj)) {
        return cache.get(obj);
      }
      var newObj = {};
      var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
      for (var key in obj) {
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
          if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }
      newObj.default = obj;
      if (cache) {
        cache.set(obj, newObj);
      }
      return newObj;
    }
    function asyncGeneratorStep(gen, resolve2, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve2(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve2, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve2, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve2, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    var re$3 = {
      exports: {}
    };
    var SEMVER_SPEC_VERSION = "2.0.0";
    var MAX_LENGTH$2 = 256;
    var MAX_SAFE_INTEGER$1 = Number.MAX_SAFE_INTEGER || 9007199254740991;
    var MAX_SAFE_COMPONENT_LENGTH = 16;
    var constants = {
      SEMVER_SPEC_VERSION,
      MAX_LENGTH: MAX_LENGTH$2,
      MAX_SAFE_INTEGER: MAX_SAFE_INTEGER$1,
      MAX_SAFE_COMPONENT_LENGTH
    };
    var debug$1 = typeof process === "object" && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG) ? (...args) => console.error("SEMVER", ...args) : () => {
    };
    var debug_1 = debug$1;
    (function(module3, exports2) {
      const {
        MAX_SAFE_COMPONENT_LENGTH: MAX_SAFE_COMPONENT_LENGTH2
      } = constants;
      const debug2 = debug_1;
      exports2 = module3.exports = {};
      const re2 = exports2.re = [];
      const src = exports2.src = [];
      const t4 = exports2.t = {};
      let R = 0;
      const createToken = (name, value2, isGlobal) => {
        const index = R++;
        debug2(name, index, value2);
        t4[name] = index;
        src[index] = value2;
        re2[index] = new RegExp(value2, isGlobal ? "g" : void 0);
      };
      createToken("NUMERICIDENTIFIER", "0|[1-9]\\d*");
      createToken("NUMERICIDENTIFIERLOOSE", "[0-9]+");
      createToken("NONNUMERICIDENTIFIER", "\\d*[a-zA-Z-][a-zA-Z0-9-]*");
      createToken("MAINVERSION", `(${src[t4.NUMERICIDENTIFIER]})\\.(${src[t4.NUMERICIDENTIFIER]})\\.(${src[t4.NUMERICIDENTIFIER]})`);
      createToken("MAINVERSIONLOOSE", `(${src[t4.NUMERICIDENTIFIERLOOSE]})\\.(${src[t4.NUMERICIDENTIFIERLOOSE]})\\.(${src[t4.NUMERICIDENTIFIERLOOSE]})`);
      createToken("PRERELEASEIDENTIFIER", `(?:${src[t4.NUMERICIDENTIFIER]}|${src[t4.NONNUMERICIDENTIFIER]})`);
      createToken("PRERELEASEIDENTIFIERLOOSE", `(?:${src[t4.NUMERICIDENTIFIERLOOSE]}|${src[t4.NONNUMERICIDENTIFIER]})`);
      createToken("PRERELEASE", `(?:-(${src[t4.PRERELEASEIDENTIFIER]}(?:\\.${src[t4.PRERELEASEIDENTIFIER]})*))`);
      createToken("PRERELEASELOOSE", `(?:-?(${src[t4.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${src[t4.PRERELEASEIDENTIFIERLOOSE]})*))`);
      createToken("BUILDIDENTIFIER", "[0-9A-Za-z-]+");
      createToken("BUILD", `(?:\\+(${src[t4.BUILDIDENTIFIER]}(?:\\.${src[t4.BUILDIDENTIFIER]})*))`);
      createToken("FULLPLAIN", `v?${src[t4.MAINVERSION]}${src[t4.PRERELEASE]}?${src[t4.BUILD]}?`);
      createToken("FULL", `^${src[t4.FULLPLAIN]}$`);
      createToken("LOOSEPLAIN", `[v=\\s]*${src[t4.MAINVERSIONLOOSE]}${src[t4.PRERELEASELOOSE]}?${src[t4.BUILD]}?`);
      createToken("LOOSE", `^${src[t4.LOOSEPLAIN]}$`);
      createToken("GTLT", "((?:<|>)?=?)");
      createToken("XRANGEIDENTIFIERLOOSE", `${src[t4.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`);
      createToken("XRANGEIDENTIFIER", `${src[t4.NUMERICIDENTIFIER]}|x|X|\\*`);
      createToken("XRANGEPLAIN", `[v=\\s]*(${src[t4.XRANGEIDENTIFIER]})(?:\\.(${src[t4.XRANGEIDENTIFIER]})(?:\\.(${src[t4.XRANGEIDENTIFIER]})(?:${src[t4.PRERELEASE]})?${src[t4.BUILD]}?)?)?`);
      createToken("XRANGEPLAINLOOSE", `[v=\\s]*(${src[t4.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t4.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t4.XRANGEIDENTIFIERLOOSE]})(?:${src[t4.PRERELEASELOOSE]})?${src[t4.BUILD]}?)?)?`);
      createToken("XRANGE", `^${src[t4.GTLT]}\\s*${src[t4.XRANGEPLAIN]}$`);
      createToken("XRANGELOOSE", `^${src[t4.GTLT]}\\s*${src[t4.XRANGEPLAINLOOSE]}$`);
      createToken("COERCE", `${"(^|[^\\d])(\\d{1,"}${MAX_SAFE_COMPONENT_LENGTH2}})(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH2}}))?(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH2}}))?(?:$|[^\\d])`);
      createToken("COERCERTL", src[t4.COERCE], true);
      createToken("LONETILDE", "(?:~>?)");
      createToken("TILDETRIM", `(\\s*)${src[t4.LONETILDE]}\\s+`, true);
      exports2.tildeTrimReplace = "$1~";
      createToken("TILDE", `^${src[t4.LONETILDE]}${src[t4.XRANGEPLAIN]}$`);
      createToken("TILDELOOSE", `^${src[t4.LONETILDE]}${src[t4.XRANGEPLAINLOOSE]}$`);
      createToken("LONECARET", "(?:\\^)");
      createToken("CARETTRIM", `(\\s*)${src[t4.LONECARET]}\\s+`, true);
      exports2.caretTrimReplace = "$1^";
      createToken("CARET", `^${src[t4.LONECARET]}${src[t4.XRANGEPLAIN]}$`);
      createToken("CARETLOOSE", `^${src[t4.LONECARET]}${src[t4.XRANGEPLAINLOOSE]}$`);
      createToken("COMPARATORLOOSE", `^${src[t4.GTLT]}\\s*(${src[t4.LOOSEPLAIN]})$|^$`);
      createToken("COMPARATOR", `^${src[t4.GTLT]}\\s*(${src[t4.FULLPLAIN]})$|^$`);
      createToken("COMPARATORTRIM", `(\\s*)${src[t4.GTLT]}\\s*(${src[t4.LOOSEPLAIN]}|${src[t4.XRANGEPLAIN]})`, true);
      exports2.comparatorTrimReplace = "$1$2$3";
      createToken("HYPHENRANGE", `^\\s*(${src[t4.XRANGEPLAIN]})\\s+-\\s+(${src[t4.XRANGEPLAIN]})\\s*$`);
      createToken("HYPHENRANGELOOSE", `^\\s*(${src[t4.XRANGEPLAINLOOSE]})\\s+-\\s+(${src[t4.XRANGEPLAINLOOSE]})\\s*$`);
      createToken("STAR", "(<|>)?=?\\s*\\*");
      createToken("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$");
      createToken("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
    })(re$3, re$3.exports);
    var opts = ["includePrerelease", "loose", "rtl"];
    var parseOptions$2 = (options) => !options ? {} : typeof options !== "object" ? {
      loose: true
    } : opts.filter((k) => options[k]).reduce((o, k) => {
      o[k] = true;
      return o;
    }, {});
    var parseOptions_1 = parseOptions$2;
    var numeric = /^[0-9]+$/;
    var compareIdentifiers$1 = (a, b) => {
      const anum = numeric.test(a);
      const bnum = numeric.test(b);
      if (anum && bnum) {
        a = +a;
        b = +b;
      }
      return a === b ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a < b ? -1 : 1;
    };
    var rcompareIdentifiers = (a, b) => compareIdentifiers$1(b, a);
    var identifiers = {
      compareIdentifiers: compareIdentifiers$1,
      rcompareIdentifiers
    };
    var debug = debug_1;
    var {
      MAX_LENGTH: MAX_LENGTH$1,
      MAX_SAFE_INTEGER
    } = constants;
    var {
      re: re$2,
      t: t$2
    } = re$3.exports;
    var parseOptions$1 = parseOptions_1;
    var {
      compareIdentifiers
    } = identifiers;
    var SemVer$c = class _SemVer$c {
      constructor(version2, options) {
        options = parseOptions$1(options);
        if (version2 instanceof _SemVer$c) {
          if (version2.loose === !!options.loose && version2.includePrerelease === !!options.includePrerelease) {
            return version2;
          } else {
            version2 = version2.version;
          }
        } else if (typeof version2 !== "string") {
          throw new TypeError(`Invalid Version: ${version2}`);
        }
        if (version2.length > MAX_LENGTH$1) {
          throw new TypeError(`version is longer than ${MAX_LENGTH$1} characters`);
        }
        debug("SemVer", version2, options);
        this.options = options;
        this.loose = !!options.loose;
        this.includePrerelease = !!options.includePrerelease;
        const m = version2.trim().match(options.loose ? re$2[t$2.LOOSE] : re$2[t$2.FULL]);
        if (!m) {
          throw new TypeError(`Invalid Version: ${version2}`);
        }
        this.raw = version2;
        this.major = +m[1];
        this.minor = +m[2];
        this.patch = +m[3];
        if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
          throw new TypeError("Invalid major version");
        }
        if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
          throw new TypeError("Invalid minor version");
        }
        if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
          throw new TypeError("Invalid patch version");
        }
        if (!m[4]) {
          this.prerelease = [];
        } else {
          this.prerelease = m[4].split(".").map((id) => {
            if (/^[0-9]+$/.test(id)) {
              const num = +id;
              if (num >= 0 && num < MAX_SAFE_INTEGER) {
                return num;
              }
            }
            return id;
          });
        }
        this.build = m[5] ? m[5].split(".") : [];
        this.format();
      }
      format() {
        this.version = `${this.major}.${this.minor}.${this.patch}`;
        if (this.prerelease.length) {
          this.version += `-${this.prerelease.join(".")}`;
        }
        return this.version;
      }
      toString() {
        return this.version;
      }
      compare(other) {
        debug("SemVer.compare", this.version, this.options, other);
        if (!(other instanceof _SemVer$c)) {
          if (typeof other === "string" && other === this.version) {
            return 0;
          }
          other = new _SemVer$c(other, this.options);
        }
        if (other.version === this.version) {
          return 0;
        }
        return this.compareMain(other) || this.comparePre(other);
      }
      compareMain(other) {
        if (!(other instanceof _SemVer$c)) {
          other = new _SemVer$c(other, this.options);
        }
        return compareIdentifiers(this.major, other.major) || compareIdentifiers(this.minor, other.minor) || compareIdentifiers(this.patch, other.patch);
      }
      comparePre(other) {
        if (!(other instanceof _SemVer$c)) {
          other = new _SemVer$c(other, this.options);
        }
        if (this.prerelease.length && !other.prerelease.length) {
          return -1;
        } else if (!this.prerelease.length && other.prerelease.length) {
          return 1;
        } else if (!this.prerelease.length && !other.prerelease.length) {
          return 0;
        }
        let i = 0;
        do {
          const a = this.prerelease[i];
          const b = other.prerelease[i];
          debug("prerelease compare", i, a, b);
          if (a === void 0 && b === void 0) {
            return 0;
          } else if (b === void 0) {
            return 1;
          } else if (a === void 0) {
            return -1;
          } else if (a === b) {
            continue;
          } else {
            return compareIdentifiers(a, b);
          }
        } while (++i);
      }
      compareBuild(other) {
        if (!(other instanceof _SemVer$c)) {
          other = new _SemVer$c(other, this.options);
        }
        let i = 0;
        do {
          const a = this.build[i];
          const b = other.build[i];
          debug("prerelease compare", i, a, b);
          if (a === void 0 && b === void 0) {
            return 0;
          } else if (b === void 0) {
            return 1;
          } else if (a === void 0) {
            return -1;
          } else if (a === b) {
            continue;
          } else {
            return compareIdentifiers(a, b);
          }
        } while (++i);
      }
      inc(release, identifier3) {
        switch (release) {
          case "premajor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor = 0;
            this.major++;
            this.inc("pre", identifier3);
            break;
          case "preminor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor++;
            this.inc("pre", identifier3);
            break;
          case "prepatch":
            this.prerelease.length = 0;
            this.inc("patch", identifier3);
            this.inc("pre", identifier3);
            break;
          case "prerelease":
            if (this.prerelease.length === 0) {
              this.inc("patch", identifier3);
            }
            this.inc("pre", identifier3);
            break;
          case "major":
            if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {
              this.major++;
            }
            this.minor = 0;
            this.patch = 0;
            this.prerelease = [];
            break;
          case "minor":
            if (this.patch !== 0 || this.prerelease.length === 0) {
              this.minor++;
            }
            this.patch = 0;
            this.prerelease = [];
            break;
          case "patch":
            if (this.prerelease.length === 0) {
              this.patch++;
            }
            this.prerelease = [];
            break;
          case "pre":
            if (this.prerelease.length === 0) {
              this.prerelease = [0];
            } else {
              let i = this.prerelease.length;
              while (--i >= 0) {
                if (typeof this.prerelease[i] === "number") {
                  this.prerelease[i]++;
                  i = -2;
                }
              }
              if (i === -1) {
                this.prerelease.push(0);
              }
            }
            if (identifier3) {
              if (compareIdentifiers(this.prerelease[0], identifier3) === 0) {
                if (isNaN(this.prerelease[1])) {
                  this.prerelease = [identifier3, 0];
                }
              } else {
                this.prerelease = [identifier3, 0];
              }
            }
            break;
          default:
            throw new Error(`invalid increment argument: ${release}`);
        }
        this.format();
        this.raw = this.version;
        return this;
      }
    };
    var semver$2 = SemVer$c;
    var {
      MAX_LENGTH
    } = constants;
    var {
      re: re$1,
      t: t$1
    } = re$3.exports;
    var SemVer$b = semver$2;
    var parseOptions = parseOptions_1;
    var parse$5 = (version2, options) => {
      options = parseOptions(options);
      if (version2 instanceof SemVer$b) {
        return version2;
      }
      if (typeof version2 !== "string") {
        return null;
      }
      if (version2.length > MAX_LENGTH) {
        return null;
      }
      const r = options.loose ? re$1[t$1.LOOSE] : re$1[t$1.FULL];
      if (!r.test(version2)) {
        return null;
      }
      try {
        return new SemVer$b(version2, options);
      } catch (er) {
        return null;
      }
    };
    var parse_1 = parse$5;
    var parse$4 = parse_1;
    var valid$1 = (version2, options) => {
      const v = parse$4(version2, options);
      return v ? v.version : null;
    };
    var valid_1 = valid$1;
    var parse$3 = parse_1;
    var clean = (version2, options) => {
      const s = parse$3(version2.trim().replace(/^[=v]+/, ""), options);
      return s ? s.version : null;
    };
    var clean_1 = clean;
    var SemVer$a = semver$2;
    var inc = (version2, release, options, identifier3) => {
      if (typeof options === "string") {
        identifier3 = options;
        options = void 0;
      }
      try {
        return new SemVer$a(version2 instanceof SemVer$a ? version2.version : version2, options).inc(release, identifier3).version;
      } catch (er) {
        return null;
      }
    };
    var inc_1 = inc;
    var SemVer$9 = semver$2;
    var compare$a = (a, b, loose) => new SemVer$9(a, loose).compare(new SemVer$9(b, loose));
    var compare_1 = compare$a;
    var compare$9 = compare_1;
    var eq$2 = (a, b, loose) => compare$9(a, b, loose) === 0;
    var eq_1 = eq$2;
    var parse$2 = parse_1;
    var eq$1 = eq_1;
    var diff = (version1, version2) => {
      if (eq$1(version1, version2)) {
        return null;
      } else {
        const v1 = parse$2(version1);
        const v2 = parse$2(version2);
        const hasPre = v1.prerelease.length || v2.prerelease.length;
        const prefix = hasPre ? "pre" : "";
        const defaultResult = hasPre ? "prerelease" : "";
        for (const key in v1) {
          if (key === "major" || key === "minor" || key === "patch") {
            if (v1[key] !== v2[key]) {
              return prefix + key;
            }
          }
        }
        return defaultResult;
      }
    };
    var diff_1 = diff;
    var SemVer$8 = semver$2;
    var major = (a, loose) => new SemVer$8(a, loose).major;
    var major_1 = major;
    var SemVer$7 = semver$2;
    var minor = (a, loose) => new SemVer$7(a, loose).minor;
    var minor_1 = minor;
    var SemVer$6 = semver$2;
    var patch = (a, loose) => new SemVer$6(a, loose).patch;
    var patch_1 = patch;
    var parse$1 = parse_1;
    var prerelease = (version2, options) => {
      const parsed = parse$1(version2, options);
      return parsed && parsed.prerelease.length ? parsed.prerelease : null;
    };
    var prerelease_1 = prerelease;
    var compare$8 = compare_1;
    var rcompare = (a, b, loose) => compare$8(b, a, loose);
    var rcompare_1 = rcompare;
    var compare$7 = compare_1;
    var compareLoose = (a, b) => compare$7(a, b, true);
    var compareLoose_1 = compareLoose;
    var SemVer$5 = semver$2;
    var compareBuild$2 = (a, b, loose) => {
      const versionA = new SemVer$5(a, loose);
      const versionB = new SemVer$5(b, loose);
      return versionA.compare(versionB) || versionA.compareBuild(versionB);
    };
    var compareBuild_1 = compareBuild$2;
    var compareBuild$1 = compareBuild_1;
    var sort = (list, loose) => list.sort((a, b) => compareBuild$1(a, b, loose));
    var sort_1 = sort;
    var compareBuild = compareBuild_1;
    var rsort = (list, loose) => list.sort((a, b) => compareBuild(b, a, loose));
    var rsort_1 = rsort;
    var compare$6 = compare_1;
    var gt$3 = (a, b, loose) => compare$6(a, b, loose) > 0;
    var gt_1 = gt$3;
    var compare$5 = compare_1;
    var lt$2 = (a, b, loose) => compare$5(a, b, loose) < 0;
    var lt_1 = lt$2;
    var compare$4 = compare_1;
    var neq$1 = (a, b, loose) => compare$4(a, b, loose) !== 0;
    var neq_1 = neq$1;
    var compare$3 = compare_1;
    var gte$2 = (a, b, loose) => compare$3(a, b, loose) >= 0;
    var gte_1 = gte$2;
    var compare$2 = compare_1;
    var lte$2 = (a, b, loose) => compare$2(a, b, loose) <= 0;
    var lte_1 = lte$2;
    var eq = eq_1;
    var neq = neq_1;
    var gt$2 = gt_1;
    var gte$1 = gte_1;
    var lt$1 = lt_1;
    var lte$1 = lte_1;
    var cmp = (a, op, b, loose) => {
      switch (op) {
        case "===":
          if (typeof a === "object") {
            a = a.version;
          }
          if (typeof b === "object") {
            b = b.version;
          }
          return a === b;
        case "!==":
          if (typeof a === "object") {
            a = a.version;
          }
          if (typeof b === "object") {
            b = b.version;
          }
          return a !== b;
        case "":
        case "=":
        case "==":
          return eq(a, b, loose);
        case "!=":
          return neq(a, b, loose);
        case ">":
          return gt$2(a, b, loose);
        case ">=":
          return gte$1(a, b, loose);
        case "<":
          return lt$1(a, b, loose);
        case "<=":
          return lte$1(a, b, loose);
        default:
          throw new TypeError(`Invalid operator: ${op}`);
      }
    };
    var cmp_1 = cmp;
    var SemVer$4 = semver$2;
    var parse3 = parse_1;
    var {
      re,
      t: t3
    } = re$3.exports;
    var coerce = (version2, options) => {
      if (version2 instanceof SemVer$4) {
        return version2;
      }
      if (typeof version2 === "number") {
        version2 = String(version2);
      }
      if (typeof version2 !== "string") {
        return null;
      }
      options = options || {};
      let match = null;
      if (!options.rtl) {
        match = version2.match(re[t3.COERCE]);
      } else {
        let next;
        while ((next = re[t3.COERCERTL].exec(version2)) && (!match || match.index + match[0].length !== version2.length)) {
          if (!match || next.index + next[0].length !== match.index + match[0].length) {
            match = next;
          }
          re[t3.COERCERTL].lastIndex = next.index + next[1].length + next[2].length;
        }
        re[t3.COERCERTL].lastIndex = -1;
      }
      if (match === null) {
        return null;
      }
      return parse3(`${match[2]}.${match[3] || "0"}.${match[4] || "0"}`, options);
    };
    var coerce_1 = coerce;
    var iterator;
    var hasRequiredIterator;
    function requireIterator() {
      if (hasRequiredIterator)
        return iterator;
      hasRequiredIterator = 1;
      iterator = function(Yallist) {
        Yallist.prototype[Symbol.iterator] = function* () {
          for (let walker = this.head; walker; walker = walker.next) {
            yield walker.value;
          }
        };
      };
      return iterator;
    }
    var yallist;
    var hasRequiredYallist;
    function requireYallist() {
      if (hasRequiredYallist)
        return yallist;
      hasRequiredYallist = 1;
      yallist = Yallist;
      Yallist.Node = Node2;
      Yallist.create = Yallist;
      function Yallist(list) {
        var self2 = this;
        if (!(self2 instanceof Yallist)) {
          self2 = new Yallist();
        }
        self2.tail = null;
        self2.head = null;
        self2.length = 0;
        if (list && typeof list.forEach === "function") {
          list.forEach(function(item) {
            self2.push(item);
          });
        } else if (arguments.length > 0) {
          for (var i = 0, l = arguments.length; i < l; i++) {
            self2.push(arguments[i]);
          }
        }
        return self2;
      }
      Yallist.prototype.removeNode = function(node) {
        if (node.list !== this) {
          throw new Error("removing node which does not belong to this list");
        }
        var next = node.next;
        var prev = node.prev;
        if (next) {
          next.prev = prev;
        }
        if (prev) {
          prev.next = next;
        }
        if (node === this.head) {
          this.head = next;
        }
        if (node === this.tail) {
          this.tail = prev;
        }
        node.list.length--;
        node.next = null;
        node.prev = null;
        node.list = null;
        return next;
      };
      Yallist.prototype.unshiftNode = function(node) {
        if (node === this.head) {
          return;
        }
        if (node.list) {
          node.list.removeNode(node);
        }
        var head = this.head;
        node.list = this;
        node.next = head;
        if (head) {
          head.prev = node;
        }
        this.head = node;
        if (!this.tail) {
          this.tail = node;
        }
        this.length++;
      };
      Yallist.prototype.pushNode = function(node) {
        if (node === this.tail) {
          return;
        }
        if (node.list) {
          node.list.removeNode(node);
        }
        var tail = this.tail;
        node.list = this;
        node.prev = tail;
        if (tail) {
          tail.next = node;
        }
        this.tail = node;
        if (!this.head) {
          this.head = node;
        }
        this.length++;
      };
      Yallist.prototype.push = function() {
        for (var i = 0, l = arguments.length; i < l; i++) {
          push(this, arguments[i]);
        }
        return this.length;
      };
      Yallist.prototype.unshift = function() {
        for (var i = 0, l = arguments.length; i < l; i++) {
          unshift(this, arguments[i]);
        }
        return this.length;
      };
      Yallist.prototype.pop = function() {
        if (!this.tail) {
          return void 0;
        }
        var res = this.tail.value;
        this.tail = this.tail.prev;
        if (this.tail) {
          this.tail.next = null;
        } else {
          this.head = null;
        }
        this.length--;
        return res;
      };
      Yallist.prototype.shift = function() {
        if (!this.head) {
          return void 0;
        }
        var res = this.head.value;
        this.head = this.head.next;
        if (this.head) {
          this.head.prev = null;
        } else {
          this.tail = null;
        }
        this.length--;
        return res;
      };
      Yallist.prototype.forEach = function(fn, thisp) {
        thisp = thisp || this;
        for (var walker = this.head, i = 0; walker !== null; i++) {
          fn.call(thisp, walker.value, i, this);
          walker = walker.next;
        }
      };
      Yallist.prototype.forEachReverse = function(fn, thisp) {
        thisp = thisp || this;
        for (var walker = this.tail, i = this.length - 1; walker !== null; i--) {
          fn.call(thisp, walker.value, i, this);
          walker = walker.prev;
        }
      };
      Yallist.prototype.get = function(n) {
        for (var i = 0, walker = this.head; walker !== null && i < n; i++) {
          walker = walker.next;
        }
        if (i === n && walker !== null) {
          return walker.value;
        }
      };
      Yallist.prototype.getReverse = function(n) {
        for (var i = 0, walker = this.tail; walker !== null && i < n; i++) {
          walker = walker.prev;
        }
        if (i === n && walker !== null) {
          return walker.value;
        }
      };
      Yallist.prototype.map = function(fn, thisp) {
        thisp = thisp || this;
        var res = new Yallist();
        for (var walker = this.head; walker !== null; ) {
          res.push(fn.call(thisp, walker.value, this));
          walker = walker.next;
        }
        return res;
      };
      Yallist.prototype.mapReverse = function(fn, thisp) {
        thisp = thisp || this;
        var res = new Yallist();
        for (var walker = this.tail; walker !== null; ) {
          res.push(fn.call(thisp, walker.value, this));
          walker = walker.prev;
        }
        return res;
      };
      Yallist.prototype.reduce = function(fn, initial) {
        var acc;
        var walker = this.head;
        if (arguments.length > 1) {
          acc = initial;
        } else if (this.head) {
          walker = this.head.next;
          acc = this.head.value;
        } else {
          throw new TypeError("Reduce of empty list with no initial value");
        }
        for (var i = 0; walker !== null; i++) {
          acc = fn(acc, walker.value, i);
          walker = walker.next;
        }
        return acc;
      };
      Yallist.prototype.reduceReverse = function(fn, initial) {
        var acc;
        var walker = this.tail;
        if (arguments.length > 1) {
          acc = initial;
        } else if (this.tail) {
          walker = this.tail.prev;
          acc = this.tail.value;
        } else {
          throw new TypeError("Reduce of empty list with no initial value");
        }
        for (var i = this.length - 1; walker !== null; i--) {
          acc = fn(acc, walker.value, i);
          walker = walker.prev;
        }
        return acc;
      };
      Yallist.prototype.toArray = function() {
        var arr = new Array(this.length);
        for (var i = 0, walker = this.head; walker !== null; i++) {
          arr[i] = walker.value;
          walker = walker.next;
        }
        return arr;
      };
      Yallist.prototype.toArrayReverse = function() {
        var arr = new Array(this.length);
        for (var i = 0, walker = this.tail; walker !== null; i++) {
          arr[i] = walker.value;
          walker = walker.prev;
        }
        return arr;
      };
      Yallist.prototype.slice = function(from, to) {
        to = to || this.length;
        if (to < 0) {
          to += this.length;
        }
        from = from || 0;
        if (from < 0) {
          from += this.length;
        }
        var ret = new Yallist();
        if (to < from || to < 0) {
          return ret;
        }
        if (from < 0) {
          from = 0;
        }
        if (to > this.length) {
          to = this.length;
        }
        for (var i = 0, walker = this.head; walker !== null && i < from; i++) {
          walker = walker.next;
        }
        for (; walker !== null && i < to; i++, walker = walker.next) {
          ret.push(walker.value);
        }
        return ret;
      };
      Yallist.prototype.sliceReverse = function(from, to) {
        to = to || this.length;
        if (to < 0) {
          to += this.length;
        }
        from = from || 0;
        if (from < 0) {
          from += this.length;
        }
        var ret = new Yallist();
        if (to < from || to < 0) {
          return ret;
        }
        if (from < 0) {
          from = 0;
        }
        if (to > this.length) {
          to = this.length;
        }
        for (var i = this.length, walker = this.tail; walker !== null && i > to; i--) {
          walker = walker.prev;
        }
        for (; walker !== null && i > from; i--, walker = walker.prev) {
          ret.push(walker.value);
        }
        return ret;
      };
      Yallist.prototype.splice = function(start, deleteCount, ...nodes) {
        if (start > this.length) {
          start = this.length - 1;
        }
        if (start < 0) {
          start = this.length + start;
        }
        for (var i = 0, walker = this.head; walker !== null && i < start; i++) {
          walker = walker.next;
        }
        var ret = [];
        for (var i = 0; walker && i < deleteCount; i++) {
          ret.push(walker.value);
          walker = this.removeNode(walker);
        }
        if (walker === null) {
          walker = this.tail;
        }
        if (walker !== this.head && walker !== this.tail) {
          walker = walker.prev;
        }
        for (var i = 0; i < nodes.length; i++) {
          walker = insert(this, walker, nodes[i]);
        }
        return ret;
      };
      Yallist.prototype.reverse = function() {
        var head = this.head;
        var tail = this.tail;
        for (var walker = head; walker !== null; walker = walker.prev) {
          var p = walker.prev;
          walker.prev = walker.next;
          walker.next = p;
        }
        this.head = tail;
        this.tail = head;
        return this;
      };
      function insert(self2, node, value2) {
        var inserted = node === self2.head ? new Node2(value2, null, node, self2) : new Node2(value2, node, node.next, self2);
        if (inserted.next === null) {
          self2.tail = inserted;
        }
        if (inserted.prev === null) {
          self2.head = inserted;
        }
        self2.length++;
        return inserted;
      }
      function push(self2, item) {
        self2.tail = new Node2(item, self2.tail, null, self2);
        if (!self2.head) {
          self2.head = self2.tail;
        }
        self2.length++;
      }
      function unshift(self2, item) {
        self2.head = new Node2(item, null, self2.head, self2);
        if (!self2.tail) {
          self2.tail = self2.head;
        }
        self2.length++;
      }
      function Node2(value2, prev, next, list) {
        if (!(this instanceof Node2)) {
          return new Node2(value2, prev, next, list);
        }
        this.list = list;
        this.value = value2;
        if (prev) {
          prev.next = this;
          this.prev = prev;
        } else {
          this.prev = null;
        }
        if (next) {
          next.prev = this;
          this.next = next;
        } else {
          this.next = null;
        }
      }
      try {
        requireIterator()(Yallist);
      } catch (er) {
      }
      return yallist;
    }
    var lruCache;
    var hasRequiredLruCache;
    function requireLruCache() {
      if (hasRequiredLruCache)
        return lruCache;
      hasRequiredLruCache = 1;
      const Yallist = requireYallist();
      const MAX = Symbol("max");
      const LENGTH = Symbol("length");
      const LENGTH_CALCULATOR = Symbol("lengthCalculator");
      const ALLOW_STALE = Symbol("allowStale");
      const MAX_AGE = Symbol("maxAge");
      const DISPOSE = Symbol("dispose");
      const NO_DISPOSE_ON_SET = Symbol("noDisposeOnSet");
      const LRU_LIST = Symbol("lruList");
      const CACHE = Symbol("cache");
      const UPDATE_AGE_ON_GET = Symbol("updateAgeOnGet");
      const naiveLength = () => 1;
      class LRUCache {
        constructor(options) {
          if (typeof options === "number")
            options = {
              max: options
            };
          if (!options)
            options = {};
          if (options.max && (typeof options.max !== "number" || options.max < 0))
            throw new TypeError("max must be a non-negative number");
          this[MAX] = options.max || Infinity;
          const lc = options.length || naiveLength;
          this[LENGTH_CALCULATOR] = typeof lc !== "function" ? naiveLength : lc;
          this[ALLOW_STALE] = options.stale || false;
          if (options.maxAge && typeof options.maxAge !== "number")
            throw new TypeError("maxAge must be a number");
          this[MAX_AGE] = options.maxAge || 0;
          this[DISPOSE] = options.dispose;
          this[NO_DISPOSE_ON_SET] = options.noDisposeOnSet || false;
          this[UPDATE_AGE_ON_GET] = options.updateAgeOnGet || false;
          this.reset();
        }
        set max(mL) {
          if (typeof mL !== "number" || mL < 0)
            throw new TypeError("max must be a non-negative number");
          this[MAX] = mL || Infinity;
          trim(this);
        }
        get max() {
          return this[MAX];
        }
        set allowStale(allowStale) {
          this[ALLOW_STALE] = !!allowStale;
        }
        get allowStale() {
          return this[ALLOW_STALE];
        }
        set maxAge(mA) {
          if (typeof mA !== "number")
            throw new TypeError("maxAge must be a non-negative number");
          this[MAX_AGE] = mA;
          trim(this);
        }
        get maxAge() {
          return this[MAX_AGE];
        }
        set lengthCalculator(lC) {
          if (typeof lC !== "function")
            lC = naiveLength;
          if (lC !== this[LENGTH_CALCULATOR]) {
            this[LENGTH_CALCULATOR] = lC;
            this[LENGTH] = 0;
            this[LRU_LIST].forEach((hit) => {
              hit.length = this[LENGTH_CALCULATOR](hit.value, hit.key);
              this[LENGTH] += hit.length;
            });
          }
          trim(this);
        }
        get lengthCalculator() {
          return this[LENGTH_CALCULATOR];
        }
        get length() {
          return this[LENGTH];
        }
        get itemCount() {
          return this[LRU_LIST].length;
        }
        rforEach(fn, thisp) {
          thisp = thisp || this;
          for (let walker = this[LRU_LIST].tail; walker !== null; ) {
            const prev = walker.prev;
            forEachStep(this, fn, walker, thisp);
            walker = prev;
          }
        }
        forEach(fn, thisp) {
          thisp = thisp || this;
          for (let walker = this[LRU_LIST].head; walker !== null; ) {
            const next = walker.next;
            forEachStep(this, fn, walker, thisp);
            walker = next;
          }
        }
        keys() {
          return this[LRU_LIST].toArray().map((k) => k.key);
        }
        values() {
          return this[LRU_LIST].toArray().map((k) => k.value);
        }
        reset() {
          if (this[DISPOSE] && this[LRU_LIST] && this[LRU_LIST].length) {
            this[LRU_LIST].forEach((hit) => this[DISPOSE](hit.key, hit.value));
          }
          this[CACHE] = /* @__PURE__ */ new Map();
          this[LRU_LIST] = new Yallist();
          this[LENGTH] = 0;
        }
        dump() {
          return this[LRU_LIST].map((hit) => isStale(this, hit) ? false : {
            k: hit.key,
            v: hit.value,
            e: hit.now + (hit.maxAge || 0)
          }).toArray().filter((h) => h);
        }
        dumpLru() {
          return this[LRU_LIST];
        }
        set(key, value2, maxAge) {
          maxAge = maxAge || this[MAX_AGE];
          if (maxAge && typeof maxAge !== "number")
            throw new TypeError("maxAge must be a number");
          const now = maxAge ? Date.now() : 0;
          const len = this[LENGTH_CALCULATOR](value2, key);
          if (this[CACHE].has(key)) {
            if (len > this[MAX]) {
              del(this, this[CACHE].get(key));
              return false;
            }
            const node = this[CACHE].get(key);
            const item = node.value;
            if (this[DISPOSE]) {
              if (!this[NO_DISPOSE_ON_SET])
                this[DISPOSE](key, item.value);
            }
            item.now = now;
            item.maxAge = maxAge;
            item.value = value2;
            this[LENGTH] += len - item.length;
            item.length = len;
            this.get(key);
            trim(this);
            return true;
          }
          const hit = new Entry(key, value2, len, now, maxAge);
          if (hit.length > this[MAX]) {
            if (this[DISPOSE])
              this[DISPOSE](key, value2);
            return false;
          }
          this[LENGTH] += hit.length;
          this[LRU_LIST].unshift(hit);
          this[CACHE].set(key, this[LRU_LIST].head);
          trim(this);
          return true;
        }
        has(key) {
          if (!this[CACHE].has(key))
            return false;
          const hit = this[CACHE].get(key).value;
          return !isStale(this, hit);
        }
        get(key) {
          return get(this, key, true);
        }
        peek(key) {
          return get(this, key, false);
        }
        pop() {
          const node = this[LRU_LIST].tail;
          if (!node)
            return null;
          del(this, node);
          return node.value;
        }
        del(key) {
          del(this, this[CACHE].get(key));
        }
        load(arr) {
          this.reset();
          const now = Date.now();
          for (let l = arr.length - 1; l >= 0; l--) {
            const hit = arr[l];
            const expiresAt = hit.e || 0;
            if (expiresAt === 0)
              this.set(hit.k, hit.v);
            else {
              const maxAge = expiresAt - now;
              if (maxAge > 0) {
                this.set(hit.k, hit.v, maxAge);
              }
            }
          }
        }
        prune() {
          this[CACHE].forEach((value2, key) => get(this, key, false));
        }
      }
      const get = (self2, key, doUse) => {
        const node = self2[CACHE].get(key);
        if (node) {
          const hit = node.value;
          if (isStale(self2, hit)) {
            del(self2, node);
            if (!self2[ALLOW_STALE])
              return void 0;
          } else {
            if (doUse) {
              if (self2[UPDATE_AGE_ON_GET])
                node.value.now = Date.now();
              self2[LRU_LIST].unshiftNode(node);
            }
          }
          return hit.value;
        }
      };
      const isStale = (self2, hit) => {
        if (!hit || !hit.maxAge && !self2[MAX_AGE])
          return false;
        const diff2 = Date.now() - hit.now;
        return hit.maxAge ? diff2 > hit.maxAge : self2[MAX_AGE] && diff2 > self2[MAX_AGE];
      };
      const trim = (self2) => {
        if (self2[LENGTH] > self2[MAX]) {
          for (let walker = self2[LRU_LIST].tail; self2[LENGTH] > self2[MAX] && walker !== null; ) {
            const prev = walker.prev;
            del(self2, walker);
            walker = prev;
          }
        }
      };
      const del = (self2, node) => {
        if (node) {
          const hit = node.value;
          if (self2[DISPOSE])
            self2[DISPOSE](hit.key, hit.value);
          self2[LENGTH] -= hit.length;
          self2[CACHE].delete(hit.key);
          self2[LRU_LIST].removeNode(node);
        }
      };
      class Entry {
        constructor(key, value2, length, now, maxAge) {
          this.key = key;
          this.value = value2;
          this.length = length;
          this.now = now;
          this.maxAge = maxAge || 0;
        }
      }
      const forEachStep = (self2, fn, node, thisp) => {
        let hit = node.value;
        if (isStale(self2, hit)) {
          del(self2, node);
          if (!self2[ALLOW_STALE])
            hit = void 0;
        }
        if (hit)
          fn.call(thisp, hit.value, hit.key, self2);
      };
      lruCache = LRUCache;
      return lruCache;
    }
    var range;
    var hasRequiredRange;
    function requireRange() {
      if (hasRequiredRange)
        return range;
      hasRequiredRange = 1;
      class Range2 {
        constructor(range2, options) {
          options = parseOptions2(options);
          if (range2 instanceof Range2) {
            if (range2.loose === !!options.loose && range2.includePrerelease === !!options.includePrerelease) {
              return range2;
            } else {
              return new Range2(range2.raw, options);
            }
          }
          if (range2 instanceof Comparator2) {
            this.raw = range2.value;
            this.set = [[range2]];
            this.format();
            return this;
          }
          this.options = options;
          this.loose = !!options.loose;
          this.includePrerelease = !!options.includePrerelease;
          this.raw = range2;
          this.set = range2.split("||").map((r) => this.parseRange(r.trim())).filter((c) => c.length);
          if (!this.set.length) {
            throw new TypeError(`Invalid SemVer Range: ${range2}`);
          }
          if (this.set.length > 1) {
            const first2 = this.set[0];
            this.set = this.set.filter((c) => !isNullSet(c[0]));
            if (this.set.length === 0) {
              this.set = [first2];
            } else if (this.set.length > 1) {
              for (const c of this.set) {
                if (c.length === 1 && isAny(c[0])) {
                  this.set = [c];
                  break;
                }
              }
            }
          }
          this.format();
        }
        format() {
          this.range = this.set.map((comps) => {
            return comps.join(" ").trim();
          }).join("||").trim();
          return this.range;
        }
        toString() {
          return this.range;
        }
        parseRange(range2) {
          range2 = range2.trim();
          const memoOpts = Object.keys(this.options).join(",");
          const memoKey = `parseRange:${memoOpts}:${range2}`;
          const cached = cache.get(memoKey);
          if (cached) {
            return cached;
          }
          const loose = this.options.loose;
          const hr = loose ? re2[t4.HYPHENRANGELOOSE] : re2[t4.HYPHENRANGE];
          range2 = range2.replace(hr, hyphenReplace(this.options.includePrerelease));
          debug2("hyphen replace", range2);
          range2 = range2.replace(re2[t4.COMPARATORTRIM], comparatorTrimReplace);
          debug2("comparator trim", range2);
          range2 = range2.replace(re2[t4.TILDETRIM], tildeTrimReplace);
          range2 = range2.replace(re2[t4.CARETTRIM], caretTrimReplace);
          range2 = range2.split(/\s+/).join(" ");
          let rangeList = range2.split(" ").map((comp) => parseComparator(comp, this.options)).join(" ").split(/\s+/).map((comp) => replaceGTE0(comp, this.options));
          if (loose) {
            rangeList = rangeList.filter((comp) => {
              debug2("loose invalid filter", comp, this.options);
              return !!comp.match(re2[t4.COMPARATORLOOSE]);
            });
          }
          debug2("range list", rangeList);
          const rangeMap = /* @__PURE__ */ new Map();
          const comparators = rangeList.map((comp) => new Comparator2(comp, this.options));
          for (const comp of comparators) {
            if (isNullSet(comp)) {
              return [comp];
            }
            rangeMap.set(comp.value, comp);
          }
          if (rangeMap.size > 1 && rangeMap.has("")) {
            rangeMap.delete("");
          }
          const result = [...rangeMap.values()];
          cache.set(memoKey, result);
          return result;
        }
        intersects(range2, options) {
          if (!(range2 instanceof Range2)) {
            throw new TypeError("a Range is required");
          }
          return this.set.some((thisComparators) => {
            return isSatisfiable(thisComparators, options) && range2.set.some((rangeComparators) => {
              return isSatisfiable(rangeComparators, options) && thisComparators.every((thisComparator) => {
                return rangeComparators.every((rangeComparator) => {
                  return thisComparator.intersects(rangeComparator, options);
                });
              });
            });
          });
        }
        test(version2) {
          if (!version2) {
            return false;
          }
          if (typeof version2 === "string") {
            try {
              version2 = new SemVer2(version2, this.options);
            } catch (er) {
              return false;
            }
          }
          for (let i = 0; i < this.set.length; i++) {
            if (testSet(this.set[i], version2, this.options)) {
              return true;
            }
          }
          return false;
        }
      }
      range = Range2;
      const LRU = requireLruCache();
      const cache = new LRU({
        max: 1e3
      });
      const parseOptions2 = parseOptions_1;
      const Comparator2 = requireComparator();
      const debug2 = debug_1;
      const SemVer2 = semver$2;
      const {
        re: re2,
        t: t4,
        comparatorTrimReplace,
        tildeTrimReplace,
        caretTrimReplace
      } = re$3.exports;
      const isNullSet = (c) => c.value === "<0.0.0-0";
      const isAny = (c) => c.value === "";
      const isSatisfiable = (comparators, options) => {
        let result = true;
        const remainingComparators = comparators.slice();
        let testComparator = remainingComparators.pop();
        while (result && remainingComparators.length) {
          result = remainingComparators.every((otherComparator) => {
            return testComparator.intersects(otherComparator, options);
          });
          testComparator = remainingComparators.pop();
        }
        return result;
      };
      const parseComparator = (comp, options) => {
        debug2("comp", comp, options);
        comp = replaceCarets(comp, options);
        debug2("caret", comp);
        comp = replaceTildes(comp, options);
        debug2("tildes", comp);
        comp = replaceXRanges(comp, options);
        debug2("xrange", comp);
        comp = replaceStars(comp, options);
        debug2("stars", comp);
        return comp;
      };
      const isX = (id) => !id || id.toLowerCase() === "x" || id === "*";
      const replaceTildes = (comp, options) => comp.trim().split(/\s+/).map((c) => {
        return replaceTilde(c, options);
      }).join(" ");
      const replaceTilde = (comp, options) => {
        const r = options.loose ? re2[t4.TILDELOOSE] : re2[t4.TILDE];
        return comp.replace(r, (_, M, m, p, pr) => {
          debug2("tilde", comp, _, M, m, p, pr);
          let ret;
          if (isX(M)) {
            ret = "";
          } else if (isX(m)) {
            ret = `>=${M}.0.0 <${+M + 1}.0.0-0`;
          } else if (isX(p)) {
            ret = `>=${M}.${m}.0 <${M}.${+m + 1}.0-0`;
          } else if (pr) {
            debug2("replaceTilde pr", pr);
            ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;
          } else {
            ret = `>=${M}.${m}.${p} <${M}.${+m + 1}.0-0`;
          }
          debug2("tilde return", ret);
          return ret;
        });
      };
      const replaceCarets = (comp, options) => comp.trim().split(/\s+/).map((c) => {
        return replaceCaret(c, options);
      }).join(" ");
      const replaceCaret = (comp, options) => {
        debug2("caret", comp, options);
        const r = options.loose ? re2[t4.CARETLOOSE] : re2[t4.CARET];
        const z = options.includePrerelease ? "-0" : "";
        return comp.replace(r, (_, M, m, p, pr) => {
          debug2("caret", comp, _, M, m, p, pr);
          let ret;
          if (isX(M)) {
            ret = "";
          } else if (isX(m)) {
            ret = `>=${M}.0.0${z} <${+M + 1}.0.0-0`;
          } else if (isX(p)) {
            if (M === "0") {
              ret = `>=${M}.${m}.0${z} <${M}.${+m + 1}.0-0`;
            } else {
              ret = `>=${M}.${m}.0${z} <${+M + 1}.0.0-0`;
            }
          } else if (pr) {
            debug2("replaceCaret pr", pr);
            if (M === "0") {
              if (m === "0") {
                ret = `>=${M}.${m}.${p}-${pr} <${M}.${m}.${+p + 1}-0`;
              } else {
                ret = `>=${M}.${m}.${p}-${pr} <${M}.${+m + 1}.0-0`;
              }
            } else {
              ret = `>=${M}.${m}.${p}-${pr} <${+M + 1}.0.0-0`;
            }
          } else {
            debug2("no pr");
            if (M === "0") {
              if (m === "0") {
                ret = `>=${M}.${m}.${p}${z} <${M}.${m}.${+p + 1}-0`;
              } else {
                ret = `>=${M}.${m}.${p}${z} <${M}.${+m + 1}.0-0`;
              }
            } else {
              ret = `>=${M}.${m}.${p} <${+M + 1}.0.0-0`;
            }
          }
          debug2("caret return", ret);
          return ret;
        });
      };
      const replaceXRanges = (comp, options) => {
        debug2("replaceXRanges", comp, options);
        return comp.split(/\s+/).map((c) => {
          return replaceXRange(c, options);
        }).join(" ");
      };
      const replaceXRange = (comp, options) => {
        comp = comp.trim();
        const r = options.loose ? re2[t4.XRANGELOOSE] : re2[t4.XRANGE];
        return comp.replace(r, (ret, gtlt, M, m, p, pr) => {
          debug2("xRange", comp, ret, gtlt, M, m, p, pr);
          const xM = isX(M);
          const xm = xM || isX(m);
          const xp = xm || isX(p);
          const anyX = xp;
          if (gtlt === "=" && anyX) {
            gtlt = "";
          }
          pr = options.includePrerelease ? "-0" : "";
          if (xM) {
            if (gtlt === ">" || gtlt === "<") {
              ret = "<0.0.0-0";
            } else {
              ret = "*";
            }
          } else if (gtlt && anyX) {
            if (xm) {
              m = 0;
            }
            p = 0;
            if (gtlt === ">") {
              gtlt = ">=";
              if (xm) {
                M = +M + 1;
                m = 0;
                p = 0;
              } else {
                m = +m + 1;
                p = 0;
              }
            } else if (gtlt === "<=") {
              gtlt = "<";
              if (xm) {
                M = +M + 1;
              } else {
                m = +m + 1;
              }
            }
            if (gtlt === "<") {
              pr = "-0";
            }
            ret = `${gtlt + M}.${m}.${p}${pr}`;
          } else if (xm) {
            ret = `>=${M}.0.0${pr} <${+M + 1}.0.0-0`;
          } else if (xp) {
            ret = `>=${M}.${m}.0${pr} <${M}.${+m + 1}.0-0`;
          }
          debug2("xRange return", ret);
          return ret;
        });
      };
      const replaceStars = (comp, options) => {
        debug2("replaceStars", comp, options);
        return comp.trim().replace(re2[t4.STAR], "");
      };
      const replaceGTE0 = (comp, options) => {
        debug2("replaceGTE0", comp, options);
        return comp.trim().replace(re2[options.includePrerelease ? t4.GTE0PRE : t4.GTE0], "");
      };
      const hyphenReplace = (incPr) => ($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr, tb) => {
        if (isX(fM)) {
          from = "";
        } else if (isX(fm)) {
          from = `>=${fM}.0.0${incPr ? "-0" : ""}`;
        } else if (isX(fp)) {
          from = `>=${fM}.${fm}.0${incPr ? "-0" : ""}`;
        } else if (fpr) {
          from = `>=${from}`;
        } else {
          from = `>=${from}${incPr ? "-0" : ""}`;
        }
        if (isX(tM)) {
          to = "";
        } else if (isX(tm)) {
          to = `<${+tM + 1}.0.0-0`;
        } else if (isX(tp)) {
          to = `<${tM}.${+tm + 1}.0-0`;
        } else if (tpr) {
          to = `<=${tM}.${tm}.${tp}-${tpr}`;
        } else if (incPr) {
          to = `<${tM}.${tm}.${+tp + 1}-0`;
        } else {
          to = `<=${to}`;
        }
        return `${from} ${to}`.trim();
      };
      const testSet = (set, version2, options) => {
        for (let i = 0; i < set.length; i++) {
          if (!set[i].test(version2)) {
            return false;
          }
        }
        if (version2.prerelease.length && !options.includePrerelease) {
          for (let i = 0; i < set.length; i++) {
            debug2(set[i].semver);
            if (set[i].semver === Comparator2.ANY) {
              continue;
            }
            if (set[i].semver.prerelease.length > 0) {
              const allowed = set[i].semver;
              if (allowed.major === version2.major && allowed.minor === version2.minor && allowed.patch === version2.patch) {
                return true;
              }
            }
          }
          return false;
        }
        return true;
      };
      return range;
    }
    var comparator;
    var hasRequiredComparator;
    function requireComparator() {
      if (hasRequiredComparator)
        return comparator;
      hasRequiredComparator = 1;
      const ANY2 = Symbol("SemVer ANY");
      class Comparator2 {
        static get ANY() {
          return ANY2;
        }
        constructor(comp, options) {
          options = parseOptions2(options);
          if (comp instanceof Comparator2) {
            if (comp.loose === !!options.loose) {
              return comp;
            } else {
              comp = comp.value;
            }
          }
          debug2("comparator", comp, options);
          this.options = options;
          this.loose = !!options.loose;
          this.parse(comp);
          if (this.semver === ANY2) {
            this.value = "";
          } else {
            this.value = this.operator + this.semver.version;
          }
          debug2("comp", this);
        }
        parse(comp) {
          const r = this.options.loose ? re2[t4.COMPARATORLOOSE] : re2[t4.COMPARATOR];
          const m = comp.match(r);
          if (!m) {
            throw new TypeError(`Invalid comparator: ${comp}`);
          }
          this.operator = m[1] !== void 0 ? m[1] : "";
          if (this.operator === "=") {
            this.operator = "";
          }
          if (!m[2]) {
            this.semver = ANY2;
          } else {
            this.semver = new SemVer2(m[2], this.options.loose);
          }
        }
        toString() {
          return this.value;
        }
        test(version2) {
          debug2("Comparator.test", version2, this.options.loose);
          if (this.semver === ANY2 || version2 === ANY2) {
            return true;
          }
          if (typeof version2 === "string") {
            try {
              version2 = new SemVer2(version2, this.options);
            } catch (er) {
              return false;
            }
          }
          return cmp2(version2, this.operator, this.semver, this.options);
        }
        intersects(comp, options) {
          if (!(comp instanceof Comparator2)) {
            throw new TypeError("a Comparator is required");
          }
          if (!options || typeof options !== "object") {
            options = {
              loose: !!options,
              includePrerelease: false
            };
          }
          if (this.operator === "") {
            if (this.value === "") {
              return true;
            }
            return new Range2(comp.value, options).test(this.value);
          } else if (comp.operator === "") {
            if (comp.value === "") {
              return true;
            }
            return new Range2(this.value, options).test(comp.semver);
          }
          const sameDirectionIncreasing = (this.operator === ">=" || this.operator === ">") && (comp.operator === ">=" || comp.operator === ">");
          const sameDirectionDecreasing = (this.operator === "<=" || this.operator === "<") && (comp.operator === "<=" || comp.operator === "<");
          const sameSemVer = this.semver.version === comp.semver.version;
          const differentDirectionsInclusive = (this.operator === ">=" || this.operator === "<=") && (comp.operator === ">=" || comp.operator === "<=");
          const oppositeDirectionsLessThan = cmp2(this.semver, "<", comp.semver, options) && (this.operator === ">=" || this.operator === ">") && (comp.operator === "<=" || comp.operator === "<");
          const oppositeDirectionsGreaterThan = cmp2(this.semver, ">", comp.semver, options) && (this.operator === "<=" || this.operator === "<") && (comp.operator === ">=" || comp.operator === ">");
          return sameDirectionIncreasing || sameDirectionDecreasing || sameSemVer && differentDirectionsInclusive || oppositeDirectionsLessThan || oppositeDirectionsGreaterThan;
        }
      }
      comparator = Comparator2;
      const parseOptions2 = parseOptions_1;
      const {
        re: re2,
        t: t4
      } = re$3.exports;
      const cmp2 = cmp_1;
      const debug2 = debug_1;
      const SemVer2 = semver$2;
      const Range2 = requireRange();
      return comparator;
    }
    var Range$8 = requireRange();
    var satisfies$3 = (version2, range2, options) => {
      try {
        range2 = new Range$8(range2, options);
      } catch (er) {
        return false;
      }
      return range2.test(version2);
    };
    var satisfies_1 = satisfies$3;
    var Range$7 = requireRange();
    var toComparators = (range2, options) => new Range$7(range2, options).set.map((comp) => comp.map((c) => c.value).join(" ").trim().split(" "));
    var toComparators_1 = toComparators;
    var SemVer$3 = semver$2;
    var Range$6 = requireRange();
    var maxSatisfying = (versions, range2, options) => {
      let max2 = null;
      let maxSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range$6(range2, options);
      } catch (er) {
        return null;
      }
      versions.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!max2 || maxSV.compare(v) === -1) {
            max2 = v;
            maxSV = new SemVer$3(max2, options);
          }
        }
      });
      return max2;
    };
    var maxSatisfying_1 = maxSatisfying;
    var SemVer$2 = semver$2;
    var Range$5 = requireRange();
    var minSatisfying = (versions, range2, options) => {
      let min2 = null;
      let minSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range$5(range2, options);
      } catch (er) {
        return null;
      }
      versions.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!min2 || minSV.compare(v) === 1) {
            min2 = v;
            minSV = new SemVer$2(min2, options);
          }
        }
      });
      return min2;
    };
    var minSatisfying_1 = minSatisfying;
    var SemVer$1 = semver$2;
    var Range$4 = requireRange();
    var gt$1 = gt_1;
    var minVersion = (range2, loose) => {
      range2 = new Range$4(range2, loose);
      let minver = new SemVer$1("0.0.0");
      if (range2.test(minver)) {
        return minver;
      }
      minver = new SemVer$1("0.0.0-0");
      if (range2.test(minver)) {
        return minver;
      }
      minver = null;
      for (let i = 0; i < range2.set.length; ++i) {
        const comparators = range2.set[i];
        let setMin = null;
        comparators.forEach((comparator2) => {
          const compver = new SemVer$1(comparator2.semver.version);
          switch (comparator2.operator) {
            case ">":
              if (compver.prerelease.length === 0) {
                compver.patch++;
              } else {
                compver.prerelease.push(0);
              }
              compver.raw = compver.format();
            case "":
            case ">=":
              if (!setMin || gt$1(compver, setMin)) {
                setMin = compver;
              }
              break;
            case "<":
            case "<=":
              break;
            default:
              throw new Error(`Unexpected operation: ${comparator2.operator}`);
          }
        });
        if (setMin && (!minver || gt$1(minver, setMin))) {
          minver = setMin;
        }
      }
      if (minver && range2.test(minver)) {
        return minver;
      }
      return null;
    };
    var minVersion_1 = minVersion;
    var Range$3 = requireRange();
    var validRange = (range2, options) => {
      try {
        return new Range$3(range2, options).range || "*";
      } catch (er) {
        return null;
      }
    };
    var valid = validRange;
    var SemVer = semver$2;
    var Comparator$1 = requireComparator();
    var {
      ANY: ANY$1
    } = Comparator$1;
    var Range$2 = requireRange();
    var satisfies$2 = satisfies_1;
    var gt = gt_1;
    var lt = lt_1;
    var lte = lte_1;
    var gte = gte_1;
    var outside$2 = (version2, range2, hilo, options) => {
      version2 = new SemVer(version2, options);
      range2 = new Range$2(range2, options);
      let gtfn, ltefn, ltfn, comp, ecomp;
      switch (hilo) {
        case ">":
          gtfn = gt;
          ltefn = lte;
          ltfn = lt;
          comp = ">";
          ecomp = ">=";
          break;
        case "<":
          gtfn = lt;
          ltefn = gte;
          ltfn = gt;
          comp = "<";
          ecomp = "<=";
          break;
        default:
          throw new TypeError('Must provide a hilo val of "<" or ">"');
      }
      if (satisfies$2(version2, range2, options)) {
        return false;
      }
      for (let i = 0; i < range2.set.length; ++i) {
        const comparators = range2.set[i];
        let high = null;
        let low = null;
        comparators.forEach((comparator2) => {
          if (comparator2.semver === ANY$1) {
            comparator2 = new Comparator$1(">=0.0.0");
          }
          high = high || comparator2;
          low = low || comparator2;
          if (gtfn(comparator2.semver, high.semver, options)) {
            high = comparator2;
          } else if (ltfn(comparator2.semver, low.semver, options)) {
            low = comparator2;
          }
        });
        if (high.operator === comp || high.operator === ecomp) {
          return false;
        }
        if ((!low.operator || low.operator === comp) && ltefn(version2, low.semver)) {
          return false;
        } else if (low.operator === ecomp && ltfn(version2, low.semver)) {
          return false;
        }
      }
      return true;
    };
    var outside_1 = outside$2;
    var outside$1 = outside_1;
    var gtr = (version2, range2, options) => outside$1(version2, range2, ">", options);
    var gtr_1 = gtr;
    var outside = outside_1;
    var ltr = (version2, range2, options) => outside(version2, range2, "<", options);
    var ltr_1 = ltr;
    var Range$1 = requireRange();
    var intersects = (r1, r2, options) => {
      r1 = new Range$1(r1, options);
      r2 = new Range$1(r2, options);
      return r1.intersects(r2);
    };
    var intersects_1 = intersects;
    var satisfies$1 = satisfies_1;
    var compare$1 = compare_1;
    var simplify = (versions, range2, options) => {
      const set = [];
      let first2 = null;
      let prev = null;
      const v = versions.sort((a, b) => compare$1(a, b, options));
      for (const version2 of v) {
        const included = satisfies$1(version2, range2, options);
        if (included) {
          prev = version2;
          if (!first2) {
            first2 = version2;
          }
        } else {
          if (prev) {
            set.push([first2, prev]);
          }
          prev = null;
          first2 = null;
        }
      }
      if (first2) {
        set.push([first2, null]);
      }
      const ranges = [];
      for (const [min2, max2] of set) {
        if (min2 === max2) {
          ranges.push(min2);
        } else if (!max2 && min2 === v[0]) {
          ranges.push("*");
        } else if (!max2) {
          ranges.push(`>=${min2}`);
        } else if (min2 === v[0]) {
          ranges.push(`<=${max2}`);
        } else {
          ranges.push(`${min2} - ${max2}`);
        }
      }
      const simplified = ranges.join(" || ");
      const original = typeof range2.raw === "string" ? range2.raw : String(range2);
      return simplified.length < original.length ? simplified : range2;
    };
    var Range = requireRange();
    var Comparator = requireComparator();
    var {
      ANY
    } = Comparator;
    var satisfies = satisfies_1;
    var compare = compare_1;
    var subset = (sub, dom, options = {}) => {
      if (sub === dom) {
        return true;
      }
      sub = new Range(sub, options);
      dom = new Range(dom, options);
      let sawNonNull = false;
      OUTER:
        for (const simpleSub of sub.set) {
          for (const simpleDom of dom.set) {
            const isSub = simpleSubset(simpleSub, simpleDom, options);
            sawNonNull = sawNonNull || isSub !== null;
            if (isSub) {
              continue OUTER;
            }
          }
          if (sawNonNull) {
            return false;
          }
        }
      return true;
    };
    var simpleSubset = (sub, dom, options) => {
      if (sub === dom) {
        return true;
      }
      if (sub.length === 1 && sub[0].semver === ANY) {
        if (dom.length === 1 && dom[0].semver === ANY) {
          return true;
        } else if (options.includePrerelease) {
          sub = [new Comparator(">=0.0.0-0")];
        } else {
          sub = [new Comparator(">=0.0.0")];
        }
      }
      if (dom.length === 1 && dom[0].semver === ANY) {
        if (options.includePrerelease) {
          return true;
        } else {
          dom = [new Comparator(">=0.0.0")];
        }
      }
      const eqSet = /* @__PURE__ */ new Set();
      let gt2, lt2;
      for (const c of sub) {
        if (c.operator === ">" || c.operator === ">=") {
          gt2 = higherGT(gt2, c, options);
        } else if (c.operator === "<" || c.operator === "<=") {
          lt2 = lowerLT(lt2, c, options);
        } else {
          eqSet.add(c.semver);
        }
      }
      if (eqSet.size > 1) {
        return null;
      }
      let gtltComp;
      if (gt2 && lt2) {
        gtltComp = compare(gt2.semver, lt2.semver, options);
        if (gtltComp > 0) {
          return null;
        } else if (gtltComp === 0 && (gt2.operator !== ">=" || lt2.operator !== "<=")) {
          return null;
        }
      }
      for (const eq2 of eqSet) {
        if (gt2 && !satisfies(eq2, String(gt2), options)) {
          return null;
        }
        if (lt2 && !satisfies(eq2, String(lt2), options)) {
          return null;
        }
        for (const c of dom) {
          if (!satisfies(eq2, String(c), options)) {
            return false;
          }
        }
        return true;
      }
      let higher, lower;
      let hasDomLT, hasDomGT;
      let needDomLTPre = lt2 && !options.includePrerelease && lt2.semver.prerelease.length ? lt2.semver : false;
      let needDomGTPre = gt2 && !options.includePrerelease && gt2.semver.prerelease.length ? gt2.semver : false;
      if (needDomLTPre && needDomLTPre.prerelease.length === 1 && lt2.operator === "<" && needDomLTPre.prerelease[0] === 0) {
        needDomLTPre = false;
      }
      for (const c of dom) {
        hasDomGT = hasDomGT || c.operator === ">" || c.operator === ">=";
        hasDomLT = hasDomLT || c.operator === "<" || c.operator === "<=";
        if (gt2) {
          if (needDomGTPre) {
            if (c.semver.prerelease && c.semver.prerelease.length && c.semver.major === needDomGTPre.major && c.semver.minor === needDomGTPre.minor && c.semver.patch === needDomGTPre.patch) {
              needDomGTPre = false;
            }
          }
          if (c.operator === ">" || c.operator === ">=") {
            higher = higherGT(gt2, c, options);
            if (higher === c && higher !== gt2) {
              return false;
            }
          } else if (gt2.operator === ">=" && !satisfies(gt2.semver, String(c), options)) {
            return false;
          }
        }
        if (lt2) {
          if (needDomLTPre) {
            if (c.semver.prerelease && c.semver.prerelease.length && c.semver.major === needDomLTPre.major && c.semver.minor === needDomLTPre.minor && c.semver.patch === needDomLTPre.patch) {
              needDomLTPre = false;
            }
          }
          if (c.operator === "<" || c.operator === "<=") {
            lower = lowerLT(lt2, c, options);
            if (lower === c && lower !== lt2) {
              return false;
            }
          } else if (lt2.operator === "<=" && !satisfies(lt2.semver, String(c), options)) {
            return false;
          }
        }
        if (!c.operator && (lt2 || gt2) && gtltComp !== 0) {
          return false;
        }
      }
      if (gt2 && hasDomLT && !lt2 && gtltComp !== 0) {
        return false;
      }
      if (lt2 && hasDomGT && !gt2 && gtltComp !== 0) {
        return false;
      }
      if (needDomGTPre || needDomLTPre) {
        return false;
      }
      return true;
    };
    var higherGT = (a, b, options) => {
      if (!a) {
        return b;
      }
      const comp = compare(a.semver, b.semver, options);
      return comp > 0 ? a : comp < 0 ? b : b.operator === ">" && a.operator === ">=" ? b : a;
    };
    var lowerLT = (a, b, options) => {
      if (!a) {
        return b;
      }
      const comp = compare(a.semver, b.semver, options);
      return comp < 0 ? a : comp > 0 ? b : b.operator === "<" && a.operator === "<=" ? b : a;
    };
    var subset_1 = subset;
    var internalRe = re$3.exports;
    var semver$1 = {
      re: internalRe.re,
      src: internalRe.src,
      tokens: internalRe.t,
      SEMVER_SPEC_VERSION: constants.SEMVER_SPEC_VERSION,
      SemVer: semver$2,
      compareIdentifiers: identifiers.compareIdentifiers,
      rcompareIdentifiers: identifiers.rcompareIdentifiers,
      parse: parse_1,
      valid: valid_1,
      clean: clean_1,
      inc: inc_1,
      diff: diff_1,
      major: major_1,
      minor: minor_1,
      patch: patch_1,
      prerelease: prerelease_1,
      compare: compare_1,
      rcompare: rcompare_1,
      compareLoose: compareLoose_1,
      compareBuild: compareBuild_1,
      sort: sort_1,
      rsort: rsort_1,
      gt: gt_1,
      lt: lt_1,
      eq: eq_1,
      neq: neq_1,
      gte: gte_1,
      lte: lte_1,
      cmp: cmp_1,
      coerce: coerce_1,
      Comparator: requireComparator(),
      Range: requireRange(),
      satisfies: satisfies_1,
      toComparators: toComparators_1,
      maxSatisfying: maxSatisfying_1,
      minSatisfying: minSatisfying_1,
      minVersion: minVersion_1,
      validRange: valid,
      outside: outside_1,
      gtr: gtr_1,
      ltr: ltr_1,
      intersects: intersects_1,
      simplifyRange: simplify,
      subset: subset_1
    };
    var semver = semver$1;
    var builtins = function({
      version: version2 = process.version,
      experimental = false
    } = {}) {
      var coreModules = ["assert", "buffer", "child_process", "cluster", "console", "constants", "crypto", "dgram", "dns", "domain", "events", "fs", "http", "https", "module", "net", "os", "path", "punycode", "querystring", "readline", "repl", "stream", "string_decoder", "sys", "timers", "tls", "tty", "url", "util", "vm", "zlib"];
      if (semver.lt(version2, "6.0.0"))
        coreModules.push("freelist");
      if (semver.gte(version2, "1.0.0"))
        coreModules.push("v8");
      if (semver.gte(version2, "1.1.0"))
        coreModules.push("process");
      if (semver.gte(version2, "8.0.0"))
        coreModules.push("inspector");
      if (semver.gte(version2, "8.1.0"))
        coreModules.push("async_hooks");
      if (semver.gte(version2, "8.4.0"))
        coreModules.push("http2");
      if (semver.gte(version2, "8.5.0"))
        coreModules.push("perf_hooks");
      if (semver.gte(version2, "10.0.0"))
        coreModules.push("trace_events");
      if (semver.gte(version2, "10.5.0") && (experimental || semver.gte(version2, "12.0.0"))) {
        coreModules.push("worker_threads");
      }
      if (semver.gte(version2, "12.16.0") && experimental) {
        coreModules.push("wasi");
      }
      return coreModules;
    };
    var reader = {
      read
    };
    function read(jsonPath) {
      return find(_path().dirname(jsonPath));
    }
    function find(dir) {
      try {
        const string = _fs().default.readFileSync(_path().toNamespacedPath(_path().join(dir, "package.json")), "utf8");
        return {
          string
        };
      } catch (error) {
        if (error.code === "ENOENT") {
          const parent = _path().dirname(dir);
          if (dir !== parent)
            return find(parent);
          return {
            string: void 0
          };
        }
        throw error;
      }
    }
    var isWindows = process.platform === "win32";
    var own$1 = {}.hasOwnProperty;
    var codes = {};
    var messages = /* @__PURE__ */ new Map();
    var nodeInternalPrefix = "__node_internal_";
    var userStackTraceLimit;
    codes.ERR_INVALID_MODULE_SPECIFIER = createError("ERR_INVALID_MODULE_SPECIFIER", (request, reason, base = void 0) => {
      return `Invalid module "${request}" ${reason}${base ? ` imported from ${base}` : ""}`;
    }, TypeError);
    codes.ERR_INVALID_PACKAGE_CONFIG = createError("ERR_INVALID_PACKAGE_CONFIG", (path2, base, message) => {
      return `Invalid package config ${path2}${base ? ` while importing ${base}` : ""}${message ? `. ${message}` : ""}`;
    }, Error);
    codes.ERR_INVALID_PACKAGE_TARGET = createError("ERR_INVALID_PACKAGE_TARGET", (pkgPath, key, target, isImport = false, base = void 0) => {
      const relError = typeof target === "string" && !isImport && target.length > 0 && !target.startsWith("./");
      if (key === ".") {
        _assert()(isImport === false);
        return `Invalid "exports" main target ${JSON.stringify(target)} defined in the package config ${pkgPath}package.json${base ? ` imported from ${base}` : ""}${relError ? '; targets must start with "./"' : ""}`;
      }
      return `Invalid "${isImport ? "imports" : "exports"}" target ${JSON.stringify(target)} defined for '${key}' in the package config ${pkgPath}package.json${base ? ` imported from ${base}` : ""}${relError ? '; targets must start with "./"' : ""}`;
    }, Error);
    codes.ERR_MODULE_NOT_FOUND = createError("ERR_MODULE_NOT_FOUND", (path2, base, type = "package") => {
      return `Cannot find ${type} '${path2}' imported from ${base}`;
    }, Error);
    codes.ERR_PACKAGE_IMPORT_NOT_DEFINED = createError("ERR_PACKAGE_IMPORT_NOT_DEFINED", (specifier, packagePath, base) => {
      return `Package import specifier "${specifier}" is not defined${packagePath ? ` in package ${packagePath}package.json` : ""} imported from ${base}`;
    }, TypeError);
    codes.ERR_PACKAGE_PATH_NOT_EXPORTED = createError("ERR_PACKAGE_PATH_NOT_EXPORTED", (pkgPath, subpath, base = void 0) => {
      if (subpath === ".")
        return `No "exports" main defined in ${pkgPath}package.json${base ? ` imported from ${base}` : ""}`;
      return `Package subpath '${subpath}' is not defined by "exports" in ${pkgPath}package.json${base ? ` imported from ${base}` : ""}`;
    }, Error);
    codes.ERR_UNSUPPORTED_DIR_IMPORT = createError("ERR_UNSUPPORTED_DIR_IMPORT", "Directory import '%s' is not supported resolving ES modules imported from %s", Error);
    codes.ERR_UNKNOWN_FILE_EXTENSION = createError("ERR_UNKNOWN_FILE_EXTENSION", 'Unknown file extension "%s" for %s', TypeError);
    codes.ERR_INVALID_ARG_VALUE = createError("ERR_INVALID_ARG_VALUE", (name, value2, reason = "is invalid") => {
      let inspected = (0, _util().inspect)(value2);
      if (inspected.length > 128) {
        inspected = `${inspected.slice(0, 128)}...`;
      }
      const type = name.includes(".") ? "property" : "argument";
      return `The ${type} '${name}' ${reason}. Received ${inspected}`;
    }, TypeError);
    codes.ERR_UNSUPPORTED_ESM_URL_SCHEME = createError("ERR_UNSUPPORTED_ESM_URL_SCHEME", (url) => {
      let message = "Only file and data URLs are supported by the default ESM loader";
      if (isWindows && url.protocol.length === 2) {
        message += ". On Windows, absolute paths must be valid file:// URLs";
      }
      message += `. Received protocol '${url.protocol}'`;
      return message;
    }, Error);
    function createError(sym, value2, def) {
      messages.set(sym, value2);
      return makeNodeErrorWithCode(def, sym);
    }
    function makeNodeErrorWithCode(Base, key) {
      return NodeError;
      function NodeError(...args) {
        const limit = Error.stackTraceLimit;
        if (isErrorStackTraceLimitWritable())
          Error.stackTraceLimit = 0;
        const error = new Base();
        if (isErrorStackTraceLimitWritable())
          Error.stackTraceLimit = limit;
        const message = getMessage(key, args, error);
        Object.defineProperty(error, "message", {
          value: message,
          enumerable: false,
          writable: true,
          configurable: true
        });
        Object.defineProperty(error, "toString", {
          value() {
            return `${this.name} [${key}]: ${this.message}`;
          },
          enumerable: false,
          writable: true,
          configurable: true
        });
        addCodeToName(error, Base.name, key);
        error.code = key;
        return error;
      }
    }
    var addCodeToName = hideStackFrames(function(error, name, code) {
      error = captureLargerStackTrace(error);
      error.name = `${name} [${code}]`;
      error.stack;
      if (name === "SystemError") {
        Object.defineProperty(error, "name", {
          value: name,
          enumerable: false,
          writable: true,
          configurable: true
        });
      } else {
        delete error.name;
      }
    });
    function isErrorStackTraceLimitWritable() {
      const desc = Object.getOwnPropertyDescriptor(Error, "stackTraceLimit");
      if (desc === void 0) {
        return Object.isExtensible(Error);
      }
      return own$1.call(desc, "writable") ? desc.writable : desc.set !== void 0;
    }
    function hideStackFrames(fn) {
      const hidden = nodeInternalPrefix + fn.name;
      Object.defineProperty(fn, "name", {
        value: hidden
      });
      return fn;
    }
    var captureLargerStackTrace = hideStackFrames(function(error) {
      const stackTraceLimitIsWritable = isErrorStackTraceLimitWritable();
      if (stackTraceLimitIsWritable) {
        userStackTraceLimit = Error.stackTraceLimit;
        Error.stackTraceLimit = Number.POSITIVE_INFINITY;
      }
      Error.captureStackTrace(error);
      if (stackTraceLimitIsWritable)
        Error.stackTraceLimit = userStackTraceLimit;
      return error;
    });
    function getMessage(key, args, self2) {
      const message = messages.get(key);
      if (typeof message === "function") {
        _assert()(message.length <= args.length, `Code: ${key}; The provided arguments length (${args.length}) does not match the required ones (${message.length}).`);
        return Reflect.apply(message, self2, args);
      }
      const expectedLength = (message.match(/%[dfijoOs]/g) || []).length;
      _assert()(expectedLength === args.length, `Code: ${key}; The provided arguments length (${args.length}) does not match the required ones (${expectedLength}).`);
      if (args.length === 0)
        return message;
      args.unshift(message);
      return Reflect.apply(_util().format, null, args);
    }
    var {
      ERR_UNKNOWN_FILE_EXTENSION
    } = codes;
    var extensionFormatMap = {
      __proto__: null,
      ".cjs": "commonjs",
      ".js": "module",
      ".mjs": "module"
    };
    function defaultGetFormat(url) {
      if (url.startsWith("node:")) {
        return {
          format: "builtin"
        };
      }
      const parsed = new (_url()).URL(url);
      if (parsed.protocol === "data:") {
        const {
          1: mime
        } = /^([^/]+\/[^;,]+)[^,]*?(;base64)?,/.exec(parsed.pathname) || [null, null];
        const format2 = mime === "text/javascript" ? "module" : null;
        return {
          format: format2
        };
      }
      if (parsed.protocol === "file:") {
        const ext = _path().extname(parsed.pathname);
        let format2;
        if (ext === ".js") {
          format2 = getPackageType(parsed.href) === "module" ? "module" : "commonjs";
        } else {
          format2 = extensionFormatMap[ext];
        }
        if (!format2) {
          throw new ERR_UNKNOWN_FILE_EXTENSION(ext, (0, _url().fileURLToPath)(url));
        }
        return {
          format: format2 || null
        };
      }
      return {
        format: null
      };
    }
    var listOfBuiltins = builtins();
    var {
      ERR_INVALID_MODULE_SPECIFIER,
      ERR_INVALID_PACKAGE_CONFIG,
      ERR_INVALID_PACKAGE_TARGET,
      ERR_MODULE_NOT_FOUND,
      ERR_PACKAGE_IMPORT_NOT_DEFINED,
      ERR_PACKAGE_PATH_NOT_EXPORTED,
      ERR_UNSUPPORTED_DIR_IMPORT,
      ERR_UNSUPPORTED_ESM_URL_SCHEME,
      ERR_INVALID_ARG_VALUE
    } = codes;
    var own = {}.hasOwnProperty;
    var DEFAULT_CONDITIONS = Object.freeze(["node", "import"]);
    var DEFAULT_CONDITIONS_SET = new Set(DEFAULT_CONDITIONS);
    var invalidSegmentRegEx = /(^|\\|\/)(\.\.?|node_modules)(\\|\/|$)/;
    var patternRegEx = /\*/g;
    var encodedSepRegEx = /%2f|%2c/i;
    var emittedPackageWarnings = /* @__PURE__ */ new Set();
    var packageJsonCache = /* @__PURE__ */ new Map();
    function emitFolderMapDeprecation(match, pjsonUrl, isExports, base) {
      const pjsonPath = (0, _url().fileURLToPath)(pjsonUrl);
      if (emittedPackageWarnings.has(pjsonPath + "|" + match))
        return;
      emittedPackageWarnings.add(pjsonPath + "|" + match);
      process.emitWarning(`Use of deprecated folder mapping "${match}" in the ${isExports ? '"exports"' : '"imports"'} field module resolution of the package at ${pjsonPath}${base ? ` imported from ${(0, _url().fileURLToPath)(base)}` : ""}.
Update this package.json to use a subpath pattern like "${match}*".`, "DeprecationWarning", "DEP0148");
    }
    function emitLegacyIndexDeprecation(url, packageJsonUrl, base, main) {
      const {
        format: format2
      } = defaultGetFormat(url.href);
      if (format2 !== "module")
        return;
      const path2 = (0, _url().fileURLToPath)(url.href);
      const pkgPath = (0, _url().fileURLToPath)(new (_url()).URL(".", packageJsonUrl));
      const basePath = (0, _url().fileURLToPath)(base);
      if (main)
        process.emitWarning(`Package ${pkgPath} has a "main" field set to ${JSON.stringify(main)}, excluding the full filename and extension to the resolved file at "${path2.slice(pkgPath.length)}", imported from ${basePath}.
 Automatic extension resolution of the "main" field isdeprecated for ES modules.`, "DeprecationWarning", "DEP0151");
      else
        process.emitWarning(`No "main" or "exports" field defined in the package.json for ${pkgPath} resolving the main entry point "${path2.slice(pkgPath.length)}", imported from ${basePath}.
Default "index" lookups for the main are deprecated for ES modules.`, "DeprecationWarning", "DEP0151");
    }
    function getConditionsSet(conditions) {
      if (conditions !== void 0 && conditions !== DEFAULT_CONDITIONS) {
        if (!Array.isArray(conditions)) {
          throw new ERR_INVALID_ARG_VALUE("conditions", conditions, "expected an array");
        }
        return new Set(conditions);
      }
      return DEFAULT_CONDITIONS_SET;
    }
    function tryStatSync(path2) {
      try {
        return (0, _fs().statSync)(path2);
      } catch (_unused) {
        return new (_fs()).Stats();
      }
    }
    function getPackageConfig(path2, specifier, base) {
      const existing = packageJsonCache.get(path2);
      if (existing !== void 0) {
        return existing;
      }
      const source = reader.read(path2).string;
      if (source === void 0) {
        const packageConfig2 = {
          pjsonPath: path2,
          exists: false,
          main: void 0,
          name: void 0,
          type: "none",
          exports: void 0,
          imports: void 0
        };
        packageJsonCache.set(path2, packageConfig2);
        return packageConfig2;
      }
      let packageJson;
      try {
        packageJson = JSON.parse(source);
      } catch (error) {
        throw new ERR_INVALID_PACKAGE_CONFIG(path2, (base ? `"${specifier}" from ` : "") + (0, _url().fileURLToPath)(base || specifier), error.message);
      }
      const {
        exports: exports2,
        imports,
        main,
        name,
        type
      } = packageJson;
      const packageConfig = {
        pjsonPath: path2,
        exists: true,
        main: typeof main === "string" ? main : void 0,
        name: typeof name === "string" ? name : void 0,
        type: type === "module" || type === "commonjs" ? type : "none",
        exports: exports2,
        imports: imports && typeof imports === "object" ? imports : void 0
      };
      packageJsonCache.set(path2, packageConfig);
      return packageConfig;
    }
    function getPackageScopeConfig(resolved) {
      let packageJsonUrl = new (_url()).URL("./package.json", resolved);
      while (true) {
        const packageJsonPath2 = packageJsonUrl.pathname;
        if (packageJsonPath2.endsWith("node_modules/package.json"))
          break;
        const packageConfig2 = getPackageConfig((0, _url().fileURLToPath)(packageJsonUrl), resolved);
        if (packageConfig2.exists)
          return packageConfig2;
        const lastPackageJsonUrl = packageJsonUrl;
        packageJsonUrl = new (_url()).URL("../package.json", packageJsonUrl);
        if (packageJsonUrl.pathname === lastPackageJsonUrl.pathname)
          break;
      }
      const packageJsonPath = (0, _url().fileURLToPath)(packageJsonUrl);
      const packageConfig = {
        pjsonPath: packageJsonPath,
        exists: false,
        main: void 0,
        name: void 0,
        type: "none",
        exports: void 0,
        imports: void 0
      };
      packageJsonCache.set(packageJsonPath, packageConfig);
      return packageConfig;
    }
    function fileExists(url) {
      return tryStatSync((0, _url().fileURLToPath)(url)).isFile();
    }
    function legacyMainResolve(packageJsonUrl, packageConfig, base) {
      let guess;
      if (packageConfig.main !== void 0) {
        guess = new (_url()).URL(`./${packageConfig.main}`, packageJsonUrl);
        if (fileExists(guess))
          return guess;
        const tries2 = [`./${packageConfig.main}.js`, `./${packageConfig.main}.json`, `./${packageConfig.main}.node`, `./${packageConfig.main}/index.js`, `./${packageConfig.main}/index.json`, `./${packageConfig.main}/index.node`];
        let i2 = -1;
        while (++i2 < tries2.length) {
          guess = new (_url()).URL(tries2[i2], packageJsonUrl);
          if (fileExists(guess))
            break;
          guess = void 0;
        }
        if (guess) {
          emitLegacyIndexDeprecation(guess, packageJsonUrl, base, packageConfig.main);
          return guess;
        }
      }
      const tries = ["./index.js", "./index.json", "./index.node"];
      let i = -1;
      while (++i < tries.length) {
        guess = new (_url()).URL(tries[i], packageJsonUrl);
        if (fileExists(guess))
          break;
        guess = void 0;
      }
      if (guess) {
        emitLegacyIndexDeprecation(guess, packageJsonUrl, base, packageConfig.main);
        return guess;
      }
      throw new ERR_MODULE_NOT_FOUND((0, _url().fileURLToPath)(new (_url()).URL(".", packageJsonUrl)), (0, _url().fileURLToPath)(base));
    }
    function finalizeResolution(resolved, base) {
      if (encodedSepRegEx.test(resolved.pathname))
        throw new ERR_INVALID_MODULE_SPECIFIER(resolved.pathname, 'must not include encoded "/" or "\\" characters', (0, _url().fileURLToPath)(base));
      const path2 = (0, _url().fileURLToPath)(resolved);
      const stats = tryStatSync(path2.endsWith("/") ? path2.slice(-1) : path2);
      if (stats.isDirectory()) {
        const error = new ERR_UNSUPPORTED_DIR_IMPORT(path2, (0, _url().fileURLToPath)(base));
        error.url = String(resolved);
        throw error;
      }
      if (!stats.isFile()) {
        throw new ERR_MODULE_NOT_FOUND(path2 || resolved.pathname, base && (0, _url().fileURLToPath)(base), "module");
      }
      return resolved;
    }
    function throwImportNotDefined(specifier, packageJsonUrl, base) {
      throw new ERR_PACKAGE_IMPORT_NOT_DEFINED(specifier, packageJsonUrl && (0, _url().fileURLToPath)(new (_url()).URL(".", packageJsonUrl)), (0, _url().fileURLToPath)(base));
    }
    function throwExportsNotFound(subpath, packageJsonUrl, base) {
      throw new ERR_PACKAGE_PATH_NOT_EXPORTED((0, _url().fileURLToPath)(new (_url()).URL(".", packageJsonUrl)), subpath, base && (0, _url().fileURLToPath)(base));
    }
    function throwInvalidSubpath(subpath, packageJsonUrl, internal, base) {
      const reason = `request is not a valid subpath for the "${internal ? "imports" : "exports"}" resolution of ${(0, _url().fileURLToPath)(packageJsonUrl)}`;
      throw new ERR_INVALID_MODULE_SPECIFIER(subpath, reason, base && (0, _url().fileURLToPath)(base));
    }
    function throwInvalidPackageTarget(subpath, target, packageJsonUrl, internal, base) {
      target = typeof target === "object" && target !== null ? JSON.stringify(target, null, "") : `${target}`;
      throw new ERR_INVALID_PACKAGE_TARGET((0, _url().fileURLToPath)(new (_url()).URL(".", packageJsonUrl)), subpath, target, internal, base && (0, _url().fileURLToPath)(base));
    }
    function resolvePackageTargetString(target, subpath, match, packageJsonUrl, base, pattern, internal, conditions) {
      if (subpath !== "" && !pattern && target[target.length - 1] !== "/")
        throwInvalidPackageTarget(match, target, packageJsonUrl, internal, base);
      if (!target.startsWith("./")) {
        if (internal && !target.startsWith("../") && !target.startsWith("/")) {
          let isURL = false;
          try {
            new (_url()).URL(target);
            isURL = true;
          } catch (_unused2) {
          }
          if (!isURL) {
            const exportTarget = pattern ? target.replace(patternRegEx, subpath) : target + subpath;
            return packageResolve(exportTarget, packageJsonUrl, conditions);
          }
        }
        throwInvalidPackageTarget(match, target, packageJsonUrl, internal, base);
      }
      if (invalidSegmentRegEx.test(target.slice(2)))
        throwInvalidPackageTarget(match, target, packageJsonUrl, internal, base);
      const resolved = new (_url()).URL(target, packageJsonUrl);
      const resolvedPath = resolved.pathname;
      const packagePath = new (_url()).URL(".", packageJsonUrl).pathname;
      if (!resolvedPath.startsWith(packagePath))
        throwInvalidPackageTarget(match, target, packageJsonUrl, internal, base);
      if (subpath === "")
        return resolved;
      if (invalidSegmentRegEx.test(subpath))
        throwInvalidSubpath(match + subpath, packageJsonUrl, internal, base);
      if (pattern)
        return new (_url()).URL(resolved.href.replace(patternRegEx, subpath));
      return new (_url()).URL(subpath, resolved);
    }
    function isArrayIndex(key) {
      const keyNumber = Number(key);
      if (`${keyNumber}` !== key)
        return false;
      return keyNumber >= 0 && keyNumber < 4294967295;
    }
    function resolvePackageTarget(packageJsonUrl, target, subpath, packageSubpath, base, pattern, internal, conditions) {
      if (typeof target === "string") {
        return resolvePackageTargetString(target, subpath, packageSubpath, packageJsonUrl, base, pattern, internal, conditions);
      }
      if (Array.isArray(target)) {
        const targetList = target;
        if (targetList.length === 0)
          return null;
        let lastException;
        let i = -1;
        while (++i < targetList.length) {
          const targetItem = targetList[i];
          let resolved;
          try {
            resolved = resolvePackageTarget(packageJsonUrl, targetItem, subpath, packageSubpath, base, pattern, internal, conditions);
          } catch (error) {
            lastException = error;
            if (error.code === "ERR_INVALID_PACKAGE_TARGET")
              continue;
            throw error;
          }
          if (resolved === void 0)
            continue;
          if (resolved === null) {
            lastException = null;
            continue;
          }
          return resolved;
        }
        if (lastException === void 0 || lastException === null) {
          return lastException;
        }
        throw lastException;
      }
      if (typeof target === "object" && target !== null) {
        const keys3 = Object.getOwnPropertyNames(target);
        let i = -1;
        while (++i < keys3.length) {
          const key = keys3[i];
          if (isArrayIndex(key)) {
            throw new ERR_INVALID_PACKAGE_CONFIG((0, _url().fileURLToPath)(packageJsonUrl), base, '"exports" cannot contain numeric property keys.');
          }
        }
        i = -1;
        while (++i < keys3.length) {
          const key = keys3[i];
          if (key === "default" || conditions && conditions.has(key)) {
            const conditionalTarget = target[key];
            const resolved = resolvePackageTarget(packageJsonUrl, conditionalTarget, subpath, packageSubpath, base, pattern, internal, conditions);
            if (resolved === void 0)
              continue;
            return resolved;
          }
        }
        return void 0;
      }
      if (target === null) {
        return null;
      }
      throwInvalidPackageTarget(packageSubpath, target, packageJsonUrl, internal, base);
    }
    function isConditionalExportsMainSugar(exports2, packageJsonUrl, base) {
      if (typeof exports2 === "string" || Array.isArray(exports2))
        return true;
      if (typeof exports2 !== "object" || exports2 === null)
        return false;
      const keys3 = Object.getOwnPropertyNames(exports2);
      let isConditionalSugar = false;
      let i = 0;
      let j = -1;
      while (++j < keys3.length) {
        const key = keys3[j];
        const curIsConditionalSugar = key === "" || key[0] !== ".";
        if (i++ === 0) {
          isConditionalSugar = curIsConditionalSugar;
        } else if (isConditionalSugar !== curIsConditionalSugar) {
          throw new ERR_INVALID_PACKAGE_CONFIG((0, _url().fileURLToPath)(packageJsonUrl), base, `"exports" cannot contain some keys starting with '.' and some not. The exports object must either be an object of package subpath keys or an object of main entry condition name keys only.`);
        }
      }
      return isConditionalSugar;
    }
    function packageExportsResolve(packageJsonUrl, packageSubpath, packageConfig, base, conditions) {
      let exports2 = packageConfig.exports;
      if (isConditionalExportsMainSugar(exports2, packageJsonUrl, base))
        exports2 = {
          ".": exports2
        };
      if (own.call(exports2, packageSubpath)) {
        const target = exports2[packageSubpath];
        const resolved = resolvePackageTarget(packageJsonUrl, target, "", packageSubpath, base, false, false, conditions);
        if (resolved === null || resolved === void 0)
          throwExportsNotFound(packageSubpath, packageJsonUrl, base);
        return {
          resolved,
          exact: true
        };
      }
      let bestMatch = "";
      const keys3 = Object.getOwnPropertyNames(exports2);
      let i = -1;
      while (++i < keys3.length) {
        const key = keys3[i];
        if (key[key.length - 1] === "*" && packageSubpath.startsWith(key.slice(0, -1)) && packageSubpath.length >= key.length && key.length > bestMatch.length) {
          bestMatch = key;
        } else if (key[key.length - 1] === "/" && packageSubpath.startsWith(key) && key.length > bestMatch.length) {
          bestMatch = key;
        }
      }
      if (bestMatch) {
        const target = exports2[bestMatch];
        const pattern = bestMatch[bestMatch.length - 1] === "*";
        const subpath = packageSubpath.slice(bestMatch.length - (pattern ? 1 : 0));
        const resolved = resolvePackageTarget(packageJsonUrl, target, subpath, bestMatch, base, pattern, false, conditions);
        if (resolved === null || resolved === void 0)
          throwExportsNotFound(packageSubpath, packageJsonUrl, base);
        if (!pattern)
          emitFolderMapDeprecation(bestMatch, packageJsonUrl, true, base);
        return {
          resolved,
          exact: pattern
        };
      }
      throwExportsNotFound(packageSubpath, packageJsonUrl, base);
    }
    function packageImportsResolve(name, base, conditions) {
      if (name === "#" || name.startsWith("#/")) {
        const reason = "is not a valid internal imports specifier name";
        throw new ERR_INVALID_MODULE_SPECIFIER(name, reason, (0, _url().fileURLToPath)(base));
      }
      let packageJsonUrl;
      const packageConfig = getPackageScopeConfig(base);
      if (packageConfig.exists) {
        packageJsonUrl = (0, _url().pathToFileURL)(packageConfig.pjsonPath);
        const imports = packageConfig.imports;
        if (imports) {
          if (own.call(imports, name)) {
            const resolved = resolvePackageTarget(packageJsonUrl, imports[name], "", name, base, false, true, conditions);
            if (resolved !== null)
              return {
                resolved,
                exact: true
              };
          } else {
            let bestMatch = "";
            const keys3 = Object.getOwnPropertyNames(imports);
            let i = -1;
            while (++i < keys3.length) {
              const key = keys3[i];
              if (key[key.length - 1] === "*" && name.startsWith(key.slice(0, -1)) && name.length >= key.length && key.length > bestMatch.length) {
                bestMatch = key;
              } else if (key[key.length - 1] === "/" && name.startsWith(key) && key.length > bestMatch.length) {
                bestMatch = key;
              }
            }
            if (bestMatch) {
              const target = imports[bestMatch];
              const pattern = bestMatch[bestMatch.length - 1] === "*";
              const subpath = name.slice(bestMatch.length - (pattern ? 1 : 0));
              const resolved = resolvePackageTarget(packageJsonUrl, target, subpath, bestMatch, base, pattern, true, conditions);
              if (resolved !== null) {
                if (!pattern)
                  emitFolderMapDeprecation(bestMatch, packageJsonUrl, false, base);
                return {
                  resolved,
                  exact: pattern
                };
              }
            }
          }
        }
      }
      throwImportNotDefined(name, packageJsonUrl, base);
    }
    function getPackageType(url) {
      const packageConfig = getPackageScopeConfig(url);
      return packageConfig.type;
    }
    function parsePackageName(specifier, base) {
      let separatorIndex = specifier.indexOf("/");
      let validPackageName = true;
      let isScoped = false;
      if (specifier[0] === "@") {
        isScoped = true;
        if (separatorIndex === -1 || specifier.length === 0) {
          validPackageName = false;
        } else {
          separatorIndex = specifier.indexOf("/", separatorIndex + 1);
        }
      }
      const packageName = separatorIndex === -1 ? specifier : specifier.slice(0, separatorIndex);
      let i = -1;
      while (++i < packageName.length) {
        if (packageName[i] === "%" || packageName[i] === "\\") {
          validPackageName = false;
          break;
        }
      }
      if (!validPackageName) {
        throw new ERR_INVALID_MODULE_SPECIFIER(specifier, "is not a valid package name", (0, _url().fileURLToPath)(base));
      }
      const packageSubpath = "." + (separatorIndex === -1 ? "" : specifier.slice(separatorIndex));
      return {
        packageName,
        packageSubpath,
        isScoped
      };
    }
    function packageResolve(specifier, base, conditions) {
      const {
        packageName,
        packageSubpath,
        isScoped
      } = parsePackageName(specifier, base);
      const packageConfig = getPackageScopeConfig(base);
      if (packageConfig.exists) {
        const packageJsonUrl2 = (0, _url().pathToFileURL)(packageConfig.pjsonPath);
        if (packageConfig.name === packageName && packageConfig.exports !== void 0 && packageConfig.exports !== null) {
          return packageExportsResolve(packageJsonUrl2, packageSubpath, packageConfig, base, conditions).resolved;
        }
      }
      let packageJsonUrl = new (_url()).URL("./node_modules/" + packageName + "/package.json", base);
      let packageJsonPath = (0, _url().fileURLToPath)(packageJsonUrl);
      let lastPath;
      do {
        const stat = tryStatSync(packageJsonPath.slice(0, -13));
        if (!stat.isDirectory()) {
          lastPath = packageJsonPath;
          packageJsonUrl = new (_url()).URL((isScoped ? "../../../../node_modules/" : "../../../node_modules/") + packageName + "/package.json", packageJsonUrl);
          packageJsonPath = (0, _url().fileURLToPath)(packageJsonUrl);
          continue;
        }
        const packageConfig2 = getPackageConfig(packageJsonPath, specifier, base);
        if (packageConfig2.exports !== void 0 && packageConfig2.exports !== null)
          return packageExportsResolve(packageJsonUrl, packageSubpath, packageConfig2, base, conditions).resolved;
        if (packageSubpath === ".")
          return legacyMainResolve(packageJsonUrl, packageConfig2, base);
        return new (_url()).URL(packageSubpath, packageJsonUrl);
      } while (packageJsonPath.length !== lastPath.length);
      throw new ERR_MODULE_NOT_FOUND(packageName, (0, _url().fileURLToPath)(base));
    }
    function isRelativeSpecifier(specifier) {
      if (specifier[0] === ".") {
        if (specifier.length === 1 || specifier[1] === "/")
          return true;
        if (specifier[1] === "." && (specifier.length === 2 || specifier[2] === "/")) {
          return true;
        }
      }
      return false;
    }
    function shouldBeTreatedAsRelativeOrAbsolutePath(specifier) {
      if (specifier === "")
        return false;
      if (specifier[0] === "/")
        return true;
      return isRelativeSpecifier(specifier);
    }
    function moduleResolve(specifier, base, conditions) {
      let resolved;
      if (shouldBeTreatedAsRelativeOrAbsolutePath(specifier)) {
        resolved = new (_url()).URL(specifier, base);
      } else if (specifier[0] === "#") {
        ({
          resolved
        } = packageImportsResolve(specifier, base, conditions));
      } else {
        try {
          resolved = new (_url()).URL(specifier);
        } catch (_unused3) {
          resolved = packageResolve(specifier, base, conditions);
        }
      }
      return finalizeResolution(resolved, base);
    }
    function defaultResolve(specifier, context = {}) {
      const {
        parentURL
      } = context;
      let parsed;
      try {
        parsed = new (_url()).URL(specifier);
        if (parsed.protocol === "data:") {
          return {
            url: specifier
          };
        }
      } catch (_unused4) {
      }
      if (parsed && parsed.protocol === "node:")
        return {
          url: specifier
        };
      if (parsed && parsed.protocol !== "file:" && parsed.protocol !== "data:")
        throw new ERR_UNSUPPORTED_ESM_URL_SCHEME(parsed);
      if (listOfBuiltins.includes(specifier)) {
        return {
          url: "node:" + specifier
        };
      }
      if (parentURL.startsWith("data:")) {
        new (_url()).URL(specifier, parentURL);
      }
      const conditions = getConditionsSet(context.conditions);
      let url = moduleResolve(specifier, new (_url()).URL(parentURL), conditions);
      const urlPath = (0, _url().fileURLToPath)(url);
      const real = (0, _fs().realpathSync)(urlPath);
      const old = url;
      url = (0, _url().pathToFileURL)(real + (urlPath.endsWith(_path().sep) ? "/" : ""));
      url.search = old.search;
      url.hash = old.hash;
      return {
        url: `${url}`
      };
    }
    function resolve(_x, _x2) {
      return _resolve.apply(this, arguments);
    }
    function _resolve() {
      _resolve = _asyncToGenerator(function* (specifier, parent) {
        if (!parent) {
          throw new Error("Please pass `parent`: `import-meta-resolve` cannot ponyfill that");
        }
        try {
          return defaultResolve(specifier, {
            parentURL: parent
          }).url;
        } catch (error) {
          return error.code === "ERR_UNSUPPORTED_DIR_IMPORT" ? error.url : Promise.reject(error);
        }
      });
      return _resolve.apply(this, arguments);
    }
  }
});

// node_modules/@babel/core/lib/config/files/import-meta-resolve.js
var require_import_meta_resolve2 = __commonJS({
  "node_modules/@babel/core/lib/config/files/import-meta-resolve.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = resolve;
    var _importMetaResolve = require_import_meta_resolve();
    function asyncGeneratorStep(gen, resolve2, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve2(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve2, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve2, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve2, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    var import_;
    try {
      import_ = require_import();
    } catch (_unused) {
    }
    var importMetaResolveP = import_ && process.execArgv.includes("--experimental-import-meta-resolve") ? import_("data:text/javascript,export default import.meta.resolve").then((m) => m.default || _importMetaResolve.resolve, () => _importMetaResolve.resolve) : Promise.resolve(_importMetaResolve.resolve);
    function resolve(_x, _x2) {
      return _resolve.apply(this, arguments);
    }
    function _resolve() {
      _resolve = _asyncToGenerator(function* (specifier, parent) {
        return (yield importMetaResolveP)(specifier, parent);
      });
      return _resolve.apply(this, arguments);
    }
  }
});

// node_modules/@babel/core/lib/config/files/plugins.js
var require_plugins = __commonJS({
  "node_modules/@babel/core/lib/config/files/plugins.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.loadPlugin = loadPlugin;
    exports.loadPreset = loadPreset;
    exports.resolvePlugin = resolvePlugin;
    exports.resolvePreset = resolvePreset;
    function _debug() {
      const data = require_src();
      _debug = function() {
        return data;
      };
      return data;
    }
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _async = require_async7();
    var _moduleTypes = require_module_types();
    function _url() {
      const data = require("url");
      _url = function() {
        return data;
      };
      return data;
    }
    var _importMetaResolve = require_import_meta_resolve2();
    function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
      try {
        var info = gen[key](arg);
        var value2 = info.value;
      } catch (error) {
        reject(error);
        return;
      }
      if (info.done) {
        resolve(value2);
      } else {
        Promise.resolve(value2).then(_next, _throw);
      }
    }
    function _asyncToGenerator(fn) {
      return function() {
        var self2 = this, args = arguments;
        return new Promise(function(resolve, reject) {
          var gen = fn.apply(self2, args);
          function _next(value2) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value2);
          }
          function _throw(err) {
            asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
          }
          _next(void 0);
        });
      };
    }
    var debug = _debug()("babel:config:loading:files:plugins");
    var EXACT_RE = /^module:/;
    var BABEL_PLUGIN_PREFIX_RE = /^(?!@|module:|[^/]+\/|babel-plugin-)/;
    var BABEL_PRESET_PREFIX_RE = /^(?!@|module:|[^/]+\/|babel-preset-)/;
    var BABEL_PLUGIN_ORG_RE = /^(@babel\/)(?!plugin-|[^/]+\/)/;
    var BABEL_PRESET_ORG_RE = /^(@babel\/)(?!preset-|[^/]+\/)/;
    var OTHER_PLUGIN_ORG_RE = /^(@(?!babel\/)[^/]+\/)(?![^/]*babel-plugin(?:-|\/|$)|[^/]+\/)/;
    var OTHER_PRESET_ORG_RE = /^(@(?!babel\/)[^/]+\/)(?![^/]*babel-preset(?:-|\/|$)|[^/]+\/)/;
    var OTHER_ORG_DEFAULT_RE = /^(@(?!babel$)[^/]+)$/;
    function* resolvePlugin(name, dirname) {
      return yield* resolveStandardizedName("plugin", name, dirname);
    }
    function* resolvePreset(name, dirname) {
      return yield* resolveStandardizedName("preset", name, dirname);
    }
    function* loadPlugin(name, dirname) {
      const filepath = yield* resolvePlugin(name, dirname);
      const value2 = yield* requireModule("plugin", filepath);
      debug("Loaded plugin %o from %o.", name, dirname);
      return {
        filepath,
        value: value2
      };
    }
    function* loadPreset(name, dirname) {
      const filepath = yield* resolvePreset(name, dirname);
      const value2 = yield* requireModule("preset", filepath);
      debug("Loaded preset %o from %o.", name, dirname);
      return {
        filepath,
        value: value2
      };
    }
    function standardizeName(type, name) {
      if (_path().isAbsolute(name))
        return name;
      const isPreset = type === "preset";
      return name.replace(isPreset ? BABEL_PRESET_PREFIX_RE : BABEL_PLUGIN_PREFIX_RE, `babel-${type}-`).replace(isPreset ? BABEL_PRESET_ORG_RE : BABEL_PLUGIN_ORG_RE, `$1${type}-`).replace(isPreset ? OTHER_PRESET_ORG_RE : OTHER_PLUGIN_ORG_RE, `$1babel-${type}-`).replace(OTHER_ORG_DEFAULT_RE, `$1/babel-${type}`).replace(EXACT_RE, "");
    }
    function* resolveAlternativesHelper(type, name) {
      const standardizedName = standardizeName(type, name);
      const {
        error,
        value: value2
      } = yield standardizedName;
      if (!error)
        return value2;
      if (error.code !== "MODULE_NOT_FOUND")
        throw error;
      if (standardizedName !== name && !(yield name).error) {
        error.message += `
- If you want to resolve "${name}", use "module:${name}"`;
      }
      if (!(yield standardizeName(type, "@babel/" + name)).error) {
        error.message += `
- Did you mean "@babel/${name}"?`;
      }
      const oppositeType = type === "preset" ? "plugin" : "preset";
      if (!(yield standardizeName(oppositeType, name)).error) {
        error.message += `
- Did you accidentally pass a ${oppositeType} as a ${type}?`;
      }
      throw error;
    }
    function tryRequireResolve(id, {
      paths: [dirname]
    }) {
      try {
        return {
          error: null,
          value: (((v, w) => (v = v.split("."), w = w.split("."), +v[0] > +w[0] || v[0] == w[0] && +v[1] >= +w[1]))(process.versions.node, "8.9") ? require.resolve : (r, {
            paths: [b]
          }, M = require("module")) => {
            let f = M._findPath(r, M._nodeModulePaths(b).concat(b));
            if (f)
              return f;
            f = new Error(`Cannot resolve module '${r}'`);
            f.code = "MODULE_NOT_FOUND";
            throw f;
          })(id, {
            paths: [dirname]
          })
        };
      } catch (error) {
        return {
          error,
          value: null
        };
      }
    }
    function tryImportMetaResolve(_x, _x2) {
      return _tryImportMetaResolve.apply(this, arguments);
    }
    function _tryImportMetaResolve() {
      _tryImportMetaResolve = _asyncToGenerator(function* (id, options) {
        try {
          return {
            error: null,
            value: yield (0, _importMetaResolve.default)(id, options)
          };
        } catch (error) {
          return {
            error,
            value: null
          };
        }
      });
      return _tryImportMetaResolve.apply(this, arguments);
    }
    function resolveStandardizedNameForRequire(type, name, dirname) {
      const it2 = resolveAlternativesHelper(type, name);
      let res = it2.next();
      while (!res.done) {
        res = it2.next(tryRequireResolve(res.value, {
          paths: [dirname]
        }));
      }
      return res.value;
    }
    function resolveStandardizedNameForImport(_x3, _x4, _x5) {
      return _resolveStandardizedNameForImport.apply(this, arguments);
    }
    function _resolveStandardizedNameForImport() {
      _resolveStandardizedNameForImport = _asyncToGenerator(function* (type, name, dirname) {
        const parentUrl = (0, _url().pathToFileURL)(_path().join(dirname, "./babel-virtual-resolve-base.js")).href;
        const it2 = resolveAlternativesHelper(type, name);
        let res = it2.next();
        while (!res.done) {
          res = it2.next(yield tryImportMetaResolve(res.value, parentUrl));
        }
        return (0, _url().fileURLToPath)(res.value);
      });
      return _resolveStandardizedNameForImport.apply(this, arguments);
    }
    var resolveStandardizedName = _gensync()({
      sync(type, name, dirname = process.cwd()) {
        return resolveStandardizedNameForRequire(type, name, dirname);
      },
      async(type, name, dirname = process.cwd()) {
        return _asyncToGenerator(function* () {
          if (!_moduleTypes.supportsESM) {
            return resolveStandardizedNameForRequire(type, name, dirname);
          }
          try {
            return yield resolveStandardizedNameForImport(type, name, dirname);
          } catch (e) {
            try {
              return resolveStandardizedNameForRequire(type, name, dirname);
            } catch (e2) {
              if (e.type === "MODULE_NOT_FOUND")
                throw e;
              if (e2.type === "MODULE_NOT_FOUND")
                throw e2;
              throw e;
            }
          }
        })();
      }
    });
    {
      LOADING_MODULES = /* @__PURE__ */ new Set();
    }
    var LOADING_MODULES;
    function* requireModule(type, name) {
      {
        if (!(yield* (0, _async.isAsync)()) && LOADING_MODULES.has(name)) {
          throw new Error(`Reentrant ${type} detected trying to load "${name}". This module is not ignored and is trying to load itself while compiling itself, leading to a dependency cycle. We recommend adding it to your "ignore" list in your babelrc, or to a .babelignore.`);
        }
      }
      try {
        {
          LOADING_MODULES.add(name);
        }
        return yield* (0, _moduleTypes.default)(name, `You appear to be using a native ECMAScript module ${type}, which is only supported when running Babel asynchronously.`, true);
      } catch (err) {
        err.message = `[BABEL]: ${err.message} (While processing: ${name})`;
        throw err;
      } finally {
        {
          LOADING_MODULES.delete(name);
        }
      }
    }
  }
});

// node_modules/@babel/core/lib/config/files/index.js
var require_files = __commonJS({
  "node_modules/@babel/core/lib/config/files/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "ROOT_CONFIG_FILENAMES", {
      enumerable: true,
      get: function() {
        return _configuration.ROOT_CONFIG_FILENAMES;
      }
    });
    Object.defineProperty(exports, "findConfigUpwards", {
      enumerable: true,
      get: function() {
        return _configuration.findConfigUpwards;
      }
    });
    Object.defineProperty(exports, "findPackageData", {
      enumerable: true,
      get: function() {
        return _package.findPackageData;
      }
    });
    Object.defineProperty(exports, "findRelativeConfig", {
      enumerable: true,
      get: function() {
        return _configuration.findRelativeConfig;
      }
    });
    Object.defineProperty(exports, "findRootConfig", {
      enumerable: true,
      get: function() {
        return _configuration.findRootConfig;
      }
    });
    Object.defineProperty(exports, "loadConfig", {
      enumerable: true,
      get: function() {
        return _configuration.loadConfig;
      }
    });
    Object.defineProperty(exports, "loadPlugin", {
      enumerable: true,
      get: function() {
        return plugins.loadPlugin;
      }
    });
    Object.defineProperty(exports, "loadPreset", {
      enumerable: true,
      get: function() {
        return plugins.loadPreset;
      }
    });
    exports.resolvePreset = exports.resolvePlugin = void 0;
    Object.defineProperty(exports, "resolveShowConfigPath", {
      enumerable: true,
      get: function() {
        return _configuration.resolveShowConfigPath;
      }
    });
    var _package = require_package6();
    var _configuration = require_configuration();
    var plugins = require_plugins();
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var resolvePlugin = _gensync()(plugins.resolvePlugin).sync;
    exports.resolvePlugin = resolvePlugin;
    var resolvePreset = _gensync()(plugins.resolvePreset).sync;
    exports.resolvePreset = resolvePreset;
  }
});

// node_modules/@babel/core/lib/config/helpers/environment.js
var require_environment = __commonJS({
  "node_modules/@babel/core/lib/config/helpers/environment.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.getEnv = getEnv;
    function getEnv(defaultValue = "development") {
      return process.env.BABEL_ENV || process.env.NODE_ENV || defaultValue;
    }
  }
});

// node_modules/@babel/core/lib/config/helpers/deep-array.js
var require_deep_array = __commonJS({
  "node_modules/@babel/core/lib/config/helpers/deep-array.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.finalize = finalize;
    exports.flattenToSet = flattenToSet;
    function finalize(deepArr) {
      return Object.freeze(deepArr);
    }
    function flattenToSet(arr) {
      const result = /* @__PURE__ */ new Set();
      const stack = [arr];
      while (stack.length > 0) {
        for (const el of stack.pop()) {
          if (Array.isArray(el))
            stack.push(el);
          else
            result.add(el);
        }
      }
      return result;
    }
  }
});

// node_modules/@babel/core/lib/config/plugin.js
var require_plugin = __commonJS({
  "node_modules/@babel/core/lib/config/plugin.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _deepArray = require_deep_array();
    var Plugin = class {
      constructor(plugin, options, key, externalDependencies = (0, _deepArray.finalize)([])) {
        this.key = void 0;
        this.manipulateOptions = void 0;
        this.post = void 0;
        this.pre = void 0;
        this.visitor = void 0;
        this.parserOverride = void 0;
        this.generatorOverride = void 0;
        this.options = void 0;
        this.externalDependencies = void 0;
        this.key = plugin.name || key;
        this.manipulateOptions = plugin.manipulateOptions;
        this.post = plugin.post;
        this.pre = plugin.pre;
        this.visitor = plugin.visitor || {};
        this.parserOverride = plugin.parserOverride;
        this.generatorOverride = plugin.generatorOverride;
        this.options = options;
        this.externalDependencies = externalDependencies;
      }
    };
    exports.default = Plugin;
  }
});

// node_modules/@babel/core/lib/gensync-utils/functional.js
var require_functional = __commonJS({
  "node_modules/@babel/core/lib/gensync-utils/functional.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.once = once;
    var _async = require_async7();
    function once(fn) {
      let result;
      let resultP;
      return function* () {
        if (result)
          return result;
        if (!(yield* (0, _async.isAsync)()))
          return result = yield* fn();
        if (resultP)
          return yield* (0, _async.waitFor)(resultP);
        let resolve, reject;
        resultP = new Promise((res, rej) => {
          resolve = res;
          reject = rej;
        });
        try {
          result = yield* fn();
          resultP = null;
          resolve(result);
          return result;
        } catch (error) {
          reject(error);
          throw error;
        }
      };
    }
  }
});

// node_modules/node-releases/data/processed/envs.json
var require_envs = __commonJS({
  "node_modules/node-releases/data/processed/envs.json"(exports, module2) {
    module2.exports = [{ name: "nodejs", version: "0.2.0", date: "2011-08-26", lts: false, security: false }, { name: "nodejs", version: "0.3.0", date: "2011-08-26", lts: false, security: false }, { name: "nodejs", version: "0.4.0", date: "2011-08-26", lts: false, security: false }, { name: "nodejs", version: "0.5.0", date: "2011-08-26", lts: false, security: false }, { name: "nodejs", version: "0.6.0", date: "2011-11-04", lts: false, security: false }, { name: "nodejs", version: "0.7.0", date: "2012-01-17", lts: false, security: false }, { name: "nodejs", version: "0.8.0", date: "2012-06-22", lts: false, security: false }, { name: "nodejs", version: "0.9.0", date: "2012-07-20", lts: false, security: false }, { name: "nodejs", version: "0.10.0", date: "2013-03-11", lts: false, security: false }, { name: "nodejs", version: "0.11.0", date: "2013-03-28", lts: false, security: false }, { name: "nodejs", version: "0.12.0", date: "2015-02-06", lts: false, security: false }, { name: "nodejs", version: "4.0.0", date: "2015-09-08", lts: false, security: false }, { name: "nodejs", version: "4.1.0", date: "2015-09-17", lts: false, security: false }, { name: "nodejs", version: "4.2.0", date: "2015-10-12", lts: "Argon", security: false }, { name: "nodejs", version: "4.3.0", date: "2016-02-09", lts: "Argon", security: false }, { name: "nodejs", version: "4.4.0", date: "2016-03-08", lts: "Argon", security: false }, { name: "nodejs", version: "4.5.0", date: "2016-08-16", lts: "Argon", security: false }, { name: "nodejs", version: "4.6.0", date: "2016-09-27", lts: "Argon", security: true }, { name: "nodejs", version: "4.7.0", date: "2016-12-06", lts: "Argon", security: false }, { name: "nodejs", version: "4.8.0", date: "2017-02-21", lts: "Argon", security: false }, { name: "nodejs", version: "4.9.0", date: "2018-03-28", lts: "Argon", security: true }, { name: "nodejs", version: "5.0.0", date: "2015-10-29", lts: false, security: false }, { name: "nodejs", version: "5.1.0", date: "2015-11-17", lts: false, security: false }, { name: "nodejs", version: "5.2.0", date: "2015-12-09", lts: false, security: false }, { name: "nodejs", version: "5.3.0", date: "2015-12-15", lts: false, security: false }, { name: "nodejs", version: "5.4.0", date: "2016-01-06", lts: false, security: false }, { name: "nodejs", version: "5.5.0", date: "2016-01-21", lts: false, security: false }, { name: "nodejs", version: "5.6.0", date: "2016-02-09", lts: false, security: false }, { name: "nodejs", version: "5.7.0", date: "2016-02-23", lts: false, security: false }, { name: "nodejs", version: "5.8.0", date: "2016-03-09", lts: false, security: false }, { name: "nodejs", version: "5.9.0", date: "2016-03-16", lts: false, security: false }, { name: "nodejs", version: "5.10.0", date: "2016-04-01", lts: false, security: false }, { name: "nodejs", version: "5.11.0", date: "2016-04-21", lts: false, security: false }, { name: "nodejs", version: "5.12.0", date: "2016-06-23", lts: false, security: false }, { name: "nodejs", version: "6.0.0", date: "2016-04-26", lts: false, security: false }, { name: "nodejs", version: "6.1.0", date: "2016-05-05", lts: false, security: false }, { name: "nodejs", version: "6.2.0", date: "2016-05-17", lts: false, security: false }, { name: "nodejs", version: "6.3.0", date: "2016-07-06", lts: false, security: false }, { name: "nodejs", version: "6.4.0", date: "2016-08-12", lts: false, security: false }, { name: "nodejs", version: "6.5.0", date: "2016-08-26", lts: false, security: false }, { name: "nodejs", version: "6.6.0", date: "2016-09-14", lts: false, security: false }, { name: "nodejs", version: "6.7.0", date: "2016-09-27", lts: false, security: true }, { name: "nodejs", version: "6.8.0", date: "2016-10-12", lts: false, security: false }, { name: "nodejs", version: "6.9.0", date: "2016-10-18", lts: "Boron", security: false }, { name: "nodejs", version: "6.10.0", date: "2017-02-21", lts: "Boron", security: false }, { name: "nodejs", version: "6.11.0", date: "2017-06-06", lts: "Boron", security: false }, { name: "nodejs", version: "6.12.0", date: "2017-11-06", lts: "Boron", security: false }, { name: "nodejs", version: "6.13.0", date: "2018-02-10", lts: "Boron", security: false }, { name: "nodejs", version: "6.14.0", date: "2018-03-28", lts: "Boron", security: true }, { name: "nodejs", version: "6.15.0", date: "2018-11-27", lts: "Boron", security: true }, { name: "nodejs", version: "6.16.0", date: "2018-12-26", lts: "Boron", security: false }, { name: "nodejs", version: "6.17.0", date: "2019-02-28", lts: "Boron", security: true }, { name: "nodejs", version: "7.0.0", date: "2016-10-25", lts: false, security: false }, { name: "nodejs", version: "7.1.0", date: "2016-11-08", lts: false, security: false }, { name: "nodejs", version: "7.2.0", date: "2016-11-22", lts: false, security: false }, { name: "nodejs", version: "7.3.0", date: "2016-12-20", lts: false, security: false }, { name: "nodejs", version: "7.4.0", date: "2017-01-04", lts: false, security: false }, { name: "nodejs", version: "7.5.0", date: "2017-01-31", lts: false, security: false }, { name: "nodejs", version: "7.6.0", date: "2017-02-21", lts: false, security: false }, { name: "nodejs", version: "7.7.0", date: "2017-02-28", lts: false, security: false }, { name: "nodejs", version: "7.8.0", date: "2017-03-29", lts: false, security: false }, { name: "nodejs", version: "7.9.0", date: "2017-04-11", lts: false, security: false }, { name: "nodejs", version: "7.10.0", date: "2017-05-02", lts: false, security: false }, { name: "nodejs", version: "8.0.0", date: "2017-05-30", lts: false, security: false }, { name: "nodejs", version: "8.1.0", date: "2017-06-08", lts: false, security: false }, { name: "nodejs", version: "8.2.0", date: "2017-07-19", lts: false, security: false }, { name: "nodejs", version: "8.3.0", date: "2017-08-08", lts: false, security: false }, { name: "nodejs", version: "8.4.0", date: "2017-08-15", lts: false, security: false }, { name: "nodejs", version: "8.5.0", date: "2017-09-12", lts: false, security: false }, { name: "nodejs", version: "8.6.0", date: "2017-09-26", lts: false, security: false }, { name: "nodejs", version: "8.7.0", date: "2017-10-11", lts: false, security: false }, { name: "nodejs", version: "8.8.0", date: "2017-10-24", lts: false, security: false }, { name: "nodejs", version: "8.9.0", date: "2017-10-31", lts: "Carbon", security: false }, { name: "nodejs", version: "8.10.0", date: "2018-03-06", lts: "Carbon", security: false }, { name: "nodejs", version: "8.11.0", date: "2018-03-28", lts: "Carbon", security: true }, { name: "nodejs", version: "8.12.0", date: "2018-09-10", lts: "Carbon", security: false }, { name: "nodejs", version: "8.13.0", date: "2018-11-20", lts: "Carbon", security: false }, { name: "nodejs", version: "8.14.0", date: "2018-11-27", lts: "Carbon", security: true }, { name: "nodejs", version: "8.15.0", date: "2018-12-26", lts: "Carbon", security: false }, { name: "nodejs", version: "8.16.0", date: "2019-04-16", lts: "Carbon", security: false }, { name: "nodejs", version: "8.17.0", date: "2019-12-17", lts: "Carbon", security: true }, { name: "nodejs", version: "9.0.0", date: "2017-10-31", lts: false, security: false }, { name: "nodejs", version: "9.1.0", date: "2017-11-07", lts: false, security: false }, { name: "nodejs", version: "9.2.0", date: "2017-11-14", lts: false, security: false }, { name: "nodejs", version: "9.3.0", date: "2017-12-12", lts: false, security: false }, { name: "nodejs", version: "9.4.0", date: "2018-01-10", lts: false, security: false }, { name: "nodejs", version: "9.5.0", date: "2018-01-31", lts: false, security: false }, { name: "nodejs", version: "9.6.0", date: "2018-02-21", lts: false, security: false }, { name: "nodejs", version: "9.7.0", date: "2018-03-01", lts: false, security: false }, { name: "nodejs", version: "9.8.0", date: "2018-03-07", lts: false, security: false }, { name: "nodejs", version: "9.9.0", date: "2018-03-21", lts: false, security: false }, { name: "nodejs", version: "9.10.0", date: "2018-03-28", lts: false, security: true }, { name: "nodejs", version: "9.11.0", date: "2018-04-04", lts: false, security: false }, { name: "nodejs", version: "10.0.0", date: "2018-04-24", lts: false, security: false }, { name: "nodejs", version: "10.1.0", date: "2018-05-08", lts: false, security: false }, { name: "nodejs", version: "10.2.0", date: "2018-05-23", lts: false, security: false }, { name: "nodejs", version: "10.3.0", date: "2018-05-29", lts: false, security: false }, { name: "nodejs", version: "10.4.0", date: "2018-06-06", lts: false, security: false }, { name: "nodejs", version: "10.5.0", date: "2018-06-20", lts: false, security: false }, { name: "nodejs", version: "10.6.0", date: "2018-07-04", lts: false, security: false }, { name: "nodejs", version: "10.7.0", date: "2018-07-18", lts: false, security: false }, { name: "nodejs", version: "10.8.0", date: "2018-08-01", lts: false, security: false }, { name: "nodejs", version: "10.9.0", date: "2018-08-15", lts: false, security: false }, { name: "nodejs", version: "10.10.0", date: "2018-09-06", lts: false, security: false }, { name: "nodejs", version: "10.11.0", date: "2018-09-19", lts: false, security: false }, { name: "nodejs", version: "10.12.0", date: "2018-10-10", lts: false, security: false }, { name: "nodejs", version: "10.13.0", date: "2018-10-30", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.14.0", date: "2018-11-27", lts: "Dubnium", security: true }, { name: "nodejs", version: "10.15.0", date: "2018-12-26", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.16.0", date: "2019-05-28", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.17.0", date: "2019-10-22", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.18.0", date: "2019-12-17", lts: "Dubnium", security: true }, { name: "nodejs", version: "10.19.0", date: "2020-02-05", lts: "Dubnium", security: true }, { name: "nodejs", version: "10.20.0", date: "2020-03-26", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.21.0", date: "2020-06-02", lts: "Dubnium", security: true }, { name: "nodejs", version: "10.22.0", date: "2020-07-21", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.23.0", date: "2020-10-27", lts: "Dubnium", security: false }, { name: "nodejs", version: "10.24.0", date: "2021-02-23", lts: "Dubnium", security: true }, { name: "nodejs", version: "11.0.0", date: "2018-10-23", lts: false, security: false }, { name: "nodejs", version: "11.1.0", date: "2018-10-30", lts: false, security: false }, { name: "nodejs", version: "11.2.0", date: "2018-11-15", lts: false, security: false }, { name: "nodejs", version: "11.3.0", date: "2018-11-27", lts: false, security: true }, { name: "nodejs", version: "11.4.0", date: "2018-12-07", lts: false, security: false }, { name: "nodejs", version: "11.5.0", date: "2018-12-18", lts: false, security: false }, { name: "nodejs", version: "11.6.0", date: "2018-12-26", lts: false, security: false }, { name: "nodejs", version: "11.7.0", date: "2019-01-17", lts: false, security: false }, { name: "nodejs", version: "11.8.0", date: "2019-01-24", lts: false, security: false }, { name: "nodejs", version: "11.9.0", date: "2019-01-30", lts: false, security: false }, { name: "nodejs", version: "11.10.0", date: "2019-02-14", lts: false, security: false }, { name: "nodejs", version: "11.11.0", date: "2019-03-05", lts: false, security: false }, { name: "nodejs", version: "11.12.0", date: "2019-03-14", lts: false, security: false }, { name: "nodejs", version: "11.13.0", date: "2019-03-28", lts: false, security: false }, { name: "nodejs", version: "11.14.0", date: "2019-04-10", lts: false, security: false }, { name: "nodejs", version: "11.15.0", date: "2019-04-30", lts: false, security: false }, { name: "nodejs", version: "12.0.0", date: "2019-04-23", lts: false, security: false }, { name: "nodejs", version: "12.1.0", date: "2019-04-29", lts: false, security: false }, { name: "nodejs", version: "12.2.0", date: "2019-05-07", lts: false, security: false }, { name: "nodejs", version: "12.3.0", date: "2019-05-21", lts: false, security: false }, { name: "nodejs", version: "12.4.0", date: "2019-06-04", lts: false, security: false }, { name: "nodejs", version: "12.5.0", date: "2019-06-26", lts: false, security: false }, { name: "nodejs", version: "12.6.0", date: "2019-07-03", lts: false, security: false }, { name: "nodejs", version: "12.7.0", date: "2019-07-23", lts: false, security: false }, { name: "nodejs", version: "12.8.0", date: "2019-08-06", lts: false, security: false }, { name: "nodejs", version: "12.9.0", date: "2019-08-20", lts: false, security: false }, { name: "nodejs", version: "12.10.0", date: "2019-09-04", lts: false, security: false }, { name: "nodejs", version: "12.11.0", date: "2019-09-25", lts: false, security: false }, { name: "nodejs", version: "12.12.0", date: "2019-10-11", lts: false, security: false }, { name: "nodejs", version: "12.13.0", date: "2019-10-21", lts: "Erbium", security: false }, { name: "nodejs", version: "12.14.0", date: "2019-12-17", lts: "Erbium", security: true }, { name: "nodejs", version: "12.15.0", date: "2020-02-05", lts: "Erbium", security: true }, { name: "nodejs", version: "12.16.0", date: "2020-02-11", lts: "Erbium", security: false }, { name: "nodejs", version: "12.17.0", date: "2020-05-26", lts: "Erbium", security: false }, { name: "nodejs", version: "12.18.0", date: "2020-06-02", lts: "Erbium", security: true }, { name: "nodejs", version: "12.19.0", date: "2020-10-06", lts: "Erbium", security: false }, { name: "nodejs", version: "12.20.0", date: "2020-11-24", lts: "Erbium", security: false }, { name: "nodejs", version: "12.21.0", date: "2021-02-23", lts: "Erbium", security: true }, { name: "nodejs", version: "12.22.0", date: "2021-03-30", lts: "Erbium", security: false }, { name: "nodejs", version: "13.0.0", date: "2019-10-22", lts: false, security: false }, { name: "nodejs", version: "13.1.0", date: "2019-11-05", lts: false, security: false }, { name: "nodejs", version: "13.2.0", date: "2019-11-21", lts: false, security: false }, { name: "nodejs", version: "13.3.0", date: "2019-12-03", lts: false, security: false }, { name: "nodejs", version: "13.4.0", date: "2019-12-17", lts: false, security: true }, { name: "nodejs", version: "13.5.0", date: "2019-12-18", lts: false, security: false }, { name: "nodejs", version: "13.6.0", date: "2020-01-07", lts: false, security: false }, { name: "nodejs", version: "13.7.0", date: "2020-01-21", lts: false, security: false }, { name: "nodejs", version: "13.8.0", date: "2020-02-05", lts: false, security: true }, { name: "nodejs", version: "13.9.0", date: "2020-02-18", lts: false, security: false }, { name: "nodejs", version: "13.10.0", date: "2020-03-04", lts: false, security: false }, { name: "nodejs", version: "13.11.0", date: "2020-03-12", lts: false, security: false }, { name: "nodejs", version: "13.12.0", date: "2020-03-26", lts: false, security: false }, { name: "nodejs", version: "13.13.0", date: "2020-04-14", lts: false, security: false }, { name: "nodejs", version: "13.14.0", date: "2020-04-29", lts: false, security: false }, { name: "nodejs", version: "14.0.0", date: "2020-04-21", lts: false, security: false }, { name: "nodejs", version: "14.1.0", date: "2020-04-29", lts: false, security: false }, { name: "nodejs", version: "14.2.0", date: "2020-05-05", lts: false, security: false }, { name: "nodejs", version: "14.3.0", date: "2020-05-19", lts: false, security: false }, { name: "nodejs", version: "14.4.0", date: "2020-06-02", lts: false, security: true }, { name: "nodejs", version: "14.5.0", date: "2020-06-30", lts: false, security: false }, { name: "nodejs", version: "14.6.0", date: "2020-07-20", lts: false, security: false }, { name: "nodejs", version: "14.7.0", date: "2020-07-29", lts: false, security: false }, { name: "nodejs", version: "14.8.0", date: "2020-08-11", lts: false, security: false }, { name: "nodejs", version: "14.9.0", date: "2020-08-27", lts: false, security: false }, { name: "nodejs", version: "14.10.0", date: "2020-09-08", lts: false, security: false }, { name: "nodejs", version: "14.11.0", date: "2020-09-15", lts: false, security: true }, { name: "nodejs", version: "14.12.0", date: "2020-09-22", lts: false, security: false }, { name: "nodejs", version: "14.13.0", date: "2020-09-29", lts: false, security: false }, { name: "nodejs", version: "14.14.0", date: "2020-10-15", lts: false, security: false }, { name: "nodejs", version: "14.15.0", date: "2020-10-27", lts: "Fermium", security: false }, { name: "nodejs", version: "14.16.0", date: "2021-02-23", lts: "Fermium", security: true }, { name: "nodejs", version: "14.17.0", date: "2021-05-11", lts: "Fermium", security: false }, { name: "nodejs", version: "14.18.0", date: "2021-09-28", lts: "Fermium", security: false }, { name: "nodejs", version: "14.19.0", date: "2022-02-01", lts: "Fermium", security: false }, { name: "nodejs", version: "14.20.0", date: "2022-07-07", lts: "Fermium", security: true }, { name: "nodejs", version: "14.21.0", date: "2022-11-01", lts: "Fermium", security: false }, { name: "nodejs", version: "15.0.0", date: "2020-10-20", lts: false, security: false }, { name: "nodejs", version: "15.1.0", date: "2020-11-04", lts: false, security: false }, { name: "nodejs", version: "15.2.0", date: "2020-11-10", lts: false, security: false }, { name: "nodejs", version: "15.3.0", date: "2020-11-24", lts: false, security: false }, { name: "nodejs", version: "15.4.0", date: "2020-12-09", lts: false, security: false }, { name: "nodejs", version: "15.5.0", date: "2020-12-22", lts: false, security: false }, { name: "nodejs", version: "15.6.0", date: "2021-01-14", lts: false, security: false }, { name: "nodejs", version: "15.7.0", date: "2021-01-25", lts: false, security: false }, { name: "nodejs", version: "15.8.0", date: "2021-02-02", lts: false, security: false }, { name: "nodejs", version: "15.9.0", date: "2021-02-18", lts: false, security: false }, { name: "nodejs", version: "15.10.0", date: "2021-02-23", lts: false, security: true }, { name: "nodejs", version: "15.11.0", date: "2021-03-03", lts: false, security: false }, { name: "nodejs", version: "15.12.0", date: "2021-03-17", lts: false, security: false }, { name: "nodejs", version: "15.13.0", date: "2021-03-31", lts: false, security: false }, { name: "nodejs", version: "15.14.0", date: "2021-04-06", lts: false, security: false }, { name: "nodejs", version: "16.0.0", date: "2021-04-20", lts: false, security: false }, { name: "nodejs", version: "16.1.0", date: "2021-05-04", lts: false, security: false }, { name: "nodejs", version: "16.2.0", date: "2021-05-19", lts: false, security: false }, { name: "nodejs", version: "16.3.0", date: "2021-06-03", lts: false, security: false }, { name: "nodejs", version: "16.4.0", date: "2021-06-23", lts: false, security: false }, { name: "nodejs", version: "16.5.0", date: "2021-07-14", lts: false, security: false }, { name: "nodejs", version: "16.6.0", date: "2021-07-29", lts: false, security: true }, { name: "nodejs", version: "16.7.0", date: "2021-08-18", lts: false, security: false }, { name: "nodejs", version: "16.8.0", date: "2021-08-25", lts: false, security: false }, { name: "nodejs", version: "16.9.0", date: "2021-09-07", lts: false, security: false }, { name: "nodejs", version: "16.10.0", date: "2021-09-22", lts: false, security: false }, { name: "nodejs", version: "16.11.0", date: "2021-10-08", lts: false, security: false }, { name: "nodejs", version: "16.12.0", date: "2021-10-20", lts: false, security: false }, { name: "nodejs", version: "16.13.0", date: "2021-10-26", lts: "Gallium", security: false }, { name: "nodejs", version: "16.14.0", date: "2022-02-08", lts: "Gallium", security: false }, { name: "nodejs", version: "16.15.0", date: "2022-04-26", lts: "Gallium", security: false }, { name: "nodejs", version: "16.16.0", date: "2022-07-07", lts: "Gallium", security: true }, { name: "nodejs", version: "16.17.0", date: "2022-08-16", lts: "Gallium", security: false }, { name: "nodejs", version: "16.18.0", date: "2022-10-12", lts: "Gallium", security: false }, { name: "nodejs", version: "16.19.0", date: "2022-12-13", lts: "Gallium", security: false }, { name: "nodejs", version: "17.0.0", date: "2021-10-19", lts: false, security: false }, { name: "nodejs", version: "17.1.0", date: "2021-11-09", lts: false, security: false }, { name: "nodejs", version: "17.2.0", date: "2021-11-30", lts: false, security: false }, { name: "nodejs", version: "17.3.0", date: "2021-12-17", lts: false, security: false }, { name: "nodejs", version: "17.4.0", date: "2022-01-18", lts: false, security: false }, { name: "nodejs", version: "17.5.0", date: "2022-02-10", lts: false, security: false }, { name: "nodejs", version: "17.6.0", date: "2022-02-22", lts: false, security: false }, { name: "nodejs", version: "17.7.0", date: "2022-03-09", lts: false, security: false }, { name: "nodejs", version: "17.8.0", date: "2022-03-22", lts: false, security: false }, { name: "nodejs", version: "17.9.0", date: "2022-04-07", lts: false, security: false }, { name: "nodejs", version: "18.0.0", date: "2022-04-18", lts: false, security: false }, { name: "nodejs", version: "18.1.0", date: "2022-05-03", lts: false, security: false }, { name: "nodejs", version: "18.2.0", date: "2022-05-17", lts: false, security: false }, { name: "nodejs", version: "18.3.0", date: "2022-06-02", lts: false, security: false }, { name: "nodejs", version: "18.4.0", date: "2022-06-16", lts: false, security: false }, { name: "nodejs", version: "18.5.0", date: "2022-07-06", lts: false, security: true }, { name: "nodejs", version: "18.6.0", date: "2022-07-13", lts: false, security: false }, { name: "nodejs", version: "18.7.0", date: "2022-07-26", lts: false, security: false }, { name: "nodejs", version: "18.8.0", date: "2022-08-24", lts: false, security: false }, { name: "nodejs", version: "18.9.0", date: "2022-09-07", lts: false, security: false }, { name: "nodejs", version: "18.10.0", date: "2022-09-28", lts: false, security: false }, { name: "nodejs", version: "18.11.0", date: "2022-10-13", lts: false, security: false }, { name: "nodejs", version: "18.12.0", date: "2022-10-25", lts: "Hydrogen", security: false }, { name: "nodejs", version: "19.0.0", date: "2022-10-17", lts: false, security: false }, { name: "nodejs", version: "19.1.0", date: "2022-11-14", lts: false, security: false }, { name: "nodejs", version: "19.2.0", date: "2022-11-29", lts: false, security: false }, { name: "nodejs", version: "19.3.0", date: "2022-12-14", lts: false, security: false }];
  }
});

// node_modules/caniuse-lite/data/browsers.js
var require_browsers = __commonJS({
  "node_modules/caniuse-lite/data/browsers.js"(exports, module2) {
    module2.exports = { A: "ie", B: "edge", C: "firefox", D: "chrome", E: "safari", F: "opera", G: "ios_saf", H: "op_mini", I: "android", J: "bb", K: "op_mob", L: "and_chr", M: "and_ff", N: "ie_mob", O: "and_uc", P: "samsung", Q: "and_qq", R: "baidu", S: "kaios" };
  }
});

// node_modules/caniuse-lite/dist/unpacker/browsers.js
var require_browsers2 = __commonJS({
  "node_modules/caniuse-lite/dist/unpacker/browsers.js"(exports, module2) {
    module2.exports.browsers = require_browsers();
  }
});

// node_modules/caniuse-lite/data/browserVersions.js
var require_browserVersions = __commonJS({
  "node_modules/caniuse-lite/data/browserVersions.js"(exports, module2) {
    module2.exports = { "0": "26", "1": "27", "2": "28", "3": "29", "4": "30", "5": "31", "6": "32", "7": "33", "8": "34", "9": "35", A: "10", B: "11", C: "12", D: "7", E: "8", F: "9", G: "15", H: "108", I: "4", J: "6", K: "13", L: "14", M: "16", N: "17", O: "18", P: "79", Q: "80", R: "81", S: "83", T: "84", U: "85", V: "86", W: "87", X: "88", Y: "89", Z: "90", a: "91", b: "92", c: "107", d: "72", e: "93", f: "94", g: "95", h: "96", i: "97", j: "98", k: "99", l: "100", m: "101", n: "102", o: "103", p: "104", q: "105", r: "106", s: "5", t: "19", u: "20", v: "21", w: "22", x: "23", y: "24", z: "25", AB: "36", BB: "37", CB: "38", DB: "39", EB: "40", FB: "41", GB: "42", HB: "43", IB: "44", JB: "45", KB: "46", LB: "47", MB: "48", NB: "49", OB: "50", PB: "51", QB: "52", RB: "53", SB: "54", TB: "55", UB: "56", VB: "57", WB: "58", XB: "60", YB: "62", ZB: "63", aB: "64", bB: "65", cB: "66", dB: "67", eB: "68", fB: "69", gB: "70", hB: "71", iB: "73", jB: "74", kB: "75", lB: "76", mB: "77", nB: "78", oB: "11.1", pB: "12.1", qB: "16.0", rB: "3", sB: "59", tB: "61", uB: "82", vB: "109", wB: "110", xB: "3.2", yB: "10.1", zB: "13.1", "0B": "15.2-15.3", "1B": "15.4", "2B": "15.5", "3B": "15.6", "4B": "16.1", "5B": "16.2", "6B": "16.3", "7B": "11.5", "8B": "4.2-4.3", "9B": "5.5", AC: "2", BC: "3.5", CC: "3.6", DC: "111", EC: "112", FC: "3.1", GC: "5.1", HC: "6.1", IC: "7.1", JC: "9.1", KC: "14.1", LC: "15.1", MC: "TP", NC: "9.5-9.6", OC: "10.0-10.1", PC: "10.5", QC: "10.6", RC: "11.6", SC: "4.0-4.1", TC: "5.0-5.1", UC: "6.0-6.1", VC: "7.0-7.1", WC: "8.1-8.4", XC: "9.0-9.2", YC: "9.3", ZC: "10.0-10.2", aC: "10.3", bC: "11.0-11.2", cC: "11.3-11.4", dC: "12.0-12.1", eC: "12.2-12.5", fC: "13.0-13.1", gC: "13.2", hC: "13.3", iC: "13.4-13.7", jC: "14.0-14.4", kC: "14.5-14.8", lC: "15.0-15.1", mC: "all", nC: "2.1", oC: "2.2", pC: "2.3", qC: "4.1", rC: "4.4", sC: "4.4.3-4.4.4", tC: "13.4", uC: "5.0-5.4", vC: "6.2-6.4", wC: "7.2-7.4", xC: "8.2", yC: "9.2", zC: "11.1-11.2", "0C": "12.0", "1C": "13.0", "2C": "14.0", "3C": "15.0", "4C": "17.0", "5C": "18.0", "6C": "19.0", "7C": "13.18", "8C": "2.5" };
  }
});

// node_modules/caniuse-lite/dist/unpacker/browserVersions.js
var require_browserVersions2 = __commonJS({
  "node_modules/caniuse-lite/dist/unpacker/browserVersions.js"(exports, module2) {
    module2.exports.browserVersions = require_browserVersions();
  }
});

// node_modules/caniuse-lite/data/agents.js
var require_agents = __commonJS({
  "node_modules/caniuse-lite/data/agents.js"(exports, module2) {
    module2.exports = { A: { A: { J: 0.0131217, D: 621152e-8, E: 0.0581246, F: 0.0774995, A: 968743e-8, B: 0.571559, "9B": 9298e-6 }, B: "ms", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "9B", "J", "D", "E", "F", "A", "B", "", "", ""], E: "IE", F: { "9B": 962323200, J: 998870400, D: 1161129600, E: 1237420800, F: 1300060800, A: 1346716800, B: 1381968e3 } }, B: { A: { C: 3773e-6, K: 4267e-6, L: 4268e-6, G: 3773e-6, M: 3702e-6, N: 3773e-6, O: 0.015092, P: 0, Q: 4298e-6, R: 944e-5, S: 4043e-6, T: 3773e-6, U: 3773e-6, V: 3974e-6, W: 3901e-6, X: 4318e-6, Y: 3773e-6, Z: 4118e-6, a: 3939e-6, b: 7546e-6, e: 4118e-6, f: 3939e-6, g: 3801e-6, h: 3901e-6, i: 3855e-6, j: 3929e-6, k: 3901e-6, l: 3773e-6, m: 7546e-6, n: 3773e-6, o: 0.011319, p: 0.011319, q: 0.018865, r: 0.033957, c: 1.13945, H: 2.85239 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "C", "K", "L", "G", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "a", "b", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "c", "H", "", "", ""], E: "Edge", F: { C: 1438128e3, K: 1447286400, L: 1470096e3, G: 1491868800, M: 1508198400, N: 1525046400, O: 1542067200, P: 1579046400, Q: 1581033600, R: 1586736e3, S: 1590019200, T: 1594857600, U: 1598486400, V: 1602201600, W: 1605830400, X: 161136e4, Y: 1614816e3, Z: 1618358400, a: 1622073600, b: 1626912e3, e: 1630627200, f: 1632441600, g: 1634774400, h: 1637539200, i: 1641427200, j: 1643932800, k: 1646265600, l: 1649635200, m: 1651190400, n: 1653955200, o: 1655942400, p: 1659657600, q: 1661990400, r: 1664755200, c: 1666915200, H: 1670198400 }, D: { C: "ms", K: "ms", L: "ms", G: "ms", M: "ms", N: "ms", O: "ms" } }, C: { A: { "0": 4317e-6, "1": 4393e-6, "2": 4418e-6, "3": 8834e-6, "4": 8322e-6, "5": 8928e-6, "6": 4471e-6, "7": 9284e-6, "8": 4707e-6, "9": 9076e-6, AC: 4118e-6, rB: 4271e-6, I: 0.011703, s: 4879e-6, J: 0.020136, D: 5725e-6, E: 4525e-6, F: 533e-5, A: 4283e-6, B: 7546e-6, C: 4471e-6, K: 4486e-6, L: 453e-5, G: 8322e-6, M: 4417e-6, N: 4425e-6, O: 4161e-6, t: 4443e-6, u: 4283e-6, v: 8322e-6, w: 0.013698, x: 4161e-6, y: 8786e-6, z: 4118e-6, AB: 7546e-6, BB: 4783e-6, CB: 3929e-6, DB: 4783e-6, EB: 487e-5, FB: 5029e-6, GB: 47e-4, HB: 0.094325, IB: 7546e-6, JB: 3867e-6, KB: 4525e-6, LB: 4293e-6, MB: 3773e-6, NB: 4538e-6, OB: 8282e-6, PB: 0.011601, QB: 0.052822, RB: 0.011601, SB: 3929e-6, TB: 3974e-6, UB: 7546e-6, VB: 0.011601, WB: 3939e-6, sB: 3773e-6, XB: 3929e-6, tB: 4356e-6, YB: 4425e-6, ZB: 8322e-6, aB: 415e-5, bB: 4267e-6, cB: 3801e-6, dB: 4267e-6, eB: 3773e-6, fB: 415e-5, gB: 4293e-6, hB: 4425e-6, d: 3773e-6, iB: 415e-5, jB: 415e-5, kB: 4318e-6, lB: 4356e-6, mB: 3974e-6, nB: 0.033957, P: 3773e-6, Q: 3773e-6, R: 3773e-6, uB: 3773e-6, S: 3773e-6, T: 3929e-6, U: 4268e-6, V: 3801e-6, W: 0.011319, X: 7546e-6, Y: 3773e-6, Z: 3773e-6, a: 0.018865, b: 3801e-6, e: 3855e-6, f: 0.018865, g: 3773e-6, h: 3773e-6, i: 3901e-6, j: 3901e-6, k: 7546e-6, l: 7546e-6, m: 7546e-6, n: 0.083006, o: 0.030184, p: 0.015092, q: 0.030184, r: 0.049049, c: 1.12058, H: 0.939477, vB: 0.011319, wB: 0, BC: 8786e-6, CC: 487e-5 }, B: "moz", C: ["AC", "rB", "BC", "CC", "I", "s", "J", "D", "E", "F", "A", "B", "C", "K", "L", "G", "M", "N", "O", "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "AB", "BB", "CB", "DB", "EB", "FB", "GB", "HB", "IB", "JB", "KB", "LB", "MB", "NB", "OB", "PB", "QB", "RB", "SB", "TB", "UB", "VB", "WB", "sB", "XB", "tB", "YB", "ZB", "aB", "bB", "cB", "dB", "eB", "fB", "gB", "hB", "d", "iB", "jB", "kB", "lB", "mB", "nB", "P", "Q", "R", "uB", "S", "T", "U", "V", "W", "X", "Y", "Z", "a", "b", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "c", "H", "vB", "wB", ""], E: "Firefox", F: { "0": 1386633600, "1": 1391472e3, "2": 1395100800, "3": 1398729600, "4": 1402358400, "5": 1405987200, "6": 1409616e3, "7": 1413244800, "8": 1417392e3, "9": 1421107200, AC: 1161648e3, rB: 1213660800, BC: 124632e4, CC: 1264032e3, I: 1300752e3, s: 1308614400, J: 1313452800, D: 1317081600, E: 1317081600, F: 1320710400, A: 1324339200, B: 1327968e3, C: 1331596800, K: 1335225600, L: 1338854400, G: 1342483200, M: 1346112e3, N: 1349740800, O: 1353628800, t: 1357603200, u: 1361232e3, v: 1364860800, w: 1368489600, x: 1372118400, y: 1375747200, z: 1379376e3, AB: 1424736e3, BB: 1428278400, CB: 1431475200, DB: 1435881600, EB: 1439251200, FB: 144288e4, GB: 1446508800, HB: 1450137600, IB: 1453852800, JB: 1457395200, KB: 1461628800, LB: 1465257600, MB: 1470096e3, NB: 1474329600, OB: 1479168e3, PB: 1485216e3, QB: 1488844800, RB: 149256e4, SB: 1497312e3, TB: 1502150400, UB: 1506556800, VB: 1510617600, WB: 1516665600, sB: 1520985600, XB: 1525824e3, tB: 1529971200, YB: 1536105600, ZB: 1540252800, aB: 1544486400, bB: 154872e4, cB: 1552953600, dB: 1558396800, eB: 1562630400, fB: 1567468800, gB: 1571788800, hB: 1575331200, d: 1578355200, iB: 1581379200, jB: 1583798400, kB: 1586304e3, lB: 1588636800, mB: 1591056e3, nB: 1593475200, P: 1595894400, Q: 1598313600, R: 1600732800, uB: 1603152e3, S: 1605571200, T: 1607990400, U: 1611619200, V: 1614038400, W: 1616457600, X: 1618790400, Y: 1622505600, Z: 1626134400, a: 1628553600, b: 1630972800, e: 1633392e3, f: 1635811200, g: 1638835200, h: 1641859200, i: 1644364800, j: 1646697600, k: 1649116800, l: 1651536e3, m: 1653955200, n: 1656374400, o: 1658793600, p: 1661212800, q: 1663632e3, r: 1666051200, c: 1668470400, H: 1670889600, vB: null, wB: null } }, D: { A: { "0": 4141e-6, "1": 4326e-6, "2": 47e-4, "3": 4538e-6, "4": 8322e-6, "5": 8596e-6, "6": 4566e-6, "7": 4118e-6, "8": 7546e-6, "9": 3901e-6, I: 4706e-6, s: 4879e-6, J: 4879e-6, D: 5591e-6, E: 5591e-6, F: 5591e-6, A: 4534e-6, B: 4464e-6, C: 0.010424, K: 83e-4, L: 4706e-6, G: 0.015087, M: 4393e-6, N: 4393e-6, O: 8652e-6, t: 8322e-6, u: 4393e-6, v: 4317e-6, w: 3901e-6, x: 8786e-6, y: 3939e-6, z: 4461e-6, AB: 4335e-6, BB: 4464e-6, CB: 0.015092, DB: 3867e-6, EB: 0.015092, FB: 3773e-6, GB: 3974e-6, HB: 7546e-6, IB: 7948e-6, JB: 3974e-6, KB: 3867e-6, LB: 7546e-6, MB: 0.022638, NB: 0.049049, OB: 3867e-6, PB: 3929e-6, QB: 7546e-6, RB: 0.011319, SB: 3867e-6, TB: 7546e-6, UB: 0.045276, VB: 3773e-6, WB: 3773e-6, sB: 3773e-6, XB: 0.011319, tB: 0.011319, YB: 3773e-6, ZB: 0.015092, aB: 3773e-6, bB: 0.011319, cB: 0.030184, dB: 7546e-6, eB: 7546e-6, fB: 0.079233, gB: 0.026411, hB: 0.011319, d: 0.03773, iB: 0.011319, jB: 0.045276, kB: 0.041503, lB: 0.026411, mB: 0.011319, nB: 0.033957, P: 0.120736, Q: 0.041503, R: 0.041503, S: 0.07546, T: 0.045276, U: 0.094325, V: 0.07546, W: 0.079233, X: 0.018865, Y: 0.033957, Z: 0.026411, a: 0.056595, b: 0.041503, e: 0.049049, f: 0.033957, g: 0.022638, h: 0.041503, i: 0.056595, j: 0.098098, k: 0.049049, l: 0.079233, m: 0.060368, n: 0.098098, o: 0.279202, p: 0.124509, q: 0.192423, r: 0.286748, c: 3.64849, H: 16.8389, vB: 0.033957, wB: 0.018865, DC: 0.011319, EC: 0 }, B: "webkit", C: ["", "", "", "", "I", "s", "J", "D", "E", "F", "A", "B", "C", "K", "L", "G", "M", "N", "O", "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "AB", "BB", "CB", "DB", "EB", "FB", "GB", "HB", "IB", "JB", "KB", "LB", "MB", "NB", "OB", "PB", "QB", "RB", "SB", "TB", "UB", "VB", "WB", "sB", "XB", "tB", "YB", "ZB", "aB", "bB", "cB", "dB", "eB", "fB", "gB", "hB", "d", "iB", "jB", "kB", "lB", "mB", "nB", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "a", "b", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "c", "H", "vB", "wB", "DC", "EC"], E: "Chrome", F: { "0": 1361404800, "1": 1364428800, "2": 1369094400, "3": 1374105600, "4": 1376956800, "5": 1384214400, "6": 1389657600, "7": 1392940800, "8": 1397001600, "9": 1400544e3, I: 1264377600, s: 1274745600, J: 1283385600, D: 1287619200, E: 1291248e3, F: 1296777600, A: 1299542400, B: 1303862400, C: 1307404800, K: 1312243200, L: 1316131200, G: 1316131200, M: 1319500800, N: 1323734400, O: 1328659200, t: 1332892800, u: 133704e4, v: 1340668800, w: 1343692800, x: 1348531200, y: 1352246400, z: 1357862400, AB: 1405468800, BB: 1409011200, CB: 141264e4, DB: 1416268800, EB: 1421798400, FB: 1425513600, GB: 1429401600, HB: 143208e4, IB: 1437523200, JB: 1441152e3, KB: 1444780800, LB: 1449014400, MB: 1453248e3, NB: 1456963200, OB: 1460592e3, PB: 1464134400, QB: 1469059200, RB: 1472601600, SB: 1476230400, TB: 1480550400, UB: 1485302400, VB: 1489017600, WB: 149256e4, sB: 1496707200, XB: 1500940800, tB: 1504569600, YB: 1508198400, ZB: 1512518400, aB: 1516752e3, bB: 1520294400, cB: 1523923200, dB: 1527552e3, eB: 1532390400, fB: 1536019200, gB: 1539648e3, hB: 1543968e3, d: 154872e4, iB: 1552348800, jB: 1555977600, kB: 1559606400, lB: 1564444800, mB: 1568073600, nB: 1571702400, P: 1575936e3, Q: 1580860800, R: 1586304e3, S: 1589846400, T: 1594684800, U: 1598313600, V: 1601942400, W: 1605571200, X: 1611014400, Y: 1614556800, Z: 1618272e3, a: 1621987200, b: 1626739200, e: 1630368e3, f: 1632268800, g: 1634601600, h: 1637020800, i: 1641340800, j: 1643673600, k: 1646092800, l: 1648512e3, m: 1650931200, n: 1653350400, o: 1655769600, p: 1659398400, q: 1661817600, r: 1664236800, c: 1666656e3, H: 166968e4, vB: 1673308800, wB: null, DC: null, EC: null } }, E: { A: { I: 0, s: 8322e-6, J: 4656e-6, D: 4465e-6, E: 3974e-6, F: 3929e-6, A: 4425e-6, B: 4318e-6, C: 3801e-6, K: 0.018865, L: 0.094325, G: 0.022638, FC: 0, xB: 8692e-6, GC: 0.011319, HC: 456e-5, IC: 4283e-6, JC: 0.022638, yB: 7802e-6, oB: 7546e-6, pB: 0.033957, zB: 0.18865, KC: 0.256564, LC: 0.041503, "0B": 0.03773, "1B": 0.094325, "2B": 0.192423, "3B": 1.313, qB: 0.162239, "4B": 0.64141, "5B": 0.143374, "6B": 0, MC: 0 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "FC", "xB", "I", "s", "GC", "J", "HC", "D", "IC", "E", "F", "JC", "A", "yB", "B", "oB", "C", "pB", "K", "zB", "L", "KC", "G", "LC", "0B", "1B", "2B", "3B", "qB", "4B", "5B", "6B", "MC", ""], E: "Safari", F: { FC: 1205798400, xB: 1226534400, I: 1244419200, s: 1275868800, GC: 131112e4, J: 1343174400, HC: 13824e5, D: 13824e5, IC: 1410998400, E: 1413417600, F: 1443657600, JC: 1458518400, A: 1474329600, yB: 1490572800, B: 1505779200, oB: 1522281600, C: 1537142400, pB: 1553472e3, K: 1568851200, zB: 1585008e3, L: 1600214400, KC: 1619395200, G: 1632096e3, LC: 1635292800, "0B": 1639353600, "1B": 1647216e3, "2B": 1652745600, "3B": 1658275200, qB: 1662940800, "4B": 1666569600, "5B": 1670889600, "6B": null, MC: null } }, F: { A: { "0": 5595e-6, "1": 4393e-6, "2": 7546e-6, "3": 4879e-6, "4": 4879e-6, "5": 3773e-6, "6": 5152e-6, "7": 5014e-6, "8": 9758e-6, "9": 4879e-6, F: 82e-4, B: 0.016581, C: 4317e-6, G: 685e-5, M: 685e-5, N: 685e-5, O: 5014e-6, t: 6015e-6, u: 4879e-6, v: 6597e-6, w: 6597e-6, x: 0.013434, y: 6702e-6, z: 6015e-6, AB: 3773e-6, BB: 4283e-6, CB: 4367e-6, DB: 4534e-6, EB: 7546e-6, FB: 4227e-6, GB: 4418e-6, HB: 4161e-6, IB: 4227e-6, JB: 4725e-6, KB: 0.015092, LB: 8942e-6, MB: 4707e-6, NB: 4827e-6, OB: 4707e-6, PB: 4707e-6, QB: 4326e-6, RB: 8922e-6, SB: 0.014349, TB: 4425e-6, UB: 472e-5, VB: 4425e-6, WB: 4425e-6, XB: 472e-5, YB: 4532e-6, ZB: 4566e-6, aB: 0.02283, bB: 867e-5, cB: 4656e-6, dB: 4642e-6, eB: 3929e-6, fB: 944e-5, gB: 4293e-6, hB: 3929e-6, d: 4298e-6, iB: 0.096692, jB: 4201e-6, kB: 4141e-6, lB: 4257e-6, mB: 3939e-6, nB: 8236e-6, P: 3855e-6, Q: 3939e-6, R: 8514e-6, uB: 3939e-6, S: 3939e-6, T: 3702e-6, U: 7546e-6, V: 3855e-6, W: 3855e-6, X: 3929e-6, Y: 7802e-6, Z: 0.011703, a: 7546e-6, b: 0.207515, NC: 685e-5, OC: 0, PC: 8392e-6, QC: 4706e-6, oB: 6229e-6, "7B": 4879e-6, RC: 8786e-6, pB: 472e-5 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "F", "NC", "OC", "PC", "QC", "B", "oB", "7B", "RC", "C", "pB", "G", "M", "N", "O", "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "AB", "BB", "CB", "DB", "EB", "FB", "GB", "HB", "IB", "JB", "KB", "LB", "MB", "NB", "OB", "PB", "QB", "RB", "SB", "TB", "UB", "VB", "WB", "XB", "YB", "ZB", "aB", "bB", "cB", "dB", "eB", "fB", "gB", "hB", "d", "iB", "jB", "kB", "lB", "mB", "nB", "P", "Q", "R", "uB", "S", "T", "U", "V", "W", "X", "Y", "Z", "a", "b", "", "", ""], E: "Opera", F: { "0": 1417132800, "1": 1422316800, "2": 1425945600, "3": 1430179200, "4": 1433808e3, "5": 1438646400, "6": 1442448e3, "7": 1445904e3, "8": 1449100800, "9": 1454371200, F: 1150761600, NC: 1223424e3, OC: 1251763200, PC: 1267488e3, QC: 1277942400, B: 1292457600, oB: 1302566400, "7B": 1309219200, RC: 1323129600, C: 1323129600, pB: 1352073600, G: 1372723200, M: 1377561600, N: 1381104e3, O: 1386288e3, t: 1390867200, u: 1393891200, v: 1399334400, w: 1401753600, x: 1405987200, y: 1409616e3, z: 1413331200, AB: 1457308800, BB: 146232e4, CB: 1465344e3, DB: 1470096e3, EB: 1474329600, FB: 1477267200, GB: 1481587200, HB: 1486425600, IB: 1490054400, JB: 1494374400, KB: 1498003200, LB: 1502236800, MB: 1506470400, NB: 1510099200, OB: 1515024e3, PB: 1517961600, QB: 1521676800, RB: 1525910400, SB: 1530144e3, TB: 1534982400, UB: 1537833600, VB: 1543363200, WB: 1548201600, XB: 1554768e3, YB: 1561593600, ZB: 1566259200, aB: 1570406400, bB: 1573689600, cB: 1578441600, dB: 1583971200, eB: 1587513600, fB: 1592956800, gB: 1595894400, hB: 1600128e3, d: 1603238400, iB: 161352e4, jB: 1612224e3, kB: 1616544e3, lB: 1619568e3, mB: 1623715200, nB: 1627948800, P: 1631577600, Q: 1633392e3, R: 1635984e3, uB: 1638403200, S: 1642550400, T: 1644969600, U: 1647993600, V: 1650412800, W: 1652745600, X: 1654646400, Y: 1657152e3, Z: 1660780800, a: 1663113600, b: 1668816e3 }, D: { F: "o", B: "o", C: "o", NC: "o", OC: "o", PC: "o", QC: "o", oB: "o", "7B": "o", RC: "o", pB: "o" } }, G: { A: { E: 0, xB: 0, SC: 0, "8B": 470195e-8, TC: 470195e-8, UC: 313463e-8, VC: 0.0141058, WC: 626926e-8, XC: 0.0188078, YC: 0.0611253, ZC: 783658e-8, aC: 0.106577, bC: 0.0282117, cC: 0.0266444, dC: 0.0250771, eC: 0.405935, fC: 0.0423175, gC: 0.0109712, hC: 0.0391829, iC: 0.141058, jC: 0.340108, kC: 0.647301, lC: 0.186511, "0B": 0.239799, "1B": 0.304059, "2B": 0.546993, "3B": 2.31493, qB: 2.09864, "4B": 6.33196, "5B": 0.694321, "6B": 0.0156732 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "xB", "SC", "8B", "TC", "UC", "VC", "E", "WC", "XC", "YC", "ZC", "aC", "bC", "cC", "dC", "eC", "fC", "gC", "hC", "iC", "jC", "kC", "lC", "0B", "1B", "2B", "3B", "qB", "4B", "5B", "6B", "", ""], E: "Safari on iOS", F: { xB: 1270252800, SC: 1283904e3, "8B": 1299628800, TC: 1331078400, UC: 1359331200, VC: 1394409600, E: 1410912e3, WC: 1413763200, XC: 1442361600, YC: 1458518400, ZC: 1473724800, aC: 1490572800, bC: 1505779200, cC: 1522281600, dC: 1537142400, eC: 1553472e3, fC: 1568851200, gC: 1572220800, hC: 1580169600, iC: 1585008e3, jC: 1600214400, kC: 1619395200, lC: 1632096e3, "0B": 1639353600, "1B": 1647216e3, "2B": 1652659200, "3B": 1658275200, qB: 1662940800, "4B": 1666569600, "5B": 1670889600, "6B": null } }, H: { A: { mC: 0.966988 }, B: "o", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "mC", "", "", ""], E: "Opera Mini", F: { mC: 1426464e3 } }, I: { A: { rB: 0, I: 0.0306951, H: 0, nC: 0, oC: 0.0204634, pC: 0, qC: 0.0204634, "8B": 0.0818537, rC: 0, sC: 0.4195 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "nC", "oC", "pC", "rB", "I", "qC", "8B", "rC", "sC", "H", "", "", ""], E: "Android Browser", F: { nC: 1256515200, oC: 1274313600, pC: 1291593600, rB: 1298332800, I: 1318896e3, qC: 1341792e3, "8B": 1374624e3, rC: 1386547200, sC: 1401667200, H: 1669939200 } }, J: { A: { D: 0, A: 0 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "D", "A", "", "", ""], E: "Blackberry Browser", F: { D: 1325376e3, A: 1359504e3 } }, K: { A: { A: 0, B: 0, C: 0, d: 0.0111391, oB: 0, "7B": 0, pB: 0 }, B: "o", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "A", "B", "oB", "7B", "C", "pB", "d", "", "", ""], E: "Opera Mobile", F: { A: 1287100800, B: 1300752e3, oB: 1314835200, "7B": 1318291200, C: 1330300800, pB: 1349740800, d: 1666828800 }, D: { d: "webkit" } }, L: { A: { H: 41.5426 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "H", "", "", ""], E: "Chrome for Android", F: { H: 1669939200 } }, M: { A: { c: 0.292716 }, B: "moz", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "c", "", "", ""], E: "Firefox for Android", F: { c: 1668470400 } }, N: { A: { A: 0.0115934, B: 0.022664 }, B: "ms", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "A", "B", "", "", ""], E: "IE Mobile", F: { A: 1340150400, B: 1353456e3 } }, O: { A: { tC: 1.75007 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "tC", "", "", ""], E: "UC Browser for Android", F: { tC: 1634688e3 }, D: { tC: "webkit" } }, P: { A: { I: 0.166409, uC: 0.0103543, vC: 0.010304, wC: 0.0520028, xC: 0.0103584, yC: 0.0104443, yB: 0.0105043, zC: 0.0312017, "0C": 0.0104006, "1C": 0.0520028, "2C": 0.0624033, "3C": 0.0312017, qB: 0.114406, "4C": 0.124807, "5C": 0.249613, "6C": 2.25692 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "I", "uC", "vC", "wC", "xC", "yC", "yB", "zC", "0C", "1C", "2C", "3C", "qB", "4C", "5C", "6C", "", "", ""], E: "Samsung Internet", F: { I: 1461024e3, uC: 1481846400, vC: 1509408e3, wC: 1528329600, xC: 1546128e3, yC: 1554163200, yB: 1567900800, zC: 1582588800, "0C": 1593475200, "1C": 1605657600, "2C": 1618531200, "3C": 1629072e3, qB: 1640736e3, "4C": 1651708800, "5C": 1659657600, "6C": 1667260800 } }, Q: { A: { zB: 0.199296 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "zB", "", "", ""], E: "QQ Browser", F: { zB: 1663718400 } }, R: { A: { "7C": 0 }, B: "webkit", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "7C", "", "", ""], E: "Baidu Browser", F: { "7C": 1663027200 } }, S: { A: { "8C": 0.068508 }, B: "moz", C: ["", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "8C", "", "", ""], E: "KaiOS Browser", F: { "8C": 1527811200 } } };
  }
});

// node_modules/caniuse-lite/dist/unpacker/agents.js
var require_agents2 = __commonJS({
  "node_modules/caniuse-lite/dist/unpacker/agents.js"(exports, module2) {
    "use strict";
    var browsers = require_browsers2().browsers;
    var versions = require_browserVersions2().browserVersions;
    var agentsData = require_agents();
    function unpackBrowserVersions(versionsData) {
      return Object.keys(versionsData).reduce((usage, version2) => {
        usage[versions[version2]] = versionsData[version2];
        return usage;
      }, {});
    }
    module2.exports.agents = Object.keys(agentsData).reduce((map, key) => {
      let versionsData = agentsData[key];
      map[browsers[key]] = Object.keys(versionsData).reduce((data, entry) => {
        if (entry === "A") {
          data.usage_global = unpackBrowserVersions(versionsData[entry]);
        } else if (entry === "C") {
          data.versions = versionsData[entry].reduce((list, version2) => {
            if (version2 === "") {
              list.push(null);
            } else {
              list.push(versions[version2]);
            }
            return list;
          }, []);
        } else if (entry === "D") {
          data.prefix_exceptions = unpackBrowserVersions(versionsData[entry]);
        } else if (entry === "E") {
          data.browser = versionsData[entry];
        } else if (entry === "F") {
          data.release_date = Object.keys(versionsData[entry]).reduce(
            (map2, key2) => {
              map2[versions[key2]] = versionsData[entry][key2];
              return map2;
            },
            {}
          );
        } else {
          data.prefix = versionsData[entry];
        }
        return data;
      }, {});
      return map;
    }, {});
  }
});

// node_modules/node-releases/data/release-schedule/release-schedule.json
var require_release_schedule = __commonJS({
  "node_modules/node-releases/data/release-schedule/release-schedule.json"(exports, module2) {
    module2.exports = { "v0.8": { start: "2012-06-25", end: "2014-07-31" }, "v0.10": { start: "2013-03-11", end: "2016-10-31" }, "v0.12": { start: "2015-02-06", end: "2016-12-31" }, v4: { start: "2015-09-08", lts: "2015-10-12", maintenance: "2017-04-01", end: "2018-04-30", codename: "Argon" }, v5: { start: "2015-10-29", maintenance: "2016-04-30", end: "2016-06-30" }, v6: { start: "2016-04-26", lts: "2016-10-18", maintenance: "2018-04-30", end: "2019-04-30", codename: "Boron" }, v7: { start: "2016-10-25", maintenance: "2017-04-30", end: "2017-06-30" }, v8: { start: "2017-05-30", lts: "2017-10-31", maintenance: "2019-01-01", end: "2019-12-31", codename: "Carbon" }, v9: { start: "2017-10-01", maintenance: "2018-04-01", end: "2018-06-30" }, v10: { start: "2018-04-24", lts: "2018-10-30", maintenance: "2020-05-19", end: "2021-04-30", codename: "Dubnium" }, v11: { start: "2018-10-23", maintenance: "2019-04-22", end: "2019-06-01" }, v12: { start: "2019-04-23", lts: "2019-10-21", maintenance: "2020-11-30", end: "2022-04-30", codename: "Erbium" }, v13: { start: "2019-10-22", maintenance: "2020-04-01", end: "2020-06-01" }, v14: { start: "2020-04-21", lts: "2020-10-27", maintenance: "2021-10-19", end: "2023-04-30", codename: "Fermium" }, v15: { start: "2020-10-20", maintenance: "2021-04-01", end: "2021-06-01" }, v16: { start: "2021-04-20", lts: "2021-10-26", maintenance: "2022-10-18", end: "2023-09-11", codename: "Gallium" }, v17: { start: "2021-10-19", maintenance: "2022-04-01", end: "2022-06-01" }, v18: { start: "2022-04-19", lts: "2022-10-25", maintenance: "2023-10-18", end: "2025-04-30", codename: "Hydrogen" }, v19: { start: "2022-10-18", maintenance: "2023-04-01", end: "2023-06-01" }, v20: { start: "2023-04-18", lts: "2023-10-24", maintenance: "2024-10-22", end: "2026-04-30", codename: "" } };
  }
});

// node_modules/electron-to-chromium/versions.js
var require_versions = __commonJS({
  "node_modules/electron-to-chromium/versions.js"(exports, module2) {
    module2.exports = {
      "0.20": "39",
      "0.21": "41",
      "0.22": "41",
      "0.23": "41",
      "0.24": "41",
      "0.25": "42",
      "0.26": "42",
      "0.27": "43",
      "0.28": "43",
      "0.29": "43",
      "0.30": "44",
      "0.31": "45",
      "0.32": "45",
      "0.33": "45",
      "0.34": "45",
      "0.35": "45",
      "0.36": "47",
      "0.37": "49",
      "1.0": "49",
      "1.1": "50",
      "1.2": "51",
      "1.3": "52",
      "1.4": "53",
      "1.5": "54",
      "1.6": "56",
      "1.7": "58",
      "1.8": "59",
      "2.0": "61",
      "2.1": "61",
      "3.0": "66",
      "3.1": "66",
      "4.0": "69",
      "4.1": "69",
      "4.2": "69",
      "5.0": "73",
      "6.0": "76",
      "6.1": "76",
      "7.0": "78",
      "7.1": "78",
      "7.2": "78",
      "7.3": "78",
      "8.0": "80",
      "8.1": "80",
      "8.2": "80",
      "8.3": "80",
      "8.4": "80",
      "8.5": "80",
      "9.0": "83",
      "9.1": "83",
      "9.2": "83",
      "9.3": "83",
      "9.4": "83",
      "10.0": "85",
      "10.1": "85",
      "10.2": "85",
      "10.3": "85",
      "10.4": "85",
      "11.0": "87",
      "11.1": "87",
      "11.2": "87",
      "11.3": "87",
      "11.4": "87",
      "11.5": "87",
      "12.0": "89",
      "12.1": "89",
      "12.2": "89",
      "13.0": "91",
      "13.1": "91",
      "13.2": "91",
      "13.3": "91",
      "13.4": "91",
      "13.5": "91",
      "13.6": "91",
      "14.0": "93",
      "14.1": "93",
      "14.2": "93",
      "15.0": "94",
      "15.1": "94",
      "15.2": "94",
      "15.3": "94",
      "15.4": "94",
      "15.5": "94",
      "16.0": "96",
      "16.1": "96",
      "16.2": "96",
      "17.0": "98",
      "17.1": "98",
      "17.2": "98",
      "17.3": "98",
      "17.4": "98",
      "18.0": "100",
      "18.1": "100",
      "18.2": "100",
      "18.3": "100",
      "19.0": "102",
      "19.1": "102",
      "20.0": "104",
      "20.1": "104",
      "20.2": "104",
      "20.3": "104",
      "21.0": "106",
      "21.1": "106",
      "22.0": "108"
    };
  }
});

// node_modules/browserslist/error.js
var require_error2 = __commonJS({
  "node_modules/browserslist/error.js"(exports, module2) {
    function BrowserslistError(message) {
      this.name = "BrowserslistError";
      this.message = message;
      this.browserslist = true;
      if (Error.captureStackTrace) {
        Error.captureStackTrace(this, BrowserslistError);
      }
    }
    BrowserslistError.prototype = Error.prototype;
    module2.exports = BrowserslistError;
  }
});

// node_modules/browserslist/parse.js
var require_parse3 = __commonJS({
  "node_modules/browserslist/parse.js"(exports, module2) {
    var AND_REGEXP = /^\s+and\s+(.*)/i;
    var OR_REGEXP = /^(?:,\s*|\s+or\s+)(.*)/i;
    function flatten(array) {
      if (!Array.isArray(array))
        return [array];
      return array.reduce(function(a, b) {
        return a.concat(flatten(b));
      }, []);
    }
    function find(string, predicate) {
      for (var n = 1, max2 = string.length; n <= max2; n++) {
        var parsed = string.substr(-n, n);
        if (predicate(parsed, n, max2)) {
          return string.slice(0, -n);
        }
      }
      return "";
    }
    function matchQuery(all, query) {
      var node = { query };
      if (query.indexOf("not ") === 0) {
        node.not = true;
        query = query.slice(4);
      }
      for (var name in all) {
        var type = all[name];
        var match = query.match(type.regexp);
        if (match) {
          node.type = name;
          for (var i = 0; i < type.matches.length; i++) {
            node[type.matches[i]] = match[i + 1];
          }
          return node;
        }
      }
      node.type = "unknown";
      return node;
    }
    function matchBlock(all, string, qs) {
      var node;
      return find(string, function(parsed, n, max2) {
        if (AND_REGEXP.test(parsed)) {
          node = matchQuery(all, parsed.match(AND_REGEXP)[1]);
          node.compose = "and";
          qs.unshift(node);
          return true;
        } else if (OR_REGEXP.test(parsed)) {
          node = matchQuery(all, parsed.match(OR_REGEXP)[1]);
          node.compose = "or";
          qs.unshift(node);
          return true;
        } else if (n === max2) {
          node = matchQuery(all, parsed.trim());
          node.compose = "or";
          qs.unshift(node);
          return true;
        }
        return false;
      });
    }
    module2.exports = function parse3(all, queries) {
      if (!Array.isArray(queries))
        queries = [queries];
      return flatten(
        queries.map(function(block) {
          var qs = [];
          do {
            block = matchBlock(all, block, qs);
          } while (block);
          return qs;
        })
      );
    };
  }
});

// node_modules/caniuse-lite/dist/lib/statuses.js
var require_statuses = __commonJS({
  "node_modules/caniuse-lite/dist/lib/statuses.js"(exports, module2) {
    module2.exports = {
      1: "ls",
      // WHATWG Living Standard
      2: "rec",
      // W3C Recommendation
      3: "pr",
      // W3C Proposed Recommendation
      4: "cr",
      // W3C Candidate Recommendation
      5: "wd",
      // W3C Working Draft
      6: "other",
      // Non-W3C, but reputable
      7: "unoff"
      // Unofficial, Editor's Draft or W3C "Note"
    };
  }
});

// node_modules/caniuse-lite/dist/lib/supported.js
var require_supported = __commonJS({
  "node_modules/caniuse-lite/dist/lib/supported.js"(exports, module2) {
    module2.exports = {
      y: 1 << 0,
      n: 1 << 1,
      a: 1 << 2,
      p: 1 << 3,
      u: 1 << 4,
      x: 1 << 5,
      d: 1 << 6
    };
  }
});

// node_modules/caniuse-lite/dist/unpacker/feature.js
var require_feature = __commonJS({
  "node_modules/caniuse-lite/dist/unpacker/feature.js"(exports, module2) {
    "use strict";
    var statuses = require_statuses();
    var supported = require_supported();
    var browsers = require_browsers2().browsers;
    var versions = require_browserVersions2().browserVersions;
    var MATH2LOG = Math.log(2);
    function unpackSupport(cipher) {
      let stats = Object.keys(supported).reduce((list, support) => {
        if (cipher & supported[support])
          list.push(support);
        return list;
      }, []);
      let notes = cipher >> 7;
      let notesArray = [];
      while (notes) {
        let note = Math.floor(Math.log(notes) / MATH2LOG) + 1;
        notesArray.unshift(`#${note}`);
        notes -= Math.pow(2, note - 1);
      }
      return stats.concat(notesArray).join(" ");
    }
    function unpackFeature(packed) {
      let unpacked = { status: statuses[packed.B], title: packed.C };
      unpacked.stats = Object.keys(packed.A).reduce((browserStats, key) => {
        let browser = packed.A[key];
        browserStats[browsers[key]] = Object.keys(browser).reduce(
          (stats, support) => {
            let packedVersions = browser[support].split(" ");
            let unpacked2 = unpackSupport(support);
            packedVersions.forEach((v) => stats[versions[v]] = unpacked2);
            return stats;
          },
          {}
        );
        return browserStats;
      }, {});
      return unpacked;
    }
    module2.exports = unpackFeature;
    module2.exports.default = unpackFeature;
  }
});

// node_modules/caniuse-lite/dist/unpacker/region.js
var require_region = __commonJS({
  "node_modules/caniuse-lite/dist/unpacker/region.js"(exports, module2) {
    "use strict";
    var browsers = require_browsers2().browsers;
    function unpackRegion(packed) {
      return Object.keys(packed).reduce((list, browser) => {
        let data = packed[browser];
        list[browsers[browser]] = Object.keys(data).reduce((memo, key) => {
          let stats = data[key];
          if (key === "_") {
            stats.split(" ").forEach((version2) => memo[version2] = null);
          } else {
            memo[key] = stats;
          }
          return memo;
        }, {});
        return list;
      }, {});
    }
    module2.exports = unpackRegion;
    module2.exports.default = unpackRegion;
  }
});

// node_modules/browserslist/node.js
var require_node4 = __commonJS({
  "node_modules/browserslist/node.js"(exports, module2) {
    var feature = require_feature().default;
    var region = require_region().default;
    var path2 = require("path");
    var fs2 = require("fs");
    var BrowserslistError = require_error2();
    var IS_SECTION = /^\s*\[(.+)]\s*$/;
    var CONFIG_PATTERN = /^browserslist-config-/;
    var SCOPED_CONFIG__PATTERN = /@[^/]+\/browserslist-config(-|$|\/)/;
    var TIME_TO_UPDATE_CANIUSE = 6 * 30 * 24 * 60 * 60 * 1e3;
    var FORMAT = "Browserslist config should be a string or an array of strings with browser queries";
    var dataTimeChecked = false;
    var filenessCache = {};
    var configCache = {};
    function checkExtend(name) {
      var use = " Use `dangerousExtend` option to disable.";
      if (!CONFIG_PATTERN.test(name) && !SCOPED_CONFIG__PATTERN.test(name)) {
        throw new BrowserslistError(
          "Browserslist config needs `browserslist-config-` prefix. " + use
        );
      }
      if (name.replace(/^@[^/]+\//, "").indexOf(".") !== -1) {
        throw new BrowserslistError(
          "`.` not allowed in Browserslist config name. " + use
        );
      }
      if (name.indexOf("node_modules") !== -1) {
        throw new BrowserslistError(
          "`node_modules` not allowed in Browserslist config." + use
        );
      }
    }
    function isFile2(file) {
      if (file in filenessCache) {
        return filenessCache[file];
      }
      var result = fs2.existsSync(file) && fs2.statSync(file).isFile();
      if (!process.env.BROWSERSLIST_DISABLE_CACHE) {
        filenessCache[file] = result;
      }
      return result;
    }
    function eachParent(file, callback) {
      var dir = isFile2(file) ? path2.dirname(file) : file;
      var loc = path2.resolve(dir);
      do {
        var result = callback(loc);
        if (typeof result !== "undefined")
          return result;
      } while (loc !== (loc = path2.dirname(loc)));
      return void 0;
    }
    function check(section) {
      if (Array.isArray(section)) {
        for (var i = 0; i < section.length; i++) {
          if (typeof section[i] !== "string") {
            throw new BrowserslistError(FORMAT);
          }
        }
      } else if (typeof section !== "string") {
        throw new BrowserslistError(FORMAT);
      }
    }
    function pickEnv(config, opts) {
      if (typeof config !== "object")
        return config;
      var name;
      if (typeof opts.env === "string") {
        name = opts.env;
      } else if (process.env.BROWSERSLIST_ENV) {
        name = process.env.BROWSERSLIST_ENV;
      } else if (process.env.NODE_ENV) {
        name = process.env.NODE_ENV;
      } else {
        name = "production";
      }
      if (opts.throwOnMissing) {
        if (name && name !== "defaults" && !config[name]) {
          throw new BrowserslistError(
            "Missing config for Browserslist environment `" + name + "`"
          );
        }
      }
      return config[name] || config.defaults;
    }
    function parsePackage(file) {
      var config = JSON.parse(
        fs2.readFileSync(file).toString().replace(/^\uFEFF/m, "")
      );
      if (config.browserlist && !config.browserslist) {
        throw new BrowserslistError(
          "`browserlist` key instead of `browserslist` in " + file
        );
      }
      var list = config.browserslist;
      if (Array.isArray(list) || typeof list === "string") {
        list = { defaults: list };
      }
      for (var i in list) {
        check(list[i]);
      }
      return list;
    }
    function latestReleaseTime(agents) {
      var latest = 0;
      for (var name in agents) {
        var dates = agents[name].releaseDate || {};
        for (var key in dates) {
          if (latest < dates[key]) {
            latest = dates[key];
          }
        }
      }
      return latest * 1e3;
    }
    function normalizeStats(data, stats) {
      if (!data) {
        data = {};
      }
      if (stats && "dataByBrowser" in stats) {
        stats = stats.dataByBrowser;
      }
      if (typeof stats !== "object")
        return void 0;
      var normalized = {};
      for (var i in stats) {
        var versions = Object.keys(stats[i]);
        if (versions.length === 1 && data[i] && data[i].versions.length === 1) {
          var normal = data[i].versions[0];
          normalized[i] = {};
          normalized[i][normal] = stats[i][versions[0]];
        } else {
          normalized[i] = stats[i];
        }
      }
      return normalized;
    }
    function normalizeUsageData(usageData, data) {
      for (var browser in usageData) {
        var browserUsage = usageData[browser];
        if ("0" in browserUsage) {
          var versions = data[browser].versions;
          browserUsage[versions[versions.length - 1]] = browserUsage[0];
          delete browserUsage[0];
        }
      }
    }
    module2.exports = {
      loadQueries: function loadQueries(ctx, name) {
        if (!ctx.dangerousExtend && !process.env.BROWSERSLIST_DANGEROUS_EXTEND) {
          checkExtend(name);
        }
        var queries = require(require.resolve(name, { paths: [".", ctx.path] }));
        if (queries) {
          if (Array.isArray(queries)) {
            return queries;
          } else if (typeof queries === "object") {
            if (!queries.defaults)
              queries.defaults = [];
            return pickEnv(queries, ctx, name);
          }
        }
        throw new BrowserslistError(
          "`" + name + "` config exports not an array of queries or an object of envs"
        );
      },
      loadStat: function loadStat(ctx, name, data) {
        if (!ctx.dangerousExtend && !process.env.BROWSERSLIST_DANGEROUS_EXTEND) {
          checkExtend(name);
        }
        var stats = require(require.resolve(
          path2.join(name, "browserslist-stats.json"),
          { paths: ["."] }
        ));
        return normalizeStats(data, stats);
      },
      getStat: function getStat(opts, data) {
        var stats;
        if (opts.stats) {
          stats = opts.stats;
        } else if (process.env.BROWSERSLIST_STATS) {
          stats = process.env.BROWSERSLIST_STATS;
        } else if (opts.path && path2.resolve && fs2.existsSync) {
          stats = eachParent(opts.path, function(dir) {
            var file = path2.join(dir, "browserslist-stats.json");
            return isFile2(file) ? file : void 0;
          });
        }
        if (typeof stats === "string") {
          try {
            stats = JSON.parse(fs2.readFileSync(stats));
          } catch (e) {
            throw new BrowserslistError("Can't read " + stats);
          }
        }
        return normalizeStats(data, stats);
      },
      loadConfig: function loadConfig(opts) {
        if (process.env.BROWSERSLIST) {
          return process.env.BROWSERSLIST;
        } else if (opts.config || process.env.BROWSERSLIST_CONFIG) {
          var file = opts.config || process.env.BROWSERSLIST_CONFIG;
          if (path2.basename(file) === "package.json") {
            return pickEnv(parsePackage(file), opts);
          } else {
            return pickEnv(module2.exports.readConfig(file), opts);
          }
        } else if (opts.path) {
          return pickEnv(module2.exports.findConfig(opts.path), opts);
        } else {
          return void 0;
        }
      },
      loadCountry: function loadCountry(usage, country, data) {
        var code = country.replace(/[^\w-]/g, "");
        if (!usage[code]) {
          var compressed;
          try {
            compressed = require("caniuse-lite/data/regions/" + code + ".js");
          } catch (e) {
            throw new BrowserslistError("Unknown region name `" + code + "`.");
          }
          var usageData = region(compressed);
          normalizeUsageData(usageData, data);
          usage[country] = {};
          for (var i in usageData) {
            for (var j in usageData[i]) {
              usage[country][i + " " + j] = usageData[i][j];
            }
          }
        }
      },
      loadFeature: function loadFeature(features, name) {
        name = name.replace(/[^\w-]/g, "");
        if (features[name])
          return;
        var compressed;
        try {
          compressed = require("caniuse-lite/data/features/" + name + ".js");
        } catch (e) {
          throw new BrowserslistError("Unknown feature name `" + name + "`.");
        }
        var stats = feature(compressed).stats;
        features[name] = {};
        for (var i in stats) {
          for (var j in stats[i]) {
            features[name][i + " " + j] = stats[i][j];
          }
        }
      },
      parseConfig: function parseConfig(string) {
        var result = { defaults: [] };
        var sections = ["defaults"];
        string.toString().replace(/#[^\n]*/g, "").split(/\n|,/).map(function(line) {
          return line.trim();
        }).filter(function(line) {
          return line !== "";
        }).forEach(function(line) {
          if (IS_SECTION.test(line)) {
            sections = line.match(IS_SECTION)[1].trim().split(" ");
            sections.forEach(function(section) {
              if (result[section]) {
                throw new BrowserslistError(
                  "Duplicate section " + section + " in Browserslist config"
                );
              }
              result[section] = [];
            });
          } else {
            sections.forEach(function(section) {
              result[section].push(line);
            });
          }
        });
        return result;
      },
      readConfig: function readConfig(file) {
        if (!isFile2(file)) {
          throw new BrowserslistError("Can't read " + file + " config");
        }
        return module2.exports.parseConfig(fs2.readFileSync(file));
      },
      findConfig: function findConfig(from) {
        from = path2.resolve(from);
        var passed = [];
        var resolved = eachParent(from, function(dir) {
          if (dir in configCache) {
            return configCache[dir];
          }
          passed.push(dir);
          var config = path2.join(dir, "browserslist");
          var pkg = path2.join(dir, "package.json");
          var rc = path2.join(dir, ".browserslistrc");
          var pkgBrowserslist;
          if (isFile2(pkg)) {
            try {
              pkgBrowserslist = parsePackage(pkg);
            } catch (e) {
              if (e.name === "BrowserslistError")
                throw e;
              console.warn(
                "[Browserslist] Could not parse " + pkg + ". Ignoring it."
              );
            }
          }
          if (isFile2(config) && pkgBrowserslist) {
            throw new BrowserslistError(
              dir + " contains both browserslist and package.json with browsers"
            );
          } else if (isFile2(rc) && pkgBrowserslist) {
            throw new BrowserslistError(
              dir + " contains both .browserslistrc and package.json with browsers"
            );
          } else if (isFile2(config) && isFile2(rc)) {
            throw new BrowserslistError(
              dir + " contains both .browserslistrc and browserslist"
            );
          } else if (isFile2(config)) {
            return module2.exports.readConfig(config);
          } else if (isFile2(rc)) {
            return module2.exports.readConfig(rc);
          } else {
            return pkgBrowserslist;
          }
        });
        if (!process.env.BROWSERSLIST_DISABLE_CACHE) {
          passed.forEach(function(dir) {
            configCache[dir] = resolved;
          });
        }
        return resolved;
      },
      clearCaches: function clearCaches() {
        dataTimeChecked = false;
        filenessCache = {};
        configCache = {};
        this.cache = {};
      },
      oldDataWarning: function oldDataWarning(agentsObj) {
        if (dataTimeChecked)
          return;
        dataTimeChecked = true;
        if (process.env.BROWSERSLIST_IGNORE_OLD_DATA)
          return;
        var latest = latestReleaseTime(agentsObj);
        var halfYearAgo = Date.now() - TIME_TO_UPDATE_CANIUSE;
        if (latest !== 0 && latest < halfYearAgo) {
          console.warn(
            "Browserslist: caniuse-lite is outdated. Please run:\n  npx update-browserslist-db@latest\n  Why you should do it regularly: https://github.com/browserslist/update-db#readme"
          );
        }
      },
      currentNode: function currentNode() {
        return "node " + process.versions.node;
      }
    };
  }
});

// node_modules/browserslist/index.js
var require_browserslist = __commonJS({
  "node_modules/browserslist/index.js"(exports, module2) {
    var jsReleases = require_envs();
    var agents = require_agents2().agents;
    var jsEOL = require_release_schedule();
    var path2 = require("path");
    var e2c = require_versions();
    var BrowserslistError = require_error2();
    var parse3 = require_parse3();
    var env = require_node4();
    var YEAR = 365.259641 * 24 * 60 * 60 * 1e3;
    var ANDROID_EVERGREEN_FIRST = 37;
    function isVersionsMatch(versionA, versionB) {
      return (versionA + ".").indexOf(versionB + ".") === 0;
    }
    function isEolReleased(name) {
      var version2 = name.slice(1);
      return browserslist.nodeVersions.some(function(i) {
        return isVersionsMatch(i, version2);
      });
    }
    function normalize(versions) {
      return versions.filter(function(version2) {
        return typeof version2 === "string";
      });
    }
    function normalizeElectron(version2) {
      var versionToUse = version2;
      if (version2.split(".").length === 3) {
        versionToUse = version2.split(".").slice(0, -1).join(".");
      }
      return versionToUse;
    }
    function nameMapper(name) {
      return function mapName(version2) {
        return name + " " + version2;
      };
    }
    function getMajor(version2) {
      return parseInt(version2.split(".")[0]);
    }
    function getMajorVersions(released, number) {
      if (released.length === 0)
        return [];
      var majorVersions = uniq(released.map(getMajor));
      var minimum = majorVersions[majorVersions.length - number];
      if (!minimum) {
        return released;
      }
      var selected = [];
      for (var i = released.length - 1; i >= 0; i--) {
        if (minimum > getMajor(released[i]))
          break;
        selected.unshift(released[i]);
      }
      return selected;
    }
    function uniq(array) {
      var filtered = [];
      for (var i = 0; i < array.length; i++) {
        if (filtered.indexOf(array[i]) === -1)
          filtered.push(array[i]);
      }
      return filtered;
    }
    function fillUsage(result, name, data) {
      for (var i in data) {
        result[name + " " + i] = data[i];
      }
    }
    function generateFilter(sign, version2) {
      version2 = parseFloat(version2);
      if (sign === ">") {
        return function(v) {
          return parseFloat(v) > version2;
        };
      } else if (sign === ">=") {
        return function(v) {
          return parseFloat(v) >= version2;
        };
      } else if (sign === "<") {
        return function(v) {
          return parseFloat(v) < version2;
        };
      } else {
        return function(v) {
          return parseFloat(v) <= version2;
        };
      }
    }
    function generateSemverFilter(sign, version2) {
      version2 = version2.split(".").map(parseSimpleInt);
      version2[1] = version2[1] || 0;
      version2[2] = version2[2] || 0;
      if (sign === ">") {
        return function(v) {
          v = v.split(".").map(parseSimpleInt);
          return compareSemver(v, version2) > 0;
        };
      } else if (sign === ">=") {
        return function(v) {
          v = v.split(".").map(parseSimpleInt);
          return compareSemver(v, version2) >= 0;
        };
      } else if (sign === "<") {
        return function(v) {
          v = v.split(".").map(parseSimpleInt);
          return compareSemver(version2, v) > 0;
        };
      } else {
        return function(v) {
          v = v.split(".").map(parseSimpleInt);
          return compareSemver(version2, v) >= 0;
        };
      }
    }
    function parseSimpleInt(x) {
      return parseInt(x);
    }
    function compare(a, b) {
      if (a < b)
        return -1;
      if (a > b)
        return 1;
      return 0;
    }
    function compareSemver(a, b) {
      return compare(parseInt(a[0]), parseInt(b[0])) || compare(parseInt(a[1] || "0"), parseInt(b[1] || "0")) || compare(parseInt(a[2] || "0"), parseInt(b[2] || "0"));
    }
    function semverFilterLoose(operator, range) {
      range = range.split(".").map(parseSimpleInt);
      if (typeof range[1] === "undefined") {
        range[1] = "x";
      }
      switch (operator) {
        case "<=":
          return function(version2) {
            version2 = version2.split(".").map(parseSimpleInt);
            return compareSemverLoose(version2, range) <= 0;
          };
        case ">=":
        default:
          return function(version2) {
            version2 = version2.split(".").map(parseSimpleInt);
            return compareSemverLoose(version2, range) >= 0;
          };
      }
    }
    function compareSemverLoose(version2, range) {
      if (version2[0] !== range[0]) {
        return version2[0] < range[0] ? -1 : 1;
      }
      if (range[1] === "x") {
        return 0;
      }
      if (version2[1] !== range[1]) {
        return version2[1] < range[1] ? -1 : 1;
      }
      return 0;
    }
    function resolveVersion(data, version2) {
      if (data.versions.indexOf(version2) !== -1) {
        return version2;
      } else if (browserslist.versionAliases[data.name][version2]) {
        return browserslist.versionAliases[data.name][version2];
      } else {
        return false;
      }
    }
    function normalizeVersion(data, version2) {
      var resolved = resolveVersion(data, version2);
      if (resolved) {
        return resolved;
      } else if (data.versions.length === 1) {
        return data.versions[0];
      } else {
        return false;
      }
    }
    function filterByYear(since, context) {
      since = since / 1e3;
      return Object.keys(agents).reduce(function(selected, name) {
        var data = byName(name, context);
        if (!data)
          return selected;
        var versions = Object.keys(data.releaseDate).filter(function(v) {
          var date = data.releaseDate[v];
          return date !== null && date >= since;
        });
        return selected.concat(versions.map(nameMapper(data.name)));
      }, []);
    }
    function cloneData(data) {
      return {
        name: data.name,
        versions: data.versions,
        released: data.released,
        releaseDate: data.releaseDate
      };
    }
    function mapVersions(data, map) {
      data.versions = data.versions.map(function(i2) {
        return map[i2] || i2;
      });
      data.released = data.released.map(function(i2) {
        return map[i2] || i2;
      });
      var fixedDate = {};
      for (var i in data.releaseDate) {
        fixedDate[map[i] || i] = data.releaseDate[i];
      }
      data.releaseDate = fixedDate;
      return data;
    }
    function byName(name, context) {
      name = name.toLowerCase();
      name = browserslist.aliases[name] || name;
      if (context.mobileToDesktop && browserslist.desktopNames[name]) {
        var desktop = browserslist.data[browserslist.desktopNames[name]];
        if (name === "android") {
          return normalizeAndroidData(cloneData(browserslist.data[name]), desktop);
        } else {
          var cloned = cloneData(desktop);
          cloned.name = name;
          if (name === "op_mob") {
            cloned = mapVersions(cloned, { "10.0-10.1": "10" });
          }
          return cloned;
        }
      }
      return browserslist.data[name];
    }
    function normalizeAndroidVersions(androidVersions, chromeVersions) {
      var firstEvergreen = ANDROID_EVERGREEN_FIRST;
      var last2 = chromeVersions[chromeVersions.length - 1];
      return androidVersions.filter(function(version2) {
        return /^(?:[2-4]\.|[34]$)/.test(version2);
      }).concat(chromeVersions.slice(firstEvergreen - last2 - 1));
    }
    function normalizeAndroidData(android, chrome2) {
      android.released = normalizeAndroidVersions(android.released, chrome2.released);
      android.versions = normalizeAndroidVersions(android.versions, chrome2.versions);
      return android;
    }
    function checkName(name, context) {
      var data = byName(name, context);
      if (!data)
        throw new BrowserslistError("Unknown browser " + name);
      return data;
    }
    function unknownQuery(query) {
      return new BrowserslistError(
        "Unknown browser query `" + query + "`. Maybe you are using old Browserslist or made typo in query."
      );
    }
    function filterAndroid(list, versions, context) {
      if (context.mobileToDesktop)
        return list;
      var released = browserslist.data.android.released;
      var last2 = released[released.length - 1];
      var diff = last2 - ANDROID_EVERGREEN_FIRST - versions;
      if (diff > 0) {
        return list.slice(-1);
      } else {
        return list.slice(diff - 1);
      }
    }
    function resolve(queries, context) {
      return parse3(QUERIES, queries).reduce(function(result, node, index) {
        if (node.not && index === 0) {
          throw new BrowserslistError(
            "Write any browsers query (for instance, `defaults`) before `" + node.query + "`"
          );
        }
        var type = QUERIES[node.type];
        var array = type.select.call(browserslist, context, node).map(function(j) {
          var parts = j.split(" ");
          if (parts[1] === "0") {
            return parts[0] + " " + byName(parts[0], context).versions[0];
          } else {
            return j;
          }
        });
        if (node.compose === "and") {
          if (node.not) {
            return result.filter(function(j) {
              return array.indexOf(j) === -1;
            });
          } else {
            return result.filter(function(j) {
              return array.indexOf(j) !== -1;
            });
          }
        } else {
          if (node.not) {
            var filter = {};
            array.forEach(function(j) {
              filter[j] = true;
            });
            return result.filter(function(j) {
              return !filter[j];
            });
          }
          return result.concat(array);
        }
      }, []);
    }
    function prepareOpts(opts) {
      if (typeof opts === "undefined")
        opts = {};
      if (typeof opts.path === "undefined") {
        opts.path = path2.resolve ? path2.resolve(".") : ".";
      }
      return opts;
    }
    function prepareQueries(queries, opts) {
      if (typeof queries === "undefined" || queries === null) {
        var config = browserslist.loadConfig(opts);
        if (config) {
          queries = config;
        } else {
          queries = browserslist.defaults;
        }
      }
      return queries;
    }
    function checkQueries(queries) {
      if (!(typeof queries === "string" || Array.isArray(queries))) {
        throw new BrowserslistError(
          "Browser queries must be an array or string. Got " + typeof queries + "."
        );
      }
    }
    var cache = {};
    function browserslist(queries, opts) {
      opts = prepareOpts(opts);
      queries = prepareQueries(queries, opts);
      checkQueries(queries);
      var context = {
        ignoreUnknownVersions: opts.ignoreUnknownVersions,
        dangerousExtend: opts.dangerousExtend,
        mobileToDesktop: opts.mobileToDesktop,
        path: opts.path,
        env: opts.env
      };
      env.oldDataWarning(browserslist.data);
      var stats = env.getStat(opts, browserslist.data);
      if (stats) {
        context.customUsage = {};
        for (var browser in stats) {
          fillUsage(context.customUsage, browser, stats[browser]);
        }
      }
      var cacheKey = JSON.stringify([queries, context]);
      if (cache[cacheKey])
        return cache[cacheKey];
      var result = uniq(resolve(queries, context)).sort(function(name1, name2) {
        name1 = name1.split(" ");
        name2 = name2.split(" ");
        if (name1[0] === name2[0]) {
          var version1 = name1[1].split("-")[0];
          var version2 = name2[1].split("-")[0];
          return compareSemver(version2.split("."), version1.split("."));
        } else {
          return compare(name1[0], name2[0]);
        }
      });
      if (!process.env.BROWSERSLIST_DISABLE_CACHE) {
        cache[cacheKey] = result;
      }
      return result;
    }
    browserslist.parse = function(queries, opts) {
      opts = prepareOpts(opts);
      queries = prepareQueries(queries, opts);
      checkQueries(queries);
      return parse3(QUERIES, queries);
    };
    browserslist.cache = {};
    browserslist.data = {};
    browserslist.usage = {
      global: {},
      custom: null
    };
    browserslist.defaults = ["> 0.5%", "last 2 versions", "Firefox ESR", "not dead"];
    browserslist.aliases = {
      fx: "firefox",
      ff: "firefox",
      ios: "ios_saf",
      explorer: "ie",
      blackberry: "bb",
      explorermobile: "ie_mob",
      operamini: "op_mini",
      operamobile: "op_mob",
      chromeandroid: "and_chr",
      firefoxandroid: "and_ff",
      ucandroid: "and_uc",
      qqandroid: "and_qq"
    };
    browserslist.desktopNames = {
      and_chr: "chrome",
      and_ff: "firefox",
      ie_mob: "ie",
      op_mob: "opera",
      android: "chrome"
      // has extra processing logic
    };
    browserslist.versionAliases = {};
    browserslist.clearCaches = env.clearCaches;
    browserslist.parseConfig = env.parseConfig;
    browserslist.readConfig = env.readConfig;
    browserslist.findConfig = env.findConfig;
    browserslist.loadConfig = env.loadConfig;
    browserslist.coverage = function(browsers, stats) {
      var data;
      if (typeof stats === "undefined") {
        data = browserslist.usage.global;
      } else if (stats === "my stats") {
        var opts = {};
        opts.path = path2.resolve ? path2.resolve(".") : ".";
        var customStats = env.getStat(opts);
        if (!customStats) {
          throw new BrowserslistError("Custom usage statistics was not provided");
        }
        data = {};
        for (var browser in customStats) {
          fillUsage(data, browser, customStats[browser]);
        }
      } else if (typeof stats === "string") {
        if (stats.length > 2) {
          stats = stats.toLowerCase();
        } else {
          stats = stats.toUpperCase();
        }
        env.loadCountry(browserslist.usage, stats, browserslist.data);
        data = browserslist.usage[stats];
      } else {
        if ("dataByBrowser" in stats) {
          stats = stats.dataByBrowser;
        }
        data = {};
        for (var name in stats) {
          for (var version2 in stats[name]) {
            data[name + " " + version2] = stats[name][version2];
          }
        }
      }
      return browsers.reduce(function(all, i) {
        var usage = data[i];
        if (usage === void 0) {
          usage = data[i.replace(/ \S+$/, " 0")];
        }
        return all + (usage || 0);
      }, 0);
    };
    function nodeQuery(context, node) {
      var matched = browserslist.nodeVersions.filter(function(i) {
        return isVersionsMatch(i, node.version);
      });
      if (matched.length === 0) {
        if (context.ignoreUnknownVersions) {
          return [];
        } else {
          throw new BrowserslistError(
            "Unknown version " + node.version + " of Node.js"
          );
        }
      }
      return ["node " + matched[matched.length - 1]];
    }
    function sinceQuery(context, node) {
      var year = parseInt(node.year);
      var month = parseInt(node.month || "01") - 1;
      var day = parseInt(node.day || "01");
      return filterByYear(Date.UTC(year, month, day, 0, 0, 0), context);
    }
    function coverQuery(context, node) {
      var coverage = parseFloat(node.coverage);
      var usage = browserslist.usage.global;
      if (node.place) {
        if (node.place.match(/^my\s+stats$/i)) {
          if (!context.customUsage) {
            throw new BrowserslistError("Custom usage statistics was not provided");
          }
          usage = context.customUsage;
        } else {
          var place;
          if (node.place.length === 2) {
            place = node.place.toUpperCase();
          } else {
            place = node.place.toLowerCase();
          }
          env.loadCountry(browserslist.usage, place, browserslist.data);
          usage = browserslist.usage[place];
        }
      }
      var versions = Object.keys(usage).sort(function(a, b) {
        return usage[b] - usage[a];
      });
      var coveraged = 0;
      var result = [];
      var version2;
      for (var i = 0; i < versions.length; i++) {
        version2 = versions[i];
        if (usage[version2] === 0)
          break;
        coveraged += usage[version2];
        result.push(version2);
        if (coveraged >= coverage)
          break;
      }
      return result;
    }
    var QUERIES = {
      last_major_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+major\s+versions?$/i,
        select: function(context, node) {
          return Object.keys(agents).reduce(function(selected, name) {
            var data = byName(name, context);
            if (!data)
              return selected;
            var list = getMajorVersions(data.released, node.versions);
            list = list.map(nameMapper(data.name));
            if (data.name === "android") {
              list = filterAndroid(list, node.versions, context);
            }
            return selected.concat(list);
          }, []);
        }
      },
      last_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+versions?$/i,
        select: function(context, node) {
          return Object.keys(agents).reduce(function(selected, name) {
            var data = byName(name, context);
            if (!data)
              return selected;
            var list = data.released.slice(-node.versions);
            list = list.map(nameMapper(data.name));
            if (data.name === "android") {
              list = filterAndroid(list, node.versions, context);
            }
            return selected.concat(list);
          }, []);
        }
      },
      last_electron_major_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+electron\s+major\s+versions?$/i,
        select: function(context, node) {
          var validVersions = getMajorVersions(Object.keys(e2c), node.versions);
          return validVersions.map(function(i) {
            return "chrome " + e2c[i];
          });
        }
      },
      last_node_major_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+node\s+major\s+versions?$/i,
        select: function(context, node) {
          return getMajorVersions(browserslist.nodeVersions, node.versions).map(
            function(version2) {
              return "node " + version2;
            }
          );
        }
      },
      last_browser_major_versions: {
        matches: ["versions", "browser"],
        regexp: /^last\s+(\d+)\s+(\w+)\s+major\s+versions?$/i,
        select: function(context, node) {
          var data = checkName(node.browser, context);
          var validVersions = getMajorVersions(data.released, node.versions);
          var list = validVersions.map(nameMapper(data.name));
          if (data.name === "android") {
            list = filterAndroid(list, node.versions, context);
          }
          return list;
        }
      },
      last_electron_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+electron\s+versions?$/i,
        select: function(context, node) {
          return Object.keys(e2c).slice(-node.versions).map(function(i) {
            return "chrome " + e2c[i];
          });
        }
      },
      last_node_versions: {
        matches: ["versions"],
        regexp: /^last\s+(\d+)\s+node\s+versions?$/i,
        select: function(context, node) {
          return browserslist.nodeVersions.slice(-node.versions).map(function(version2) {
            return "node " + version2;
          });
        }
      },
      last_browser_versions: {
        matches: ["versions", "browser"],
        regexp: /^last\s+(\d+)\s+(\w+)\s+versions?$/i,
        select: function(context, node) {
          var data = checkName(node.browser, context);
          var list = data.released.slice(-node.versions).map(nameMapper(data.name));
          if (data.name === "android") {
            list = filterAndroid(list, node.versions, context);
          }
          return list;
        }
      },
      unreleased_versions: {
        matches: [],
        regexp: /^unreleased\s+versions$/i,
        select: function(context) {
          return Object.keys(agents).reduce(function(selected, name) {
            var data = byName(name, context);
            if (!data)
              return selected;
            var list = data.versions.filter(function(v) {
              return data.released.indexOf(v) === -1;
            });
            list = list.map(nameMapper(data.name));
            return selected.concat(list);
          }, []);
        }
      },
      unreleased_electron_versions: {
        matches: [],
        regexp: /^unreleased\s+electron\s+versions?$/i,
        select: function() {
          return [];
        }
      },
      unreleased_browser_versions: {
        matches: ["browser"],
        regexp: /^unreleased\s+(\w+)\s+versions?$/i,
        select: function(context, node) {
          var data = checkName(node.browser, context);
          return data.versions.filter(function(v) {
            return data.released.indexOf(v) === -1;
          }).map(nameMapper(data.name));
        }
      },
      last_years: {
        matches: ["years"],
        regexp: /^last\s+(\d*.?\d+)\s+years?$/i,
        select: function(context, node) {
          return filterByYear(Date.now() - YEAR * node.years, context);
        }
      },
      since_y: {
        matches: ["year"],
        regexp: /^since (\d+)$/i,
        select: sinceQuery
      },
      since_y_m: {
        matches: ["year", "month"],
        regexp: /^since (\d+)-(\d+)$/i,
        select: sinceQuery
      },
      since_y_m_d: {
        matches: ["year", "month", "day"],
        regexp: /^since (\d+)-(\d+)-(\d+)$/i,
        select: sinceQuery
      },
      popularity: {
        matches: ["sign", "popularity"],
        regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%$/,
        select: function(context, node) {
          var popularity = parseFloat(node.popularity);
          var usage = browserslist.usage.global;
          return Object.keys(usage).reduce(function(result, version2) {
            if (node.sign === ">") {
              if (usage[version2] > popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<") {
              if (usage[version2] < popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<=") {
              if (usage[version2] <= popularity) {
                result.push(version2);
              }
            } else if (usage[version2] >= popularity) {
              result.push(version2);
            }
            return result;
          }, []);
        }
      },
      popularity_in_my_stats: {
        matches: ["sign", "popularity"],
        regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+my\s+stats$/,
        select: function(context, node) {
          var popularity = parseFloat(node.popularity);
          if (!context.customUsage) {
            throw new BrowserslistError("Custom usage statistics was not provided");
          }
          var usage = context.customUsage;
          return Object.keys(usage).reduce(function(result, version2) {
            var percentage = usage[version2];
            if (percentage == null) {
              return result;
            }
            if (node.sign === ">") {
              if (percentage > popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<") {
              if (percentage < popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<=") {
              if (percentage <= popularity) {
                result.push(version2);
              }
            } else if (percentage >= popularity) {
              result.push(version2);
            }
            return result;
          }, []);
        }
      },
      popularity_in_config_stats: {
        matches: ["sign", "popularity", "config"],
        regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+(\S+)\s+stats$/,
        select: function(context, node) {
          var popularity = parseFloat(node.popularity);
          var stats = env.loadStat(context, node.config, browserslist.data);
          if (stats) {
            context.customUsage = {};
            for (var browser in stats) {
              fillUsage(context.customUsage, browser, stats[browser]);
            }
          }
          if (!context.customUsage) {
            throw new BrowserslistError("Custom usage statistics was not provided");
          }
          var usage = context.customUsage;
          return Object.keys(usage).reduce(function(result, version2) {
            var percentage = usage[version2];
            if (percentage == null) {
              return result;
            }
            if (node.sign === ">") {
              if (percentage > popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<") {
              if (percentage < popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<=") {
              if (percentage <= popularity) {
                result.push(version2);
              }
            } else if (percentage >= popularity) {
              result.push(version2);
            }
            return result;
          }, []);
        }
      },
      popularity_in_place: {
        matches: ["sign", "popularity", "place"],
        regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+((alt-)?\w\w)$/,
        select: function(context, node) {
          var popularity = parseFloat(node.popularity);
          var place = node.place;
          if (place.length === 2) {
            place = place.toUpperCase();
          } else {
            place = place.toLowerCase();
          }
          env.loadCountry(browserslist.usage, place, browserslist.data);
          var usage = browserslist.usage[place];
          return Object.keys(usage).reduce(function(result, version2) {
            var percentage = usage[version2];
            if (percentage == null) {
              return result;
            }
            if (node.sign === ">") {
              if (percentage > popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<") {
              if (percentage < popularity) {
                result.push(version2);
              }
            } else if (node.sign === "<=") {
              if (percentage <= popularity) {
                result.push(version2);
              }
            } else if (percentage >= popularity) {
              result.push(version2);
            }
            return result;
          }, []);
        }
      },
      cover: {
        matches: ["coverage"],
        regexp: /^cover\s+(\d+|\d+\.\d+|\.\d+)%$/i,
        select: coverQuery
      },
      cover_in: {
        matches: ["coverage", "place"],
        regexp: /^cover\s+(\d+|\d+\.\d+|\.\d+)%\s+in\s+(my\s+stats|(alt-)?\w\w)$/i,
        select: coverQuery
      },
      supports: {
        matches: ["feature"],
        regexp: /^supports\s+([\w-]+)$/,
        select: function(context, node) {
          env.loadFeature(browserslist.cache, node.feature);
          var features = browserslist.cache[node.feature];
          return Object.keys(features).reduce(function(result, version2) {
            var flags = features[version2];
            if (flags.indexOf("y") >= 0 || flags.indexOf("a") >= 0) {
              result.push(version2);
            }
            return result;
          }, []);
        }
      },
      electron_range: {
        matches: ["from", "to"],
        regexp: /^electron\s+([\d.]+)\s*-\s*([\d.]+)$/i,
        select: function(context, node) {
          var fromToUse = normalizeElectron(node.from);
          var toToUse = normalizeElectron(node.to);
          var from = parseFloat(node.from);
          var to = parseFloat(node.to);
          if (!e2c[fromToUse]) {
            throw new BrowserslistError("Unknown version " + from + " of electron");
          }
          if (!e2c[toToUse]) {
            throw new BrowserslistError("Unknown version " + to + " of electron");
          }
          return Object.keys(e2c).filter(function(i) {
            var parsed = parseFloat(i);
            return parsed >= from && parsed <= to;
          }).map(function(i) {
            return "chrome " + e2c[i];
          });
        }
      },
      node_range: {
        matches: ["from", "to"],
        regexp: /^node\s+([\d.]+)\s*-\s*([\d.]+)$/i,
        select: function(context, node) {
          return browserslist.nodeVersions.filter(semverFilterLoose(">=", node.from)).filter(semverFilterLoose("<=", node.to)).map(function(v) {
            return "node " + v;
          });
        }
      },
      browser_range: {
        matches: ["browser", "from", "to"],
        regexp: /^(\w+)\s+([\d.]+)\s*-\s*([\d.]+)$/i,
        select: function(context, node) {
          var data = checkName(node.browser, context);
          var from = parseFloat(normalizeVersion(data, node.from) || node.from);
          var to = parseFloat(normalizeVersion(data, node.to) || node.to);
          function filter(v) {
            var parsed = parseFloat(v);
            return parsed >= from && parsed <= to;
          }
          return data.released.filter(filter).map(nameMapper(data.name));
        }
      },
      electron_ray: {
        matches: ["sign", "version"],
        regexp: /^electron\s*(>=?|<=?)\s*([\d.]+)$/i,
        select: function(context, node) {
          var versionToUse = normalizeElectron(node.version);
          return Object.keys(e2c).filter(generateFilter(node.sign, versionToUse)).map(function(i) {
            return "chrome " + e2c[i];
          });
        }
      },
      node_ray: {
        matches: ["sign", "version"],
        regexp: /^node\s*(>=?|<=?)\s*([\d.]+)$/i,
        select: function(context, node) {
          return browserslist.nodeVersions.filter(generateSemverFilter(node.sign, node.version)).map(function(v) {
            return "node " + v;
          });
        }
      },
      browser_ray: {
        matches: ["browser", "sign", "version"],
        regexp: /^(\w+)\s*(>=?|<=?)\s*([\d.]+)$/,
        select: function(context, node) {
          var version2 = node.version;
          var data = checkName(node.browser, context);
          var alias = browserslist.versionAliases[data.name][version2];
          if (alias)
            version2 = alias;
          return data.released.filter(generateFilter(node.sign, version2)).map(function(v) {
            return data.name + " " + v;
          });
        }
      },
      firefox_esr: {
        matches: [],
        regexp: /^(firefox|ff|fx)\s+esr$/i,
        select: function() {
          return ["firefox 102"];
        }
      },
      opera_mini_all: {
        matches: [],
        regexp: /(operamini|op_mini)\s+all/i,
        select: function() {
          return ["op_mini all"];
        }
      },
      electron_version: {
        matches: ["version"],
        regexp: /^electron\s+([\d.]+)$/i,
        select: function(context, node) {
          var versionToUse = normalizeElectron(node.version);
          var chrome2 = e2c[versionToUse];
          if (!chrome2) {
            throw new BrowserslistError(
              "Unknown version " + node.version + " of electron"
            );
          }
          return ["chrome " + chrome2];
        }
      },
      node_major_version: {
        matches: ["version"],
        regexp: /^node\s+(\d+)$/i,
        select: nodeQuery
      },
      node_minor_version: {
        matches: ["version"],
        regexp: /^node\s+(\d+\.\d+)$/i,
        select: nodeQuery
      },
      node_patch_version: {
        matches: ["version"],
        regexp: /^node\s+(\d+\.\d+\.\d+)$/i,
        select: nodeQuery
      },
      current_node: {
        matches: [],
        regexp: /^current\s+node$/i,
        select: function(context) {
          return [env.currentNode(resolve, context)];
        }
      },
      maintained_node: {
        matches: [],
        regexp: /^maintained\s+node\s+versions$/i,
        select: function(context) {
          var now = Date.now();
          var queries = Object.keys(jsEOL).filter(function(key) {
            return now < Date.parse(jsEOL[key].end) && now > Date.parse(jsEOL[key].start) && isEolReleased(key);
          }).map(function(key) {
            return "node " + key.slice(1);
          });
          return resolve(queries, context);
        }
      },
      phantomjs_1_9: {
        matches: [],
        regexp: /^phantomjs\s+1.9$/i,
        select: function() {
          return ["safari 5"];
        }
      },
      phantomjs_2_1: {
        matches: [],
        regexp: /^phantomjs\s+2.1$/i,
        select: function() {
          return ["safari 6"];
        }
      },
      browser_version: {
        matches: ["browser", "version"],
        regexp: /^(\w+)\s+(tp|[\d.]+)$/i,
        select: function(context, node) {
          var version2 = node.version;
          if (/^tp$/i.test(version2))
            version2 = "TP";
          var data = checkName(node.browser, context);
          var alias = normalizeVersion(data, version2);
          if (alias) {
            version2 = alias;
          } else {
            if (version2.indexOf(".") === -1) {
              alias = version2 + ".0";
            } else {
              alias = version2.replace(/\.0$/, "");
            }
            alias = normalizeVersion(data, alias);
            if (alias) {
              version2 = alias;
            } else if (context.ignoreUnknownVersions) {
              return [];
            } else {
              throw new BrowserslistError(
                "Unknown version " + version2 + " of " + node.browser
              );
            }
          }
          return [data.name + " " + version2];
        }
      },
      browserslist_config: {
        matches: [],
        regexp: /^browserslist config$/i,
        select: function(context) {
          return browserslist(void 0, context);
        }
      },
      extends: {
        matches: ["config"],
        regexp: /^extends (.+)$/i,
        select: function(context, node) {
          return resolve(env.loadQueries(context, node.config), context);
        }
      },
      defaults: {
        matches: [],
        regexp: /^defaults$/i,
        select: function(context) {
          return resolve(browserslist.defaults, context);
        }
      },
      dead: {
        matches: [],
        regexp: /^dead$/i,
        select: function(context) {
          var dead = [
            "Baidu >= 0",
            "ie <= 11",
            "ie_mob <= 11",
            "bb <= 10",
            "op_mob <= 12.1",
            "samsung 4"
          ];
          return resolve(dead, context);
        }
      },
      unknown: {
        matches: [],
        regexp: /^(\w+)$/i,
        select: function(context, node) {
          if (byName(node.query, context)) {
            throw new BrowserslistError(
              "Specify versions in Browserslist query for browser " + node.query
            );
          } else {
            throw unknownQuery(node.query);
          }
        }
      }
    };
    (function() {
      for (var name in agents) {
        var browser = agents[name];
        browserslist.data[name] = {
          name,
          versions: normalize(agents[name].versions),
          released: normalize(agents[name].versions.slice(0, -3)),
          releaseDate: agents[name].release_date
        };
        fillUsage(browserslist.usage.global, name, browser.usage_global);
        browserslist.versionAliases[name] = {};
        for (var i = 0; i < browser.versions.length; i++) {
          var full = browser.versions[i];
          if (!full)
            continue;
          if (full.indexOf("-") !== -1) {
            var interval = full.split("-");
            for (var j = 0; j < interval.length; j++) {
              browserslist.versionAliases[name][interval[j]] = full;
            }
          }
        }
      }
      browserslist.versionAliases.op_mob["59"] = "58";
      browserslist.nodeVersions = jsReleases.map(function(release) {
        return release.version;
      });
    })();
    module2.exports = browserslist;
  }
});

// node_modules/@babel/helper-validator-option/lib/find-suggestion.js
var require_find_suggestion = __commonJS({
  "node_modules/@babel/helper-validator-option/lib/find-suggestion.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.findSuggestion = findSuggestion;
    var {
      min: min2
    } = Math;
    function levenshtein(a, b) {
      let t3 = [], u = [], i, j;
      const m = a.length, n = b.length;
      if (!m) {
        return n;
      }
      if (!n) {
        return m;
      }
      for (j = 0; j <= n; j++) {
        t3[j] = j;
      }
      for (i = 1; i <= m; i++) {
        for (u = [i], j = 1; j <= n; j++) {
          u[j] = a[i - 1] === b[j - 1] ? t3[j - 1] : min2(t3[j - 1], t3[j], u[j - 1]) + 1;
        }
        t3 = u;
      }
      return u[n];
    }
    function findSuggestion(str, arr) {
      const distances = arr.map((el) => levenshtein(el, str));
      return arr[distances.indexOf(min2(...distances))];
    }
  }
});

// node_modules/@babel/helper-validator-option/lib/validator.js
var require_validator = __commonJS({
  "node_modules/@babel/helper-validator-option/lib/validator.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.OptionValidator = void 0;
    var _findSuggestion = require_find_suggestion();
    var OptionValidator = class {
      constructor(descriptor) {
        this.descriptor = descriptor;
      }
      validateTopLevelOptions(options, TopLevelOptionShape) {
        const validOptionNames = Object.keys(TopLevelOptionShape);
        for (const option of Object.keys(options)) {
          if (!validOptionNames.includes(option)) {
            throw new Error(this.formatMessage(`'${option}' is not a valid top-level option.
- Did you mean '${(0, _findSuggestion.findSuggestion)(option, validOptionNames)}'?`));
          }
        }
      }
      validateBooleanOption(name, value2, defaultValue) {
        if (value2 === void 0) {
          return defaultValue;
        } else {
          this.invariant(typeof value2 === "boolean", `'${name}' option must be a boolean.`);
        }
        return value2;
      }
      validateStringOption(name, value2, defaultValue) {
        if (value2 === void 0) {
          return defaultValue;
        } else {
          this.invariant(typeof value2 === "string", `'${name}' option must be a string.`);
        }
        return value2;
      }
      invariant(condition, message) {
        if (!condition) {
          throw new Error(this.formatMessage(message));
        }
      }
      formatMessage(message) {
        return `${this.descriptor}: ${message}`;
      }
    };
    exports.OptionValidator = OptionValidator;
  }
});

// node_modules/@babel/helper-validator-option/lib/index.js
var require_lib26 = __commonJS({
  "node_modules/@babel/helper-validator-option/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "OptionValidator", {
      enumerable: true,
      get: function() {
        return _validator.OptionValidator;
      }
    });
    Object.defineProperty(exports, "findSuggestion", {
      enumerable: true,
      get: function() {
        return _findSuggestion.findSuggestion;
      }
    });
    var _validator = require_validator();
    var _findSuggestion = require_find_suggestion();
  }
});

// node_modules/@babel/compat-data/data/native-modules.json
var require_native_modules = __commonJS({
  "node_modules/@babel/compat-data/data/native-modules.json"(exports, module2) {
    module2.exports = {
      "es6.module": {
        chrome: "61",
        and_chr: "61",
        edge: "16",
        firefox: "60",
        and_ff: "60",
        node: "13.2.0",
        opera: "48",
        op_mob: "48",
        safari: "10.1",
        ios: "10.3",
        samsung: "8.2",
        android: "61",
        electron: "2.0",
        ios_saf: "10.3"
      }
    };
  }
});

// node_modules/@babel/compat-data/native-modules.js
var require_native_modules2 = __commonJS({
  "node_modules/@babel/compat-data/native-modules.js"(exports, module2) {
    module2.exports = require_native_modules();
  }
});

// node_modules/lru-cache/node_modules/yallist/iterator.js
var require_iterator2 = __commonJS({
  "node_modules/lru-cache/node_modules/yallist/iterator.js"(exports, module2) {
    "use strict";
    module2.exports = function(Yallist) {
      Yallist.prototype[Symbol.iterator] = function* () {
        for (let walker = this.head; walker; walker = walker.next) {
          yield walker.value;
        }
      };
    };
  }
});

// node_modules/lru-cache/node_modules/yallist/yallist.js
var require_yallist = __commonJS({
  "node_modules/lru-cache/node_modules/yallist/yallist.js"(exports, module2) {
    "use strict";
    module2.exports = Yallist;
    Yallist.Node = Node2;
    Yallist.create = Yallist;
    function Yallist(list) {
      var self2 = this;
      if (!(self2 instanceof Yallist)) {
        self2 = new Yallist();
      }
      self2.tail = null;
      self2.head = null;
      self2.length = 0;
      if (list && typeof list.forEach === "function") {
        list.forEach(function(item) {
          self2.push(item);
        });
      } else if (arguments.length > 0) {
        for (var i = 0, l = arguments.length; i < l; i++) {
          self2.push(arguments[i]);
        }
      }
      return self2;
    }
    Yallist.prototype.removeNode = function(node) {
      if (node.list !== this) {
        throw new Error("removing node which does not belong to this list");
      }
      var next = node.next;
      var prev = node.prev;
      if (next) {
        next.prev = prev;
      }
      if (prev) {
        prev.next = next;
      }
      if (node === this.head) {
        this.head = next;
      }
      if (node === this.tail) {
        this.tail = prev;
      }
      node.list.length--;
      node.next = null;
      node.prev = null;
      node.list = null;
      return next;
    };
    Yallist.prototype.unshiftNode = function(node) {
      if (node === this.head) {
        return;
      }
      if (node.list) {
        node.list.removeNode(node);
      }
      var head = this.head;
      node.list = this;
      node.next = head;
      if (head) {
        head.prev = node;
      }
      this.head = node;
      if (!this.tail) {
        this.tail = node;
      }
      this.length++;
    };
    Yallist.prototype.pushNode = function(node) {
      if (node === this.tail) {
        return;
      }
      if (node.list) {
        node.list.removeNode(node);
      }
      var tail = this.tail;
      node.list = this;
      node.prev = tail;
      if (tail) {
        tail.next = node;
      }
      this.tail = node;
      if (!this.head) {
        this.head = node;
      }
      this.length++;
    };
    Yallist.prototype.push = function() {
      for (var i = 0, l = arguments.length; i < l; i++) {
        push(this, arguments[i]);
      }
      return this.length;
    };
    Yallist.prototype.unshift = function() {
      for (var i = 0, l = arguments.length; i < l; i++) {
        unshift(this, arguments[i]);
      }
      return this.length;
    };
    Yallist.prototype.pop = function() {
      if (!this.tail) {
        return void 0;
      }
      var res = this.tail.value;
      this.tail = this.tail.prev;
      if (this.tail) {
        this.tail.next = null;
      } else {
        this.head = null;
      }
      this.length--;
      return res;
    };
    Yallist.prototype.shift = function() {
      if (!this.head) {
        return void 0;
      }
      var res = this.head.value;
      this.head = this.head.next;
      if (this.head) {
        this.head.prev = null;
      } else {
        this.tail = null;
      }
      this.length--;
      return res;
    };
    Yallist.prototype.forEach = function(fn, thisp) {
      thisp = thisp || this;
      for (var walker = this.head, i = 0; walker !== null; i++) {
        fn.call(thisp, walker.value, i, this);
        walker = walker.next;
      }
    };
    Yallist.prototype.forEachReverse = function(fn, thisp) {
      thisp = thisp || this;
      for (var walker = this.tail, i = this.length - 1; walker !== null; i--) {
        fn.call(thisp, walker.value, i, this);
        walker = walker.prev;
      }
    };
    Yallist.prototype.get = function(n) {
      for (var i = 0, walker = this.head; walker !== null && i < n; i++) {
        walker = walker.next;
      }
      if (i === n && walker !== null) {
        return walker.value;
      }
    };
    Yallist.prototype.getReverse = function(n) {
      for (var i = 0, walker = this.tail; walker !== null && i < n; i++) {
        walker = walker.prev;
      }
      if (i === n && walker !== null) {
        return walker.value;
      }
    };
    Yallist.prototype.map = function(fn, thisp) {
      thisp = thisp || this;
      var res = new Yallist();
      for (var walker = this.head; walker !== null; ) {
        res.push(fn.call(thisp, walker.value, this));
        walker = walker.next;
      }
      return res;
    };
    Yallist.prototype.mapReverse = function(fn, thisp) {
      thisp = thisp || this;
      var res = new Yallist();
      for (var walker = this.tail; walker !== null; ) {
        res.push(fn.call(thisp, walker.value, this));
        walker = walker.prev;
      }
      return res;
    };
    Yallist.prototype.reduce = function(fn, initial) {
      var acc;
      var walker = this.head;
      if (arguments.length > 1) {
        acc = initial;
      } else if (this.head) {
        walker = this.head.next;
        acc = this.head.value;
      } else {
        throw new TypeError("Reduce of empty list with no initial value");
      }
      for (var i = 0; walker !== null; i++) {
        acc = fn(acc, walker.value, i);
        walker = walker.next;
      }
      return acc;
    };
    Yallist.prototype.reduceReverse = function(fn, initial) {
      var acc;
      var walker = this.tail;
      if (arguments.length > 1) {
        acc = initial;
      } else if (this.tail) {
        walker = this.tail.prev;
        acc = this.tail.value;
      } else {
        throw new TypeError("Reduce of empty list with no initial value");
      }
      for (var i = this.length - 1; walker !== null; i--) {
        acc = fn(acc, walker.value, i);
        walker = walker.prev;
      }
      return acc;
    };
    Yallist.prototype.toArray = function() {
      var arr = new Array(this.length);
      for (var i = 0, walker = this.head; walker !== null; i++) {
        arr[i] = walker.value;
        walker = walker.next;
      }
      return arr;
    };
    Yallist.prototype.toArrayReverse = function() {
      var arr = new Array(this.length);
      for (var i = 0, walker = this.tail; walker !== null; i++) {
        arr[i] = walker.value;
        walker = walker.prev;
      }
      return arr;
    };
    Yallist.prototype.slice = function(from, to) {
      to = to || this.length;
      if (to < 0) {
        to += this.length;
      }
      from = from || 0;
      if (from < 0) {
        from += this.length;
      }
      var ret = new Yallist();
      if (to < from || to < 0) {
        return ret;
      }
      if (from < 0) {
        from = 0;
      }
      if (to > this.length) {
        to = this.length;
      }
      for (var i = 0, walker = this.head; walker !== null && i < from; i++) {
        walker = walker.next;
      }
      for (; walker !== null && i < to; i++, walker = walker.next) {
        ret.push(walker.value);
      }
      return ret;
    };
    Yallist.prototype.sliceReverse = function(from, to) {
      to = to || this.length;
      if (to < 0) {
        to += this.length;
      }
      from = from || 0;
      if (from < 0) {
        from += this.length;
      }
      var ret = new Yallist();
      if (to < from || to < 0) {
        return ret;
      }
      if (from < 0) {
        from = 0;
      }
      if (to > this.length) {
        to = this.length;
      }
      for (var i = this.length, walker = this.tail; walker !== null && i > to; i--) {
        walker = walker.prev;
      }
      for (; walker !== null && i > from; i--, walker = walker.prev) {
        ret.push(walker.value);
      }
      return ret;
    };
    Yallist.prototype.splice = function(start, deleteCount) {
      if (start > this.length) {
        start = this.length - 1;
      }
      if (start < 0) {
        start = this.length + start;
      }
      for (var i = 0, walker = this.head; walker !== null && i < start; i++) {
        walker = walker.next;
      }
      var ret = [];
      for (var i = 0; walker && i < deleteCount; i++) {
        ret.push(walker.value);
        walker = this.removeNode(walker);
      }
      if (walker === null) {
        walker = this.tail;
      }
      if (walker !== this.head && walker !== this.tail) {
        walker = walker.prev;
      }
      for (var i = 2; i < arguments.length; i++) {
        walker = insert(this, walker, arguments[i]);
      }
      return ret;
    };
    Yallist.prototype.reverse = function() {
      var head = this.head;
      var tail = this.tail;
      for (var walker = head; walker !== null; walker = walker.prev) {
        var p = walker.prev;
        walker.prev = walker.next;
        walker.next = p;
      }
      this.head = tail;
      this.tail = head;
      return this;
    };
    function insert(self2, node, value2) {
      var inserted = node === self2.head ? new Node2(value2, null, node, self2) : new Node2(value2, node, node.next, self2);
      if (inserted.next === null) {
        self2.tail = inserted;
      }
      if (inserted.prev === null) {
        self2.head = inserted;
      }
      self2.length++;
      return inserted;
    }
    function push(self2, item) {
      self2.tail = new Node2(item, self2.tail, null, self2);
      if (!self2.head) {
        self2.head = self2.tail;
      }
      self2.length++;
    }
    function unshift(self2, item) {
      self2.head = new Node2(item, null, self2.head, self2);
      if (!self2.tail) {
        self2.tail = self2.head;
      }
      self2.length++;
    }
    function Node2(value2, prev, next, list) {
      if (!(this instanceof Node2)) {
        return new Node2(value2, prev, next, list);
      }
      this.list = list;
      this.value = value2;
      if (prev) {
        prev.next = this;
        this.prev = prev;
      } else {
        this.prev = null;
      }
      if (next) {
        next.prev = this;
        this.next = next;
      } else {
        this.next = null;
      }
    }
    try {
      require_iterator2()(Yallist);
    } catch (er) {
    }
  }
});

// node_modules/lru-cache/index.js
var require_lru_cache = __commonJS({
  "node_modules/lru-cache/index.js"(exports, module2) {
    "use strict";
    var Yallist = require_yallist();
    var MAX = Symbol("max");
    var LENGTH = Symbol("length");
    var LENGTH_CALCULATOR = Symbol("lengthCalculator");
    var ALLOW_STALE = Symbol("allowStale");
    var MAX_AGE = Symbol("maxAge");
    var DISPOSE = Symbol("dispose");
    var NO_DISPOSE_ON_SET = Symbol("noDisposeOnSet");
    var LRU_LIST = Symbol("lruList");
    var CACHE = Symbol("cache");
    var UPDATE_AGE_ON_GET = Symbol("updateAgeOnGet");
    var naiveLength = () => 1;
    var LRUCache = class {
      constructor(options) {
        if (typeof options === "number")
          options = { max: options };
        if (!options)
          options = {};
        if (options.max && (typeof options.max !== "number" || options.max < 0))
          throw new TypeError("max must be a non-negative number");
        const max2 = this[MAX] = options.max || Infinity;
        const lc = options.length || naiveLength;
        this[LENGTH_CALCULATOR] = typeof lc !== "function" ? naiveLength : lc;
        this[ALLOW_STALE] = options.stale || false;
        if (options.maxAge && typeof options.maxAge !== "number")
          throw new TypeError("maxAge must be a number");
        this[MAX_AGE] = options.maxAge || 0;
        this[DISPOSE] = options.dispose;
        this[NO_DISPOSE_ON_SET] = options.noDisposeOnSet || false;
        this[UPDATE_AGE_ON_GET] = options.updateAgeOnGet || false;
        this.reset();
      }
      // resize the cache when the max changes.
      set max(mL) {
        if (typeof mL !== "number" || mL < 0)
          throw new TypeError("max must be a non-negative number");
        this[MAX] = mL || Infinity;
        trim(this);
      }
      get max() {
        return this[MAX];
      }
      set allowStale(allowStale) {
        this[ALLOW_STALE] = !!allowStale;
      }
      get allowStale() {
        return this[ALLOW_STALE];
      }
      set maxAge(mA) {
        if (typeof mA !== "number")
          throw new TypeError("maxAge must be a non-negative number");
        this[MAX_AGE] = mA;
        trim(this);
      }
      get maxAge() {
        return this[MAX_AGE];
      }
      // resize the cache when the lengthCalculator changes.
      set lengthCalculator(lC) {
        if (typeof lC !== "function")
          lC = naiveLength;
        if (lC !== this[LENGTH_CALCULATOR]) {
          this[LENGTH_CALCULATOR] = lC;
          this[LENGTH] = 0;
          this[LRU_LIST].forEach((hit) => {
            hit.length = this[LENGTH_CALCULATOR](hit.value, hit.key);
            this[LENGTH] += hit.length;
          });
        }
        trim(this);
      }
      get lengthCalculator() {
        return this[LENGTH_CALCULATOR];
      }
      get length() {
        return this[LENGTH];
      }
      get itemCount() {
        return this[LRU_LIST].length;
      }
      rforEach(fn, thisp) {
        thisp = thisp || this;
        for (let walker = this[LRU_LIST].tail; walker !== null; ) {
          const prev = walker.prev;
          forEachStep(this, fn, walker, thisp);
          walker = prev;
        }
      }
      forEach(fn, thisp) {
        thisp = thisp || this;
        for (let walker = this[LRU_LIST].head; walker !== null; ) {
          const next = walker.next;
          forEachStep(this, fn, walker, thisp);
          walker = next;
        }
      }
      keys() {
        return this[LRU_LIST].toArray().map((k) => k.key);
      }
      values() {
        return this[LRU_LIST].toArray().map((k) => k.value);
      }
      reset() {
        if (this[DISPOSE] && this[LRU_LIST] && this[LRU_LIST].length) {
          this[LRU_LIST].forEach((hit) => this[DISPOSE](hit.key, hit.value));
        }
        this[CACHE] = /* @__PURE__ */ new Map();
        this[LRU_LIST] = new Yallist();
        this[LENGTH] = 0;
      }
      dump() {
        return this[LRU_LIST].map((hit) => isStale(this, hit) ? false : {
          k: hit.key,
          v: hit.value,
          e: hit.now + (hit.maxAge || 0)
        }).toArray().filter((h) => h);
      }
      dumpLru() {
        return this[LRU_LIST];
      }
      set(key, value2, maxAge) {
        maxAge = maxAge || this[MAX_AGE];
        if (maxAge && typeof maxAge !== "number")
          throw new TypeError("maxAge must be a number");
        const now = maxAge ? Date.now() : 0;
        const len = this[LENGTH_CALCULATOR](value2, key);
        if (this[CACHE].has(key)) {
          if (len > this[MAX]) {
            del(this, this[CACHE].get(key));
            return false;
          }
          const node = this[CACHE].get(key);
          const item = node.value;
          if (this[DISPOSE]) {
            if (!this[NO_DISPOSE_ON_SET])
              this[DISPOSE](key, item.value);
          }
          item.now = now;
          item.maxAge = maxAge;
          item.value = value2;
          this[LENGTH] += len - item.length;
          item.length = len;
          this.get(key);
          trim(this);
          return true;
        }
        const hit = new Entry(key, value2, len, now, maxAge);
        if (hit.length > this[MAX]) {
          if (this[DISPOSE])
            this[DISPOSE](key, value2);
          return false;
        }
        this[LENGTH] += hit.length;
        this[LRU_LIST].unshift(hit);
        this[CACHE].set(key, this[LRU_LIST].head);
        trim(this);
        return true;
      }
      has(key) {
        if (!this[CACHE].has(key))
          return false;
        const hit = this[CACHE].get(key).value;
        return !isStale(this, hit);
      }
      get(key) {
        return get(this, key, true);
      }
      peek(key) {
        return get(this, key, false);
      }
      pop() {
        const node = this[LRU_LIST].tail;
        if (!node)
          return null;
        del(this, node);
        return node.value;
      }
      del(key) {
        del(this, this[CACHE].get(key));
      }
      load(arr) {
        this.reset();
        const now = Date.now();
        for (let l = arr.length - 1; l >= 0; l--) {
          const hit = arr[l];
          const expiresAt = hit.e || 0;
          if (expiresAt === 0)
            this.set(hit.k, hit.v);
          else {
            const maxAge = expiresAt - now;
            if (maxAge > 0) {
              this.set(hit.k, hit.v, maxAge);
            }
          }
        }
      }
      prune() {
        this[CACHE].forEach((value2, key) => get(this, key, false));
      }
    };
    var get = (self2, key, doUse) => {
      const node = self2[CACHE].get(key);
      if (node) {
        const hit = node.value;
        if (isStale(self2, hit)) {
          del(self2, node);
          if (!self2[ALLOW_STALE])
            return void 0;
        } else {
          if (doUse) {
            if (self2[UPDATE_AGE_ON_GET])
              node.value.now = Date.now();
            self2[LRU_LIST].unshiftNode(node);
          }
        }
        return hit.value;
      }
    };
    var isStale = (self2, hit) => {
      if (!hit || !hit.maxAge && !self2[MAX_AGE])
        return false;
      const diff = Date.now() - hit.now;
      return hit.maxAge ? diff > hit.maxAge : self2[MAX_AGE] && diff > self2[MAX_AGE];
    };
    var trim = (self2) => {
      if (self2[LENGTH] > self2[MAX]) {
        for (let walker = self2[LRU_LIST].tail; self2[LENGTH] > self2[MAX] && walker !== null; ) {
          const prev = walker.prev;
          del(self2, walker);
          walker = prev;
        }
      }
    };
    var del = (self2, node) => {
      if (node) {
        const hit = node.value;
        if (self2[DISPOSE])
          self2[DISPOSE](hit.key, hit.value);
        self2[LENGTH] -= hit.length;
        self2[CACHE].delete(hit.key);
        self2[LRU_LIST].removeNode(node);
      }
    };
    var Entry = class {
      constructor(key, value2, length, now, maxAge) {
        this.key = key;
        this.value = value2;
        this.length = length;
        this.now = now;
        this.maxAge = maxAge || 0;
      }
    };
    var forEachStep = (self2, fn, node, thisp) => {
      let hit = node.value;
      if (isStale(self2, hit)) {
        del(self2, node);
        if (!self2[ALLOW_STALE])
          hit = void 0;
      }
      if (hit)
        fn.call(thisp, hit.value, hit.key, self2);
    };
    module2.exports = LRUCache;
  }
});

// node_modules/@babel/helper-compilation-targets/lib/targets.js
var require_targets = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/targets.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.unreleasedLabels = exports.browserNameMap = void 0;
    var unreleasedLabels = {
      safari: "tp"
    };
    exports.unreleasedLabels = unreleasedLabels;
    var browserNameMap = {
      and_chr: "chrome",
      and_ff: "firefox",
      android: "android",
      chrome: "chrome",
      edge: "edge",
      firefox: "firefox",
      ie: "ie",
      ie_mob: "ie",
      ios_saf: "ios",
      node: "node",
      deno: "deno",
      op_mob: "opera",
      opera: "opera",
      safari: "safari",
      samsung: "samsung"
    };
    exports.browserNameMap = browserNameMap;
  }
});

// node_modules/@babel/helper-compilation-targets/lib/utils.js
var require_utils8 = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/utils.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.getHighestUnreleased = getHighestUnreleased;
    exports.getLowestImplementedVersion = getLowestImplementedVersion;
    exports.getLowestUnreleased = getLowestUnreleased;
    exports.isUnreleasedVersion = isUnreleasedVersion;
    exports.semverMin = semverMin;
    exports.semverify = semverify;
    var _semver = require_semver();
    var _helperValidatorOption = require_lib26();
    var _targets = require_targets();
    var versionRegExp = /^(\d+|\d+.\d+)$/;
    var v = new _helperValidatorOption.OptionValidator("@babel/helper-compilation-targets");
    function semverMin(first2, second) {
      return first2 && _semver.lt(first2, second) ? first2 : second;
    }
    function semverify(version2) {
      if (typeof version2 === "string" && _semver.valid(version2)) {
        return version2;
      }
      v.invariant(typeof version2 === "number" || typeof version2 === "string" && versionRegExp.test(version2), `'${version2}' is not a valid version`);
      version2 = version2.toString();
      let pos = 0;
      let num = 0;
      while ((pos = version2.indexOf(".", pos + 1)) > 0) {
        num++;
      }
      return version2 + ".0".repeat(2 - num);
    }
    function isUnreleasedVersion(version2, env) {
      const unreleasedLabel = _targets.unreleasedLabels[env];
      return !!unreleasedLabel && unreleasedLabel === version2.toString().toLowerCase();
    }
    function getLowestUnreleased(a, b, env) {
      const unreleasedLabel = _targets.unreleasedLabels[env];
      if (a === unreleasedLabel) {
        return b;
      }
      if (b === unreleasedLabel) {
        return a;
      }
      return semverMin(a, b);
    }
    function getHighestUnreleased(a, b, env) {
      return getLowestUnreleased(a, b, env) === a ? b : a;
    }
    function getLowestImplementedVersion(plugin, environment) {
      const result = plugin[environment];
      if (!result && environment === "android") {
        return plugin.chrome;
      }
      return result;
    }
  }
});

// node_modules/@babel/helper-compilation-targets/lib/options.js
var require_options2 = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/options.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.TargetNames = void 0;
    var TargetNames = {
      node: "node",
      deno: "deno",
      chrome: "chrome",
      opera: "opera",
      edge: "edge",
      firefox: "firefox",
      safari: "safari",
      ie: "ie",
      ios: "ios",
      android: "android",
      electron: "electron",
      samsung: "samsung",
      rhino: "rhino"
    };
    exports.TargetNames = TargetNames;
  }
});

// node_modules/@babel/helper-compilation-targets/lib/pretty.js
var require_pretty = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/pretty.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.prettifyTargets = prettifyTargets;
    exports.prettifyVersion = prettifyVersion;
    var _semver = require_semver();
    var _targets = require_targets();
    function prettifyVersion(version2) {
      if (typeof version2 !== "string") {
        return version2;
      }
      const {
        major,
        minor,
        patch
      } = _semver.parse(version2);
      const parts = [major];
      if (minor || patch) {
        parts.push(minor);
      }
      if (patch) {
        parts.push(patch);
      }
      return parts.join(".");
    }
    function prettifyTargets(targets) {
      return Object.keys(targets).reduce((results, target) => {
        let value2 = targets[target];
        const unreleasedLabel = _targets.unreleasedLabels[target];
        if (typeof value2 === "string" && unreleasedLabel !== value2) {
          value2 = prettifyVersion(value2);
        }
        results[target] = value2;
        return results;
      }, {});
    }
  }
});

// node_modules/@babel/helper-compilation-targets/lib/debug.js
var require_debug = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/debug.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.getInclusionReasons = getInclusionReasons;
    var _semver = require_semver();
    var _pretty = require_pretty();
    var _utils = require_utils8();
    function getInclusionReasons(item, targetVersions, list) {
      const minVersions = list[item] || {};
      return Object.keys(targetVersions).reduce((result, env) => {
        const minVersion = (0, _utils.getLowestImplementedVersion)(minVersions, env);
        const targetVersion = targetVersions[env];
        if (!minVersion) {
          result[env] = (0, _pretty.prettifyVersion)(targetVersion);
        } else {
          const minIsUnreleased = (0, _utils.isUnreleasedVersion)(minVersion, env);
          const targetIsUnreleased = (0, _utils.isUnreleasedVersion)(targetVersion, env);
          if (!targetIsUnreleased && (minIsUnreleased || _semver.lt(targetVersion.toString(), (0, _utils.semverify)(minVersion)))) {
            result[env] = (0, _pretty.prettifyVersion)(targetVersion);
          }
        }
        return result;
      }, {});
    }
  }
});

// node_modules/@babel/compat-data/data/plugins.json
var require_plugins2 = __commonJS({
  "node_modules/@babel/compat-data/data/plugins.json"(exports, module2) {
    module2.exports = {
      "transform-class-static-block": {
        chrome: "94",
        opera: "80",
        edge: "94",
        firefox: "93",
        node: "16.11",
        deno: "1.14",
        samsung: "17",
        electron: "15.0"
      },
      "proposal-class-static-block": {
        chrome: "94",
        opera: "80",
        edge: "94",
        firefox: "93",
        node: "16.11",
        deno: "1.14",
        samsung: "17",
        electron: "15.0"
      },
      "transform-private-property-in-object": {
        chrome: "91",
        opera: "77",
        edge: "91",
        firefox: "90",
        safari: "15",
        node: "16.9",
        deno: "1.9",
        ios: "15",
        samsung: "16",
        electron: "13.0"
      },
      "proposal-private-property-in-object": {
        chrome: "91",
        opera: "77",
        edge: "91",
        firefox: "90",
        safari: "15",
        node: "16.9",
        deno: "1.9",
        ios: "15",
        samsung: "16",
        electron: "13.0"
      },
      "transform-class-properties": {
        chrome: "74",
        opera: "62",
        edge: "79",
        firefox: "90",
        safari: "14.1",
        node: "12",
        deno: "1",
        ios: "15",
        samsung: "11",
        electron: "6.0"
      },
      "proposal-class-properties": {
        chrome: "74",
        opera: "62",
        edge: "79",
        firefox: "90",
        safari: "14.1",
        node: "12",
        deno: "1",
        ios: "15",
        samsung: "11",
        electron: "6.0"
      },
      "transform-private-methods": {
        chrome: "84",
        opera: "70",
        edge: "84",
        firefox: "90",
        safari: "15",
        node: "14.6",
        deno: "1",
        ios: "15",
        samsung: "14",
        electron: "10.0"
      },
      "proposal-private-methods": {
        chrome: "84",
        opera: "70",
        edge: "84",
        firefox: "90",
        safari: "15",
        node: "14.6",
        deno: "1",
        ios: "15",
        samsung: "14",
        electron: "10.0"
      },
      "transform-numeric-separator": {
        chrome: "75",
        opera: "62",
        edge: "79",
        firefox: "70",
        safari: "13",
        node: "12.5",
        deno: "1",
        ios: "13",
        samsung: "11",
        rhino: "1.7.14",
        electron: "6.0"
      },
      "proposal-numeric-separator": {
        chrome: "75",
        opera: "62",
        edge: "79",
        firefox: "70",
        safari: "13",
        node: "12.5",
        deno: "1",
        ios: "13",
        samsung: "11",
        rhino: "1.7.14",
        electron: "6.0"
      },
      "transform-logical-assignment-operators": {
        chrome: "85",
        opera: "71",
        edge: "85",
        firefox: "79",
        safari: "14",
        node: "15",
        deno: "1.2",
        ios: "14",
        samsung: "14",
        electron: "10.0"
      },
      "proposal-logical-assignment-operators": {
        chrome: "85",
        opera: "71",
        edge: "85",
        firefox: "79",
        safari: "14",
        node: "15",
        deno: "1.2",
        ios: "14",
        samsung: "14",
        electron: "10.0"
      },
      "transform-nullish-coalescing-operator": {
        chrome: "80",
        opera: "67",
        edge: "80",
        firefox: "72",
        safari: "13.1",
        node: "14",
        deno: "1",
        ios: "13.4",
        samsung: "13",
        electron: "8.0"
      },
      "proposal-nullish-coalescing-operator": {
        chrome: "80",
        opera: "67",
        edge: "80",
        firefox: "72",
        safari: "13.1",
        node: "14",
        deno: "1",
        ios: "13.4",
        samsung: "13",
        electron: "8.0"
      },
      "transform-optional-chaining": {
        chrome: "91",
        opera: "77",
        edge: "91",
        firefox: "74",
        safari: "13.1",
        node: "16.9",
        deno: "1.9",
        ios: "13.4",
        samsung: "16",
        electron: "13.0"
      },
      "proposal-optional-chaining": {
        chrome: "91",
        opera: "77",
        edge: "91",
        firefox: "74",
        safari: "13.1",
        node: "16.9",
        deno: "1.9",
        ios: "13.4",
        samsung: "16",
        electron: "13.0"
      },
      "transform-json-strings": {
        chrome: "66",
        opera: "53",
        edge: "79",
        firefox: "62",
        safari: "12",
        node: "10",
        deno: "1",
        ios: "12",
        samsung: "9",
        rhino: "1.7.14",
        electron: "3.0"
      },
      "proposal-json-strings": {
        chrome: "66",
        opera: "53",
        edge: "79",
        firefox: "62",
        safari: "12",
        node: "10",
        deno: "1",
        ios: "12",
        samsung: "9",
        rhino: "1.7.14",
        electron: "3.0"
      },
      "transform-optional-catch-binding": {
        chrome: "66",
        opera: "53",
        edge: "79",
        firefox: "58",
        safari: "11.1",
        node: "10",
        deno: "1",
        ios: "11.3",
        samsung: "9",
        electron: "3.0"
      },
      "proposal-optional-catch-binding": {
        chrome: "66",
        opera: "53",
        edge: "79",
        firefox: "58",
        safari: "11.1",
        node: "10",
        deno: "1",
        ios: "11.3",
        samsung: "9",
        electron: "3.0"
      },
      "transform-parameters": {
        chrome: "49",
        opera: "36",
        edge: "18",
        firefox: "53",
        node: "6",
        deno: "1",
        samsung: "5",
        electron: "0.37"
      },
      "transform-async-generator-functions": {
        chrome: "63",
        opera: "50",
        edge: "79",
        firefox: "57",
        safari: "12",
        node: "10",
        deno: "1",
        ios: "12",
        samsung: "8",
        electron: "3.0"
      },
      "proposal-async-generator-functions": {
        chrome: "63",
        opera: "50",
        edge: "79",
        firefox: "57",
        safari: "12",
        node: "10",
        deno: "1",
        ios: "12",
        samsung: "8",
        electron: "3.0"
      },
      "transform-object-rest-spread": {
        chrome: "60",
        opera: "47",
        edge: "79",
        firefox: "55",
        safari: "11.1",
        node: "8.3",
        deno: "1",
        ios: "11.3",
        samsung: "8",
        electron: "2.0"
      },
      "proposal-object-rest-spread": {
        chrome: "60",
        opera: "47",
        edge: "79",
        firefox: "55",
        safari: "11.1",
        node: "8.3",
        deno: "1",
        ios: "11.3",
        samsung: "8",
        electron: "2.0"
      },
      "transform-dotall-regex": {
        chrome: "62",
        opera: "49",
        edge: "79",
        firefox: "78",
        safari: "11.1",
        node: "8.10",
        deno: "1",
        ios: "11.3",
        samsung: "8",
        electron: "3.0"
      },
      "transform-unicode-property-regex": {
        chrome: "64",
        opera: "51",
        edge: "79",
        firefox: "78",
        safari: "11.1",
        node: "10",
        deno: "1",
        ios: "11.3",
        samsung: "9",
        electron: "3.0"
      },
      "proposal-unicode-property-regex": {
        chrome: "64",
        opera: "51",
        edge: "79",
        firefox: "78",
        safari: "11.1",
        node: "10",
        deno: "1",
        ios: "11.3",
        samsung: "9",
        electron: "3.0"
      },
      "transform-named-capturing-groups-regex": {
        chrome: "64",
        opera: "51",
        edge: "79",
        firefox: "78",
        safari: "11.1",
        node: "10",
        deno: "1",
        ios: "11.3",
        samsung: "9",
        electron: "3.0"
      },
      "transform-async-to-generator": {
        chrome: "55",
        opera: "42",
        edge: "15",
        firefox: "52",
        safari: "11",
        node: "7.6",
        deno: "1",
        ios: "11",
        samsung: "6",
        electron: "1.6"
      },
      "transform-exponentiation-operator": {
        chrome: "52",
        opera: "39",
        edge: "14",
        firefox: "52",
        safari: "10.1",
        node: "7",
        deno: "1",
        ios: "10.3",
        samsung: "6",
        rhino: "1.7.14",
        electron: "1.3"
      },
      "transform-template-literals": {
        chrome: "41",
        opera: "28",
        edge: "13",
        firefox: "34",
        safari: "13",
        node: "4",
        deno: "1",
        ios: "13",
        samsung: "3.4",
        electron: "0.21"
      },
      "transform-literals": {
        chrome: "44",
        opera: "31",
        edge: "12",
        firefox: "53",
        safari: "9",
        node: "4",
        deno: "1",
        ios: "9",
        samsung: "4",
        electron: "0.30"
      },
      "transform-function-name": {
        chrome: "51",
        opera: "38",
        edge: "79",
        firefox: "53",
        safari: "10",
        node: "6.5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "1.2"
      },
      "transform-arrow-functions": {
        chrome: "47",
        opera: "34",
        edge: "13",
        firefox: "43",
        safari: "10",
        node: "6",
        deno: "1",
        ios: "10",
        samsung: "5",
        rhino: "1.7.13",
        electron: "0.36"
      },
      "transform-block-scoped-functions": {
        chrome: "41",
        opera: "28",
        edge: "12",
        firefox: "46",
        safari: "10",
        node: "4",
        deno: "1",
        ie: "11",
        ios: "10",
        samsung: "3.4",
        electron: "0.21"
      },
      "transform-classes": {
        chrome: "46",
        opera: "33",
        edge: "13",
        firefox: "45",
        safari: "10",
        node: "5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "0.36"
      },
      "transform-object-super": {
        chrome: "46",
        opera: "33",
        edge: "13",
        firefox: "45",
        safari: "10",
        node: "5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "0.36"
      },
      "transform-shorthand-properties": {
        chrome: "43",
        opera: "30",
        edge: "12",
        firefox: "33",
        safari: "9",
        node: "4",
        deno: "1",
        ios: "9",
        samsung: "4",
        rhino: "1.7.14",
        electron: "0.27"
      },
      "transform-duplicate-keys": {
        chrome: "42",
        opera: "29",
        edge: "12",
        firefox: "34",
        safari: "9",
        node: "4",
        deno: "1",
        ios: "9",
        samsung: "3.4",
        electron: "0.25"
      },
      "transform-computed-properties": {
        chrome: "44",
        opera: "31",
        edge: "12",
        firefox: "34",
        safari: "7.1",
        node: "4",
        deno: "1",
        ios: "8",
        samsung: "4",
        electron: "0.30"
      },
      "transform-for-of": {
        chrome: "51",
        opera: "38",
        edge: "15",
        firefox: "53",
        safari: "10",
        node: "6.5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "1.2"
      },
      "transform-sticky-regex": {
        chrome: "49",
        opera: "36",
        edge: "13",
        firefox: "3",
        safari: "10",
        node: "6",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "0.37"
      },
      "transform-unicode-escapes": {
        chrome: "44",
        opera: "31",
        edge: "12",
        firefox: "53",
        safari: "9",
        node: "4",
        deno: "1",
        ios: "9",
        samsung: "4",
        electron: "0.30"
      },
      "transform-unicode-regex": {
        chrome: "50",
        opera: "37",
        edge: "13",
        firefox: "46",
        safari: "12",
        node: "6",
        deno: "1",
        ios: "12",
        samsung: "5",
        electron: "1.1"
      },
      "transform-spread": {
        chrome: "46",
        opera: "33",
        edge: "13",
        firefox: "45",
        safari: "10",
        node: "5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "0.36"
      },
      "transform-destructuring": {
        chrome: "51",
        opera: "38",
        edge: "15",
        firefox: "53",
        safari: "10",
        node: "6.5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "1.2"
      },
      "transform-block-scoping": {
        chrome: "49",
        opera: "36",
        edge: "14",
        firefox: "51",
        safari: "11",
        node: "6",
        deno: "1",
        ios: "11",
        samsung: "5",
        electron: "0.37"
      },
      "transform-typeof-symbol": {
        chrome: "38",
        opera: "25",
        edge: "12",
        firefox: "36",
        safari: "9",
        node: "0.12",
        deno: "1",
        ios: "9",
        samsung: "3",
        rhino: "1.7.13",
        electron: "0.20"
      },
      "transform-new-target": {
        chrome: "46",
        opera: "33",
        edge: "14",
        firefox: "41",
        safari: "10",
        node: "5",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "0.36"
      },
      "transform-regenerator": {
        chrome: "50",
        opera: "37",
        edge: "13",
        firefox: "53",
        safari: "10",
        node: "6",
        deno: "1",
        ios: "10",
        samsung: "5",
        electron: "1.1"
      },
      "transform-member-expression-literals": {
        chrome: "7",
        opera: "12",
        edge: "12",
        firefox: "2",
        safari: "5.1",
        node: "0.4",
        deno: "1",
        ie: "9",
        android: "4",
        ios: "6",
        phantom: "1.9",
        samsung: "1",
        rhino: "1.7.13",
        electron: "0.20"
      },
      "transform-property-literals": {
        chrome: "7",
        opera: "12",
        edge: "12",
        firefox: "2",
        safari: "5.1",
        node: "0.4",
        deno: "1",
        ie: "9",
        android: "4",
        ios: "6",
        phantom: "1.9",
        samsung: "1",
        rhino: "1.7.13",
        electron: "0.20"
      },
      "transform-reserved-words": {
        chrome: "13",
        opera: "10.50",
        edge: "12",
        firefox: "2",
        safari: "3.1",
        node: "0.6",
        deno: "1",
        ie: "9",
        android: "4.4",
        ios: "6",
        phantom: "1.9",
        samsung: "1",
        rhino: "1.7.13",
        electron: "0.20"
      },
      "transform-export-namespace-from": {
        chrome: "72",
        and_chr: "72",
        edge: "79",
        firefox: "80",
        and_ff: "80",
        node: "13.2",
        opera: "60",
        op_mob: "51",
        samsung: "11.0",
        android: "72",
        electron: "5.0"
      },
      "proposal-export-namespace-from": {
        chrome: "72",
        and_chr: "72",
        edge: "79",
        firefox: "80",
        and_ff: "80",
        node: "13.2",
        opera: "60",
        op_mob: "51",
        samsung: "11.0",
        android: "72",
        electron: "5.0"
      }
    };
  }
});

// node_modules/@babel/compat-data/plugins.js
var require_plugins3 = __commonJS({
  "node_modules/@babel/compat-data/plugins.js"(exports, module2) {
    module2.exports = require_plugins2();
  }
});

// node_modules/@babel/helper-compilation-targets/lib/filter-items.js
var require_filter_items = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/filter-items.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = filterItems;
    exports.isRequired = isRequired;
    exports.targetsSupported = targetsSupported;
    var _semver = require_semver();
    var _plugins = require_plugins3();
    var _utils = require_utils8();
    function targetsSupported(target, support) {
      const targetEnvironments = Object.keys(target);
      if (targetEnvironments.length === 0) {
        return false;
      }
      const unsupportedEnvironments = targetEnvironments.filter((environment) => {
        const lowestImplementedVersion = (0, _utils.getLowestImplementedVersion)(support, environment);
        if (!lowestImplementedVersion) {
          return true;
        }
        const lowestTargetedVersion = target[environment];
        if ((0, _utils.isUnreleasedVersion)(lowestTargetedVersion, environment)) {
          return false;
        }
        if ((0, _utils.isUnreleasedVersion)(lowestImplementedVersion, environment)) {
          return true;
        }
        if (!_semver.valid(lowestTargetedVersion.toString())) {
          throw new Error(`Invalid version passed for target "${environment}": "${lowestTargetedVersion}". Versions must be in semver format (major.minor.patch)`);
        }
        return _semver.gt((0, _utils.semverify)(lowestImplementedVersion), lowestTargetedVersion.toString());
      });
      return unsupportedEnvironments.length === 0;
    }
    function isRequired(name, targets, {
      compatData = _plugins,
      includes,
      excludes
    } = {}) {
      if (excludes != null && excludes.has(name))
        return false;
      if (includes != null && includes.has(name))
        return true;
      return !targetsSupported(targets, compatData[name]);
    }
    function filterItems(list, includes, excludes, targets, defaultIncludes, defaultExcludes, pluginSyntaxMap) {
      const result = /* @__PURE__ */ new Set();
      const options = {
        compatData: list,
        includes,
        excludes
      };
      for (const item in list) {
        if (isRequired(item, targets, options)) {
          result.add(item);
        } else if (pluginSyntaxMap) {
          const shippedProposalsSyntax = pluginSyntaxMap.get(item);
          if (shippedProposalsSyntax) {
            result.add(shippedProposalsSyntax);
          }
        }
      }
      if (defaultIncludes) {
        defaultIncludes.forEach((item) => !excludes.has(item) && result.add(item));
      }
      if (defaultExcludes) {
        defaultExcludes.forEach((item) => !includes.has(item) && result.delete(item));
      }
      return result;
    }
  }
});

// node_modules/@babel/helper-compilation-targets/lib/index.js
var require_lib27 = __commonJS({
  "node_modules/@babel/helper-compilation-targets/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "TargetNames", {
      enumerable: true,
      get: function() {
        return _options.TargetNames;
      }
    });
    exports.default = getTargets;
    Object.defineProperty(exports, "filterItems", {
      enumerable: true,
      get: function() {
        return _filterItems.default;
      }
    });
    Object.defineProperty(exports, "getInclusionReasons", {
      enumerable: true,
      get: function() {
        return _debug.getInclusionReasons;
      }
    });
    exports.isBrowsersQueryValid = isBrowsersQueryValid;
    Object.defineProperty(exports, "isRequired", {
      enumerable: true,
      get: function() {
        return _filterItems.isRequired;
      }
    });
    Object.defineProperty(exports, "prettifyTargets", {
      enumerable: true,
      get: function() {
        return _pretty.prettifyTargets;
      }
    });
    Object.defineProperty(exports, "unreleasedLabels", {
      enumerable: true,
      get: function() {
        return _targets.unreleasedLabels;
      }
    });
    var _browserslist = require_browserslist();
    var _helperValidatorOption = require_lib26();
    var _nativeModules = require_native_modules2();
    var _lruCache = require_lru_cache();
    var _utils = require_utils8();
    var _targets = require_targets();
    var _options = require_options2();
    var _pretty = require_pretty();
    var _debug = require_debug();
    var _filterItems = require_filter_items();
    var ESM_SUPPORT = _nativeModules["es6.module"];
    var v = new _helperValidatorOption.OptionValidator("@babel/helper-compilation-targets");
    function validateTargetNames(targets) {
      const validTargets = Object.keys(_options.TargetNames);
      for (const target of Object.keys(targets)) {
        if (!(target in _options.TargetNames)) {
          throw new Error(v.formatMessage(`'${target}' is not a valid target
- Did you mean '${(0, _helperValidatorOption.findSuggestion)(target, validTargets)}'?`));
        }
      }
      return targets;
    }
    function isBrowsersQueryValid(browsers) {
      return typeof browsers === "string" || Array.isArray(browsers) && browsers.every((b) => typeof b === "string");
    }
    function validateBrowsers(browsers) {
      v.invariant(browsers === void 0 || isBrowsersQueryValid(browsers), `'${String(browsers)}' is not a valid browserslist query`);
      return browsers;
    }
    function getLowestVersions(browsers) {
      return browsers.reduce((all, browser) => {
        const [browserName, browserVersion] = browser.split(" ");
        const target = _targets.browserNameMap[browserName];
        if (!target) {
          return all;
        }
        try {
          const splitVersion = browserVersion.split("-")[0].toLowerCase();
          const isSplitUnreleased = (0, _utils.isUnreleasedVersion)(splitVersion, target);
          if (!all[target]) {
            all[target] = isSplitUnreleased ? splitVersion : (0, _utils.semverify)(splitVersion);
            return all;
          }
          const version2 = all[target];
          const isUnreleased = (0, _utils.isUnreleasedVersion)(version2, target);
          if (isUnreleased && isSplitUnreleased) {
            all[target] = (0, _utils.getLowestUnreleased)(version2, splitVersion, target);
          } else if (isUnreleased) {
            all[target] = (0, _utils.semverify)(splitVersion);
          } else if (!isUnreleased && !isSplitUnreleased) {
            const parsedBrowserVersion = (0, _utils.semverify)(splitVersion);
            all[target] = (0, _utils.semverMin)(version2, parsedBrowserVersion);
          }
        } catch (e) {
        }
        return all;
      }, {});
    }
    function outputDecimalWarning(decimalTargets) {
      if (!decimalTargets.length) {
        return;
      }
      console.warn("Warning, the following targets are using a decimal version:\n");
      decimalTargets.forEach(({
        target,
        value: value2
      }) => console.warn(`  ${target}: ${value2}`));
      console.warn(`
We recommend using a string for minor/patch versions to avoid numbers like 6.10
getting parsed as 6.1, which can lead to unexpected behavior.
`);
    }
    function semverifyTarget(target, value2) {
      try {
        return (0, _utils.semverify)(value2);
      } catch (error) {
        throw new Error(v.formatMessage(`'${value2}' is not a valid value for 'targets.${target}'.`));
      }
    }
    function nodeTargetParser(value2) {
      const parsed = value2 === true || value2 === "current" ? process.versions.node : semverifyTarget("node", value2);
      return ["node", parsed];
    }
    function defaultTargetParser(target, value2) {
      const version2 = (0, _utils.isUnreleasedVersion)(value2, target) ? value2.toLowerCase() : semverifyTarget(target, value2);
      return [target, version2];
    }
    function generateTargets(inputTargets) {
      const input = Object.assign({}, inputTargets);
      delete input.esmodules;
      delete input.browsers;
      return input;
    }
    function resolveTargets(queries, env) {
      const resolved = _browserslist(queries, {
        mobileToDesktop: true,
        env
      });
      return getLowestVersions(resolved);
    }
    var targetsCache = new _lruCache({
      max: 64
    });
    function resolveTargetsCached(queries, env) {
      const cacheKey = typeof queries === "string" ? queries : queries.join() + env;
      let cached = targetsCache.get(cacheKey);
      if (!cached) {
        cached = resolveTargets(queries, env);
        targetsCache.set(cacheKey, cached);
      }
      return Object.assign({}, cached);
    }
    function getTargets(inputTargets = {}, options = {}) {
      var _browsers, _browsers2;
      let {
        browsers,
        esmodules
      } = inputTargets;
      const {
        configPath = "."
      } = options;
      validateBrowsers(browsers);
      const input = generateTargets(inputTargets);
      let targets = validateTargetNames(input);
      const shouldParseBrowsers = !!browsers;
      const hasTargets = shouldParseBrowsers || Object.keys(targets).length > 0;
      const shouldSearchForConfig = !options.ignoreBrowserslistConfig && !hasTargets;
      if (!browsers && shouldSearchForConfig) {
        browsers = _browserslist.loadConfig({
          config: options.configFile,
          path: configPath,
          env: options.browserslistEnv
        });
        if (browsers == null) {
          {
            browsers = [];
          }
        }
      }
      if (esmodules && (esmodules !== "intersect" || !((_browsers = browsers) != null && _browsers.length))) {
        browsers = Object.keys(ESM_SUPPORT).map((browser) => `${browser} >= ${ESM_SUPPORT[browser]}`).join(", ");
        esmodules = false;
      }
      if ((_browsers2 = browsers) != null && _browsers2.length) {
        const queryBrowsers = resolveTargetsCached(browsers, options.browserslistEnv);
        if (esmodules === "intersect") {
          for (const browser of Object.keys(queryBrowsers)) {
            const version2 = queryBrowsers[browser];
            const esmSupportVersion = ESM_SUPPORT[browser];
            if (esmSupportVersion) {
              queryBrowsers[browser] = (0, _utils.getHighestUnreleased)(version2, (0, _utils.semverify)(esmSupportVersion), browser);
            } else {
              delete queryBrowsers[browser];
            }
          }
        }
        targets = Object.assign(queryBrowsers, targets);
      }
      const result = {};
      const decimalWarnings = [];
      for (const target of Object.keys(targets).sort()) {
        const value2 = targets[target];
        if (typeof value2 === "number" && value2 % 1 !== 0) {
          decimalWarnings.push({
            target,
            value: value2
          });
        }
        const [parsedTarget, parsedValue] = target === "node" ? nodeTargetParser(value2) : defaultTargetParser(target, value2);
        if (parsedValue) {
          result[parsedTarget] = parsedValue;
        }
      }
      outputDecimalWarning(decimalWarnings);
      return result;
    }
  }
});

// node_modules/@babel/core/lib/config/resolve-targets.js
var require_resolve_targets = __commonJS({
  "node_modules/@babel/core/lib/config/resolve-targets.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.resolveBrowserslistConfigFile = resolveBrowserslistConfigFile;
    exports.resolveTargets = resolveTargets;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _helperCompilationTargets() {
      const data = require_lib27();
      _helperCompilationTargets = function() {
        return data;
      };
      return data;
    }
    function resolveBrowserslistConfigFile(browserslistConfigFile, configFileDir) {
      return _path().resolve(configFileDir, browserslistConfigFile);
    }
    function resolveTargets(options, root2) {
      const optTargets = options.targets;
      let targets;
      if (typeof optTargets === "string" || Array.isArray(optTargets)) {
        targets = {
          browsers: optTargets
        };
      } else if (optTargets) {
        if ("esmodules" in optTargets) {
          targets = Object.assign({}, optTargets, {
            esmodules: "intersect"
          });
        } else {
          targets = optTargets;
        }
      }
      const {
        browserslistConfigFile
      } = options;
      let configFile;
      let ignoreBrowserslistConfig = false;
      if (typeof browserslistConfigFile === "string") {
        configFile = browserslistConfigFile;
      } else {
        ignoreBrowserslistConfig = browserslistConfigFile === false;
      }
      return (0, _helperCompilationTargets().default)(targets, {
        ignoreBrowserslistConfig,
        configFile,
        configPath: root2,
        browserslistEnv: options.browserslistEnv
      });
    }
  }
});

// node_modules/@babel/core/lib/config/config-descriptors.js
var require_config_descriptors = __commonJS({
  "node_modules/@babel/core/lib/config/config-descriptors.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.createCachedDescriptors = createCachedDescriptors;
    exports.createDescriptor = createDescriptor;
    exports.createUncachedDescriptors = createUncachedDescriptors;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _functional = require_functional();
    var _files = require_files();
    var _item = require_item();
    var _caching = require_caching();
    var _resolveTargets = require_resolve_targets();
    function isEqualDescriptor(a, b) {
      return a.name === b.name && a.value === b.value && a.options === b.options && a.dirname === b.dirname && a.alias === b.alias && a.ownPass === b.ownPass && (a.file && a.file.request) === (b.file && b.file.request) && (a.file && a.file.resolved) === (b.file && b.file.resolved);
    }
    function* handlerOf(value2) {
      return value2;
    }
    function optionsWithResolvedBrowserslistConfigFile(options, dirname) {
      if (typeof options.browserslistConfigFile === "string") {
        options.browserslistConfigFile = (0, _resolveTargets.resolveBrowserslistConfigFile)(options.browserslistConfigFile, dirname);
      }
      return options;
    }
    function createCachedDescriptors(dirname, options, alias) {
      const {
        plugins,
        presets,
        passPerPreset
      } = options;
      return {
        options: optionsWithResolvedBrowserslistConfigFile(options, dirname),
        plugins: plugins ? () => createCachedPluginDescriptors(plugins, dirname)(alias) : () => handlerOf([]),
        presets: presets ? () => createCachedPresetDescriptors(presets, dirname)(alias)(!!passPerPreset) : () => handlerOf([])
      };
    }
    function createUncachedDescriptors(dirname, options, alias) {
      return {
        options: optionsWithResolvedBrowserslistConfigFile(options, dirname),
        plugins: (0, _functional.once)(() => createPluginDescriptors(options.plugins || [], dirname, alias)),
        presets: (0, _functional.once)(() => createPresetDescriptors(options.presets || [], dirname, alias, !!options.passPerPreset))
      };
    }
    var PRESET_DESCRIPTOR_CACHE = /* @__PURE__ */ new WeakMap();
    var createCachedPresetDescriptors = (0, _caching.makeWeakCacheSync)((items, cache) => {
      const dirname = cache.using((dir) => dir);
      return (0, _caching.makeStrongCacheSync)((alias) => (0, _caching.makeStrongCache)(function* (passPerPreset) {
        const descriptors = yield* createPresetDescriptors(items, dirname, alias, passPerPreset);
        return descriptors.map((desc) => loadCachedDescriptor(PRESET_DESCRIPTOR_CACHE, desc));
      }));
    });
    var PLUGIN_DESCRIPTOR_CACHE = /* @__PURE__ */ new WeakMap();
    var createCachedPluginDescriptors = (0, _caching.makeWeakCacheSync)((items, cache) => {
      const dirname = cache.using((dir) => dir);
      return (0, _caching.makeStrongCache)(function* (alias) {
        const descriptors = yield* createPluginDescriptors(items, dirname, alias);
        return descriptors.map((desc) => loadCachedDescriptor(PLUGIN_DESCRIPTOR_CACHE, desc));
      });
    });
    var DEFAULT_OPTIONS = {};
    function loadCachedDescriptor(cache, desc) {
      const {
        value: value2,
        options = DEFAULT_OPTIONS
      } = desc;
      if (options === false)
        return desc;
      let cacheByOptions = cache.get(value2);
      if (!cacheByOptions) {
        cacheByOptions = /* @__PURE__ */ new WeakMap();
        cache.set(value2, cacheByOptions);
      }
      let possibilities = cacheByOptions.get(options);
      if (!possibilities) {
        possibilities = [];
        cacheByOptions.set(options, possibilities);
      }
      if (possibilities.indexOf(desc) === -1) {
        const matches = possibilities.filter((possibility) => isEqualDescriptor(possibility, desc));
        if (matches.length > 0) {
          return matches[0];
        }
        possibilities.push(desc);
      }
      return desc;
    }
    function* createPresetDescriptors(items, dirname, alias, passPerPreset) {
      return yield* createDescriptors("preset", items, dirname, alias, passPerPreset);
    }
    function* createPluginDescriptors(items, dirname, alias) {
      return yield* createDescriptors("plugin", items, dirname, alias);
    }
    function* createDescriptors(type, items, dirname, alias, ownPass) {
      const descriptors = yield* _gensync().all(items.map((item, index) => createDescriptor(item, dirname, {
        type,
        alias: `${alias}$${index}`,
        ownPass: !!ownPass
      })));
      assertNoDuplicates(descriptors);
      return descriptors;
    }
    function* createDescriptor(pair, dirname, {
      type,
      alias,
      ownPass
    }) {
      const desc = (0, _item.getItemDescriptor)(pair);
      if (desc) {
        return desc;
      }
      let name;
      let options;
      let value2 = pair;
      if (Array.isArray(value2)) {
        if (value2.length === 3) {
          [value2, options, name] = value2;
        } else {
          [value2, options] = value2;
        }
      }
      let file = void 0;
      let filepath = null;
      if (typeof value2 === "string") {
        if (typeof type !== "string") {
          throw new Error("To resolve a string-based item, the type of item must be given");
        }
        const resolver = type === "plugin" ? _files.loadPlugin : _files.loadPreset;
        const request = value2;
        ({
          filepath,
          value: value2
        } = yield* resolver(value2, dirname));
        file = {
          request,
          resolved: filepath
        };
      }
      if (!value2) {
        throw new Error(`Unexpected falsy value: ${String(value2)}`);
      }
      if (typeof value2 === "object" && value2.__esModule) {
        if (value2.default) {
          value2 = value2.default;
        } else {
          throw new Error("Must export a default export when using ES6 modules.");
        }
      }
      if (typeof value2 !== "object" && typeof value2 !== "function") {
        throw new Error(`Unsupported format: ${typeof value2}. Expected an object or a function.`);
      }
      if (filepath !== null && typeof value2 === "object" && value2) {
        throw new Error(`Plugin/Preset files are not allowed to export objects, only functions. In ${filepath}`);
      }
      return {
        name,
        alias: filepath || alias,
        value: value2,
        options,
        dirname,
        ownPass,
        file
      };
    }
    function assertNoDuplicates(items) {
      const map = /* @__PURE__ */ new Map();
      for (const item of items) {
        if (typeof item.value !== "function")
          continue;
        let nameMap = map.get(item.value);
        if (!nameMap) {
          nameMap = /* @__PURE__ */ new Set();
          map.set(item.value, nameMap);
        }
        if (nameMap.has(item.name)) {
          const conflicts = items.filter((i) => i.value === item.value);
          throw new Error([`Duplicate plugin/preset detected.`, `If you'd like to use two separate instances of a plugin,`, `they need separate names, e.g.`, ``, `  plugins: [`, `    ['some-plugin', {}],`, `    ['some-plugin', {}, 'some unique name'],`, `  ]`, ``, `Duplicates detected are:`, `${JSON.stringify(conflicts, null, 2)}`].join("\n"));
        }
        nameMap.add(item.name);
      }
    }
  }
});

// node_modules/@babel/core/lib/config/item.js
var require_item = __commonJS({
  "node_modules/@babel/core/lib/config/item.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.createConfigItem = createConfigItem;
    exports.createItemFromDescriptor = createItemFromDescriptor;
    exports.getItemDescriptor = getItemDescriptor;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    var _configDescriptors = require_config_descriptors();
    function createItemFromDescriptor(desc) {
      return new ConfigItem(desc);
    }
    function* createConfigItem(value2, {
      dirname = ".",
      type
    } = {}) {
      const descriptor = yield* (0, _configDescriptors.createDescriptor)(value2, _path().resolve(dirname), {
        type,
        alias: "programmatic item"
      });
      return createItemFromDescriptor(descriptor);
    }
    var CONFIG_ITEM_BRAND = Symbol.for("@babel/core@7 - ConfigItem");
    function getItemDescriptor(item) {
      if (item != null && item[CONFIG_ITEM_BRAND]) {
        return item._descriptor;
      }
      return void 0;
    }
    var ConfigItem = class {
      constructor(descriptor) {
        this._descriptor = void 0;
        this[CONFIG_ITEM_BRAND] = true;
        this.value = void 0;
        this.options = void 0;
        this.dirname = void 0;
        this.name = void 0;
        this.file = void 0;
        this._descriptor = descriptor;
        Object.defineProperty(this, "_descriptor", {
          enumerable: false
        });
        Object.defineProperty(this, CONFIG_ITEM_BRAND, {
          enumerable: false
        });
        this.value = this._descriptor.value;
        this.options = this._descriptor.options;
        this.dirname = this._descriptor.dirname;
        this.name = this._descriptor.name;
        this.file = this._descriptor.file ? {
          request: this._descriptor.file.request,
          resolved: this._descriptor.file.resolved
        } : void 0;
        Object.freeze(this);
      }
    };
    Object.freeze(ConfigItem.prototype);
  }
});

// node_modules/@babel/core/lib/config/validation/removed.js
var require_removed = __commonJS({
  "node_modules/@babel/core/lib/config/validation/removed.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _default = {
      auxiliaryComment: {
        message: "Use `auxiliaryCommentBefore` or `auxiliaryCommentAfter`"
      },
      blacklist: {
        message: "Put the specific transforms you want in the `plugins` option"
      },
      breakConfig: {
        message: "This is not a necessary option in Babel 6"
      },
      experimental: {
        message: "Put the specific transforms you want in the `plugins` option"
      },
      externalHelpers: {
        message: "Use the `external-helpers` plugin instead. Check out http://babeljs.io/docs/plugins/external-helpers/"
      },
      extra: {
        message: ""
      },
      jsxPragma: {
        message: "use the `pragma` option in the `react-jsx` plugin. Check out http://babeljs.io/docs/plugins/transform-react-jsx/"
      },
      loose: {
        message: "Specify the `loose` option for the relevant plugin you are using or use a preset that sets the option."
      },
      metadataUsedHelpers: {
        message: "Not required anymore as this is enabled by default"
      },
      modules: {
        message: "Use the corresponding module transform plugin in the `plugins` option. Check out http://babeljs.io/docs/plugins/#modules"
      },
      nonStandard: {
        message: "Use the `react-jsx` and `flow-strip-types` plugins to support JSX and Flow. Also check out the react preset http://babeljs.io/docs/plugins/preset-react/"
      },
      optional: {
        message: "Put the specific transforms you want in the `plugins` option"
      },
      sourceMapName: {
        message: "The `sourceMapName` option has been removed because it makes more sense for the tooling that calls Babel to assign `map.file` themselves."
      },
      stage: {
        message: "Check out the corresponding stage-x presets http://babeljs.io/docs/plugins/#presets"
      },
      whitelist: {
        message: "Put the specific transforms you want in the `plugins` option"
      },
      resolveModuleSource: {
        version: 6,
        message: "Use `babel-plugin-module-resolver@3`'s 'resolvePath' options"
      },
      metadata: {
        version: 6,
        message: "Generated plugin metadata is always included in the output result"
      },
      sourceMapTarget: {
        version: 6,
        message: "The `sourceMapTarget` option has been removed because it makes more sense for the tooling that calls Babel to assign `map.file` themselves."
      }
    };
    exports.default = _default;
  }
});

// node_modules/@babel/core/lib/config/validation/option-assertions.js
var require_option_assertions = __commonJS({
  "node_modules/@babel/core/lib/config/validation/option-assertions.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.access = access;
    exports.assertArray = assertArray;
    exports.assertAssumptions = assertAssumptions;
    exports.assertBabelrcSearch = assertBabelrcSearch;
    exports.assertBoolean = assertBoolean;
    exports.assertCallerMetadata = assertCallerMetadata;
    exports.assertCompact = assertCompact;
    exports.assertConfigApplicableTest = assertConfigApplicableTest;
    exports.assertConfigFileSearch = assertConfigFileSearch;
    exports.assertFunction = assertFunction;
    exports.assertIgnoreList = assertIgnoreList;
    exports.assertInputSourceMap = assertInputSourceMap;
    exports.assertObject = assertObject;
    exports.assertPluginList = assertPluginList;
    exports.assertRootMode = assertRootMode;
    exports.assertSourceMaps = assertSourceMaps;
    exports.assertSourceType = assertSourceType;
    exports.assertString = assertString;
    exports.assertTargets = assertTargets;
    exports.msg = msg;
    function _helperCompilationTargets() {
      const data = require_lib27();
      _helperCompilationTargets = function() {
        return data;
      };
      return data;
    }
    var _options = require_options3();
    function msg(loc) {
      switch (loc.type) {
        case "root":
          return ``;
        case "env":
          return `${msg(loc.parent)}.env["${loc.name}"]`;
        case "overrides":
          return `${msg(loc.parent)}.overrides[${loc.index}]`;
        case "option":
          return `${msg(loc.parent)}.${loc.name}`;
        case "access":
          return `${msg(loc.parent)}[${JSON.stringify(loc.name)}]`;
        default:
          throw new Error(`Assertion failure: Unknown type ${loc.type}`);
      }
    }
    function access(loc, name) {
      return {
        type: "access",
        name,
        parent: loc
      };
    }
    function assertRootMode(loc, value2) {
      if (value2 !== void 0 && value2 !== "root" && value2 !== "upward" && value2 !== "upward-optional") {
        throw new Error(`${msg(loc)} must be a "root", "upward", "upward-optional" or undefined`);
      }
      return value2;
    }
    function assertSourceMaps(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "boolean" && value2 !== "inline" && value2 !== "both") {
        throw new Error(`${msg(loc)} must be a boolean, "inline", "both", or undefined`);
      }
      return value2;
    }
    function assertCompact(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "boolean" && value2 !== "auto") {
        throw new Error(`${msg(loc)} must be a boolean, "auto", or undefined`);
      }
      return value2;
    }
    function assertSourceType(loc, value2) {
      if (value2 !== void 0 && value2 !== "module" && value2 !== "script" && value2 !== "unambiguous") {
        throw new Error(`${msg(loc)} must be "module", "script", "unambiguous", or undefined`);
      }
      return value2;
    }
    function assertCallerMetadata(loc, value2) {
      const obj = assertObject(loc, value2);
      if (obj) {
        if (typeof obj.name !== "string") {
          throw new Error(`${msg(loc)} set but does not contain "name" property string`);
        }
        for (const prop of Object.keys(obj)) {
          const propLoc = access(loc, prop);
          const value3 = obj[prop];
          if (value3 != null && typeof value3 !== "boolean" && typeof value3 !== "string" && typeof value3 !== "number") {
            throw new Error(`${msg(propLoc)} must be null, undefined, a boolean, a string, or a number.`);
          }
        }
      }
      return value2;
    }
    function assertInputSourceMap(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "boolean" && (typeof value2 !== "object" || !value2)) {
        throw new Error(`${msg(loc)} must be a boolean, object, or undefined`);
      }
      return value2;
    }
    function assertString(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "string") {
        throw new Error(`${msg(loc)} must be a string, or undefined`);
      }
      return value2;
    }
    function assertFunction(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "function") {
        throw new Error(`${msg(loc)} must be a function, or undefined`);
      }
      return value2;
    }
    function assertBoolean(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "boolean") {
        throw new Error(`${msg(loc)} must be a boolean, or undefined`);
      }
      return value2;
    }
    function assertObject(loc, value2) {
      if (value2 !== void 0 && (typeof value2 !== "object" || Array.isArray(value2) || !value2)) {
        throw new Error(`${msg(loc)} must be an object, or undefined`);
      }
      return value2;
    }
    function assertArray(loc, value2) {
      if (value2 != null && !Array.isArray(value2)) {
        throw new Error(`${msg(loc)} must be an array, or undefined`);
      }
      return value2;
    }
    function assertIgnoreList(loc, value2) {
      const arr = assertArray(loc, value2);
      if (arr) {
        arr.forEach((item, i) => assertIgnoreItem(access(loc, i), item));
      }
      return arr;
    }
    function assertIgnoreItem(loc, value2) {
      if (typeof value2 !== "string" && typeof value2 !== "function" && !(value2 instanceof RegExp)) {
        throw new Error(`${msg(loc)} must be an array of string/Function/RegExp values, or undefined`);
      }
      return value2;
    }
    function assertConfigApplicableTest(loc, value2) {
      if (value2 === void 0) {
        return value2;
      }
      if (Array.isArray(value2)) {
        value2.forEach((item, i) => {
          if (!checkValidTest(item)) {
            throw new Error(`${msg(access(loc, i))} must be a string/Function/RegExp.`);
          }
        });
      } else if (!checkValidTest(value2)) {
        throw new Error(`${msg(loc)} must be a string/Function/RegExp, or an array of those`);
      }
      return value2;
    }
    function checkValidTest(value2) {
      return typeof value2 === "string" || typeof value2 === "function" || value2 instanceof RegExp;
    }
    function assertConfigFileSearch(loc, value2) {
      if (value2 !== void 0 && typeof value2 !== "boolean" && typeof value2 !== "string") {
        throw new Error(`${msg(loc)} must be a undefined, a boolean, a string, got ${JSON.stringify(value2)}`);
      }
      return value2;
    }
    function assertBabelrcSearch(loc, value2) {
      if (value2 === void 0 || typeof value2 === "boolean") {
        return value2;
      }
      if (Array.isArray(value2)) {
        value2.forEach((item, i) => {
          if (!checkValidTest(item)) {
            throw new Error(`${msg(access(loc, i))} must be a string/Function/RegExp.`);
          }
        });
      } else if (!checkValidTest(value2)) {
        throw new Error(`${msg(loc)} must be a undefined, a boolean, a string/Function/RegExp or an array of those, got ${JSON.stringify(value2)}`);
      }
      return value2;
    }
    function assertPluginList(loc, value2) {
      const arr = assertArray(loc, value2);
      if (arr) {
        arr.forEach((item, i) => assertPluginItem(access(loc, i), item));
      }
      return arr;
    }
    function assertPluginItem(loc, value2) {
      if (Array.isArray(value2)) {
        if (value2.length === 0) {
          throw new Error(`${msg(loc)} must include an object`);
        }
        if (value2.length > 3) {
          throw new Error(`${msg(loc)} may only be a two-tuple or three-tuple`);
        }
        assertPluginTarget(access(loc, 0), value2[0]);
        if (value2.length > 1) {
          const opts = value2[1];
          if (opts !== void 0 && opts !== false && (typeof opts !== "object" || Array.isArray(opts) || opts === null)) {
            throw new Error(`${msg(access(loc, 1))} must be an object, false, or undefined`);
          }
        }
        if (value2.length === 3) {
          const name = value2[2];
          if (name !== void 0 && typeof name !== "string") {
            throw new Error(`${msg(access(loc, 2))} must be a string, or undefined`);
          }
        }
      } else {
        assertPluginTarget(loc, value2);
      }
      return value2;
    }
    function assertPluginTarget(loc, value2) {
      if ((typeof value2 !== "object" || !value2) && typeof value2 !== "string" && typeof value2 !== "function") {
        throw new Error(`${msg(loc)} must be a string, object, function`);
      }
      return value2;
    }
    function assertTargets(loc, value2) {
      if ((0, _helperCompilationTargets().isBrowsersQueryValid)(value2))
        return value2;
      if (typeof value2 !== "object" || !value2 || Array.isArray(value2)) {
        throw new Error(`${msg(loc)} must be a string, an array of strings or an object`);
      }
      const browsersLoc = access(loc, "browsers");
      const esmodulesLoc = access(loc, "esmodules");
      assertBrowsersList(browsersLoc, value2.browsers);
      assertBoolean(esmodulesLoc, value2.esmodules);
      for (const key of Object.keys(value2)) {
        const val = value2[key];
        const subLoc = access(loc, key);
        if (key === "esmodules")
          assertBoolean(subLoc, val);
        else if (key === "browsers")
          assertBrowsersList(subLoc, val);
        else if (!Object.hasOwnProperty.call(_helperCompilationTargets().TargetNames, key)) {
          const validTargets = Object.keys(_helperCompilationTargets().TargetNames).join(", ");
          throw new Error(`${msg(subLoc)} is not a valid target. Supported targets are ${validTargets}`);
        } else
          assertBrowserVersion(subLoc, val);
      }
      return value2;
    }
    function assertBrowsersList(loc, value2) {
      if (value2 !== void 0 && !(0, _helperCompilationTargets().isBrowsersQueryValid)(value2)) {
        throw new Error(`${msg(loc)} must be undefined, a string or an array of strings`);
      }
    }
    function assertBrowserVersion(loc, value2) {
      if (typeof value2 === "number" && Math.round(value2) === value2)
        return;
      if (typeof value2 === "string")
        return;
      throw new Error(`${msg(loc)} must be a string or an integer number`);
    }
    function assertAssumptions(loc, value2) {
      if (value2 === void 0)
        return;
      if (typeof value2 !== "object" || value2 === null) {
        throw new Error(`${msg(loc)} must be an object or undefined.`);
      }
      let root2 = loc;
      do {
        root2 = root2.parent;
      } while (root2.type !== "root");
      const inPreset = root2.source === "preset";
      for (const name of Object.keys(value2)) {
        const subLoc = access(loc, name);
        if (!_options.assumptionsNames.has(name)) {
          throw new Error(`${msg(subLoc)} is not a supported assumption.`);
        }
        if (typeof value2[name] !== "boolean") {
          throw new Error(`${msg(subLoc)} must be a boolean.`);
        }
        if (inPreset && value2[name] === false) {
          throw new Error(`${msg(subLoc)} cannot be set to 'false' inside presets.`);
        }
      }
      return value2;
    }
  }
});

// node_modules/@babel/core/lib/config/validation/options.js
var require_options3 = __commonJS({
  "node_modules/@babel/core/lib/config/validation/options.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.assumptionsNames = void 0;
    exports.checkNoUnwrappedItemOptionPairs = checkNoUnwrappedItemOptionPairs;
    exports.validate = validate;
    var _removed = require_removed();
    var _optionAssertions = require_option_assertions();
    var _configError = require_config_error();
    var ROOT_VALIDATORS = {
      cwd: _optionAssertions.assertString,
      root: _optionAssertions.assertString,
      rootMode: _optionAssertions.assertRootMode,
      configFile: _optionAssertions.assertConfigFileSearch,
      caller: _optionAssertions.assertCallerMetadata,
      filename: _optionAssertions.assertString,
      filenameRelative: _optionAssertions.assertString,
      code: _optionAssertions.assertBoolean,
      ast: _optionAssertions.assertBoolean,
      cloneInputAst: _optionAssertions.assertBoolean,
      envName: _optionAssertions.assertString
    };
    var BABELRC_VALIDATORS = {
      babelrc: _optionAssertions.assertBoolean,
      babelrcRoots: _optionAssertions.assertBabelrcSearch
    };
    var NONPRESET_VALIDATORS = {
      extends: _optionAssertions.assertString,
      ignore: _optionAssertions.assertIgnoreList,
      only: _optionAssertions.assertIgnoreList,
      targets: _optionAssertions.assertTargets,
      browserslistConfigFile: _optionAssertions.assertConfigFileSearch,
      browserslistEnv: _optionAssertions.assertString
    };
    var COMMON_VALIDATORS = {
      inputSourceMap: _optionAssertions.assertInputSourceMap,
      presets: _optionAssertions.assertPluginList,
      plugins: _optionAssertions.assertPluginList,
      passPerPreset: _optionAssertions.assertBoolean,
      assumptions: _optionAssertions.assertAssumptions,
      env: assertEnvSet,
      overrides: assertOverridesList,
      test: _optionAssertions.assertConfigApplicableTest,
      include: _optionAssertions.assertConfigApplicableTest,
      exclude: _optionAssertions.assertConfigApplicableTest,
      retainLines: _optionAssertions.assertBoolean,
      comments: _optionAssertions.assertBoolean,
      shouldPrintComment: _optionAssertions.assertFunction,
      compact: _optionAssertions.assertCompact,
      minified: _optionAssertions.assertBoolean,
      auxiliaryCommentBefore: _optionAssertions.assertString,
      auxiliaryCommentAfter: _optionAssertions.assertString,
      sourceType: _optionAssertions.assertSourceType,
      wrapPluginVisitorMethod: _optionAssertions.assertFunction,
      highlightCode: _optionAssertions.assertBoolean,
      sourceMaps: _optionAssertions.assertSourceMaps,
      sourceMap: _optionAssertions.assertSourceMaps,
      sourceFileName: _optionAssertions.assertString,
      sourceRoot: _optionAssertions.assertString,
      parserOpts: _optionAssertions.assertObject,
      generatorOpts: _optionAssertions.assertObject
    };
    {
      Object.assign(COMMON_VALIDATORS, {
        getModuleId: _optionAssertions.assertFunction,
        moduleRoot: _optionAssertions.assertString,
        moduleIds: _optionAssertions.assertBoolean,
        moduleId: _optionAssertions.assertString
      });
    }
    var knownAssumptions = ["arrayLikeIsIterable", "constantReexports", "constantSuper", "enumerableModuleMeta", "ignoreFunctionLength", "ignoreToPrimitiveHint", "iterableIsArray", "mutableTemplateObject", "noClassCalls", "noDocumentAll", "noIncompleteNsImportDetection", "noNewArrows", "objectRestNoSymbols", "privateFieldsAsProperties", "pureGetters", "setClassMethods", "setComputedProperties", "setPublicClassFields", "setSpreadProperties", "skipForOfIteratorClosing", "superIsCallableConstructor"];
    var assumptionsNames = new Set(knownAssumptions);
    exports.assumptionsNames = assumptionsNames;
    function getSource(loc) {
      return loc.type === "root" ? loc.source : getSource(loc.parent);
    }
    function validate(type, opts, filename) {
      try {
        return validateNested({
          type: "root",
          source: type
        }, opts);
      } catch (error) {
        const configError = new _configError.default(error.message, filename);
        if (error.code)
          configError.code = error.code;
        throw configError;
      }
    }
    function validateNested(loc, opts) {
      const type = getSource(loc);
      assertNoDuplicateSourcemap(opts);
      Object.keys(opts).forEach((key) => {
        const optLoc = {
          type: "option",
          name: key,
          parent: loc
        };
        if (type === "preset" && NONPRESET_VALIDATORS[key]) {
          throw new Error(`${(0, _optionAssertions.msg)(optLoc)} is not allowed in preset options`);
        }
        if (type !== "arguments" && ROOT_VALIDATORS[key]) {
          throw new Error(`${(0, _optionAssertions.msg)(optLoc)} is only allowed in root programmatic options`);
        }
        if (type !== "arguments" && type !== "configfile" && BABELRC_VALIDATORS[key]) {
          if (type === "babelrcfile" || type === "extendsfile") {
            throw new Error(`${(0, _optionAssertions.msg)(optLoc)} is not allowed in .babelrc or "extends"ed files, only in root programmatic options, or babel.config.js/config file options`);
          }
          throw new Error(`${(0, _optionAssertions.msg)(optLoc)} is only allowed in root programmatic options, or babel.config.js/config file options`);
        }
        const validator = COMMON_VALIDATORS[key] || NONPRESET_VALIDATORS[key] || BABELRC_VALIDATORS[key] || ROOT_VALIDATORS[key] || throwUnknownError;
        validator(optLoc, opts[key]);
      });
      return opts;
    }
    function throwUnknownError(loc) {
      const key = loc.name;
      if (_removed.default[key]) {
        const {
          message,
          version: version2 = 5
        } = _removed.default[key];
        throw new Error(`Using removed Babel ${version2} option: ${(0, _optionAssertions.msg)(loc)} - ${message}`);
      } else {
        const unknownOptErr = new Error(`Unknown option: ${(0, _optionAssertions.msg)(loc)}. Check out https://babeljs.io/docs/en/babel-core/#options for more information about options.`);
        unknownOptErr.code = "BABEL_UNKNOWN_OPTION";
        throw unknownOptErr;
      }
    }
    function has(obj, key) {
      return Object.prototype.hasOwnProperty.call(obj, key);
    }
    function assertNoDuplicateSourcemap(opts) {
      if (has(opts, "sourceMap") && has(opts, "sourceMaps")) {
        throw new Error(".sourceMap is an alias for .sourceMaps, cannot use both");
      }
    }
    function assertEnvSet(loc, value2) {
      if (loc.parent.type === "env") {
        throw new Error(`${(0, _optionAssertions.msg)(loc)} is not allowed inside of another .env block`);
      }
      const parent = loc.parent;
      const obj = (0, _optionAssertions.assertObject)(loc, value2);
      if (obj) {
        for (const envName of Object.keys(obj)) {
          const env = (0, _optionAssertions.assertObject)((0, _optionAssertions.access)(loc, envName), obj[envName]);
          if (!env)
            continue;
          const envLoc = {
            type: "env",
            name: envName,
            parent
          };
          validateNested(envLoc, env);
        }
      }
      return obj;
    }
    function assertOverridesList(loc, value2) {
      if (loc.parent.type === "env") {
        throw new Error(`${(0, _optionAssertions.msg)(loc)} is not allowed inside an .env block`);
      }
      if (loc.parent.type === "overrides") {
        throw new Error(`${(0, _optionAssertions.msg)(loc)} is not allowed inside an .overrides block`);
      }
      const parent = loc.parent;
      const arr = (0, _optionAssertions.assertArray)(loc, value2);
      if (arr) {
        for (const [index, item] of arr.entries()) {
          const objLoc = (0, _optionAssertions.access)(loc, index);
          const env = (0, _optionAssertions.assertObject)(objLoc, item);
          if (!env)
            throw new Error(`${(0, _optionAssertions.msg)(objLoc)} must be an object`);
          const overridesLoc = {
            type: "overrides",
            index,
            parent
          };
          validateNested(overridesLoc, env);
        }
      }
      return arr;
    }
    function checkNoUnwrappedItemOptionPairs(items, index, type, e) {
      if (index === 0)
        return;
      const lastItem = items[index - 1];
      const thisItem = items[index];
      if (lastItem.file && lastItem.options === void 0 && typeof thisItem.value === "object") {
        e.message += `
- Maybe you meant to use
"${type}s": [
  ["${lastItem.file.request}", ${JSON.stringify(thisItem.value, void 0, 2)}]
]
To be a valid ${type}, its name and options should be wrapped in a pair of brackets`;
      }
    }
  }
});

// node_modules/@babel/core/lib/config/printer.js
var require_printer2 = __commonJS({
  "node_modules/@babel/core/lib/config/printer.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ConfigPrinter = exports.ChainFormatter = void 0;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var ChainFormatter = {
      Programmatic: 0,
      Config: 1
    };
    exports.ChainFormatter = ChainFormatter;
    var Formatter = {
      title(type, callerName, filepath) {
        let title = "";
        if (type === ChainFormatter.Programmatic) {
          title = "programmatic options";
          if (callerName) {
            title += " from " + callerName;
          }
        } else {
          title = "config " + filepath;
        }
        return title;
      },
      loc(index, envName) {
        let loc = "";
        if (index != null) {
          loc += `.overrides[${index}]`;
        }
        if (envName != null) {
          loc += `.env["${envName}"]`;
        }
        return loc;
      },
      *optionsAndDescriptors(opt) {
        const content = Object.assign({}, opt.options);
        delete content.overrides;
        delete content.env;
        const pluginDescriptors = [...yield* opt.plugins()];
        if (pluginDescriptors.length) {
          content.plugins = pluginDescriptors.map((d) => descriptorToConfig(d));
        }
        const presetDescriptors = [...yield* opt.presets()];
        if (presetDescriptors.length) {
          content.presets = [...presetDescriptors].map((d) => descriptorToConfig(d));
        }
        return JSON.stringify(content, void 0, 2);
      }
    };
    function descriptorToConfig(d) {
      var _d$file;
      let name = (_d$file = d.file) == null ? void 0 : _d$file.request;
      if (name == null) {
        if (typeof d.value === "object") {
          name = d.value;
        } else if (typeof d.value === "function") {
          name = `[Function: ${d.value.toString().slice(0, 50)} ... ]`;
        }
      }
      if (name == null) {
        name = "[Unknown]";
      }
      if (d.options === void 0) {
        return name;
      } else if (d.name == null) {
        return [name, d.options];
      } else {
        return [name, d.options, d.name];
      }
    }
    var ConfigPrinter = class _ConfigPrinter {
      constructor() {
        this._stack = [];
      }
      configure(enabled, type, {
        callerName,
        filepath
      }) {
        if (!enabled)
          return () => {
          };
        return (content, index, envName) => {
          this._stack.push({
            type,
            callerName,
            filepath,
            content,
            index,
            envName
          });
        };
      }
      static *format(config) {
        let title = Formatter.title(config.type, config.callerName, config.filepath);
        const loc = Formatter.loc(config.index, config.envName);
        if (loc)
          title += ` ${loc}`;
        const content = yield* Formatter.optionsAndDescriptors(config.content);
        return `${title}
${content}`;
      }
      *output() {
        if (this._stack.length === 0)
          return "";
        const configs = yield* _gensync().all(this._stack.map((s) => _ConfigPrinter.format(s)));
        return configs.join("\n\n");
      }
    };
    exports.ConfigPrinter = ConfigPrinter;
  }
});

// node_modules/@babel/core/lib/config/config-chain.js
var require_config_chain = __commonJS({
  "node_modules/@babel/core/lib/config/config-chain.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.buildPresetChain = buildPresetChain;
    exports.buildPresetChainWalker = void 0;
    exports.buildRootChain = buildRootChain;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _debug() {
      const data = require_src();
      _debug = function() {
        return data;
      };
      return data;
    }
    var _options = require_options3();
    var _patternToRegex = require_pattern_to_regex();
    var _printer = require_printer2();
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var _configError = require_config_error();
    var _files = require_files();
    var _caching = require_caching();
    var _configDescriptors = require_config_descriptors();
    var debug = _debug()("babel:config:config-chain");
    function* buildPresetChain(arg, context) {
      const chain = yield* buildPresetChainWalker(arg, context);
      if (!chain)
        return null;
      return {
        plugins: dedupDescriptors(chain.plugins),
        presets: dedupDescriptors(chain.presets),
        options: chain.options.map((o) => normalizeOptions(o)),
        files: /* @__PURE__ */ new Set()
      };
    }
    var buildPresetChainWalker = makeChainWalker({
      root: (preset) => loadPresetDescriptors(preset),
      env: (preset, envName) => loadPresetEnvDescriptors(preset)(envName),
      overrides: (preset, index) => loadPresetOverridesDescriptors(preset)(index),
      overridesEnv: (preset, index, envName) => loadPresetOverridesEnvDescriptors(preset)(index)(envName),
      createLogger: () => () => {
      }
    });
    exports.buildPresetChainWalker = buildPresetChainWalker;
    var loadPresetDescriptors = (0, _caching.makeWeakCacheSync)((preset) => buildRootDescriptors(preset, preset.alias, _configDescriptors.createUncachedDescriptors));
    var loadPresetEnvDescriptors = (0, _caching.makeWeakCacheSync)((preset) => (0, _caching.makeStrongCacheSync)((envName) => buildEnvDescriptors(preset, preset.alias, _configDescriptors.createUncachedDescriptors, envName)));
    var loadPresetOverridesDescriptors = (0, _caching.makeWeakCacheSync)((preset) => (0, _caching.makeStrongCacheSync)((index) => buildOverrideDescriptors(preset, preset.alias, _configDescriptors.createUncachedDescriptors, index)));
    var loadPresetOverridesEnvDescriptors = (0, _caching.makeWeakCacheSync)((preset) => (0, _caching.makeStrongCacheSync)((index) => (0, _caching.makeStrongCacheSync)((envName) => buildOverrideEnvDescriptors(preset, preset.alias, _configDescriptors.createUncachedDescriptors, index, envName))));
    function* buildRootChain(opts, context) {
      let configReport, babelRcReport;
      const programmaticLogger = new _printer.ConfigPrinter();
      const programmaticChain = yield* loadProgrammaticChain({
        options: opts,
        dirname: context.cwd
      }, context, void 0, programmaticLogger);
      if (!programmaticChain)
        return null;
      const programmaticReport = yield* programmaticLogger.output();
      let configFile;
      if (typeof opts.configFile === "string") {
        configFile = yield* (0, _files.loadConfig)(opts.configFile, context.cwd, context.envName, context.caller);
      } else if (opts.configFile !== false) {
        configFile = yield* (0, _files.findRootConfig)(context.root, context.envName, context.caller);
      }
      let {
        babelrc,
        babelrcRoots
      } = opts;
      let babelrcRootsDirectory = context.cwd;
      const configFileChain = emptyChain();
      const configFileLogger = new _printer.ConfigPrinter();
      if (configFile) {
        const validatedFile = validateConfigFile(configFile);
        const result = yield* loadFileChain(validatedFile, context, void 0, configFileLogger);
        if (!result)
          return null;
        configReport = yield* configFileLogger.output();
        if (babelrc === void 0) {
          babelrc = validatedFile.options.babelrc;
        }
        if (babelrcRoots === void 0) {
          babelrcRootsDirectory = validatedFile.dirname;
          babelrcRoots = validatedFile.options.babelrcRoots;
        }
        mergeChain(configFileChain, result);
      }
      let ignoreFile, babelrcFile;
      let isIgnored = false;
      const fileChain = emptyChain();
      if ((babelrc === true || babelrc === void 0) && typeof context.filename === "string") {
        const pkgData = yield* (0, _files.findPackageData)(context.filename);
        if (pkgData && babelrcLoadEnabled(context, pkgData, babelrcRoots, babelrcRootsDirectory)) {
          ({
            ignore: ignoreFile,
            config: babelrcFile
          } = yield* (0, _files.findRelativeConfig)(pkgData, context.envName, context.caller));
          if (ignoreFile) {
            fileChain.files.add(ignoreFile.filepath);
          }
          if (ignoreFile && shouldIgnore(context, ignoreFile.ignore, null, ignoreFile.dirname)) {
            isIgnored = true;
          }
          if (babelrcFile && !isIgnored) {
            const validatedFile = validateBabelrcFile(babelrcFile);
            const babelrcLogger = new _printer.ConfigPrinter();
            const result = yield* loadFileChain(validatedFile, context, void 0, babelrcLogger);
            if (!result) {
              isIgnored = true;
            } else {
              babelRcReport = yield* babelrcLogger.output();
              mergeChain(fileChain, result);
            }
          }
          if (babelrcFile && isIgnored) {
            fileChain.files.add(babelrcFile.filepath);
          }
        }
      }
      if (context.showConfig) {
        console.log(`Babel configs on "${context.filename}" (ascending priority):
` + [configReport, babelRcReport, programmaticReport].filter((x) => !!x).join("\n\n") + "\n-----End Babel configs-----");
      }
      const chain = mergeChain(mergeChain(mergeChain(emptyChain(), configFileChain), fileChain), programmaticChain);
      return {
        plugins: isIgnored ? [] : dedupDescriptors(chain.plugins),
        presets: isIgnored ? [] : dedupDescriptors(chain.presets),
        options: isIgnored ? [] : chain.options.map((o) => normalizeOptions(o)),
        fileHandling: isIgnored ? "ignored" : "transpile",
        ignore: ignoreFile || void 0,
        babelrc: babelrcFile || void 0,
        config: configFile || void 0,
        files: chain.files
      };
    }
    function babelrcLoadEnabled(context, pkgData, babelrcRoots, babelrcRootsDirectory) {
      if (typeof babelrcRoots === "boolean")
        return babelrcRoots;
      const absoluteRoot = context.root;
      if (babelrcRoots === void 0) {
        return pkgData.directories.indexOf(absoluteRoot) !== -1;
      }
      let babelrcPatterns = babelrcRoots;
      if (!Array.isArray(babelrcPatterns)) {
        babelrcPatterns = [babelrcPatterns];
      }
      babelrcPatterns = babelrcPatterns.map((pat) => {
        return typeof pat === "string" ? _path().resolve(babelrcRootsDirectory, pat) : pat;
      });
      if (babelrcPatterns.length === 1 && babelrcPatterns[0] === absoluteRoot) {
        return pkgData.directories.indexOf(absoluteRoot) !== -1;
      }
      return babelrcPatterns.some((pat) => {
        if (typeof pat === "string") {
          pat = (0, _patternToRegex.default)(pat, babelrcRootsDirectory);
        }
        return pkgData.directories.some((directory) => {
          return matchPattern(pat, babelrcRootsDirectory, directory, context);
        });
      });
    }
    var validateConfigFile = (0, _caching.makeWeakCacheSync)((file) => ({
      filepath: file.filepath,
      dirname: file.dirname,
      options: (0, _options.validate)("configfile", file.options, file.filepath)
    }));
    var validateBabelrcFile = (0, _caching.makeWeakCacheSync)((file) => ({
      filepath: file.filepath,
      dirname: file.dirname,
      options: (0, _options.validate)("babelrcfile", file.options, file.filepath)
    }));
    var validateExtendFile = (0, _caching.makeWeakCacheSync)((file) => ({
      filepath: file.filepath,
      dirname: file.dirname,
      options: (0, _options.validate)("extendsfile", file.options, file.filepath)
    }));
    var loadProgrammaticChain = makeChainWalker({
      root: (input) => buildRootDescriptors(input, "base", _configDescriptors.createCachedDescriptors),
      env: (input, envName) => buildEnvDescriptors(input, "base", _configDescriptors.createCachedDescriptors, envName),
      overrides: (input, index) => buildOverrideDescriptors(input, "base", _configDescriptors.createCachedDescriptors, index),
      overridesEnv: (input, index, envName) => buildOverrideEnvDescriptors(input, "base", _configDescriptors.createCachedDescriptors, index, envName),
      createLogger: (input, context, baseLogger) => buildProgrammaticLogger(input, context, baseLogger)
    });
    var loadFileChainWalker = makeChainWalker({
      root: (file) => loadFileDescriptors(file),
      env: (file, envName) => loadFileEnvDescriptors(file)(envName),
      overrides: (file, index) => loadFileOverridesDescriptors(file)(index),
      overridesEnv: (file, index, envName) => loadFileOverridesEnvDescriptors(file)(index)(envName),
      createLogger: (file, context, baseLogger) => buildFileLogger(file.filepath, context, baseLogger)
    });
    function* loadFileChain(input, context, files, baseLogger) {
      const chain = yield* loadFileChainWalker(input, context, files, baseLogger);
      if (chain) {
        chain.files.add(input.filepath);
      }
      return chain;
    }
    var loadFileDescriptors = (0, _caching.makeWeakCacheSync)((file) => buildRootDescriptors(file, file.filepath, _configDescriptors.createUncachedDescriptors));
    var loadFileEnvDescriptors = (0, _caching.makeWeakCacheSync)((file) => (0, _caching.makeStrongCacheSync)((envName) => buildEnvDescriptors(file, file.filepath, _configDescriptors.createUncachedDescriptors, envName)));
    var loadFileOverridesDescriptors = (0, _caching.makeWeakCacheSync)((file) => (0, _caching.makeStrongCacheSync)((index) => buildOverrideDescriptors(file, file.filepath, _configDescriptors.createUncachedDescriptors, index)));
    var loadFileOverridesEnvDescriptors = (0, _caching.makeWeakCacheSync)((file) => (0, _caching.makeStrongCacheSync)((index) => (0, _caching.makeStrongCacheSync)((envName) => buildOverrideEnvDescriptors(file, file.filepath, _configDescriptors.createUncachedDescriptors, index, envName))));
    function buildFileLogger(filepath, context, baseLogger) {
      if (!baseLogger) {
        return () => {
        };
      }
      return baseLogger.configure(context.showConfig, _printer.ChainFormatter.Config, {
        filepath
      });
    }
    function buildRootDescriptors({
      dirname,
      options
    }, alias, descriptors) {
      return descriptors(dirname, options, alias);
    }
    function buildProgrammaticLogger(_, context, baseLogger) {
      var _context$caller;
      if (!baseLogger) {
        return () => {
        };
      }
      return baseLogger.configure(context.showConfig, _printer.ChainFormatter.Programmatic, {
        callerName: (_context$caller = context.caller) == null ? void 0 : _context$caller.name
      });
    }
    function buildEnvDescriptors({
      dirname,
      options
    }, alias, descriptors, envName) {
      const opts = options.env && options.env[envName];
      return opts ? descriptors(dirname, opts, `${alias}.env["${envName}"]`) : null;
    }
    function buildOverrideDescriptors({
      dirname,
      options
    }, alias, descriptors, index) {
      const opts = options.overrides && options.overrides[index];
      if (!opts)
        throw new Error("Assertion failure - missing override");
      return descriptors(dirname, opts, `${alias}.overrides[${index}]`);
    }
    function buildOverrideEnvDescriptors({
      dirname,
      options
    }, alias, descriptors, index, envName) {
      const override = options.overrides && options.overrides[index];
      if (!override)
        throw new Error("Assertion failure - missing override");
      const opts = override.env && override.env[envName];
      return opts ? descriptors(dirname, opts, `${alias}.overrides[${index}].env["${envName}"]`) : null;
    }
    function makeChainWalker({
      root: root2,
      env,
      overrides,
      overridesEnv,
      createLogger
    }) {
      return function* chainWalker(input, context, files = /* @__PURE__ */ new Set(), baseLogger) {
        const {
          dirname
        } = input;
        const flattenedConfigs = [];
        const rootOpts = root2(input);
        if (configIsApplicable(rootOpts, dirname, context, input.filepath)) {
          flattenedConfigs.push({
            config: rootOpts,
            envName: void 0,
            index: void 0
          });
          const envOpts = env(input, context.envName);
          if (envOpts && configIsApplicable(envOpts, dirname, context, input.filepath)) {
            flattenedConfigs.push({
              config: envOpts,
              envName: context.envName,
              index: void 0
            });
          }
          (rootOpts.options.overrides || []).forEach((_, index) => {
            const overrideOps = overrides(input, index);
            if (configIsApplicable(overrideOps, dirname, context, input.filepath)) {
              flattenedConfigs.push({
                config: overrideOps,
                index,
                envName: void 0
              });
              const overrideEnvOpts = overridesEnv(input, index, context.envName);
              if (overrideEnvOpts && configIsApplicable(overrideEnvOpts, dirname, context, input.filepath)) {
                flattenedConfigs.push({
                  config: overrideEnvOpts,
                  index,
                  envName: context.envName
                });
              }
            }
          });
        }
        if (flattenedConfigs.some(({
          config: {
            options: {
              ignore,
              only
            }
          }
        }) => shouldIgnore(context, ignore, only, dirname))) {
          return null;
        }
        const chain = emptyChain();
        const logger = createLogger(input, context, baseLogger);
        for (const {
          config,
          index,
          envName
        } of flattenedConfigs) {
          if (!(yield* mergeExtendsChain(chain, config.options, dirname, context, files, baseLogger))) {
            return null;
          }
          logger(config, index, envName);
          yield* mergeChainOpts(chain, config);
        }
        return chain;
      };
    }
    function* mergeExtendsChain(chain, opts, dirname, context, files, baseLogger) {
      if (opts.extends === void 0)
        return true;
      const file = yield* (0, _files.loadConfig)(opts.extends, dirname, context.envName, context.caller);
      if (files.has(file)) {
        throw new Error(`Configuration cycle detected loading ${file.filepath}.
File already loaded following the config chain:
` + Array.from(files, (file2) => ` - ${file2.filepath}`).join("\n"));
      }
      files.add(file);
      const fileChain = yield* loadFileChain(validateExtendFile(file), context, files, baseLogger);
      files.delete(file);
      if (!fileChain)
        return false;
      mergeChain(chain, fileChain);
      return true;
    }
    function mergeChain(target, source) {
      target.options.push(...source.options);
      target.plugins.push(...source.plugins);
      target.presets.push(...source.presets);
      for (const file of source.files) {
        target.files.add(file);
      }
      return target;
    }
    function* mergeChainOpts(target, {
      options,
      plugins,
      presets
    }) {
      target.options.push(options);
      target.plugins.push(...yield* plugins());
      target.presets.push(...yield* presets());
      return target;
    }
    function emptyChain() {
      return {
        options: [],
        presets: [],
        plugins: [],
        files: /* @__PURE__ */ new Set()
      };
    }
    function normalizeOptions(opts) {
      const options = Object.assign({}, opts);
      delete options.extends;
      delete options.env;
      delete options.overrides;
      delete options.plugins;
      delete options.presets;
      delete options.passPerPreset;
      delete options.ignore;
      delete options.only;
      delete options.test;
      delete options.include;
      delete options.exclude;
      if (Object.prototype.hasOwnProperty.call(options, "sourceMap")) {
        options.sourceMaps = options.sourceMap;
        delete options.sourceMap;
      }
      return options;
    }
    function dedupDescriptors(items) {
      const map = /* @__PURE__ */ new Map();
      const descriptors = [];
      for (const item of items) {
        if (typeof item.value === "function") {
          const fnKey = item.value;
          let nameMap = map.get(fnKey);
          if (!nameMap) {
            nameMap = /* @__PURE__ */ new Map();
            map.set(fnKey, nameMap);
          }
          let desc = nameMap.get(item.name);
          if (!desc) {
            desc = {
              value: item
            };
            descriptors.push(desc);
            if (!item.ownPass)
              nameMap.set(item.name, desc);
          } else {
            desc.value = item;
          }
        } else {
          descriptors.push({
            value: item
          });
        }
      }
      return descriptors.reduce((acc, desc) => {
        acc.push(desc.value);
        return acc;
      }, []);
    }
    function configIsApplicable({
      options
    }, dirname, context, configName) {
      return (options.test === void 0 || configFieldIsApplicable(context, options.test, dirname, configName)) && (options.include === void 0 || configFieldIsApplicable(context, options.include, dirname, configName)) && (options.exclude === void 0 || !configFieldIsApplicable(context, options.exclude, dirname, configName));
    }
    function configFieldIsApplicable(context, test, dirname, configName) {
      const patterns = Array.isArray(test) ? test : [test];
      return matchesPatterns(context, patterns, dirname, configName);
    }
    function ignoreListReplacer(_key, value2) {
      if (value2 instanceof RegExp) {
        return String(value2);
      }
      return value2;
    }
    function shouldIgnore(context, ignore, only, dirname) {
      if (ignore && matchesPatterns(context, ignore, dirname)) {
        var _context$filename;
        const message = `No config is applied to "${(_context$filename = context.filename) != null ? _context$filename : "(unknown)"}" because it matches one of \`ignore: ${JSON.stringify(ignore, ignoreListReplacer)}\` from "${dirname}"`;
        debug(message);
        if (context.showConfig) {
          console.log(message);
        }
        return true;
      }
      if (only && !matchesPatterns(context, only, dirname)) {
        var _context$filename2;
        const message = `No config is applied to "${(_context$filename2 = context.filename) != null ? _context$filename2 : "(unknown)"}" because it fails to match one of \`only: ${JSON.stringify(only, ignoreListReplacer)}\` from "${dirname}"`;
        debug(message);
        if (context.showConfig) {
          console.log(message);
        }
        return true;
      }
      return false;
    }
    function matchesPatterns(context, patterns, dirname, configName) {
      return patterns.some((pattern) => matchPattern(pattern, dirname, context.filename, context, configName));
    }
    function matchPattern(pattern, dirname, pathToTest, context, configName) {
      if (typeof pattern === "function") {
        return !!(0, _rewriteStackTrace.endHiddenCallStack)(pattern)(pathToTest, {
          dirname,
          envName: context.envName,
          caller: context.caller
        });
      }
      if (typeof pathToTest !== "string") {
        throw new _configError.default(`Configuration contains string/RegExp pattern, but no filename was passed to Babel`, configName);
      }
      if (typeof pattern === "string") {
        pattern = (0, _patternToRegex.default)(pattern, dirname);
      }
      return pattern.test(pathToTest);
    }
  }
});

// node_modules/@babel/core/lib/config/validation/plugins.js
var require_plugins4 = __commonJS({
  "node_modules/@babel/core/lib/config/validation/plugins.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.validatePluginObject = validatePluginObject;
    var _optionAssertions = require_option_assertions();
    var VALIDATORS = {
      name: _optionAssertions.assertString,
      manipulateOptions: _optionAssertions.assertFunction,
      pre: _optionAssertions.assertFunction,
      post: _optionAssertions.assertFunction,
      inherits: _optionAssertions.assertFunction,
      visitor: assertVisitorMap,
      parserOverride: _optionAssertions.assertFunction,
      generatorOverride: _optionAssertions.assertFunction
    };
    function assertVisitorMap(loc, value2) {
      const obj = (0, _optionAssertions.assertObject)(loc, value2);
      if (obj) {
        Object.keys(obj).forEach((prop) => assertVisitorHandler(prop, obj[prop]));
        if (obj.enter || obj.exit) {
          throw new Error(`${(0, _optionAssertions.msg)(loc)} cannot contain catch-all "enter" or "exit" handlers. Please target individual nodes.`);
        }
      }
      return obj;
    }
    function assertVisitorHandler(key, value2) {
      if (value2 && typeof value2 === "object") {
        Object.keys(value2).forEach((handler) => {
          if (handler !== "enter" && handler !== "exit") {
            throw new Error(`.visitor["${key}"] may only have .enter and/or .exit handlers.`);
          }
        });
      } else if (typeof value2 !== "function") {
        throw new Error(`.visitor["${key}"] must be a function`);
      }
      return value2;
    }
    function validatePluginObject(obj) {
      const rootPath = {
        type: "root",
        source: "plugin"
      };
      Object.keys(obj).forEach((key) => {
        const validator = VALIDATORS[key];
        if (validator) {
          const optLoc = {
            type: "option",
            name: key,
            parent: rootPath
          };
          validator(optLoc, obj[key]);
        } else {
          const invalidPluginPropertyError = new Error(`.${key} is not a valid Plugin property`);
          invalidPluginPropertyError.code = "BABEL_UNKNOWN_PLUGIN_PROPERTY";
          throw invalidPluginPropertyError;
        }
      });
      return obj;
    }
  }
});

// node_modules/@babel/core/lib/config/partial.js
var require_partial = __commonJS({
  "node_modules/@babel/core/lib/config/partial.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = loadPrivatePartialConfig;
    exports.loadPartialConfig = void 0;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _plugin = require_plugin();
    var _util = require_util4();
    var _item = require_item();
    var _configChain = require_config_chain();
    var _environment = require_environment();
    var _options = require_options3();
    var _files = require_files();
    var _resolveTargets = require_resolve_targets();
    var _excluded = ["showIgnoredFiles"];
    function _objectWithoutPropertiesLoose(source, excluded) {
      if (source == null)
        return {};
      var target = {};
      var sourceKeys = Object.keys(source);
      var key, i;
      for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0)
          continue;
        target[key] = source[key];
      }
      return target;
    }
    function resolveRootMode(rootDir, rootMode) {
      switch (rootMode) {
        case "root":
          return rootDir;
        case "upward-optional": {
          const upwardRootDir = (0, _files.findConfigUpwards)(rootDir);
          return upwardRootDir === null ? rootDir : upwardRootDir;
        }
        case "upward": {
          const upwardRootDir = (0, _files.findConfigUpwards)(rootDir);
          if (upwardRootDir !== null)
            return upwardRootDir;
          throw Object.assign(new Error(`Babel was run with rootMode:"upward" but a root could not be found when searching upward from "${rootDir}".
One of the following config files must be in the directory tree: "${_files.ROOT_CONFIG_FILENAMES.join(", ")}".`), {
            code: "BABEL_ROOT_NOT_FOUND",
            dirname: rootDir
          });
        }
        default:
          throw new Error(`Assertion failure - unknown rootMode value.`);
      }
    }
    function* loadPrivatePartialConfig(inputOpts) {
      if (inputOpts != null && (typeof inputOpts !== "object" || Array.isArray(inputOpts))) {
        throw new Error("Babel options must be an object, null, or undefined");
      }
      const args = inputOpts ? (0, _options.validate)("arguments", inputOpts) : {};
      const {
        envName = (0, _environment.getEnv)(),
        cwd = ".",
        root: rootDir = ".",
        rootMode = "root",
        caller,
        cloneInputAst = true
      } = args;
      const absoluteCwd = _path().resolve(cwd);
      const absoluteRootDir = resolveRootMode(_path().resolve(absoluteCwd, rootDir), rootMode);
      const filename = typeof args.filename === "string" ? _path().resolve(cwd, args.filename) : void 0;
      const showConfigPath = yield* (0, _files.resolveShowConfigPath)(absoluteCwd);
      const context = {
        filename,
        cwd: absoluteCwd,
        root: absoluteRootDir,
        envName,
        caller,
        showConfig: showConfigPath === filename
      };
      const configChain = yield* (0, _configChain.buildRootChain)(args, context);
      if (!configChain)
        return null;
      const merged = {
        assumptions: {}
      };
      configChain.options.forEach((opts) => {
        (0, _util.mergeOptions)(merged, opts);
      });
      const options = Object.assign({}, merged, {
        targets: (0, _resolveTargets.resolveTargets)(merged, absoluteRootDir),
        cloneInputAst,
        babelrc: false,
        configFile: false,
        browserslistConfigFile: false,
        passPerPreset: false,
        envName: context.envName,
        cwd: context.cwd,
        root: context.root,
        rootMode: "root",
        filename: typeof context.filename === "string" ? context.filename : void 0,
        plugins: configChain.plugins.map((descriptor) => (0, _item.createItemFromDescriptor)(descriptor)),
        presets: configChain.presets.map((descriptor) => (0, _item.createItemFromDescriptor)(descriptor))
      });
      return {
        options,
        context,
        fileHandling: configChain.fileHandling,
        ignore: configChain.ignore,
        babelrc: configChain.babelrc,
        config: configChain.config,
        files: configChain.files
      };
    }
    var loadPartialConfig = _gensync()(function* (opts) {
      let showIgnoredFiles = false;
      if (typeof opts === "object" && opts !== null && !Array.isArray(opts)) {
        var _opts = opts;
        ({
          showIgnoredFiles
        } = _opts);
        opts = _objectWithoutPropertiesLoose(_opts, _excluded);
        _opts;
      }
      const result = yield* loadPrivatePartialConfig(opts);
      if (!result)
        return null;
      const {
        options,
        babelrc,
        ignore,
        config,
        fileHandling,
        files
      } = result;
      if (fileHandling === "ignored" && !showIgnoredFiles) {
        return null;
      }
      (options.plugins || []).forEach((item) => {
        if (item.value instanceof _plugin.default) {
          throw new Error("Passing cached plugin instances is not supported in babel.loadPartialConfig()");
        }
      });
      return new PartialConfig(options, babelrc ? babelrc.filepath : void 0, ignore ? ignore.filepath : void 0, config ? config.filepath : void 0, fileHandling, files);
    });
    exports.loadPartialConfig = loadPartialConfig;
    var PartialConfig = class {
      constructor(options, babelrc, ignore, config, fileHandling, files) {
        this.options = void 0;
        this.babelrc = void 0;
        this.babelignore = void 0;
        this.config = void 0;
        this.fileHandling = void 0;
        this.files = void 0;
        this.options = options;
        this.babelignore = ignore;
        this.babelrc = babelrc;
        this.config = config;
        this.fileHandling = fileHandling;
        this.files = files;
        Object.freeze(this);
      }
      hasFilesystemConfig() {
        return this.babelrc !== void 0 || this.config !== void 0;
      }
    };
    Object.freeze(PartialConfig.prototype);
  }
});

// node_modules/@babel/core/lib/config/full.js
var require_full = __commonJS({
  "node_modules/@babel/core/lib/config/full.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _async = require_async7();
    var _util = require_util4();
    var context = require_lib28();
    var _plugin = require_plugin();
    var _item = require_item();
    var _configChain = require_config_chain();
    var _deepArray = require_deep_array();
    function _traverse() {
      const data = require_lib20();
      _traverse = function() {
        return data;
      };
      return data;
    }
    var _caching = require_caching();
    var _options = require_options3();
    var _plugins = require_plugins4();
    var _configApi = require_config_api();
    var _partial = require_partial();
    var _configError = require_config_error();
    var _default = _gensync()(function* loadFullConfig(inputOpts) {
      var _opts$assumptions;
      const result = yield* (0, _partial.default)(inputOpts);
      if (!result) {
        return null;
      }
      const {
        options,
        context: context2,
        fileHandling
      } = result;
      if (fileHandling === "ignored") {
        return null;
      }
      const optionDefaults = {};
      const {
        plugins,
        presets
      } = options;
      if (!plugins || !presets) {
        throw new Error("Assertion failure - plugins and presets exist");
      }
      const presetContext = Object.assign({}, context2, {
        targets: options.targets
      });
      const toDescriptor = (item) => {
        const desc = (0, _item.getItemDescriptor)(item);
        if (!desc) {
          throw new Error("Assertion failure - must be config item");
        }
        return desc;
      };
      const presetsDescriptors = presets.map(toDescriptor);
      const initialPluginsDescriptors = plugins.map(toDescriptor);
      const pluginDescriptorsByPass = [[]];
      const passes = [];
      const externalDependencies = [];
      const ignored = yield* enhanceError(context2, function* recursePresetDescriptors(rawPresets, pluginDescriptorsPass) {
        const presets2 = [];
        for (let i = 0; i < rawPresets.length; i++) {
          const descriptor = rawPresets[i];
          if (descriptor.options !== false) {
            try {
              var preset = yield* loadPresetDescriptor(descriptor, presetContext);
            } catch (e) {
              if (e.code === "BABEL_UNKNOWN_OPTION") {
                (0, _options.checkNoUnwrappedItemOptionPairs)(rawPresets, i, "preset", e);
              }
              throw e;
            }
            externalDependencies.push(preset.externalDependencies);
            if (descriptor.ownPass) {
              presets2.push({
                preset: preset.chain,
                pass: []
              });
            } else {
              presets2.unshift({
                preset: preset.chain,
                pass: pluginDescriptorsPass
              });
            }
          }
        }
        if (presets2.length > 0) {
          pluginDescriptorsByPass.splice(1, 0, ...presets2.map((o) => o.pass).filter((p) => p !== pluginDescriptorsPass));
          for (const {
            preset: preset2,
            pass
          } of presets2) {
            if (!preset2)
              return true;
            pass.push(...preset2.plugins);
            const ignored2 = yield* recursePresetDescriptors(preset2.presets, pass);
            if (ignored2)
              return true;
            preset2.options.forEach((opts2) => {
              (0, _util.mergeOptions)(optionDefaults, opts2);
            });
          }
        }
      })(presetsDescriptors, pluginDescriptorsByPass[0]);
      if (ignored)
        return null;
      const opts = optionDefaults;
      (0, _util.mergeOptions)(opts, options);
      const pluginContext = Object.assign({}, presetContext, {
        assumptions: (_opts$assumptions = opts.assumptions) != null ? _opts$assumptions : {}
      });
      yield* enhanceError(context2, function* loadPluginDescriptors() {
        pluginDescriptorsByPass[0].unshift(...initialPluginsDescriptors);
        for (const descs of pluginDescriptorsByPass) {
          const pass = [];
          passes.push(pass);
          for (let i = 0; i < descs.length; i++) {
            const descriptor = descs[i];
            if (descriptor.options !== false) {
              try {
                var plugin = yield* loadPluginDescriptor(descriptor, pluginContext);
              } catch (e) {
                if (e.code === "BABEL_UNKNOWN_PLUGIN_PROPERTY") {
                  (0, _options.checkNoUnwrappedItemOptionPairs)(descs, i, "plugin", e);
                }
                throw e;
              }
              pass.push(plugin);
              externalDependencies.push(plugin.externalDependencies);
            }
          }
        }
      })();
      opts.plugins = passes[0];
      opts.presets = passes.slice(1).filter((plugins2) => plugins2.length > 0).map((plugins2) => ({
        plugins: plugins2
      }));
      opts.passPerPreset = opts.presets.length > 0;
      return {
        options: opts,
        passes,
        externalDependencies: (0, _deepArray.finalize)(externalDependencies)
      };
    });
    exports.default = _default;
    function enhanceError(context2, fn) {
      return function* (arg1, arg2) {
        try {
          return yield* fn(arg1, arg2);
        } catch (e) {
          if (!/^\[BABEL\]/.test(e.message)) {
            var _context$filename;
            e.message = `[BABEL] ${(_context$filename = context2.filename) != null ? _context$filename : "unknown file"}: ${e.message}`;
          }
          throw e;
        }
      };
    }
    var makeDescriptorLoader = (apiFactory) => (0, _caching.makeWeakCache)(function* ({
      value: value2,
      options,
      dirname,
      alias
    }, cache) {
      if (options === false)
        throw new Error("Assertion failure");
      options = options || {};
      const externalDependencies = [];
      let item = value2;
      if (typeof value2 === "function") {
        const factory = (0, _async.maybeAsync)(value2, `You appear to be using an async plugin/preset, but Babel has been called synchronously`);
        const api = Object.assign({}, context, apiFactory(cache, externalDependencies));
        try {
          item = yield* factory(api, options, dirname);
        } catch (e) {
          if (alias) {
            e.message += ` (While processing: ${JSON.stringify(alias)})`;
          }
          throw e;
        }
      }
      if (!item || typeof item !== "object") {
        throw new Error("Plugin/Preset did not return an object.");
      }
      if ((0, _async.isThenable)(item)) {
        yield* [];
        throw new Error(`You appear to be using a promise as a plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version. As an alternative, you can prefix the promise with "await". (While processing: ${JSON.stringify(alias)})`);
      }
      if (externalDependencies.length > 0 && (!cache.configured() || cache.mode() === "forever")) {
        let error = `A plugin/preset has external untracked dependencies (${externalDependencies[0]}), but the cache `;
        if (!cache.configured()) {
          error += `has not been configured to be invalidated when the external dependencies change. `;
        } else {
          error += ` has been configured to never be invalidated. `;
        }
        error += `Plugins/presets should configure their cache to be invalidated when the external dependencies change, for example using \`api.cache.invalidate(() => statSync(filepath).mtimeMs)\` or \`api.cache.never()\`
(While processing: ${JSON.stringify(alias)})`;
        throw new Error(error);
      }
      return {
        value: item,
        options,
        dirname,
        alias,
        externalDependencies: (0, _deepArray.finalize)(externalDependencies)
      };
    });
    var pluginDescriptorLoader = makeDescriptorLoader(_configApi.makePluginAPI);
    var presetDescriptorLoader = makeDescriptorLoader(_configApi.makePresetAPI);
    var instantiatePlugin = (0, _caching.makeWeakCache)(function* ({
      value: value2,
      options,
      dirname,
      alias,
      externalDependencies
    }, cache) {
      const pluginObj = (0, _plugins.validatePluginObject)(value2);
      const plugin = Object.assign({}, pluginObj);
      if (plugin.visitor) {
        plugin.visitor = _traverse().default.explode(Object.assign({}, plugin.visitor));
      }
      if (plugin.inherits) {
        const inheritsDescriptor = {
          name: void 0,
          alias: `${alias}$inherits`,
          value: plugin.inherits,
          options,
          dirname
        };
        const inherits = yield* (0, _async.forwardAsync)(loadPluginDescriptor, (run) => {
          return cache.invalidate((data) => run(inheritsDescriptor, data));
        });
        plugin.pre = chain(inherits.pre, plugin.pre);
        plugin.post = chain(inherits.post, plugin.post);
        plugin.manipulateOptions = chain(inherits.manipulateOptions, plugin.manipulateOptions);
        plugin.visitor = _traverse().default.visitors.merge([inherits.visitor || {}, plugin.visitor || {}]);
        if (inherits.externalDependencies.length > 0) {
          if (externalDependencies.length === 0) {
            externalDependencies = inherits.externalDependencies;
          } else {
            externalDependencies = (0, _deepArray.finalize)([externalDependencies, inherits.externalDependencies]);
          }
        }
      }
      return new _plugin.default(plugin, options, alias, externalDependencies);
    });
    function* loadPluginDescriptor(descriptor, context2) {
      if (descriptor.value instanceof _plugin.default) {
        if (descriptor.options) {
          throw new Error("Passed options to an existing Plugin instance will not work.");
        }
        return descriptor.value;
      }
      return yield* instantiatePlugin(yield* pluginDescriptorLoader(descriptor, context2), context2);
    }
    var needsFilename = (val) => val && typeof val !== "function";
    var validateIfOptionNeedsFilename = (options, descriptor) => {
      if (needsFilename(options.test) || needsFilename(options.include) || needsFilename(options.exclude)) {
        const formattedPresetName = descriptor.name ? `"${descriptor.name}"` : "/* your preset */";
        throw new _configError.default([`Preset ${formattedPresetName} requires a filename to be set when babel is called directly,`, `\`\`\``, `babel.transformSync(code, { filename: 'file.ts', presets: [${formattedPresetName}] });`, `\`\`\``, `See https://babeljs.io/docs/en/options#filename for more information.`].join("\n"));
      }
    };
    var validatePreset = (preset, context2, descriptor) => {
      if (!context2.filename) {
        const {
          options
        } = preset;
        validateIfOptionNeedsFilename(options, descriptor);
        if (options.overrides) {
          options.overrides.forEach((overrideOptions) => validateIfOptionNeedsFilename(overrideOptions, descriptor));
        }
      }
    };
    var instantiatePreset = (0, _caching.makeWeakCacheSync)(({
      value: value2,
      dirname,
      alias,
      externalDependencies
    }) => {
      return {
        options: (0, _options.validate)("preset", value2),
        alias,
        dirname,
        externalDependencies
      };
    });
    function* loadPresetDescriptor(descriptor, context2) {
      const preset = instantiatePreset(yield* presetDescriptorLoader(descriptor, context2));
      validatePreset(preset, context2, descriptor);
      return {
        chain: yield* (0, _configChain.buildPresetChain)(preset, context2),
        externalDependencies: preset.externalDependencies
      };
    }
    function chain(a, b) {
      const fns = [a, b].filter(Boolean);
      if (fns.length <= 1)
        return fns[0];
      return function(...args) {
        for (const fn of fns) {
          fn.apply(this, args);
        }
      };
    }
  }
});

// node_modules/@babel/core/lib/config/index.js
var require_config2 = __commonJS({
  "node_modules/@babel/core/lib/config/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.createConfigItem = createConfigItem;
    exports.createConfigItemSync = exports.createConfigItemAsync = void 0;
    Object.defineProperty(exports, "default", {
      enumerable: true,
      get: function() {
        return _full.default;
      }
    });
    exports.loadPartialConfigSync = exports.loadPartialConfigAsync = exports.loadPartialConfig = exports.loadOptionsSync = exports.loadOptionsAsync = exports.loadOptions = void 0;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _full = require_full();
    var _partial = require_partial();
    var _item = require_item();
    var loadOptionsRunner = _gensync()(function* (opts) {
      var _config$options;
      const config = yield* (0, _full.default)(opts);
      return (_config$options = config == null ? void 0 : config.options) != null ? _config$options : null;
    });
    var createConfigItemRunner = _gensync()(_item.createConfigItem);
    var maybeErrback = (runner) => (argOrCallback, maybeCallback) => {
      let arg;
      let callback;
      if (maybeCallback === void 0 && typeof argOrCallback === "function") {
        callback = argOrCallback;
        arg = void 0;
      } else {
        callback = maybeCallback;
        arg = argOrCallback;
      }
      return callback ? runner.errback(arg, callback) : runner.sync(arg);
    };
    var loadPartialConfig = maybeErrback(_partial.loadPartialConfig);
    exports.loadPartialConfig = loadPartialConfig;
    var loadPartialConfigSync = _partial.loadPartialConfig.sync;
    exports.loadPartialConfigSync = loadPartialConfigSync;
    var loadPartialConfigAsync = _partial.loadPartialConfig.async;
    exports.loadPartialConfigAsync = loadPartialConfigAsync;
    var loadOptions = maybeErrback(loadOptionsRunner);
    exports.loadOptions = loadOptions;
    var loadOptionsSync = loadOptionsRunner.sync;
    exports.loadOptionsSync = loadOptionsSync;
    var loadOptionsAsync = loadOptionsRunner.async;
    exports.loadOptionsAsync = loadOptionsAsync;
    var createConfigItemSync = createConfigItemRunner.sync;
    exports.createConfigItemSync = createConfigItemSync;
    var createConfigItemAsync = createConfigItemRunner.async;
    exports.createConfigItemAsync = createConfigItemAsync;
    function createConfigItem(target, options, callback) {
      if (callback !== void 0) {
        return createConfigItemRunner.errback(target, options, callback);
      } else if (typeof options === "function") {
        return createConfigItemRunner.errback(target, void 0, callback);
      } else {
        return createConfigItemRunner.sync(target, options);
      }
    }
  }
});

// node_modules/@babel/core/lib/transformation/plugin-pass.js
var require_plugin_pass = __commonJS({
  "node_modules/@babel/core/lib/transformation/plugin-pass.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var PluginPass = class {
      constructor(file, key, options) {
        this._map = /* @__PURE__ */ new Map();
        this.key = void 0;
        this.file = void 0;
        this.opts = void 0;
        this.cwd = void 0;
        this.filename = void 0;
        this.key = key;
        this.file = file;
        this.opts = options || {};
        this.cwd = file.opts.cwd;
        this.filename = file.opts.filename;
      }
      set(key, val) {
        this._map.set(key, val);
      }
      get(key) {
        return this._map.get(key);
      }
      availableHelper(name, versionRange) {
        return this.file.availableHelper(name, versionRange);
      }
      addHelper(name) {
        return this.file.addHelper(name);
      }
      addImport() {
        return this.file.addImport();
      }
      buildCodeFrameError(node, msg, _Error) {
        return this.file.buildCodeFrameError(node, msg, _Error);
      }
    };
    exports.default = PluginPass;
    {
      PluginPass.prototype.getModuleName = function getModuleName() {
        return this.file.getModuleName();
      };
    }
  }
});

// node_modules/@babel/core/lib/transformation/block-hoist-plugin.js
var require_block_hoist_plugin = __commonJS({
  "node_modules/@babel/core/lib/transformation/block-hoist-plugin.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = loadBlockHoistPlugin;
    function _traverse() {
      const data = require_lib20();
      _traverse = function() {
        return data;
      };
      return data;
    }
    var _plugin = require_plugin();
    var LOADED_PLUGIN;
    var blockHoistPlugin = {
      name: "internal.blockHoist",
      visitor: {
        Block: {
          exit({
            node
          }) {
            const {
              body
            } = node;
            let max2 = Math.pow(2, 30) - 1;
            let hasChange = false;
            for (let i = 0; i < body.length; i++) {
              const n = body[i];
              const p = priority(n);
              if (p > max2) {
                hasChange = true;
                break;
              }
              max2 = p;
            }
            if (!hasChange)
              return;
            node.body = stableSort(body.slice());
          }
        }
      }
    };
    function loadBlockHoistPlugin() {
      if (!LOADED_PLUGIN) {
        LOADED_PLUGIN = new _plugin.default(Object.assign({}, blockHoistPlugin, {
          visitor: _traverse().default.explode(blockHoistPlugin.visitor)
        }), {});
      }
      return LOADED_PLUGIN;
    }
    function priority(bodyNode) {
      const priority2 = bodyNode == null ? void 0 : bodyNode._blockHoist;
      if (priority2 == null)
        return 1;
      if (priority2 === true)
        return 2;
      return priority2;
    }
    function stableSort(body) {
      const buckets = /* @__PURE__ */ Object.create(null);
      for (let i = 0; i < body.length; i++) {
        const n = body[i];
        const p = priority(n);
        const bucket = buckets[p] || (buckets[p] = []);
        bucket.push(n);
      }
      const keys3 = Object.keys(buckets).map((k) => +k).sort((a, b) => b - a);
      let index = 0;
      for (const key of keys3) {
        const bucket = buckets[key];
        for (const n of bucket) {
          body[index++] = n;
        }
      }
      return body;
    }
  }
});

// node_modules/@babel/core/lib/transformation/normalize-opts.js
var require_normalize_opts = __commonJS({
  "node_modules/@babel/core/lib/transformation/normalize-opts.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = normalizeOptions;
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function normalizeOptions(config) {
      const {
        filename,
        cwd,
        filenameRelative = typeof filename === "string" ? _path().relative(cwd, filename) : "unknown",
        sourceType = "module",
        inputSourceMap,
        sourceMaps = !!inputSourceMap,
        sourceRoot = config.options.moduleRoot,
        sourceFileName = _path().basename(filenameRelative),
        comments = true,
        compact = "auto"
      } = config.options;
      const opts = config.options;
      const options = Object.assign({}, opts, {
        parserOpts: Object.assign({
          sourceType: _path().extname(filenameRelative) === ".mjs" ? "module" : sourceType,
          sourceFileName: filename,
          plugins: []
        }, opts.parserOpts),
        generatorOpts: Object.assign({
          filename,
          auxiliaryCommentBefore: opts.auxiliaryCommentBefore,
          auxiliaryCommentAfter: opts.auxiliaryCommentAfter,
          retainLines: opts.retainLines,
          comments,
          shouldPrintComment: opts.shouldPrintComment,
          compact,
          minified: opts.minified,
          sourceMaps,
          sourceRoot,
          sourceFileName
        }, opts.generatorOpts)
      });
      for (const plugins of config.passes) {
        for (const plugin of plugins) {
          if (plugin.manipulateOptions) {
            plugin.manipulateOptions(options, options.parserOpts);
          }
        }
      }
      return options;
    }
  }
});

// node_modules/convert-source-map/index.js
var require_convert_source_map = __commonJS({
  "node_modules/convert-source-map/index.js"(exports) {
    "use strict";
    var fs2 = require("fs");
    var path2 = require("path");
    Object.defineProperty(exports, "commentRegex", {
      get: function getCommentRegex() {
        return /^\s*\/(?:\/|\*)[@#]\s+sourceMappingURL=data:(?:application|text)\/json;(?:charset[:=]\S+?;)?base64,(?:.*)$/mg;
      }
    });
    Object.defineProperty(exports, "mapFileCommentRegex", {
      get: function getMapFileCommentRegex() {
        return /(?:\/\/[@#][ \t]+sourceMappingURL=([^\s'"`]+?)[ \t]*$)|(?:\/\*[@#][ \t]+sourceMappingURL=([^\*]+?)[ \t]*(?:\*\/){1}[ \t]*$)/mg;
      }
    });
    var decodeBase64;
    if (typeof Buffer !== "undefined") {
      if (typeof Buffer.from === "function") {
        decodeBase64 = decodeBase64WithBufferFrom;
      } else {
        decodeBase64 = decodeBase64WithNewBuffer;
      }
    } else {
      decodeBase64 = decodeBase64WithAtob;
    }
    function decodeBase64WithBufferFrom(base64) {
      return Buffer.from(base64, "base64").toString();
    }
    function decodeBase64WithNewBuffer(base64) {
      if (typeof value === "number") {
        throw new TypeError("The value to decode must not be of type number.");
      }
      return new Buffer(base64, "base64").toString();
    }
    function decodeBase64WithAtob(base64) {
      return decodeURIComponent(escape(atob(base64)));
    }
    function stripComment(sm) {
      return sm.split(",").pop();
    }
    function readFromFileMap(sm, dir) {
      var r = exports.mapFileCommentRegex.exec(sm);
      var filename = r[1] || r[2];
      var filepath = path2.resolve(dir, filename);
      try {
        return fs2.readFileSync(filepath, "utf8");
      } catch (e) {
        throw new Error("An error occurred while trying to read the map file at " + filepath + "\n" + e);
      }
    }
    function Converter(sm, opts) {
      opts = opts || {};
      if (opts.isFileComment)
        sm = readFromFileMap(sm, opts.commentFileDir);
      if (opts.hasComment)
        sm = stripComment(sm);
      if (opts.isEncoded)
        sm = decodeBase64(sm);
      if (opts.isJSON || opts.isEncoded)
        sm = JSON.parse(sm);
      this.sourcemap = sm;
    }
    Converter.prototype.toJSON = function(space) {
      return JSON.stringify(this.sourcemap, null, space);
    };
    if (typeof Buffer !== "undefined") {
      if (typeof Buffer.from === "function") {
        Converter.prototype.toBase64 = encodeBase64WithBufferFrom;
      } else {
        Converter.prototype.toBase64 = encodeBase64WithNewBuffer;
      }
    } else {
      Converter.prototype.toBase64 = encodeBase64WithBtoa;
    }
    function encodeBase64WithBufferFrom() {
      var json = this.toJSON();
      return Buffer.from(json, "utf8").toString("base64");
    }
    function encodeBase64WithNewBuffer() {
      var json = this.toJSON();
      if (typeof json === "number") {
        throw new TypeError("The json to encode must not be of type number.");
      }
      return new Buffer(json, "utf8").toString("base64");
    }
    function encodeBase64WithBtoa() {
      var json = this.toJSON();
      return btoa(unescape(encodeURIComponent(json)));
    }
    Converter.prototype.toComment = function(options) {
      var base64 = this.toBase64();
      var data = "sourceMappingURL=data:application/json;charset=utf-8;base64," + base64;
      return options && options.multiline ? "/*# " + data + " */" : "//# " + data;
    };
    Converter.prototype.toObject = function() {
      return JSON.parse(this.toJSON());
    };
    Converter.prototype.addProperty = function(key, value2) {
      if (this.sourcemap.hasOwnProperty(key))
        throw new Error('property "' + key + '" already exists on the sourcemap, use set property instead');
      return this.setProperty(key, value2);
    };
    Converter.prototype.setProperty = function(key, value2) {
      this.sourcemap[key] = value2;
      return this;
    };
    Converter.prototype.getProperty = function(key) {
      return this.sourcemap[key];
    };
    exports.fromObject = function(obj) {
      return new Converter(obj);
    };
    exports.fromJSON = function(json) {
      return new Converter(json, { isJSON: true });
    };
    exports.fromBase64 = function(base64) {
      return new Converter(base64, { isEncoded: true });
    };
    exports.fromComment = function(comment) {
      comment = comment.replace(/^\/\*/g, "//").replace(/\*\/$/g, "");
      return new Converter(comment, { isEncoded: true, hasComment: true });
    };
    exports.fromMapFileComment = function(comment, dir) {
      return new Converter(comment, { commentFileDir: dir, isFileComment: true, isJSON: true });
    };
    exports.fromSource = function(content) {
      var m = content.match(exports.commentRegex);
      return m ? exports.fromComment(m.pop()) : null;
    };
    exports.fromMapFileSource = function(content, dir) {
      var m = content.match(exports.mapFileCommentRegex);
      return m ? exports.fromMapFileComment(m.pop(), dir) : null;
    };
    exports.removeComments = function(src) {
      return src.replace(exports.commentRegex, "");
    };
    exports.removeMapFileComments = function(src) {
      return src.replace(exports.mapFileCommentRegex, "");
    };
    exports.generateMapFileComment = function(file, options) {
      var data = "sourceMappingURL=" + file;
      return options && options.multiline ? "/*# " + data + " */" : "//# " + data;
    };
  }
});

// node_modules/@babel/core/lib/parser/util/missing-plugin-helper.js
var require_missing_plugin_helper = __commonJS({
  "node_modules/@babel/core/lib/parser/util/missing-plugin-helper.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = generateMissingPluginMessage;
    var pluginNameMap = {
      asyncDoExpressions: {
        syntax: {
          name: "@babel/plugin-syntax-async-do-expressions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-async-do-expressions"
        }
      },
      decimal: {
        syntax: {
          name: "@babel/plugin-syntax-decimal",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-decimal"
        }
      },
      decorators: {
        syntax: {
          name: "@babel/plugin-syntax-decorators",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-decorators"
        },
        transform: {
          name: "@babel/plugin-proposal-decorators",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-decorators"
        }
      },
      doExpressions: {
        syntax: {
          name: "@babel/plugin-syntax-do-expressions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-do-expressions"
        },
        transform: {
          name: "@babel/plugin-proposal-do-expressions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-do-expressions"
        }
      },
      exportDefaultFrom: {
        syntax: {
          name: "@babel/plugin-syntax-export-default-from",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-export-default-from"
        },
        transform: {
          name: "@babel/plugin-proposal-export-default-from",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-export-default-from"
        }
      },
      flow: {
        syntax: {
          name: "@babel/plugin-syntax-flow",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-flow"
        },
        transform: {
          name: "@babel/preset-flow",
          url: "https://github.com/babel/babel/tree/main/packages/babel-preset-flow"
        }
      },
      functionBind: {
        syntax: {
          name: "@babel/plugin-syntax-function-bind",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-function-bind"
        },
        transform: {
          name: "@babel/plugin-proposal-function-bind",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-function-bind"
        }
      },
      functionSent: {
        syntax: {
          name: "@babel/plugin-syntax-function-sent",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-function-sent"
        },
        transform: {
          name: "@babel/plugin-proposal-function-sent",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-function-sent"
        }
      },
      jsx: {
        syntax: {
          name: "@babel/plugin-syntax-jsx",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-jsx"
        },
        transform: {
          name: "@babel/preset-react",
          url: "https://github.com/babel/babel/tree/main/packages/babel-preset-react"
        }
      },
      importAssertions: {
        syntax: {
          name: "@babel/plugin-syntax-import-assertions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-import-assertions"
        }
      },
      pipelineOperator: {
        syntax: {
          name: "@babel/plugin-syntax-pipeline-operator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-pipeline-operator"
        },
        transform: {
          name: "@babel/plugin-proposal-pipeline-operator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-pipeline-operator"
        }
      },
      recordAndTuple: {
        syntax: {
          name: "@babel/plugin-syntax-record-and-tuple",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-record-and-tuple"
        }
      },
      regexpUnicodeSets: {
        syntax: {
          name: "@babel/plugin-syntax-unicode-sets-regex",
          url: "https://github.com/babel/babel/blob/main/packages/babel-plugin-syntax-unicode-sets-regex/README.md"
        },
        transform: {
          name: "@babel/plugin-proposal-unicode-sets-regex",
          url: "https://github.com/babel/babel/blob/main/packages/babel-plugin-proposalunicode-sets-regex/README.md"
        }
      },
      throwExpressions: {
        syntax: {
          name: "@babel/plugin-syntax-throw-expressions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-throw-expressions"
        },
        transform: {
          name: "@babel/plugin-proposal-throw-expressions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-throw-expressions"
        }
      },
      typescript: {
        syntax: {
          name: "@babel/plugin-syntax-typescript",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-typescript"
        },
        transform: {
          name: "@babel/preset-typescript",
          url: "https://github.com/babel/babel/tree/main/packages/babel-preset-typescript"
        }
      },
      asyncGenerators: {
        syntax: {
          name: "@babel/plugin-syntax-async-generators",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-async-generators"
        },
        transform: {
          name: "@babel/plugin-proposal-async-generator-functions",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-async-generator-functions"
        }
      },
      classProperties: {
        syntax: {
          name: "@babel/plugin-syntax-class-properties",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
        },
        transform: {
          name: "@babel/plugin-proposal-class-properties",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-class-properties"
        }
      },
      classPrivateProperties: {
        syntax: {
          name: "@babel/plugin-syntax-class-properties",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
        },
        transform: {
          name: "@babel/plugin-proposal-class-properties",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-class-properties"
        }
      },
      classPrivateMethods: {
        syntax: {
          name: "@babel/plugin-syntax-class-properties",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
        },
        transform: {
          name: "@babel/plugin-proposal-private-methods",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-private-methods"
        }
      },
      classStaticBlock: {
        syntax: {
          name: "@babel/plugin-syntax-class-static-block",
          url: "https://github.com/babel/babel/tree/HEAD/packages/babel-plugin-syntax-class-static-block"
        },
        transform: {
          name: "@babel/plugin-proposal-class-static-block",
          url: "https://github.com/babel/babel/tree/HEAD/packages/babel-plugin-proposal-class-static-block"
        }
      },
      dynamicImport: {
        syntax: {
          name: "@babel/plugin-syntax-dynamic-import",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-dynamic-import"
        }
      },
      exportNamespaceFrom: {
        syntax: {
          name: "@babel/plugin-syntax-export-namespace-from",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-export-namespace-from"
        },
        transform: {
          name: "@babel/plugin-proposal-export-namespace-from",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-export-namespace-from"
        }
      },
      importMeta: {
        syntax: {
          name: "@babel/plugin-syntax-import-meta",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-import-meta"
        }
      },
      logicalAssignment: {
        syntax: {
          name: "@babel/plugin-syntax-logical-assignment-operators",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-logical-assignment-operators"
        },
        transform: {
          name: "@babel/plugin-proposal-logical-assignment-operators",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-logical-assignment-operators"
        }
      },
      moduleStringNames: {
        syntax: {
          name: "@babel/plugin-syntax-module-string-names",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-module-string-names"
        }
      },
      numericSeparator: {
        syntax: {
          name: "@babel/plugin-syntax-numeric-separator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-numeric-separator"
        },
        transform: {
          name: "@babel/plugin-proposal-numeric-separator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-numeric-separator"
        }
      },
      nullishCoalescingOperator: {
        syntax: {
          name: "@babel/plugin-syntax-nullish-coalescing-operator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-nullish-coalescing-operator"
        },
        transform: {
          name: "@babel/plugin-proposal-nullish-coalescing-operator",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-nullish-coalescing-opearator"
        }
      },
      objectRestSpread: {
        syntax: {
          name: "@babel/plugin-syntax-object-rest-spread",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-object-rest-spread"
        },
        transform: {
          name: "@babel/plugin-proposal-object-rest-spread",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-object-rest-spread"
        }
      },
      optionalCatchBinding: {
        syntax: {
          name: "@babel/plugin-syntax-optional-catch-binding",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-optional-catch-binding"
        },
        transform: {
          name: "@babel/plugin-proposal-optional-catch-binding",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-optional-catch-binding"
        }
      },
      optionalChaining: {
        syntax: {
          name: "@babel/plugin-syntax-optional-chaining",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-optional-chaining"
        },
        transform: {
          name: "@babel/plugin-proposal-optional-chaining",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-optional-chaining"
        }
      },
      privateIn: {
        syntax: {
          name: "@babel/plugin-syntax-private-property-in-object",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-private-property-in-object"
        },
        transform: {
          name: "@babel/plugin-proposal-private-property-in-object",
          url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-private-property-in-object"
        }
      }
    };
    pluginNameMap.privateIn.syntax = pluginNameMap.privateIn.transform;
    var getNameURLCombination = ({
      name,
      url
    }) => `${name} (${url})`;
    function generateMissingPluginMessage(missingPluginName, loc, codeFrame) {
      let helpMessage = `Support for the experimental syntax '${missingPluginName}' isn't currently enabled (${loc.line}:${loc.column + 1}):

` + codeFrame;
      const pluginInfo = pluginNameMap[missingPluginName];
      if (pluginInfo) {
        const {
          syntax: syntaxPlugin,
          transform: transformPlugin
        } = pluginInfo;
        if (syntaxPlugin) {
          const syntaxPluginInfo = getNameURLCombination(syntaxPlugin);
          if (transformPlugin) {
            const transformPluginInfo = getNameURLCombination(transformPlugin);
            const sectionType = transformPlugin.name.startsWith("@babel/plugin") ? "plugins" : "presets";
            helpMessage += `

Add ${transformPluginInfo} to the '${sectionType}' section of your Babel config to enable transformation.
If you want to leave it as-is, add ${syntaxPluginInfo} to the 'plugins' section to enable parsing.`;
          } else {
            helpMessage += `

Add ${syntaxPluginInfo} to the 'plugins' section of your Babel config to enable parsing.`;
          }
        }
      }
      return helpMessage;
    }
  }
});

// node_modules/@babel/core/lib/parser/index.js
var require_parser = __commonJS({
  "node_modules/@babel/core/lib/parser/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = parser;
    function _parser() {
      const data = require_lib2();
      _parser = function() {
        return data;
      };
      return data;
    }
    function _codeFrame() {
      const data = require_lib16();
      _codeFrame = function() {
        return data;
      };
      return data;
    }
    var _missingPluginHelper = require_missing_plugin_helper();
    function* parser(pluginPasses, {
      parserOpts,
      highlightCode = true,
      filename = "unknown"
    }, code) {
      try {
        const results = [];
        for (const plugins of pluginPasses) {
          for (const plugin of plugins) {
            const {
              parserOverride
            } = plugin;
            if (parserOverride) {
              const ast = parserOverride(code, parserOpts, _parser().parse);
              if (ast !== void 0)
                results.push(ast);
            }
          }
        }
        if (results.length === 0) {
          return (0, _parser().parse)(code, parserOpts);
        } else if (results.length === 1) {
          yield* [];
          if (typeof results[0].then === "function") {
            throw new Error(`You appear to be using an async parser plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.`);
          }
          return results[0];
        }
        throw new Error("More than one plugin attempted to override parsing.");
      } catch (err) {
        if (err.code === "BABEL_PARSER_SOURCETYPE_MODULE_REQUIRED") {
          err.message += "\nConsider renaming the file to '.mjs', or setting sourceType:module or sourceType:unambiguous in your Babel config for this file.";
        }
        const {
          loc,
          missingPlugin
        } = err;
        if (loc) {
          const codeFrame = (0, _codeFrame().codeFrameColumns)(code, {
            start: {
              line: loc.line,
              column: loc.column + 1
            }
          }, {
            highlightCode
          });
          if (missingPlugin) {
            err.message = `${filename}: ` + (0, _missingPluginHelper.default)(missingPlugin[0], loc, codeFrame);
          } else {
            err.message = `${filename}: ${err.message}

` + codeFrame;
          }
          err.code = "BABEL_PARSE_ERROR";
        }
        throw err;
      }
    }
  }
});

// node_modules/@babel/core/lib/transformation/util/clone-deep.js
var require_clone_deep = __commonJS({
  "node_modules/@babel/core/lib/transformation/util/clone-deep.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;
    function deepClone(value2, cache) {
      if (value2 !== null) {
        if (cache.has(value2))
          return cache.get(value2);
        let cloned;
        if (Array.isArray(value2)) {
          cloned = new Array(value2.length);
          for (let i = 0; i < value2.length; i++) {
            cloned[i] = typeof value2[i] !== "object" ? value2[i] : deepClone(value2[i], cache);
          }
        } else {
          cloned = {};
          const keys3 = Object.keys(value2);
          for (let i = 0; i < keys3.length; i++) {
            const key = keys3[i];
            cloned[key] = typeof value2[key] !== "object" ? value2[key] : deepClone(value2[key], cache);
          }
        }
        cache.set(value2, cloned);
        return cloned;
      }
      return value2;
    }
    function _default(value2) {
      if (typeof value2 !== "object")
        return value2;
      return deepClone(value2, /* @__PURE__ */ new Map());
    }
  }
});

// node_modules/@babel/core/lib/transformation/normalize-file.js
var require_normalize_file = __commonJS({
  "node_modules/@babel/core/lib/transformation/normalize-file.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = normalizeFile;
    function _fs() {
      const data = require("fs");
      _fs = function() {
        return data;
      };
      return data;
    }
    function _path() {
      const data = require("path");
      _path = function() {
        return data;
      };
      return data;
    }
    function _debug() {
      const data = require_src();
      _debug = function() {
        return data;
      };
      return data;
    }
    function _t() {
      const data = require_lib11();
      _t = function() {
        return data;
      };
      return data;
    }
    function _convertSourceMap() {
      const data = require_convert_source_map();
      _convertSourceMap = function() {
        return data;
      };
      return data;
    }
    var _file = require_file();
    var _parser = require_parser();
    var _cloneDeep = require_clone_deep();
    var {
      file,
      traverseFast
    } = _t();
    var debug = _debug()("babel:transform:file");
    var LARGE_INPUT_SOURCEMAP_THRESHOLD = 3e6;
    var INLINE_SOURCEMAP_REGEX = /^[@#]\s+sourceMappingURL=data:(?:application|text)\/json;(?:charset[:=]\S+?;)?base64,(?:.*)$/;
    var EXTERNAL_SOURCEMAP_REGEX = /^[@#][ \t]+sourceMappingURL=([^\s'"`]+)[ \t]*$/;
    function* normalizeFile(pluginPasses, options, code, ast) {
      code = `${code || ""}`;
      if (ast) {
        if (ast.type === "Program") {
          ast = file(ast, [], []);
        } else if (ast.type !== "File") {
          throw new Error("AST root must be a Program or File node");
        }
        if (options.cloneInputAst) {
          ast = (0, _cloneDeep.default)(ast);
        }
      } else {
        ast = yield* (0, _parser.default)(pluginPasses, options, code);
      }
      let inputMap = null;
      if (options.inputSourceMap !== false) {
        if (typeof options.inputSourceMap === "object") {
          inputMap = _convertSourceMap().fromObject(options.inputSourceMap);
        }
        if (!inputMap) {
          const lastComment = extractComments(INLINE_SOURCEMAP_REGEX, ast);
          if (lastComment) {
            try {
              inputMap = _convertSourceMap().fromComment(lastComment);
            } catch (err) {
              debug("discarding unknown inline input sourcemap", err);
            }
          }
        }
        if (!inputMap) {
          const lastComment = extractComments(EXTERNAL_SOURCEMAP_REGEX, ast);
          if (typeof options.filename === "string" && lastComment) {
            try {
              const match = EXTERNAL_SOURCEMAP_REGEX.exec(lastComment);
              const inputMapContent = _fs().readFileSync(_path().resolve(_path().dirname(options.filename), match[1]));
              if (inputMapContent.length > LARGE_INPUT_SOURCEMAP_THRESHOLD) {
                debug("skip merging input map > 1 MB");
              } else {
                inputMap = _convertSourceMap().fromJSON(inputMapContent);
              }
            } catch (err) {
              debug("discarding unknown file input sourcemap", err);
            }
          } else if (lastComment) {
            debug("discarding un-loadable file input sourcemap");
          }
        }
      }
      return new _file.default(options, {
        code,
        ast,
        inputMap
      });
    }
    function extractCommentsFromList(regex, comments, lastComment) {
      if (comments) {
        comments = comments.filter(({
          value: value2
        }) => {
          if (regex.test(value2)) {
            lastComment = value2;
            return false;
          }
          return true;
        });
      }
      return [comments, lastComment];
    }
    function extractComments(regex, ast) {
      let lastComment = null;
      traverseFast(ast, (node) => {
        [node.leadingComments, lastComment] = extractCommentsFromList(regex, node.leadingComments, lastComment);
        [node.innerComments, lastComment] = extractCommentsFromList(regex, node.innerComments, lastComment);
        [node.trailingComments, lastComment] = extractCommentsFromList(regex, node.trailingComments, lastComment);
      });
      return lastComment;
    }
  }
});

// node_modules/@ampproject/remapping/node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js
var require_gen_mapping_umd2 = __commonJS({
  "node_modules/@ampproject/remapping/node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? factory(exports, require_set_array_umd(), require_sourcemap_codec_umd()) : typeof define === "function" && define.amd ? define(["exports", "@jridgewell/set-array", "@jridgewell/sourcemap-codec"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, factory(global2.genMapping = {}, global2.setArray, global2.sourcemapCodec));
    })(exports, function(exports2, setArray, sourcemapCodec) {
      "use strict";
      exports2.addSegment = void 0;
      exports2.addMapping = void 0;
      exports2.setSourceContent = void 0;
      exports2.decodedMap = void 0;
      exports2.encodedMap = void 0;
      exports2.allMappings = void 0;
      class GenMapping {
        constructor({ file, sourceRoot } = {}) {
          this._names = new setArray.SetArray();
          this._sources = new setArray.SetArray();
          this._sourcesContent = [];
          this._mappings = [];
          this.file = file;
          this.sourceRoot = sourceRoot;
        }
      }
      (() => {
        exports2.addSegment = (map, genLine, genColumn, source, sourceLine, sourceColumn, name) => {
          const { _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names } = map;
          const line = getLine(mappings, genLine);
          if (source == null) {
            const seg2 = [genColumn];
            const index2 = getColumnIndex(line, genColumn, seg2);
            return insert(line, index2, seg2);
          }
          const sourcesIndex = setArray.put(sources, source);
          const seg = name ? [genColumn, sourcesIndex, sourceLine, sourceColumn, setArray.put(names, name)] : [genColumn, sourcesIndex, sourceLine, sourceColumn];
          const index = getColumnIndex(line, genColumn, seg);
          if (sourcesIndex === sourcesContent.length)
            sourcesContent[sourcesIndex] = null;
          insert(line, index, seg);
        };
        exports2.addMapping = (map, mapping) => {
          const { generated, source, original, name } = mapping;
          return exports2.addSegment(map, generated.line - 1, generated.column, source, original == null ? void 0 : original.line - 1, original === null || original === void 0 ? void 0 : original.column, name);
        };
        exports2.setSourceContent = (map, source, content) => {
          const { _sources: sources, _sourcesContent: sourcesContent } = map;
          sourcesContent[setArray.put(sources, source)] = content;
        };
        exports2.decodedMap = (map) => {
          const { file, sourceRoot, _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names } = map;
          return {
            version: 3,
            file,
            names: names.array,
            sourceRoot: sourceRoot || void 0,
            sources: sources.array,
            sourcesContent,
            mappings
          };
        };
        exports2.encodedMap = (map) => {
          const decoded = exports2.decodedMap(map);
          return Object.assign(Object.assign({}, decoded), { mappings: sourcemapCodec.encode(decoded.mappings) });
        };
        exports2.allMappings = (map) => {
          const out = [];
          const { _mappings: mappings, _sources: sources, _names: names } = map;
          for (let i = 0; i < mappings.length; i++) {
            const line = mappings[i];
            for (let j = 0; j < line.length; j++) {
              const seg = line[j];
              const generated = { line: i + 1, column: seg[0] };
              let source = void 0;
              let original = void 0;
              let name = void 0;
              if (seg.length !== 1) {
                source = sources.array[seg[1]];
                original = { line: seg[2] + 1, column: seg[3] };
                if (seg.length === 5)
                  name = names.array[seg[4]];
              }
              out.push({ generated, source, original, name });
            }
          }
          return out;
        };
      })();
      function getLine(mappings, index) {
        for (let i = mappings.length; i <= index; i++) {
          mappings[i] = [];
        }
        return mappings[index];
      }
      function getColumnIndex(line, column, seg) {
        let index = line.length;
        for (let i = index - 1; i >= 0; i--, index--) {
          const current = line[i];
          const col = current[0];
          if (col > column)
            continue;
          if (col < column)
            break;
          const cmp = compare(current, seg);
          if (cmp === 0)
            return index;
          if (cmp < 0)
            break;
        }
        return index;
      }
      function compare(a, b) {
        let cmp = compareNum(a.length, b.length);
        if (cmp !== 0)
          return cmp;
        if (a.length === 1)
          return 0;
        cmp = compareNum(a[1], b[1]);
        if (cmp !== 0)
          return cmp;
        cmp = compareNum(a[2], b[2]);
        if (cmp !== 0)
          return cmp;
        cmp = compareNum(a[3], b[3]);
        if (cmp !== 0)
          return cmp;
        if (a.length === 4)
          return 0;
        return compareNum(a[4], b[4]);
      }
      function compareNum(a, b) {
        return a - b;
      }
      function insert(array, index, value2) {
        if (index === -1)
          return;
        for (let i = array.length; i > index; i--) {
          array[i] = array[i - 1];
        }
        array[index] = value2;
      }
      exports2.GenMapping = GenMapping;
      Object.defineProperty(exports2, "__esModule", { value: true });
    });
  }
});

// node_modules/@ampproject/remapping/dist/remapping.umd.js
var require_remapping_umd = __commonJS({
  "node_modules/@ampproject/remapping/dist/remapping.umd.js"(exports, module2) {
    (function(global2, factory) {
      typeof exports === "object" && typeof module2 !== "undefined" ? module2.exports = factory(require_trace_mapping_umd(), require_gen_mapping_umd2()) : typeof define === "function" && define.amd ? define(["@jridgewell/trace-mapping", "@jridgewell/gen-mapping"], factory) : (global2 = typeof globalThis !== "undefined" ? globalThis : global2 || self, global2.remapping = factory(global2.traceMapping, global2.genMapping));
    })(exports, function(traceMapping, genMapping) {
      "use strict";
      const SOURCELESS_MAPPING = {
        source: null,
        column: null,
        line: null,
        name: null,
        content: null
      };
      const EMPTY_SOURCES = [];
      function Source(map, sources, source, content) {
        return {
          map,
          sources,
          source,
          content
        };
      }
      function MapSource(map, sources) {
        return Source(map, sources, "", null);
      }
      function OriginalSource(source, content) {
        return Source(null, EMPTY_SOURCES, source, content);
      }
      function traceMappings(tree) {
        const gen = new genMapping.GenMapping({ file: tree.map.file });
        const { sources: rootSources, map } = tree;
        const rootNames = map.names;
        const rootMappings = traceMapping.decodedMappings(map);
        for (let i = 0; i < rootMappings.length; i++) {
          const segments = rootMappings[i];
          let lastSource = null;
          let lastSourceLine = null;
          let lastSourceColumn = null;
          for (let j = 0; j < segments.length; j++) {
            const segment = segments[j];
            const genCol = segment[0];
            let traced = SOURCELESS_MAPPING;
            if (segment.length !== 1) {
              const source2 = rootSources[segment[1]];
              traced = originalPositionFor(source2, segment[2], segment[3], segment.length === 5 ? rootNames[segment[4]] : "");
              if (traced == null)
                continue;
            }
            const { column, line, name, content, source } = traced;
            if (line === lastSourceLine && column === lastSourceColumn && source === lastSource) {
              continue;
            }
            lastSourceLine = line;
            lastSourceColumn = column;
            lastSource = source;
            genMapping.addSegment(gen, i, genCol, source, line, column, name);
            if (content != null)
              genMapping.setSourceContent(gen, source, content);
          }
        }
        return gen;
      }
      function originalPositionFor(source, line, column, name) {
        if (!source.map) {
          return { column, line, name, source: source.source, content: source.content };
        }
        const segment = traceMapping.traceSegment(source.map, line, column);
        if (segment == null)
          return null;
        if (segment.length === 1)
          return SOURCELESS_MAPPING;
        return originalPositionFor(source.sources[segment[1]], segment[2], segment[3], segment.length === 5 ? source.map.names[segment[4]] : name);
      }
      function asArray(value2) {
        if (Array.isArray(value2))
          return value2;
        return [value2];
      }
      function buildSourceMapTree(input, loader) {
        const maps = asArray(input).map((m) => new traceMapping.TraceMap(m, ""));
        const map = maps.pop();
        for (let i = 0; i < maps.length; i++) {
          if (maps[i].sources.length > 1) {
            throw new Error(`Transformation map ${i} must have exactly one source file.
Did you specify these with the most recent transformation maps first?`);
          }
        }
        let tree = build(map, loader, "", 0);
        for (let i = maps.length - 1; i >= 0; i--) {
          tree = MapSource(maps[i], [tree]);
        }
        return tree;
      }
      function build(map, loader, importer, importerDepth) {
        const { resolvedSources, sourcesContent } = map;
        const depth = importerDepth + 1;
        const children = resolvedSources.map((sourceFile, i) => {
          const ctx = {
            importer,
            depth,
            source: sourceFile || "",
            content: void 0
          };
          const sourceMap = loader(ctx.source, ctx);
          const { source, content } = ctx;
          if (sourceMap)
            return build(new traceMapping.TraceMap(sourceMap, source), loader, source, depth);
          const sourceContent = content !== void 0 ? content : sourcesContent ? sourcesContent[i] : null;
          return OriginalSource(source, sourceContent);
        });
        return MapSource(map, children);
      }
      class SourceMap {
        constructor(map, options) {
          const out = options.decodedMappings ? genMapping.decodedMap(map) : genMapping.encodedMap(map);
          this.version = out.version;
          this.file = out.file;
          this.mappings = out.mappings;
          this.names = out.names;
          this.sourceRoot = out.sourceRoot;
          this.sources = out.sources;
          if (!options.excludeContent) {
            this.sourcesContent = out.sourcesContent;
          }
        }
        toString() {
          return JSON.stringify(this);
        }
      }
      function remapping(input, loader, options) {
        const opts = typeof options === "object" ? options : { excludeContent: !!options, decodedMappings: false };
        const tree = buildSourceMapTree(input, loader);
        return new SourceMap(traceMappings(tree), opts);
      }
      return remapping;
    });
  }
});

// node_modules/@babel/core/lib/transformation/file/merge-map.js
var require_merge_map = __commonJS({
  "node_modules/@babel/core/lib/transformation/file/merge-map.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = mergeSourceMap;
    function _remapping() {
      const data = require_remapping_umd();
      _remapping = function() {
        return data;
      };
      return data;
    }
    function mergeSourceMap(inputMap, map, sourceFileName) {
      const source = sourceFileName.replace(/\\/g, "/");
      let found = false;
      const result = _remapping()(rootless(map), (s, ctx) => {
        if (s === source && !found) {
          found = true;
          ctx.source = "";
          return rootless(inputMap);
        }
        return null;
      });
      if (typeof inputMap.sourceRoot === "string") {
        result.sourceRoot = inputMap.sourceRoot;
      }
      return Object.assign({}, result);
    }
    function rootless(map) {
      return Object.assign({}, map, {
        sourceRoot: null
      });
    }
  }
});

// node_modules/@babel/core/lib/transformation/file/generate.js
var require_generate2 = __commonJS({
  "node_modules/@babel/core/lib/transformation/file/generate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = generateCode;
    function _convertSourceMap() {
      const data = require_convert_source_map();
      _convertSourceMap = function() {
        return data;
      };
      return data;
    }
    function _generator() {
      const data = require_lib14();
      _generator = function() {
        return data;
      };
      return data;
    }
    var _mergeMap = require_merge_map();
    function generateCode(pluginPasses, file) {
      const {
        opts,
        ast,
        code,
        inputMap
      } = file;
      const {
        generatorOpts
      } = opts;
      const results = [];
      for (const plugins of pluginPasses) {
        for (const plugin of plugins) {
          const {
            generatorOverride
          } = plugin;
          if (generatorOverride) {
            const result2 = generatorOverride(ast, generatorOpts, code, _generator().default);
            if (result2 !== void 0)
              results.push(result2);
          }
        }
      }
      let result;
      if (results.length === 0) {
        result = (0, _generator().default)(ast, generatorOpts, code);
      } else if (results.length === 1) {
        result = results[0];
        if (typeof result.then === "function") {
          throw new Error(`You appear to be using an async codegen plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.`);
        }
      } else {
        throw new Error("More than one plugin attempted to override codegen.");
      }
      let {
        code: outputCode,
        decodedMap: outputMap = result.map
      } = result;
      if (outputMap) {
        if (inputMap) {
          outputMap = (0, _mergeMap.default)(inputMap.toObject(), outputMap, generatorOpts.sourceFileName);
        } else {
          outputMap = result.map;
        }
      }
      if (opts.sourceMaps === "inline" || opts.sourceMaps === "both") {
        outputCode += "\n" + _convertSourceMap().fromObject(outputMap).toComment();
      }
      if (opts.sourceMaps === "inline") {
        outputMap = null;
      }
      return {
        outputCode,
        outputMap
      };
    }
  }
});

// node_modules/@babel/core/lib/transformation/index.js
var require_transformation = __commonJS({
  "node_modules/@babel/core/lib/transformation/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.run = run;
    function _traverse() {
      const data = require_lib20();
      _traverse = function() {
        return data;
      };
      return data;
    }
    var _pluginPass = require_plugin_pass();
    var _blockHoistPlugin = require_block_hoist_plugin();
    var _normalizeOpts = require_normalize_opts();
    var _normalizeFile = require_normalize_file();
    var _generate = require_generate2();
    var _deepArray = require_deep_array();
    function* run(config, code, ast) {
      const file = yield* (0, _normalizeFile.default)(config.passes, (0, _normalizeOpts.default)(config), code, ast);
      const opts = file.opts;
      try {
        yield* transformFile2(file, config.passes);
      } catch (e) {
        var _opts$filename;
        e.message = `${(_opts$filename = opts.filename) != null ? _opts$filename : "unknown file"}: ${e.message}`;
        if (!e.code) {
          e.code = "BABEL_TRANSFORM_ERROR";
        }
        throw e;
      }
      let outputCode, outputMap;
      try {
        if (opts.code !== false) {
          ({
            outputCode,
            outputMap
          } = (0, _generate.default)(config.passes, file));
        }
      } catch (e) {
        var _opts$filename2;
        e.message = `${(_opts$filename2 = opts.filename) != null ? _opts$filename2 : "unknown file"}: ${e.message}`;
        if (!e.code) {
          e.code = "BABEL_GENERATE_ERROR";
        }
        throw e;
      }
      return {
        metadata: file.metadata,
        options: opts,
        ast: opts.ast === true ? file.ast : null,
        code: outputCode === void 0 ? null : outputCode,
        map: outputMap === void 0 ? null : outputMap,
        sourceType: file.ast.program.sourceType,
        externalDependencies: (0, _deepArray.flattenToSet)(config.externalDependencies)
      };
    }
    function* transformFile2(file, pluginPasses) {
      for (const pluginPairs of pluginPasses) {
        const passPairs = [];
        const passes = [];
        const visitors = [];
        for (const plugin of pluginPairs.concat([(0, _blockHoistPlugin.default)()])) {
          const pass = new _pluginPass.default(file, plugin.key, plugin.options);
          passPairs.push([plugin, pass]);
          passes.push(pass);
          visitors.push(plugin.visitor);
        }
        for (const [plugin, pass] of passPairs) {
          const fn = plugin.pre;
          if (fn) {
            const result = fn.call(pass, file);
            yield* [];
            if (isThenable(result)) {
              throw new Error(`You appear to be using an plugin with an async .pre, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.`);
            }
          }
        }
        const visitor = _traverse().default.visitors.merge(visitors, passes, file.opts.wrapPluginVisitorMethod);
        (0, _traverse().default)(file.ast, visitor, file.scope);
        for (const [plugin, pass] of passPairs) {
          const fn = plugin.post;
          if (fn) {
            const result = fn.call(pass, file);
            yield* [];
            if (isThenable(result)) {
              throw new Error(`You appear to be using an plugin with an async .post, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.`);
            }
          }
        }
      }
    }
    function isThenable(val) {
      return !!val && (typeof val === "object" || typeof val === "function") && !!val.then && typeof val.then === "function";
    }
  }
});

// node_modules/@babel/core/lib/transform.js
var require_transform = __commonJS({
  "node_modules/@babel/core/lib/transform.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.transform = void 0;
    exports.transformAsync = transformAsync;
    exports.transformSync = transformSync;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _config = require_config2();
    var _transformation = require_transformation();
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var transformRunner = _gensync()(function* transform2(code, opts) {
      const config = yield* (0, _config.default)(opts);
      if (config === null)
        return null;
      return yield* (0, _transformation.run)(config, code);
    });
    var transform = function transform2(code, optsOrCallback, maybeCallback) {
      let opts;
      let callback;
      if (typeof optsOrCallback === "function") {
        callback = optsOrCallback;
        opts = void 0;
      } else {
        opts = optsOrCallback;
        callback = maybeCallback;
      }
      if (callback === void 0) {
        {
          return (0, _rewriteStackTrace.beginHiddenCallStack)(transformRunner.sync)(code, opts);
        }
      }
      (0, _rewriteStackTrace.beginHiddenCallStack)(transformRunner.errback)(code, opts, callback);
    };
    exports.transform = transform;
    function transformSync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(transformRunner.sync)(...args);
    }
    function transformAsync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(transformRunner.async)(...args);
    }
  }
});

// node_modules/@babel/core/lib/transform-file.js
var require_transform_file = __commonJS({
  "node_modules/@babel/core/lib/transform-file.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.transformFile = transformFile2;
    exports.transformFileAsync = transformFileAsync;
    exports.transformFileSync = transformFileSync;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _config = require_config2();
    var _transformation = require_transformation();
    var fs2 = require_fs5();
    var transformFileRunner = _gensync()(function* (filename, opts) {
      const options = Object.assign({}, opts, {
        filename
      });
      const config = yield* (0, _config.default)(options);
      if (config === null)
        return null;
      const code = yield* fs2.readFile(filename, "utf8");
      return yield* (0, _transformation.run)(config, code);
    });
    function transformFile2(...args) {
      return transformFileRunner.errback(...args);
    }
    function transformFileSync(...args) {
      return transformFileRunner.sync(...args);
    }
    function transformFileAsync(...args) {
      return transformFileRunner.async(...args);
    }
  }
});

// node_modules/@babel/core/lib/transform-ast.js
var require_transform_ast = __commonJS({
  "node_modules/@babel/core/lib/transform-ast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.transformFromAst = void 0;
    exports.transformFromAstAsync = transformFromAstAsync;
    exports.transformFromAstSync = transformFromAstSync;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _config = require_config2();
    var _transformation = require_transformation();
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var transformFromAstRunner = _gensync()(function* (ast, code, opts) {
      const config = yield* (0, _config.default)(opts);
      if (config === null)
        return null;
      if (!ast)
        throw new Error("No AST given");
      return yield* (0, _transformation.run)(config, code, ast);
    });
    var transformFromAst = function transformFromAst2(ast, code, optsOrCallback, maybeCallback) {
      let opts;
      let callback;
      if (typeof optsOrCallback === "function") {
        callback = optsOrCallback;
        opts = void 0;
      } else {
        opts = optsOrCallback;
        callback = maybeCallback;
      }
      if (callback === void 0) {
        {
          return (0, _rewriteStackTrace.beginHiddenCallStack)(transformFromAstRunner.sync)(ast, code, opts);
        }
      }
      (0, _rewriteStackTrace.beginHiddenCallStack)(transformFromAstRunner.errback)(ast, code, opts, callback);
    };
    exports.transformFromAst = transformFromAst;
    function transformFromAstSync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(transformFromAstRunner.sync)(...args);
    }
    function transformFromAstAsync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(transformFromAstRunner.async)(...args);
    }
  }
});

// node_modules/@babel/core/lib/parse.js
var require_parse4 = __commonJS({
  "node_modules/@babel/core/lib/parse.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.parse = void 0;
    exports.parseAsync = parseAsync;
    exports.parseSync = parseSync;
    function _gensync() {
      const data = require_gensync();
      _gensync = function() {
        return data;
      };
      return data;
    }
    var _config = require_config2();
    var _parser = require_parser();
    var _normalizeOpts = require_normalize_opts();
    var _rewriteStackTrace = require_rewrite_stack_trace();
    var parseRunner = _gensync()(function* parse4(code, opts) {
      const config = yield* (0, _config.default)(opts);
      if (config === null) {
        return null;
      }
      return yield* (0, _parser.default)(config.passes, (0, _normalizeOpts.default)(config), code);
    });
    var parse3 = function parse4(code, opts, callback) {
      if (typeof opts === "function") {
        callback = opts;
        opts = void 0;
      }
      if (callback === void 0) {
        {
          return (0, _rewriteStackTrace.beginHiddenCallStack)(parseRunner.sync)(code, opts);
        }
      }
      (0, _rewriteStackTrace.beginHiddenCallStack)(parseRunner.errback)(code, opts, callback);
    };
    exports.parse = parse3;
    function parseSync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(parseRunner.sync)(...args);
    }
    function parseAsync(...args) {
      return (0, _rewriteStackTrace.beginHiddenCallStack)(parseRunner.async)(...args);
    }
  }
});

// node_modules/@babel/core/lib/index.js
var require_lib28 = __commonJS({
  "node_modules/@babel/core/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.DEFAULT_EXTENSIONS = void 0;
    Object.defineProperty(exports, "File", {
      enumerable: true,
      get: function() {
        return _file.default;
      }
    });
    exports.OptionManager = void 0;
    exports.Plugin = Plugin;
    Object.defineProperty(exports, "buildExternalHelpers", {
      enumerable: true,
      get: function() {
        return _buildExternalHelpers.default;
      }
    });
    Object.defineProperty(exports, "createConfigItem", {
      enumerable: true,
      get: function() {
        return _config.createConfigItem;
      }
    });
    Object.defineProperty(exports, "createConfigItemAsync", {
      enumerable: true,
      get: function() {
        return _config.createConfigItemAsync;
      }
    });
    Object.defineProperty(exports, "createConfigItemSync", {
      enumerable: true,
      get: function() {
        return _config.createConfigItemSync;
      }
    });
    Object.defineProperty(exports, "getEnv", {
      enumerable: true,
      get: function() {
        return _environment.getEnv;
      }
    });
    Object.defineProperty(exports, "loadOptions", {
      enumerable: true,
      get: function() {
        return _config.loadOptions;
      }
    });
    Object.defineProperty(exports, "loadOptionsAsync", {
      enumerable: true,
      get: function() {
        return _config.loadOptionsAsync;
      }
    });
    Object.defineProperty(exports, "loadOptionsSync", {
      enumerable: true,
      get: function() {
        return _config.loadOptionsSync;
      }
    });
    Object.defineProperty(exports, "loadPartialConfig", {
      enumerable: true,
      get: function() {
        return _config.loadPartialConfig;
      }
    });
    Object.defineProperty(exports, "loadPartialConfigAsync", {
      enumerable: true,
      get: function() {
        return _config.loadPartialConfigAsync;
      }
    });
    Object.defineProperty(exports, "loadPartialConfigSync", {
      enumerable: true,
      get: function() {
        return _config.loadPartialConfigSync;
      }
    });
    Object.defineProperty(exports, "parse", {
      enumerable: true,
      get: function() {
        return _parse.parse;
      }
    });
    Object.defineProperty(exports, "parseAsync", {
      enumerable: true,
      get: function() {
        return _parse.parseAsync;
      }
    });
    Object.defineProperty(exports, "parseSync", {
      enumerable: true,
      get: function() {
        return _parse.parseSync;
      }
    });
    Object.defineProperty(exports, "resolvePlugin", {
      enumerable: true,
      get: function() {
        return _files.resolvePlugin;
      }
    });
    Object.defineProperty(exports, "resolvePreset", {
      enumerable: true,
      get: function() {
        return _files.resolvePreset;
      }
    });
    Object.defineProperty((0, exports), "template", {
      enumerable: true,
      get: function() {
        return _template().default;
      }
    });
    Object.defineProperty((0, exports), "tokTypes", {
      enumerable: true,
      get: function() {
        return _parser().tokTypes;
      }
    });
    Object.defineProperty(exports, "transform", {
      enumerable: true,
      get: function() {
        return _transform.transform;
      }
    });
    Object.defineProperty(exports, "transformAsync", {
      enumerable: true,
      get: function() {
        return _transform.transformAsync;
      }
    });
    Object.defineProperty(exports, "transformFile", {
      enumerable: true,
      get: function() {
        return _transformFile.transformFile;
      }
    });
    Object.defineProperty(exports, "transformFileAsync", {
      enumerable: true,
      get: function() {
        return _transformFile.transformFileAsync;
      }
    });
    Object.defineProperty(exports, "transformFileSync", {
      enumerable: true,
      get: function() {
        return _transformFile.transformFileSync;
      }
    });
    Object.defineProperty(exports, "transformFromAst", {
      enumerable: true,
      get: function() {
        return _transformAst.transformFromAst;
      }
    });
    Object.defineProperty(exports, "transformFromAstAsync", {
      enumerable: true,
      get: function() {
        return _transformAst.transformFromAstAsync;
      }
    });
    Object.defineProperty(exports, "transformFromAstSync", {
      enumerable: true,
      get: function() {
        return _transformAst.transformFromAstSync;
      }
    });
    Object.defineProperty(exports, "transformSync", {
      enumerable: true,
      get: function() {
        return _transform.transformSync;
      }
    });
    Object.defineProperty((0, exports), "traverse", {
      enumerable: true,
      get: function() {
        return _traverse().default;
      }
    });
    exports.version = exports.types = void 0;
    var _file = require_file();
    var _buildExternalHelpers = require_build_external_helpers();
    var _files = require_files();
    var _environment = require_environment();
    function _types() {
      const data = require_lib11();
      _types = function() {
        return data;
      };
      return data;
    }
    Object.defineProperty((0, exports), "types", {
      enumerable: true,
      get: function() {
        return _types();
      }
    });
    function _parser() {
      const data = require_lib2();
      _parser = function() {
        return data;
      };
      return data;
    }
    function _traverse() {
      const data = require_lib20();
      _traverse = function() {
        return data;
      };
      return data;
    }
    function _template() {
      const data = require_lib18();
      _template = function() {
        return data;
      };
      return data;
    }
    var _config = require_config2();
    var _transform = require_transform();
    var _transformFile = require_transform_file();
    var _transformAst = require_transform_ast();
    var _parse = require_parse4();
    var version2 = "7.20.12";
    exports.version = version2;
    var DEFAULT_EXTENSIONS = Object.freeze([".js", ".jsx", ".es6", ".es", ".mjs", ".cjs"]);
    exports.DEFAULT_EXTENSIONS = DEFAULT_EXTENSIONS;
    var OptionManager = class {
      init(opts) {
        return (0, _config.loadOptionsSync)(opts);
      }
    };
    exports.OptionManager = OptionManager;
    function Plugin(alias) {
      throw new Error(`The (${alias}) Babel 5 plugin is being run with an unsupported Babel version.`);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/shallowEqual.js
var require_shallowEqual2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/shallowEqual.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = shallowEqual;
    function shallowEqual(actual, expected) {
      const keys3 = Object.keys(expected);
      for (const key of keys3) {
        if (actual[key] !== expected[key]) {
          return false;
        }
      }
      return true;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/deprecationWarning.js
var require_deprecationWarning = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/deprecationWarning.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = deprecationWarning;
    var warnings = /* @__PURE__ */ new Set();
    function deprecationWarning(oldName, newName, prefix = "") {
      if (warnings.has(oldName))
        return;
      warnings.add(oldName);
      const {
        internal,
        trace
      } = captureShortStackTrace(1, 2);
      if (internal) {
        return;
      }
      console.warn(`${prefix}\`${oldName}\` has been deprecated, please migrate to \`${newName}\`
${trace}`);
    }
    function captureShortStackTrace(skip, length) {
      const {
        stackTraceLimit,
        prepareStackTrace
      } = Error;
      let stackTrace;
      Error.stackTraceLimit = 1 + skip + length;
      Error.prepareStackTrace = function(err, stack) {
        stackTrace = stack;
      };
      new Error().stack;
      Error.stackTraceLimit = stackTraceLimit;
      Error.prepareStackTrace = prepareStackTrace;
      if (!stackTrace)
        return {
          internal: false,
          trace: ""
        };
      const shortStackTrace = stackTrace.slice(1 + skip, 1 + skip + length);
      return {
        internal: /[\\/]@babel[\\/]/.test(shortStackTrace[1].getFileName()),
        trace: shortStackTrace.map((frame) => `    at ${frame}`).join("\n")
      };
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/generated/index.js
var require_generated6 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isAccessor = isAccessor;
    exports.isAnyTypeAnnotation = isAnyTypeAnnotation;
    exports.isArgumentPlaceholder = isArgumentPlaceholder;
    exports.isArrayExpression = isArrayExpression;
    exports.isArrayPattern = isArrayPattern;
    exports.isArrayTypeAnnotation = isArrayTypeAnnotation;
    exports.isArrowFunctionExpression = isArrowFunctionExpression;
    exports.isAssignmentExpression = isAssignmentExpression;
    exports.isAssignmentPattern = isAssignmentPattern;
    exports.isAwaitExpression = isAwaitExpression;
    exports.isBigIntLiteral = isBigIntLiteral;
    exports.isBinary = isBinary;
    exports.isBinaryExpression = isBinaryExpression;
    exports.isBindExpression = isBindExpression;
    exports.isBlock = isBlock;
    exports.isBlockParent = isBlockParent;
    exports.isBlockStatement = isBlockStatement2;
    exports.isBooleanLiteral = isBooleanLiteral;
    exports.isBooleanLiteralTypeAnnotation = isBooleanLiteralTypeAnnotation;
    exports.isBooleanTypeAnnotation = isBooleanTypeAnnotation;
    exports.isBreakStatement = isBreakStatement;
    exports.isCallExpression = isCallExpression2;
    exports.isCatchClause = isCatchClause;
    exports.isClass = isClass;
    exports.isClassAccessorProperty = isClassAccessorProperty;
    exports.isClassBody = isClassBody;
    exports.isClassDeclaration = isClassDeclaration;
    exports.isClassExpression = isClassExpression;
    exports.isClassImplements = isClassImplements;
    exports.isClassMethod = isClassMethod;
    exports.isClassPrivateMethod = isClassPrivateMethod;
    exports.isClassPrivateProperty = isClassPrivateProperty;
    exports.isClassProperty = isClassProperty;
    exports.isCompletionStatement = isCompletionStatement;
    exports.isConditional = isConditional;
    exports.isConditionalExpression = isConditionalExpression;
    exports.isContinueStatement = isContinueStatement;
    exports.isDebuggerStatement = isDebuggerStatement;
    exports.isDecimalLiteral = isDecimalLiteral;
    exports.isDeclaration = isDeclaration;
    exports.isDeclareClass = isDeclareClass;
    exports.isDeclareExportAllDeclaration = isDeclareExportAllDeclaration;
    exports.isDeclareExportDeclaration = isDeclareExportDeclaration;
    exports.isDeclareFunction = isDeclareFunction;
    exports.isDeclareInterface = isDeclareInterface;
    exports.isDeclareModule = isDeclareModule;
    exports.isDeclareModuleExports = isDeclareModuleExports;
    exports.isDeclareOpaqueType = isDeclareOpaqueType;
    exports.isDeclareTypeAlias = isDeclareTypeAlias;
    exports.isDeclareVariable = isDeclareVariable;
    exports.isDeclaredPredicate = isDeclaredPredicate;
    exports.isDecorator = isDecorator;
    exports.isDirective = isDirective;
    exports.isDirectiveLiteral = isDirectiveLiteral;
    exports.isDoExpression = isDoExpression;
    exports.isDoWhileStatement = isDoWhileStatement;
    exports.isEmptyStatement = isEmptyStatement;
    exports.isEmptyTypeAnnotation = isEmptyTypeAnnotation;
    exports.isEnumBody = isEnumBody;
    exports.isEnumBooleanBody = isEnumBooleanBody;
    exports.isEnumBooleanMember = isEnumBooleanMember;
    exports.isEnumDeclaration = isEnumDeclaration;
    exports.isEnumDefaultedMember = isEnumDefaultedMember;
    exports.isEnumMember = isEnumMember;
    exports.isEnumNumberBody = isEnumNumberBody;
    exports.isEnumNumberMember = isEnumNumberMember;
    exports.isEnumStringBody = isEnumStringBody;
    exports.isEnumStringMember = isEnumStringMember;
    exports.isEnumSymbolBody = isEnumSymbolBody;
    exports.isExistsTypeAnnotation = isExistsTypeAnnotation;
    exports.isExportAllDeclaration = isExportAllDeclaration;
    exports.isExportDeclaration = isExportDeclaration;
    exports.isExportDefaultDeclaration = isExportDefaultDeclaration;
    exports.isExportDefaultSpecifier = isExportDefaultSpecifier;
    exports.isExportNamedDeclaration = isExportNamedDeclaration;
    exports.isExportNamespaceSpecifier = isExportNamespaceSpecifier;
    exports.isExportSpecifier = isExportSpecifier;
    exports.isExpression = isExpression2;
    exports.isExpressionStatement = isExpressionStatement;
    exports.isExpressionWrapper = isExpressionWrapper;
    exports.isFile = isFile2;
    exports.isFlow = isFlow;
    exports.isFlowBaseAnnotation = isFlowBaseAnnotation;
    exports.isFlowDeclaration = isFlowDeclaration;
    exports.isFlowPredicate = isFlowPredicate;
    exports.isFlowType = isFlowType;
    exports.isFor = isFor;
    exports.isForInStatement = isForInStatement;
    exports.isForOfStatement = isForOfStatement;
    exports.isForStatement = isForStatement;
    exports.isForXStatement = isForXStatement;
    exports.isFunction = isFunction;
    exports.isFunctionDeclaration = isFunctionDeclaration;
    exports.isFunctionExpression = isFunctionExpression;
    exports.isFunctionParent = isFunctionParent;
    exports.isFunctionTypeAnnotation = isFunctionTypeAnnotation;
    exports.isFunctionTypeParam = isFunctionTypeParam;
    exports.isGenericTypeAnnotation = isGenericTypeAnnotation;
    exports.isIdentifier = isIdentifier2;
    exports.isIfStatement = isIfStatement;
    exports.isImmutable = isImmutable;
    exports.isImport = isImport;
    exports.isImportAttribute = isImportAttribute;
    exports.isImportDeclaration = isImportDeclaration;
    exports.isImportDefaultSpecifier = isImportDefaultSpecifier;
    exports.isImportNamespaceSpecifier = isImportNamespaceSpecifier;
    exports.isImportOrExportDeclaration = isImportOrExportDeclaration;
    exports.isImportSpecifier = isImportSpecifier2;
    exports.isIndexedAccessType = isIndexedAccessType;
    exports.isInferredPredicate = isInferredPredicate;
    exports.isInterfaceDeclaration = isInterfaceDeclaration;
    exports.isInterfaceExtends = isInterfaceExtends;
    exports.isInterfaceTypeAnnotation = isInterfaceTypeAnnotation;
    exports.isInterpreterDirective = isInterpreterDirective;
    exports.isIntersectionTypeAnnotation = isIntersectionTypeAnnotation;
    exports.isJSX = isJSX;
    exports.isJSXAttribute = isJSXAttribute;
    exports.isJSXClosingElement = isJSXClosingElement;
    exports.isJSXClosingFragment = isJSXClosingFragment;
    exports.isJSXElement = isJSXElement2;
    exports.isJSXEmptyExpression = isJSXEmptyExpression;
    exports.isJSXExpressionContainer = isJSXExpressionContainer;
    exports.isJSXFragment = isJSXFragment;
    exports.isJSXIdentifier = isJSXIdentifier;
    exports.isJSXMemberExpression = isJSXMemberExpression;
    exports.isJSXNamespacedName = isJSXNamespacedName;
    exports.isJSXOpeningElement = isJSXOpeningElement;
    exports.isJSXOpeningFragment = isJSXOpeningFragment;
    exports.isJSXSpreadAttribute = isJSXSpreadAttribute;
    exports.isJSXSpreadChild = isJSXSpreadChild;
    exports.isJSXText = isJSXText;
    exports.isLVal = isLVal;
    exports.isLabeledStatement = isLabeledStatement;
    exports.isLiteral = isLiteral;
    exports.isLogicalExpression = isLogicalExpression;
    exports.isLoop = isLoop;
    exports.isMemberExpression = isMemberExpression;
    exports.isMetaProperty = isMetaProperty;
    exports.isMethod = isMethod;
    exports.isMiscellaneous = isMiscellaneous;
    exports.isMixedTypeAnnotation = isMixedTypeAnnotation;
    exports.isModuleDeclaration = isModuleDeclaration;
    exports.isModuleExpression = isModuleExpression;
    exports.isModuleSpecifier = isModuleSpecifier;
    exports.isNewExpression = isNewExpression;
    exports.isNoop = isNoop;
    exports.isNullLiteral = isNullLiteral;
    exports.isNullLiteralTypeAnnotation = isNullLiteralTypeAnnotation;
    exports.isNullableTypeAnnotation = isNullableTypeAnnotation;
    exports.isNumberLiteral = isNumberLiteral;
    exports.isNumberLiteralTypeAnnotation = isNumberLiteralTypeAnnotation;
    exports.isNumberTypeAnnotation = isNumberTypeAnnotation;
    exports.isNumericLiteral = isNumericLiteral;
    exports.isObjectExpression = isObjectExpression;
    exports.isObjectMember = isObjectMember;
    exports.isObjectMethod = isObjectMethod;
    exports.isObjectPattern = isObjectPattern;
    exports.isObjectProperty = isObjectProperty;
    exports.isObjectTypeAnnotation = isObjectTypeAnnotation;
    exports.isObjectTypeCallProperty = isObjectTypeCallProperty;
    exports.isObjectTypeIndexer = isObjectTypeIndexer;
    exports.isObjectTypeInternalSlot = isObjectTypeInternalSlot;
    exports.isObjectTypeProperty = isObjectTypeProperty;
    exports.isObjectTypeSpreadProperty = isObjectTypeSpreadProperty;
    exports.isOpaqueType = isOpaqueType;
    exports.isOptionalCallExpression = isOptionalCallExpression;
    exports.isOptionalIndexedAccessType = isOptionalIndexedAccessType;
    exports.isOptionalMemberExpression = isOptionalMemberExpression;
    exports.isParenthesizedExpression = isParenthesizedExpression;
    exports.isPattern = isPattern;
    exports.isPatternLike = isPatternLike;
    exports.isPipelineBareFunction = isPipelineBareFunction;
    exports.isPipelinePrimaryTopicReference = isPipelinePrimaryTopicReference;
    exports.isPipelineTopicExpression = isPipelineTopicExpression;
    exports.isPlaceholder = isPlaceholder;
    exports.isPrivate = isPrivate;
    exports.isPrivateName = isPrivateName;
    exports.isProgram = isProgram;
    exports.isProperty = isProperty;
    exports.isPureish = isPureish;
    exports.isQualifiedTypeIdentifier = isQualifiedTypeIdentifier;
    exports.isRecordExpression = isRecordExpression;
    exports.isRegExpLiteral = isRegExpLiteral;
    exports.isRegexLiteral = isRegexLiteral;
    exports.isRestElement = isRestElement;
    exports.isRestProperty = isRestProperty;
    exports.isReturnStatement = isReturnStatement2;
    exports.isScopable = isScopable;
    exports.isSequenceExpression = isSequenceExpression;
    exports.isSpreadElement = isSpreadElement;
    exports.isSpreadProperty = isSpreadProperty;
    exports.isStandardized = isStandardized;
    exports.isStatement = isStatement;
    exports.isStaticBlock = isStaticBlock;
    exports.isStringLiteral = isStringLiteral3;
    exports.isStringLiteralTypeAnnotation = isStringLiteralTypeAnnotation;
    exports.isStringTypeAnnotation = isStringTypeAnnotation;
    exports.isSuper = isSuper;
    exports.isSwitchCase = isSwitchCase;
    exports.isSwitchStatement = isSwitchStatement;
    exports.isSymbolTypeAnnotation = isSymbolTypeAnnotation;
    exports.isTSAnyKeyword = isTSAnyKeyword;
    exports.isTSArrayType = isTSArrayType;
    exports.isTSAsExpression = isTSAsExpression;
    exports.isTSBaseType = isTSBaseType;
    exports.isTSBigIntKeyword = isTSBigIntKeyword;
    exports.isTSBooleanKeyword = isTSBooleanKeyword;
    exports.isTSCallSignatureDeclaration = isTSCallSignatureDeclaration;
    exports.isTSConditionalType = isTSConditionalType;
    exports.isTSConstructSignatureDeclaration = isTSConstructSignatureDeclaration;
    exports.isTSConstructorType = isTSConstructorType;
    exports.isTSDeclareFunction = isTSDeclareFunction;
    exports.isTSDeclareMethod = isTSDeclareMethod;
    exports.isTSEntityName = isTSEntityName;
    exports.isTSEnumDeclaration = isTSEnumDeclaration;
    exports.isTSEnumMember = isTSEnumMember;
    exports.isTSExportAssignment = isTSExportAssignment;
    exports.isTSExpressionWithTypeArguments = isTSExpressionWithTypeArguments;
    exports.isTSExternalModuleReference = isTSExternalModuleReference;
    exports.isTSFunctionType = isTSFunctionType;
    exports.isTSImportEqualsDeclaration = isTSImportEqualsDeclaration;
    exports.isTSImportType = isTSImportType;
    exports.isTSIndexSignature = isTSIndexSignature;
    exports.isTSIndexedAccessType = isTSIndexedAccessType;
    exports.isTSInferType = isTSInferType;
    exports.isTSInstantiationExpression = isTSInstantiationExpression;
    exports.isTSInterfaceBody = isTSInterfaceBody;
    exports.isTSInterfaceDeclaration = isTSInterfaceDeclaration;
    exports.isTSIntersectionType = isTSIntersectionType;
    exports.isTSIntrinsicKeyword = isTSIntrinsicKeyword;
    exports.isTSLiteralType = isTSLiteralType;
    exports.isTSMappedType = isTSMappedType;
    exports.isTSMethodSignature = isTSMethodSignature;
    exports.isTSModuleBlock = isTSModuleBlock;
    exports.isTSModuleDeclaration = isTSModuleDeclaration;
    exports.isTSNamedTupleMember = isTSNamedTupleMember;
    exports.isTSNamespaceExportDeclaration = isTSNamespaceExportDeclaration;
    exports.isTSNeverKeyword = isTSNeverKeyword;
    exports.isTSNonNullExpression = isTSNonNullExpression;
    exports.isTSNullKeyword = isTSNullKeyword;
    exports.isTSNumberKeyword = isTSNumberKeyword;
    exports.isTSObjectKeyword = isTSObjectKeyword;
    exports.isTSOptionalType = isTSOptionalType;
    exports.isTSParameterProperty = isTSParameterProperty;
    exports.isTSParenthesizedType = isTSParenthesizedType;
    exports.isTSPropertySignature = isTSPropertySignature;
    exports.isTSQualifiedName = isTSQualifiedName;
    exports.isTSRestType = isTSRestType;
    exports.isTSSatisfiesExpression = isTSSatisfiesExpression;
    exports.isTSStringKeyword = isTSStringKeyword;
    exports.isTSSymbolKeyword = isTSSymbolKeyword;
    exports.isTSThisType = isTSThisType;
    exports.isTSTupleType = isTSTupleType;
    exports.isTSType = isTSType2;
    exports.isTSTypeAliasDeclaration = isTSTypeAliasDeclaration;
    exports.isTSTypeAnnotation = isTSTypeAnnotation;
    exports.isTSTypeAssertion = isTSTypeAssertion;
    exports.isTSTypeElement = isTSTypeElement;
    exports.isTSTypeLiteral = isTSTypeLiteral;
    exports.isTSTypeOperator = isTSTypeOperator;
    exports.isTSTypeParameter = isTSTypeParameter;
    exports.isTSTypeParameterDeclaration = isTSTypeParameterDeclaration;
    exports.isTSTypeParameterInstantiation = isTSTypeParameterInstantiation;
    exports.isTSTypePredicate = isTSTypePredicate;
    exports.isTSTypeQuery = isTSTypeQuery;
    exports.isTSTypeReference = isTSTypeReference;
    exports.isTSUndefinedKeyword = isTSUndefinedKeyword;
    exports.isTSUnionType = isTSUnionType;
    exports.isTSUnknownKeyword = isTSUnknownKeyword;
    exports.isTSVoidKeyword = isTSVoidKeyword;
    exports.isTaggedTemplateExpression = isTaggedTemplateExpression;
    exports.isTemplateElement = isTemplateElement2;
    exports.isTemplateLiteral = isTemplateLiteral;
    exports.isTerminatorless = isTerminatorless;
    exports.isThisExpression = isThisExpression;
    exports.isThisTypeAnnotation = isThisTypeAnnotation;
    exports.isThrowStatement = isThrowStatement;
    exports.isTopicReference = isTopicReference;
    exports.isTryStatement = isTryStatement;
    exports.isTupleExpression = isTupleExpression;
    exports.isTupleTypeAnnotation = isTupleTypeAnnotation;
    exports.isTypeAlias = isTypeAlias;
    exports.isTypeAnnotation = isTypeAnnotation;
    exports.isTypeCastExpression = isTypeCastExpression;
    exports.isTypeParameter = isTypeParameter;
    exports.isTypeParameterDeclaration = isTypeParameterDeclaration;
    exports.isTypeParameterInstantiation = isTypeParameterInstantiation;
    exports.isTypeScript = isTypeScript;
    exports.isTypeofTypeAnnotation = isTypeofTypeAnnotation;
    exports.isUnaryExpression = isUnaryExpression;
    exports.isUnaryLike = isUnaryLike;
    exports.isUnionTypeAnnotation = isUnionTypeAnnotation;
    exports.isUpdateExpression = isUpdateExpression;
    exports.isUserWhitespacable = isUserWhitespacable;
    exports.isV8IntrinsicIdentifier = isV8IntrinsicIdentifier;
    exports.isVariableDeclaration = isVariableDeclaration;
    exports.isVariableDeclarator = isVariableDeclarator2;
    exports.isVariance = isVariance;
    exports.isVoidTypeAnnotation = isVoidTypeAnnotation;
    exports.isWhile = isWhile;
    exports.isWhileStatement = isWhileStatement;
    exports.isWithStatement = isWithStatement;
    exports.isYieldExpression = isYieldExpression;
    var _shallowEqual = require_shallowEqual2();
    var _deprecationWarning = require_deprecationWarning();
    function isArrayExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ArrayExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isAssignmentExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "AssignmentExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBinaryExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BinaryExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isInterpreterDirective(node, opts) {
      if (!node)
        return false;
      if (node.type !== "InterpreterDirective")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDirective(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Directive")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDirectiveLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DirectiveLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBlockStatement2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BlockStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBreakStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BreakStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isCallExpression2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "CallExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isCatchClause(node, opts) {
      if (!node)
        return false;
      if (node.type !== "CatchClause")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isConditionalExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ConditionalExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isContinueStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ContinueStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDebuggerStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DebuggerStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDoWhileStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DoWhileStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEmptyStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EmptyStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExpressionStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExpressionStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFile2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "File")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isForInStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ForInStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isForStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ForStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunctionDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "FunctionDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunctionExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "FunctionExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isIdentifier2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Identifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isIfStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "IfStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isLabeledStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "LabeledStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStringLiteral3(node, opts) {
      if (!node)
        return false;
      if (node.type !== "StringLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNumericLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NumericLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNullLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NullLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBooleanLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BooleanLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isRegExpLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "RegExpLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isLogicalExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "LogicalExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isMemberExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "MemberExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNewExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NewExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isProgram(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Program")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectMethod(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectMethod")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isRestElement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "RestElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isReturnStatement2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ReturnStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSequenceExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "SequenceExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isParenthesizedExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ParenthesizedExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSwitchCase(node, opts) {
      if (!node)
        return false;
      if (node.type !== "SwitchCase")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSwitchStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "SwitchStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isThisExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ThisExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isThrowStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ThrowStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTryStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TryStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isUnaryExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "UnaryExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isUpdateExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "UpdateExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isVariableDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "VariableDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isVariableDeclarator2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "VariableDeclarator")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isWhileStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "WhileStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isWithStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "WithStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isAssignmentPattern(node, opts) {
      if (!node)
        return false;
      if (node.type !== "AssignmentPattern")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isArrayPattern(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ArrayPattern")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isArrowFunctionExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ArrowFunctionExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportAllDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportAllDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportDefaultDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportDefaultDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportNamedDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportNamedDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportSpecifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isForOfStatement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ForOfStatement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ImportDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportDefaultSpecifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ImportDefaultSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportNamespaceSpecifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ImportNamespaceSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportSpecifier2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ImportSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isMetaProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "MetaProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassMethod(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassMethod")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectPattern(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectPattern")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSpreadElement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "SpreadElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSuper(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Super")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTaggedTemplateExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TaggedTemplateExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTemplateElement2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TemplateElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTemplateLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TemplateLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isYieldExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "YieldExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isAwaitExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "AwaitExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImport(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Import")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBigIntLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BigIntLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportNamespaceSpecifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportNamespaceSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isOptionalMemberExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "OptionalMemberExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isOptionalCallExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "OptionalCallExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassAccessorProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassAccessorProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassPrivateProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassPrivateProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassPrivateMethod(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassPrivateMethod")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPrivateName(node, opts) {
      if (!node)
        return false;
      if (node.type !== "PrivateName")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStaticBlock(node, opts) {
      if (!node)
        return false;
      if (node.type !== "StaticBlock")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isAnyTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "AnyTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isArrayTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ArrayTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBooleanTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BooleanTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBooleanLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BooleanLiteralTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNullLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NullLiteralTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClassImplements(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ClassImplements")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareClass(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareClass")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareFunction(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareFunction")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareInterface(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareInterface")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareModule(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareModule")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareModuleExports(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareModuleExports")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareTypeAlias(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareTypeAlias")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareOpaqueType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareOpaqueType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareVariable(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareVariable")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareExportDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareExportDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclareExportAllDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclareExportAllDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclaredPredicate(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DeclaredPredicate")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExistsTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExistsTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunctionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "FunctionTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunctionTypeParam(node, opts) {
      if (!node)
        return false;
      if (node.type !== "FunctionTypeParam")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isGenericTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "GenericTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isInferredPredicate(node, opts) {
      if (!node)
        return false;
      if (node.type !== "InferredPredicate")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isInterfaceExtends(node, opts) {
      if (!node)
        return false;
      if (node.type !== "InterfaceExtends")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isInterfaceDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "InterfaceDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isInterfaceTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "InterfaceTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isIntersectionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "IntersectionTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isMixedTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "MixedTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEmptyTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EmptyTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNullableTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NullableTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNumberLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NumberLiteralTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNumberTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "NumberTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeInternalSlot(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeInternalSlot")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeCallProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeCallProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeIndexer(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeIndexer")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectTypeSpreadProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ObjectTypeSpreadProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isOpaqueType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "OpaqueType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isQualifiedTypeIdentifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "QualifiedTypeIdentifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStringLiteralTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "StringLiteralTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStringTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "StringTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSymbolTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "SymbolTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isThisTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ThisTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTupleTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TupleTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeofTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeofTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeAlias(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeAlias")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeCastExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeCastExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeParameter(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeParameter")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeParameterDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeParameterDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeParameterInstantiation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TypeParameterInstantiation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isUnionTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "UnionTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isVariance(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Variance")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isVoidTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "VoidTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumBooleanBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumBooleanBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumNumberBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumNumberBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumStringBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumStringBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumSymbolBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumSymbolBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumBooleanMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumBooleanMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumNumberMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumNumberMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumStringMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumStringMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumDefaultedMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "EnumDefaultedMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isIndexedAccessType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "IndexedAccessType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isOptionalIndexedAccessType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "OptionalIndexedAccessType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXAttribute(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXAttribute")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXClosingElement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXClosingElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXElement2(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXEmptyExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXEmptyExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXExpressionContainer(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXExpressionContainer")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXSpreadChild(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXSpreadChild")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXIdentifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXIdentifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXMemberExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXMemberExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXNamespacedName(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXNamespacedName")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXOpeningElement(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXOpeningElement")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXSpreadAttribute(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXSpreadAttribute")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXText(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXText")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXFragment(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXFragment")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXOpeningFragment(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXOpeningFragment")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSXClosingFragment(node, opts) {
      if (!node)
        return false;
      if (node.type !== "JSXClosingFragment")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNoop(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Noop")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPlaceholder(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Placeholder")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isV8IntrinsicIdentifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "V8IntrinsicIdentifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isArgumentPlaceholder(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ArgumentPlaceholder")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBindExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "BindExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportAttribute(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ImportAttribute")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDecorator(node, opts) {
      if (!node)
        return false;
      if (node.type !== "Decorator")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDoExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DoExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportDefaultSpecifier(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ExportDefaultSpecifier")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isRecordExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "RecordExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTupleExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TupleExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDecimalLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "DecimalLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isModuleExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "ModuleExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTopicReference(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TopicReference")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPipelineTopicExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "PipelineTopicExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPipelineBareFunction(node, opts) {
      if (!node)
        return false;
      if (node.type !== "PipelineBareFunction")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPipelinePrimaryTopicReference(node, opts) {
      if (!node)
        return false;
      if (node.type !== "PipelinePrimaryTopicReference")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSParameterProperty(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSParameterProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSDeclareFunction(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSDeclareFunction")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSDeclareMethod(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSDeclareMethod")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSQualifiedName(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSQualifiedName")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSCallSignatureDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSCallSignatureDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSConstructSignatureDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSConstructSignatureDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSPropertySignature(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSPropertySignature")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSMethodSignature(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSMethodSignature")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSIndexSignature(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSIndexSignature")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSAnyKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSAnyKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSBooleanKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSBooleanKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSBigIntKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSBigIntKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSIntrinsicKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSIntrinsicKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNeverKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNeverKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNullKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNullKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNumberKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNumberKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSObjectKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSObjectKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSStringKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSStringKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSSymbolKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSSymbolKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSUndefinedKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSUndefinedKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSUnknownKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSUnknownKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSVoidKeyword(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSVoidKeyword")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSThisType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSThisType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSFunctionType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSFunctionType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSConstructorType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSConstructorType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeReference(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeReference")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypePredicate(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypePredicate")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeQuery(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeQuery")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeLiteral(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSArrayType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSArrayType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTupleType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTupleType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSOptionalType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSOptionalType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSRestType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSRestType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNamedTupleMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNamedTupleMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSUnionType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSUnionType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSIntersectionType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSIntersectionType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSConditionalType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSConditionalType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSInferType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSInferType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSParenthesizedType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSParenthesizedType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeOperator(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeOperator")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSIndexedAccessType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSIndexedAccessType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSMappedType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSMappedType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSLiteralType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSLiteralType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSExpressionWithTypeArguments(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSExpressionWithTypeArguments")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSInterfaceDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSInterfaceDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSInterfaceBody(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSInterfaceBody")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeAliasDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeAliasDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSInstantiationExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSInstantiationExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSAsExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSAsExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSSatisfiesExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSSatisfiesExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeAssertion(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeAssertion")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSEnumDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSEnumDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSEnumMember(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSEnumMember")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSModuleDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSModuleDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSModuleBlock(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSModuleBlock")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSImportType(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSImportType")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSImportEqualsDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSImportEqualsDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSExternalModuleReference(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSExternalModuleReference")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNonNullExpression(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNonNullExpression")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSExportAssignment(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSExportAssignment")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSNamespaceExportDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSNamespaceExportDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeAnnotation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeAnnotation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeParameterInstantiation(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeParameterInstantiation")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeParameterDeclaration(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeParameterDeclaration")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeParameter(node, opts) {
      if (!node)
        return false;
      if (node.type !== "TSTypeParameter")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStandardized(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ArrayExpression":
        case "AssignmentExpression":
        case "BinaryExpression":
        case "InterpreterDirective":
        case "Directive":
        case "DirectiveLiteral":
        case "BlockStatement":
        case "BreakStatement":
        case "CallExpression":
        case "CatchClause":
        case "ConditionalExpression":
        case "ContinueStatement":
        case "DebuggerStatement":
        case "DoWhileStatement":
        case "EmptyStatement":
        case "ExpressionStatement":
        case "File":
        case "ForInStatement":
        case "ForStatement":
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "Identifier":
        case "IfStatement":
        case "LabeledStatement":
        case "StringLiteral":
        case "NumericLiteral":
        case "NullLiteral":
        case "BooleanLiteral":
        case "RegExpLiteral":
        case "LogicalExpression":
        case "MemberExpression":
        case "NewExpression":
        case "Program":
        case "ObjectExpression":
        case "ObjectMethod":
        case "ObjectProperty":
        case "RestElement":
        case "ReturnStatement":
        case "SequenceExpression":
        case "ParenthesizedExpression":
        case "SwitchCase":
        case "SwitchStatement":
        case "ThisExpression":
        case "ThrowStatement":
        case "TryStatement":
        case "UnaryExpression":
        case "UpdateExpression":
        case "VariableDeclaration":
        case "VariableDeclarator":
        case "WhileStatement":
        case "WithStatement":
        case "AssignmentPattern":
        case "ArrayPattern":
        case "ArrowFunctionExpression":
        case "ClassBody":
        case "ClassExpression":
        case "ClassDeclaration":
        case "ExportAllDeclaration":
        case "ExportDefaultDeclaration":
        case "ExportNamedDeclaration":
        case "ExportSpecifier":
        case "ForOfStatement":
        case "ImportDeclaration":
        case "ImportDefaultSpecifier":
        case "ImportNamespaceSpecifier":
        case "ImportSpecifier":
        case "MetaProperty":
        case "ClassMethod":
        case "ObjectPattern":
        case "SpreadElement":
        case "Super":
        case "TaggedTemplateExpression":
        case "TemplateElement":
        case "TemplateLiteral":
        case "YieldExpression":
        case "AwaitExpression":
        case "Import":
        case "BigIntLiteral":
        case "ExportNamespaceSpecifier":
        case "OptionalMemberExpression":
        case "OptionalCallExpression":
        case "ClassProperty":
        case "ClassAccessorProperty":
        case "ClassPrivateProperty":
        case "ClassPrivateMethod":
        case "PrivateName":
        case "StaticBlock":
          break;
        case "Placeholder":
          switch (node.expectedNode) {
            case "Identifier":
            case "StringLiteral":
            case "BlockStatement":
            case "ClassBody":
              break;
            default:
              return false;
          }
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExpression2(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ArrayExpression":
        case "AssignmentExpression":
        case "BinaryExpression":
        case "CallExpression":
        case "ConditionalExpression":
        case "FunctionExpression":
        case "Identifier":
        case "StringLiteral":
        case "NumericLiteral":
        case "NullLiteral":
        case "BooleanLiteral":
        case "RegExpLiteral":
        case "LogicalExpression":
        case "MemberExpression":
        case "NewExpression":
        case "ObjectExpression":
        case "SequenceExpression":
        case "ParenthesizedExpression":
        case "ThisExpression":
        case "UnaryExpression":
        case "UpdateExpression":
        case "ArrowFunctionExpression":
        case "ClassExpression":
        case "MetaProperty":
        case "Super":
        case "TaggedTemplateExpression":
        case "TemplateLiteral":
        case "YieldExpression":
        case "AwaitExpression":
        case "Import":
        case "BigIntLiteral":
        case "OptionalMemberExpression":
        case "OptionalCallExpression":
        case "TypeCastExpression":
        case "JSXElement":
        case "JSXFragment":
        case "BindExpression":
        case "DoExpression":
        case "RecordExpression":
        case "TupleExpression":
        case "DecimalLiteral":
        case "ModuleExpression":
        case "TopicReference":
        case "PipelineTopicExpression":
        case "PipelineBareFunction":
        case "PipelinePrimaryTopicReference":
        case "TSInstantiationExpression":
        case "TSAsExpression":
        case "TSSatisfiesExpression":
        case "TSTypeAssertion":
        case "TSNonNullExpression":
          break;
        case "Placeholder":
          switch (node.expectedNode) {
            case "Expression":
            case "Identifier":
            case "StringLiteral":
              break;
            default:
              return false;
          }
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBinary(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BinaryExpression":
        case "LogicalExpression":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isScopable(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BlockStatement":
        case "CatchClause":
        case "DoWhileStatement":
        case "ForInStatement":
        case "ForStatement":
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "Program":
        case "ObjectMethod":
        case "SwitchStatement":
        case "WhileStatement":
        case "ArrowFunctionExpression":
        case "ClassExpression":
        case "ClassDeclaration":
        case "ForOfStatement":
        case "ClassMethod":
        case "ClassPrivateMethod":
        case "StaticBlock":
        case "TSModuleBlock":
          break;
        case "Placeholder":
          if (node.expectedNode === "BlockStatement")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBlockParent(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BlockStatement":
        case "CatchClause":
        case "DoWhileStatement":
        case "ForInStatement":
        case "ForStatement":
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "Program":
        case "ObjectMethod":
        case "SwitchStatement":
        case "WhileStatement":
        case "ArrowFunctionExpression":
        case "ForOfStatement":
        case "ClassMethod":
        case "ClassPrivateMethod":
        case "StaticBlock":
        case "TSModuleBlock":
          break;
        case "Placeholder":
          if (node.expectedNode === "BlockStatement")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isBlock(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BlockStatement":
        case "Program":
        case "TSModuleBlock":
          break;
        case "Placeholder":
          if (node.expectedNode === "BlockStatement")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isStatement(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BlockStatement":
        case "BreakStatement":
        case "ContinueStatement":
        case "DebuggerStatement":
        case "DoWhileStatement":
        case "EmptyStatement":
        case "ExpressionStatement":
        case "ForInStatement":
        case "ForStatement":
        case "FunctionDeclaration":
        case "IfStatement":
        case "LabeledStatement":
        case "ReturnStatement":
        case "SwitchStatement":
        case "ThrowStatement":
        case "TryStatement":
        case "VariableDeclaration":
        case "WhileStatement":
        case "WithStatement":
        case "ClassDeclaration":
        case "ExportAllDeclaration":
        case "ExportDefaultDeclaration":
        case "ExportNamedDeclaration":
        case "ForOfStatement":
        case "ImportDeclaration":
        case "DeclareClass":
        case "DeclareFunction":
        case "DeclareInterface":
        case "DeclareModule":
        case "DeclareModuleExports":
        case "DeclareTypeAlias":
        case "DeclareOpaqueType":
        case "DeclareVariable":
        case "DeclareExportDeclaration":
        case "DeclareExportAllDeclaration":
        case "InterfaceDeclaration":
        case "OpaqueType":
        case "TypeAlias":
        case "EnumDeclaration":
        case "TSDeclareFunction":
        case "TSInterfaceDeclaration":
        case "TSTypeAliasDeclaration":
        case "TSEnumDeclaration":
        case "TSModuleDeclaration":
        case "TSImportEqualsDeclaration":
        case "TSExportAssignment":
        case "TSNamespaceExportDeclaration":
          break;
        case "Placeholder":
          switch (node.expectedNode) {
            case "Statement":
            case "Declaration":
            case "BlockStatement":
              break;
            default:
              return false;
          }
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTerminatorless(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BreakStatement":
        case "ContinueStatement":
        case "ReturnStatement":
        case "ThrowStatement":
        case "YieldExpression":
        case "AwaitExpression":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isCompletionStatement(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "BreakStatement":
        case "ContinueStatement":
        case "ReturnStatement":
        case "ThrowStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isConditional(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ConditionalExpression":
        case "IfStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isLoop(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "DoWhileStatement":
        case "ForInStatement":
        case "ForStatement":
        case "WhileStatement":
        case "ForOfStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isWhile(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "DoWhileStatement":
        case "WhileStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExpressionWrapper(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ExpressionStatement":
        case "ParenthesizedExpression":
        case "TypeCastExpression":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFor(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ForInStatement":
        case "ForStatement":
        case "ForOfStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isForXStatement(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ForInStatement":
        case "ForOfStatement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunction(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "ObjectMethod":
        case "ArrowFunctionExpression":
        case "ClassMethod":
        case "ClassPrivateMethod":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFunctionParent(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "ObjectMethod":
        case "ArrowFunctionExpression":
        case "ClassMethod":
        case "ClassPrivateMethod":
        case "StaticBlock":
        case "TSModuleBlock":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPureish(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "FunctionDeclaration":
        case "FunctionExpression":
        case "StringLiteral":
        case "NumericLiteral":
        case "NullLiteral":
        case "BooleanLiteral":
        case "RegExpLiteral":
        case "ArrowFunctionExpression":
        case "BigIntLiteral":
        case "DecimalLiteral":
          break;
        case "Placeholder":
          if (node.expectedNode === "StringLiteral")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isDeclaration(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "FunctionDeclaration":
        case "VariableDeclaration":
        case "ClassDeclaration":
        case "ExportAllDeclaration":
        case "ExportDefaultDeclaration":
        case "ExportNamedDeclaration":
        case "ImportDeclaration":
        case "DeclareClass":
        case "DeclareFunction":
        case "DeclareInterface":
        case "DeclareModule":
        case "DeclareModuleExports":
        case "DeclareTypeAlias":
        case "DeclareOpaqueType":
        case "DeclareVariable":
        case "DeclareExportDeclaration":
        case "DeclareExportAllDeclaration":
        case "InterfaceDeclaration":
        case "OpaqueType":
        case "TypeAlias":
        case "EnumDeclaration":
        case "TSDeclareFunction":
        case "TSInterfaceDeclaration":
        case "TSTypeAliasDeclaration":
        case "TSEnumDeclaration":
        case "TSModuleDeclaration":
          break;
        case "Placeholder":
          if (node.expectedNode === "Declaration")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPatternLike(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "Identifier":
        case "RestElement":
        case "AssignmentPattern":
        case "ArrayPattern":
        case "ObjectPattern":
        case "TSAsExpression":
        case "TSSatisfiesExpression":
        case "TSTypeAssertion":
        case "TSNonNullExpression":
          break;
        case "Placeholder":
          switch (node.expectedNode) {
            case "Pattern":
            case "Identifier":
              break;
            default:
              return false;
          }
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isLVal(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "Identifier":
        case "MemberExpression":
        case "RestElement":
        case "AssignmentPattern":
        case "ArrayPattern":
        case "ObjectPattern":
        case "TSParameterProperty":
        case "TSAsExpression":
        case "TSSatisfiesExpression":
        case "TSTypeAssertion":
        case "TSNonNullExpression":
          break;
        case "Placeholder":
          switch (node.expectedNode) {
            case "Pattern":
            case "Identifier":
              break;
            default:
              return false;
          }
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSEntityName(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "Identifier":
        case "TSQualifiedName":
          break;
        case "Placeholder":
          if (node.expectedNode === "Identifier")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isLiteral(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "StringLiteral":
        case "NumericLiteral":
        case "NullLiteral":
        case "BooleanLiteral":
        case "RegExpLiteral":
        case "TemplateLiteral":
        case "BigIntLiteral":
        case "DecimalLiteral":
          break;
        case "Placeholder":
          if (node.expectedNode === "StringLiteral")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImmutable(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "StringLiteral":
        case "NumericLiteral":
        case "NullLiteral":
        case "BooleanLiteral":
        case "BigIntLiteral":
        case "JSXAttribute":
        case "JSXClosingElement":
        case "JSXElement":
        case "JSXExpressionContainer":
        case "JSXSpreadChild":
        case "JSXOpeningElement":
        case "JSXText":
        case "JSXFragment":
        case "JSXOpeningFragment":
        case "JSXClosingFragment":
        case "DecimalLiteral":
          break;
        case "Placeholder":
          if (node.expectedNode === "StringLiteral")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isUserWhitespacable(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ObjectMethod":
        case "ObjectProperty":
        case "ObjectTypeInternalSlot":
        case "ObjectTypeCallProperty":
        case "ObjectTypeIndexer":
        case "ObjectTypeProperty":
        case "ObjectTypeSpreadProperty":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isMethod(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ObjectMethod":
        case "ClassMethod":
        case "ClassPrivateMethod":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isObjectMember(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ObjectMethod":
        case "ObjectProperty":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isProperty(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ObjectProperty":
        case "ClassProperty":
        case "ClassAccessorProperty":
        case "ClassPrivateProperty":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isUnaryLike(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "UnaryExpression":
        case "SpreadElement":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPattern(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "AssignmentPattern":
        case "ArrayPattern":
        case "ObjectPattern":
          break;
        case "Placeholder":
          if (node.expectedNode === "Pattern")
            break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isClass(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ClassExpression":
        case "ClassDeclaration":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isImportOrExportDeclaration(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ExportAllDeclaration":
        case "ExportDefaultDeclaration":
        case "ExportNamedDeclaration":
        case "ImportDeclaration":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isExportDeclaration(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ExportAllDeclaration":
        case "ExportDefaultDeclaration":
        case "ExportNamedDeclaration":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isModuleSpecifier(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ExportSpecifier":
        case "ImportDefaultSpecifier":
        case "ImportNamespaceSpecifier":
        case "ImportSpecifier":
        case "ExportNamespaceSpecifier":
        case "ExportDefaultSpecifier":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isAccessor(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ClassAccessorProperty":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isPrivate(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "ClassPrivateProperty":
        case "ClassPrivateMethod":
        case "PrivateName":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFlow(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "AnyTypeAnnotation":
        case "ArrayTypeAnnotation":
        case "BooleanTypeAnnotation":
        case "BooleanLiteralTypeAnnotation":
        case "NullLiteralTypeAnnotation":
        case "ClassImplements":
        case "DeclareClass":
        case "DeclareFunction":
        case "DeclareInterface":
        case "DeclareModule":
        case "DeclareModuleExports":
        case "DeclareTypeAlias":
        case "DeclareOpaqueType":
        case "DeclareVariable":
        case "DeclareExportDeclaration":
        case "DeclareExportAllDeclaration":
        case "DeclaredPredicate":
        case "ExistsTypeAnnotation":
        case "FunctionTypeAnnotation":
        case "FunctionTypeParam":
        case "GenericTypeAnnotation":
        case "InferredPredicate":
        case "InterfaceExtends":
        case "InterfaceDeclaration":
        case "InterfaceTypeAnnotation":
        case "IntersectionTypeAnnotation":
        case "MixedTypeAnnotation":
        case "EmptyTypeAnnotation":
        case "NullableTypeAnnotation":
        case "NumberLiteralTypeAnnotation":
        case "NumberTypeAnnotation":
        case "ObjectTypeAnnotation":
        case "ObjectTypeInternalSlot":
        case "ObjectTypeCallProperty":
        case "ObjectTypeIndexer":
        case "ObjectTypeProperty":
        case "ObjectTypeSpreadProperty":
        case "OpaqueType":
        case "QualifiedTypeIdentifier":
        case "StringLiteralTypeAnnotation":
        case "StringTypeAnnotation":
        case "SymbolTypeAnnotation":
        case "ThisTypeAnnotation":
        case "TupleTypeAnnotation":
        case "TypeofTypeAnnotation":
        case "TypeAlias":
        case "TypeAnnotation":
        case "TypeCastExpression":
        case "TypeParameter":
        case "TypeParameterDeclaration":
        case "TypeParameterInstantiation":
        case "UnionTypeAnnotation":
        case "Variance":
        case "VoidTypeAnnotation":
        case "EnumDeclaration":
        case "EnumBooleanBody":
        case "EnumNumberBody":
        case "EnumStringBody":
        case "EnumSymbolBody":
        case "EnumBooleanMember":
        case "EnumNumberMember":
        case "EnumStringMember":
        case "EnumDefaultedMember":
        case "IndexedAccessType":
        case "OptionalIndexedAccessType":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFlowType(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "AnyTypeAnnotation":
        case "ArrayTypeAnnotation":
        case "BooleanTypeAnnotation":
        case "BooleanLiteralTypeAnnotation":
        case "NullLiteralTypeAnnotation":
        case "ExistsTypeAnnotation":
        case "FunctionTypeAnnotation":
        case "GenericTypeAnnotation":
        case "InterfaceTypeAnnotation":
        case "IntersectionTypeAnnotation":
        case "MixedTypeAnnotation":
        case "EmptyTypeAnnotation":
        case "NullableTypeAnnotation":
        case "NumberLiteralTypeAnnotation":
        case "NumberTypeAnnotation":
        case "ObjectTypeAnnotation":
        case "StringLiteralTypeAnnotation":
        case "StringTypeAnnotation":
        case "SymbolTypeAnnotation":
        case "ThisTypeAnnotation":
        case "TupleTypeAnnotation":
        case "TypeofTypeAnnotation":
        case "UnionTypeAnnotation":
        case "VoidTypeAnnotation":
        case "IndexedAccessType":
        case "OptionalIndexedAccessType":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFlowBaseAnnotation(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "AnyTypeAnnotation":
        case "BooleanTypeAnnotation":
        case "NullLiteralTypeAnnotation":
        case "MixedTypeAnnotation":
        case "EmptyTypeAnnotation":
        case "NumberTypeAnnotation":
        case "StringTypeAnnotation":
        case "SymbolTypeAnnotation":
        case "ThisTypeAnnotation":
        case "VoidTypeAnnotation":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFlowDeclaration(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "DeclareClass":
        case "DeclareFunction":
        case "DeclareInterface":
        case "DeclareModule":
        case "DeclareModuleExports":
        case "DeclareTypeAlias":
        case "DeclareOpaqueType":
        case "DeclareVariable":
        case "DeclareExportDeclaration":
        case "DeclareExportAllDeclaration":
        case "InterfaceDeclaration":
        case "OpaqueType":
        case "TypeAlias":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isFlowPredicate(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "DeclaredPredicate":
        case "InferredPredicate":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumBody(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "EnumBooleanBody":
        case "EnumNumberBody":
        case "EnumStringBody":
        case "EnumSymbolBody":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isEnumMember(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "EnumBooleanMember":
        case "EnumNumberMember":
        case "EnumStringMember":
        case "EnumDefaultedMember":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isJSX(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "JSXAttribute":
        case "JSXClosingElement":
        case "JSXElement":
        case "JSXEmptyExpression":
        case "JSXExpressionContainer":
        case "JSXSpreadChild":
        case "JSXIdentifier":
        case "JSXMemberExpression":
        case "JSXNamespacedName":
        case "JSXOpeningElement":
        case "JSXSpreadAttribute":
        case "JSXText":
        case "JSXFragment":
        case "JSXOpeningFragment":
        case "JSXClosingFragment":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isMiscellaneous(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "Noop":
        case "Placeholder":
        case "V8IntrinsicIdentifier":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTypeScript(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "TSParameterProperty":
        case "TSDeclareFunction":
        case "TSDeclareMethod":
        case "TSQualifiedName":
        case "TSCallSignatureDeclaration":
        case "TSConstructSignatureDeclaration":
        case "TSPropertySignature":
        case "TSMethodSignature":
        case "TSIndexSignature":
        case "TSAnyKeyword":
        case "TSBooleanKeyword":
        case "TSBigIntKeyword":
        case "TSIntrinsicKeyword":
        case "TSNeverKeyword":
        case "TSNullKeyword":
        case "TSNumberKeyword":
        case "TSObjectKeyword":
        case "TSStringKeyword":
        case "TSSymbolKeyword":
        case "TSUndefinedKeyword":
        case "TSUnknownKeyword":
        case "TSVoidKeyword":
        case "TSThisType":
        case "TSFunctionType":
        case "TSConstructorType":
        case "TSTypeReference":
        case "TSTypePredicate":
        case "TSTypeQuery":
        case "TSTypeLiteral":
        case "TSArrayType":
        case "TSTupleType":
        case "TSOptionalType":
        case "TSRestType":
        case "TSNamedTupleMember":
        case "TSUnionType":
        case "TSIntersectionType":
        case "TSConditionalType":
        case "TSInferType":
        case "TSParenthesizedType":
        case "TSTypeOperator":
        case "TSIndexedAccessType":
        case "TSMappedType":
        case "TSLiteralType":
        case "TSExpressionWithTypeArguments":
        case "TSInterfaceDeclaration":
        case "TSInterfaceBody":
        case "TSTypeAliasDeclaration":
        case "TSInstantiationExpression":
        case "TSAsExpression":
        case "TSSatisfiesExpression":
        case "TSTypeAssertion":
        case "TSEnumDeclaration":
        case "TSEnumMember":
        case "TSModuleDeclaration":
        case "TSModuleBlock":
        case "TSImportType":
        case "TSImportEqualsDeclaration":
        case "TSExternalModuleReference":
        case "TSNonNullExpression":
        case "TSExportAssignment":
        case "TSNamespaceExportDeclaration":
        case "TSTypeAnnotation":
        case "TSTypeParameterInstantiation":
        case "TSTypeParameterDeclaration":
        case "TSTypeParameter":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSTypeElement(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "TSCallSignatureDeclaration":
        case "TSConstructSignatureDeclaration":
        case "TSPropertySignature":
        case "TSMethodSignature":
        case "TSIndexSignature":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSType2(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "TSAnyKeyword":
        case "TSBooleanKeyword":
        case "TSBigIntKeyword":
        case "TSIntrinsicKeyword":
        case "TSNeverKeyword":
        case "TSNullKeyword":
        case "TSNumberKeyword":
        case "TSObjectKeyword":
        case "TSStringKeyword":
        case "TSSymbolKeyword":
        case "TSUndefinedKeyword":
        case "TSUnknownKeyword":
        case "TSVoidKeyword":
        case "TSThisType":
        case "TSFunctionType":
        case "TSConstructorType":
        case "TSTypeReference":
        case "TSTypePredicate":
        case "TSTypeQuery":
        case "TSTypeLiteral":
        case "TSArrayType":
        case "TSTupleType":
        case "TSOptionalType":
        case "TSRestType":
        case "TSUnionType":
        case "TSIntersectionType":
        case "TSConditionalType":
        case "TSInferType":
        case "TSParenthesizedType":
        case "TSTypeOperator":
        case "TSIndexedAccessType":
        case "TSMappedType":
        case "TSLiteralType":
        case "TSExpressionWithTypeArguments":
        case "TSImportType":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isTSBaseType(node, opts) {
      if (!node)
        return false;
      switch (node.type) {
        case "TSAnyKeyword":
        case "TSBooleanKeyword":
        case "TSBigIntKeyword":
        case "TSIntrinsicKeyword":
        case "TSNeverKeyword":
        case "TSNullKeyword":
        case "TSNumberKeyword":
        case "TSObjectKeyword":
        case "TSStringKeyword":
        case "TSSymbolKeyword":
        case "TSUndefinedKeyword":
        case "TSUnknownKeyword":
        case "TSVoidKeyword":
        case "TSThisType":
        case "TSLiteralType":
          break;
        default:
          return false;
      }
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isNumberLiteral(node, opts) {
      (0, _deprecationWarning.default)("isNumberLiteral", "isNumericLiteral");
      if (!node)
        return false;
      if (node.type !== "NumberLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isRegexLiteral(node, opts) {
      (0, _deprecationWarning.default)("isRegexLiteral", "isRegExpLiteral");
      if (!node)
        return false;
      if (node.type !== "RegexLiteral")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isRestProperty(node, opts) {
      (0, _deprecationWarning.default)("isRestProperty", "isRestElement");
      if (!node)
        return false;
      if (node.type !== "RestProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isSpreadProperty(node, opts) {
      (0, _deprecationWarning.default)("isSpreadProperty", "isSpreadElement");
      if (!node)
        return false;
      if (node.type !== "SpreadProperty")
        return false;
      return opts == null || (0, _shallowEqual.default)(node, opts);
    }
    function isModuleDeclaration(node, opts) {
      (0, _deprecationWarning.default)("isModuleDeclaration", "isImportOrExportDeclaration");
      return isImportOrExportDeclaration(node, opts);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/matchesPattern.js
var require_matchesPattern2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/matchesPattern.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = matchesPattern;
    var _index = require_generated6();
    function matchesPattern(member, match, allowPartial) {
      if (!(0, _index.isMemberExpression)(member))
        return false;
      const parts = Array.isArray(match) ? match : match.split(".");
      const nodes = [];
      let node;
      for (node = member; (0, _index.isMemberExpression)(node); node = node.object) {
        nodes.push(node.property);
      }
      nodes.push(node);
      if (nodes.length < parts.length)
        return false;
      if (!allowPartial && nodes.length > parts.length)
        return false;
      for (let i = 0, j = nodes.length - 1; i < parts.length; i++, j--) {
        const node2 = nodes[j];
        let value2;
        if ((0, _index.isIdentifier)(node2)) {
          value2 = node2.name;
        } else if ((0, _index.isStringLiteral)(node2)) {
          value2 = node2.value;
        } else if ((0, _index.isThisExpression)(node2)) {
          value2 = "this";
        } else {
          return false;
        }
        if (parts[i] !== value2)
          return false;
      }
      return true;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js
var require_buildMatchMemberExpression2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = buildMatchMemberExpression;
    var _matchesPattern = require_matchesPattern2();
    function buildMatchMemberExpression(match, allowPartial) {
      const parts = match.split(".");
      return (member) => (0, _matchesPattern.default)(member, parts, allowPartial);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/react/isReactComponent.js
var require_isReactComponent2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/react/isReactComponent.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _buildMatchMemberExpression = require_buildMatchMemberExpression2();
    var isReactComponent = (0, _buildMatchMemberExpression.default)("React.Component");
    var _default = isReactComponent;
    exports.default = _default;
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/react/isCompatTag.js
var require_isCompatTag2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/react/isCompatTag.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isCompatTag;
    function isCompatTag(tagName) {
      return !!tagName && /^[a-z]/.test(tagName);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isType.js
var require_isType2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isType;
    var _index = require_definitions2();
    function isType(nodeType, targetType) {
      if (nodeType === targetType)
        return true;
      if (nodeType == null)
        return false;
      if (_index.ALIAS_KEYS[targetType])
        return false;
      const aliases = _index.FLIPPED_ALIAS_KEYS[targetType];
      if (aliases) {
        if (aliases[0] === nodeType)
          return true;
        for (const alias of aliases) {
          if (nodeType === alias)
            return true;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isPlaceholderType.js
var require_isPlaceholderType2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isPlaceholderType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isPlaceholderType;
    var _index = require_definitions2();
    function isPlaceholderType(placeholderType, targetType) {
      if (placeholderType === targetType)
        return true;
      const aliases = _index.PLACEHOLDERS_ALIAS[placeholderType];
      if (aliases) {
        for (const alias of aliases) {
          if (targetType === alias)
            return true;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/is.js
var require_is2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/is.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = is;
    var _shallowEqual = require_shallowEqual2();
    var _isType = require_isType2();
    var _isPlaceholderType = require_isPlaceholderType2();
    var _index = require_definitions2();
    function is(type, node, opts) {
      if (!node)
        return false;
      const matches = (0, _isType.default)(node.type, type);
      if (!matches) {
        if (!opts && node.type === "Placeholder" && type in _index.FLIPPED_ALIAS_KEYS) {
          return (0, _isPlaceholderType.default)(node.expectedNode, type);
        }
        return false;
      }
      if (typeof opts === "undefined") {
        return true;
      } else {
        return (0, _shallowEqual.default)(node, opts);
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/identifier.js
var require_identifier2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/identifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isIdentifierChar = isIdentifierChar;
    exports.isIdentifierName = isIdentifierName;
    exports.isIdentifierStart = isIdentifierStart;
    var nonASCIIidentifierStartChars = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC";
    var nonASCIIidentifierChars = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F";
    var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
    var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
    nonASCIIidentifierStartChars = nonASCIIidentifierChars = null;
    var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
    var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
    function isInAstralSet(code, set) {
      let pos = 65536;
      for (let i = 0, length = set.length; i < length; i += 2) {
        pos += set[i];
        if (pos > code)
          return false;
        pos += set[i + 1];
        if (pos >= code)
          return true;
      }
      return false;
    }
    function isIdentifierStart(code) {
      if (code < 65)
        return code === 36;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifierStart.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes);
    }
    function isIdentifierChar(code) {
      if (code < 48)
        return code === 36;
      if (code < 58)
        return true;
      if (code < 65)
        return false;
      if (code <= 90)
        return true;
      if (code < 97)
        return code === 95;
      if (code <= 122)
        return true;
      if (code <= 65535) {
        return code >= 170 && nonASCIIidentifier.test(String.fromCharCode(code));
      }
      return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
    }
    function isIdentifierName(name) {
      let isFirst = true;
      for (let i = 0; i < name.length; i++) {
        let cp = name.charCodeAt(i);
        if ((cp & 64512) === 55296 && i + 1 < name.length) {
          const trail = name.charCodeAt(++i);
          if ((trail & 64512) === 56320) {
            cp = 65536 + ((cp & 1023) << 10) + (trail & 1023);
          }
        }
        if (isFirst) {
          isFirst = false;
          if (!isIdentifierStart(cp)) {
            return false;
          }
        } else if (!isIdentifierChar(cp)) {
          return false;
        }
      }
      return !isFirst;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/keyword.js
var require_keyword4 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/keyword.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.isKeyword = isKeyword;
    exports.isReservedWord = isReservedWord;
    exports.isStrictBindOnlyReservedWord = isStrictBindOnlyReservedWord;
    exports.isStrictBindReservedWord = isStrictBindReservedWord;
    exports.isStrictReservedWord = isStrictReservedWord;
    var reservedWords = {
      keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"],
      strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"],
      strictBind: ["eval", "arguments"]
    };
    var keywords = new Set(reservedWords.keyword);
    var reservedWordsStrictSet = new Set(reservedWords.strict);
    var reservedWordsStrictBindSet = new Set(reservedWords.strictBind);
    function isReservedWord(word, inModule) {
      return inModule && word === "await" || word === "enum";
    }
    function isStrictReservedWord(word, inModule) {
      return isReservedWord(word, inModule) || reservedWordsStrictSet.has(word);
    }
    function isStrictBindOnlyReservedWord(word) {
      return reservedWordsStrictBindSet.has(word);
    }
    function isStrictBindReservedWord(word, inModule) {
      return isStrictReservedWord(word, inModule) || isStrictBindOnlyReservedWord(word);
    }
    function isKeyword(word) {
      return keywords.has(word);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/index.js
var require_lib29 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/helper-validator-identifier/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "isIdentifierChar", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierChar;
      }
    });
    Object.defineProperty(exports, "isIdentifierName", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierName;
      }
    });
    Object.defineProperty(exports, "isIdentifierStart", {
      enumerable: true,
      get: function() {
        return _identifier.isIdentifierStart;
      }
    });
    Object.defineProperty(exports, "isKeyword", {
      enumerable: true,
      get: function() {
        return _keyword.isKeyword;
      }
    });
    Object.defineProperty(exports, "isReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictBindOnlyReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictBindOnlyReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictBindReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictBindReservedWord;
      }
    });
    Object.defineProperty(exports, "isStrictReservedWord", {
      enumerable: true,
      get: function() {
        return _keyword.isStrictReservedWord;
      }
    });
    var _identifier = require_identifier2();
    var _keyword = require_keyword4();
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isValidIdentifier.js
var require_isValidIdentifier2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isValidIdentifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isValidIdentifier;
    var _helperValidatorIdentifier = require_lib29();
    function isValidIdentifier(name, reserved = true) {
      if (typeof name !== "string")
        return false;
      if (reserved) {
        if ((0, _helperValidatorIdentifier.isKeyword)(name) || (0, _helperValidatorIdentifier.isStrictReservedWord)(name, true)) {
          return false;
        }
      }
      return (0, _helperValidatorIdentifier.isIdentifierName)(name);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/helper-string-parser/lib/index.js
var require_lib30 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/helper-string-parser/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.readCodePoint = readCodePoint;
    exports.readInt = readInt;
    exports.readStringContents = readStringContents;
    var _isDigit = function isDigit(code) {
      return code >= 48 && code <= 57;
    };
    var forbiddenNumericSeparatorSiblings = {
      decBinOct: /* @__PURE__ */ new Set([46, 66, 69, 79, 95, 98, 101, 111]),
      hex: /* @__PURE__ */ new Set([46, 88, 95, 120])
    };
    var isAllowedNumericSeparatorSibling = {
      bin: (ch) => ch === 48 || ch === 49,
      oct: (ch) => ch >= 48 && ch <= 55,
      dec: (ch) => ch >= 48 && ch <= 57,
      hex: (ch) => ch >= 48 && ch <= 57 || ch >= 65 && ch <= 70 || ch >= 97 && ch <= 102
    };
    function readStringContents(type, input, pos, lineStart, curLine, errors) {
      const initialPos = pos;
      const initialLineStart = lineStart;
      const initialCurLine = curLine;
      let out = "";
      let firstInvalidLoc = null;
      let chunkStart = pos;
      const {
        length
      } = input;
      for (; ; ) {
        if (pos >= length) {
          errors.unterminated(initialPos, initialLineStart, initialCurLine);
          out += input.slice(chunkStart, pos);
          break;
        }
        const ch = input.charCodeAt(pos);
        if (isStringEnd(type, ch, input, pos)) {
          out += input.slice(chunkStart, pos);
          break;
        }
        if (ch === 92) {
          out += input.slice(chunkStart, pos);
          const res = readEscapedChar(input, pos, lineStart, curLine, type === "template", errors);
          if (res.ch === null && !firstInvalidLoc) {
            firstInvalidLoc = {
              pos,
              lineStart,
              curLine
            };
          } else {
            out += res.ch;
          }
          ({
            pos,
            lineStart,
            curLine
          } = res);
          chunkStart = pos;
        } else if (ch === 8232 || ch === 8233) {
          ++pos;
          ++curLine;
          lineStart = pos;
        } else if (ch === 10 || ch === 13) {
          if (type === "template") {
            out += input.slice(chunkStart, pos) + "\n";
            ++pos;
            if (ch === 13 && input.charCodeAt(pos) === 10) {
              ++pos;
            }
            ++curLine;
            chunkStart = lineStart = pos;
          } else {
            errors.unterminated(initialPos, initialLineStart, initialCurLine);
          }
        } else {
          ++pos;
        }
      }
      return {
        pos,
        str: out,
        firstInvalidLoc,
        lineStart,
        curLine,
        containsInvalid: !!firstInvalidLoc
      };
    }
    function isStringEnd(type, ch, input, pos) {
      if (type === "template") {
        return ch === 96 || ch === 36 && input.charCodeAt(pos + 1) === 123;
      }
      return ch === (type === "double" ? 34 : 39);
    }
    function readEscapedChar(input, pos, lineStart, curLine, inTemplate, errors) {
      const throwOnInvalid = !inTemplate;
      pos++;
      const res = (ch2) => ({
        pos,
        ch: ch2,
        lineStart,
        curLine
      });
      const ch = input.charCodeAt(pos++);
      switch (ch) {
        case 110:
          return res("\n");
        case 114:
          return res("\r");
        case 120: {
          let code;
          ({
            code,
            pos
          } = readHexChar(input, pos, lineStart, curLine, 2, false, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCharCode(code));
        }
        case 117: {
          let code;
          ({
            code,
            pos
          } = readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors));
          return res(code === null ? null : String.fromCodePoint(code));
        }
        case 116:
          return res("	");
        case 98:
          return res("\b");
        case 118:
          return res("\v");
        case 102:
          return res("\f");
        case 13:
          if (input.charCodeAt(pos) === 10) {
            ++pos;
          }
        case 10:
          lineStart = pos;
          ++curLine;
        case 8232:
        case 8233:
          return res("");
        case 56:
        case 57:
          if (inTemplate) {
            return res(null);
          } else {
            errors.strictNumericEscape(pos - 1, lineStart, curLine);
          }
        default:
          if (ch >= 48 && ch <= 55) {
            const startPos = pos - 1;
            const match = input.slice(startPos, pos + 2).match(/^[0-7]+/);
            let octalStr = match[0];
            let octal = parseInt(octalStr, 8);
            if (octal > 255) {
              octalStr = octalStr.slice(0, -1);
              octal = parseInt(octalStr, 8);
            }
            pos += octalStr.length - 1;
            const next = input.charCodeAt(pos);
            if (octalStr !== "0" || next === 56 || next === 57) {
              if (inTemplate) {
                return res(null);
              } else {
                errors.strictNumericEscape(startPos, lineStart, curLine);
              }
            }
            return res(String.fromCharCode(octal));
          }
          return res(String.fromCharCode(ch));
      }
    }
    function readHexChar(input, pos, lineStart, curLine, len, forceLen, throwOnInvalid, errors) {
      const initialPos = pos;
      let n;
      ({
        n,
        pos
      } = readInt(input, pos, lineStart, curLine, 16, len, forceLen, false, errors, !throwOnInvalid));
      if (n === null) {
        if (throwOnInvalid) {
          errors.invalidEscapeSequence(initialPos, lineStart, curLine);
        } else {
          pos = initialPos - 1;
        }
      }
      return {
        code: n,
        pos
      };
    }
    function readInt(input, pos, lineStart, curLine, radix, len, forceLen, allowNumSeparator, errors, bailOnError) {
      const start = pos;
      const forbiddenSiblings = radix === 16 ? forbiddenNumericSeparatorSiblings.hex : forbiddenNumericSeparatorSiblings.decBinOct;
      const isAllowedSibling = radix === 16 ? isAllowedNumericSeparatorSibling.hex : radix === 10 ? isAllowedNumericSeparatorSibling.dec : radix === 8 ? isAllowedNumericSeparatorSibling.oct : isAllowedNumericSeparatorSibling.bin;
      let invalid = false;
      let total = 0;
      for (let i = 0, e = len == null ? Infinity : len; i < e; ++i) {
        const code = input.charCodeAt(pos);
        let val;
        if (code === 95 && allowNumSeparator !== "bail") {
          const prev = input.charCodeAt(pos - 1);
          const next = input.charCodeAt(pos + 1);
          if (!allowNumSeparator) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.numericSeparatorInEscapeSequence(pos, lineStart, curLine);
          } else if (Number.isNaN(next) || !isAllowedSibling(next) || forbiddenSiblings.has(prev) || forbiddenSiblings.has(next)) {
            if (bailOnError)
              return {
                n: null,
                pos
              };
            errors.unexpectedNumericSeparator(pos, lineStart, curLine);
          }
          ++pos;
          continue;
        }
        if (code >= 97) {
          val = code - 97 + 10;
        } else if (code >= 65) {
          val = code - 65 + 10;
        } else if (_isDigit(code)) {
          val = code - 48;
        } else {
          val = Infinity;
        }
        if (val >= radix) {
          if (val <= 9 && bailOnError) {
            return {
              n: null,
              pos
            };
          } else if (val <= 9 && errors.invalidDigit(pos, lineStart, curLine, radix)) {
            val = 0;
          } else if (forceLen) {
            val = 0;
            invalid = true;
          } else {
            break;
          }
        }
        ++pos;
        total = total * radix + val;
      }
      if (pos === start || len != null && pos - start !== len || invalid) {
        return {
          n: null,
          pos
        };
      }
      return {
        n: total,
        pos
      };
    }
    function readCodePoint(input, pos, lineStart, curLine, throwOnInvalid, errors) {
      const ch = input.charCodeAt(pos);
      let code;
      if (ch === 123) {
        ++pos;
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, input.indexOf("}", pos) - pos, true, throwOnInvalid, errors));
        ++pos;
        if (code !== null && code > 1114111) {
          if (throwOnInvalid) {
            errors.invalidCodePoint(pos, lineStart, curLine);
          } else {
            return {
              code: null,
              pos
            };
          }
        }
      } else {
        ({
          code,
          pos
        } = readHexChar(input, pos, lineStart, curLine, 4, false, throwOnInvalid, errors));
      }
      return {
        code,
        pos
      };
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/constants/index.js
var require_constants3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/constants/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.UPDATE_OPERATORS = exports.UNARY_OPERATORS = exports.STRING_UNARY_OPERATORS = exports.STATEMENT_OR_BLOCK_KEYS = exports.NUMBER_UNARY_OPERATORS = exports.NUMBER_BINARY_OPERATORS = exports.NOT_LOCAL_BINDING = exports.LOGICAL_OPERATORS = exports.INHERIT_KEYS = exports.FOR_INIT_KEYS = exports.FLATTENABLE_KEYS = exports.EQUALITY_BINARY_OPERATORS = exports.COMPARISON_BINARY_OPERATORS = exports.COMMENT_KEYS = exports.BOOLEAN_UNARY_OPERATORS = exports.BOOLEAN_NUMBER_BINARY_OPERATORS = exports.BOOLEAN_BINARY_OPERATORS = exports.BLOCK_SCOPED_SYMBOL = exports.BINARY_OPERATORS = exports.ASSIGNMENT_OPERATORS = void 0;
    var STATEMENT_OR_BLOCK_KEYS = ["consequent", "body", "alternate"];
    exports.STATEMENT_OR_BLOCK_KEYS = STATEMENT_OR_BLOCK_KEYS;
    var FLATTENABLE_KEYS = ["body", "expressions"];
    exports.FLATTENABLE_KEYS = FLATTENABLE_KEYS;
    var FOR_INIT_KEYS = ["left", "init"];
    exports.FOR_INIT_KEYS = FOR_INIT_KEYS;
    var COMMENT_KEYS = ["leadingComments", "trailingComments", "innerComments"];
    exports.COMMENT_KEYS = COMMENT_KEYS;
    var LOGICAL_OPERATORS = ["||", "&&", "??"];
    exports.LOGICAL_OPERATORS = LOGICAL_OPERATORS;
    var UPDATE_OPERATORS = ["++", "--"];
    exports.UPDATE_OPERATORS = UPDATE_OPERATORS;
    var BOOLEAN_NUMBER_BINARY_OPERATORS = [">", "<", ">=", "<="];
    exports.BOOLEAN_NUMBER_BINARY_OPERATORS = BOOLEAN_NUMBER_BINARY_OPERATORS;
    var EQUALITY_BINARY_OPERATORS = ["==", "===", "!=", "!=="];
    exports.EQUALITY_BINARY_OPERATORS = EQUALITY_BINARY_OPERATORS;
    var COMPARISON_BINARY_OPERATORS = [...EQUALITY_BINARY_OPERATORS, "in", "instanceof"];
    exports.COMPARISON_BINARY_OPERATORS = COMPARISON_BINARY_OPERATORS;
    var BOOLEAN_BINARY_OPERATORS = [...COMPARISON_BINARY_OPERATORS, ...BOOLEAN_NUMBER_BINARY_OPERATORS];
    exports.BOOLEAN_BINARY_OPERATORS = BOOLEAN_BINARY_OPERATORS;
    var NUMBER_BINARY_OPERATORS = ["-", "/", "%", "*", "**", "&", "|", ">>", ">>>", "<<", "^"];
    exports.NUMBER_BINARY_OPERATORS = NUMBER_BINARY_OPERATORS;
    var BINARY_OPERATORS = ["+", ...NUMBER_BINARY_OPERATORS, ...BOOLEAN_BINARY_OPERATORS, "|>"];
    exports.BINARY_OPERATORS = BINARY_OPERATORS;
    var ASSIGNMENT_OPERATORS = ["=", "+=", ...NUMBER_BINARY_OPERATORS.map((op) => op + "="), ...LOGICAL_OPERATORS.map((op) => op + "=")];
    exports.ASSIGNMENT_OPERATORS = ASSIGNMENT_OPERATORS;
    var BOOLEAN_UNARY_OPERATORS = ["delete", "!"];
    exports.BOOLEAN_UNARY_OPERATORS = BOOLEAN_UNARY_OPERATORS;
    var NUMBER_UNARY_OPERATORS = ["+", "-", "~"];
    exports.NUMBER_UNARY_OPERATORS = NUMBER_UNARY_OPERATORS;
    var STRING_UNARY_OPERATORS = ["typeof"];
    exports.STRING_UNARY_OPERATORS = STRING_UNARY_OPERATORS;
    var UNARY_OPERATORS = ["void", "throw", ...BOOLEAN_UNARY_OPERATORS, ...NUMBER_UNARY_OPERATORS, ...STRING_UNARY_OPERATORS];
    exports.UNARY_OPERATORS = UNARY_OPERATORS;
    var INHERIT_KEYS = {
      optional: ["typeAnnotation", "typeParameters", "returnType"],
      force: ["start", "loc", "end"]
    };
    exports.INHERIT_KEYS = INHERIT_KEYS;
    var BLOCK_SCOPED_SYMBOL = Symbol.for("var used to be block scoped");
    exports.BLOCK_SCOPED_SYMBOL = BLOCK_SCOPED_SYMBOL;
    var NOT_LOCAL_BINDING = Symbol.for("should not be considered a local binding");
    exports.NOT_LOCAL_BINDING = NOT_LOCAL_BINDING;
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/utils.js
var require_utils9 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/utils.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.VISITOR_KEYS = exports.NODE_PARENT_VALIDATIONS = exports.NODE_FIELDS = exports.FLIPPED_ALIAS_KEYS = exports.DEPRECATED_KEYS = exports.BUILDER_KEYS = exports.ALIAS_KEYS = void 0;
    exports.arrayOf = arrayOf;
    exports.arrayOfType = arrayOfType;
    exports.assertEach = assertEach;
    exports.assertNodeOrValueType = assertNodeOrValueType;
    exports.assertNodeType = assertNodeType;
    exports.assertOneOf = assertOneOf;
    exports.assertOptionalChainStart = assertOptionalChainStart;
    exports.assertShape = assertShape;
    exports.assertValueType = assertValueType;
    exports.chain = chain;
    exports.default = defineType;
    exports.defineAliasedType = defineAliasedType;
    exports.typeIs = typeIs;
    exports.validate = validate;
    exports.validateArrayOfType = validateArrayOfType;
    exports.validateOptional = validateOptional;
    exports.validateOptionalType = validateOptionalType;
    exports.validateType = validateType;
    var _is = require_is2();
    var _validate = require_validate3();
    var VISITOR_KEYS = {};
    exports.VISITOR_KEYS = VISITOR_KEYS;
    var ALIAS_KEYS = {};
    exports.ALIAS_KEYS = ALIAS_KEYS;
    var FLIPPED_ALIAS_KEYS = {};
    exports.FLIPPED_ALIAS_KEYS = FLIPPED_ALIAS_KEYS;
    var NODE_FIELDS = {};
    exports.NODE_FIELDS = NODE_FIELDS;
    var BUILDER_KEYS = {};
    exports.BUILDER_KEYS = BUILDER_KEYS;
    var DEPRECATED_KEYS = {};
    exports.DEPRECATED_KEYS = DEPRECATED_KEYS;
    var NODE_PARENT_VALIDATIONS = {};
    exports.NODE_PARENT_VALIDATIONS = NODE_PARENT_VALIDATIONS;
    function getType(val) {
      if (Array.isArray(val)) {
        return "array";
      } else if (val === null) {
        return "null";
      } else {
        return typeof val;
      }
    }
    function validate(validate2) {
      return {
        validate: validate2
      };
    }
    function typeIs(typeName) {
      return typeof typeName === "string" ? assertNodeType(typeName) : assertNodeType(...typeName);
    }
    function validateType(typeName) {
      return validate(typeIs(typeName));
    }
    function validateOptional(validate2) {
      return {
        validate: validate2,
        optional: true
      };
    }
    function validateOptionalType(typeName) {
      return {
        validate: typeIs(typeName),
        optional: true
      };
    }
    function arrayOf(elementType) {
      return chain(assertValueType("array"), assertEach(elementType));
    }
    function arrayOfType(typeName) {
      return arrayOf(typeIs(typeName));
    }
    function validateArrayOfType(typeName) {
      return validate(arrayOfType(typeName));
    }
    function assertEach(callback) {
      function validator(node, key, val) {
        if (!Array.isArray(val))
          return;
        for (let i = 0; i < val.length; i++) {
          const subkey = `${key}[${i}]`;
          const v = val[i];
          callback(node, subkey, v);
          if (process.env.BABEL_TYPES_8_BREAKING)
            (0, _validate.validateChild)(node, subkey, v);
        }
      }
      validator.each = callback;
      return validator;
    }
    function assertOneOf(...values2) {
      function validate2(node, key, val) {
        if (values2.indexOf(val) < 0) {
          throw new TypeError(`Property ${key} expected value to be one of ${JSON.stringify(values2)} but got ${JSON.stringify(val)}`);
        }
      }
      validate2.oneOf = values2;
      return validate2;
    }
    function assertNodeType(...types) {
      function validate2(node, key, val) {
        for (const type of types) {
          if ((0, _is.default)(type, val)) {
            (0, _validate.validateChild)(node, key, val);
            return;
          }
        }
        throw new TypeError(`Property ${key} of ${node.type} expected node to be of a type ${JSON.stringify(types)} but instead got ${JSON.stringify(val == null ? void 0 : val.type)}`);
      }
      validate2.oneOfNodeTypes = types;
      return validate2;
    }
    function assertNodeOrValueType(...types) {
      function validate2(node, key, val) {
        for (const type of types) {
          if (getType(val) === type || (0, _is.default)(type, val)) {
            (0, _validate.validateChild)(node, key, val);
            return;
          }
        }
        throw new TypeError(`Property ${key} of ${node.type} expected node to be of a type ${JSON.stringify(types)} but instead got ${JSON.stringify(val == null ? void 0 : val.type)}`);
      }
      validate2.oneOfNodeOrValueTypes = types;
      return validate2;
    }
    function assertValueType(type) {
      function validate2(node, key, val) {
        const valid = getType(val) === type;
        if (!valid) {
          throw new TypeError(`Property ${key} expected type of ${type} but got ${getType(val)}`);
        }
      }
      validate2.type = type;
      return validate2;
    }
    function assertShape(shape) {
      function validate2(node, key, val) {
        const errors = [];
        for (const property of Object.keys(shape)) {
          try {
            (0, _validate.validateField)(node, property, val[property], shape[property]);
          } catch (error) {
            if (error instanceof TypeError) {
              errors.push(error.message);
              continue;
            }
            throw error;
          }
        }
        if (errors.length) {
          throw new TypeError(`Property ${key} of ${node.type} expected to have the following:
${errors.join("\n")}`);
        }
      }
      validate2.shapeOf = shape;
      return validate2;
    }
    function assertOptionalChainStart() {
      function validate2(node) {
        var _current;
        let current = node;
        while (node) {
          const {
            type
          } = current;
          if (type === "OptionalCallExpression") {
            if (current.optional)
              return;
            current = current.callee;
            continue;
          }
          if (type === "OptionalMemberExpression") {
            if (current.optional)
              return;
            current = current.object;
            continue;
          }
          break;
        }
        throw new TypeError(`Non-optional ${node.type} must chain from an optional OptionalMemberExpression or OptionalCallExpression. Found chain from ${(_current = current) == null ? void 0 : _current.type}`);
      }
      return validate2;
    }
    function chain(...fns) {
      function validate2(...args) {
        for (const fn of fns) {
          fn(...args);
        }
      }
      validate2.chainOf = fns;
      if (fns.length >= 2 && "type" in fns[0] && fns[0].type === "array" && !("each" in fns[1])) {
        throw new Error(`An assertValueType("array") validator can only be followed by an assertEach(...) validator.`);
      }
      return validate2;
    }
    var validTypeOpts = ["aliases", "builder", "deprecatedAlias", "fields", "inherits", "visitor", "validate"];
    var validFieldKeys = ["default", "optional", "deprecated", "validate"];
    var store = {};
    function defineAliasedType(...aliases) {
      return (type, opts = {}) => {
        let defined = opts.aliases;
        if (!defined) {
          var _store$opts$inherits$, _defined;
          if (opts.inherits)
            defined = (_store$opts$inherits$ = store[opts.inherits].aliases) == null ? void 0 : _store$opts$inherits$.slice();
          (_defined = defined) != null ? _defined : defined = [];
          opts.aliases = defined;
        }
        const additional = aliases.filter((a) => !defined.includes(a));
        defined.unshift(...additional);
        defineType(type, opts);
      };
    }
    function defineType(type, opts = {}) {
      const inherits = opts.inherits && store[opts.inherits] || {};
      let fields = opts.fields;
      if (!fields) {
        fields = {};
        if (inherits.fields) {
          const keys3 = Object.getOwnPropertyNames(inherits.fields);
          for (const key of keys3) {
            const field = inherits.fields[key];
            const def = field.default;
            if (Array.isArray(def) ? def.length > 0 : def && typeof def === "object") {
              throw new Error("field defaults can only be primitives or empty arrays currently");
            }
            fields[key] = {
              default: Array.isArray(def) ? [] : def,
              optional: field.optional,
              deprecated: field.deprecated,
              validate: field.validate
            };
          }
        }
      }
      const visitor = opts.visitor || inherits.visitor || [];
      const aliases = opts.aliases || inherits.aliases || [];
      const builder = opts.builder || inherits.builder || opts.visitor || [];
      for (const k of Object.keys(opts)) {
        if (validTypeOpts.indexOf(k) === -1) {
          throw new Error(`Unknown type option "${k}" on ${type}`);
        }
      }
      if (opts.deprecatedAlias) {
        DEPRECATED_KEYS[opts.deprecatedAlias] = type;
      }
      for (const key of visitor.concat(builder)) {
        fields[key] = fields[key] || {};
      }
      for (const key of Object.keys(fields)) {
        const field = fields[key];
        if (field.default !== void 0 && builder.indexOf(key) === -1) {
          field.optional = true;
        }
        if (field.default === void 0) {
          field.default = null;
        } else if (!field.validate && field.default != null) {
          field.validate = assertValueType(getType(field.default));
        }
        for (const k of Object.keys(field)) {
          if (validFieldKeys.indexOf(k) === -1) {
            throw new Error(`Unknown field key "${k}" on ${type}.${key}`);
          }
        }
      }
      VISITOR_KEYS[type] = opts.visitor = visitor;
      BUILDER_KEYS[type] = opts.builder = builder;
      NODE_FIELDS[type] = opts.fields = fields;
      ALIAS_KEYS[type] = opts.aliases = aliases;
      aliases.forEach((alias) => {
        FLIPPED_ALIAS_KEYS[alias] = FLIPPED_ALIAS_KEYS[alias] || [];
        FLIPPED_ALIAS_KEYS[alias].push(type);
      });
      if (opts.validate) {
        NODE_PARENT_VALIDATIONS[type] = opts.validate;
      }
      store[type] = opts;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/core.js
var require_core2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/core.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.patternLikeCommon = exports.functionTypeAnnotationCommon = exports.functionDeclarationCommon = exports.functionCommon = exports.classMethodOrPropertyCommon = exports.classMethodOrDeclareMethodCommon = void 0;
    var _is = require_is2();
    var _isValidIdentifier = require_isValidIdentifier2();
    var _helperValidatorIdentifier = require_lib29();
    var _helperStringParser = require_lib30();
    var _index = require_constants3();
    var _utils = require_utils9();
    var defineType = (0, _utils.defineAliasedType)("Standardized");
    defineType("ArrayExpression", {
      fields: {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeOrValueType)("null", "Expression", "SpreadElement"))),
          default: !process.env.BABEL_TYPES_8_BREAKING ? [] : void 0
        }
      },
      visitor: ["elements"],
      aliases: ["Expression"]
    });
    defineType("AssignmentExpression", {
      fields: {
        operator: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertValueType)("string");
            }
            const identifier3 = (0, _utils.assertOneOf)(..._index.ASSIGNMENT_OPERATORS);
            const pattern = (0, _utils.assertOneOf)("=");
            return function(node, key, val) {
              const validator = (0, _is.default)("Pattern", node.left) ? pattern : identifier3;
              validator(node, key, val);
            };
          }()
        },
        left: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("LVal") : (0, _utils.assertNodeType)("Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      builder: ["operator", "left", "right"],
      visitor: ["left", "right"],
      aliases: ["Expression"]
    });
    defineType("BinaryExpression", {
      builder: ["operator", "left", "right"],
      fields: {
        operator: {
          validate: (0, _utils.assertOneOf)(..._index.BINARY_OPERATORS)
        },
        left: {
          validate: function() {
            const expression = (0, _utils.assertNodeType)("Expression");
            const inOp = (0, _utils.assertNodeType)("Expression", "PrivateName");
            const validator = Object.assign(function(node, key, val) {
              const validator2 = node.operator === "in" ? inOp : expression;
              validator2(node, key, val);
            }, {
              oneOfNodeTypes: ["Expression", "PrivateName"]
            });
            return validator;
          }()
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      visitor: ["left", "right"],
      aliases: ["Binary", "Expression"]
    });
    defineType("InterpreterDirective", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("Directive", {
      visitor: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertNodeType)("DirectiveLiteral")
        }
      }
    });
    defineType("DirectiveLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("BlockStatement", {
      builder: ["body", "directives"],
      visitor: ["directives", "body"],
      fields: {
        directives: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Directive"))),
          default: []
        },
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "Block", "Statement"]
    });
    defineType("BreakStatement", {
      visitor: ["label"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        }
      },
      aliases: ["Statement", "Terminatorless", "CompletionStatement"]
    });
    defineType("CallExpression", {
      visitor: ["callee", "arguments", "typeParameters", "typeArguments"],
      builder: ["callee", "arguments"],
      aliases: ["Expression"],
      fields: Object.assign({
        callee: {
          validate: (0, _utils.assertNodeType)("Expression", "Super", "V8IntrinsicIdentifier")
        },
        arguments: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement", "JSXNamespacedName", "ArgumentPlaceholder")))
        }
      }, !process.env.BABEL_TYPES_8_BREAKING ? {
        optional: {
          validate: (0, _utils.assertOneOf)(true, false),
          optional: true
        }
      } : {}, {
        typeArguments: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TSTypeParameterInstantiation"),
          optional: true
        }
      })
    });
    defineType("CatchClause", {
      visitor: ["param", "body"],
      fields: {
        param: {
          validate: (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      },
      aliases: ["Scopable", "BlockParent"]
    });
    defineType("ConditionalExpression", {
      visitor: ["test", "consequent", "alternate"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        consequent: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        alternate: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression", "Conditional"]
    });
    defineType("ContinueStatement", {
      visitor: ["label"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        }
      },
      aliases: ["Statement", "Terminatorless", "CompletionStatement"]
    });
    defineType("DebuggerStatement", {
      aliases: ["Statement"]
    });
    defineType("DoWhileStatement", {
      visitor: ["test", "body"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      },
      aliases: ["Statement", "BlockParent", "Loop", "While", "Scopable"]
    });
    defineType("EmptyStatement", {
      aliases: ["Statement"]
    });
    defineType("ExpressionStatement", {
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Statement", "ExpressionWrapper"]
    });
    defineType("File", {
      builder: ["program", "comments", "tokens"],
      visitor: ["program"],
      fields: {
        program: {
          validate: (0, _utils.assertNodeType)("Program")
        },
        comments: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? Object.assign(() => {
          }, {
            each: {
              oneOfNodeTypes: ["CommentBlock", "CommentLine"]
            }
          }) : (0, _utils.assertEach)((0, _utils.assertNodeType)("CommentBlock", "CommentLine")),
          optional: true
        },
        tokens: {
          validate: (0, _utils.assertEach)(Object.assign(() => {
          }, {
            type: "any"
          })),
          optional: true
        }
      }
    });
    defineType("ForInStatement", {
      visitor: ["left", "right", "body"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop", "ForXStatement"],
      fields: {
        left: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("VariableDeclaration", "LVal") : (0, _utils.assertNodeType)("VariableDeclaration", "Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("ForStatement", {
      visitor: ["init", "test", "update", "body"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop"],
      fields: {
        init: {
          validate: (0, _utils.assertNodeType)("VariableDeclaration", "Expression"),
          optional: true
        },
        test: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        update: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    var functionCommon = () => ({
      params: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Identifier", "Pattern", "RestElement")))
      },
      generator: {
        default: false
      },
      async: {
        default: false
      }
    });
    exports.functionCommon = functionCommon;
    var functionTypeAnnotationCommon = () => ({
      returnType: {
        validate: (0, _utils.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
        optional: true
      },
      typeParameters: {
        validate: (0, _utils.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
        optional: true
      }
    });
    exports.functionTypeAnnotationCommon = functionTypeAnnotationCommon;
    var functionDeclarationCommon = () => Object.assign({}, functionCommon(), {
      declare: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      id: {
        validate: (0, _utils.assertNodeType)("Identifier"),
        optional: true
      }
    });
    exports.functionDeclarationCommon = functionDeclarationCommon;
    defineType("FunctionDeclaration", {
      builder: ["id", "params", "body", "generator", "async"],
      visitor: ["id", "params", "body", "returnType", "typeParameters"],
      fields: Object.assign({}, functionDeclarationCommon(), functionTypeAnnotationCommon(), {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      }),
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Statement", "Pureish", "Declaration"],
      validate: function() {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return () => {
          };
        const identifier3 = (0, _utils.assertNodeType)("Identifier");
        return function(parent, key, node) {
          if (!(0, _is.default)("ExportDefaultDeclaration", parent)) {
            identifier3(node, "id", node.id);
          }
        };
      }()
    });
    defineType("FunctionExpression", {
      inherits: "FunctionDeclaration",
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Expression", "Pureish"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      })
    });
    var patternLikeCommon = () => ({
      typeAnnotation: {
        validate: (0, _utils.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
        optional: true
      },
      optional: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      decorators: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
        optional: true
      }
    });
    exports.patternLikeCommon = patternLikeCommon;
    defineType("Identifier", {
      builder: ["name"],
      visitor: ["typeAnnotation", "decorators"],
      aliases: ["Expression", "PatternLike", "LVal", "TSEntityName"],
      fields: Object.assign({}, patternLikeCommon(), {
        name: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (!(0, _isValidIdentifier.default)(val, false)) {
              throw new TypeError(`"${val}" is not a valid identifier name`);
            }
          }, {
            type: "string"
          }))
        }
      }),
      validate(parent, key, node) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        const match = /\.(\w+)$/.exec(key);
        if (!match)
          return;
        const [, parentKey] = match;
        const nonComp = {
          computed: false
        };
        if (parentKey === "property") {
          if ((0, _is.default)("MemberExpression", parent, nonComp))
            return;
          if ((0, _is.default)("OptionalMemberExpression", parent, nonComp))
            return;
        } else if (parentKey === "key") {
          if ((0, _is.default)("Property", parent, nonComp))
            return;
          if ((0, _is.default)("Method", parent, nonComp))
            return;
        } else if (parentKey === "exported") {
          if ((0, _is.default)("ExportSpecifier", parent))
            return;
        } else if (parentKey === "imported") {
          if ((0, _is.default)("ImportSpecifier", parent, {
            imported: node
          }))
            return;
        } else if (parentKey === "meta") {
          if ((0, _is.default)("MetaProperty", parent, {
            meta: node
          }))
            return;
        }
        if (((0, _helperValidatorIdentifier.isKeyword)(node.name) || (0, _helperValidatorIdentifier.isReservedWord)(node.name, false)) && node.name !== "this") {
          throw new TypeError(`"${node.name}" is not a valid identifier`);
        }
      }
    });
    defineType("IfStatement", {
      visitor: ["test", "consequent", "alternate"],
      aliases: ["Statement", "Conditional"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        consequent: {
          validate: (0, _utils.assertNodeType)("Statement")
        },
        alternate: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("LabeledStatement", {
      visitor: ["label", "body"],
      aliases: ["Statement"],
      fields: {
        label: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("StringLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("NumericLiteral", {
      builder: ["value"],
      deprecatedAlias: "NumberLiteral",
      fields: {
        value: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("number"), Object.assign(function(node, key, val) {
            if (1 / val < 0 || !Number.isFinite(val)) {
              const error = new Error(`NumericLiterals must be non-negative finite numbers. You can use t.valueToNode(${val}) instead.`);
              {
              }
            }
          }, {
            type: "number"
          }))
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("NullLiteral", {
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("BooleanLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("boolean")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("RegExpLiteral", {
      builder: ["pattern", "flags"],
      deprecatedAlias: "RegexLiteral",
      aliases: ["Expression", "Pureish", "Literal"],
      fields: {
        pattern: {
          validate: (0, _utils.assertValueType)("string")
        },
        flags: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            const invalid = /[^gimsuy]/.exec(val);
            if (invalid) {
              throw new TypeError(`"${invalid[0]}" is not a valid RegExp flag`);
            }
          }, {
            type: "string"
          })),
          default: ""
        }
      }
    });
    defineType("LogicalExpression", {
      builder: ["operator", "left", "right"],
      visitor: ["left", "right"],
      aliases: ["Binary", "Expression"],
      fields: {
        operator: {
          validate: (0, _utils.assertOneOf)(..._index.LOGICAL_OPERATORS)
        },
        left: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("MemberExpression", {
      builder: ["object", "property", "computed", ...!process.env.BABEL_TYPES_8_BREAKING ? ["optional"] : []],
      visitor: ["object", "property"],
      aliases: ["Expression", "LVal"],
      fields: Object.assign({
        object: {
          validate: (0, _utils.assertNodeType)("Expression", "Super")
        },
        property: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            };
            validator.oneOfNodeTypes = ["Expression", "Identifier", "PrivateName"];
            return validator;
          }()
        },
        computed: {
          default: false
        }
      }, !process.env.BABEL_TYPES_8_BREAKING ? {
        optional: {
          validate: (0, _utils.assertOneOf)(true, false),
          optional: true
        }
      } : {})
    });
    defineType("NewExpression", {
      inherits: "CallExpression"
    });
    defineType("Program", {
      visitor: ["directives", "body"],
      builder: ["body", "directives", "sourceType", "interpreter"],
      fields: {
        sourceFile: {
          validate: (0, _utils.assertValueType)("string")
        },
        sourceType: {
          validate: (0, _utils.assertOneOf)("script", "module"),
          default: "script"
        },
        interpreter: {
          validate: (0, _utils.assertNodeType)("InterpreterDirective"),
          default: null,
          optional: true
        },
        directives: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Directive"))),
          default: []
        },
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "Block"]
    });
    defineType("ObjectExpression", {
      visitor: ["properties"],
      aliases: ["Expression"],
      fields: {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ObjectMethod", "ObjectProperty", "SpreadElement")))
        }
      }
    });
    defineType("ObjectMethod", {
      builder: ["kind", "key", "params", "body", "computed", "generator", "async"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        kind: Object.assign({
          validate: (0, _utils.assertOneOf)("method", "get", "set")
        }, !process.env.BABEL_TYPES_8_BREAKING ? {
          default: "method"
        } : {}),
        computed: {
          default: false
        },
        key: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            };
            validator.oneOfNodeTypes = ["Expression", "Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral"];
            return validator;
          }()
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      }),
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      aliases: ["UserWhitespacable", "Function", "Scopable", "BlockParent", "FunctionParent", "Method", "ObjectMember"]
    });
    defineType("ObjectProperty", {
      builder: ["key", "value", "computed", "shorthand", ...!process.env.BABEL_TYPES_8_BREAKING ? ["decorators"] : []],
      fields: {
        computed: {
          default: false
        },
        key: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = Object.assign(function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            }, {
              oneOfNodeTypes: ["Expression", "Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "PrivateName"]
            });
            return validator;
          }()
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression", "PatternLike")
        },
        shorthand: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("boolean"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.computed) {
              throw new TypeError("Property shorthand of ObjectProperty cannot be true if computed is true");
            }
          }, {
            type: "boolean"
          }), function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && !(0, _is.default)("Identifier", node.key)) {
              throw new TypeError("Property shorthand of ObjectProperty cannot be true if key is not an Identifier");
            }
          }),
          default: false
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      },
      visitor: ["key", "value", "decorators"],
      aliases: ["UserWhitespacable", "Property", "ObjectMember"],
      validate: function() {
        const pattern = (0, _utils.assertNodeType)("Identifier", "Pattern", "TSAsExpression", "TSSatisfiesExpression", "TSNonNullExpression", "TSTypeAssertion");
        const expression = (0, _utils.assertNodeType)("Expression");
        return function(parent, key, node) {
          if (!process.env.BABEL_TYPES_8_BREAKING)
            return;
          const validator = (0, _is.default)("ObjectPattern", parent) ? pattern : expression;
          validator(node, "value", node.value);
        };
      }()
    });
    defineType("RestElement", {
      visitor: ["argument", "typeAnnotation"],
      builder: ["argument"],
      aliases: ["LVal", "PatternLike"],
      deprecatedAlias: "RestProperty",
      fields: Object.assign({}, patternLikeCommon(), {
        argument: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("LVal") : (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        }
      }),
      validate(parent, key) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        const match = /(\w+)\[(\d+)\]/.exec(key);
        if (!match)
          throw new Error("Internal Babel error: malformed key.");
        const [, listKey, index] = match;
        if (parent[listKey].length > +index + 1) {
          throw new TypeError(`RestElement must be last element of ${listKey}`);
        }
      }
    });
    defineType("ReturnStatement", {
      visitor: ["argument"],
      aliases: ["Statement", "Terminatorless", "CompletionStatement"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        }
      }
    });
    defineType("SequenceExpression", {
      visitor: ["expressions"],
      fields: {
        expressions: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression")))
        }
      },
      aliases: ["Expression"]
    });
    defineType("ParenthesizedExpression", {
      visitor: ["expression"],
      aliases: ["Expression", "ExpressionWrapper"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("SwitchCase", {
      visitor: ["test", "consequent"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        consequent: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      }
    });
    defineType("SwitchStatement", {
      visitor: ["discriminant", "cases"],
      aliases: ["Statement", "BlockParent", "Scopable"],
      fields: {
        discriminant: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        cases: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("SwitchCase")))
        }
      }
    });
    defineType("ThisExpression", {
      aliases: ["Expression"]
    });
    defineType("ThrowStatement", {
      visitor: ["argument"],
      aliases: ["Statement", "Terminatorless", "CompletionStatement"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("TryStatement", {
      visitor: ["block", "handler", "finalizer"],
      aliases: ["Statement"],
      fields: {
        block: {
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("BlockStatement"), Object.assign(function(node) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (!node.handler && !node.finalizer) {
              throw new TypeError("TryStatement expects either a handler or finalizer, or both");
            }
          }, {
            oneOfNodeTypes: ["BlockStatement"]
          }))
        },
        handler: {
          optional: true,
          validate: (0, _utils.assertNodeType)("CatchClause")
        },
        finalizer: {
          optional: true,
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      }
    });
    defineType("UnaryExpression", {
      builder: ["operator", "argument", "prefix"],
      fields: {
        prefix: {
          default: true
        },
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        operator: {
          validate: (0, _utils.assertOneOf)(..._index.UNARY_OPERATORS)
        }
      },
      visitor: ["argument"],
      aliases: ["UnaryLike", "Expression"]
    });
    defineType("UpdateExpression", {
      builder: ["operator", "argument", "prefix"],
      fields: {
        prefix: {
          default: false
        },
        argument: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertNodeType)("Expression") : (0, _utils.assertNodeType)("Identifier", "MemberExpression")
        },
        operator: {
          validate: (0, _utils.assertOneOf)(..._index.UPDATE_OPERATORS)
        }
      },
      visitor: ["argument"],
      aliases: ["Expression"]
    });
    defineType("VariableDeclaration", {
      builder: ["kind", "declarations"],
      visitor: ["declarations"],
      aliases: ["Statement", "Declaration"],
      fields: {
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        kind: {
          validate: (0, _utils.assertOneOf)("var", "let", "const", "using", "await using")
        },
        declarations: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("VariableDeclarator")))
        }
      },
      validate(parent, key, node) {
        if (!process.env.BABEL_TYPES_8_BREAKING)
          return;
        if (!(0, _is.default)("ForXStatement", parent, {
          left: node
        }))
          return;
        if (node.declarations.length !== 1) {
          throw new TypeError(`Exactly one VariableDeclarator is required in the VariableDeclaration of a ${parent.type}`);
        }
      }
    });
    defineType("VariableDeclarator", {
      visitor: ["id", "init"],
      fields: {
        id: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertNodeType)("LVal");
            }
            const normal = (0, _utils.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern");
            const without = (0, _utils.assertNodeType)("Identifier");
            return function(node, key, val) {
              const validator = node.init ? normal : without;
              validator(node, key, val);
            };
          }()
        },
        definite: {
          optional: true,
          validate: (0, _utils.assertValueType)("boolean")
        },
        init: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("WhileStatement", {
      visitor: ["test", "body"],
      aliases: ["Statement", "BlockParent", "Loop", "While", "Scopable"],
      fields: {
        test: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("WithStatement", {
      visitor: ["object", "body"],
      aliases: ["Statement"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        }
      }
    });
    defineType("AssignmentPattern", {
      visitor: ["left", "right", "decorators"],
      builder: ["left", "right"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        left: {
          validate: (0, _utils.assertNodeType)("Identifier", "ObjectPattern", "ArrayPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression")
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      })
    });
    defineType("ArrayPattern", {
      visitor: ["elements", "typeAnnotation"],
      builder: ["elements"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeOrValueType)("null", "PatternLike", "LVal")))
        }
      })
    });
    defineType("ArrowFunctionExpression", {
      builder: ["params", "body", "async"],
      visitor: ["params", "body", "returnType", "typeParameters"],
      aliases: ["Scopable", "Function", "BlockParent", "FunctionParent", "Expression", "Pureish"],
      fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
        expression: {
          validate: (0, _utils.assertValueType)("boolean")
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement", "Expression")
        },
        predicate: {
          validate: (0, _utils.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
          optional: true
        }
      })
    });
    defineType("ClassBody", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ClassMethod", "ClassPrivateMethod", "ClassProperty", "ClassPrivateProperty", "ClassAccessorProperty", "TSDeclareMethod", "TSIndexSignature", "StaticBlock")))
        }
      }
    });
    defineType("ClassExpression", {
      builder: ["id", "superClass", "body", "decorators"],
      visitor: ["id", "body", "superClass", "mixins", "typeParameters", "superTypeParameters", "implements", "decorators"],
      aliases: ["Scopable", "Class", "Expression"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("ClassBody")
        },
        superClass: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        },
        superTypeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        },
        implements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSExpressionWithTypeArguments", "ClassImplements"))),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        mixins: {
          validate: (0, _utils.assertNodeType)("InterfaceExtends"),
          optional: true
        }
      }
    });
    defineType("ClassDeclaration", {
      inherits: "ClassExpression",
      aliases: ["Scopable", "Class", "Statement", "Declaration"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
          optional: true
        },
        body: {
          validate: (0, _utils.assertNodeType)("ClassBody")
        },
        superClass: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        },
        superTypeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        },
        implements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSExpressionWithTypeArguments", "ClassImplements"))),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        mixins: {
          validate: (0, _utils.assertNodeType)("InterfaceExtends"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        abstract: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      },
      validate: function() {
        const identifier3 = (0, _utils.assertNodeType)("Identifier");
        return function(parent, key, node) {
          if (!process.env.BABEL_TYPES_8_BREAKING)
            return;
          if (!(0, _is.default)("ExportDefaultDeclaration", parent)) {
            identifier3(node, "id", node.id);
          }
        };
      }()
    });
    defineType("ExportAllDeclaration", {
      builder: ["source"],
      visitor: ["source", "attributes", "assertions"],
      aliases: ["Statement", "Declaration", "ImportOrExportDeclaration", "ExportDeclaration"],
      fields: {
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value")),
        attributes: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        }
      }
    });
    defineType("ExportDefaultDeclaration", {
      visitor: ["declaration"],
      aliases: ["Statement", "Declaration", "ImportOrExportDeclaration", "ExportDeclaration"],
      fields: {
        declaration: {
          validate: (0, _utils.assertNodeType)("TSDeclareFunction", "FunctionDeclaration", "ClassDeclaration", "Expression")
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("value"))
      }
    });
    defineType("ExportNamedDeclaration", {
      builder: ["declaration", "specifiers", "source"],
      visitor: ["declaration", "specifiers", "source", "attributes", "assertions"],
      aliases: ["Statement", "Declaration", "ImportOrExportDeclaration", "ExportDeclaration"],
      fields: {
        declaration: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("Declaration"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.specifiers.length) {
              throw new TypeError("Only declaration or specifiers is allowed on ExportNamedDeclaration");
            }
          }, {
            oneOfNodeTypes: ["Declaration"]
          }), function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && node.source) {
              throw new TypeError("Cannot export a declaration from a source");
            }
          })
        },
        attributes: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        specifiers: {
          default: [],
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)(function() {
            const sourced = (0, _utils.assertNodeType)("ExportSpecifier", "ExportDefaultSpecifier", "ExportNamespaceSpecifier");
            const sourceless = (0, _utils.assertNodeType)("ExportSpecifier");
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return sourced;
            return function(node, key, val) {
              const validator = node.source ? sourced : sourceless;
              validator(node, key, val);
            };
          }()))
        },
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral"),
          optional: true
        },
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value"))
      }
    });
    defineType("ExportSpecifier", {
      visitor: ["local", "exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        exportKind: {
          validate: (0, _utils.assertOneOf)("type", "value"),
          optional: true
        }
      }
    });
    defineType("ForOfStatement", {
      visitor: ["left", "right", "body"],
      builder: ["left", "right", "body", "await"],
      aliases: ["Scopable", "Statement", "For", "BlockParent", "Loop", "ForXStatement"],
      fields: {
        left: {
          validate: function() {
            if (!process.env.BABEL_TYPES_8_BREAKING) {
              return (0, _utils.assertNodeType)("VariableDeclaration", "LVal");
            }
            const declaration = (0, _utils.assertNodeType)("VariableDeclaration");
            const lval = (0, _utils.assertNodeType)("Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression");
            return function(node, key, val) {
              if ((0, _is.default)("VariableDeclaration", val)) {
                declaration(node, key, val);
              } else {
                lval(node, key, val);
              }
            };
          }()
        },
        right: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        body: {
          validate: (0, _utils.assertNodeType)("Statement")
        },
        await: {
          default: false
        }
      }
    });
    defineType("ImportDeclaration", {
      builder: ["specifiers", "source"],
      visitor: ["specifiers", "source", "attributes", "assertions"],
      aliases: ["Statement", "Declaration", "ImportOrExportDeclaration"],
      fields: {
        attributes: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        assertions: {
          optional: true,
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportAttribute")))
        },
        module: {
          optional: true,
          validate: (0, _utils.assertValueType)("boolean")
        },
        specifiers: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ImportSpecifier", "ImportDefaultSpecifier", "ImportNamespaceSpecifier")))
        },
        source: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        },
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "typeof", "value"),
          optional: true
        }
      }
    });
    defineType("ImportDefaultSpecifier", {
      visitor: ["local"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("ImportNamespaceSpecifier", {
      visitor: ["local"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("ImportSpecifier", {
      visitor: ["local", "imported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        local: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        imported: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "typeof", "value"),
          optional: true
        }
      }
    });
    defineType("MetaProperty", {
      visitor: ["meta", "property"],
      aliases: ["Expression"],
      fields: {
        meta: {
          validate: (0, _utils.chain)((0, _utils.assertNodeType)("Identifier"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            let property;
            switch (val.name) {
              case "function":
                property = "sent";
                break;
              case "new":
                property = "target";
                break;
              case "import":
                property = "meta";
                break;
            }
            if (!(0, _is.default)("Identifier", node.property, {
              name: property
            })) {
              throw new TypeError("Unrecognised MetaProperty");
            }
          }, {
            oneOfNodeTypes: ["Identifier"]
          }))
        },
        property: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    var classMethodOrPropertyCommon = () => ({
      abstract: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      accessibility: {
        validate: (0, _utils.assertOneOf)("public", "private", "protected"),
        optional: true
      },
      static: {
        default: false
      },
      override: {
        default: false
      },
      computed: {
        default: false
      },
      optional: {
        validate: (0, _utils.assertValueType)("boolean"),
        optional: true
      },
      key: {
        validate: (0, _utils.chain)(function() {
          const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral");
          const computed = (0, _utils.assertNodeType)("Expression");
          return function(node, key, val) {
            const validator = node.computed ? computed : normal;
            validator(node, key, val);
          };
        }(), (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression"))
      }
    });
    exports.classMethodOrPropertyCommon = classMethodOrPropertyCommon;
    var classMethodOrDeclareMethodCommon = () => Object.assign({}, functionCommon(), classMethodOrPropertyCommon(), {
      params: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Identifier", "Pattern", "RestElement", "TSParameterProperty")))
      },
      kind: {
        validate: (0, _utils.assertOneOf)("get", "set", "method", "constructor"),
        default: "method"
      },
      access: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("string"), (0, _utils.assertOneOf)("public", "private", "protected")),
        optional: true
      },
      decorators: {
        validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
        optional: true
      }
    });
    exports.classMethodOrDeclareMethodCommon = classMethodOrDeclareMethodCommon;
    defineType("ClassMethod", {
      aliases: ["Function", "Scopable", "BlockParent", "FunctionParent", "Method"],
      builder: ["kind", "key", "params", "body", "computed", "static", "generator", "async"],
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      })
    });
    defineType("ObjectPattern", {
      visitor: ["properties", "typeAnnotation", "decorators"],
      builder: ["properties"],
      aliases: ["Pattern", "PatternLike", "LVal"],
      fields: Object.assign({}, patternLikeCommon(), {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("RestElement", "ObjectProperty")))
        }
      })
    });
    defineType("SpreadElement", {
      visitor: ["argument"],
      aliases: ["UnaryLike"],
      deprecatedAlias: "SpreadProperty",
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("Super", {
      aliases: ["Expression"]
    });
    defineType("TaggedTemplateExpression", {
      visitor: ["tag", "quasi", "typeParameters"],
      builder: ["tag", "quasi"],
      aliases: ["Expression"],
      fields: {
        tag: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        quasi: {
          validate: (0, _utils.assertNodeType)("TemplateLiteral")
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("TemplateElement", {
      builder: ["value", "tail"],
      fields: {
        value: {
          validate: (0, _utils.chain)((0, _utils.assertShape)({
            raw: {
              validate: (0, _utils.assertValueType)("string")
            },
            cooked: {
              validate: (0, _utils.assertValueType)("string"),
              optional: true
            }
          }), function templateElementCookedValidator(node) {
            const raw = node.value.raw;
            let unterminatedCalled = false;
            const error = () => {
              throw new Error("Internal @babel/types error.");
            };
            const {
              str,
              firstInvalidLoc
            } = (0, _helperStringParser.readStringContents)("template", raw, 0, 0, 0, {
              unterminated() {
                unterminatedCalled = true;
              },
              strictNumericEscape: error,
              invalidEscapeSequence: error,
              numericSeparatorInEscapeSequence: error,
              unexpectedNumericSeparator: error,
              invalidDigit: error,
              invalidCodePoint: error
            });
            if (!unterminatedCalled)
              throw new Error("Invalid raw");
            node.value.cooked = firstInvalidLoc ? null : str;
          })
        },
        tail: {
          default: false
        }
      }
    });
    defineType("TemplateLiteral", {
      visitor: ["quasis", "expressions"],
      aliases: ["Expression", "Literal"],
      fields: {
        quasis: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TemplateElement")))
        },
        expressions: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "TSType")), function(node, key, val) {
            if (node.quasis.length !== val.length + 1) {
              throw new TypeError(`Number of ${node.type} quasis should be exactly one more than the number of expressions.
Expected ${val.length + 1} quasis but got ${node.quasis.length}`);
            }
          })
        }
      }
    });
    defineType("YieldExpression", {
      builder: ["argument", "delegate"],
      visitor: ["argument"],
      aliases: ["Expression", "Terminatorless"],
      fields: {
        delegate: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("boolean"), Object.assign(function(node, key, val) {
            if (!process.env.BABEL_TYPES_8_BREAKING)
              return;
            if (val && !node.argument) {
              throw new TypeError("Property delegate of YieldExpression cannot be true if there is no argument");
            }
          }, {
            type: "boolean"
          })),
          default: false
        },
        argument: {
          optional: true,
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("AwaitExpression", {
      builder: ["argument"],
      visitor: ["argument"],
      aliases: ["Expression", "Terminatorless"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("Import", {
      aliases: ["Expression"]
    });
    defineType("BigIntLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    defineType("ExportNamespaceSpecifier", {
      visitor: ["exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("OptionalMemberExpression", {
      builder: ["object", "property", "computed", "optional"],
      visitor: ["object", "property"],
      aliases: ["Expression"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        property: {
          validate: function() {
            const normal = (0, _utils.assertNodeType)("Identifier");
            const computed = (0, _utils.assertNodeType)("Expression");
            const validator = Object.assign(function(node, key, val) {
              const validator2 = node.computed ? computed : normal;
              validator2(node, key, val);
            }, {
              oneOfNodeTypes: ["Expression", "Identifier"]
            });
            return validator;
          }()
        },
        computed: {
          default: false
        },
        optional: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertValueType)("boolean") : (0, _utils.chain)((0, _utils.assertValueType)("boolean"), (0, _utils.assertOptionalChainStart)())
        }
      }
    });
    defineType("OptionalCallExpression", {
      visitor: ["callee", "arguments", "typeParameters", "typeArguments"],
      builder: ["callee", "arguments", "optional"],
      aliases: ["Expression"],
      fields: {
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        arguments: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement", "JSXNamespacedName", "ArgumentPlaceholder")))
        },
        optional: {
          validate: !process.env.BABEL_TYPES_8_BREAKING ? (0, _utils.assertValueType)("boolean") : (0, _utils.chain)((0, _utils.assertValueType)("boolean"), (0, _utils.assertOptionalChainStart)())
        },
        typeArguments: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation"),
          optional: true
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("ClassProperty", {
      visitor: ["key", "value", "typeAnnotation", "decorators"],
      builder: ["key", "value", "typeAnnotation", "decorators", "computed", "static"],
      aliases: ["Property"],
      fields: Object.assign({}, classMethodOrPropertyCommon(), {
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      })
    });
    defineType("ClassAccessorProperty", {
      visitor: ["key", "value", "typeAnnotation", "decorators"],
      builder: ["key", "value", "typeAnnotation", "decorators", "computed", "static"],
      aliases: ["Property", "Accessor"],
      fields: Object.assign({}, classMethodOrPropertyCommon(), {
        key: {
          validate: (0, _utils.chain)(function() {
            const normal = (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "PrivateName");
            const computed = (0, _utils.assertNodeType)("Expression");
            return function(node, key, val) {
              const validator = node.computed ? computed : normal;
              validator(node, key, val);
            };
          }(), (0, _utils.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression", "PrivateName"))
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        declare: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      })
    });
    defineType("ClassPrivateProperty", {
      visitor: ["key", "value", "decorators", "typeAnnotation"],
      builder: ["key", "value", "decorators", "static"],
      aliases: ["Property", "Private"],
      fields: {
        key: {
          validate: (0, _utils.assertNodeType)("PrivateName")
        },
        value: {
          validate: (0, _utils.assertNodeType)("Expression"),
          optional: true
        },
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        },
        static: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        definite: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        variance: {
          validate: (0, _utils.assertNodeType)("Variance"),
          optional: true
        }
      }
    });
    defineType("ClassPrivateMethod", {
      builder: ["kind", "key", "params", "body", "static"],
      visitor: ["key", "params", "body", "decorators", "returnType", "typeParameters"],
      aliases: ["Function", "Scopable", "BlockParent", "FunctionParent", "Method", "Private"],
      fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), {
        kind: {
          validate: (0, _utils.assertOneOf)("get", "set", "method"),
          default: "method"
        },
        key: {
          validate: (0, _utils.assertNodeType)("PrivateName")
        },
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        }
      })
    });
    defineType("PrivateName", {
      visitor: ["id"],
      aliases: ["Private"],
      fields: {
        id: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    defineType("StaticBlock", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Statement")))
        }
      },
      aliases: ["Scopable", "BlockParent", "FunctionParent"]
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/flow.js
var require_flow3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/flow.js"() {
    "use strict";
    var _utils = require_utils9();
    var defineType = (0, _utils.defineAliasedType)("Flow");
    var defineInterfaceishType = (name) => {
      const isDeclareClass = name === "DeclareClass";
      defineType(name, {
        builder: ["id", "typeParameters", "extends", "body"],
        visitor: ["id", "typeParameters", "extends", ...isDeclareClass ? ["mixins", "implements"] : [], "body"],
        aliases: ["FlowDeclaration", "Statement", "Declaration"],
        fields: Object.assign({
          id: (0, _utils.validateType)("Identifier"),
          typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
          extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends"))
        }, isDeclareClass ? {
          mixins: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends")),
          implements: (0, _utils.validateOptional)((0, _utils.arrayOfType)("ClassImplements"))
        } : {}, {
          body: (0, _utils.validateType)("ObjectTypeAnnotation")
        })
      });
    };
    defineType("AnyTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ArrayTypeAnnotation", {
      visitor: ["elementType"],
      aliases: ["FlowType"],
      fields: {
        elementType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("BooleanTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("BooleanLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("NullLiteralTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ClassImplements", {
      visitor: ["id", "typeParameters"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineInterfaceishType("DeclareClass");
    defineType("DeclareFunction", {
      visitor: ["id"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        predicate: (0, _utils.validateOptionalType)("DeclaredPredicate")
      }
    });
    defineInterfaceishType("DeclareInterface");
    defineType("DeclareModule", {
      builder: ["id", "body", "kind"],
      visitor: ["id", "body"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        body: (0, _utils.validateType)("BlockStatement"),
        kind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("CommonJS", "ES"))
      }
    });
    defineType("DeclareModuleExports", {
      visitor: ["typeAnnotation"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TypeAnnotation")
      }
    });
    defineType("DeclareTypeAlias", {
      visitor: ["id", "typeParameters", "right"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        right: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("DeclareOpaqueType", {
      visitor: ["id", "typeParameters", "supertype"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        supertype: (0, _utils.validateOptionalType)("FlowType"),
        impltype: (0, _utils.validateOptionalType)("FlowType")
      }
    });
    defineType("DeclareVariable", {
      visitor: ["id"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("DeclareExportDeclaration", {
      visitor: ["declaration", "specifiers", "source"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        declaration: (0, _utils.validateOptionalType)("Flow"),
        specifiers: (0, _utils.validateOptional)((0, _utils.arrayOfType)(["ExportSpecifier", "ExportNamespaceSpecifier"])),
        source: (0, _utils.validateOptionalType)("StringLiteral"),
        default: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("DeclareExportAllDeclaration", {
      visitor: ["source"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        source: (0, _utils.validateType)("StringLiteral"),
        exportKind: (0, _utils.validateOptional)((0, _utils.assertOneOf)("type", "value"))
      }
    });
    defineType("DeclaredPredicate", {
      visitor: ["value"],
      aliases: ["FlowPredicate"],
      fields: {
        value: (0, _utils.validateType)("Flow")
      }
    });
    defineType("ExistsTypeAnnotation", {
      aliases: ["FlowType"]
    });
    defineType("FunctionTypeAnnotation", {
      visitor: ["typeParameters", "params", "rest", "returnType"],
      aliases: ["FlowType"],
      fields: {
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        params: (0, _utils.validate)((0, _utils.arrayOfType)("FunctionTypeParam")),
        rest: (0, _utils.validateOptionalType)("FunctionTypeParam"),
        this: (0, _utils.validateOptionalType)("FunctionTypeParam"),
        returnType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("FunctionTypeParam", {
      visitor: ["name", "typeAnnotation"],
      fields: {
        name: (0, _utils.validateOptionalType)("Identifier"),
        typeAnnotation: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("GenericTypeAnnotation", {
      visitor: ["id", "typeParameters"],
      aliases: ["FlowType"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"]),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineType("InferredPredicate", {
      aliases: ["FlowPredicate"]
    });
    defineType("InterfaceExtends", {
      visitor: ["id", "typeParameters"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"]),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterInstantiation")
      }
    });
    defineInterfaceishType("InterfaceDeclaration");
    defineType("InterfaceTypeAnnotation", {
      visitor: ["extends", "body"],
      aliases: ["FlowType"],
      fields: {
        extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("InterfaceExtends")),
        body: (0, _utils.validateType)("ObjectTypeAnnotation")
      }
    });
    defineType("IntersectionTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("MixedTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("EmptyTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("NullableTypeAnnotation", {
      visitor: ["typeAnnotation"],
      aliases: ["FlowType"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("NumberLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("number"))
      }
    });
    defineType("NumberTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ObjectTypeAnnotation", {
      visitor: ["properties", "indexers", "callProperties", "internalSlots"],
      aliases: ["FlowType"],
      builder: ["properties", "indexers", "callProperties", "internalSlots", "exact"],
      fields: {
        properties: (0, _utils.validate)((0, _utils.arrayOfType)(["ObjectTypeProperty", "ObjectTypeSpreadProperty"])),
        indexers: {
          validate: (0, _utils.arrayOfType)("ObjectTypeIndexer"),
          optional: true,
          default: []
        },
        callProperties: {
          validate: (0, _utils.arrayOfType)("ObjectTypeCallProperty"),
          optional: true,
          default: []
        },
        internalSlots: {
          validate: (0, _utils.arrayOfType)("ObjectTypeInternalSlot"),
          optional: true,
          default: []
        },
        exact: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        },
        inexact: (0, _utils.validateOptional)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeInternalSlot", {
      visitor: ["id", "value", "optional", "static", "method"],
      aliases: ["UserWhitespacable"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        value: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        method: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeCallProperty", {
      visitor: ["value"],
      aliases: ["UserWhitespacable"],
      fields: {
        value: (0, _utils.validateType)("FlowType"),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeIndexer", {
      visitor: ["id", "key", "value", "variance"],
      aliases: ["UserWhitespacable"],
      fields: {
        id: (0, _utils.validateOptionalType)("Identifier"),
        key: (0, _utils.validateType)("FlowType"),
        value: (0, _utils.validateType)("FlowType"),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        variance: (0, _utils.validateOptionalType)("Variance")
      }
    });
    defineType("ObjectTypeProperty", {
      visitor: ["key", "value", "variance"],
      aliases: ["UserWhitespacable"],
      fields: {
        key: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        value: (0, _utils.validateType)("FlowType"),
        kind: (0, _utils.validate)((0, _utils.assertOneOf)("init", "get", "set")),
        static: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        proto: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        variance: (0, _utils.validateOptionalType)("Variance"),
        method: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("ObjectTypeSpreadProperty", {
      visitor: ["argument"],
      aliases: ["UserWhitespacable"],
      fields: {
        argument: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("OpaqueType", {
      visitor: ["id", "typeParameters", "supertype", "impltype"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        supertype: (0, _utils.validateOptionalType)("FlowType"),
        impltype: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("QualifiedTypeIdentifier", {
      visitor: ["id", "qualification"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        qualification: (0, _utils.validateType)(["Identifier", "QualifiedTypeIdentifier"])
      }
    });
    defineType("StringLiteralTypeAnnotation", {
      builder: ["value"],
      aliases: ["FlowType"],
      fields: {
        value: (0, _utils.validate)((0, _utils.assertValueType)("string"))
      }
    });
    defineType("StringTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("SymbolTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("ThisTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("TupleTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("TypeofTypeAnnotation", {
      visitor: ["argument"],
      aliases: ["FlowType"],
      fields: {
        argument: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeAlias", {
      visitor: ["id", "typeParameters", "right"],
      aliases: ["FlowDeclaration", "Statement", "Declaration"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TypeParameterDeclaration"),
        right: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeAnnotation", {
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("TypeCastExpression", {
      visitor: ["expression", "typeAnnotation"],
      aliases: ["ExpressionWrapper", "Expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeAnnotation: (0, _utils.validateType)("TypeAnnotation")
      }
    });
    defineType("TypeParameter", {
      visitor: ["bound", "default", "variance"],
      fields: {
        name: (0, _utils.validate)((0, _utils.assertValueType)("string")),
        bound: (0, _utils.validateOptionalType)("TypeAnnotation"),
        default: (0, _utils.validateOptionalType)("FlowType"),
        variance: (0, _utils.validateOptionalType)("Variance")
      }
    });
    defineType("TypeParameterDeclaration", {
      visitor: ["params"],
      fields: {
        params: (0, _utils.validate)((0, _utils.arrayOfType)("TypeParameter"))
      }
    });
    defineType("TypeParameterInstantiation", {
      visitor: ["params"],
      fields: {
        params: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("UnionTypeAnnotation", {
      visitor: ["types"],
      aliases: ["FlowType"],
      fields: {
        types: (0, _utils.validate)((0, _utils.arrayOfType)("FlowType"))
      }
    });
    defineType("Variance", {
      builder: ["kind"],
      fields: {
        kind: (0, _utils.validate)((0, _utils.assertOneOf)("minus", "plus"))
      }
    });
    defineType("VoidTypeAnnotation", {
      aliases: ["FlowType", "FlowBaseAnnotation"]
    });
    defineType("EnumDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "body"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        body: (0, _utils.validateType)(["EnumBooleanBody", "EnumNumberBody", "EnumStringBody", "EnumSymbolBody"])
      }
    });
    defineType("EnumBooleanBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)("EnumBooleanMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumNumberBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)("EnumNumberMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumStringBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        explicitType: (0, _utils.validate)((0, _utils.assertValueType)("boolean")),
        members: (0, _utils.validateArrayOfType)(["EnumStringMember", "EnumDefaultedMember"]),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumSymbolBody", {
      aliases: ["EnumBody"],
      visitor: ["members"],
      fields: {
        members: (0, _utils.validateArrayOfType)("EnumDefaultedMember"),
        hasUnknownMembers: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
    defineType("EnumBooleanMember", {
      aliases: ["EnumMember"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("BooleanLiteral")
      }
    });
    defineType("EnumNumberMember", {
      aliases: ["EnumMember"],
      visitor: ["id", "init"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("NumericLiteral")
      }
    });
    defineType("EnumStringMember", {
      aliases: ["EnumMember"],
      visitor: ["id", "init"],
      fields: {
        id: (0, _utils.validateType)("Identifier"),
        init: (0, _utils.validateType)("StringLiteral")
      }
    });
    defineType("EnumDefaultedMember", {
      aliases: ["EnumMember"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("IndexedAccessType", {
      visitor: ["objectType", "indexType"],
      aliases: ["FlowType"],
      fields: {
        objectType: (0, _utils.validateType)("FlowType"),
        indexType: (0, _utils.validateType)("FlowType")
      }
    });
    defineType("OptionalIndexedAccessType", {
      visitor: ["objectType", "indexType"],
      aliases: ["FlowType"],
      fields: {
        objectType: (0, _utils.validateType)("FlowType"),
        indexType: (0, _utils.validateType)("FlowType"),
        optional: (0, _utils.validate)((0, _utils.assertValueType)("boolean"))
      }
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/jsx.js
var require_jsx3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/jsx.js"() {
    "use strict";
    var _utils = require_utils9();
    var defineType = (0, _utils.defineAliasedType)("JSX");
    defineType("JSXAttribute", {
      visitor: ["name", "value"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXNamespacedName")
        },
        value: {
          optional: true,
          validate: (0, _utils.assertNodeType)("JSXElement", "JSXFragment", "StringLiteral", "JSXExpressionContainer")
        }
      }
    });
    defineType("JSXClosingElement", {
      visitor: ["name"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName")
        }
      }
    });
    defineType("JSXElement", {
      builder: ["openingElement", "closingElement", "children", "selfClosing"],
      visitor: ["openingElement", "children", "closingElement"],
      aliases: ["Immutable", "Expression"],
      fields: Object.assign({
        openingElement: {
          validate: (0, _utils.assertNodeType)("JSXOpeningElement")
        },
        closingElement: {
          optional: true,
          validate: (0, _utils.assertNodeType)("JSXClosingElement")
        },
        children: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")))
        }
      }, {
        selfClosing: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        }
      })
    });
    defineType("JSXEmptyExpression", {});
    defineType("JSXExpressionContainer", {
      visitor: ["expression"],
      aliases: ["Immutable"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression", "JSXEmptyExpression")
        }
      }
    });
    defineType("JSXSpreadChild", {
      visitor: ["expression"],
      aliases: ["Immutable"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("JSXIdentifier", {
      builder: ["name"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("JSXMemberExpression", {
      visitor: ["object", "property"],
      fields: {
        object: {
          validate: (0, _utils.assertNodeType)("JSXMemberExpression", "JSXIdentifier")
        },
        property: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        }
      }
    });
    defineType("JSXNamespacedName", {
      visitor: ["namespace", "name"],
      fields: {
        namespace: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        },
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier")
        }
      }
    });
    defineType("JSXOpeningElement", {
      builder: ["name", "attributes", "selfClosing"],
      visitor: ["name", "attributes"],
      aliases: ["Immutable"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName")
        },
        selfClosing: {
          default: false
        },
        attributes: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXAttribute", "JSXSpreadAttribute")))
        },
        typeParameters: {
          validate: (0, _utils.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
          optional: true
        }
      }
    });
    defineType("JSXSpreadAttribute", {
      visitor: ["argument"],
      fields: {
        argument: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    defineType("JSXText", {
      aliases: ["Immutable"],
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
    defineType("JSXFragment", {
      builder: ["openingFragment", "closingFragment", "children"],
      visitor: ["openingFragment", "children", "closingFragment"],
      aliases: ["Immutable", "Expression"],
      fields: {
        openingFragment: {
          validate: (0, _utils.assertNodeType)("JSXOpeningFragment")
        },
        closingFragment: {
          validate: (0, _utils.assertNodeType)("JSXClosingFragment")
        },
        children: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")))
        }
      }
    });
    defineType("JSXOpeningFragment", {
      aliases: ["Immutable"]
    });
    defineType("JSXClosingFragment", {
      aliases: ["Immutable"]
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/placeholders.js
var require_placeholders2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/placeholders.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.PLACEHOLDERS_FLIPPED_ALIAS = exports.PLACEHOLDERS_ALIAS = exports.PLACEHOLDERS = void 0;
    var _utils = require_utils9();
    var PLACEHOLDERS = ["Identifier", "StringLiteral", "Expression", "Statement", "Declaration", "BlockStatement", "ClassBody", "Pattern"];
    exports.PLACEHOLDERS = PLACEHOLDERS;
    var PLACEHOLDERS_ALIAS = {
      Declaration: ["Statement"],
      Pattern: ["PatternLike", "LVal"]
    };
    exports.PLACEHOLDERS_ALIAS = PLACEHOLDERS_ALIAS;
    for (const type of PLACEHOLDERS) {
      const alias = _utils.ALIAS_KEYS[type];
      if (alias != null && alias.length)
        PLACEHOLDERS_ALIAS[type] = alias;
    }
    var PLACEHOLDERS_FLIPPED_ALIAS = {};
    exports.PLACEHOLDERS_FLIPPED_ALIAS = PLACEHOLDERS_FLIPPED_ALIAS;
    Object.keys(PLACEHOLDERS_ALIAS).forEach((type) => {
      PLACEHOLDERS_ALIAS[type].forEach((alias) => {
        if (!Object.hasOwnProperty.call(PLACEHOLDERS_FLIPPED_ALIAS, alias)) {
          PLACEHOLDERS_FLIPPED_ALIAS[alias] = [];
        }
        PLACEHOLDERS_FLIPPED_ALIAS[alias].push(type);
      });
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/misc.js
var require_misc2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/misc.js"() {
    "use strict";
    var _utils = require_utils9();
    var _placeholders = require_placeholders2();
    var defineType = (0, _utils.defineAliasedType)("Miscellaneous");
    {
      defineType("Noop", {
        visitor: []
      });
    }
    defineType("Placeholder", {
      visitor: [],
      builder: ["expectedNode", "name"],
      fields: {
        name: {
          validate: (0, _utils.assertNodeType)("Identifier")
        },
        expectedNode: {
          validate: (0, _utils.assertOneOf)(..._placeholders.PLACEHOLDERS)
        }
      }
    });
    defineType("V8IntrinsicIdentifier", {
      builder: ["name"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        }
      }
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/experimental.js
var require_experimental2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/experimental.js"() {
    "use strict";
    var _utils = require_utils9();
    (0, _utils.default)("ArgumentPlaceholder", {});
    (0, _utils.default)("BindExpression", {
      visitor: ["object", "callee"],
      aliases: ["Expression"],
      fields: !process.env.BABEL_TYPES_8_BREAKING ? {
        object: {
          validate: Object.assign(() => {
          }, {
            oneOfNodeTypes: ["Expression"]
          })
        },
        callee: {
          validate: Object.assign(() => {
          }, {
            oneOfNodeTypes: ["Expression"]
          })
        }
      } : {
        object: {
          validate: (0, _utils.assertNodeType)("Expression")
        },
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    (0, _utils.default)("ImportAttribute", {
      visitor: ["key", "value"],
      fields: {
        key: {
          validate: (0, _utils.assertNodeType)("Identifier", "StringLiteral")
        },
        value: {
          validate: (0, _utils.assertNodeType)("StringLiteral")
        }
      }
    });
    (0, _utils.default)("Decorator", {
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      }
    });
    (0, _utils.default)("DoExpression", {
      visitor: ["body"],
      builder: ["body", "async"],
      aliases: ["Expression"],
      fields: {
        body: {
          validate: (0, _utils.assertNodeType)("BlockStatement")
        },
        async: {
          validate: (0, _utils.assertValueType)("boolean"),
          default: false
        }
      }
    });
    (0, _utils.default)("ExportDefaultSpecifier", {
      visitor: ["exported"],
      aliases: ["ModuleSpecifier"],
      fields: {
        exported: {
          validate: (0, _utils.assertNodeType)("Identifier")
        }
      }
    });
    (0, _utils.default)("RecordExpression", {
      visitor: ["properties"],
      aliases: ["Expression"],
      fields: {
        properties: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("ObjectProperty", "SpreadElement")))
        }
      }
    });
    (0, _utils.default)("TupleExpression", {
      fields: {
        elements: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Expression", "SpreadElement"))),
          default: []
        }
      },
      visitor: ["elements"],
      aliases: ["Expression"]
    });
    (0, _utils.default)("DecimalLiteral", {
      builder: ["value"],
      fields: {
        value: {
          validate: (0, _utils.assertValueType)("string")
        }
      },
      aliases: ["Expression", "Pureish", "Literal", "Immutable"]
    });
    (0, _utils.default)("ModuleExpression", {
      visitor: ["body"],
      fields: {
        body: {
          validate: (0, _utils.assertNodeType)("Program")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("TopicReference", {
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelineTopicExpression", {
      builder: ["expression"],
      visitor: ["expression"],
      fields: {
        expression: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelineBareFunction", {
      builder: ["callee"],
      visitor: ["callee"],
      fields: {
        callee: {
          validate: (0, _utils.assertNodeType)("Expression")
        }
      },
      aliases: ["Expression"]
    });
    (0, _utils.default)("PipelinePrimaryTopicReference", {
      aliases: ["Expression"]
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/typescript.js
var require_typescript3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/typescript.js"() {
    "use strict";
    var _utils = require_utils9();
    var _core = require_core2();
    var _is = require_is2();
    var defineType = (0, _utils.defineAliasedType)("TypeScript");
    var bool = (0, _utils.assertValueType)("boolean");
    var tSFunctionTypeAnnotationCommon = () => ({
      returnType: {
        validate: (0, _utils.assertNodeType)("TSTypeAnnotation", "Noop"),
        optional: true
      },
      typeParameters: {
        validate: (0, _utils.assertNodeType)("TSTypeParameterDeclaration", "Noop"),
        optional: true
      }
    });
    defineType("TSParameterProperty", {
      aliases: ["LVal"],
      visitor: ["parameter"],
      fields: {
        accessibility: {
          validate: (0, _utils.assertOneOf)("public", "private", "protected"),
          optional: true
        },
        readonly: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        parameter: {
          validate: (0, _utils.assertNodeType)("Identifier", "AssignmentPattern")
        },
        override: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        decorators: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("Decorator"))),
          optional: true
        }
      }
    });
    defineType("TSDeclareFunction", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "params", "returnType"],
      fields: Object.assign({}, (0, _core.functionDeclarationCommon)(), tSFunctionTypeAnnotationCommon())
    });
    defineType("TSDeclareMethod", {
      visitor: ["decorators", "key", "typeParameters", "params", "returnType"],
      fields: Object.assign({}, (0, _core.classMethodOrDeclareMethodCommon)(), tSFunctionTypeAnnotationCommon())
    });
    defineType("TSQualifiedName", {
      aliases: ["TSEntityName"],
      visitor: ["left", "right"],
      fields: {
        left: (0, _utils.validateType)("TSEntityName"),
        right: (0, _utils.validateType)("Identifier")
      }
    });
    var signatureDeclarationCommon = () => ({
      typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
      ["parameters"]: (0, _utils.validateArrayOfType)(["ArrayPattern", "Identifier", "ObjectPattern", "RestElement"]),
      ["typeAnnotation"]: (0, _utils.validateOptionalType)("TSTypeAnnotation")
    });
    var callConstructSignatureDeclaration = {
      aliases: ["TSTypeElement"],
      visitor: ["typeParameters", "parameters", "typeAnnotation"],
      fields: signatureDeclarationCommon()
    };
    defineType("TSCallSignatureDeclaration", callConstructSignatureDeclaration);
    defineType("TSConstructSignatureDeclaration", callConstructSignatureDeclaration);
    var namedTypeElementCommon = () => ({
      key: (0, _utils.validateType)("Expression"),
      computed: {
        default: false
      },
      optional: (0, _utils.validateOptional)(bool)
    });
    defineType("TSPropertySignature", {
      aliases: ["TSTypeElement"],
      visitor: ["key", "typeAnnotation", "initializer"],
      fields: Object.assign({}, namedTypeElementCommon(), {
        readonly: (0, _utils.validateOptional)(bool),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation"),
        initializer: (0, _utils.validateOptionalType)("Expression"),
        kind: {
          validate: (0, _utils.assertOneOf)("get", "set")
        }
      })
    });
    defineType("TSMethodSignature", {
      aliases: ["TSTypeElement"],
      visitor: ["key", "typeParameters", "parameters", "typeAnnotation"],
      fields: Object.assign({}, signatureDeclarationCommon(), namedTypeElementCommon(), {
        kind: {
          validate: (0, _utils.assertOneOf)("method", "get", "set")
        }
      })
    });
    defineType("TSIndexSignature", {
      aliases: ["TSTypeElement"],
      visitor: ["parameters", "typeAnnotation"],
      fields: {
        readonly: (0, _utils.validateOptional)(bool),
        static: (0, _utils.validateOptional)(bool),
        parameters: (0, _utils.validateArrayOfType)("Identifier"),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation")
      }
    });
    var tsKeywordTypes = ["TSAnyKeyword", "TSBooleanKeyword", "TSBigIntKeyword", "TSIntrinsicKeyword", "TSNeverKeyword", "TSNullKeyword", "TSNumberKeyword", "TSObjectKeyword", "TSStringKeyword", "TSSymbolKeyword", "TSUndefinedKeyword", "TSUnknownKeyword", "TSVoidKeyword"];
    for (const type of tsKeywordTypes) {
      defineType(type, {
        aliases: ["TSType", "TSBaseType"],
        visitor: [],
        fields: {}
      });
    }
    defineType("TSThisType", {
      aliases: ["TSType", "TSBaseType"],
      visitor: [],
      fields: {}
    });
    var fnOrCtrBase = {
      aliases: ["TSType"],
      visitor: ["typeParameters", "parameters", "typeAnnotation"]
    };
    defineType("TSFunctionType", Object.assign({}, fnOrCtrBase, {
      fields: signatureDeclarationCommon()
    }));
    defineType("TSConstructorType", Object.assign({}, fnOrCtrBase, {
      fields: Object.assign({}, signatureDeclarationCommon(), {
        abstract: (0, _utils.validateOptional)(bool)
      })
    }));
    defineType("TSTypeReference", {
      aliases: ["TSType"],
      visitor: ["typeName", "typeParameters"],
      fields: {
        typeName: (0, _utils.validateType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSTypePredicate", {
      aliases: ["TSType"],
      visitor: ["parameterName", "typeAnnotation"],
      builder: ["parameterName", "typeAnnotation", "asserts"],
      fields: {
        parameterName: (0, _utils.validateType)(["Identifier", "TSThisType"]),
        typeAnnotation: (0, _utils.validateOptionalType)("TSTypeAnnotation"),
        asserts: (0, _utils.validateOptional)(bool)
      }
    });
    defineType("TSTypeQuery", {
      aliases: ["TSType"],
      visitor: ["exprName", "typeParameters"],
      fields: {
        exprName: (0, _utils.validateType)(["TSEntityName", "TSImportType"]),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSTypeLiteral", {
      aliases: ["TSType"],
      visitor: ["members"],
      fields: {
        members: (0, _utils.validateArrayOfType)("TSTypeElement")
      }
    });
    defineType("TSArrayType", {
      aliases: ["TSType"],
      visitor: ["elementType"],
      fields: {
        elementType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSTupleType", {
      aliases: ["TSType"],
      visitor: ["elementTypes"],
      fields: {
        elementTypes: (0, _utils.validateArrayOfType)(["TSType", "TSNamedTupleMember"])
      }
    });
    defineType("TSOptionalType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSRestType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSNamedTupleMember", {
      visitor: ["label", "elementType"],
      builder: ["label", "elementType", "optional"],
      fields: {
        label: (0, _utils.validateType)("Identifier"),
        optional: {
          validate: bool,
          default: false
        },
        elementType: (0, _utils.validateType)("TSType")
      }
    });
    var unionOrIntersection = {
      aliases: ["TSType"],
      visitor: ["types"],
      fields: {
        types: (0, _utils.validateArrayOfType)("TSType")
      }
    };
    defineType("TSUnionType", unionOrIntersection);
    defineType("TSIntersectionType", unionOrIntersection);
    defineType("TSConditionalType", {
      aliases: ["TSType"],
      visitor: ["checkType", "extendsType", "trueType", "falseType"],
      fields: {
        checkType: (0, _utils.validateType)("TSType"),
        extendsType: (0, _utils.validateType)("TSType"),
        trueType: (0, _utils.validateType)("TSType"),
        falseType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSInferType", {
      aliases: ["TSType"],
      visitor: ["typeParameter"],
      fields: {
        typeParameter: (0, _utils.validateType)("TSTypeParameter")
      }
    });
    defineType("TSParenthesizedType", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSTypeOperator", {
      aliases: ["TSType"],
      visitor: ["typeAnnotation"],
      fields: {
        operator: (0, _utils.validate)((0, _utils.assertValueType)("string")),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSIndexedAccessType", {
      aliases: ["TSType"],
      visitor: ["objectType", "indexType"],
      fields: {
        objectType: (0, _utils.validateType)("TSType"),
        indexType: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSMappedType", {
      aliases: ["TSType"],
      visitor: ["typeParameter", "typeAnnotation", "nameType"],
      fields: {
        readonly: (0, _utils.validateOptional)((0, _utils.assertOneOf)(true, false, "+", "-")),
        typeParameter: (0, _utils.validateType)("TSTypeParameter"),
        optional: (0, _utils.validateOptional)((0, _utils.assertOneOf)(true, false, "+", "-")),
        typeAnnotation: (0, _utils.validateOptionalType)("TSType"),
        nameType: (0, _utils.validateOptionalType)("TSType")
      }
    });
    defineType("TSLiteralType", {
      aliases: ["TSType", "TSBaseType"],
      visitor: ["literal"],
      fields: {
        literal: {
          validate: function() {
            const unaryExpression = (0, _utils.assertNodeType)("NumericLiteral", "BigIntLiteral");
            const unaryOperator = (0, _utils.assertOneOf)("-");
            const literal = (0, _utils.assertNodeType)("NumericLiteral", "StringLiteral", "BooleanLiteral", "BigIntLiteral", "TemplateLiteral");
            function validator(parent, key, node) {
              if ((0, _is.default)("UnaryExpression", node)) {
                unaryOperator(node, "operator", node.operator);
                unaryExpression(node, "argument", node.argument);
              } else {
                literal(parent, key, node);
              }
            }
            validator.oneOfNodeTypes = ["NumericLiteral", "StringLiteral", "BooleanLiteral", "BigIntLiteral", "TemplateLiteral", "UnaryExpression"];
            return validator;
          }()
        }
      }
    });
    defineType("TSExpressionWithTypeArguments", {
      aliases: ["TSType"],
      visitor: ["expression", "typeParameters"],
      fields: {
        expression: (0, _utils.validateType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSInterfaceDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "extends", "body"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
        extends: (0, _utils.validateOptional)((0, _utils.arrayOfType)("TSExpressionWithTypeArguments")),
        body: (0, _utils.validateType)("TSInterfaceBody")
      }
    });
    defineType("TSInterfaceBody", {
      visitor: ["body"],
      fields: {
        body: (0, _utils.validateArrayOfType)("TSTypeElement")
      }
    });
    defineType("TSTypeAliasDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "typeParameters", "typeAnnotation"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterDeclaration"),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    });
    defineType("TSInstantiationExpression", {
      aliases: ["Expression"],
      visitor: ["expression", "typeParameters"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    var TSTypeExpression = {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["expression", "typeAnnotation"],
      fields: {
        expression: (0, _utils.validateType)("Expression"),
        typeAnnotation: (0, _utils.validateType)("TSType")
      }
    };
    defineType("TSAsExpression", TSTypeExpression);
    defineType("TSSatisfiesExpression", TSTypeExpression);
    defineType("TSTypeAssertion", {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["typeAnnotation", "expression"],
      fields: {
        typeAnnotation: (0, _utils.validateType)("TSType"),
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSEnumDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "members"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        const: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)("Identifier"),
        members: (0, _utils.validateArrayOfType)("TSEnumMember"),
        initializer: (0, _utils.validateOptionalType)("Expression")
      }
    });
    defineType("TSEnumMember", {
      visitor: ["id", "initializer"],
      fields: {
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        initializer: (0, _utils.validateOptionalType)("Expression")
      }
    });
    defineType("TSModuleDeclaration", {
      aliases: ["Statement", "Declaration"],
      visitor: ["id", "body"],
      fields: {
        declare: (0, _utils.validateOptional)(bool),
        global: (0, _utils.validateOptional)(bool),
        id: (0, _utils.validateType)(["Identifier", "StringLiteral"]),
        body: (0, _utils.validateType)(["TSModuleBlock", "TSModuleDeclaration"])
      }
    });
    defineType("TSModuleBlock", {
      aliases: ["Scopable", "Block", "BlockParent", "FunctionParent"],
      visitor: ["body"],
      fields: {
        body: (0, _utils.validateArrayOfType)("Statement")
      }
    });
    defineType("TSImportType", {
      aliases: ["TSType"],
      visitor: ["argument", "qualifier", "typeParameters"],
      fields: {
        argument: (0, _utils.validateType)("StringLiteral"),
        qualifier: (0, _utils.validateOptionalType)("TSEntityName"),
        typeParameters: (0, _utils.validateOptionalType)("TSTypeParameterInstantiation")
      }
    });
    defineType("TSImportEqualsDeclaration", {
      aliases: ["Statement"],
      visitor: ["id", "moduleReference"],
      fields: {
        isExport: (0, _utils.validate)(bool),
        id: (0, _utils.validateType)("Identifier"),
        moduleReference: (0, _utils.validateType)(["TSEntityName", "TSExternalModuleReference"]),
        importKind: {
          validate: (0, _utils.assertOneOf)("type", "value"),
          optional: true
        }
      }
    });
    defineType("TSExternalModuleReference", {
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("StringLiteral")
      }
    });
    defineType("TSNonNullExpression", {
      aliases: ["Expression", "LVal", "PatternLike"],
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSExportAssignment", {
      aliases: ["Statement"],
      visitor: ["expression"],
      fields: {
        expression: (0, _utils.validateType)("Expression")
      }
    });
    defineType("TSNamespaceExportDeclaration", {
      aliases: ["Statement"],
      visitor: ["id"],
      fields: {
        id: (0, _utils.validateType)("Identifier")
      }
    });
    defineType("TSTypeAnnotation", {
      visitor: ["typeAnnotation"],
      fields: {
        typeAnnotation: {
          validate: (0, _utils.assertNodeType)("TSType")
        }
      }
    });
    defineType("TSTypeParameterInstantiation", {
      visitor: ["params"],
      fields: {
        params: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSType")))
        }
      }
    });
    defineType("TSTypeParameterDeclaration", {
      visitor: ["params"],
      fields: {
        params: {
          validate: (0, _utils.chain)((0, _utils.assertValueType)("array"), (0, _utils.assertEach)((0, _utils.assertNodeType)("TSTypeParameter")))
        }
      }
    });
    defineType("TSTypeParameter", {
      builder: ["constraint", "default", "name"],
      visitor: ["constraint", "default"],
      fields: {
        name: {
          validate: (0, _utils.assertValueType)("string")
        },
        in: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        out: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        const: {
          validate: (0, _utils.assertValueType)("boolean"),
          optional: true
        },
        constraint: {
          validate: (0, _utils.assertNodeType)("TSType"),
          optional: true
        },
        default: {
          validate: (0, _utils.assertNodeType)("TSType"),
          optional: true
        }
      }
    });
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/deprecated-aliases.js
var require_deprecated_aliases = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/deprecated-aliases.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.DEPRECATED_ALIASES = void 0;
    var DEPRECATED_ALIASES = {
      ModuleDeclaration: "ImportOrExportDeclaration"
    };
    exports.DEPRECATED_ALIASES = DEPRECATED_ALIASES;
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/index.js
var require_definitions2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/definitions/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "ALIAS_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.ALIAS_KEYS;
      }
    });
    Object.defineProperty(exports, "BUILDER_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.BUILDER_KEYS;
      }
    });
    Object.defineProperty(exports, "DEPRECATED_ALIASES", {
      enumerable: true,
      get: function() {
        return _deprecatedAliases.DEPRECATED_ALIASES;
      }
    });
    Object.defineProperty(exports, "DEPRECATED_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.DEPRECATED_KEYS;
      }
    });
    Object.defineProperty(exports, "FLIPPED_ALIAS_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.FLIPPED_ALIAS_KEYS;
      }
    });
    Object.defineProperty(exports, "NODE_FIELDS", {
      enumerable: true,
      get: function() {
        return _utils.NODE_FIELDS;
      }
    });
    Object.defineProperty(exports, "NODE_PARENT_VALIDATIONS", {
      enumerable: true,
      get: function() {
        return _utils.NODE_PARENT_VALIDATIONS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS_ALIAS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS_ALIAS;
      }
    });
    Object.defineProperty(exports, "PLACEHOLDERS_FLIPPED_ALIAS", {
      enumerable: true,
      get: function() {
        return _placeholders.PLACEHOLDERS_FLIPPED_ALIAS;
      }
    });
    exports.TYPES = void 0;
    Object.defineProperty(exports, "VISITOR_KEYS", {
      enumerable: true,
      get: function() {
        return _utils.VISITOR_KEYS;
      }
    });
    var _toFastProperties = require_to_fast_properties();
    require_core2();
    require_flow3();
    require_jsx3();
    require_misc2();
    require_experimental2();
    require_typescript3();
    var _utils = require_utils9();
    var _placeholders = require_placeholders2();
    var _deprecatedAliases = require_deprecated_aliases();
    Object.keys(_deprecatedAliases.DEPRECATED_ALIASES).forEach((deprecatedAlias) => {
      _utils.FLIPPED_ALIAS_KEYS[deprecatedAlias] = _utils.FLIPPED_ALIAS_KEYS[_deprecatedAliases.DEPRECATED_ALIASES[deprecatedAlias]];
    });
    _toFastProperties(_utils.VISITOR_KEYS);
    _toFastProperties(_utils.ALIAS_KEYS);
    _toFastProperties(_utils.FLIPPED_ALIAS_KEYS);
    _toFastProperties(_utils.NODE_FIELDS);
    _toFastProperties(_utils.BUILDER_KEYS);
    _toFastProperties(_utils.DEPRECATED_KEYS);
    _toFastProperties(_placeholders.PLACEHOLDERS_ALIAS);
    _toFastProperties(_placeholders.PLACEHOLDERS_FLIPPED_ALIAS);
    var TYPES = [].concat(Object.keys(_utils.VISITOR_KEYS), Object.keys(_utils.FLIPPED_ALIAS_KEYS), Object.keys(_utils.DEPRECATED_KEYS));
    exports.TYPES = TYPES;
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/validate.js
var require_validate3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/validate.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = validate;
    exports.validateChild = validateChild;
    exports.validateField = validateField;
    var _index = require_definitions2();
    function validate(node, key, val) {
      if (!node)
        return;
      const fields = _index.NODE_FIELDS[node.type];
      if (!fields)
        return;
      const field = fields[key];
      validateField(node, key, val, field);
      validateChild(node, key, val);
    }
    function validateField(node, key, val, field) {
      if (!(field != null && field.validate))
        return;
      if (field.optional && val == null)
        return;
      field.validate(node, key, val);
    }
    function validateChild(node, key, val) {
      if (val == null)
        return;
      const validate2 = _index.NODE_PARENT_VALIDATIONS[val.type];
      if (!validate2)
        return;
      validate2(node, key, val);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/validateNode.js
var require_validateNode2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/validateNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = validateNode;
    var _validate = require_validate3();
    var _index = require_lib31();
    function validateNode(node) {
      const keys3 = _index.BUILDER_KEYS[node.type];
      for (const key of keys3) {
        (0, _validate.default)(node, key, node[key]);
      }
      return node;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/generated/index.js
var require_generated7 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.anyTypeAnnotation = anyTypeAnnotation;
    exports.argumentPlaceholder = argumentPlaceholder;
    exports.arrayExpression = arrayExpression;
    exports.arrayPattern = arrayPattern;
    exports.arrayTypeAnnotation = arrayTypeAnnotation;
    exports.arrowFunctionExpression = arrowFunctionExpression;
    exports.assignmentExpression = assignmentExpression;
    exports.assignmentPattern = assignmentPattern;
    exports.awaitExpression = awaitExpression;
    exports.bigIntLiteral = bigIntLiteral;
    exports.binaryExpression = binaryExpression;
    exports.bindExpression = bindExpression;
    exports.blockStatement = blockStatement2;
    exports.booleanLiteral = booleanLiteral;
    exports.booleanLiteralTypeAnnotation = booleanLiteralTypeAnnotation;
    exports.booleanTypeAnnotation = booleanTypeAnnotation;
    exports.breakStatement = breakStatement;
    exports.callExpression = callExpression3;
    exports.catchClause = catchClause;
    exports.classAccessorProperty = classAccessorProperty;
    exports.classBody = classBody;
    exports.classDeclaration = classDeclaration;
    exports.classExpression = classExpression;
    exports.classImplements = classImplements;
    exports.classMethod = classMethod;
    exports.classPrivateMethod = classPrivateMethod;
    exports.classPrivateProperty = classPrivateProperty;
    exports.classProperty = classProperty;
    exports.conditionalExpression = conditionalExpression;
    exports.continueStatement = continueStatement;
    exports.debuggerStatement = debuggerStatement;
    exports.decimalLiteral = decimalLiteral;
    exports.declareClass = declareClass;
    exports.declareExportAllDeclaration = declareExportAllDeclaration;
    exports.declareExportDeclaration = declareExportDeclaration;
    exports.declareFunction = declareFunction;
    exports.declareInterface = declareInterface;
    exports.declareModule = declareModule;
    exports.declareModuleExports = declareModuleExports;
    exports.declareOpaqueType = declareOpaqueType;
    exports.declareTypeAlias = declareTypeAlias;
    exports.declareVariable = declareVariable;
    exports.declaredPredicate = declaredPredicate;
    exports.decorator = decorator;
    exports.directive = directive;
    exports.directiveLiteral = directiveLiteral;
    exports.doExpression = doExpression;
    exports.doWhileStatement = doWhileStatement;
    exports.emptyStatement = emptyStatement;
    exports.emptyTypeAnnotation = emptyTypeAnnotation;
    exports.enumBooleanBody = enumBooleanBody;
    exports.enumBooleanMember = enumBooleanMember;
    exports.enumDeclaration = enumDeclaration;
    exports.enumDefaultedMember = enumDefaultedMember;
    exports.enumNumberBody = enumNumberBody;
    exports.enumNumberMember = enumNumberMember;
    exports.enumStringBody = enumStringBody;
    exports.enumStringMember = enumStringMember;
    exports.enumSymbolBody = enumSymbolBody;
    exports.existsTypeAnnotation = existsTypeAnnotation;
    exports.exportAllDeclaration = exportAllDeclaration;
    exports.exportDefaultDeclaration = exportDefaultDeclaration;
    exports.exportDefaultSpecifier = exportDefaultSpecifier;
    exports.exportNamedDeclaration = exportNamedDeclaration;
    exports.exportNamespaceSpecifier = exportNamespaceSpecifier;
    exports.exportSpecifier = exportSpecifier;
    exports.expressionStatement = expressionStatement;
    exports.file = file;
    exports.forInStatement = forInStatement;
    exports.forOfStatement = forOfStatement;
    exports.forStatement = forStatement;
    exports.functionDeclaration = functionDeclaration;
    exports.functionExpression = functionExpression;
    exports.functionTypeAnnotation = functionTypeAnnotation;
    exports.functionTypeParam = functionTypeParam;
    exports.genericTypeAnnotation = genericTypeAnnotation;
    exports.identifier = identifier3;
    exports.ifStatement = ifStatement;
    exports.import = _import;
    exports.importAttribute = importAttribute;
    exports.importDeclaration = importDeclaration;
    exports.importDefaultSpecifier = importDefaultSpecifier;
    exports.importNamespaceSpecifier = importNamespaceSpecifier;
    exports.importSpecifier = importSpecifier2;
    exports.indexedAccessType = indexedAccessType;
    exports.inferredPredicate = inferredPredicate;
    exports.interfaceDeclaration = interfaceDeclaration;
    exports.interfaceExtends = interfaceExtends;
    exports.interfaceTypeAnnotation = interfaceTypeAnnotation;
    exports.interpreterDirective = interpreterDirective;
    exports.intersectionTypeAnnotation = intersectionTypeAnnotation;
    exports.jSXAttribute = exports.jsxAttribute = jsxAttribute;
    exports.jSXClosingElement = exports.jsxClosingElement = jsxClosingElement;
    exports.jSXClosingFragment = exports.jsxClosingFragment = jsxClosingFragment;
    exports.jSXElement = exports.jsxElement = jsxElement;
    exports.jSXEmptyExpression = exports.jsxEmptyExpression = jsxEmptyExpression;
    exports.jSXExpressionContainer = exports.jsxExpressionContainer = jsxExpressionContainer;
    exports.jSXFragment = exports.jsxFragment = jsxFragment;
    exports.jSXIdentifier = exports.jsxIdentifier = jsxIdentifier;
    exports.jSXMemberExpression = exports.jsxMemberExpression = jsxMemberExpression;
    exports.jSXNamespacedName = exports.jsxNamespacedName = jsxNamespacedName;
    exports.jSXOpeningElement = exports.jsxOpeningElement = jsxOpeningElement;
    exports.jSXOpeningFragment = exports.jsxOpeningFragment = jsxOpeningFragment;
    exports.jSXSpreadAttribute = exports.jsxSpreadAttribute = jsxSpreadAttribute;
    exports.jSXSpreadChild = exports.jsxSpreadChild = jsxSpreadChild;
    exports.jSXText = exports.jsxText = jsxText;
    exports.labeledStatement = labeledStatement;
    exports.logicalExpression = logicalExpression;
    exports.memberExpression = memberExpression;
    exports.metaProperty = metaProperty;
    exports.mixedTypeAnnotation = mixedTypeAnnotation;
    exports.moduleExpression = moduleExpression;
    exports.newExpression = newExpression;
    exports.noop = noop;
    exports.nullLiteral = nullLiteral;
    exports.nullLiteralTypeAnnotation = nullLiteralTypeAnnotation;
    exports.nullableTypeAnnotation = nullableTypeAnnotation;
    exports.numberLiteral = NumberLiteral;
    exports.numberLiteralTypeAnnotation = numberLiteralTypeAnnotation;
    exports.numberTypeAnnotation = numberTypeAnnotation;
    exports.numericLiteral = numericLiteral;
    exports.objectExpression = objectExpression;
    exports.objectMethod = objectMethod;
    exports.objectPattern = objectPattern2;
    exports.objectProperty = objectProperty2;
    exports.objectTypeAnnotation = objectTypeAnnotation;
    exports.objectTypeCallProperty = objectTypeCallProperty;
    exports.objectTypeIndexer = objectTypeIndexer;
    exports.objectTypeInternalSlot = objectTypeInternalSlot;
    exports.objectTypeProperty = objectTypeProperty;
    exports.objectTypeSpreadProperty = objectTypeSpreadProperty;
    exports.opaqueType = opaqueType;
    exports.optionalCallExpression = optionalCallExpression;
    exports.optionalIndexedAccessType = optionalIndexedAccessType;
    exports.optionalMemberExpression = optionalMemberExpression;
    exports.parenthesizedExpression = parenthesizedExpression;
    exports.pipelineBareFunction = pipelineBareFunction;
    exports.pipelinePrimaryTopicReference = pipelinePrimaryTopicReference;
    exports.pipelineTopicExpression = pipelineTopicExpression;
    exports.placeholder = placeholder;
    exports.privateName = privateName;
    exports.program = program2;
    exports.qualifiedTypeIdentifier = qualifiedTypeIdentifier;
    exports.recordExpression = recordExpression;
    exports.regExpLiteral = regExpLiteral;
    exports.regexLiteral = RegexLiteral;
    exports.restElement = restElement;
    exports.restProperty = RestProperty;
    exports.returnStatement = returnStatement2;
    exports.sequenceExpression = sequenceExpression;
    exports.spreadElement = spreadElement;
    exports.spreadProperty = SpreadProperty;
    exports.staticBlock = staticBlock;
    exports.stringLiteral = stringLiteral2;
    exports.stringLiteralTypeAnnotation = stringLiteralTypeAnnotation;
    exports.stringTypeAnnotation = stringTypeAnnotation;
    exports.super = _super;
    exports.switchCase = switchCase;
    exports.switchStatement = switchStatement;
    exports.symbolTypeAnnotation = symbolTypeAnnotation;
    exports.taggedTemplateExpression = taggedTemplateExpression;
    exports.templateElement = templateElement;
    exports.templateLiteral = templateLiteral;
    exports.thisExpression = thisExpression;
    exports.thisTypeAnnotation = thisTypeAnnotation;
    exports.throwStatement = throwStatement;
    exports.topicReference = topicReference;
    exports.tryStatement = tryStatement;
    exports.tSAnyKeyword = exports.tsAnyKeyword = tsAnyKeyword;
    exports.tSArrayType = exports.tsArrayType = tsArrayType;
    exports.tSAsExpression = exports.tsAsExpression = tsAsExpression;
    exports.tSBigIntKeyword = exports.tsBigIntKeyword = tsBigIntKeyword;
    exports.tSBooleanKeyword = exports.tsBooleanKeyword = tsBooleanKeyword;
    exports.tSCallSignatureDeclaration = exports.tsCallSignatureDeclaration = tsCallSignatureDeclaration;
    exports.tSConditionalType = exports.tsConditionalType = tsConditionalType;
    exports.tSConstructSignatureDeclaration = exports.tsConstructSignatureDeclaration = tsConstructSignatureDeclaration;
    exports.tSConstructorType = exports.tsConstructorType = tsConstructorType;
    exports.tSDeclareFunction = exports.tsDeclareFunction = tsDeclareFunction;
    exports.tSDeclareMethod = exports.tsDeclareMethod = tsDeclareMethod;
    exports.tSEnumDeclaration = exports.tsEnumDeclaration = tsEnumDeclaration;
    exports.tSEnumMember = exports.tsEnumMember = tsEnumMember;
    exports.tSExportAssignment = exports.tsExportAssignment = tsExportAssignment;
    exports.tSExpressionWithTypeArguments = exports.tsExpressionWithTypeArguments = tsExpressionWithTypeArguments;
    exports.tSExternalModuleReference = exports.tsExternalModuleReference = tsExternalModuleReference;
    exports.tSFunctionType = exports.tsFunctionType = tsFunctionType;
    exports.tSImportEqualsDeclaration = exports.tsImportEqualsDeclaration = tsImportEqualsDeclaration;
    exports.tSImportType = exports.tsImportType = tsImportType;
    exports.tSIndexSignature = exports.tsIndexSignature = tsIndexSignature;
    exports.tSIndexedAccessType = exports.tsIndexedAccessType = tsIndexedAccessType;
    exports.tSInferType = exports.tsInferType = tsInferType;
    exports.tSInstantiationExpression = exports.tsInstantiationExpression = tsInstantiationExpression;
    exports.tSInterfaceBody = exports.tsInterfaceBody = tsInterfaceBody;
    exports.tSInterfaceDeclaration = exports.tsInterfaceDeclaration = tsInterfaceDeclaration;
    exports.tSIntersectionType = exports.tsIntersectionType = tsIntersectionType;
    exports.tSIntrinsicKeyword = exports.tsIntrinsicKeyword = tsIntrinsicKeyword;
    exports.tSLiteralType = exports.tsLiteralType = tsLiteralType;
    exports.tSMappedType = exports.tsMappedType = tsMappedType;
    exports.tSMethodSignature = exports.tsMethodSignature = tsMethodSignature;
    exports.tSModuleBlock = exports.tsModuleBlock = tsModuleBlock;
    exports.tSModuleDeclaration = exports.tsModuleDeclaration = tsModuleDeclaration;
    exports.tSNamedTupleMember = exports.tsNamedTupleMember = tsNamedTupleMember;
    exports.tSNamespaceExportDeclaration = exports.tsNamespaceExportDeclaration = tsNamespaceExportDeclaration;
    exports.tSNeverKeyword = exports.tsNeverKeyword = tsNeverKeyword;
    exports.tSNonNullExpression = exports.tsNonNullExpression = tsNonNullExpression;
    exports.tSNullKeyword = exports.tsNullKeyword = tsNullKeyword;
    exports.tSNumberKeyword = exports.tsNumberKeyword = tsNumberKeyword;
    exports.tSObjectKeyword = exports.tsObjectKeyword = tsObjectKeyword;
    exports.tSOptionalType = exports.tsOptionalType = tsOptionalType;
    exports.tSParameterProperty = exports.tsParameterProperty = tsParameterProperty;
    exports.tSParenthesizedType = exports.tsParenthesizedType = tsParenthesizedType;
    exports.tSPropertySignature = exports.tsPropertySignature = tsPropertySignature;
    exports.tSQualifiedName = exports.tsQualifiedName = tsQualifiedName;
    exports.tSRestType = exports.tsRestType = tsRestType;
    exports.tSSatisfiesExpression = exports.tsSatisfiesExpression = tsSatisfiesExpression;
    exports.tSStringKeyword = exports.tsStringKeyword = tsStringKeyword;
    exports.tSSymbolKeyword = exports.tsSymbolKeyword = tsSymbolKeyword;
    exports.tSThisType = exports.tsThisType = tsThisType;
    exports.tSTupleType = exports.tsTupleType = tsTupleType;
    exports.tSTypeAliasDeclaration = exports.tsTypeAliasDeclaration = tsTypeAliasDeclaration;
    exports.tSTypeAnnotation = exports.tsTypeAnnotation = tsTypeAnnotation;
    exports.tSTypeAssertion = exports.tsTypeAssertion = tsTypeAssertion;
    exports.tSTypeLiteral = exports.tsTypeLiteral = tsTypeLiteral;
    exports.tSTypeOperator = exports.tsTypeOperator = tsTypeOperator;
    exports.tSTypeParameter = exports.tsTypeParameter = tsTypeParameter;
    exports.tSTypeParameterDeclaration = exports.tsTypeParameterDeclaration = tsTypeParameterDeclaration;
    exports.tSTypeParameterInstantiation = exports.tsTypeParameterInstantiation = tsTypeParameterInstantiation;
    exports.tSTypePredicate = exports.tsTypePredicate = tsTypePredicate;
    exports.tSTypeQuery = exports.tsTypeQuery = tsTypeQuery;
    exports.tSTypeReference = exports.tsTypeReference = tsTypeReference;
    exports.tSUndefinedKeyword = exports.tsUndefinedKeyword = tsUndefinedKeyword;
    exports.tSUnionType = exports.tsUnionType = tsUnionType;
    exports.tSUnknownKeyword = exports.tsUnknownKeyword = tsUnknownKeyword;
    exports.tSVoidKeyword = exports.tsVoidKeyword = tsVoidKeyword;
    exports.tupleExpression = tupleExpression;
    exports.tupleTypeAnnotation = tupleTypeAnnotation;
    exports.typeAlias = typeAlias;
    exports.typeAnnotation = typeAnnotation;
    exports.typeCastExpression = typeCastExpression;
    exports.typeParameter = typeParameter;
    exports.typeParameterDeclaration = typeParameterDeclaration;
    exports.typeParameterInstantiation = typeParameterInstantiation;
    exports.typeofTypeAnnotation = typeofTypeAnnotation;
    exports.unaryExpression = unaryExpression;
    exports.unionTypeAnnotation = unionTypeAnnotation;
    exports.updateExpression = updateExpression;
    exports.v8IntrinsicIdentifier = v8IntrinsicIdentifier;
    exports.variableDeclaration = variableDeclaration2;
    exports.variableDeclarator = variableDeclarator2;
    exports.variance = variance;
    exports.voidTypeAnnotation = voidTypeAnnotation;
    exports.whileStatement = whileStatement;
    exports.withStatement = withStatement;
    exports.yieldExpression = yieldExpression;
    var _validateNode = require_validateNode2();
    var _deprecationWarning = require_deprecationWarning();
    function arrayExpression(elements = []) {
      return (0, _validateNode.default)({
        type: "ArrayExpression",
        elements
      });
    }
    function assignmentExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "AssignmentExpression",
        operator,
        left,
        right
      });
    }
    function binaryExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "BinaryExpression",
        operator,
        left,
        right
      });
    }
    function interpreterDirective(value2) {
      return (0, _validateNode.default)({
        type: "InterpreterDirective",
        value: value2
      });
    }
    function directive(value2) {
      return (0, _validateNode.default)({
        type: "Directive",
        value: value2
      });
    }
    function directiveLiteral(value2) {
      return (0, _validateNode.default)({
        type: "DirectiveLiteral",
        value: value2
      });
    }
    function blockStatement2(body, directives = []) {
      return (0, _validateNode.default)({
        type: "BlockStatement",
        body,
        directives
      });
    }
    function breakStatement(label = null) {
      return (0, _validateNode.default)({
        type: "BreakStatement",
        label
      });
    }
    function callExpression3(callee, _arguments) {
      return (0, _validateNode.default)({
        type: "CallExpression",
        callee,
        arguments: _arguments
      });
    }
    function catchClause(param = null, body) {
      return (0, _validateNode.default)({
        type: "CatchClause",
        param,
        body
      });
    }
    function conditionalExpression(test, consequent, alternate) {
      return (0, _validateNode.default)({
        type: "ConditionalExpression",
        test,
        consequent,
        alternate
      });
    }
    function continueStatement(label = null) {
      return (0, _validateNode.default)({
        type: "ContinueStatement",
        label
      });
    }
    function debuggerStatement() {
      return {
        type: "DebuggerStatement"
      };
    }
    function doWhileStatement(test, body) {
      return (0, _validateNode.default)({
        type: "DoWhileStatement",
        test,
        body
      });
    }
    function emptyStatement() {
      return {
        type: "EmptyStatement"
      };
    }
    function expressionStatement(expression) {
      return (0, _validateNode.default)({
        type: "ExpressionStatement",
        expression
      });
    }
    function file(program3, comments = null, tokens = null) {
      return (0, _validateNode.default)({
        type: "File",
        program: program3,
        comments,
        tokens
      });
    }
    function forInStatement(left, right, body) {
      return (0, _validateNode.default)({
        type: "ForInStatement",
        left,
        right,
        body
      });
    }
    function forStatement(init = null, test = null, update = null, body) {
      return (0, _validateNode.default)({
        type: "ForStatement",
        init,
        test,
        update,
        body
      });
    }
    function functionDeclaration(id = null, params, body, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "FunctionDeclaration",
        id,
        params,
        body,
        generator,
        async
      });
    }
    function functionExpression(id = null, params, body, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "FunctionExpression",
        id,
        params,
        body,
        generator,
        async
      });
    }
    function identifier3(name) {
      return (0, _validateNode.default)({
        type: "Identifier",
        name
      });
    }
    function ifStatement(test, consequent, alternate = null) {
      return (0, _validateNode.default)({
        type: "IfStatement",
        test,
        consequent,
        alternate
      });
    }
    function labeledStatement(label, body) {
      return (0, _validateNode.default)({
        type: "LabeledStatement",
        label,
        body
      });
    }
    function stringLiteral2(value2) {
      return (0, _validateNode.default)({
        type: "StringLiteral",
        value: value2
      });
    }
    function numericLiteral(value2) {
      return (0, _validateNode.default)({
        type: "NumericLiteral",
        value: value2
      });
    }
    function nullLiteral() {
      return {
        type: "NullLiteral"
      };
    }
    function booleanLiteral(value2) {
      return (0, _validateNode.default)({
        type: "BooleanLiteral",
        value: value2
      });
    }
    function regExpLiteral(pattern, flags = "") {
      return (0, _validateNode.default)({
        type: "RegExpLiteral",
        pattern,
        flags
      });
    }
    function logicalExpression(operator, left, right) {
      return (0, _validateNode.default)({
        type: "LogicalExpression",
        operator,
        left,
        right
      });
    }
    function memberExpression(object, property, computed = false, optional = null) {
      return (0, _validateNode.default)({
        type: "MemberExpression",
        object,
        property,
        computed,
        optional
      });
    }
    function newExpression(callee, _arguments) {
      return (0, _validateNode.default)({
        type: "NewExpression",
        callee,
        arguments: _arguments
      });
    }
    function program2(body, directives = [], sourceType = "script", interpreter = null) {
      return (0, _validateNode.default)({
        type: "Program",
        body,
        directives,
        sourceType,
        interpreter,
        sourceFile: null
      });
    }
    function objectExpression(properties) {
      return (0, _validateNode.default)({
        type: "ObjectExpression",
        properties
      });
    }
    function objectMethod(kind = "method", key, params, body, computed = false, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "ObjectMethod",
        kind,
        key,
        params,
        body,
        computed,
        generator,
        async
      });
    }
    function objectProperty2(key, value2, computed = false, shorthand = false, decorators = null) {
      return (0, _validateNode.default)({
        type: "ObjectProperty",
        key,
        value: value2,
        computed,
        shorthand,
        decorators
      });
    }
    function restElement(argument) {
      return (0, _validateNode.default)({
        type: "RestElement",
        argument
      });
    }
    function returnStatement2(argument = null) {
      return (0, _validateNode.default)({
        type: "ReturnStatement",
        argument
      });
    }
    function sequenceExpression(expressions) {
      return (0, _validateNode.default)({
        type: "SequenceExpression",
        expressions
      });
    }
    function parenthesizedExpression(expression) {
      return (0, _validateNode.default)({
        type: "ParenthesizedExpression",
        expression
      });
    }
    function switchCase(test = null, consequent) {
      return (0, _validateNode.default)({
        type: "SwitchCase",
        test,
        consequent
      });
    }
    function switchStatement(discriminant, cases) {
      return (0, _validateNode.default)({
        type: "SwitchStatement",
        discriminant,
        cases
      });
    }
    function thisExpression() {
      return {
        type: "ThisExpression"
      };
    }
    function throwStatement(argument) {
      return (0, _validateNode.default)({
        type: "ThrowStatement",
        argument
      });
    }
    function tryStatement(block, handler = null, finalizer = null) {
      return (0, _validateNode.default)({
        type: "TryStatement",
        block,
        handler,
        finalizer
      });
    }
    function unaryExpression(operator, argument, prefix = true) {
      return (0, _validateNode.default)({
        type: "UnaryExpression",
        operator,
        argument,
        prefix
      });
    }
    function updateExpression(operator, argument, prefix = false) {
      return (0, _validateNode.default)({
        type: "UpdateExpression",
        operator,
        argument,
        prefix
      });
    }
    function variableDeclaration2(kind, declarations) {
      return (0, _validateNode.default)({
        type: "VariableDeclaration",
        kind,
        declarations
      });
    }
    function variableDeclarator2(id, init = null) {
      return (0, _validateNode.default)({
        type: "VariableDeclarator",
        id,
        init
      });
    }
    function whileStatement(test, body) {
      return (0, _validateNode.default)({
        type: "WhileStatement",
        test,
        body
      });
    }
    function withStatement(object, body) {
      return (0, _validateNode.default)({
        type: "WithStatement",
        object,
        body
      });
    }
    function assignmentPattern(left, right) {
      return (0, _validateNode.default)({
        type: "AssignmentPattern",
        left,
        right
      });
    }
    function arrayPattern(elements) {
      return (0, _validateNode.default)({
        type: "ArrayPattern",
        elements
      });
    }
    function arrowFunctionExpression(params, body, async = false) {
      return (0, _validateNode.default)({
        type: "ArrowFunctionExpression",
        params,
        body,
        async,
        expression: null
      });
    }
    function classBody(body) {
      return (0, _validateNode.default)({
        type: "ClassBody",
        body
      });
    }
    function classExpression(id = null, superClass = null, body, decorators = null) {
      return (0, _validateNode.default)({
        type: "ClassExpression",
        id,
        superClass,
        body,
        decorators
      });
    }
    function classDeclaration(id = null, superClass = null, body, decorators = null) {
      return (0, _validateNode.default)({
        type: "ClassDeclaration",
        id,
        superClass,
        body,
        decorators
      });
    }
    function exportAllDeclaration(source) {
      return (0, _validateNode.default)({
        type: "ExportAllDeclaration",
        source
      });
    }
    function exportDefaultDeclaration(declaration) {
      return (0, _validateNode.default)({
        type: "ExportDefaultDeclaration",
        declaration
      });
    }
    function exportNamedDeclaration(declaration = null, specifiers = [], source = null) {
      return (0, _validateNode.default)({
        type: "ExportNamedDeclaration",
        declaration,
        specifiers,
        source
      });
    }
    function exportSpecifier(local, exported) {
      return (0, _validateNode.default)({
        type: "ExportSpecifier",
        local,
        exported
      });
    }
    function forOfStatement(left, right, body, _await = false) {
      return (0, _validateNode.default)({
        type: "ForOfStatement",
        left,
        right,
        body,
        await: _await
      });
    }
    function importDeclaration(specifiers, source) {
      return (0, _validateNode.default)({
        type: "ImportDeclaration",
        specifiers,
        source
      });
    }
    function importDefaultSpecifier(local) {
      return (0, _validateNode.default)({
        type: "ImportDefaultSpecifier",
        local
      });
    }
    function importNamespaceSpecifier(local) {
      return (0, _validateNode.default)({
        type: "ImportNamespaceSpecifier",
        local
      });
    }
    function importSpecifier2(local, imported) {
      return (0, _validateNode.default)({
        type: "ImportSpecifier",
        local,
        imported
      });
    }
    function metaProperty(meta, property) {
      return (0, _validateNode.default)({
        type: "MetaProperty",
        meta,
        property
      });
    }
    function classMethod(kind = "method", key, params, body, computed = false, _static = false, generator = false, async = false) {
      return (0, _validateNode.default)({
        type: "ClassMethod",
        kind,
        key,
        params,
        body,
        computed,
        static: _static,
        generator,
        async
      });
    }
    function objectPattern2(properties) {
      return (0, _validateNode.default)({
        type: "ObjectPattern",
        properties
      });
    }
    function spreadElement(argument) {
      return (0, _validateNode.default)({
        type: "SpreadElement",
        argument
      });
    }
    function _super() {
      return {
        type: "Super"
      };
    }
    function taggedTemplateExpression(tag, quasi) {
      return (0, _validateNode.default)({
        type: "TaggedTemplateExpression",
        tag,
        quasi
      });
    }
    function templateElement(value2, tail = false) {
      return (0, _validateNode.default)({
        type: "TemplateElement",
        value: value2,
        tail
      });
    }
    function templateLiteral(quasis, expressions) {
      return (0, _validateNode.default)({
        type: "TemplateLiteral",
        quasis,
        expressions
      });
    }
    function yieldExpression(argument = null, delegate = false) {
      return (0, _validateNode.default)({
        type: "YieldExpression",
        argument,
        delegate
      });
    }
    function awaitExpression(argument) {
      return (0, _validateNode.default)({
        type: "AwaitExpression",
        argument
      });
    }
    function _import() {
      return {
        type: "Import"
      };
    }
    function bigIntLiteral(value2) {
      return (0, _validateNode.default)({
        type: "BigIntLiteral",
        value: value2
      });
    }
    function exportNamespaceSpecifier(exported) {
      return (0, _validateNode.default)({
        type: "ExportNamespaceSpecifier",
        exported
      });
    }
    function optionalMemberExpression(object, property, computed = false, optional) {
      return (0, _validateNode.default)({
        type: "OptionalMemberExpression",
        object,
        property,
        computed,
        optional
      });
    }
    function optionalCallExpression(callee, _arguments, optional) {
      return (0, _validateNode.default)({
        type: "OptionalCallExpression",
        callee,
        arguments: _arguments,
        optional
      });
    }
    function classProperty(key, value2 = null, typeAnnotation2 = null, decorators = null, computed = false, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassProperty",
        key,
        value: value2,
        typeAnnotation: typeAnnotation2,
        decorators,
        computed,
        static: _static
      });
    }
    function classAccessorProperty(key, value2 = null, typeAnnotation2 = null, decorators = null, computed = false, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassAccessorProperty",
        key,
        value: value2,
        typeAnnotation: typeAnnotation2,
        decorators,
        computed,
        static: _static
      });
    }
    function classPrivateProperty(key, value2 = null, decorators = null, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassPrivateProperty",
        key,
        value: value2,
        decorators,
        static: _static
      });
    }
    function classPrivateMethod(kind = "method", key, params, body, _static = false) {
      return (0, _validateNode.default)({
        type: "ClassPrivateMethod",
        kind,
        key,
        params,
        body,
        static: _static
      });
    }
    function privateName(id) {
      return (0, _validateNode.default)({
        type: "PrivateName",
        id
      });
    }
    function staticBlock(body) {
      return (0, _validateNode.default)({
        type: "StaticBlock",
        body
      });
    }
    function anyTypeAnnotation() {
      return {
        type: "AnyTypeAnnotation"
      };
    }
    function arrayTypeAnnotation(elementType) {
      return (0, _validateNode.default)({
        type: "ArrayTypeAnnotation",
        elementType
      });
    }
    function booleanTypeAnnotation() {
      return {
        type: "BooleanTypeAnnotation"
      };
    }
    function booleanLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "BooleanLiteralTypeAnnotation",
        value: value2
      });
    }
    function nullLiteralTypeAnnotation() {
      return {
        type: "NullLiteralTypeAnnotation"
      };
    }
    function classImplements(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "ClassImplements",
        id,
        typeParameters
      });
    }
    function declareClass(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "DeclareClass",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function declareFunction(id) {
      return (0, _validateNode.default)({
        type: "DeclareFunction",
        id
      });
    }
    function declareInterface(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "DeclareInterface",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function declareModule(id, body, kind = null) {
      return (0, _validateNode.default)({
        type: "DeclareModule",
        id,
        body,
        kind
      });
    }
    function declareModuleExports(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "DeclareModuleExports",
        typeAnnotation: typeAnnotation2
      });
    }
    function declareTypeAlias(id, typeParameters = null, right) {
      return (0, _validateNode.default)({
        type: "DeclareTypeAlias",
        id,
        typeParameters,
        right
      });
    }
    function declareOpaqueType(id, typeParameters = null, supertype = null) {
      return (0, _validateNode.default)({
        type: "DeclareOpaqueType",
        id,
        typeParameters,
        supertype
      });
    }
    function declareVariable(id) {
      return (0, _validateNode.default)({
        type: "DeclareVariable",
        id
      });
    }
    function declareExportDeclaration(declaration = null, specifiers = null, source = null) {
      return (0, _validateNode.default)({
        type: "DeclareExportDeclaration",
        declaration,
        specifiers,
        source
      });
    }
    function declareExportAllDeclaration(source) {
      return (0, _validateNode.default)({
        type: "DeclareExportAllDeclaration",
        source
      });
    }
    function declaredPredicate(value2) {
      return (0, _validateNode.default)({
        type: "DeclaredPredicate",
        value: value2
      });
    }
    function existsTypeAnnotation() {
      return {
        type: "ExistsTypeAnnotation"
      };
    }
    function functionTypeAnnotation(typeParameters = null, params, rest = null, returnType) {
      return (0, _validateNode.default)({
        type: "FunctionTypeAnnotation",
        typeParameters,
        params,
        rest,
        returnType
      });
    }
    function functionTypeParam(name = null, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "FunctionTypeParam",
        name,
        typeAnnotation: typeAnnotation2
      });
    }
    function genericTypeAnnotation(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "GenericTypeAnnotation",
        id,
        typeParameters
      });
    }
    function inferredPredicate() {
      return {
        type: "InferredPredicate"
      };
    }
    function interfaceExtends(id, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "InterfaceExtends",
        id,
        typeParameters
      });
    }
    function interfaceDeclaration(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "InterfaceDeclaration",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function interfaceTypeAnnotation(_extends = null, body) {
      return (0, _validateNode.default)({
        type: "InterfaceTypeAnnotation",
        extends: _extends,
        body
      });
    }
    function intersectionTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "IntersectionTypeAnnotation",
        types
      });
    }
    function mixedTypeAnnotation() {
      return {
        type: "MixedTypeAnnotation"
      };
    }
    function emptyTypeAnnotation() {
      return {
        type: "EmptyTypeAnnotation"
      };
    }
    function nullableTypeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "NullableTypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function numberLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "NumberLiteralTypeAnnotation",
        value: value2
      });
    }
    function numberTypeAnnotation() {
      return {
        type: "NumberTypeAnnotation"
      };
    }
    function objectTypeAnnotation(properties, indexers = [], callProperties = [], internalSlots = [], exact = false) {
      return (0, _validateNode.default)({
        type: "ObjectTypeAnnotation",
        properties,
        indexers,
        callProperties,
        internalSlots,
        exact
      });
    }
    function objectTypeInternalSlot(id, value2, optional, _static, method) {
      return (0, _validateNode.default)({
        type: "ObjectTypeInternalSlot",
        id,
        value: value2,
        optional,
        static: _static,
        method
      });
    }
    function objectTypeCallProperty(value2) {
      return (0, _validateNode.default)({
        type: "ObjectTypeCallProperty",
        value: value2,
        static: null
      });
    }
    function objectTypeIndexer(id = null, key, value2, variance2 = null) {
      return (0, _validateNode.default)({
        type: "ObjectTypeIndexer",
        id,
        key,
        value: value2,
        variance: variance2,
        static: null
      });
    }
    function objectTypeProperty(key, value2, variance2 = null) {
      return (0, _validateNode.default)({
        type: "ObjectTypeProperty",
        key,
        value: value2,
        variance: variance2,
        kind: null,
        method: null,
        optional: null,
        proto: null,
        static: null
      });
    }
    function objectTypeSpreadProperty(argument) {
      return (0, _validateNode.default)({
        type: "ObjectTypeSpreadProperty",
        argument
      });
    }
    function opaqueType(id, typeParameters = null, supertype = null, impltype) {
      return (0, _validateNode.default)({
        type: "OpaqueType",
        id,
        typeParameters,
        supertype,
        impltype
      });
    }
    function qualifiedTypeIdentifier(id, qualification) {
      return (0, _validateNode.default)({
        type: "QualifiedTypeIdentifier",
        id,
        qualification
      });
    }
    function stringLiteralTypeAnnotation(value2) {
      return (0, _validateNode.default)({
        type: "StringLiteralTypeAnnotation",
        value: value2
      });
    }
    function stringTypeAnnotation() {
      return {
        type: "StringTypeAnnotation"
      };
    }
    function symbolTypeAnnotation() {
      return {
        type: "SymbolTypeAnnotation"
      };
    }
    function thisTypeAnnotation() {
      return {
        type: "ThisTypeAnnotation"
      };
    }
    function tupleTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "TupleTypeAnnotation",
        types
      });
    }
    function typeofTypeAnnotation(argument) {
      return (0, _validateNode.default)({
        type: "TypeofTypeAnnotation",
        argument
      });
    }
    function typeAlias(id, typeParameters = null, right) {
      return (0, _validateNode.default)({
        type: "TypeAlias",
        id,
        typeParameters,
        right
      });
    }
    function typeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function typeCastExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TypeCastExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function typeParameter(bound = null, _default = null, variance2 = null) {
      return (0, _validateNode.default)({
        type: "TypeParameter",
        bound,
        default: _default,
        variance: variance2,
        name: null
      });
    }
    function typeParameterDeclaration(params) {
      return (0, _validateNode.default)({
        type: "TypeParameterDeclaration",
        params
      });
    }
    function typeParameterInstantiation(params) {
      return (0, _validateNode.default)({
        type: "TypeParameterInstantiation",
        params
      });
    }
    function unionTypeAnnotation(types) {
      return (0, _validateNode.default)({
        type: "UnionTypeAnnotation",
        types
      });
    }
    function variance(kind) {
      return (0, _validateNode.default)({
        type: "Variance",
        kind
      });
    }
    function voidTypeAnnotation() {
      return {
        type: "VoidTypeAnnotation"
      };
    }
    function enumDeclaration(id, body) {
      return (0, _validateNode.default)({
        type: "EnumDeclaration",
        id,
        body
      });
    }
    function enumBooleanBody(members) {
      return (0, _validateNode.default)({
        type: "EnumBooleanBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumNumberBody(members) {
      return (0, _validateNode.default)({
        type: "EnumNumberBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumStringBody(members) {
      return (0, _validateNode.default)({
        type: "EnumStringBody",
        members,
        explicitType: null,
        hasUnknownMembers: null
      });
    }
    function enumSymbolBody(members) {
      return (0, _validateNode.default)({
        type: "EnumSymbolBody",
        members,
        hasUnknownMembers: null
      });
    }
    function enumBooleanMember(id) {
      return (0, _validateNode.default)({
        type: "EnumBooleanMember",
        id,
        init: null
      });
    }
    function enumNumberMember(id, init) {
      return (0, _validateNode.default)({
        type: "EnumNumberMember",
        id,
        init
      });
    }
    function enumStringMember(id, init) {
      return (0, _validateNode.default)({
        type: "EnumStringMember",
        id,
        init
      });
    }
    function enumDefaultedMember(id) {
      return (0, _validateNode.default)({
        type: "EnumDefaultedMember",
        id
      });
    }
    function indexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "IndexedAccessType",
        objectType,
        indexType
      });
    }
    function optionalIndexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "OptionalIndexedAccessType",
        objectType,
        indexType,
        optional: null
      });
    }
    function jsxAttribute(name, value2 = null) {
      return (0, _validateNode.default)({
        type: "JSXAttribute",
        name,
        value: value2
      });
    }
    function jsxClosingElement(name) {
      return (0, _validateNode.default)({
        type: "JSXClosingElement",
        name
      });
    }
    function jsxElement(openingElement, closingElement = null, children, selfClosing = null) {
      return (0, _validateNode.default)({
        type: "JSXElement",
        openingElement,
        closingElement,
        children,
        selfClosing
      });
    }
    function jsxEmptyExpression() {
      return {
        type: "JSXEmptyExpression"
      };
    }
    function jsxExpressionContainer(expression) {
      return (0, _validateNode.default)({
        type: "JSXExpressionContainer",
        expression
      });
    }
    function jsxSpreadChild(expression) {
      return (0, _validateNode.default)({
        type: "JSXSpreadChild",
        expression
      });
    }
    function jsxIdentifier(name) {
      return (0, _validateNode.default)({
        type: "JSXIdentifier",
        name
      });
    }
    function jsxMemberExpression(object, property) {
      return (0, _validateNode.default)({
        type: "JSXMemberExpression",
        object,
        property
      });
    }
    function jsxNamespacedName(namespace, name) {
      return (0, _validateNode.default)({
        type: "JSXNamespacedName",
        namespace,
        name
      });
    }
    function jsxOpeningElement(name, attributes, selfClosing = false) {
      return (0, _validateNode.default)({
        type: "JSXOpeningElement",
        name,
        attributes,
        selfClosing
      });
    }
    function jsxSpreadAttribute(argument) {
      return (0, _validateNode.default)({
        type: "JSXSpreadAttribute",
        argument
      });
    }
    function jsxText(value2) {
      return (0, _validateNode.default)({
        type: "JSXText",
        value: value2
      });
    }
    function jsxFragment(openingFragment, closingFragment, children) {
      return (0, _validateNode.default)({
        type: "JSXFragment",
        openingFragment,
        closingFragment,
        children
      });
    }
    function jsxOpeningFragment() {
      return {
        type: "JSXOpeningFragment"
      };
    }
    function jsxClosingFragment() {
      return {
        type: "JSXClosingFragment"
      };
    }
    function noop() {
      return {
        type: "Noop"
      };
    }
    function placeholder(expectedNode, name) {
      return (0, _validateNode.default)({
        type: "Placeholder",
        expectedNode,
        name
      });
    }
    function v8IntrinsicIdentifier(name) {
      return (0, _validateNode.default)({
        type: "V8IntrinsicIdentifier",
        name
      });
    }
    function argumentPlaceholder() {
      return {
        type: "ArgumentPlaceholder"
      };
    }
    function bindExpression(object, callee) {
      return (0, _validateNode.default)({
        type: "BindExpression",
        object,
        callee
      });
    }
    function importAttribute(key, value2) {
      return (0, _validateNode.default)({
        type: "ImportAttribute",
        key,
        value: value2
      });
    }
    function decorator(expression) {
      return (0, _validateNode.default)({
        type: "Decorator",
        expression
      });
    }
    function doExpression(body, async = false) {
      return (0, _validateNode.default)({
        type: "DoExpression",
        body,
        async
      });
    }
    function exportDefaultSpecifier(exported) {
      return (0, _validateNode.default)({
        type: "ExportDefaultSpecifier",
        exported
      });
    }
    function recordExpression(properties) {
      return (0, _validateNode.default)({
        type: "RecordExpression",
        properties
      });
    }
    function tupleExpression(elements = []) {
      return (0, _validateNode.default)({
        type: "TupleExpression",
        elements
      });
    }
    function decimalLiteral(value2) {
      return (0, _validateNode.default)({
        type: "DecimalLiteral",
        value: value2
      });
    }
    function moduleExpression(body) {
      return (0, _validateNode.default)({
        type: "ModuleExpression",
        body
      });
    }
    function topicReference() {
      return {
        type: "TopicReference"
      };
    }
    function pipelineTopicExpression(expression) {
      return (0, _validateNode.default)({
        type: "PipelineTopicExpression",
        expression
      });
    }
    function pipelineBareFunction(callee) {
      return (0, _validateNode.default)({
        type: "PipelineBareFunction",
        callee
      });
    }
    function pipelinePrimaryTopicReference() {
      return {
        type: "PipelinePrimaryTopicReference"
      };
    }
    function tsParameterProperty(parameter) {
      return (0, _validateNode.default)({
        type: "TSParameterProperty",
        parameter
      });
    }
    function tsDeclareFunction(id = null, typeParameters = null, params, returnType = null) {
      return (0, _validateNode.default)({
        type: "TSDeclareFunction",
        id,
        typeParameters,
        params,
        returnType
      });
    }
    function tsDeclareMethod(decorators = null, key, typeParameters = null, params, returnType = null) {
      return (0, _validateNode.default)({
        type: "TSDeclareMethod",
        decorators,
        key,
        typeParameters,
        params,
        returnType
      });
    }
    function tsQualifiedName(left, right) {
      return (0, _validateNode.default)({
        type: "TSQualifiedName",
        left,
        right
      });
    }
    function tsCallSignatureDeclaration(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSCallSignatureDeclaration",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsConstructSignatureDeclaration(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSConstructSignatureDeclaration",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsPropertySignature(key, typeAnnotation2 = null, initializer = null) {
      return (0, _validateNode.default)({
        type: "TSPropertySignature",
        key,
        typeAnnotation: typeAnnotation2,
        initializer,
        kind: null
      });
    }
    function tsMethodSignature(key, typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSMethodSignature",
        key,
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2,
        kind: null
      });
    }
    function tsIndexSignature(parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSIndexSignature",
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsAnyKeyword() {
      return {
        type: "TSAnyKeyword"
      };
    }
    function tsBooleanKeyword() {
      return {
        type: "TSBooleanKeyword"
      };
    }
    function tsBigIntKeyword() {
      return {
        type: "TSBigIntKeyword"
      };
    }
    function tsIntrinsicKeyword() {
      return {
        type: "TSIntrinsicKeyword"
      };
    }
    function tsNeverKeyword() {
      return {
        type: "TSNeverKeyword"
      };
    }
    function tsNullKeyword() {
      return {
        type: "TSNullKeyword"
      };
    }
    function tsNumberKeyword() {
      return {
        type: "TSNumberKeyword"
      };
    }
    function tsObjectKeyword() {
      return {
        type: "TSObjectKeyword"
      };
    }
    function tsStringKeyword() {
      return {
        type: "TSStringKeyword"
      };
    }
    function tsSymbolKeyword() {
      return {
        type: "TSSymbolKeyword"
      };
    }
    function tsUndefinedKeyword() {
      return {
        type: "TSUndefinedKeyword"
      };
    }
    function tsUnknownKeyword() {
      return {
        type: "TSUnknownKeyword"
      };
    }
    function tsVoidKeyword() {
      return {
        type: "TSVoidKeyword"
      };
    }
    function tsThisType() {
      return {
        type: "TSThisType"
      };
    }
    function tsFunctionType(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSFunctionType",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsConstructorType(typeParameters = null, parameters, typeAnnotation2 = null) {
      return (0, _validateNode.default)({
        type: "TSConstructorType",
        typeParameters,
        parameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeReference(typeName, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSTypeReference",
        typeName,
        typeParameters
      });
    }
    function tsTypePredicate(parameterName, typeAnnotation2 = null, asserts = null) {
      return (0, _validateNode.default)({
        type: "TSTypePredicate",
        parameterName,
        typeAnnotation: typeAnnotation2,
        asserts
      });
    }
    function tsTypeQuery(exprName, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSTypeQuery",
        exprName,
        typeParameters
      });
    }
    function tsTypeLiteral(members) {
      return (0, _validateNode.default)({
        type: "TSTypeLiteral",
        members
      });
    }
    function tsArrayType(elementType) {
      return (0, _validateNode.default)({
        type: "TSArrayType",
        elementType
      });
    }
    function tsTupleType(elementTypes) {
      return (0, _validateNode.default)({
        type: "TSTupleType",
        elementTypes
      });
    }
    function tsOptionalType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSOptionalType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsRestType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSRestType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsNamedTupleMember(label, elementType, optional = false) {
      return (0, _validateNode.default)({
        type: "TSNamedTupleMember",
        label,
        elementType,
        optional
      });
    }
    function tsUnionType(types) {
      return (0, _validateNode.default)({
        type: "TSUnionType",
        types
      });
    }
    function tsIntersectionType(types) {
      return (0, _validateNode.default)({
        type: "TSIntersectionType",
        types
      });
    }
    function tsConditionalType(checkType, extendsType, trueType, falseType) {
      return (0, _validateNode.default)({
        type: "TSConditionalType",
        checkType,
        extendsType,
        trueType,
        falseType
      });
    }
    function tsInferType(typeParameter2) {
      return (0, _validateNode.default)({
        type: "TSInferType",
        typeParameter: typeParameter2
      });
    }
    function tsParenthesizedType(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSParenthesizedType",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeOperator(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeOperator",
        typeAnnotation: typeAnnotation2,
        operator: null
      });
    }
    function tsIndexedAccessType(objectType, indexType) {
      return (0, _validateNode.default)({
        type: "TSIndexedAccessType",
        objectType,
        indexType
      });
    }
    function tsMappedType(typeParameter2, typeAnnotation2 = null, nameType = null) {
      return (0, _validateNode.default)({
        type: "TSMappedType",
        typeParameter: typeParameter2,
        typeAnnotation: typeAnnotation2,
        nameType
      });
    }
    function tsLiteralType(literal) {
      return (0, _validateNode.default)({
        type: "TSLiteralType",
        literal
      });
    }
    function tsExpressionWithTypeArguments(expression, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSExpressionWithTypeArguments",
        expression,
        typeParameters
      });
    }
    function tsInterfaceDeclaration(id, typeParameters = null, _extends = null, body) {
      return (0, _validateNode.default)({
        type: "TSInterfaceDeclaration",
        id,
        typeParameters,
        extends: _extends,
        body
      });
    }
    function tsInterfaceBody(body) {
      return (0, _validateNode.default)({
        type: "TSInterfaceBody",
        body
      });
    }
    function tsTypeAliasDeclaration(id, typeParameters = null, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeAliasDeclaration",
        id,
        typeParameters,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsInstantiationExpression(expression, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSInstantiationExpression",
        expression,
        typeParameters
      });
    }
    function tsAsExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSAsExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsSatisfiesExpression(expression, typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSSatisfiesExpression",
        expression,
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeAssertion(typeAnnotation2, expression) {
      return (0, _validateNode.default)({
        type: "TSTypeAssertion",
        typeAnnotation: typeAnnotation2,
        expression
      });
    }
    function tsEnumDeclaration(id, members) {
      return (0, _validateNode.default)({
        type: "TSEnumDeclaration",
        id,
        members
      });
    }
    function tsEnumMember(id, initializer = null) {
      return (0, _validateNode.default)({
        type: "TSEnumMember",
        id,
        initializer
      });
    }
    function tsModuleDeclaration(id, body) {
      return (0, _validateNode.default)({
        type: "TSModuleDeclaration",
        id,
        body
      });
    }
    function tsModuleBlock(body) {
      return (0, _validateNode.default)({
        type: "TSModuleBlock",
        body
      });
    }
    function tsImportType(argument, qualifier = null, typeParameters = null) {
      return (0, _validateNode.default)({
        type: "TSImportType",
        argument,
        qualifier,
        typeParameters
      });
    }
    function tsImportEqualsDeclaration(id, moduleReference) {
      return (0, _validateNode.default)({
        type: "TSImportEqualsDeclaration",
        id,
        moduleReference,
        isExport: null
      });
    }
    function tsExternalModuleReference(expression) {
      return (0, _validateNode.default)({
        type: "TSExternalModuleReference",
        expression
      });
    }
    function tsNonNullExpression(expression) {
      return (0, _validateNode.default)({
        type: "TSNonNullExpression",
        expression
      });
    }
    function tsExportAssignment(expression) {
      return (0, _validateNode.default)({
        type: "TSExportAssignment",
        expression
      });
    }
    function tsNamespaceExportDeclaration(id) {
      return (0, _validateNode.default)({
        type: "TSNamespaceExportDeclaration",
        id
      });
    }
    function tsTypeAnnotation(typeAnnotation2) {
      return (0, _validateNode.default)({
        type: "TSTypeAnnotation",
        typeAnnotation: typeAnnotation2
      });
    }
    function tsTypeParameterInstantiation(params) {
      return (0, _validateNode.default)({
        type: "TSTypeParameterInstantiation",
        params
      });
    }
    function tsTypeParameterDeclaration(params) {
      return (0, _validateNode.default)({
        type: "TSTypeParameterDeclaration",
        params
      });
    }
    function tsTypeParameter(constraint = null, _default = null, name) {
      return (0, _validateNode.default)({
        type: "TSTypeParameter",
        constraint,
        default: _default,
        name
      });
    }
    function NumberLiteral(value2) {
      (0, _deprecationWarning.default)("NumberLiteral", "NumericLiteral", "The node type ");
      return numericLiteral(value2);
    }
    function RegexLiteral(pattern, flags = "") {
      (0, _deprecationWarning.default)("RegexLiteral", "RegExpLiteral", "The node type ");
      return regExpLiteral(pattern, flags);
    }
    function RestProperty(argument) {
      (0, _deprecationWarning.default)("RestProperty", "RestElement", "The node type ");
      return restElement(argument);
    }
    function SpreadProperty(argument) {
      (0, _deprecationWarning.default)("SpreadProperty", "SpreadElement", "The node type ");
      return spreadElement(argument);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js
var require_cleanJSXElementLiteralChild2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cleanJSXElementLiteralChild;
    var _index = require_generated7();
    var _index2 = require_lib31();
    function cleanJSXElementLiteralChild(child, args) {
      const lines = child.value.split(/\r\n|\n|\r/);
      let lastNonEmptyLine = 0;
      for (let i = 0; i < lines.length; i++) {
        if (lines[i].match(/[^ \t]/)) {
          lastNonEmptyLine = i;
        }
      }
      let str = "";
      for (let i = 0; i < lines.length; i++) {
        const line = lines[i];
        const isFirstLine = i === 0;
        const isLastLine = i === lines.length - 1;
        const isLastNonEmptyLine = i === lastNonEmptyLine;
        let trimmedLine = line.replace(/\t/g, " ");
        if (!isFirstLine) {
          trimmedLine = trimmedLine.replace(/^[ ]+/, "");
        }
        if (!isLastLine) {
          trimmedLine = trimmedLine.replace(/[ ]+$/, "");
        }
        if (trimmedLine) {
          if (!isLastNonEmptyLine) {
            trimmedLine += " ";
          }
          str += trimmedLine;
        }
      }
      if (str)
        args.push((0, _index2.inherits)((0, _index.stringLiteral)(str), child));
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/react/buildChildren.js
var require_buildChildren2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/react/buildChildren.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = buildChildren;
    var _index = require_generated6();
    var _cleanJSXElementLiteralChild = require_cleanJSXElementLiteralChild2();
    function buildChildren(node) {
      const elements = [];
      for (let i = 0; i < node.children.length; i++) {
        let child = node.children[i];
        if ((0, _index.isJSXText)(child)) {
          (0, _cleanJSXElementLiteralChild.default)(child, elements);
          continue;
        }
        if ((0, _index.isJSXExpressionContainer)(child))
          child = child.expression;
        if ((0, _index.isJSXEmptyExpression)(child))
          continue;
        elements.push(child);
      }
      return elements;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isNode.js
var require_isNode2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isNode;
    var _index = require_definitions2();
    function isNode(node) {
      return !!(node && _index.VISITOR_KEYS[node.type]);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/asserts/assertNode.js
var require_assertNode2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/asserts/assertNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = assertNode;
    var _isNode = require_isNode2();
    function assertNode(node) {
      if (!(0, _isNode.default)(node)) {
        var _node$type;
        const type = (_node$type = node == null ? void 0 : node.type) != null ? _node$type : JSON.stringify(node);
        throw new TypeError(`Not a valid node of type "${type}"`);
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/asserts/generated/index.js
var require_generated8 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/asserts/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.assertAccessor = assertAccessor;
    exports.assertAnyTypeAnnotation = assertAnyTypeAnnotation;
    exports.assertArgumentPlaceholder = assertArgumentPlaceholder;
    exports.assertArrayExpression = assertArrayExpression;
    exports.assertArrayPattern = assertArrayPattern;
    exports.assertArrayTypeAnnotation = assertArrayTypeAnnotation;
    exports.assertArrowFunctionExpression = assertArrowFunctionExpression;
    exports.assertAssignmentExpression = assertAssignmentExpression;
    exports.assertAssignmentPattern = assertAssignmentPattern;
    exports.assertAwaitExpression = assertAwaitExpression;
    exports.assertBigIntLiteral = assertBigIntLiteral;
    exports.assertBinary = assertBinary;
    exports.assertBinaryExpression = assertBinaryExpression;
    exports.assertBindExpression = assertBindExpression;
    exports.assertBlock = assertBlock;
    exports.assertBlockParent = assertBlockParent;
    exports.assertBlockStatement = assertBlockStatement;
    exports.assertBooleanLiteral = assertBooleanLiteral;
    exports.assertBooleanLiteralTypeAnnotation = assertBooleanLiteralTypeAnnotation;
    exports.assertBooleanTypeAnnotation = assertBooleanTypeAnnotation;
    exports.assertBreakStatement = assertBreakStatement;
    exports.assertCallExpression = assertCallExpression;
    exports.assertCatchClause = assertCatchClause;
    exports.assertClass = assertClass;
    exports.assertClassAccessorProperty = assertClassAccessorProperty;
    exports.assertClassBody = assertClassBody;
    exports.assertClassDeclaration = assertClassDeclaration;
    exports.assertClassExpression = assertClassExpression;
    exports.assertClassImplements = assertClassImplements;
    exports.assertClassMethod = assertClassMethod;
    exports.assertClassPrivateMethod = assertClassPrivateMethod;
    exports.assertClassPrivateProperty = assertClassPrivateProperty;
    exports.assertClassProperty = assertClassProperty;
    exports.assertCompletionStatement = assertCompletionStatement;
    exports.assertConditional = assertConditional;
    exports.assertConditionalExpression = assertConditionalExpression;
    exports.assertContinueStatement = assertContinueStatement;
    exports.assertDebuggerStatement = assertDebuggerStatement;
    exports.assertDecimalLiteral = assertDecimalLiteral;
    exports.assertDeclaration = assertDeclaration;
    exports.assertDeclareClass = assertDeclareClass;
    exports.assertDeclareExportAllDeclaration = assertDeclareExportAllDeclaration;
    exports.assertDeclareExportDeclaration = assertDeclareExportDeclaration;
    exports.assertDeclareFunction = assertDeclareFunction;
    exports.assertDeclareInterface = assertDeclareInterface;
    exports.assertDeclareModule = assertDeclareModule;
    exports.assertDeclareModuleExports = assertDeclareModuleExports;
    exports.assertDeclareOpaqueType = assertDeclareOpaqueType;
    exports.assertDeclareTypeAlias = assertDeclareTypeAlias;
    exports.assertDeclareVariable = assertDeclareVariable;
    exports.assertDeclaredPredicate = assertDeclaredPredicate;
    exports.assertDecorator = assertDecorator;
    exports.assertDirective = assertDirective;
    exports.assertDirectiveLiteral = assertDirectiveLiteral;
    exports.assertDoExpression = assertDoExpression;
    exports.assertDoWhileStatement = assertDoWhileStatement;
    exports.assertEmptyStatement = assertEmptyStatement;
    exports.assertEmptyTypeAnnotation = assertEmptyTypeAnnotation;
    exports.assertEnumBody = assertEnumBody;
    exports.assertEnumBooleanBody = assertEnumBooleanBody;
    exports.assertEnumBooleanMember = assertEnumBooleanMember;
    exports.assertEnumDeclaration = assertEnumDeclaration;
    exports.assertEnumDefaultedMember = assertEnumDefaultedMember;
    exports.assertEnumMember = assertEnumMember;
    exports.assertEnumNumberBody = assertEnumNumberBody;
    exports.assertEnumNumberMember = assertEnumNumberMember;
    exports.assertEnumStringBody = assertEnumStringBody;
    exports.assertEnumStringMember = assertEnumStringMember;
    exports.assertEnumSymbolBody = assertEnumSymbolBody;
    exports.assertExistsTypeAnnotation = assertExistsTypeAnnotation;
    exports.assertExportAllDeclaration = assertExportAllDeclaration;
    exports.assertExportDeclaration = assertExportDeclaration;
    exports.assertExportDefaultDeclaration = assertExportDefaultDeclaration;
    exports.assertExportDefaultSpecifier = assertExportDefaultSpecifier;
    exports.assertExportNamedDeclaration = assertExportNamedDeclaration;
    exports.assertExportNamespaceSpecifier = assertExportNamespaceSpecifier;
    exports.assertExportSpecifier = assertExportSpecifier;
    exports.assertExpression = assertExpression;
    exports.assertExpressionStatement = assertExpressionStatement;
    exports.assertExpressionWrapper = assertExpressionWrapper;
    exports.assertFile = assertFile;
    exports.assertFlow = assertFlow;
    exports.assertFlowBaseAnnotation = assertFlowBaseAnnotation;
    exports.assertFlowDeclaration = assertFlowDeclaration;
    exports.assertFlowPredicate = assertFlowPredicate;
    exports.assertFlowType = assertFlowType;
    exports.assertFor = assertFor;
    exports.assertForInStatement = assertForInStatement;
    exports.assertForOfStatement = assertForOfStatement;
    exports.assertForStatement = assertForStatement;
    exports.assertForXStatement = assertForXStatement;
    exports.assertFunction = assertFunction;
    exports.assertFunctionDeclaration = assertFunctionDeclaration;
    exports.assertFunctionExpression = assertFunctionExpression;
    exports.assertFunctionParent = assertFunctionParent;
    exports.assertFunctionTypeAnnotation = assertFunctionTypeAnnotation;
    exports.assertFunctionTypeParam = assertFunctionTypeParam;
    exports.assertGenericTypeAnnotation = assertGenericTypeAnnotation;
    exports.assertIdentifier = assertIdentifier;
    exports.assertIfStatement = assertIfStatement;
    exports.assertImmutable = assertImmutable;
    exports.assertImport = assertImport;
    exports.assertImportAttribute = assertImportAttribute;
    exports.assertImportDeclaration = assertImportDeclaration;
    exports.assertImportDefaultSpecifier = assertImportDefaultSpecifier;
    exports.assertImportNamespaceSpecifier = assertImportNamespaceSpecifier;
    exports.assertImportOrExportDeclaration = assertImportOrExportDeclaration;
    exports.assertImportSpecifier = assertImportSpecifier;
    exports.assertIndexedAccessType = assertIndexedAccessType;
    exports.assertInferredPredicate = assertInferredPredicate;
    exports.assertInterfaceDeclaration = assertInterfaceDeclaration;
    exports.assertInterfaceExtends = assertInterfaceExtends;
    exports.assertInterfaceTypeAnnotation = assertInterfaceTypeAnnotation;
    exports.assertInterpreterDirective = assertInterpreterDirective;
    exports.assertIntersectionTypeAnnotation = assertIntersectionTypeAnnotation;
    exports.assertJSX = assertJSX;
    exports.assertJSXAttribute = assertJSXAttribute;
    exports.assertJSXClosingElement = assertJSXClosingElement;
    exports.assertJSXClosingFragment = assertJSXClosingFragment;
    exports.assertJSXElement = assertJSXElement;
    exports.assertJSXEmptyExpression = assertJSXEmptyExpression;
    exports.assertJSXExpressionContainer = assertJSXExpressionContainer;
    exports.assertJSXFragment = assertJSXFragment;
    exports.assertJSXIdentifier = assertJSXIdentifier;
    exports.assertJSXMemberExpression = assertJSXMemberExpression;
    exports.assertJSXNamespacedName = assertJSXNamespacedName;
    exports.assertJSXOpeningElement = assertJSXOpeningElement;
    exports.assertJSXOpeningFragment = assertJSXOpeningFragment;
    exports.assertJSXSpreadAttribute = assertJSXSpreadAttribute;
    exports.assertJSXSpreadChild = assertJSXSpreadChild;
    exports.assertJSXText = assertJSXText;
    exports.assertLVal = assertLVal;
    exports.assertLabeledStatement = assertLabeledStatement;
    exports.assertLiteral = assertLiteral;
    exports.assertLogicalExpression = assertLogicalExpression;
    exports.assertLoop = assertLoop;
    exports.assertMemberExpression = assertMemberExpression;
    exports.assertMetaProperty = assertMetaProperty;
    exports.assertMethod = assertMethod;
    exports.assertMiscellaneous = assertMiscellaneous;
    exports.assertMixedTypeAnnotation = assertMixedTypeAnnotation;
    exports.assertModuleDeclaration = assertModuleDeclaration;
    exports.assertModuleExpression = assertModuleExpression;
    exports.assertModuleSpecifier = assertModuleSpecifier;
    exports.assertNewExpression = assertNewExpression;
    exports.assertNoop = assertNoop;
    exports.assertNullLiteral = assertNullLiteral;
    exports.assertNullLiteralTypeAnnotation = assertNullLiteralTypeAnnotation;
    exports.assertNullableTypeAnnotation = assertNullableTypeAnnotation;
    exports.assertNumberLiteral = assertNumberLiteral;
    exports.assertNumberLiteralTypeAnnotation = assertNumberLiteralTypeAnnotation;
    exports.assertNumberTypeAnnotation = assertNumberTypeAnnotation;
    exports.assertNumericLiteral = assertNumericLiteral;
    exports.assertObjectExpression = assertObjectExpression;
    exports.assertObjectMember = assertObjectMember;
    exports.assertObjectMethod = assertObjectMethod;
    exports.assertObjectPattern = assertObjectPattern;
    exports.assertObjectProperty = assertObjectProperty;
    exports.assertObjectTypeAnnotation = assertObjectTypeAnnotation;
    exports.assertObjectTypeCallProperty = assertObjectTypeCallProperty;
    exports.assertObjectTypeIndexer = assertObjectTypeIndexer;
    exports.assertObjectTypeInternalSlot = assertObjectTypeInternalSlot;
    exports.assertObjectTypeProperty = assertObjectTypeProperty;
    exports.assertObjectTypeSpreadProperty = assertObjectTypeSpreadProperty;
    exports.assertOpaqueType = assertOpaqueType;
    exports.assertOptionalCallExpression = assertOptionalCallExpression;
    exports.assertOptionalIndexedAccessType = assertOptionalIndexedAccessType;
    exports.assertOptionalMemberExpression = assertOptionalMemberExpression;
    exports.assertParenthesizedExpression = assertParenthesizedExpression;
    exports.assertPattern = assertPattern;
    exports.assertPatternLike = assertPatternLike;
    exports.assertPipelineBareFunction = assertPipelineBareFunction;
    exports.assertPipelinePrimaryTopicReference = assertPipelinePrimaryTopicReference;
    exports.assertPipelineTopicExpression = assertPipelineTopicExpression;
    exports.assertPlaceholder = assertPlaceholder;
    exports.assertPrivate = assertPrivate;
    exports.assertPrivateName = assertPrivateName;
    exports.assertProgram = assertProgram;
    exports.assertProperty = assertProperty;
    exports.assertPureish = assertPureish;
    exports.assertQualifiedTypeIdentifier = assertQualifiedTypeIdentifier;
    exports.assertRecordExpression = assertRecordExpression;
    exports.assertRegExpLiteral = assertRegExpLiteral;
    exports.assertRegexLiteral = assertRegexLiteral;
    exports.assertRestElement = assertRestElement;
    exports.assertRestProperty = assertRestProperty;
    exports.assertReturnStatement = assertReturnStatement;
    exports.assertScopable = assertScopable;
    exports.assertSequenceExpression = assertSequenceExpression;
    exports.assertSpreadElement = assertSpreadElement;
    exports.assertSpreadProperty = assertSpreadProperty;
    exports.assertStandardized = assertStandardized;
    exports.assertStatement = assertStatement;
    exports.assertStaticBlock = assertStaticBlock;
    exports.assertStringLiteral = assertStringLiteral;
    exports.assertStringLiteralTypeAnnotation = assertStringLiteralTypeAnnotation;
    exports.assertStringTypeAnnotation = assertStringTypeAnnotation;
    exports.assertSuper = assertSuper;
    exports.assertSwitchCase = assertSwitchCase;
    exports.assertSwitchStatement = assertSwitchStatement;
    exports.assertSymbolTypeAnnotation = assertSymbolTypeAnnotation;
    exports.assertTSAnyKeyword = assertTSAnyKeyword;
    exports.assertTSArrayType = assertTSArrayType;
    exports.assertTSAsExpression = assertTSAsExpression;
    exports.assertTSBaseType = assertTSBaseType;
    exports.assertTSBigIntKeyword = assertTSBigIntKeyword;
    exports.assertTSBooleanKeyword = assertTSBooleanKeyword;
    exports.assertTSCallSignatureDeclaration = assertTSCallSignatureDeclaration;
    exports.assertTSConditionalType = assertTSConditionalType;
    exports.assertTSConstructSignatureDeclaration = assertTSConstructSignatureDeclaration;
    exports.assertTSConstructorType = assertTSConstructorType;
    exports.assertTSDeclareFunction = assertTSDeclareFunction;
    exports.assertTSDeclareMethod = assertTSDeclareMethod;
    exports.assertTSEntityName = assertTSEntityName;
    exports.assertTSEnumDeclaration = assertTSEnumDeclaration;
    exports.assertTSEnumMember = assertTSEnumMember;
    exports.assertTSExportAssignment = assertTSExportAssignment;
    exports.assertTSExpressionWithTypeArguments = assertTSExpressionWithTypeArguments;
    exports.assertTSExternalModuleReference = assertTSExternalModuleReference;
    exports.assertTSFunctionType = assertTSFunctionType;
    exports.assertTSImportEqualsDeclaration = assertTSImportEqualsDeclaration;
    exports.assertTSImportType = assertTSImportType;
    exports.assertTSIndexSignature = assertTSIndexSignature;
    exports.assertTSIndexedAccessType = assertTSIndexedAccessType;
    exports.assertTSInferType = assertTSInferType;
    exports.assertTSInstantiationExpression = assertTSInstantiationExpression;
    exports.assertTSInterfaceBody = assertTSInterfaceBody;
    exports.assertTSInterfaceDeclaration = assertTSInterfaceDeclaration;
    exports.assertTSIntersectionType = assertTSIntersectionType;
    exports.assertTSIntrinsicKeyword = assertTSIntrinsicKeyword;
    exports.assertTSLiteralType = assertTSLiteralType;
    exports.assertTSMappedType = assertTSMappedType;
    exports.assertTSMethodSignature = assertTSMethodSignature;
    exports.assertTSModuleBlock = assertTSModuleBlock;
    exports.assertTSModuleDeclaration = assertTSModuleDeclaration;
    exports.assertTSNamedTupleMember = assertTSNamedTupleMember;
    exports.assertTSNamespaceExportDeclaration = assertTSNamespaceExportDeclaration;
    exports.assertTSNeverKeyword = assertTSNeverKeyword;
    exports.assertTSNonNullExpression = assertTSNonNullExpression;
    exports.assertTSNullKeyword = assertTSNullKeyword;
    exports.assertTSNumberKeyword = assertTSNumberKeyword;
    exports.assertTSObjectKeyword = assertTSObjectKeyword;
    exports.assertTSOptionalType = assertTSOptionalType;
    exports.assertTSParameterProperty = assertTSParameterProperty;
    exports.assertTSParenthesizedType = assertTSParenthesizedType;
    exports.assertTSPropertySignature = assertTSPropertySignature;
    exports.assertTSQualifiedName = assertTSQualifiedName;
    exports.assertTSRestType = assertTSRestType;
    exports.assertTSSatisfiesExpression = assertTSSatisfiesExpression;
    exports.assertTSStringKeyword = assertTSStringKeyword;
    exports.assertTSSymbolKeyword = assertTSSymbolKeyword;
    exports.assertTSThisType = assertTSThisType;
    exports.assertTSTupleType = assertTSTupleType;
    exports.assertTSType = assertTSType;
    exports.assertTSTypeAliasDeclaration = assertTSTypeAliasDeclaration;
    exports.assertTSTypeAnnotation = assertTSTypeAnnotation;
    exports.assertTSTypeAssertion = assertTSTypeAssertion;
    exports.assertTSTypeElement = assertTSTypeElement;
    exports.assertTSTypeLiteral = assertTSTypeLiteral;
    exports.assertTSTypeOperator = assertTSTypeOperator;
    exports.assertTSTypeParameter = assertTSTypeParameter;
    exports.assertTSTypeParameterDeclaration = assertTSTypeParameterDeclaration;
    exports.assertTSTypeParameterInstantiation = assertTSTypeParameterInstantiation;
    exports.assertTSTypePredicate = assertTSTypePredicate;
    exports.assertTSTypeQuery = assertTSTypeQuery;
    exports.assertTSTypeReference = assertTSTypeReference;
    exports.assertTSUndefinedKeyword = assertTSUndefinedKeyword;
    exports.assertTSUnionType = assertTSUnionType;
    exports.assertTSUnknownKeyword = assertTSUnknownKeyword;
    exports.assertTSVoidKeyword = assertTSVoidKeyword;
    exports.assertTaggedTemplateExpression = assertTaggedTemplateExpression;
    exports.assertTemplateElement = assertTemplateElement;
    exports.assertTemplateLiteral = assertTemplateLiteral;
    exports.assertTerminatorless = assertTerminatorless;
    exports.assertThisExpression = assertThisExpression;
    exports.assertThisTypeAnnotation = assertThisTypeAnnotation;
    exports.assertThrowStatement = assertThrowStatement;
    exports.assertTopicReference = assertTopicReference;
    exports.assertTryStatement = assertTryStatement;
    exports.assertTupleExpression = assertTupleExpression;
    exports.assertTupleTypeAnnotation = assertTupleTypeAnnotation;
    exports.assertTypeAlias = assertTypeAlias;
    exports.assertTypeAnnotation = assertTypeAnnotation;
    exports.assertTypeCastExpression = assertTypeCastExpression;
    exports.assertTypeParameter = assertTypeParameter;
    exports.assertTypeParameterDeclaration = assertTypeParameterDeclaration;
    exports.assertTypeParameterInstantiation = assertTypeParameterInstantiation;
    exports.assertTypeScript = assertTypeScript;
    exports.assertTypeofTypeAnnotation = assertTypeofTypeAnnotation;
    exports.assertUnaryExpression = assertUnaryExpression;
    exports.assertUnaryLike = assertUnaryLike;
    exports.assertUnionTypeAnnotation = assertUnionTypeAnnotation;
    exports.assertUpdateExpression = assertUpdateExpression;
    exports.assertUserWhitespacable = assertUserWhitespacable;
    exports.assertV8IntrinsicIdentifier = assertV8IntrinsicIdentifier;
    exports.assertVariableDeclaration = assertVariableDeclaration;
    exports.assertVariableDeclarator = assertVariableDeclarator;
    exports.assertVariance = assertVariance;
    exports.assertVoidTypeAnnotation = assertVoidTypeAnnotation;
    exports.assertWhile = assertWhile;
    exports.assertWhileStatement = assertWhileStatement;
    exports.assertWithStatement = assertWithStatement;
    exports.assertYieldExpression = assertYieldExpression;
    var _is = require_is2();
    var _deprecationWarning = require_deprecationWarning();
    function assert(type, node, opts) {
      if (!(0, _is.default)(type, node, opts)) {
        throw new Error(`Expected type "${type}" with option ${JSON.stringify(opts)}, but instead got "${node.type}".`);
      }
    }
    function assertArrayExpression(node, opts) {
      assert("ArrayExpression", node, opts);
    }
    function assertAssignmentExpression(node, opts) {
      assert("AssignmentExpression", node, opts);
    }
    function assertBinaryExpression(node, opts) {
      assert("BinaryExpression", node, opts);
    }
    function assertInterpreterDirective(node, opts) {
      assert("InterpreterDirective", node, opts);
    }
    function assertDirective(node, opts) {
      assert("Directive", node, opts);
    }
    function assertDirectiveLiteral(node, opts) {
      assert("DirectiveLiteral", node, opts);
    }
    function assertBlockStatement(node, opts) {
      assert("BlockStatement", node, opts);
    }
    function assertBreakStatement(node, opts) {
      assert("BreakStatement", node, opts);
    }
    function assertCallExpression(node, opts) {
      assert("CallExpression", node, opts);
    }
    function assertCatchClause(node, opts) {
      assert("CatchClause", node, opts);
    }
    function assertConditionalExpression(node, opts) {
      assert("ConditionalExpression", node, opts);
    }
    function assertContinueStatement(node, opts) {
      assert("ContinueStatement", node, opts);
    }
    function assertDebuggerStatement(node, opts) {
      assert("DebuggerStatement", node, opts);
    }
    function assertDoWhileStatement(node, opts) {
      assert("DoWhileStatement", node, opts);
    }
    function assertEmptyStatement(node, opts) {
      assert("EmptyStatement", node, opts);
    }
    function assertExpressionStatement(node, opts) {
      assert("ExpressionStatement", node, opts);
    }
    function assertFile(node, opts) {
      assert("File", node, opts);
    }
    function assertForInStatement(node, opts) {
      assert("ForInStatement", node, opts);
    }
    function assertForStatement(node, opts) {
      assert("ForStatement", node, opts);
    }
    function assertFunctionDeclaration(node, opts) {
      assert("FunctionDeclaration", node, opts);
    }
    function assertFunctionExpression(node, opts) {
      assert("FunctionExpression", node, opts);
    }
    function assertIdentifier(node, opts) {
      assert("Identifier", node, opts);
    }
    function assertIfStatement(node, opts) {
      assert("IfStatement", node, opts);
    }
    function assertLabeledStatement(node, opts) {
      assert("LabeledStatement", node, opts);
    }
    function assertStringLiteral(node, opts) {
      assert("StringLiteral", node, opts);
    }
    function assertNumericLiteral(node, opts) {
      assert("NumericLiteral", node, opts);
    }
    function assertNullLiteral(node, opts) {
      assert("NullLiteral", node, opts);
    }
    function assertBooleanLiteral(node, opts) {
      assert("BooleanLiteral", node, opts);
    }
    function assertRegExpLiteral(node, opts) {
      assert("RegExpLiteral", node, opts);
    }
    function assertLogicalExpression(node, opts) {
      assert("LogicalExpression", node, opts);
    }
    function assertMemberExpression(node, opts) {
      assert("MemberExpression", node, opts);
    }
    function assertNewExpression(node, opts) {
      assert("NewExpression", node, opts);
    }
    function assertProgram(node, opts) {
      assert("Program", node, opts);
    }
    function assertObjectExpression(node, opts) {
      assert("ObjectExpression", node, opts);
    }
    function assertObjectMethod(node, opts) {
      assert("ObjectMethod", node, opts);
    }
    function assertObjectProperty(node, opts) {
      assert("ObjectProperty", node, opts);
    }
    function assertRestElement(node, opts) {
      assert("RestElement", node, opts);
    }
    function assertReturnStatement(node, opts) {
      assert("ReturnStatement", node, opts);
    }
    function assertSequenceExpression(node, opts) {
      assert("SequenceExpression", node, opts);
    }
    function assertParenthesizedExpression(node, opts) {
      assert("ParenthesizedExpression", node, opts);
    }
    function assertSwitchCase(node, opts) {
      assert("SwitchCase", node, opts);
    }
    function assertSwitchStatement(node, opts) {
      assert("SwitchStatement", node, opts);
    }
    function assertThisExpression(node, opts) {
      assert("ThisExpression", node, opts);
    }
    function assertThrowStatement(node, opts) {
      assert("ThrowStatement", node, opts);
    }
    function assertTryStatement(node, opts) {
      assert("TryStatement", node, opts);
    }
    function assertUnaryExpression(node, opts) {
      assert("UnaryExpression", node, opts);
    }
    function assertUpdateExpression(node, opts) {
      assert("UpdateExpression", node, opts);
    }
    function assertVariableDeclaration(node, opts) {
      assert("VariableDeclaration", node, opts);
    }
    function assertVariableDeclarator(node, opts) {
      assert("VariableDeclarator", node, opts);
    }
    function assertWhileStatement(node, opts) {
      assert("WhileStatement", node, opts);
    }
    function assertWithStatement(node, opts) {
      assert("WithStatement", node, opts);
    }
    function assertAssignmentPattern(node, opts) {
      assert("AssignmentPattern", node, opts);
    }
    function assertArrayPattern(node, opts) {
      assert("ArrayPattern", node, opts);
    }
    function assertArrowFunctionExpression(node, opts) {
      assert("ArrowFunctionExpression", node, opts);
    }
    function assertClassBody(node, opts) {
      assert("ClassBody", node, opts);
    }
    function assertClassExpression(node, opts) {
      assert("ClassExpression", node, opts);
    }
    function assertClassDeclaration(node, opts) {
      assert("ClassDeclaration", node, opts);
    }
    function assertExportAllDeclaration(node, opts) {
      assert("ExportAllDeclaration", node, opts);
    }
    function assertExportDefaultDeclaration(node, opts) {
      assert("ExportDefaultDeclaration", node, opts);
    }
    function assertExportNamedDeclaration(node, opts) {
      assert("ExportNamedDeclaration", node, opts);
    }
    function assertExportSpecifier(node, opts) {
      assert("ExportSpecifier", node, opts);
    }
    function assertForOfStatement(node, opts) {
      assert("ForOfStatement", node, opts);
    }
    function assertImportDeclaration(node, opts) {
      assert("ImportDeclaration", node, opts);
    }
    function assertImportDefaultSpecifier(node, opts) {
      assert("ImportDefaultSpecifier", node, opts);
    }
    function assertImportNamespaceSpecifier(node, opts) {
      assert("ImportNamespaceSpecifier", node, opts);
    }
    function assertImportSpecifier(node, opts) {
      assert("ImportSpecifier", node, opts);
    }
    function assertMetaProperty(node, opts) {
      assert("MetaProperty", node, opts);
    }
    function assertClassMethod(node, opts) {
      assert("ClassMethod", node, opts);
    }
    function assertObjectPattern(node, opts) {
      assert("ObjectPattern", node, opts);
    }
    function assertSpreadElement(node, opts) {
      assert("SpreadElement", node, opts);
    }
    function assertSuper(node, opts) {
      assert("Super", node, opts);
    }
    function assertTaggedTemplateExpression(node, opts) {
      assert("TaggedTemplateExpression", node, opts);
    }
    function assertTemplateElement(node, opts) {
      assert("TemplateElement", node, opts);
    }
    function assertTemplateLiteral(node, opts) {
      assert("TemplateLiteral", node, opts);
    }
    function assertYieldExpression(node, opts) {
      assert("YieldExpression", node, opts);
    }
    function assertAwaitExpression(node, opts) {
      assert("AwaitExpression", node, opts);
    }
    function assertImport(node, opts) {
      assert("Import", node, opts);
    }
    function assertBigIntLiteral(node, opts) {
      assert("BigIntLiteral", node, opts);
    }
    function assertExportNamespaceSpecifier(node, opts) {
      assert("ExportNamespaceSpecifier", node, opts);
    }
    function assertOptionalMemberExpression(node, opts) {
      assert("OptionalMemberExpression", node, opts);
    }
    function assertOptionalCallExpression(node, opts) {
      assert("OptionalCallExpression", node, opts);
    }
    function assertClassProperty(node, opts) {
      assert("ClassProperty", node, opts);
    }
    function assertClassAccessorProperty(node, opts) {
      assert("ClassAccessorProperty", node, opts);
    }
    function assertClassPrivateProperty(node, opts) {
      assert("ClassPrivateProperty", node, opts);
    }
    function assertClassPrivateMethod(node, opts) {
      assert("ClassPrivateMethod", node, opts);
    }
    function assertPrivateName(node, opts) {
      assert("PrivateName", node, opts);
    }
    function assertStaticBlock(node, opts) {
      assert("StaticBlock", node, opts);
    }
    function assertAnyTypeAnnotation(node, opts) {
      assert("AnyTypeAnnotation", node, opts);
    }
    function assertArrayTypeAnnotation(node, opts) {
      assert("ArrayTypeAnnotation", node, opts);
    }
    function assertBooleanTypeAnnotation(node, opts) {
      assert("BooleanTypeAnnotation", node, opts);
    }
    function assertBooleanLiteralTypeAnnotation(node, opts) {
      assert("BooleanLiteralTypeAnnotation", node, opts);
    }
    function assertNullLiteralTypeAnnotation(node, opts) {
      assert("NullLiteralTypeAnnotation", node, opts);
    }
    function assertClassImplements(node, opts) {
      assert("ClassImplements", node, opts);
    }
    function assertDeclareClass(node, opts) {
      assert("DeclareClass", node, opts);
    }
    function assertDeclareFunction(node, opts) {
      assert("DeclareFunction", node, opts);
    }
    function assertDeclareInterface(node, opts) {
      assert("DeclareInterface", node, opts);
    }
    function assertDeclareModule(node, opts) {
      assert("DeclareModule", node, opts);
    }
    function assertDeclareModuleExports(node, opts) {
      assert("DeclareModuleExports", node, opts);
    }
    function assertDeclareTypeAlias(node, opts) {
      assert("DeclareTypeAlias", node, opts);
    }
    function assertDeclareOpaqueType(node, opts) {
      assert("DeclareOpaqueType", node, opts);
    }
    function assertDeclareVariable(node, opts) {
      assert("DeclareVariable", node, opts);
    }
    function assertDeclareExportDeclaration(node, opts) {
      assert("DeclareExportDeclaration", node, opts);
    }
    function assertDeclareExportAllDeclaration(node, opts) {
      assert("DeclareExportAllDeclaration", node, opts);
    }
    function assertDeclaredPredicate(node, opts) {
      assert("DeclaredPredicate", node, opts);
    }
    function assertExistsTypeAnnotation(node, opts) {
      assert("ExistsTypeAnnotation", node, opts);
    }
    function assertFunctionTypeAnnotation(node, opts) {
      assert("FunctionTypeAnnotation", node, opts);
    }
    function assertFunctionTypeParam(node, opts) {
      assert("FunctionTypeParam", node, opts);
    }
    function assertGenericTypeAnnotation(node, opts) {
      assert("GenericTypeAnnotation", node, opts);
    }
    function assertInferredPredicate(node, opts) {
      assert("InferredPredicate", node, opts);
    }
    function assertInterfaceExtends(node, opts) {
      assert("InterfaceExtends", node, opts);
    }
    function assertInterfaceDeclaration(node, opts) {
      assert("InterfaceDeclaration", node, opts);
    }
    function assertInterfaceTypeAnnotation(node, opts) {
      assert("InterfaceTypeAnnotation", node, opts);
    }
    function assertIntersectionTypeAnnotation(node, opts) {
      assert("IntersectionTypeAnnotation", node, opts);
    }
    function assertMixedTypeAnnotation(node, opts) {
      assert("MixedTypeAnnotation", node, opts);
    }
    function assertEmptyTypeAnnotation(node, opts) {
      assert("EmptyTypeAnnotation", node, opts);
    }
    function assertNullableTypeAnnotation(node, opts) {
      assert("NullableTypeAnnotation", node, opts);
    }
    function assertNumberLiteralTypeAnnotation(node, opts) {
      assert("NumberLiteralTypeAnnotation", node, opts);
    }
    function assertNumberTypeAnnotation(node, opts) {
      assert("NumberTypeAnnotation", node, opts);
    }
    function assertObjectTypeAnnotation(node, opts) {
      assert("ObjectTypeAnnotation", node, opts);
    }
    function assertObjectTypeInternalSlot(node, opts) {
      assert("ObjectTypeInternalSlot", node, opts);
    }
    function assertObjectTypeCallProperty(node, opts) {
      assert("ObjectTypeCallProperty", node, opts);
    }
    function assertObjectTypeIndexer(node, opts) {
      assert("ObjectTypeIndexer", node, opts);
    }
    function assertObjectTypeProperty(node, opts) {
      assert("ObjectTypeProperty", node, opts);
    }
    function assertObjectTypeSpreadProperty(node, opts) {
      assert("ObjectTypeSpreadProperty", node, opts);
    }
    function assertOpaqueType(node, opts) {
      assert("OpaqueType", node, opts);
    }
    function assertQualifiedTypeIdentifier(node, opts) {
      assert("QualifiedTypeIdentifier", node, opts);
    }
    function assertStringLiteralTypeAnnotation(node, opts) {
      assert("StringLiteralTypeAnnotation", node, opts);
    }
    function assertStringTypeAnnotation(node, opts) {
      assert("StringTypeAnnotation", node, opts);
    }
    function assertSymbolTypeAnnotation(node, opts) {
      assert("SymbolTypeAnnotation", node, opts);
    }
    function assertThisTypeAnnotation(node, opts) {
      assert("ThisTypeAnnotation", node, opts);
    }
    function assertTupleTypeAnnotation(node, opts) {
      assert("TupleTypeAnnotation", node, opts);
    }
    function assertTypeofTypeAnnotation(node, opts) {
      assert("TypeofTypeAnnotation", node, opts);
    }
    function assertTypeAlias(node, opts) {
      assert("TypeAlias", node, opts);
    }
    function assertTypeAnnotation(node, opts) {
      assert("TypeAnnotation", node, opts);
    }
    function assertTypeCastExpression(node, opts) {
      assert("TypeCastExpression", node, opts);
    }
    function assertTypeParameter(node, opts) {
      assert("TypeParameter", node, opts);
    }
    function assertTypeParameterDeclaration(node, opts) {
      assert("TypeParameterDeclaration", node, opts);
    }
    function assertTypeParameterInstantiation(node, opts) {
      assert("TypeParameterInstantiation", node, opts);
    }
    function assertUnionTypeAnnotation(node, opts) {
      assert("UnionTypeAnnotation", node, opts);
    }
    function assertVariance(node, opts) {
      assert("Variance", node, opts);
    }
    function assertVoidTypeAnnotation(node, opts) {
      assert("VoidTypeAnnotation", node, opts);
    }
    function assertEnumDeclaration(node, opts) {
      assert("EnumDeclaration", node, opts);
    }
    function assertEnumBooleanBody(node, opts) {
      assert("EnumBooleanBody", node, opts);
    }
    function assertEnumNumberBody(node, opts) {
      assert("EnumNumberBody", node, opts);
    }
    function assertEnumStringBody(node, opts) {
      assert("EnumStringBody", node, opts);
    }
    function assertEnumSymbolBody(node, opts) {
      assert("EnumSymbolBody", node, opts);
    }
    function assertEnumBooleanMember(node, opts) {
      assert("EnumBooleanMember", node, opts);
    }
    function assertEnumNumberMember(node, opts) {
      assert("EnumNumberMember", node, opts);
    }
    function assertEnumStringMember(node, opts) {
      assert("EnumStringMember", node, opts);
    }
    function assertEnumDefaultedMember(node, opts) {
      assert("EnumDefaultedMember", node, opts);
    }
    function assertIndexedAccessType(node, opts) {
      assert("IndexedAccessType", node, opts);
    }
    function assertOptionalIndexedAccessType(node, opts) {
      assert("OptionalIndexedAccessType", node, opts);
    }
    function assertJSXAttribute(node, opts) {
      assert("JSXAttribute", node, opts);
    }
    function assertJSXClosingElement(node, opts) {
      assert("JSXClosingElement", node, opts);
    }
    function assertJSXElement(node, opts) {
      assert("JSXElement", node, opts);
    }
    function assertJSXEmptyExpression(node, opts) {
      assert("JSXEmptyExpression", node, opts);
    }
    function assertJSXExpressionContainer(node, opts) {
      assert("JSXExpressionContainer", node, opts);
    }
    function assertJSXSpreadChild(node, opts) {
      assert("JSXSpreadChild", node, opts);
    }
    function assertJSXIdentifier(node, opts) {
      assert("JSXIdentifier", node, opts);
    }
    function assertJSXMemberExpression(node, opts) {
      assert("JSXMemberExpression", node, opts);
    }
    function assertJSXNamespacedName(node, opts) {
      assert("JSXNamespacedName", node, opts);
    }
    function assertJSXOpeningElement(node, opts) {
      assert("JSXOpeningElement", node, opts);
    }
    function assertJSXSpreadAttribute(node, opts) {
      assert("JSXSpreadAttribute", node, opts);
    }
    function assertJSXText(node, opts) {
      assert("JSXText", node, opts);
    }
    function assertJSXFragment(node, opts) {
      assert("JSXFragment", node, opts);
    }
    function assertJSXOpeningFragment(node, opts) {
      assert("JSXOpeningFragment", node, opts);
    }
    function assertJSXClosingFragment(node, opts) {
      assert("JSXClosingFragment", node, opts);
    }
    function assertNoop(node, opts) {
      assert("Noop", node, opts);
    }
    function assertPlaceholder(node, opts) {
      assert("Placeholder", node, opts);
    }
    function assertV8IntrinsicIdentifier(node, opts) {
      assert("V8IntrinsicIdentifier", node, opts);
    }
    function assertArgumentPlaceholder(node, opts) {
      assert("ArgumentPlaceholder", node, opts);
    }
    function assertBindExpression(node, opts) {
      assert("BindExpression", node, opts);
    }
    function assertImportAttribute(node, opts) {
      assert("ImportAttribute", node, opts);
    }
    function assertDecorator(node, opts) {
      assert("Decorator", node, opts);
    }
    function assertDoExpression(node, opts) {
      assert("DoExpression", node, opts);
    }
    function assertExportDefaultSpecifier(node, opts) {
      assert("ExportDefaultSpecifier", node, opts);
    }
    function assertRecordExpression(node, opts) {
      assert("RecordExpression", node, opts);
    }
    function assertTupleExpression(node, opts) {
      assert("TupleExpression", node, opts);
    }
    function assertDecimalLiteral(node, opts) {
      assert("DecimalLiteral", node, opts);
    }
    function assertModuleExpression(node, opts) {
      assert("ModuleExpression", node, opts);
    }
    function assertTopicReference(node, opts) {
      assert("TopicReference", node, opts);
    }
    function assertPipelineTopicExpression(node, opts) {
      assert("PipelineTopicExpression", node, opts);
    }
    function assertPipelineBareFunction(node, opts) {
      assert("PipelineBareFunction", node, opts);
    }
    function assertPipelinePrimaryTopicReference(node, opts) {
      assert("PipelinePrimaryTopicReference", node, opts);
    }
    function assertTSParameterProperty(node, opts) {
      assert("TSParameterProperty", node, opts);
    }
    function assertTSDeclareFunction(node, opts) {
      assert("TSDeclareFunction", node, opts);
    }
    function assertTSDeclareMethod(node, opts) {
      assert("TSDeclareMethod", node, opts);
    }
    function assertTSQualifiedName(node, opts) {
      assert("TSQualifiedName", node, opts);
    }
    function assertTSCallSignatureDeclaration(node, opts) {
      assert("TSCallSignatureDeclaration", node, opts);
    }
    function assertTSConstructSignatureDeclaration(node, opts) {
      assert("TSConstructSignatureDeclaration", node, opts);
    }
    function assertTSPropertySignature(node, opts) {
      assert("TSPropertySignature", node, opts);
    }
    function assertTSMethodSignature(node, opts) {
      assert("TSMethodSignature", node, opts);
    }
    function assertTSIndexSignature(node, opts) {
      assert("TSIndexSignature", node, opts);
    }
    function assertTSAnyKeyword(node, opts) {
      assert("TSAnyKeyword", node, opts);
    }
    function assertTSBooleanKeyword(node, opts) {
      assert("TSBooleanKeyword", node, opts);
    }
    function assertTSBigIntKeyword(node, opts) {
      assert("TSBigIntKeyword", node, opts);
    }
    function assertTSIntrinsicKeyword(node, opts) {
      assert("TSIntrinsicKeyword", node, opts);
    }
    function assertTSNeverKeyword(node, opts) {
      assert("TSNeverKeyword", node, opts);
    }
    function assertTSNullKeyword(node, opts) {
      assert("TSNullKeyword", node, opts);
    }
    function assertTSNumberKeyword(node, opts) {
      assert("TSNumberKeyword", node, opts);
    }
    function assertTSObjectKeyword(node, opts) {
      assert("TSObjectKeyword", node, opts);
    }
    function assertTSStringKeyword(node, opts) {
      assert("TSStringKeyword", node, opts);
    }
    function assertTSSymbolKeyword(node, opts) {
      assert("TSSymbolKeyword", node, opts);
    }
    function assertTSUndefinedKeyword(node, opts) {
      assert("TSUndefinedKeyword", node, opts);
    }
    function assertTSUnknownKeyword(node, opts) {
      assert("TSUnknownKeyword", node, opts);
    }
    function assertTSVoidKeyword(node, opts) {
      assert("TSVoidKeyword", node, opts);
    }
    function assertTSThisType(node, opts) {
      assert("TSThisType", node, opts);
    }
    function assertTSFunctionType(node, opts) {
      assert("TSFunctionType", node, opts);
    }
    function assertTSConstructorType(node, opts) {
      assert("TSConstructorType", node, opts);
    }
    function assertTSTypeReference(node, opts) {
      assert("TSTypeReference", node, opts);
    }
    function assertTSTypePredicate(node, opts) {
      assert("TSTypePredicate", node, opts);
    }
    function assertTSTypeQuery(node, opts) {
      assert("TSTypeQuery", node, opts);
    }
    function assertTSTypeLiteral(node, opts) {
      assert("TSTypeLiteral", node, opts);
    }
    function assertTSArrayType(node, opts) {
      assert("TSArrayType", node, opts);
    }
    function assertTSTupleType(node, opts) {
      assert("TSTupleType", node, opts);
    }
    function assertTSOptionalType(node, opts) {
      assert("TSOptionalType", node, opts);
    }
    function assertTSRestType(node, opts) {
      assert("TSRestType", node, opts);
    }
    function assertTSNamedTupleMember(node, opts) {
      assert("TSNamedTupleMember", node, opts);
    }
    function assertTSUnionType(node, opts) {
      assert("TSUnionType", node, opts);
    }
    function assertTSIntersectionType(node, opts) {
      assert("TSIntersectionType", node, opts);
    }
    function assertTSConditionalType(node, opts) {
      assert("TSConditionalType", node, opts);
    }
    function assertTSInferType(node, opts) {
      assert("TSInferType", node, opts);
    }
    function assertTSParenthesizedType(node, opts) {
      assert("TSParenthesizedType", node, opts);
    }
    function assertTSTypeOperator(node, opts) {
      assert("TSTypeOperator", node, opts);
    }
    function assertTSIndexedAccessType(node, opts) {
      assert("TSIndexedAccessType", node, opts);
    }
    function assertTSMappedType(node, opts) {
      assert("TSMappedType", node, opts);
    }
    function assertTSLiteralType(node, opts) {
      assert("TSLiteralType", node, opts);
    }
    function assertTSExpressionWithTypeArguments(node, opts) {
      assert("TSExpressionWithTypeArguments", node, opts);
    }
    function assertTSInterfaceDeclaration(node, opts) {
      assert("TSInterfaceDeclaration", node, opts);
    }
    function assertTSInterfaceBody(node, opts) {
      assert("TSInterfaceBody", node, opts);
    }
    function assertTSTypeAliasDeclaration(node, opts) {
      assert("TSTypeAliasDeclaration", node, opts);
    }
    function assertTSInstantiationExpression(node, opts) {
      assert("TSInstantiationExpression", node, opts);
    }
    function assertTSAsExpression(node, opts) {
      assert("TSAsExpression", node, opts);
    }
    function assertTSSatisfiesExpression(node, opts) {
      assert("TSSatisfiesExpression", node, opts);
    }
    function assertTSTypeAssertion(node, opts) {
      assert("TSTypeAssertion", node, opts);
    }
    function assertTSEnumDeclaration(node, opts) {
      assert("TSEnumDeclaration", node, opts);
    }
    function assertTSEnumMember(node, opts) {
      assert("TSEnumMember", node, opts);
    }
    function assertTSModuleDeclaration(node, opts) {
      assert("TSModuleDeclaration", node, opts);
    }
    function assertTSModuleBlock(node, opts) {
      assert("TSModuleBlock", node, opts);
    }
    function assertTSImportType(node, opts) {
      assert("TSImportType", node, opts);
    }
    function assertTSImportEqualsDeclaration(node, opts) {
      assert("TSImportEqualsDeclaration", node, opts);
    }
    function assertTSExternalModuleReference(node, opts) {
      assert("TSExternalModuleReference", node, opts);
    }
    function assertTSNonNullExpression(node, opts) {
      assert("TSNonNullExpression", node, opts);
    }
    function assertTSExportAssignment(node, opts) {
      assert("TSExportAssignment", node, opts);
    }
    function assertTSNamespaceExportDeclaration(node, opts) {
      assert("TSNamespaceExportDeclaration", node, opts);
    }
    function assertTSTypeAnnotation(node, opts) {
      assert("TSTypeAnnotation", node, opts);
    }
    function assertTSTypeParameterInstantiation(node, opts) {
      assert("TSTypeParameterInstantiation", node, opts);
    }
    function assertTSTypeParameterDeclaration(node, opts) {
      assert("TSTypeParameterDeclaration", node, opts);
    }
    function assertTSTypeParameter(node, opts) {
      assert("TSTypeParameter", node, opts);
    }
    function assertStandardized(node, opts) {
      assert("Standardized", node, opts);
    }
    function assertExpression(node, opts) {
      assert("Expression", node, opts);
    }
    function assertBinary(node, opts) {
      assert("Binary", node, opts);
    }
    function assertScopable(node, opts) {
      assert("Scopable", node, opts);
    }
    function assertBlockParent(node, opts) {
      assert("BlockParent", node, opts);
    }
    function assertBlock(node, opts) {
      assert("Block", node, opts);
    }
    function assertStatement(node, opts) {
      assert("Statement", node, opts);
    }
    function assertTerminatorless(node, opts) {
      assert("Terminatorless", node, opts);
    }
    function assertCompletionStatement(node, opts) {
      assert("CompletionStatement", node, opts);
    }
    function assertConditional(node, opts) {
      assert("Conditional", node, opts);
    }
    function assertLoop(node, opts) {
      assert("Loop", node, opts);
    }
    function assertWhile(node, opts) {
      assert("While", node, opts);
    }
    function assertExpressionWrapper(node, opts) {
      assert("ExpressionWrapper", node, opts);
    }
    function assertFor(node, opts) {
      assert("For", node, opts);
    }
    function assertForXStatement(node, opts) {
      assert("ForXStatement", node, opts);
    }
    function assertFunction(node, opts) {
      assert("Function", node, opts);
    }
    function assertFunctionParent(node, opts) {
      assert("FunctionParent", node, opts);
    }
    function assertPureish(node, opts) {
      assert("Pureish", node, opts);
    }
    function assertDeclaration(node, opts) {
      assert("Declaration", node, opts);
    }
    function assertPatternLike(node, opts) {
      assert("PatternLike", node, opts);
    }
    function assertLVal(node, opts) {
      assert("LVal", node, opts);
    }
    function assertTSEntityName(node, opts) {
      assert("TSEntityName", node, opts);
    }
    function assertLiteral(node, opts) {
      assert("Literal", node, opts);
    }
    function assertImmutable(node, opts) {
      assert("Immutable", node, opts);
    }
    function assertUserWhitespacable(node, opts) {
      assert("UserWhitespacable", node, opts);
    }
    function assertMethod(node, opts) {
      assert("Method", node, opts);
    }
    function assertObjectMember(node, opts) {
      assert("ObjectMember", node, opts);
    }
    function assertProperty(node, opts) {
      assert("Property", node, opts);
    }
    function assertUnaryLike(node, opts) {
      assert("UnaryLike", node, opts);
    }
    function assertPattern(node, opts) {
      assert("Pattern", node, opts);
    }
    function assertClass(node, opts) {
      assert("Class", node, opts);
    }
    function assertImportOrExportDeclaration(node, opts) {
      assert("ImportOrExportDeclaration", node, opts);
    }
    function assertExportDeclaration(node, opts) {
      assert("ExportDeclaration", node, opts);
    }
    function assertModuleSpecifier(node, opts) {
      assert("ModuleSpecifier", node, opts);
    }
    function assertAccessor(node, opts) {
      assert("Accessor", node, opts);
    }
    function assertPrivate(node, opts) {
      assert("Private", node, opts);
    }
    function assertFlow(node, opts) {
      assert("Flow", node, opts);
    }
    function assertFlowType(node, opts) {
      assert("FlowType", node, opts);
    }
    function assertFlowBaseAnnotation(node, opts) {
      assert("FlowBaseAnnotation", node, opts);
    }
    function assertFlowDeclaration(node, opts) {
      assert("FlowDeclaration", node, opts);
    }
    function assertFlowPredicate(node, opts) {
      assert("FlowPredicate", node, opts);
    }
    function assertEnumBody(node, opts) {
      assert("EnumBody", node, opts);
    }
    function assertEnumMember(node, opts) {
      assert("EnumMember", node, opts);
    }
    function assertJSX(node, opts) {
      assert("JSX", node, opts);
    }
    function assertMiscellaneous(node, opts) {
      assert("Miscellaneous", node, opts);
    }
    function assertTypeScript(node, opts) {
      assert("TypeScript", node, opts);
    }
    function assertTSTypeElement(node, opts) {
      assert("TSTypeElement", node, opts);
    }
    function assertTSType(node, opts) {
      assert("TSType", node, opts);
    }
    function assertTSBaseType(node, opts) {
      assert("TSBaseType", node, opts);
    }
    function assertNumberLiteral(node, opts) {
      (0, _deprecationWarning.default)("assertNumberLiteral", "assertNumericLiteral");
      assert("NumberLiteral", node, opts);
    }
    function assertRegexLiteral(node, opts) {
      (0, _deprecationWarning.default)("assertRegexLiteral", "assertRegExpLiteral");
      assert("RegexLiteral", node, opts);
    }
    function assertRestProperty(node, opts) {
      (0, _deprecationWarning.default)("assertRestProperty", "assertRestElement");
      assert("RestProperty", node, opts);
    }
    function assertSpreadProperty(node, opts) {
      (0, _deprecationWarning.default)("assertSpreadProperty", "assertSpreadElement");
      assert("SpreadProperty", node, opts);
    }
    function assertModuleDeclaration(node, opts) {
      (0, _deprecationWarning.default)("assertModuleDeclaration", "assertImportOrExportDeclaration");
      assert("ModuleDeclaration", node, opts);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js
var require_createTypeAnnotationBasedOnTypeof2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _index = require_generated7();
    var _default = createTypeAnnotationBasedOnTypeof;
    exports.default = _default;
    function createTypeAnnotationBasedOnTypeof(type) {
      switch (type) {
        case "string":
          return (0, _index.stringTypeAnnotation)();
        case "number":
          return (0, _index.numberTypeAnnotation)();
        case "undefined":
          return (0, _index.voidTypeAnnotation)();
        case "boolean":
          return (0, _index.booleanTypeAnnotation)();
        case "function":
          return (0, _index.genericTypeAnnotation)((0, _index.identifier)("Function"));
        case "object":
          return (0, _index.genericTypeAnnotation)((0, _index.identifier)("Object"));
        case "symbol":
          return (0, _index.genericTypeAnnotation)((0, _index.identifier)("Symbol"));
        case "bigint":
          return (0, _index.anyTypeAnnotation)();
      }
      throw new Error("Invalid typeof value: " + type);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js
var require_removeTypeDuplicates3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeTypeDuplicates;
    var _index = require_generated6();
    function getQualifiedName(node) {
      return (0, _index.isIdentifier)(node) ? node.name : `${node.id.name}.${getQualifiedName(node.qualification)}`;
    }
    function removeTypeDuplicates(nodesIn) {
      const nodes = Array.from(nodesIn);
      const generics = /* @__PURE__ */ new Map();
      const bases = /* @__PURE__ */ new Map();
      const typeGroups = /* @__PURE__ */ new Set();
      const types = [];
      for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        if (!node)
          continue;
        if (types.indexOf(node) >= 0) {
          continue;
        }
        if ((0, _index.isAnyTypeAnnotation)(node)) {
          return [node];
        }
        if ((0, _index.isFlowBaseAnnotation)(node)) {
          bases.set(node.type, node);
          continue;
        }
        if ((0, _index.isUnionTypeAnnotation)(node)) {
          if (!typeGroups.has(node.types)) {
            nodes.push(...node.types);
            typeGroups.add(node.types);
          }
          continue;
        }
        if ((0, _index.isGenericTypeAnnotation)(node)) {
          const name = getQualifiedName(node.id);
          if (generics.has(name)) {
            let existing = generics.get(name);
            if (existing.typeParameters) {
              if (node.typeParameters) {
                existing.typeParameters.params.push(...node.typeParameters.params);
                existing.typeParameters.params = removeTypeDuplicates(existing.typeParameters.params);
              }
            } else {
              existing = node.typeParameters;
            }
          } else {
            generics.set(name, node);
          }
          continue;
        }
        types.push(node);
      }
      for (const [, baseType] of bases) {
        types.push(baseType);
      }
      for (const [, genericName] of generics) {
        types.push(genericName);
      }
      return types;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js
var require_createFlowUnionType2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = createFlowUnionType;
    var _index = require_generated7();
    var _removeTypeDuplicates = require_removeTypeDuplicates3();
    function createFlowUnionType(types) {
      const flattened = (0, _removeTypeDuplicates.default)(types);
      if (flattened.length === 1) {
        return flattened[0];
      } else {
        return (0, _index.unionTypeAnnotation)(flattened);
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js
var require_removeTypeDuplicates4 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeTypeDuplicates;
    var _index = require_generated6();
    function getQualifiedName(node) {
      return (0, _index.isIdentifier)(node) ? node.name : `${node.right.name}.${getQualifiedName(node.left)}`;
    }
    function removeTypeDuplicates(nodesIn) {
      const nodes = Array.from(nodesIn);
      const generics = /* @__PURE__ */ new Map();
      const bases = /* @__PURE__ */ new Map();
      const typeGroups = /* @__PURE__ */ new Set();
      const types = [];
      for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        if (!node)
          continue;
        if (types.indexOf(node) >= 0) {
          continue;
        }
        if ((0, _index.isTSAnyKeyword)(node)) {
          return [node];
        }
        if ((0, _index.isTSBaseType)(node)) {
          bases.set(node.type, node);
          continue;
        }
        if ((0, _index.isTSUnionType)(node)) {
          if (!typeGroups.has(node.types)) {
            nodes.push(...node.types);
            typeGroups.add(node.types);
          }
          continue;
        }
        if ((0, _index.isTSTypeReference)(node) && node.typeParameters) {
          const name = getQualifiedName(node.typeName);
          if (generics.has(name)) {
            let existing = generics.get(name);
            if (existing.typeParameters) {
              if (node.typeParameters) {
                existing.typeParameters.params.push(...node.typeParameters.params);
                existing.typeParameters.params = removeTypeDuplicates(existing.typeParameters.params);
              }
            } else {
              existing = node.typeParameters;
            }
          } else {
            generics.set(name, node);
          }
          continue;
        }
        types.push(node);
      }
      for (const [, baseType] of bases) {
        types.push(baseType);
      }
      for (const [, genericName] of generics) {
        types.push(genericName);
      }
      return types;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js
var require_createTSUnionType2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = createTSUnionType;
    var _index = require_generated7();
    var _removeTypeDuplicates = require_removeTypeDuplicates4();
    var _index2 = require_generated6();
    function createTSUnionType(typeAnnotations) {
      const types = typeAnnotations.map((type) => {
        return (0, _index2.isTSTypeAnnotation)(type) ? type.typeAnnotation : type;
      });
      const flattened = (0, _removeTypeDuplicates.default)(types);
      if (flattened.length === 1) {
        return flattened[0];
      } else {
        return (0, _index.tsUnionType)(flattened);
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/generated/uppercase.js
var require_uppercase2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/builders/generated/uppercase.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "AnyTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.anyTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ArgumentPlaceholder", {
      enumerable: true,
      get: function() {
        return _index.argumentPlaceholder;
      }
    });
    Object.defineProperty(exports, "ArrayExpression", {
      enumerable: true,
      get: function() {
        return _index.arrayExpression;
      }
    });
    Object.defineProperty(exports, "ArrayPattern", {
      enumerable: true,
      get: function() {
        return _index.arrayPattern;
      }
    });
    Object.defineProperty(exports, "ArrayTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.arrayTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ArrowFunctionExpression", {
      enumerable: true,
      get: function() {
        return _index.arrowFunctionExpression;
      }
    });
    Object.defineProperty(exports, "AssignmentExpression", {
      enumerable: true,
      get: function() {
        return _index.assignmentExpression;
      }
    });
    Object.defineProperty(exports, "AssignmentPattern", {
      enumerable: true,
      get: function() {
        return _index.assignmentPattern;
      }
    });
    Object.defineProperty(exports, "AwaitExpression", {
      enumerable: true,
      get: function() {
        return _index.awaitExpression;
      }
    });
    Object.defineProperty(exports, "BigIntLiteral", {
      enumerable: true,
      get: function() {
        return _index.bigIntLiteral;
      }
    });
    Object.defineProperty(exports, "BinaryExpression", {
      enumerable: true,
      get: function() {
        return _index.binaryExpression;
      }
    });
    Object.defineProperty(exports, "BindExpression", {
      enumerable: true,
      get: function() {
        return _index.bindExpression;
      }
    });
    Object.defineProperty(exports, "BlockStatement", {
      enumerable: true,
      get: function() {
        return _index.blockStatement;
      }
    });
    Object.defineProperty(exports, "BooleanLiteral", {
      enumerable: true,
      get: function() {
        return _index.booleanLiteral;
      }
    });
    Object.defineProperty(exports, "BooleanLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.booleanLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "BooleanTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.booleanTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "BreakStatement", {
      enumerable: true,
      get: function() {
        return _index.breakStatement;
      }
    });
    Object.defineProperty(exports, "CallExpression", {
      enumerable: true,
      get: function() {
        return _index.callExpression;
      }
    });
    Object.defineProperty(exports, "CatchClause", {
      enumerable: true,
      get: function() {
        return _index.catchClause;
      }
    });
    Object.defineProperty(exports, "ClassAccessorProperty", {
      enumerable: true,
      get: function() {
        return _index.classAccessorProperty;
      }
    });
    Object.defineProperty(exports, "ClassBody", {
      enumerable: true,
      get: function() {
        return _index.classBody;
      }
    });
    Object.defineProperty(exports, "ClassDeclaration", {
      enumerable: true,
      get: function() {
        return _index.classDeclaration;
      }
    });
    Object.defineProperty(exports, "ClassExpression", {
      enumerable: true,
      get: function() {
        return _index.classExpression;
      }
    });
    Object.defineProperty(exports, "ClassImplements", {
      enumerable: true,
      get: function() {
        return _index.classImplements;
      }
    });
    Object.defineProperty(exports, "ClassMethod", {
      enumerable: true,
      get: function() {
        return _index.classMethod;
      }
    });
    Object.defineProperty(exports, "ClassPrivateMethod", {
      enumerable: true,
      get: function() {
        return _index.classPrivateMethod;
      }
    });
    Object.defineProperty(exports, "ClassPrivateProperty", {
      enumerable: true,
      get: function() {
        return _index.classPrivateProperty;
      }
    });
    Object.defineProperty(exports, "ClassProperty", {
      enumerable: true,
      get: function() {
        return _index.classProperty;
      }
    });
    Object.defineProperty(exports, "ConditionalExpression", {
      enumerable: true,
      get: function() {
        return _index.conditionalExpression;
      }
    });
    Object.defineProperty(exports, "ContinueStatement", {
      enumerable: true,
      get: function() {
        return _index.continueStatement;
      }
    });
    Object.defineProperty(exports, "DebuggerStatement", {
      enumerable: true,
      get: function() {
        return _index.debuggerStatement;
      }
    });
    Object.defineProperty(exports, "DecimalLiteral", {
      enumerable: true,
      get: function() {
        return _index.decimalLiteral;
      }
    });
    Object.defineProperty(exports, "DeclareClass", {
      enumerable: true,
      get: function() {
        return _index.declareClass;
      }
    });
    Object.defineProperty(exports, "DeclareExportAllDeclaration", {
      enumerable: true,
      get: function() {
        return _index.declareExportAllDeclaration;
      }
    });
    Object.defineProperty(exports, "DeclareExportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.declareExportDeclaration;
      }
    });
    Object.defineProperty(exports, "DeclareFunction", {
      enumerable: true,
      get: function() {
        return _index.declareFunction;
      }
    });
    Object.defineProperty(exports, "DeclareInterface", {
      enumerable: true,
      get: function() {
        return _index.declareInterface;
      }
    });
    Object.defineProperty(exports, "DeclareModule", {
      enumerable: true,
      get: function() {
        return _index.declareModule;
      }
    });
    Object.defineProperty(exports, "DeclareModuleExports", {
      enumerable: true,
      get: function() {
        return _index.declareModuleExports;
      }
    });
    Object.defineProperty(exports, "DeclareOpaqueType", {
      enumerable: true,
      get: function() {
        return _index.declareOpaqueType;
      }
    });
    Object.defineProperty(exports, "DeclareTypeAlias", {
      enumerable: true,
      get: function() {
        return _index.declareTypeAlias;
      }
    });
    Object.defineProperty(exports, "DeclareVariable", {
      enumerable: true,
      get: function() {
        return _index.declareVariable;
      }
    });
    Object.defineProperty(exports, "DeclaredPredicate", {
      enumerable: true,
      get: function() {
        return _index.declaredPredicate;
      }
    });
    Object.defineProperty(exports, "Decorator", {
      enumerable: true,
      get: function() {
        return _index.decorator;
      }
    });
    Object.defineProperty(exports, "Directive", {
      enumerable: true,
      get: function() {
        return _index.directive;
      }
    });
    Object.defineProperty(exports, "DirectiveLiteral", {
      enumerable: true,
      get: function() {
        return _index.directiveLiteral;
      }
    });
    Object.defineProperty(exports, "DoExpression", {
      enumerable: true,
      get: function() {
        return _index.doExpression;
      }
    });
    Object.defineProperty(exports, "DoWhileStatement", {
      enumerable: true,
      get: function() {
        return _index.doWhileStatement;
      }
    });
    Object.defineProperty(exports, "EmptyStatement", {
      enumerable: true,
      get: function() {
        return _index.emptyStatement;
      }
    });
    Object.defineProperty(exports, "EmptyTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.emptyTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "EnumBooleanBody", {
      enumerable: true,
      get: function() {
        return _index.enumBooleanBody;
      }
    });
    Object.defineProperty(exports, "EnumBooleanMember", {
      enumerable: true,
      get: function() {
        return _index.enumBooleanMember;
      }
    });
    Object.defineProperty(exports, "EnumDeclaration", {
      enumerable: true,
      get: function() {
        return _index.enumDeclaration;
      }
    });
    Object.defineProperty(exports, "EnumDefaultedMember", {
      enumerable: true,
      get: function() {
        return _index.enumDefaultedMember;
      }
    });
    Object.defineProperty(exports, "EnumNumberBody", {
      enumerable: true,
      get: function() {
        return _index.enumNumberBody;
      }
    });
    Object.defineProperty(exports, "EnumNumberMember", {
      enumerable: true,
      get: function() {
        return _index.enumNumberMember;
      }
    });
    Object.defineProperty(exports, "EnumStringBody", {
      enumerable: true,
      get: function() {
        return _index.enumStringBody;
      }
    });
    Object.defineProperty(exports, "EnumStringMember", {
      enumerable: true,
      get: function() {
        return _index.enumStringMember;
      }
    });
    Object.defineProperty(exports, "EnumSymbolBody", {
      enumerable: true,
      get: function() {
        return _index.enumSymbolBody;
      }
    });
    Object.defineProperty(exports, "ExistsTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.existsTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ExportAllDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportAllDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportDefaultDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportDefaultDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportDefaultSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportDefaultSpecifier;
      }
    });
    Object.defineProperty(exports, "ExportNamedDeclaration", {
      enumerable: true,
      get: function() {
        return _index.exportNamedDeclaration;
      }
    });
    Object.defineProperty(exports, "ExportNamespaceSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportNamespaceSpecifier;
      }
    });
    Object.defineProperty(exports, "ExportSpecifier", {
      enumerable: true,
      get: function() {
        return _index.exportSpecifier;
      }
    });
    Object.defineProperty(exports, "ExpressionStatement", {
      enumerable: true,
      get: function() {
        return _index.expressionStatement;
      }
    });
    Object.defineProperty(exports, "File", {
      enumerable: true,
      get: function() {
        return _index.file;
      }
    });
    Object.defineProperty(exports, "ForInStatement", {
      enumerable: true,
      get: function() {
        return _index.forInStatement;
      }
    });
    Object.defineProperty(exports, "ForOfStatement", {
      enumerable: true,
      get: function() {
        return _index.forOfStatement;
      }
    });
    Object.defineProperty(exports, "ForStatement", {
      enumerable: true,
      get: function() {
        return _index.forStatement;
      }
    });
    Object.defineProperty(exports, "FunctionDeclaration", {
      enumerable: true,
      get: function() {
        return _index.functionDeclaration;
      }
    });
    Object.defineProperty(exports, "FunctionExpression", {
      enumerable: true,
      get: function() {
        return _index.functionExpression;
      }
    });
    Object.defineProperty(exports, "FunctionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.functionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "FunctionTypeParam", {
      enumerable: true,
      get: function() {
        return _index.functionTypeParam;
      }
    });
    Object.defineProperty(exports, "GenericTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.genericTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "Identifier", {
      enumerable: true,
      get: function() {
        return _index.identifier;
      }
    });
    Object.defineProperty(exports, "IfStatement", {
      enumerable: true,
      get: function() {
        return _index.ifStatement;
      }
    });
    Object.defineProperty(exports, "Import", {
      enumerable: true,
      get: function() {
        return _index.import;
      }
    });
    Object.defineProperty(exports, "ImportAttribute", {
      enumerable: true,
      get: function() {
        return _index.importAttribute;
      }
    });
    Object.defineProperty(exports, "ImportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.importDeclaration;
      }
    });
    Object.defineProperty(exports, "ImportDefaultSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importDefaultSpecifier;
      }
    });
    Object.defineProperty(exports, "ImportNamespaceSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importNamespaceSpecifier;
      }
    });
    Object.defineProperty(exports, "ImportSpecifier", {
      enumerable: true,
      get: function() {
        return _index.importSpecifier;
      }
    });
    Object.defineProperty(exports, "IndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.indexedAccessType;
      }
    });
    Object.defineProperty(exports, "InferredPredicate", {
      enumerable: true,
      get: function() {
        return _index.inferredPredicate;
      }
    });
    Object.defineProperty(exports, "InterfaceDeclaration", {
      enumerable: true,
      get: function() {
        return _index.interfaceDeclaration;
      }
    });
    Object.defineProperty(exports, "InterfaceExtends", {
      enumerable: true,
      get: function() {
        return _index.interfaceExtends;
      }
    });
    Object.defineProperty(exports, "InterfaceTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.interfaceTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "InterpreterDirective", {
      enumerable: true,
      get: function() {
        return _index.interpreterDirective;
      }
    });
    Object.defineProperty(exports, "IntersectionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.intersectionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "JSXAttribute", {
      enumerable: true,
      get: function() {
        return _index.jsxAttribute;
      }
    });
    Object.defineProperty(exports, "JSXClosingElement", {
      enumerable: true,
      get: function() {
        return _index.jsxClosingElement;
      }
    });
    Object.defineProperty(exports, "JSXClosingFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxClosingFragment;
      }
    });
    Object.defineProperty(exports, "JSXElement", {
      enumerable: true,
      get: function() {
        return _index.jsxElement;
      }
    });
    Object.defineProperty(exports, "JSXEmptyExpression", {
      enumerable: true,
      get: function() {
        return _index.jsxEmptyExpression;
      }
    });
    Object.defineProperty(exports, "JSXExpressionContainer", {
      enumerable: true,
      get: function() {
        return _index.jsxExpressionContainer;
      }
    });
    Object.defineProperty(exports, "JSXFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxFragment;
      }
    });
    Object.defineProperty(exports, "JSXIdentifier", {
      enumerable: true,
      get: function() {
        return _index.jsxIdentifier;
      }
    });
    Object.defineProperty(exports, "JSXMemberExpression", {
      enumerable: true,
      get: function() {
        return _index.jsxMemberExpression;
      }
    });
    Object.defineProperty(exports, "JSXNamespacedName", {
      enumerable: true,
      get: function() {
        return _index.jsxNamespacedName;
      }
    });
    Object.defineProperty(exports, "JSXOpeningElement", {
      enumerable: true,
      get: function() {
        return _index.jsxOpeningElement;
      }
    });
    Object.defineProperty(exports, "JSXOpeningFragment", {
      enumerable: true,
      get: function() {
        return _index.jsxOpeningFragment;
      }
    });
    Object.defineProperty(exports, "JSXSpreadAttribute", {
      enumerable: true,
      get: function() {
        return _index.jsxSpreadAttribute;
      }
    });
    Object.defineProperty(exports, "JSXSpreadChild", {
      enumerable: true,
      get: function() {
        return _index.jsxSpreadChild;
      }
    });
    Object.defineProperty(exports, "JSXText", {
      enumerable: true,
      get: function() {
        return _index.jsxText;
      }
    });
    Object.defineProperty(exports, "LabeledStatement", {
      enumerable: true,
      get: function() {
        return _index.labeledStatement;
      }
    });
    Object.defineProperty(exports, "LogicalExpression", {
      enumerable: true,
      get: function() {
        return _index.logicalExpression;
      }
    });
    Object.defineProperty(exports, "MemberExpression", {
      enumerable: true,
      get: function() {
        return _index.memberExpression;
      }
    });
    Object.defineProperty(exports, "MetaProperty", {
      enumerable: true,
      get: function() {
        return _index.metaProperty;
      }
    });
    Object.defineProperty(exports, "MixedTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.mixedTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ModuleExpression", {
      enumerable: true,
      get: function() {
        return _index.moduleExpression;
      }
    });
    Object.defineProperty(exports, "NewExpression", {
      enumerable: true,
      get: function() {
        return _index.newExpression;
      }
    });
    Object.defineProperty(exports, "Noop", {
      enumerable: true,
      get: function() {
        return _index.noop;
      }
    });
    Object.defineProperty(exports, "NullLiteral", {
      enumerable: true,
      get: function() {
        return _index.nullLiteral;
      }
    });
    Object.defineProperty(exports, "NullLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.nullLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NullableTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.nullableTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumberLiteral", {
      enumerable: true,
      get: function() {
        return _index.numberLiteral;
      }
    });
    Object.defineProperty(exports, "NumberLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.numberLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumberTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.numberTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "NumericLiteral", {
      enumerable: true,
      get: function() {
        return _index.numericLiteral;
      }
    });
    Object.defineProperty(exports, "ObjectExpression", {
      enumerable: true,
      get: function() {
        return _index.objectExpression;
      }
    });
    Object.defineProperty(exports, "ObjectMethod", {
      enumerable: true,
      get: function() {
        return _index.objectMethod;
      }
    });
    Object.defineProperty(exports, "ObjectPattern", {
      enumerable: true,
      get: function() {
        return _index.objectPattern;
      }
    });
    Object.defineProperty(exports, "ObjectProperty", {
      enumerable: true,
      get: function() {
        return _index.objectProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.objectTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ObjectTypeCallProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeCallProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeIndexer", {
      enumerable: true,
      get: function() {
        return _index.objectTypeIndexer;
      }
    });
    Object.defineProperty(exports, "ObjectTypeInternalSlot", {
      enumerable: true,
      get: function() {
        return _index.objectTypeInternalSlot;
      }
    });
    Object.defineProperty(exports, "ObjectTypeProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeProperty;
      }
    });
    Object.defineProperty(exports, "ObjectTypeSpreadProperty", {
      enumerable: true,
      get: function() {
        return _index.objectTypeSpreadProperty;
      }
    });
    Object.defineProperty(exports, "OpaqueType", {
      enumerable: true,
      get: function() {
        return _index.opaqueType;
      }
    });
    Object.defineProperty(exports, "OptionalCallExpression", {
      enumerable: true,
      get: function() {
        return _index.optionalCallExpression;
      }
    });
    Object.defineProperty(exports, "OptionalIndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.optionalIndexedAccessType;
      }
    });
    Object.defineProperty(exports, "OptionalMemberExpression", {
      enumerable: true,
      get: function() {
        return _index.optionalMemberExpression;
      }
    });
    Object.defineProperty(exports, "ParenthesizedExpression", {
      enumerable: true,
      get: function() {
        return _index.parenthesizedExpression;
      }
    });
    Object.defineProperty(exports, "PipelineBareFunction", {
      enumerable: true,
      get: function() {
        return _index.pipelineBareFunction;
      }
    });
    Object.defineProperty(exports, "PipelinePrimaryTopicReference", {
      enumerable: true,
      get: function() {
        return _index.pipelinePrimaryTopicReference;
      }
    });
    Object.defineProperty(exports, "PipelineTopicExpression", {
      enumerable: true,
      get: function() {
        return _index.pipelineTopicExpression;
      }
    });
    Object.defineProperty(exports, "Placeholder", {
      enumerable: true,
      get: function() {
        return _index.placeholder;
      }
    });
    Object.defineProperty(exports, "PrivateName", {
      enumerable: true,
      get: function() {
        return _index.privateName;
      }
    });
    Object.defineProperty(exports, "Program", {
      enumerable: true,
      get: function() {
        return _index.program;
      }
    });
    Object.defineProperty(exports, "QualifiedTypeIdentifier", {
      enumerable: true,
      get: function() {
        return _index.qualifiedTypeIdentifier;
      }
    });
    Object.defineProperty(exports, "RecordExpression", {
      enumerable: true,
      get: function() {
        return _index.recordExpression;
      }
    });
    Object.defineProperty(exports, "RegExpLiteral", {
      enumerable: true,
      get: function() {
        return _index.regExpLiteral;
      }
    });
    Object.defineProperty(exports, "RegexLiteral", {
      enumerable: true,
      get: function() {
        return _index.regexLiteral;
      }
    });
    Object.defineProperty(exports, "RestElement", {
      enumerable: true,
      get: function() {
        return _index.restElement;
      }
    });
    Object.defineProperty(exports, "RestProperty", {
      enumerable: true,
      get: function() {
        return _index.restProperty;
      }
    });
    Object.defineProperty(exports, "ReturnStatement", {
      enumerable: true,
      get: function() {
        return _index.returnStatement;
      }
    });
    Object.defineProperty(exports, "SequenceExpression", {
      enumerable: true,
      get: function() {
        return _index.sequenceExpression;
      }
    });
    Object.defineProperty(exports, "SpreadElement", {
      enumerable: true,
      get: function() {
        return _index.spreadElement;
      }
    });
    Object.defineProperty(exports, "SpreadProperty", {
      enumerable: true,
      get: function() {
        return _index.spreadProperty;
      }
    });
    Object.defineProperty(exports, "StaticBlock", {
      enumerable: true,
      get: function() {
        return _index.staticBlock;
      }
    });
    Object.defineProperty(exports, "StringLiteral", {
      enumerable: true,
      get: function() {
        return _index.stringLiteral;
      }
    });
    Object.defineProperty(exports, "StringLiteralTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.stringLiteralTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "StringTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.stringTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "Super", {
      enumerable: true,
      get: function() {
        return _index.super;
      }
    });
    Object.defineProperty(exports, "SwitchCase", {
      enumerable: true,
      get: function() {
        return _index.switchCase;
      }
    });
    Object.defineProperty(exports, "SwitchStatement", {
      enumerable: true,
      get: function() {
        return _index.switchStatement;
      }
    });
    Object.defineProperty(exports, "SymbolTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.symbolTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TSAnyKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsAnyKeyword;
      }
    });
    Object.defineProperty(exports, "TSArrayType", {
      enumerable: true,
      get: function() {
        return _index.tsArrayType;
      }
    });
    Object.defineProperty(exports, "TSAsExpression", {
      enumerable: true,
      get: function() {
        return _index.tsAsExpression;
      }
    });
    Object.defineProperty(exports, "TSBigIntKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsBigIntKeyword;
      }
    });
    Object.defineProperty(exports, "TSBooleanKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsBooleanKeyword;
      }
    });
    Object.defineProperty(exports, "TSCallSignatureDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsCallSignatureDeclaration;
      }
    });
    Object.defineProperty(exports, "TSConditionalType", {
      enumerable: true,
      get: function() {
        return _index.tsConditionalType;
      }
    });
    Object.defineProperty(exports, "TSConstructSignatureDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsConstructSignatureDeclaration;
      }
    });
    Object.defineProperty(exports, "TSConstructorType", {
      enumerable: true,
      get: function() {
        return _index.tsConstructorType;
      }
    });
    Object.defineProperty(exports, "TSDeclareFunction", {
      enumerable: true,
      get: function() {
        return _index.tsDeclareFunction;
      }
    });
    Object.defineProperty(exports, "TSDeclareMethod", {
      enumerable: true,
      get: function() {
        return _index.tsDeclareMethod;
      }
    });
    Object.defineProperty(exports, "TSEnumDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsEnumDeclaration;
      }
    });
    Object.defineProperty(exports, "TSEnumMember", {
      enumerable: true,
      get: function() {
        return _index.tsEnumMember;
      }
    });
    Object.defineProperty(exports, "TSExportAssignment", {
      enumerable: true,
      get: function() {
        return _index.tsExportAssignment;
      }
    });
    Object.defineProperty(exports, "TSExpressionWithTypeArguments", {
      enumerable: true,
      get: function() {
        return _index.tsExpressionWithTypeArguments;
      }
    });
    Object.defineProperty(exports, "TSExternalModuleReference", {
      enumerable: true,
      get: function() {
        return _index.tsExternalModuleReference;
      }
    });
    Object.defineProperty(exports, "TSFunctionType", {
      enumerable: true,
      get: function() {
        return _index.tsFunctionType;
      }
    });
    Object.defineProperty(exports, "TSImportEqualsDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsImportEqualsDeclaration;
      }
    });
    Object.defineProperty(exports, "TSImportType", {
      enumerable: true,
      get: function() {
        return _index.tsImportType;
      }
    });
    Object.defineProperty(exports, "TSIndexSignature", {
      enumerable: true,
      get: function() {
        return _index.tsIndexSignature;
      }
    });
    Object.defineProperty(exports, "TSIndexedAccessType", {
      enumerable: true,
      get: function() {
        return _index.tsIndexedAccessType;
      }
    });
    Object.defineProperty(exports, "TSInferType", {
      enumerable: true,
      get: function() {
        return _index.tsInferType;
      }
    });
    Object.defineProperty(exports, "TSInstantiationExpression", {
      enumerable: true,
      get: function() {
        return _index.tsInstantiationExpression;
      }
    });
    Object.defineProperty(exports, "TSInterfaceBody", {
      enumerable: true,
      get: function() {
        return _index.tsInterfaceBody;
      }
    });
    Object.defineProperty(exports, "TSInterfaceDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsInterfaceDeclaration;
      }
    });
    Object.defineProperty(exports, "TSIntersectionType", {
      enumerable: true,
      get: function() {
        return _index.tsIntersectionType;
      }
    });
    Object.defineProperty(exports, "TSIntrinsicKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsIntrinsicKeyword;
      }
    });
    Object.defineProperty(exports, "TSLiteralType", {
      enumerable: true,
      get: function() {
        return _index.tsLiteralType;
      }
    });
    Object.defineProperty(exports, "TSMappedType", {
      enumerable: true,
      get: function() {
        return _index.tsMappedType;
      }
    });
    Object.defineProperty(exports, "TSMethodSignature", {
      enumerable: true,
      get: function() {
        return _index.tsMethodSignature;
      }
    });
    Object.defineProperty(exports, "TSModuleBlock", {
      enumerable: true,
      get: function() {
        return _index.tsModuleBlock;
      }
    });
    Object.defineProperty(exports, "TSModuleDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsModuleDeclaration;
      }
    });
    Object.defineProperty(exports, "TSNamedTupleMember", {
      enumerable: true,
      get: function() {
        return _index.tsNamedTupleMember;
      }
    });
    Object.defineProperty(exports, "TSNamespaceExportDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsNamespaceExportDeclaration;
      }
    });
    Object.defineProperty(exports, "TSNeverKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNeverKeyword;
      }
    });
    Object.defineProperty(exports, "TSNonNullExpression", {
      enumerable: true,
      get: function() {
        return _index.tsNonNullExpression;
      }
    });
    Object.defineProperty(exports, "TSNullKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNullKeyword;
      }
    });
    Object.defineProperty(exports, "TSNumberKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsNumberKeyword;
      }
    });
    Object.defineProperty(exports, "TSObjectKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsObjectKeyword;
      }
    });
    Object.defineProperty(exports, "TSOptionalType", {
      enumerable: true,
      get: function() {
        return _index.tsOptionalType;
      }
    });
    Object.defineProperty(exports, "TSParameterProperty", {
      enumerable: true,
      get: function() {
        return _index.tsParameterProperty;
      }
    });
    Object.defineProperty(exports, "TSParenthesizedType", {
      enumerable: true,
      get: function() {
        return _index.tsParenthesizedType;
      }
    });
    Object.defineProperty(exports, "TSPropertySignature", {
      enumerable: true,
      get: function() {
        return _index.tsPropertySignature;
      }
    });
    Object.defineProperty(exports, "TSQualifiedName", {
      enumerable: true,
      get: function() {
        return _index.tsQualifiedName;
      }
    });
    Object.defineProperty(exports, "TSRestType", {
      enumerable: true,
      get: function() {
        return _index.tsRestType;
      }
    });
    Object.defineProperty(exports, "TSSatisfiesExpression", {
      enumerable: true,
      get: function() {
        return _index.tsSatisfiesExpression;
      }
    });
    Object.defineProperty(exports, "TSStringKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsStringKeyword;
      }
    });
    Object.defineProperty(exports, "TSSymbolKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsSymbolKeyword;
      }
    });
    Object.defineProperty(exports, "TSThisType", {
      enumerable: true,
      get: function() {
        return _index.tsThisType;
      }
    });
    Object.defineProperty(exports, "TSTupleType", {
      enumerable: true,
      get: function() {
        return _index.tsTupleType;
      }
    });
    Object.defineProperty(exports, "TSTypeAliasDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAliasDeclaration;
      }
    });
    Object.defineProperty(exports, "TSTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TSTypeAssertion", {
      enumerable: true,
      get: function() {
        return _index.tsTypeAssertion;
      }
    });
    Object.defineProperty(exports, "TSTypeLiteral", {
      enumerable: true,
      get: function() {
        return _index.tsTypeLiteral;
      }
    });
    Object.defineProperty(exports, "TSTypeOperator", {
      enumerable: true,
      get: function() {
        return _index.tsTypeOperator;
      }
    });
    Object.defineProperty(exports, "TSTypeParameter", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameter;
      }
    });
    Object.defineProperty(exports, "TSTypeParameterDeclaration", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameterDeclaration;
      }
    });
    Object.defineProperty(exports, "TSTypeParameterInstantiation", {
      enumerable: true,
      get: function() {
        return _index.tsTypeParameterInstantiation;
      }
    });
    Object.defineProperty(exports, "TSTypePredicate", {
      enumerable: true,
      get: function() {
        return _index.tsTypePredicate;
      }
    });
    Object.defineProperty(exports, "TSTypeQuery", {
      enumerable: true,
      get: function() {
        return _index.tsTypeQuery;
      }
    });
    Object.defineProperty(exports, "TSTypeReference", {
      enumerable: true,
      get: function() {
        return _index.tsTypeReference;
      }
    });
    Object.defineProperty(exports, "TSUndefinedKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsUndefinedKeyword;
      }
    });
    Object.defineProperty(exports, "TSUnionType", {
      enumerable: true,
      get: function() {
        return _index.tsUnionType;
      }
    });
    Object.defineProperty(exports, "TSUnknownKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsUnknownKeyword;
      }
    });
    Object.defineProperty(exports, "TSVoidKeyword", {
      enumerable: true,
      get: function() {
        return _index.tsVoidKeyword;
      }
    });
    Object.defineProperty(exports, "TaggedTemplateExpression", {
      enumerable: true,
      get: function() {
        return _index.taggedTemplateExpression;
      }
    });
    Object.defineProperty(exports, "TemplateElement", {
      enumerable: true,
      get: function() {
        return _index.templateElement;
      }
    });
    Object.defineProperty(exports, "TemplateLiteral", {
      enumerable: true,
      get: function() {
        return _index.templateLiteral;
      }
    });
    Object.defineProperty(exports, "ThisExpression", {
      enumerable: true,
      get: function() {
        return _index.thisExpression;
      }
    });
    Object.defineProperty(exports, "ThisTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.thisTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "ThrowStatement", {
      enumerable: true,
      get: function() {
        return _index.throwStatement;
      }
    });
    Object.defineProperty(exports, "TopicReference", {
      enumerable: true,
      get: function() {
        return _index.topicReference;
      }
    });
    Object.defineProperty(exports, "TryStatement", {
      enumerable: true,
      get: function() {
        return _index.tryStatement;
      }
    });
    Object.defineProperty(exports, "TupleExpression", {
      enumerable: true,
      get: function() {
        return _index.tupleExpression;
      }
    });
    Object.defineProperty(exports, "TupleTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.tupleTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "TypeAlias", {
      enumerable: true,
      get: function() {
        return _index.typeAlias;
      }
    });
    Object.defineProperty(exports, "TypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.typeAnnotation;
      }
    });
    Object.defineProperty(exports, "TypeCastExpression", {
      enumerable: true,
      get: function() {
        return _index.typeCastExpression;
      }
    });
    Object.defineProperty(exports, "TypeParameter", {
      enumerable: true,
      get: function() {
        return _index.typeParameter;
      }
    });
    Object.defineProperty(exports, "TypeParameterDeclaration", {
      enumerable: true,
      get: function() {
        return _index.typeParameterDeclaration;
      }
    });
    Object.defineProperty(exports, "TypeParameterInstantiation", {
      enumerable: true,
      get: function() {
        return _index.typeParameterInstantiation;
      }
    });
    Object.defineProperty(exports, "TypeofTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.typeofTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "UnaryExpression", {
      enumerable: true,
      get: function() {
        return _index.unaryExpression;
      }
    });
    Object.defineProperty(exports, "UnionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.unionTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "UpdateExpression", {
      enumerable: true,
      get: function() {
        return _index.updateExpression;
      }
    });
    Object.defineProperty(exports, "V8IntrinsicIdentifier", {
      enumerable: true,
      get: function() {
        return _index.v8IntrinsicIdentifier;
      }
    });
    Object.defineProperty(exports, "VariableDeclaration", {
      enumerable: true,
      get: function() {
        return _index.variableDeclaration;
      }
    });
    Object.defineProperty(exports, "VariableDeclarator", {
      enumerable: true,
      get: function() {
        return _index.variableDeclarator;
      }
    });
    Object.defineProperty(exports, "Variance", {
      enumerable: true,
      get: function() {
        return _index.variance;
      }
    });
    Object.defineProperty(exports, "VoidTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _index.voidTypeAnnotation;
      }
    });
    Object.defineProperty(exports, "WhileStatement", {
      enumerable: true,
      get: function() {
        return _index.whileStatement;
      }
    });
    Object.defineProperty(exports, "WithStatement", {
      enumerable: true,
      get: function() {
        return _index.withStatement;
      }
    });
    Object.defineProperty(exports, "YieldExpression", {
      enumerable: true,
      get: function() {
        return _index.yieldExpression;
      }
    });
    var _index = require_generated7();
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneNode.js
var require_cloneNode2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneNode;
    var _index = require_definitions2();
    var _index2 = require_generated6();
    var has = Function.call.bind(Object.prototype.hasOwnProperty);
    function cloneIfNode(obj, deep, withoutLoc, commentsCache) {
      if (obj && typeof obj.type === "string") {
        return cloneNodeInternal(obj, deep, withoutLoc, commentsCache);
      }
      return obj;
    }
    function cloneIfNodeOrArray(obj, deep, withoutLoc, commentsCache) {
      if (Array.isArray(obj)) {
        return obj.map((node) => cloneIfNode(node, deep, withoutLoc, commentsCache));
      }
      return cloneIfNode(obj, deep, withoutLoc, commentsCache);
    }
    function cloneNode(node, deep = true, withoutLoc = false) {
      return cloneNodeInternal(node, deep, withoutLoc, /* @__PURE__ */ new Map());
    }
    function cloneNodeInternal(node, deep = true, withoutLoc = false, commentsCache) {
      if (!node)
        return node;
      const {
        type
      } = node;
      const newNode = {
        type: node.type
      };
      if ((0, _index2.isIdentifier)(node)) {
        newNode.name = node.name;
        if (has(node, "optional") && typeof node.optional === "boolean") {
          newNode.optional = node.optional;
        }
        if (has(node, "typeAnnotation")) {
          newNode.typeAnnotation = deep ? cloneIfNodeOrArray(node.typeAnnotation, true, withoutLoc, commentsCache) : node.typeAnnotation;
        }
      } else if (!has(_index.NODE_FIELDS, type)) {
        throw new Error(`Unknown node type: "${type}"`);
      } else {
        for (const field of Object.keys(_index.NODE_FIELDS[type])) {
          if (has(node, field)) {
            if (deep) {
              newNode[field] = (0, _index2.isFile)(node) && field === "comments" ? maybeCloneComments(node.comments, deep, withoutLoc, commentsCache) : cloneIfNodeOrArray(node[field], true, withoutLoc, commentsCache);
            } else {
              newNode[field] = node[field];
            }
          }
        }
      }
      if (has(node, "loc")) {
        if (withoutLoc) {
          newNode.loc = null;
        } else {
          newNode.loc = node.loc;
        }
      }
      if (has(node, "leadingComments")) {
        newNode.leadingComments = maybeCloneComments(node.leadingComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "innerComments")) {
        newNode.innerComments = maybeCloneComments(node.innerComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "trailingComments")) {
        newNode.trailingComments = maybeCloneComments(node.trailingComments, deep, withoutLoc, commentsCache);
      }
      if (has(node, "extra")) {
        newNode.extra = Object.assign({}, node.extra);
      }
      return newNode;
    }
    function maybeCloneComments(comments, deep, withoutLoc, commentsCache) {
      if (!comments || !deep) {
        return comments;
      }
      return comments.map((comment) => {
        const cache = commentsCache.get(comment);
        if (cache)
          return cache;
        const {
          type,
          value: value2,
          loc
        } = comment;
        const ret = {
          type,
          value: value2,
          loc
        };
        if (withoutLoc) {
          ret.loc = null;
        }
        commentsCache.set(comment, ret);
        return ret;
      });
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/clone.js
var require_clone4 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/clone.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = clone;
    var _cloneNode = require_cloneNode2();
    function clone(node) {
      return (0, _cloneNode.default)(node, false);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneDeep.js
var require_cloneDeep2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneDeep.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneDeep3;
    var _cloneNode = require_cloneNode2();
    function cloneDeep3(node) {
      return (0, _cloneNode.default)(node);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js
var require_cloneDeepWithoutLoc2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneDeepWithoutLoc;
    var _cloneNode = require_cloneNode2();
    function cloneDeepWithoutLoc(node) {
      return (0, _cloneNode.default)(node, true, true);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneWithoutLoc.js
var require_cloneWithoutLoc2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/clone/cloneWithoutLoc.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = cloneWithoutLoc;
    var _cloneNode = require_cloneNode2();
    function cloneWithoutLoc(node) {
      return (0, _cloneNode.default)(node, false, true);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/addComments.js
var require_addComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/addComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = addComments;
    function addComments(node, type, comments) {
      if (!comments || !node)
        return node;
      const key = `${type}Comments`;
      if (node[key]) {
        if (type === "leading") {
          node[key] = comments.concat(node[key]);
        } else {
          node[key].push(...comments);
        }
      } else {
        node[key] = comments;
      }
      return node;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/addComment.js
var require_addComment2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/addComment.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = addComment;
    var _addComments = require_addComments2();
    function addComment(node, type, content, line) {
      return (0, _addComments.default)(node, type, [{
        type: line ? "CommentLine" : "CommentBlock",
        value: content
      }]);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/inherit.js
var require_inherit2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/utils/inherit.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inherit;
    function inherit(key, child, parent) {
      if (child && parent) {
        child[key] = Array.from(new Set([].concat(child[key], parent[key]).filter(Boolean)));
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritInnerComments.js
var require_inheritInnerComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritInnerComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritInnerComments;
    var _inherit = require_inherit2();
    function inheritInnerComments(child, parent) {
      (0, _inherit.default)("innerComments", child, parent);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritLeadingComments.js
var require_inheritLeadingComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritLeadingComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritLeadingComments;
    var _inherit = require_inherit2();
    function inheritLeadingComments(child, parent) {
      (0, _inherit.default)("leadingComments", child, parent);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritTrailingComments.js
var require_inheritTrailingComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritTrailingComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritTrailingComments;
    var _inherit = require_inherit2();
    function inheritTrailingComments(child, parent) {
      (0, _inherit.default)("trailingComments", child, parent);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritsComments.js
var require_inheritsComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/inheritsComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inheritsComments;
    var _inheritTrailingComments = require_inheritTrailingComments2();
    var _inheritLeadingComments = require_inheritLeadingComments2();
    var _inheritInnerComments = require_inheritInnerComments2();
    function inheritsComments(child, parent) {
      (0, _inheritTrailingComments.default)(child, parent);
      (0, _inheritLeadingComments.default)(child, parent);
      (0, _inheritInnerComments.default)(child, parent);
      return child;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/removeComments.js
var require_removeComments2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/comments/removeComments.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeComments;
    var _index = require_constants3();
    function removeComments(node) {
      _index.COMMENT_KEYS.forEach((key) => {
        node[key] = null;
      });
      return node;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/constants/generated/index.js
var require_generated9 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/constants/generated/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.WHILE_TYPES = exports.USERWHITESPACABLE_TYPES = exports.UNARYLIKE_TYPES = exports.TYPESCRIPT_TYPES = exports.TSTYPE_TYPES = exports.TSTYPEELEMENT_TYPES = exports.TSENTITYNAME_TYPES = exports.TSBASETYPE_TYPES = exports.TERMINATORLESS_TYPES = exports.STATEMENT_TYPES = exports.STANDARDIZED_TYPES = exports.SCOPABLE_TYPES = exports.PUREISH_TYPES = exports.PROPERTY_TYPES = exports.PRIVATE_TYPES = exports.PATTERN_TYPES = exports.PATTERNLIKE_TYPES = exports.OBJECTMEMBER_TYPES = exports.MODULESPECIFIER_TYPES = exports.MODULEDECLARATION_TYPES = exports.MISCELLANEOUS_TYPES = exports.METHOD_TYPES = exports.LVAL_TYPES = exports.LOOP_TYPES = exports.LITERAL_TYPES = exports.JSX_TYPES = exports.IMPORTOREXPORTDECLARATION_TYPES = exports.IMMUTABLE_TYPES = exports.FUNCTION_TYPES = exports.FUNCTIONPARENT_TYPES = exports.FOR_TYPES = exports.FORXSTATEMENT_TYPES = exports.FLOW_TYPES = exports.FLOWTYPE_TYPES = exports.FLOWPREDICATE_TYPES = exports.FLOWDECLARATION_TYPES = exports.FLOWBASEANNOTATION_TYPES = exports.EXPRESSION_TYPES = exports.EXPRESSIONWRAPPER_TYPES = exports.EXPORTDECLARATION_TYPES = exports.ENUMMEMBER_TYPES = exports.ENUMBODY_TYPES = exports.DECLARATION_TYPES = exports.CONDITIONAL_TYPES = exports.COMPLETIONSTATEMENT_TYPES = exports.CLASS_TYPES = exports.BLOCK_TYPES = exports.BLOCKPARENT_TYPES = exports.BINARY_TYPES = exports.ACCESSOR_TYPES = void 0;
    var _index = require_definitions2();
    var STANDARDIZED_TYPES = _index.FLIPPED_ALIAS_KEYS["Standardized"];
    exports.STANDARDIZED_TYPES = STANDARDIZED_TYPES;
    var EXPRESSION_TYPES = _index.FLIPPED_ALIAS_KEYS["Expression"];
    exports.EXPRESSION_TYPES = EXPRESSION_TYPES;
    var BINARY_TYPES = _index.FLIPPED_ALIAS_KEYS["Binary"];
    exports.BINARY_TYPES = BINARY_TYPES;
    var SCOPABLE_TYPES = _index.FLIPPED_ALIAS_KEYS["Scopable"];
    exports.SCOPABLE_TYPES = SCOPABLE_TYPES;
    var BLOCKPARENT_TYPES = _index.FLIPPED_ALIAS_KEYS["BlockParent"];
    exports.BLOCKPARENT_TYPES = BLOCKPARENT_TYPES;
    var BLOCK_TYPES = _index.FLIPPED_ALIAS_KEYS["Block"];
    exports.BLOCK_TYPES = BLOCK_TYPES;
    var STATEMENT_TYPES = _index.FLIPPED_ALIAS_KEYS["Statement"];
    exports.STATEMENT_TYPES = STATEMENT_TYPES;
    var TERMINATORLESS_TYPES = _index.FLIPPED_ALIAS_KEYS["Terminatorless"];
    exports.TERMINATORLESS_TYPES = TERMINATORLESS_TYPES;
    var COMPLETIONSTATEMENT_TYPES = _index.FLIPPED_ALIAS_KEYS["CompletionStatement"];
    exports.COMPLETIONSTATEMENT_TYPES = COMPLETIONSTATEMENT_TYPES;
    var CONDITIONAL_TYPES = _index.FLIPPED_ALIAS_KEYS["Conditional"];
    exports.CONDITIONAL_TYPES = CONDITIONAL_TYPES;
    var LOOP_TYPES = _index.FLIPPED_ALIAS_KEYS["Loop"];
    exports.LOOP_TYPES = LOOP_TYPES;
    var WHILE_TYPES = _index.FLIPPED_ALIAS_KEYS["While"];
    exports.WHILE_TYPES = WHILE_TYPES;
    var EXPRESSIONWRAPPER_TYPES = _index.FLIPPED_ALIAS_KEYS["ExpressionWrapper"];
    exports.EXPRESSIONWRAPPER_TYPES = EXPRESSIONWRAPPER_TYPES;
    var FOR_TYPES = _index.FLIPPED_ALIAS_KEYS["For"];
    exports.FOR_TYPES = FOR_TYPES;
    var FORXSTATEMENT_TYPES = _index.FLIPPED_ALIAS_KEYS["ForXStatement"];
    exports.FORXSTATEMENT_TYPES = FORXSTATEMENT_TYPES;
    var FUNCTION_TYPES = _index.FLIPPED_ALIAS_KEYS["Function"];
    exports.FUNCTION_TYPES = FUNCTION_TYPES;
    var FUNCTIONPARENT_TYPES = _index.FLIPPED_ALIAS_KEYS["FunctionParent"];
    exports.FUNCTIONPARENT_TYPES = FUNCTIONPARENT_TYPES;
    var PUREISH_TYPES = _index.FLIPPED_ALIAS_KEYS["Pureish"];
    exports.PUREISH_TYPES = PUREISH_TYPES;
    var DECLARATION_TYPES = _index.FLIPPED_ALIAS_KEYS["Declaration"];
    exports.DECLARATION_TYPES = DECLARATION_TYPES;
    var PATTERNLIKE_TYPES = _index.FLIPPED_ALIAS_KEYS["PatternLike"];
    exports.PATTERNLIKE_TYPES = PATTERNLIKE_TYPES;
    var LVAL_TYPES = _index.FLIPPED_ALIAS_KEYS["LVal"];
    exports.LVAL_TYPES = LVAL_TYPES;
    var TSENTITYNAME_TYPES = _index.FLIPPED_ALIAS_KEYS["TSEntityName"];
    exports.TSENTITYNAME_TYPES = TSENTITYNAME_TYPES;
    var LITERAL_TYPES = _index.FLIPPED_ALIAS_KEYS["Literal"];
    exports.LITERAL_TYPES = LITERAL_TYPES;
    var IMMUTABLE_TYPES = _index.FLIPPED_ALIAS_KEYS["Immutable"];
    exports.IMMUTABLE_TYPES = IMMUTABLE_TYPES;
    var USERWHITESPACABLE_TYPES = _index.FLIPPED_ALIAS_KEYS["UserWhitespacable"];
    exports.USERWHITESPACABLE_TYPES = USERWHITESPACABLE_TYPES;
    var METHOD_TYPES = _index.FLIPPED_ALIAS_KEYS["Method"];
    exports.METHOD_TYPES = METHOD_TYPES;
    var OBJECTMEMBER_TYPES = _index.FLIPPED_ALIAS_KEYS["ObjectMember"];
    exports.OBJECTMEMBER_TYPES = OBJECTMEMBER_TYPES;
    var PROPERTY_TYPES = _index.FLIPPED_ALIAS_KEYS["Property"];
    exports.PROPERTY_TYPES = PROPERTY_TYPES;
    var UNARYLIKE_TYPES = _index.FLIPPED_ALIAS_KEYS["UnaryLike"];
    exports.UNARYLIKE_TYPES = UNARYLIKE_TYPES;
    var PATTERN_TYPES = _index.FLIPPED_ALIAS_KEYS["Pattern"];
    exports.PATTERN_TYPES = PATTERN_TYPES;
    var CLASS_TYPES = _index.FLIPPED_ALIAS_KEYS["Class"];
    exports.CLASS_TYPES = CLASS_TYPES;
    var IMPORTOREXPORTDECLARATION_TYPES = _index.FLIPPED_ALIAS_KEYS["ImportOrExportDeclaration"];
    exports.IMPORTOREXPORTDECLARATION_TYPES = IMPORTOREXPORTDECLARATION_TYPES;
    var EXPORTDECLARATION_TYPES = _index.FLIPPED_ALIAS_KEYS["ExportDeclaration"];
    exports.EXPORTDECLARATION_TYPES = EXPORTDECLARATION_TYPES;
    var MODULESPECIFIER_TYPES = _index.FLIPPED_ALIAS_KEYS["ModuleSpecifier"];
    exports.MODULESPECIFIER_TYPES = MODULESPECIFIER_TYPES;
    var ACCESSOR_TYPES = _index.FLIPPED_ALIAS_KEYS["Accessor"];
    exports.ACCESSOR_TYPES = ACCESSOR_TYPES;
    var PRIVATE_TYPES = _index.FLIPPED_ALIAS_KEYS["Private"];
    exports.PRIVATE_TYPES = PRIVATE_TYPES;
    var FLOW_TYPES = _index.FLIPPED_ALIAS_KEYS["Flow"];
    exports.FLOW_TYPES = FLOW_TYPES;
    var FLOWTYPE_TYPES = _index.FLIPPED_ALIAS_KEYS["FlowType"];
    exports.FLOWTYPE_TYPES = FLOWTYPE_TYPES;
    var FLOWBASEANNOTATION_TYPES = _index.FLIPPED_ALIAS_KEYS["FlowBaseAnnotation"];
    exports.FLOWBASEANNOTATION_TYPES = FLOWBASEANNOTATION_TYPES;
    var FLOWDECLARATION_TYPES = _index.FLIPPED_ALIAS_KEYS["FlowDeclaration"];
    exports.FLOWDECLARATION_TYPES = FLOWDECLARATION_TYPES;
    var FLOWPREDICATE_TYPES = _index.FLIPPED_ALIAS_KEYS["FlowPredicate"];
    exports.FLOWPREDICATE_TYPES = FLOWPREDICATE_TYPES;
    var ENUMBODY_TYPES = _index.FLIPPED_ALIAS_KEYS["EnumBody"];
    exports.ENUMBODY_TYPES = ENUMBODY_TYPES;
    var ENUMMEMBER_TYPES = _index.FLIPPED_ALIAS_KEYS["EnumMember"];
    exports.ENUMMEMBER_TYPES = ENUMMEMBER_TYPES;
    var JSX_TYPES = _index.FLIPPED_ALIAS_KEYS["JSX"];
    exports.JSX_TYPES = JSX_TYPES;
    var MISCELLANEOUS_TYPES = _index.FLIPPED_ALIAS_KEYS["Miscellaneous"];
    exports.MISCELLANEOUS_TYPES = MISCELLANEOUS_TYPES;
    var TYPESCRIPT_TYPES = _index.FLIPPED_ALIAS_KEYS["TypeScript"];
    exports.TYPESCRIPT_TYPES = TYPESCRIPT_TYPES;
    var TSTYPEELEMENT_TYPES = _index.FLIPPED_ALIAS_KEYS["TSTypeElement"];
    exports.TSTYPEELEMENT_TYPES = TSTYPEELEMENT_TYPES;
    var TSTYPE_TYPES = _index.FLIPPED_ALIAS_KEYS["TSType"];
    exports.TSTYPE_TYPES = TSTYPE_TYPES;
    var TSBASETYPE_TYPES = _index.FLIPPED_ALIAS_KEYS["TSBaseType"];
    exports.TSBASETYPE_TYPES = TSBASETYPE_TYPES;
    var MODULEDECLARATION_TYPES = IMPORTOREXPORTDECLARATION_TYPES;
    exports.MODULEDECLARATION_TYPES = MODULEDECLARATION_TYPES;
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toBlock.js
var require_toBlock2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toBlock.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toBlock;
    var _index = require_generated6();
    var _index2 = require_generated7();
    function toBlock(node, parent) {
      if ((0, _index.isBlockStatement)(node)) {
        return node;
      }
      let blockNodes = [];
      if ((0, _index.isEmptyStatement)(node)) {
        blockNodes = [];
      } else {
        if (!(0, _index.isStatement)(node)) {
          if ((0, _index.isFunction)(parent)) {
            node = (0, _index2.returnStatement)(node);
          } else {
            node = (0, _index2.expressionStatement)(node);
          }
        }
        blockNodes = [node];
      }
      return (0, _index2.blockStatement)(blockNodes);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/ensureBlock.js
var require_ensureBlock2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/ensureBlock.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = ensureBlock;
    var _toBlock = require_toBlock2();
    function ensureBlock(node, key = "body") {
      const result = (0, _toBlock.default)(node[key], node);
      node[key] = result;
      return result;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toIdentifier.js
var require_toIdentifier2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toIdentifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toIdentifier;
    var _isValidIdentifier = require_isValidIdentifier2();
    var _helperValidatorIdentifier = require_lib29();
    function toIdentifier(input) {
      input = input + "";
      let name = "";
      for (const c of input) {
        name += (0, _helperValidatorIdentifier.isIdentifierChar)(c.codePointAt(0)) ? c : "-";
      }
      name = name.replace(/^[-0-9]+/, "");
      name = name.replace(/[-\s]+(.)?/g, function(match, c) {
        return c ? c.toUpperCase() : "";
      });
      if (!(0, _isValidIdentifier.default)(name)) {
        name = `_${name}`;
      }
      return name || "_";
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toBindingIdentifierName.js
var require_toBindingIdentifierName2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toBindingIdentifierName.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toBindingIdentifierName;
    var _toIdentifier = require_toIdentifier2();
    function toBindingIdentifierName(name) {
      name = (0, _toIdentifier.default)(name);
      if (name === "eval" || name === "arguments")
        name = "_" + name;
      return name;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toComputedKey.js
var require_toComputedKey2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toComputedKey.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toComputedKey;
    var _index = require_generated6();
    var _index2 = require_generated7();
    function toComputedKey(node, key = node.key || node.property) {
      if (!node.computed && (0, _index.isIdentifier)(key))
        key = (0, _index2.stringLiteral)(key.name);
      return key;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toExpression.js
var require_toExpression2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _index = require_generated6();
    var _default = toExpression;
    exports.default = _default;
    function toExpression(node) {
      if ((0, _index.isExpressionStatement)(node)) {
        node = node.expression;
      }
      if ((0, _index.isExpression)(node)) {
        return node;
      }
      if ((0, _index.isClass)(node)) {
        node.type = "ClassExpression";
      } else if ((0, _index.isFunction)(node)) {
        node.type = "FunctionExpression";
      }
      if (!(0, _index.isExpression)(node)) {
        throw new Error(`cannot turn ${node.type} to an expression`);
      }
      return node;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/traverse/traverseFast.js
var require_traverseFast2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/traverse/traverseFast.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = traverseFast;
    var _index = require_definitions2();
    function traverseFast(node, enter, opts) {
      if (!node)
        return;
      const keys3 = _index.VISITOR_KEYS[node.type];
      if (!keys3)
        return;
      opts = opts || {};
      enter(node, opts);
      for (const key of keys3) {
        const subNode = node[key];
        if (Array.isArray(subNode)) {
          for (const node2 of subNode) {
            traverseFast(node2, enter, opts);
          }
        } else {
          traverseFast(subNode, enter, opts);
        }
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/removeProperties.js
var require_removeProperties2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/removeProperties.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removeProperties;
    var _index = require_constants3();
    var CLEAR_KEYS = ["tokens", "start", "end", "loc", "raw", "rawValue"];
    var CLEAR_KEYS_PLUS_COMMENTS = [..._index.COMMENT_KEYS, "comments", ...CLEAR_KEYS];
    function removeProperties(node, opts = {}) {
      const map = opts.preserveComments ? CLEAR_KEYS : CLEAR_KEYS_PLUS_COMMENTS;
      for (const key of map) {
        if (node[key] != null)
          node[key] = void 0;
      }
      for (const key of Object.keys(node)) {
        if (key[0] === "_" && node[key] != null)
          node[key] = void 0;
      }
      const symbols = Object.getOwnPropertySymbols(node);
      for (const sym of symbols) {
        node[sym] = null;
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/removePropertiesDeep.js
var require_removePropertiesDeep2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/removePropertiesDeep.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = removePropertiesDeep;
    var _traverseFast = require_traverseFast2();
    var _removeProperties = require_removeProperties2();
    function removePropertiesDeep(tree, opts) {
      (0, _traverseFast.default)(tree, _removeProperties.default, opts);
      return tree;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toKeyAlias.js
var require_toKeyAlias2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toKeyAlias.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toKeyAlias;
    var _index = require_generated6();
    var _cloneNode = require_cloneNode2();
    var _removePropertiesDeep = require_removePropertiesDeep2();
    function toKeyAlias(node, key = node.key) {
      let alias;
      if (node.kind === "method") {
        return toKeyAlias.increment() + "";
      } else if ((0, _index.isIdentifier)(key)) {
        alias = key.name;
      } else if ((0, _index.isStringLiteral)(key)) {
        alias = JSON.stringify(key.value);
      } else {
        alias = JSON.stringify((0, _removePropertiesDeep.default)((0, _cloneNode.default)(key)));
      }
      if (node.computed) {
        alias = `[${alias}]`;
      }
      if (node.static) {
        alias = `static:${alias}`;
      }
      return alias;
    }
    toKeyAlias.uid = 0;
    toKeyAlias.increment = function() {
      if (toKeyAlias.uid >= Number.MAX_SAFE_INTEGER) {
        return toKeyAlias.uid = 0;
      } else {
        return toKeyAlias.uid++;
      }
    };
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js
var require_getBindingIdentifiers2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = getBindingIdentifiers;
    var _index = require_generated6();
    function getBindingIdentifiers(node, duplicates, outerOnly) {
      const search = [].concat(node);
      const ids = /* @__PURE__ */ Object.create(null);
      while (search.length) {
        const id = search.shift();
        if (!id)
          continue;
        const keys3 = getBindingIdentifiers.keys[id.type];
        if ((0, _index.isIdentifier)(id)) {
          if (duplicates) {
            const _ids = ids[id.name] = ids[id.name] || [];
            _ids.push(id);
          } else {
            ids[id.name] = id;
          }
          continue;
        }
        if ((0, _index.isExportDeclaration)(id) && !(0, _index.isExportAllDeclaration)(id)) {
          if ((0, _index.isDeclaration)(id.declaration)) {
            search.push(id.declaration);
          }
          continue;
        }
        if (outerOnly) {
          if ((0, _index.isFunctionDeclaration)(id)) {
            search.push(id.id);
            continue;
          }
          if ((0, _index.isFunctionExpression)(id)) {
            continue;
          }
        }
        if (keys3) {
          for (let i = 0; i < keys3.length; i++) {
            const key = keys3[i];
            const nodes = id[key];
            if (nodes) {
              Array.isArray(nodes) ? search.push(...nodes) : search.push(nodes);
            }
          }
        }
      }
      return ids;
    }
    getBindingIdentifiers.keys = {
      DeclareClass: ["id"],
      DeclareFunction: ["id"],
      DeclareModule: ["id"],
      DeclareVariable: ["id"],
      DeclareInterface: ["id"],
      DeclareTypeAlias: ["id"],
      DeclareOpaqueType: ["id"],
      InterfaceDeclaration: ["id"],
      TypeAlias: ["id"],
      OpaqueType: ["id"],
      CatchClause: ["param"],
      LabeledStatement: ["label"],
      UnaryExpression: ["argument"],
      AssignmentExpression: ["left"],
      ImportSpecifier: ["local"],
      ImportNamespaceSpecifier: ["local"],
      ImportDefaultSpecifier: ["local"],
      ImportDeclaration: ["specifiers"],
      ExportSpecifier: ["exported"],
      ExportNamespaceSpecifier: ["exported"],
      ExportDefaultSpecifier: ["exported"],
      FunctionDeclaration: ["id", "params"],
      FunctionExpression: ["id", "params"],
      ArrowFunctionExpression: ["params"],
      ObjectMethod: ["params"],
      ClassMethod: ["params"],
      ClassPrivateMethod: ["params"],
      ForInStatement: ["left"],
      ForOfStatement: ["left"],
      ClassDeclaration: ["id"],
      ClassExpression: ["id"],
      RestElement: ["argument"],
      UpdateExpression: ["argument"],
      ObjectProperty: ["value"],
      AssignmentPattern: ["left"],
      ArrayPattern: ["elements"],
      ObjectPattern: ["properties"],
      VariableDeclaration: ["declarations"],
      VariableDeclarator: ["id"]
    };
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js
var require_gatherSequenceExpressions2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = gatherSequenceExpressions;
    var _getBindingIdentifiers = require_getBindingIdentifiers2();
    var _index = require_generated6();
    var _index2 = require_generated7();
    var _cloneNode = require_cloneNode2();
    function gatherSequenceExpressions(nodes, scope, declars) {
      const exprs = [];
      let ensureLastUndefined = true;
      for (const node of nodes) {
        if (!(0, _index.isEmptyStatement)(node)) {
          ensureLastUndefined = false;
        }
        if ((0, _index.isExpression)(node)) {
          exprs.push(node);
        } else if ((0, _index.isExpressionStatement)(node)) {
          exprs.push(node.expression);
        } else if ((0, _index.isVariableDeclaration)(node)) {
          if (node.kind !== "var")
            return;
          for (const declar of node.declarations) {
            const bindings = (0, _getBindingIdentifiers.default)(declar);
            for (const key of Object.keys(bindings)) {
              declars.push({
                kind: node.kind,
                id: (0, _cloneNode.default)(bindings[key])
              });
            }
            if (declar.init) {
              exprs.push((0, _index2.assignmentExpression)("=", declar.id, declar.init));
            }
          }
          ensureLastUndefined = true;
        } else if ((0, _index.isIfStatement)(node)) {
          const consequent = node.consequent ? gatherSequenceExpressions([node.consequent], scope, declars) : scope.buildUndefinedNode();
          const alternate = node.alternate ? gatherSequenceExpressions([node.alternate], scope, declars) : scope.buildUndefinedNode();
          if (!consequent || !alternate)
            return;
          exprs.push((0, _index2.conditionalExpression)(node.test, consequent, alternate));
        } else if ((0, _index.isBlockStatement)(node)) {
          const body = gatherSequenceExpressions(node.body, scope, declars);
          if (!body)
            return;
          exprs.push(body);
        } else if ((0, _index.isEmptyStatement)(node)) {
          if (nodes.indexOf(node) === 0) {
            ensureLastUndefined = true;
          }
        } else {
          return;
        }
      }
      if (ensureLastUndefined) {
        exprs.push(scope.buildUndefinedNode());
      }
      if (exprs.length === 1) {
        return exprs[0];
      } else {
        return (0, _index2.sequenceExpression)(exprs);
      }
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toSequenceExpression.js
var require_toSequenceExpression2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toSequenceExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = toSequenceExpression;
    var _gatherSequenceExpressions = require_gatherSequenceExpressions2();
    function toSequenceExpression(nodes, scope) {
      if (!(nodes != null && nodes.length))
        return;
      const declars = [];
      const result = (0, _gatherSequenceExpressions.default)(nodes, scope, declars);
      if (!result)
        return;
      for (const declar of declars) {
        scope.push(declar);
      }
      return result;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toStatement.js
var require_toStatement2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/toStatement.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _index = require_generated6();
    var _index2 = require_generated7();
    var _default = toStatement;
    exports.default = _default;
    function toStatement(node, ignore) {
      if ((0, _index.isStatement)(node)) {
        return node;
      }
      let mustHaveId = false;
      let newType;
      if ((0, _index.isClass)(node)) {
        mustHaveId = true;
        newType = "ClassDeclaration";
      } else if ((0, _index.isFunction)(node)) {
        mustHaveId = true;
        newType = "FunctionDeclaration";
      } else if ((0, _index.isAssignmentExpression)(node)) {
        return (0, _index2.expressionStatement)(node);
      }
      if (mustHaveId && !node.id) {
        newType = false;
      }
      if (!newType) {
        if (ignore) {
          return false;
        } else {
          throw new Error(`cannot turn ${node.type} to a statement`);
        }
      }
      node.type = newType;
      return node;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/valueToNode.js
var require_valueToNode2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/converters/valueToNode.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _isValidIdentifier = require_isValidIdentifier2();
    var _index = require_generated7();
    var _default = valueToNode;
    exports.default = _default;
    var objectToString = Function.call.bind(Object.prototype.toString);
    function isRegExp(value2) {
      return objectToString(value2) === "[object RegExp]";
    }
    function isPlainObject(value2) {
      if (typeof value2 !== "object" || value2 === null || Object.prototype.toString.call(value2) !== "[object Object]") {
        return false;
      }
      const proto = Object.getPrototypeOf(value2);
      return proto === null || Object.getPrototypeOf(proto) === null;
    }
    function valueToNode(value2) {
      if (value2 === void 0) {
        return (0, _index.identifier)("undefined");
      }
      if (value2 === true || value2 === false) {
        return (0, _index.booleanLiteral)(value2);
      }
      if (value2 === null) {
        return (0, _index.nullLiteral)();
      }
      if (typeof value2 === "string") {
        return (0, _index.stringLiteral)(value2);
      }
      if (typeof value2 === "number") {
        let result;
        if (Number.isFinite(value2)) {
          result = (0, _index.numericLiteral)(Math.abs(value2));
        } else {
          let numerator;
          if (Number.isNaN(value2)) {
            numerator = (0, _index.numericLiteral)(0);
          } else {
            numerator = (0, _index.numericLiteral)(1);
          }
          result = (0, _index.binaryExpression)("/", numerator, (0, _index.numericLiteral)(0));
        }
        if (value2 < 0 || Object.is(value2, -0)) {
          result = (0, _index.unaryExpression)("-", result);
        }
        return result;
      }
      if (isRegExp(value2)) {
        const pattern = value2.source;
        const flags = value2.toString().match(/\/([a-z]+|)$/)[1];
        return (0, _index.regExpLiteral)(pattern, flags);
      }
      if (Array.isArray(value2)) {
        return (0, _index.arrayExpression)(value2.map(valueToNode));
      }
      if (isPlainObject(value2)) {
        const props = [];
        for (const key of Object.keys(value2)) {
          let nodeKey;
          if ((0, _isValidIdentifier.default)(key)) {
            nodeKey = (0, _index.identifier)(key);
          } else {
            nodeKey = (0, _index.stringLiteral)(key);
          }
          props.push((0, _index.objectProperty)(nodeKey, valueToNode(value2[key])));
        }
        return (0, _index.objectExpression)(props);
      }
      throw new Error("don't know how to turn this value into a node");
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/appendToMemberExpression.js
var require_appendToMemberExpression2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/appendToMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = appendToMemberExpression;
    var _index = require_generated7();
    function appendToMemberExpression(member, append, computed = false) {
      member.object = (0, _index.memberExpression)(member.object, member.property, member.computed);
      member.property = append;
      member.computed = !!computed;
      return member;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/inherits.js
var require_inherits3 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/inherits.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = inherits;
    var _index = require_constants3();
    var _inheritsComments = require_inheritsComments2();
    function inherits(child, parent) {
      if (!child || !parent)
        return child;
      for (const key of _index.INHERIT_KEYS.optional) {
        if (child[key] == null) {
          child[key] = parent[key];
        }
      }
      for (const key of Object.keys(parent)) {
        if (key[0] === "_" && key !== "__clone") {
          child[key] = parent[key];
        }
      }
      for (const key of _index.INHERIT_KEYS.force) {
        child[key] = parent[key];
      }
      (0, _inheritsComments.default)(child, parent);
      return child;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/prependToMemberExpression.js
var require_prependToMemberExpression2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/modifications/prependToMemberExpression.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = prependToMemberExpression;
    var _index = require_generated7();
    var _index2 = require_lib31();
    function prependToMemberExpression(member, prepend) {
      if ((0, _index2.isSuper)(member.object)) {
        throw new Error("Cannot prepend node to super property access (`super.foo`).");
      }
      member.object = (0, _index.memberExpression)(prepend, member.object);
      return member;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js
var require_getOuterBindingIdentifiers2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _getBindingIdentifiers = require_getBindingIdentifiers2();
    var _default = getOuterBindingIdentifiers;
    exports.default = _default;
    function getOuterBindingIdentifiers(node, duplicates) {
      return (0, _getBindingIdentifiers.default)(node, duplicates, true);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/traverse/traverse.js
var require_traverse2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/traverse/traverse.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = traverse3;
    var _index = require_definitions2();
    function traverse3(node, handlers, state) {
      if (typeof handlers === "function") {
        handlers = {
          enter: handlers
        };
      }
      const {
        enter,
        exit
      } = handlers;
      traverseSimpleImpl(node, enter, exit, state, []);
    }
    function traverseSimpleImpl(node, enter, exit, state, ancestors) {
      const keys3 = _index.VISITOR_KEYS[node.type];
      if (!keys3)
        return;
      if (enter)
        enter(node, ancestors, state);
      for (const key of keys3) {
        const subNode = node[key];
        if (Array.isArray(subNode)) {
          for (let i = 0; i < subNode.length; i++) {
            const child = subNode[i];
            if (!child)
              continue;
            ancestors.push({
              node,
              key,
              index: i
            });
            traverseSimpleImpl(child, enter, exit, state, ancestors);
            ancestors.pop();
          }
        } else if (subNode) {
          ancestors.push({
            node,
            key
          });
          traverseSimpleImpl(subNode, enter, exit, state, ancestors);
          ancestors.pop();
        }
      }
      if (exit)
        exit(node, ancestors, state);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isBinding.js
var require_isBinding2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isBinding.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isBinding;
    var _getBindingIdentifiers = require_getBindingIdentifiers2();
    function isBinding(node, parent, grandparent) {
      if (grandparent && node.type === "Identifier" && parent.type === "ObjectProperty" && grandparent.type === "ObjectExpression") {
        return false;
      }
      const keys3 = _getBindingIdentifiers.default.keys[parent.type];
      if (keys3) {
        for (let i = 0; i < keys3.length; i++) {
          const key = keys3[i];
          const val = parent[key];
          if (Array.isArray(val)) {
            if (val.indexOf(node) >= 0)
              return true;
          } else {
            if (val === node)
              return true;
          }
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isLet.js
var require_isLet2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isLet.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isLet;
    var _index = require_generated6();
    var _index2 = require_constants3();
    function isLet(node) {
      return (0, _index.isVariableDeclaration)(node) && (node.kind !== "var" || node[_index2.BLOCK_SCOPED_SYMBOL]);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isBlockScoped.js
var require_isBlockScoped2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isBlockScoped.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isBlockScoped;
    var _index = require_generated6();
    var _isLet = require_isLet2();
    function isBlockScoped(node) {
      return (0, _index.isFunctionDeclaration)(node) || (0, _index.isClassDeclaration)(node) || (0, _isLet.default)(node);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isImmutable.js
var require_isImmutable2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isImmutable.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isImmutable;
    var _isType = require_isType2();
    var _index = require_generated6();
    function isImmutable(node) {
      if ((0, _isType.default)(node.type, "Immutable"))
        return true;
      if ((0, _index.isIdentifier)(node)) {
        if (node.name === "undefined") {
          return true;
        } else {
          return false;
        }
      }
      return false;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isNodesEquivalent.js
var require_isNodesEquivalent2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isNodesEquivalent.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isNodesEquivalent;
    var _index = require_definitions2();
    function isNodesEquivalent(a, b) {
      if (typeof a !== "object" || typeof b !== "object" || a == null || b == null) {
        return a === b;
      }
      if (a.type !== b.type) {
        return false;
      }
      const fields = Object.keys(_index.NODE_FIELDS[a.type] || a.type);
      const visitorKeys = _index.VISITOR_KEYS[a.type];
      for (const field of fields) {
        const val_a = a[field];
        const val_b = b[field];
        if (typeof val_a !== typeof val_b) {
          return false;
        }
        if (val_a == null && val_b == null) {
          continue;
        } else if (val_a == null || val_b == null) {
          return false;
        }
        if (Array.isArray(val_a)) {
          if (!Array.isArray(val_b)) {
            return false;
          }
          if (val_a.length !== val_b.length) {
            return false;
          }
          for (let i = 0; i < val_a.length; i++) {
            if (!isNodesEquivalent(val_a[i], val_b[i])) {
              return false;
            }
          }
          continue;
        }
        if (typeof val_a === "object" && !(visitorKeys != null && visitorKeys.includes(field))) {
          for (const key of Object.keys(val_a)) {
            if (val_a[key] !== val_b[key]) {
              return false;
            }
          }
          continue;
        }
        if (!isNodesEquivalent(val_a, val_b)) {
          return false;
        }
      }
      return true;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isReferenced.js
var require_isReferenced2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isReferenced.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isReferenced;
    function isReferenced(node, parent, grandparent) {
      switch (parent.type) {
        case "MemberExpression":
        case "OptionalMemberExpression":
          if (parent.property === node) {
            return !!parent.computed;
          }
          return parent.object === node;
        case "JSXMemberExpression":
          return parent.object === node;
        case "VariableDeclarator":
          return parent.init === node;
        case "ArrowFunctionExpression":
          return parent.body === node;
        case "PrivateName":
          return false;
        case "ClassMethod":
        case "ClassPrivateMethod":
        case "ObjectMethod":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return false;
        case "ObjectProperty":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return !grandparent || grandparent.type !== "ObjectPattern";
        case "ClassProperty":
        case "ClassAccessorProperty":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return true;
        case "ClassPrivateProperty":
          return parent.key !== node;
        case "ClassDeclaration":
        case "ClassExpression":
          return parent.superClass === node;
        case "AssignmentExpression":
          return parent.right === node;
        case "AssignmentPattern":
          return parent.right === node;
        case "LabeledStatement":
          return false;
        case "CatchClause":
          return false;
        case "RestElement":
          return false;
        case "BreakStatement":
        case "ContinueStatement":
          return false;
        case "FunctionDeclaration":
        case "FunctionExpression":
          return false;
        case "ExportNamespaceSpecifier":
        case "ExportDefaultSpecifier":
          return false;
        case "ExportSpecifier":
          if (grandparent != null && grandparent.source) {
            return false;
          }
          return parent.local === node;
        case "ImportDefaultSpecifier":
        case "ImportNamespaceSpecifier":
        case "ImportSpecifier":
          return false;
        case "ImportAttribute":
          return false;
        case "JSXAttribute":
          return false;
        case "ObjectPattern":
        case "ArrayPattern":
          return false;
        case "MetaProperty":
          return false;
        case "ObjectTypeProperty":
          return parent.key !== node;
        case "TSEnumMember":
          return parent.id !== node;
        case "TSPropertySignature":
          if (parent.key === node) {
            return !!parent.computed;
          }
          return true;
      }
      return true;
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isScope.js
var require_isScope2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isScope.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isScope;
    var _index = require_generated6();
    function isScope(node, parent) {
      if ((0, _index.isBlockStatement)(node) && ((0, _index.isFunction)(parent) || (0, _index.isCatchClause)(parent))) {
        return false;
      }
      if ((0, _index.isPattern)(node) && ((0, _index.isFunction)(parent) || (0, _index.isCatchClause)(parent))) {
        return true;
      }
      return (0, _index.isScopable)(node);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isSpecifierDefault.js
var require_isSpecifierDefault2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isSpecifierDefault.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isSpecifierDefault;
    var _index = require_generated6();
    function isSpecifierDefault(specifier) {
      return (0, _index.isImportDefaultSpecifier)(specifier) || (0, _index.isIdentifier)(specifier.imported || specifier.exported, {
        name: "default"
      });
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isValidES3Identifier.js
var require_isValidES3Identifier2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isValidES3Identifier.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isValidES3Identifier;
    var _isValidIdentifier = require_isValidIdentifier2();
    var RESERVED_WORDS_ES3_ONLY = /* @__PURE__ */ new Set(["abstract", "boolean", "byte", "char", "double", "enum", "final", "float", "goto", "implements", "int", "interface", "long", "native", "package", "private", "protected", "public", "short", "static", "synchronized", "throws", "transient", "volatile"]);
    function isValidES3Identifier(name) {
      return (0, _isValidIdentifier.default)(name) && !RESERVED_WORDS_ES3_ONLY.has(name);
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isVar.js
var require_isVar2 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/validators/isVar.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isVar;
    var _index = require_generated6();
    var _index2 = require_constants3();
    function isVar(node) {
      return (0, _index.isVariableDeclaration)(node, {
        kind: "var"
      }) && !node[_index2.BLOCK_SCOPED_SYMBOL];
    }
  }
});

// node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/index.js
var require_lib31 = __commonJS({
  "node_modules/@babel/helper-module-imports/node_modules/@babel/types/lib/index.js"(exports) {
    "use strict";
    if (typeof process === "object" && process.version === "v20.6.0") {
      if (exports["___internal__alreadyRunning"])
        return;
      Object.defineProperty(exports, "___internal__alreadyRunning", {
        value: true,
        enumerable: false,
        configurable: true
      });
    }
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    var _exportNames = {
      react: true,
      assertNode: true,
      createTypeAnnotationBasedOnTypeof: true,
      createUnionTypeAnnotation: true,
      createFlowUnionType: true,
      createTSUnionType: true,
      cloneNode: true,
      clone: true,
      cloneDeep: true,
      cloneDeepWithoutLoc: true,
      cloneWithoutLoc: true,
      addComment: true,
      addComments: true,
      inheritInnerComments: true,
      inheritLeadingComments: true,
      inheritsComments: true,
      inheritTrailingComments: true,
      removeComments: true,
      ensureBlock: true,
      toBindingIdentifierName: true,
      toBlock: true,
      toComputedKey: true,
      toExpression: true,
      toIdentifier: true,
      toKeyAlias: true,
      toSequenceExpression: true,
      toStatement: true,
      valueToNode: true,
      appendToMemberExpression: true,
      inherits: true,
      prependToMemberExpression: true,
      removeProperties: true,
      removePropertiesDeep: true,
      removeTypeDuplicates: true,
      getBindingIdentifiers: true,
      getOuterBindingIdentifiers: true,
      traverse: true,
      traverseFast: true,
      shallowEqual: true,
      is: true,
      isBinding: true,
      isBlockScoped: true,
      isImmutable: true,
      isLet: true,
      isNode: true,
      isNodesEquivalent: true,
      isPlaceholderType: true,
      isReferenced: true,
      isScope: true,
      isSpecifierDefault: true,
      isType: true,
      isValidES3Identifier: true,
      isValidIdentifier: true,
      isVar: true,
      matchesPattern: true,
      validate: true,
      buildMatchMemberExpression: true,
      __internal__deprecationWarning: true
    };
    Object.defineProperty(exports, "__internal__deprecationWarning", {
      enumerable: true,
      get: function() {
        return _deprecationWarning.default;
      }
    });
    Object.defineProperty(exports, "addComment", {
      enumerable: true,
      get: function() {
        return _addComment.default;
      }
    });
    Object.defineProperty(exports, "addComments", {
      enumerable: true,
      get: function() {
        return _addComments.default;
      }
    });
    Object.defineProperty(exports, "appendToMemberExpression", {
      enumerable: true,
      get: function() {
        return _appendToMemberExpression.default;
      }
    });
    Object.defineProperty(exports, "assertNode", {
      enumerable: true,
      get: function() {
        return _assertNode.default;
      }
    });
    Object.defineProperty(exports, "buildMatchMemberExpression", {
      enumerable: true,
      get: function() {
        return _buildMatchMemberExpression.default;
      }
    });
    Object.defineProperty(exports, "clone", {
      enumerable: true,
      get: function() {
        return _clone.default;
      }
    });
    Object.defineProperty(exports, "cloneDeep", {
      enumerable: true,
      get: function() {
        return _cloneDeep.default;
      }
    });
    Object.defineProperty(exports, "cloneDeepWithoutLoc", {
      enumerable: true,
      get: function() {
        return _cloneDeepWithoutLoc.default;
      }
    });
    Object.defineProperty(exports, "cloneNode", {
      enumerable: true,
      get: function() {
        return _cloneNode.default;
      }
    });
    Object.defineProperty(exports, "cloneWithoutLoc", {
      enumerable: true,
      get: function() {
        return _cloneWithoutLoc.default;
      }
    });
    Object.defineProperty(exports, "createFlowUnionType", {
      enumerable: true,
      get: function() {
        return _createFlowUnionType.default;
      }
    });
    Object.defineProperty(exports, "createTSUnionType", {
      enumerable: true,
      get: function() {
        return _createTSUnionType.default;
      }
    });
    Object.defineProperty(exports, "createTypeAnnotationBasedOnTypeof", {
      enumerable: true,
      get: function() {
        return _createTypeAnnotationBasedOnTypeof.default;
      }
    });
    Object.defineProperty(exports, "createUnionTypeAnnotation", {
      enumerable: true,
      get: function() {
        return _createFlowUnionType.default;
      }
    });
    Object.defineProperty(exports, "ensureBlock", {
      enumerable: true,
      get: function() {
        return _ensureBlock.default;
      }
    });
    Object.defineProperty(exports, "getBindingIdentifiers", {
      enumerable: true,
      get: function() {
        return _getBindingIdentifiers.default;
      }
    });
    Object.defineProperty(exports, "getOuterBindingIdentifiers", {
      enumerable: true,
      get: function() {
        return _getOuterBindingIdentifiers.default;
      }
    });
    Object.defineProperty(exports, "inheritInnerComments", {
      enumerable: true,
      get: function() {
        return _inheritInnerComments.default;
      }
    });
    Object.defineProperty(exports, "inheritLeadingComments", {
      enumerable: true,
      get: function() {
        return _inheritLeadingComments.default;
      }
    });
    Object.defineProperty(exports, "inheritTrailingComments", {
      enumerable: true,
      get: function() {
        return _inheritTrailingComments.default;
      }
    });
    Object.defineProperty(exports, "inherits", {
      enumerable: true,
      get: function() {
        return _inherits.default;
      }
    });
    Object.defineProperty(exports, "inheritsComments", {
      enumerable: true,
      get: function() {
        return _inheritsComments.default;
      }
    });
    Object.defineProperty(exports, "is", {
      enumerable: true,
      get: function() {
        return _is.default;
      }
    });
    Object.defineProperty(exports, "isBinding", {
      enumerable: true,
      get: function() {
        return _isBinding.default;
      }
    });
    Object.defineProperty(exports, "isBlockScoped", {
      enumerable: true,
      get: function() {
        return _isBlockScoped.default;
      }
    });
    Object.defineProperty(exports, "isImmutable", {
      enumerable: true,
      get: function() {
        return _isImmutable.default;
      }
    });
    Object.defineProperty(exports, "isLet", {
      enumerable: true,
      get: function() {
        return _isLet.default;
      }
    });
    Object.defineProperty(exports, "isNode", {
      enumerable: true,
      get: function() {
        return _isNode.default;
      }
    });
    Object.defineProperty(exports, "isNodesEquivalent", {
      enumerable: true,
      get: function() {
        return _isNodesEquivalent.default;
      }
    });
    Object.defineProperty(exports, "isPlaceholderType", {
      enumerable: true,
      get: function() {
        return _isPlaceholderType.default;
      }
    });
    Object.defineProperty(exports, "isReferenced", {
      enumerable: true,
      get: function() {
        return _isReferenced.default;
      }
    });
    Object.defineProperty(exports, "isScope", {
      enumerable: true,
      get: function() {
        return _isScope.default;
      }
    });
    Object.defineProperty(exports, "isSpecifierDefault", {
      enumerable: true,
      get: function() {
        return _isSpecifierDefault.default;
      }
    });
    Object.defineProperty(exports, "isType", {
      enumerable: true,
      get: function() {
        return _isType.default;
      }
    });
    Object.defineProperty(exports, "isValidES3Identifier", {
      enumerable: true,
      get: function() {
        return _isValidES3Identifier.default;
      }
    });
    Object.defineProperty(exports, "isValidIdentifier", {
      enumerable: true,
      get: function() {
        return _isValidIdentifier.default;
      }
    });
    Object.defineProperty(exports, "isVar", {
      enumerable: true,
      get: function() {
        return _isVar.default;
      }
    });
    Object.defineProperty(exports, "matchesPattern", {
      enumerable: true,
      get: function() {
        return _matchesPattern.default;
      }
    });
    Object.defineProperty(exports, "prependToMemberExpression", {
      enumerable: true,
      get: function() {
        return _prependToMemberExpression.default;
      }
    });
    exports.react = void 0;
    Object.defineProperty(exports, "removeComments", {
      enumerable: true,
      get: function() {
        return _removeComments.default;
      }
    });
    Object.defineProperty(exports, "removeProperties", {
      enumerable: true,
      get: function() {
        return _removeProperties.default;
      }
    });
    Object.defineProperty(exports, "removePropertiesDeep", {
      enumerable: true,
      get: function() {
        return _removePropertiesDeep.default;
      }
    });
    Object.defineProperty(exports, "removeTypeDuplicates", {
      enumerable: true,
      get: function() {
        return _removeTypeDuplicates.default;
      }
    });
    Object.defineProperty(exports, "shallowEqual", {
      enumerable: true,
      get: function() {
        return _shallowEqual.default;
      }
    });
    Object.defineProperty(exports, "toBindingIdentifierName", {
      enumerable: true,
      get: function() {
        return _toBindingIdentifierName.default;
      }
    });
    Object.defineProperty(exports, "toBlock", {
      enumerable: true,
      get: function() {
        return _toBlock.default;
      }
    });
    Object.defineProperty(exports, "toComputedKey", {
      enumerable: true,
      get: function() {
        return _toComputedKey.default;
      }
    });
    Object.defineProperty(exports, "toExpression", {
      enumerable: true,
      get: function() {
        return _toExpression.default;
      }
    });
    Object.defineProperty(exports, "toIdentifier", {
      enumerable: true,
      get: function() {
        return _toIdentifier.default;
      }
    });
    Object.defineProperty(exports, "toKeyAlias", {
      enumerable: true,
      get: function() {
        return _toKeyAlias.default;
      }
    });
    Object.defineProperty(exports, "toSequenceExpression", {
      enumerable: true,
      get: function() {
        return _toSequenceExpression.default;
      }
    });
    Object.defineProperty(exports, "toStatement", {
      enumerable: true,
      get: function() {
        return _toStatement.default;
      }
    });
    Object.defineProperty(exports, "traverse", {
      enumerable: true,
      get: function() {
        return _traverse.default;
      }
    });
    Object.defineProperty(exports, "traverseFast", {
      enumerable: true,
      get: function() {
        return _traverseFast.default;
      }
    });
    Object.defineProperty(exports, "validate", {
      enumerable: true,
      get: function() {
        return _validate.default;
      }
    });
    Object.defineProperty(exports, "valueToNode", {
      enumerable: true,
      get: function() {
        return _valueToNode.default;
      }
    });
    var _isReactComponent = require_isReactComponent2();
    var _isCompatTag = require_isCompatTag2();
    var _buildChildren = require_buildChildren2();
    var _assertNode = require_assertNode2();
    var _index = require_generated8();
    Object.keys(_index).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index[key];
        }
      });
    });
    var _createTypeAnnotationBasedOnTypeof = require_createTypeAnnotationBasedOnTypeof2();
    var _createFlowUnionType = require_createFlowUnionType2();
    var _createTSUnionType = require_createTSUnionType2();
    var _index2 = require_generated7();
    Object.keys(_index2).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index2[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index2[key];
        }
      });
    });
    var _uppercase = require_uppercase2();
    Object.keys(_uppercase).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _uppercase[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _uppercase[key];
        }
      });
    });
    var _cloneNode = require_cloneNode2();
    var _clone = require_clone4();
    var _cloneDeep = require_cloneDeep2();
    var _cloneDeepWithoutLoc = require_cloneDeepWithoutLoc2();
    var _cloneWithoutLoc = require_cloneWithoutLoc2();
    var _addComment = require_addComment2();
    var _addComments = require_addComments2();
    var _inheritInnerComments = require_inheritInnerComments2();
    var _inheritLeadingComments = require_inheritLeadingComments2();
    var _inheritsComments = require_inheritsComments2();
    var _inheritTrailingComments = require_inheritTrailingComments2();
    var _removeComments = require_removeComments2();
    var _index3 = require_generated9();
    Object.keys(_index3).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index3[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index3[key];
        }
      });
    });
    var _index4 = require_constants3();
    Object.keys(_index4).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index4[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index4[key];
        }
      });
    });
    var _ensureBlock = require_ensureBlock2();
    var _toBindingIdentifierName = require_toBindingIdentifierName2();
    var _toBlock = require_toBlock2();
    var _toComputedKey = require_toComputedKey2();
    var _toExpression = require_toExpression2();
    var _toIdentifier = require_toIdentifier2();
    var _toKeyAlias = require_toKeyAlias2();
    var _toSequenceExpression = require_toSequenceExpression2();
    var _toStatement = require_toStatement2();
    var _valueToNode = require_valueToNode2();
    var _index5 = require_definitions2();
    Object.keys(_index5).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index5[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index5[key];
        }
      });
    });
    var _appendToMemberExpression = require_appendToMemberExpression2();
    var _inherits = require_inherits3();
    var _prependToMemberExpression = require_prependToMemberExpression2();
    var _removeProperties = require_removeProperties2();
    var _removePropertiesDeep = require_removePropertiesDeep2();
    var _removeTypeDuplicates = require_removeTypeDuplicates3();
    var _getBindingIdentifiers = require_getBindingIdentifiers2();
    var _getOuterBindingIdentifiers = require_getOuterBindingIdentifiers2();
    var _traverse = require_traverse2();
    Object.keys(_traverse).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _traverse[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _traverse[key];
        }
      });
    });
    var _traverseFast = require_traverseFast2();
    var _shallowEqual = require_shallowEqual2();
    var _is = require_is2();
    var _isBinding = require_isBinding2();
    var _isBlockScoped = require_isBlockScoped2();
    var _isImmutable = require_isImmutable2();
    var _isLet = require_isLet2();
    var _isNode = require_isNode2();
    var _isNodesEquivalent = require_isNodesEquivalent2();
    var _isPlaceholderType = require_isPlaceholderType2();
    var _isReferenced = require_isReferenced2();
    var _isScope = require_isScope2();
    var _isSpecifierDefault = require_isSpecifierDefault2();
    var _isType = require_isType2();
    var _isValidES3Identifier = require_isValidES3Identifier2();
    var _isValidIdentifier = require_isValidIdentifier2();
    var _isVar = require_isVar2();
    var _matchesPattern = require_matchesPattern2();
    var _validate = require_validate3();
    var _buildMatchMemberExpression = require_buildMatchMemberExpression2();
    var _index6 = require_generated6();
    Object.keys(_index6).forEach(function(key) {
      if (key === "default" || key === "__esModule")
        return;
      if (Object.prototype.hasOwnProperty.call(_exportNames, key))
        return;
      if (key in exports && exports[key] === _index6[key])
        return;
      Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
          return _index6[key];
        }
      });
    });
    var _deprecationWarning = require_deprecationWarning();
    var react = {
      isReactComponent: _isReactComponent.default,
      isCompatTag: _isCompatTag.default,
      buildChildren: _buildChildren.default
    };
    exports.react = react;
    if (typeof process === "object" && process.version === "v20.6.0")
      delete exports["___internal__alreadyRunning"];
  }
});

// node_modules/@babel/helper-module-imports/lib/import-builder.js
var require_import_builder2 = __commonJS({
  "node_modules/@babel/helper-module-imports/lib/import-builder.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _assert = require("assert");
    var _t = require_lib31();
    var {
      callExpression: callExpression3,
      cloneNode,
      expressionStatement,
      identifier: identifier3,
      importDeclaration,
      importDefaultSpecifier,
      importNamespaceSpecifier,
      importSpecifier: importSpecifier2,
      memberExpression,
      stringLiteral: stringLiteral2,
      variableDeclaration: variableDeclaration2,
      variableDeclarator: variableDeclarator2
    } = _t;
    var ImportBuilder = class {
      constructor(importedSource, scope, hub) {
        this._statements = [];
        this._resultName = null;
        this._importedSource = void 0;
        this._scope = scope;
        this._hub = hub;
        this._importedSource = importedSource;
      }
      done() {
        return {
          statements: this._statements,
          resultName: this._resultName
        };
      }
      import() {
        this._statements.push(importDeclaration([], stringLiteral2(this._importedSource)));
        return this;
      }
      require() {
        this._statements.push(expressionStatement(callExpression3(identifier3("require"), [stringLiteral2(this._importedSource)])));
        return this;
      }
      namespace(name = "namespace") {
        const local = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importNamespaceSpecifier(local)];
        this._resultName = cloneNode(local);
        return this;
      }
      default(name) {
        const id = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importDefaultSpecifier(id)];
        this._resultName = cloneNode(id);
        return this;
      }
      named(name, importName) {
        if (importName === "default")
          return this.default(name);
        const id = this._scope.generateUidIdentifier(name);
        const statement = this._statements[this._statements.length - 1];
        _assert(statement.type === "ImportDeclaration");
        _assert(statement.specifiers.length === 0);
        statement.specifiers = [importSpecifier2(id, identifier3(importName))];
        this._resultName = cloneNode(id);
        return this;
      }
      var(name) {
        const id = this._scope.generateUidIdentifier(name);
        let statement = this._statements[this._statements.length - 1];
        if (statement.type !== "ExpressionStatement") {
          _assert(this._resultName);
          statement = expressionStatement(this._resultName);
          this._statements.push(statement);
        }
        this._statements[this._statements.length - 1] = variableDeclaration2("var", [variableDeclarator2(id, statement.expression)]);
        this._resultName = cloneNode(id);
        return this;
      }
      defaultInterop() {
        return this._interop(this._hub.addHelper("interopRequireDefault"));
      }
      wildcardInterop() {
        return this._interop(this._hub.addHelper("interopRequireWildcard"));
      }
      _interop(callee) {
        const statement = this._statements[this._statements.length - 1];
        if (statement.type === "ExpressionStatement") {
          statement.expression = callExpression3(callee, [statement.expression]);
        } else if (statement.type === "VariableDeclaration") {
          _assert(statement.declarations.length === 1);
          statement.declarations[0].init = callExpression3(callee, [statement.declarations[0].init]);
        } else {
          _assert.fail("Unexpected type.");
        }
        return this;
      }
      prop(name) {
        const statement = this._statements[this._statements.length - 1];
        if (statement.type === "ExpressionStatement") {
          statement.expression = memberExpression(statement.expression, identifier3(name));
        } else if (statement.type === "VariableDeclaration") {
          _assert(statement.declarations.length === 1);
          statement.declarations[0].init = memberExpression(statement.declarations[0].init, identifier3(name));
        } else {
          _assert.fail("Unexpected type:" + statement.type);
        }
        return this;
      }
      read(name) {
        this._resultName = memberExpression(this._resultName, identifier3(name));
      }
    };
    exports.default = ImportBuilder;
  }
});

// node_modules/@babel/helper-module-imports/lib/is-module.js
var require_is_module2 = __commonJS({
  "node_modules/@babel/helper-module-imports/lib/is-module.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = isModule;
    function isModule(path2) {
      return path2.node.sourceType === "module";
    }
  }
});

// node_modules/@babel/helper-module-imports/lib/import-injector.js
var require_import_injector2 = __commonJS({
  "node_modules/@babel/helper-module-imports/lib/import-injector.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;
    var _assert = require("assert");
    var _t = require_lib31();
    var _importBuilder = require_import_builder2();
    var _isModule = require_is_module2();
    var {
      numericLiteral,
      sequenceExpression
    } = _t;
    var ImportInjector = class {
      constructor(path2, importedSource, opts) {
        this._defaultOpts = {
          importedSource: null,
          importedType: "commonjs",
          importedInterop: "babel",
          importingInterop: "babel",
          ensureLiveReference: false,
          ensureNoContext: false,
          importPosition: "before"
        };
        const programPath = path2.find((p) => p.isProgram());
        this._programPath = programPath;
        this._programScope = programPath.scope;
        this._hub = programPath.hub;
        this._defaultOpts = this._applyDefaults(importedSource, opts, true);
      }
      addDefault(importedSourceIn, opts) {
        return this.addNamed("default", importedSourceIn, opts);
      }
      addNamed(importName, importedSourceIn, opts) {
        _assert(typeof importName === "string");
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), importName);
      }
      addNamespace(importedSourceIn, opts) {
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), null);
      }
      addSideEffect(importedSourceIn, opts) {
        return this._generateImport(this._applyDefaults(importedSourceIn, opts), void 0);
      }
      _applyDefaults(importedSource, opts, isInit = false) {
        let newOpts;
        if (typeof importedSource === "string") {
          newOpts = Object.assign({}, this._defaultOpts, {
            importedSource
          }, opts);
        } else {
          _assert(!opts, "Unexpected secondary arguments.");
          newOpts = Object.assign({}, this._defaultOpts, importedSource);
        }
        if (!isInit && opts) {
          if (opts.nameHint !== void 0)
            newOpts.nameHint = opts.nameHint;
          if (opts.blockHoist !== void 0)
            newOpts.blockHoist = opts.blockHoist;
        }
        return newOpts;
      }
      _generateImport(opts, importName) {
        const isDefault = importName === "default";
        const isNamed = !!importName && !isDefault;
        const isNamespace = importName === null;
        const {
          importedSource,
          importedType,
          importedInterop,
          importingInterop,
          ensureLiveReference,
          ensureNoContext,
          nameHint,
          importPosition,
          blockHoist
        } = opts;
        let name = nameHint || importName;
        const isMod = (0, _isModule.default)(this._programPath);
        const isModuleForNode = isMod && importingInterop === "node";
        const isModuleForBabel = isMod && importingInterop === "babel";
        if (importPosition === "after" && !isMod) {
          throw new Error(`"importPosition": "after" is only supported in modules`);
        }
        const builder = new _importBuilder.default(importedSource, this._programScope, this._hub);
        if (importedType === "es6") {
          if (!isModuleForNode && !isModuleForBabel) {
            throw new Error("Cannot import an ES6 module from CommonJS");
          }
          builder.import();
          if (isNamespace) {
            builder.namespace(nameHint || importedSource);
          } else if (isDefault || isNamed) {
            builder.named(name, importName);
          }
        } else if (importedType !== "commonjs") {
          throw new Error(`Unexpected interopType "${importedType}"`);
        } else if (importedInterop === "babel") {
          if (isModuleForNode) {
            name = name !== "default" ? name : importedSource;
            const es6Default = `${importedSource}$es6Default`;
            builder.import();
            if (isNamespace) {
              builder.default(es6Default).var(name || importedSource).wildcardInterop();
            } else if (isDefault) {
              if (ensureLiveReference) {
                builder.default(es6Default).var(name || importedSource).defaultInterop().read("default");
              } else {
                builder.default(es6Default).var(name).defaultInterop().prop(importName);
              }
            } else if (isNamed) {
              builder.default(es6Default).read(importName);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.namespace(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource).wildcardInterop();
            } else if ((isDefault || isNamed) && ensureLiveReference) {
              if (isDefault) {
                name = name !== "default" ? name : importedSource;
                builder.var(name).read(importName);
                builder.defaultInterop();
              } else {
                builder.var(importedSource).read(importName);
              }
            } else if (isDefault) {
              builder.var(name).defaultInterop().prop(importName);
            } else if (isNamed) {
              builder.var(name).prop(importName);
            }
          }
        } else if (importedInterop === "compiled") {
          if (isModuleForNode) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.default(importedSource).read(name);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.namespace(name || importedSource);
            } else if (isDefault || isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource);
            } else if (isDefault || isNamed) {
              if (ensureLiveReference) {
                builder.var(importedSource).read(name);
              } else {
                builder.prop(importName).var(name);
              }
            }
          }
        } else if (importedInterop === "uncompiled") {
          if (isDefault && ensureLiveReference) {
            throw new Error("No live reference for commonjs default");
          }
          if (isModuleForNode) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault) {
              builder.default(name);
            } else if (isNamed) {
              builder.default(importedSource).read(name);
            }
          } else if (isModuleForBabel) {
            builder.import();
            if (isNamespace) {
              builder.default(name || importedSource);
            } else if (isDefault) {
              builder.default(name);
            } else if (isNamed) {
              builder.named(name, importName);
            }
          } else {
            builder.require();
            if (isNamespace) {
              builder.var(name || importedSource);
            } else if (isDefault) {
              builder.var(name);
            } else if (isNamed) {
              if (ensureLiveReference) {
                builder.var(importedSource).read(name);
              } else {
                builder.var(name).prop(importName);
              }
            }
          }
        } else {
          throw new Error(`Unknown importedInterop "${importedInterop}".`);
        }
        const {
          statements,
          resultName
        } = builder.done();
        this._insertStatements(statements, importPosition, blockHoist);
        if ((isDefault || isNamed) && ensureNoContext && resultName.type !== "Identifier") {
          return sequenceExpression([numericLiteral(0), resultName]);
        }
        return resultName;
      }
      _insertStatements(statements, importPosition = "before", blockHoist = 3) {
        const body = this._programPath.get("body");
        if (importPosition === "after") {
          for (let i = body.length - 1; i >= 0; i--) {
            if (body[i].isImportDeclaration()) {
              body[i].insertAfter(statements);
              return;
            }
          }
        } else {
          statements.forEach((node) => {
            node._blockHoist = blockHoist;
          });
          const targetPath = body.find((p) => {
            const val = p.node._blockHoist;
            return Number.isFinite(val) && val < 4;
          });
          if (targetPath) {
            targetPath.insertBefore(statements);
            return;
          }
        }
        this._programPath.unshiftContainer("body", statements);
      }
    };
    exports.default = ImportInjector;
  }
});

// node_modules/@babel/helper-module-imports/lib/index.js
var require_lib32 = __commonJS({
  "node_modules/@babel/helper-module-imports/lib/index.js"(exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    Object.defineProperty(exports, "ImportInjector", {
      enumerable: true,
      get: function() {
        return _importInjector.default;
      }
    });
    exports.addDefault = addDefault;
    exports.addNamed = addNamed2;
    exports.addNamespace = addNamespace;
    exports.addSideEffect = addSideEffect;
    Object.defineProperty(exports, "isModule", {
      enumerable: true,
      get: function() {
        return _isModule.default;
      }
    });
    var _importInjector = require_import_injector2();
    var _isModule = require_is_module2();
    function addDefault(path2, importedSource, opts) {
      return new _importInjector.default(path2).addDefault(importedSource, opts);
    }
    function addNamed2(path2, name, importedSource, opts) {
      return new _importInjector.default(path2).addNamed(name, importedSource, opts);
    }
    function addNamespace(path2, importedSource, opts) {
      return new _importInjector.default(path2).addNamespace(importedSource, opts);
    }
    function addSideEffect(path2, importedSource, opts) {
      return new _importInjector.default(path2).addSideEffect(importedSource, opts);
    }
  }
});

// node_modules/prettier/package.json
var require_package7 = __commonJS({
  "node_modules/prettier/package.json"(exports, module2) {
    module2.exports = {
      name: "prettier",
      version: "2.8.2",
      description: "Prettier is an opinionated code formatter",
      bin: "./bin-prettier.js",
      repository: "prettier/prettier",
      funding: "https://github.com/prettier/prettier?sponsor=1",
      homepage: "https://prettier.io",
      author: "James Long",
      license: "MIT",
      main: "./index.js",
      browser: "./standalone.js",
      unpkg: "./standalone.js",
      engines: {
        node: ">=10.13.0"
      },
      files: [
        "*.js",
        "esm/*.mjs"
      ]
    };
  }
});

// node_modules/prettier/doc.js
var require_doc = __commonJS({
  "node_modules/prettier/doc.js"(exports, module2) {
    (function(factory) {
      if (typeof exports === "object" && typeof module2 === "object") {
        module2.exports = factory();
      } else if (typeof define === "function" && define.amd) {
        define(factory);
      } else {
        var root2 = typeof globalThis !== "undefined" ? globalThis : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : this || {};
        root2.doc = factory();
      }
    })(function() {
      "use strict";
      var __getOwnPropNames2 = Object.getOwnPropertyNames;
      var __commonJS2 = (cb, mod) => function __require() {
        return mod || (0, cb[__getOwnPropNames2(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
      };
      var require_doc_js_umd = __commonJS2({
        "dist/_doc.js.umd.js"(exports2, module3) {
          var __create2 = Object.create;
          var __defProp2 = Object.defineProperty;
          var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
          var __getOwnPropNames22 = Object.getOwnPropertyNames;
          var __getProtoOf2 = Object.getPrototypeOf;
          var __hasOwnProp2 = Object.prototype.hasOwnProperty;
          var __esm = (fn, res) => function __init() {
            return fn && (res = (0, fn[__getOwnPropNames22(fn)[0]])(fn = 0)), res;
          };
          var __commonJS22 = (cb, mod) => function __require() {
            return mod || (0, cb[__getOwnPropNames22(cb)[0]])((mod = {
              exports: {}
            }).exports, mod), mod.exports;
          };
          var __export = (target, all) => {
            for (var name in all)
              __defProp2(target, name, {
                get: all[name],
                enumerable: true
              });
          };
          var __copyProps2 = (to, from, except, desc) => {
            if (from && typeof from === "object" || typeof from === "function") {
              for (let key of __getOwnPropNames22(from))
                if (!__hasOwnProp2.call(to, key) && key !== except)
                  __defProp2(to, key, {
                    get: () => from[key],
                    enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable
                  });
            }
            return to;
          };
          var __toESM2 = (mod, isNodeMode, target) => (target = mod != null ? __create2(__getProtoOf2(mod)) : {}, __copyProps2(isNodeMode || !mod || !mod.__esModule ? __defProp2(target, "default", {
            value: mod,
            enumerable: true
          }) : target, mod));
          var __toCommonJS = (mod) => __copyProps2(__defProp2({}, "__esModule", {
            value: true
          }), mod);
          var init_define_process = __esm({
            "<define:process>"() {
            }
          });
          var require_doc_builders = __commonJS22({
            "src/document/doc-builders.js"(exports22, module22) {
              "use strict";
              init_define_process();
              function concat(parts) {
                if (false) {
                  for (const part of parts) {
                    assertDoc(part);
                  }
                }
                return {
                  type: "concat",
                  parts
                };
              }
              function indent(contents) {
                if (false) {
                  assertDoc(contents);
                }
                return {
                  type: "indent",
                  contents
                };
              }
              function align(widthOrString, contents) {
                if (false) {
                  assertDoc(contents);
                }
                return {
                  type: "align",
                  contents,
                  n: widthOrString
                };
              }
              function group(contents) {
                let opts = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
                if (false) {
                  assertDoc(contents);
                }
                return {
                  type: "group",
                  id: opts.id,
                  contents,
                  break: Boolean(opts.shouldBreak),
                  expandedStates: opts.expandedStates
                };
              }
              function dedentToRoot(contents) {
                return align(Number.NEGATIVE_INFINITY, contents);
              }
              function markAsRoot(contents) {
                return align({
                  type: "root"
                }, contents);
              }
              function dedent(contents) {
                return align(-1, contents);
              }
              function conditionalGroup(states, opts) {
                return group(states[0], Object.assign(Object.assign({}, opts), {}, {
                  expandedStates: states
                }));
              }
              function fill(parts) {
                if (false) {
                  for (const part of parts) {
                    assertDoc(part);
                  }
                }
                return {
                  type: "fill",
                  parts
                };
              }
              function ifBreak(breakContents, flatContents) {
                let opts = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
                if (false) {
                  if (breakContents) {
                    assertDoc(breakContents);
                  }
                  if (flatContents) {
                    assertDoc(flatContents);
                  }
                }
                return {
                  type: "if-break",
                  breakContents,
                  flatContents,
                  groupId: opts.groupId
                };
              }
              function indentIfBreak(contents, opts) {
                return {
                  type: "indent-if-break",
                  contents,
                  groupId: opts.groupId,
                  negate: opts.negate
                };
              }
              function lineSuffix(contents) {
                if (false) {
                  assertDoc(contents);
                }
                return {
                  type: "line-suffix",
                  contents
                };
              }
              var lineSuffixBoundary = {
                type: "line-suffix-boundary"
              };
              var breakParent = {
                type: "break-parent"
              };
              var trim = {
                type: "trim"
              };
              var hardlineWithoutBreakParent = {
                type: "line",
                hard: true
              };
              var literallineWithoutBreakParent = {
                type: "line",
                hard: true,
                literal: true
              };
              var line = {
                type: "line"
              };
              var softline = {
                type: "line",
                soft: true
              };
              var hardline = concat([hardlineWithoutBreakParent, breakParent]);
              var literalline = concat([literallineWithoutBreakParent, breakParent]);
              var cursor = {
                type: "cursor",
                placeholder: Symbol("cursor")
              };
              function join(sep, arr) {
                const res = [];
                for (let i = 0; i < arr.length; i++) {
                  if (i !== 0) {
                    res.push(sep);
                  }
                  res.push(arr[i]);
                }
                return concat(res);
              }
              function addAlignmentToDoc(doc, size, tabWidth) {
                let aligned = doc;
                if (size > 0) {
                  for (let i = 0; i < Math.floor(size / tabWidth); ++i) {
                    aligned = indent(aligned);
                  }
                  aligned = align(size % tabWidth, aligned);
                  aligned = align(Number.NEGATIVE_INFINITY, aligned);
                }
                return aligned;
              }
              function label(label2, contents) {
                return {
                  type: "label",
                  label: label2,
                  contents
                };
              }
              module22.exports = {
                concat,
                join,
                line,
                softline,
                hardline,
                literalline,
                group,
                conditionalGroup,
                fill,
                lineSuffix,
                lineSuffixBoundary,
                cursor,
                breakParent,
                ifBreak,
                trim,
                indent,
                indentIfBreak,
                align,
                addAlignmentToDoc,
                markAsRoot,
                dedentToRoot,
                dedent,
                hardlineWithoutBreakParent,
                literallineWithoutBreakParent,
                label
              };
            }
          });
          var require_end_of_line = __commonJS22({
            "src/common/end-of-line.js"(exports22, module22) {
              "use strict";
              init_define_process();
              function guessEndOfLine(text) {
                const index = text.indexOf("\r");
                if (index >= 0) {
                  return text.charAt(index + 1) === "\n" ? "crlf" : "cr";
                }
                return "lf";
              }
              function convertEndOfLineToChars(value2) {
                switch (value2) {
                  case "cr":
                    return "\r";
                  case "crlf":
                    return "\r\n";
                  default:
                    return "\n";
                }
              }
              function countEndOfLineChars(text, eol) {
                let regex;
                switch (eol) {
                  case "\n":
                    regex = /\n/g;
                    break;
                  case "\r":
                    regex = /\r/g;
                    break;
                  case "\r\n":
                    regex = /\r\n/g;
                    break;
                  default:
                    throw new Error(`Unexpected "eol" ${JSON.stringify(eol)}.`);
                }
                const endOfLines = text.match(regex);
                return endOfLines ? endOfLines.length : 0;
              }
              function normalizeEndOfLine(text) {
                return text.replace(/\r\n?/g, "\n");
              }
              module22.exports = {
                guessEndOfLine,
                convertEndOfLineToChars,
                countEndOfLineChars,
                normalizeEndOfLine
              };
            }
          });
          var require_get_last = __commonJS22({
            "src/utils/get-last.js"(exports22, module22) {
              "use strict";
              init_define_process();
              var getLast = (arr) => arr[arr.length - 1];
              module22.exports = getLast;
            }
          });
          function ansiRegex() {
            let {
              onlyFirst = false
            } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
            const pattern = ["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)", "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"].join("|");
            return new RegExp(pattern, onlyFirst ? void 0 : "g");
          }
          var init_ansi_regex = __esm({
            "node_modules/strip-ansi/node_modules/ansi-regex/index.js"() {
              init_define_process();
            }
          });
          function stripAnsi(string) {
            if (typeof string !== "string") {
              throw new TypeError(`Expected a \`string\`, got \`${typeof string}\``);
            }
            return string.replace(ansiRegex(), "");
          }
          var init_strip_ansi = __esm({
            "node_modules/strip-ansi/index.js"() {
              init_define_process();
              init_ansi_regex();
            }
          });
          function isFullwidthCodePoint(codePoint) {
            if (!Number.isInteger(codePoint)) {
              return false;
            }
            return codePoint >= 4352 && (codePoint <= 4447 || codePoint === 9001 || codePoint === 9002 || 11904 <= codePoint && codePoint <= 12871 && codePoint !== 12351 || 12880 <= codePoint && codePoint <= 19903 || 19968 <= codePoint && codePoint <= 42182 || 43360 <= codePoint && codePoint <= 43388 || 44032 <= codePoint && codePoint <= 55203 || 63744 <= codePoint && codePoint <= 64255 || 65040 <= codePoint && codePoint <= 65049 || 65072 <= codePoint && codePoint <= 65131 || 65281 <= codePoint && codePoint <= 65376 || 65504 <= codePoint && codePoint <= 65510 || 110592 <= codePoint && codePoint <= 110593 || 127488 <= codePoint && codePoint <= 127569 || 131072 <= codePoint && codePoint <= 262141);
          }
          var init_is_fullwidth_code_point = __esm({
            "node_modules/is-fullwidth-code-point/index.js"() {
              init_define_process();
            }
          });
          var require_emoji_regex2 = __commonJS22({
            "node_modules/emoji-regex/index.js"(exports22, module22) {
              "use strict";
              init_define_process();
              module22.exports = function() {
                return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67)\uDB40\uDC7F|(?:\uD83E\uDDD1\uD83C\uDFFF\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFC-\uDFFF])|\uD83D\uDC68(?:\uD83C\uDFFB(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|[\u2695\u2696\u2708]\uFE0F|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))?|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])\uFE0F|\u200D(?:(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D[\uDC66\uDC67])|\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC)?|(?:\uD83D\uDC69(?:\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69]))|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC69(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83E\uDDD1(?:\u200D(?:\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDE36\u200D\uD83C\uDF2B|\uD83C\uDFF3\uFE0F\u200D\u26A7|\uD83D\uDC3B\u200D\u2744|(?:(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\uD83C\uDFF4\u200D\u2620|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])\u200D[\u2640\u2642]|[\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u2328\u23CF\u23ED-\u23EF\u23F1\u23F2\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB\u25FC\u2600-\u2604\u260E\u2611\u2618\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u2692\u2694-\u2697\u2699\u269B\u269C\u26A0\u26A7\u26B0\u26B1\u26C8\u26CF\u26D1\u26D3\u26E9\u26F0\u26F1\u26F4\u26F7\u26F8\u2702\u2708\u2709\u270F\u2712\u2714\u2716\u271D\u2721\u2733\u2734\u2744\u2747\u2763\u27A1\u2934\u2935\u2B05-\u2B07\u3030\u303D\u3297\u3299]|\uD83C[\uDD70\uDD71\uDD7E\uDD7F\uDE02\uDE37\uDF21\uDF24-\uDF2C\uDF36\uDF7D\uDF96\uDF97\uDF99-\uDF9B\uDF9E\uDF9F\uDFCD\uDFCE\uDFD4-\uDFDF\uDFF5\uDFF7]|\uD83D[\uDC3F\uDCFD\uDD49\uDD4A\uDD6F\uDD70\uDD73\uDD76-\uDD79\uDD87\uDD8A-\uDD8D\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA\uDECB\uDECD-\uDECF\uDEE0-\uDEE5\uDEE9\uDEF0\uDEF3])\uFE0F|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDE35\u200D\uD83D\uDCAB|\uD83D\uDE2E\u200D\uD83D\uDCA8|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83E\uDDD1(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83D\uDC69(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF6\uD83C\uDDE6|\uD83C\uDDF4\uD83C\uDDF2|\uD83D\uDC08\u200D\u2B1B|\u2764\uFE0F\u200D(?:\uD83D\uDD25|\uD83E\uDE79)|\uD83D\uDC41\uFE0F|\uD83C\uDFF3\uFE0F|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|[#\*0-9]\uFE0F\u20E3|\u2764\uFE0F|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|\uD83C\uDFF4|(?:[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270C\u270D]|\uD83D[\uDD74\uDD90])(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC08\uDC15\uDC3B\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE2E\uDE35\uDE36\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5]|\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD]|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF]|[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF84\uDF86-\uDF93\uDFA0-\uDFC1\uDFC5\uDFC6\uDFC8\uDFC9\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC07\uDC09-\uDC14\uDC16-\uDC3A\uDC3C-\uDC3E\uDC40\uDC44\uDC45\uDC51-\uDC65\uDC6A\uDC79-\uDC7B\uDC7D-\uDC80\uDC84\uDC88-\uDC8E\uDC90\uDC92-\uDCA9\uDCAB-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDDA4\uDDFB-\uDE2D\uDE2F-\uDE34\uDE37-\uDE44\uDE48-\uDE4A\uDE80-\uDEA2\uDEA4-\uDEB3\uDEB7-\uDEBF\uDEC1-\uDEC5\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0D\uDD0E\uDD10-\uDD17\uDD1D\uDD20-\uDD25\uDD27-\uDD2F\uDD3A\uDD3F-\uDD45\uDD47-\uDD76\uDD78\uDD7A-\uDDB4\uDDB7\uDDBA\uDDBC-\uDDCB\uDDD0\uDDE0-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6]|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26A7\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5-\uDED7\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDD77\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
              };
            }
          });
          var string_width_exports = {};
          __export(string_width_exports, {
            default: () => stringWidth
          });
          function stringWidth(string) {
            if (typeof string !== "string" || string.length === 0) {
              return 0;
            }
            string = stripAnsi(string);
            if (string.length === 0) {
              return 0;
            }
            string = string.replace((0, import_emoji_regex.default)(), "  ");
            let width = 0;
            for (let index = 0; index < string.length; index++) {
              const codePoint = string.codePointAt(index);
              if (codePoint <= 31 || codePoint >= 127 && codePoint <= 159) {
                continue;
              }
              if (codePoint >= 768 && codePoint <= 879) {
                continue;
              }
              if (codePoint > 65535) {
                index++;
              }
              width += isFullwidthCodePoint(codePoint) ? 2 : 1;
            }
            return width;
          }
          var import_emoji_regex;
          var init_string_width = __esm({
            "node_modules/string-width/index.js"() {
              init_define_process();
              init_strip_ansi();
              init_is_fullwidth_code_point();
              import_emoji_regex = __toESM2(require_emoji_regex2());
            }
          });
          var require_get_string_width = __commonJS22({
            "src/utils/get-string-width.js"(exports22, module22) {
              "use strict";
              init_define_process();
              var stringWidth2 = (init_string_width(), __toCommonJS(string_width_exports)).default;
              var notAsciiRegex = /[^\x20-\x7F]/;
              function getStringWidth(text) {
                if (!text) {
                  return 0;
                }
                if (!notAsciiRegex.test(text)) {
                  return text.length;
                }
                return stringWidth2(text);
              }
              module22.exports = getStringWidth;
            }
          });
          var require_doc_utils = __commonJS22({
            "src/document/doc-utils.js"(exports22, module22) {
              "use strict";
              init_define_process();
              var getLast = require_get_last();
              var {
                literalline,
                join
              } = require_doc_builders();
              var isConcat = (doc) => Array.isArray(doc) || doc && doc.type === "concat";
              var getDocParts = (doc) => {
                if (Array.isArray(doc)) {
                  return doc;
                }
                if (doc.type !== "concat" && doc.type !== "fill") {
                  throw new Error("Expect doc type to be `concat` or `fill`.");
                }
                return doc.parts;
              };
              var traverseDocOnExitStackMarker = {};
              function traverseDoc(doc, onEnter, onExit, shouldTraverseConditionalGroups) {
                const docsStack = [doc];
                while (docsStack.length > 0) {
                  const doc2 = docsStack.pop();
                  if (doc2 === traverseDocOnExitStackMarker) {
                    onExit(docsStack.pop());
                    continue;
                  }
                  if (onExit) {
                    docsStack.push(doc2, traverseDocOnExitStackMarker);
                  }
                  if (!onEnter || onEnter(doc2) !== false) {
                    if (isConcat(doc2) || doc2.type === "fill") {
                      const parts = getDocParts(doc2);
                      for (let ic = parts.length, i = ic - 1; i >= 0; --i) {
                        docsStack.push(parts[i]);
                      }
                    } else if (doc2.type === "if-break") {
                      if (doc2.flatContents) {
                        docsStack.push(doc2.flatContents);
                      }
                      if (doc2.breakContents) {
                        docsStack.push(doc2.breakContents);
                      }
                    } else if (doc2.type === "group" && doc2.expandedStates) {
                      if (shouldTraverseConditionalGroups) {
                        for (let ic = doc2.expandedStates.length, i = ic - 1; i >= 0; --i) {
                          docsStack.push(doc2.expandedStates[i]);
                        }
                      } else {
                        docsStack.push(doc2.contents);
                      }
                    } else if (doc2.contents) {
                      docsStack.push(doc2.contents);
                    }
                  }
                }
              }
              function mapDoc(doc, cb) {
                const mapped = /* @__PURE__ */ new Map();
                return rec(doc);
                function rec(doc2) {
                  if (mapped.has(doc2)) {
                    return mapped.get(doc2);
                  }
                  const result = process2(doc2);
                  mapped.set(doc2, result);
                  return result;
                }
                function process2(doc2) {
                  if (Array.isArray(doc2)) {
                    return cb(doc2.map(rec));
                  }
                  if (doc2.type === "concat" || doc2.type === "fill") {
                    const parts = doc2.parts.map(rec);
                    return cb(Object.assign(Object.assign({}, doc2), {}, {
                      parts
                    }));
                  }
                  if (doc2.type === "if-break") {
                    const breakContents = doc2.breakContents && rec(doc2.breakContents);
                    const flatContents = doc2.flatContents && rec(doc2.flatContents);
                    return cb(Object.assign(Object.assign({}, doc2), {}, {
                      breakContents,
                      flatContents
                    }));
                  }
                  if (doc2.type === "group" && doc2.expandedStates) {
                    const expandedStates = doc2.expandedStates.map(rec);
                    const contents = expandedStates[0];
                    return cb(Object.assign(Object.assign({}, doc2), {}, {
                      contents,
                      expandedStates
                    }));
                  }
                  if (doc2.contents) {
                    const contents = rec(doc2.contents);
                    return cb(Object.assign(Object.assign({}, doc2), {}, {
                      contents
                    }));
                  }
                  return cb(doc2);
                }
              }
              function findInDoc(doc, fn, defaultValue) {
                let result = defaultValue;
                let hasStopped = false;
                function findInDocOnEnterFn(doc2) {
                  const maybeResult = fn(doc2);
                  if (maybeResult !== void 0) {
                    hasStopped = true;
                    result = maybeResult;
                  }
                  if (hasStopped) {
                    return false;
                  }
                }
                traverseDoc(doc, findInDocOnEnterFn);
                return result;
              }
              function willBreakFn(doc) {
                if (doc.type === "group" && doc.break) {
                  return true;
                }
                if (doc.type === "line" && doc.hard) {
                  return true;
                }
                if (doc.type === "break-parent") {
                  return true;
                }
              }
              function willBreak(doc) {
                return findInDoc(doc, willBreakFn, false);
              }
              function breakParentGroup(groupStack) {
                if (groupStack.length > 0) {
                  const parentGroup = getLast(groupStack);
                  if (!parentGroup.expandedStates && !parentGroup.break) {
                    parentGroup.break = "propagated";
                  }
                }
                return null;
              }
              function propagateBreaks(doc) {
                const alreadyVisitedSet = /* @__PURE__ */ new Set();
                const groupStack = [];
                function propagateBreaksOnEnterFn(doc2) {
                  if (doc2.type === "break-parent") {
                    breakParentGroup(groupStack);
                  }
                  if (doc2.type === "group") {
                    groupStack.push(doc2);
                    if (alreadyVisitedSet.has(doc2)) {
                      return false;
                    }
                    alreadyVisitedSet.add(doc2);
                  }
                }
                function propagateBreaksOnExitFn(doc2) {
                  if (doc2.type === "group") {
                    const group = groupStack.pop();
                    if (group.break) {
                      breakParentGroup(groupStack);
                    }
                  }
                }
                traverseDoc(doc, propagateBreaksOnEnterFn, propagateBreaksOnExitFn, true);
              }
              function removeLinesFn(doc) {
                if (doc.type === "line" && !doc.hard) {
                  return doc.soft ? "" : " ";
                }
                if (doc.type === "if-break") {
                  return doc.flatContents || "";
                }
                return doc;
              }
              function removeLines(doc) {
                return mapDoc(doc, removeLinesFn);
              }
              var isHardline = (doc, nextDoc) => doc && doc.type === "line" && doc.hard && nextDoc && nextDoc.type === "break-parent";
              function stripDocTrailingHardlineFromDoc(doc) {
                if (!doc) {
                  return doc;
                }
                if (isConcat(doc) || doc.type === "fill") {
                  const parts = getDocParts(doc);
                  while (parts.length > 1 && isHardline(...parts.slice(-2))) {
                    parts.length -= 2;
                  }
                  if (parts.length > 0) {
                    const lastPart = stripDocTrailingHardlineFromDoc(getLast(parts));
                    parts[parts.length - 1] = lastPart;
                  }
                  return Array.isArray(doc) ? parts : Object.assign(Object.assign({}, doc), {}, {
                    parts
                  });
                }
                switch (doc.type) {
                  case "align":
                  case "indent":
                  case "indent-if-break":
                  case "group":
                  case "line-suffix":
                  case "label": {
                    const contents = stripDocTrailingHardlineFromDoc(doc.contents);
                    return Object.assign(Object.assign({}, doc), {}, {
                      contents
                    });
                  }
                  case "if-break": {
                    const breakContents = stripDocTrailingHardlineFromDoc(doc.breakContents);
                    const flatContents = stripDocTrailingHardlineFromDoc(doc.flatContents);
                    return Object.assign(Object.assign({}, doc), {}, {
                      breakContents,
                      flatContents
                    });
                  }
                }
                return doc;
              }
              function stripTrailingHardline(doc) {
                return stripDocTrailingHardlineFromDoc(cleanDoc(doc));
              }
              function cleanDocFn(doc) {
                switch (doc.type) {
                  case "fill":
                    if (doc.parts.every((part) => part === "")) {
                      return "";
                    }
                    break;
                  case "group":
                    if (!doc.contents && !doc.id && !doc.break && !doc.expandedStates) {
                      return "";
                    }
                    if (doc.contents.type === "group" && doc.contents.id === doc.id && doc.contents.break === doc.break && doc.contents.expandedStates === doc.expandedStates) {
                      return doc.contents;
                    }
                    break;
                  case "align":
                  case "indent":
                  case "indent-if-break":
                  case "line-suffix":
                    if (!doc.contents) {
                      return "";
                    }
                    break;
                  case "if-break":
                    if (!doc.flatContents && !doc.breakContents) {
                      return "";
                    }
                    break;
                }
                if (!isConcat(doc)) {
                  return doc;
                }
                const parts = [];
                for (const part of getDocParts(doc)) {
                  if (!part) {
                    continue;
                  }
                  const [currentPart, ...restParts] = isConcat(part) ? getDocParts(part) : [part];
                  if (typeof currentPart === "string" && typeof getLast(parts) === "string") {
                    parts[parts.length - 1] += currentPart;
                  } else {
                    parts.push(currentPart);
                  }
                  parts.push(...restParts);
                }
                if (parts.length === 0) {
                  return "";
                }
                if (parts.length === 1) {
                  return parts[0];
                }
                return Array.isArray(doc) ? parts : Object.assign(Object.assign({}, doc), {}, {
                  parts
                });
              }
              function cleanDoc(doc) {
                return mapDoc(doc, (currentDoc) => cleanDocFn(currentDoc));
              }
              function normalizeParts(parts) {
                const newParts = [];
                const restParts = parts.filter(Boolean);
                while (restParts.length > 0) {
                  const part = restParts.shift();
                  if (!part) {
                    continue;
                  }
                  if (isConcat(part)) {
                    restParts.unshift(...getDocParts(part));
                    continue;
                  }
                  if (newParts.length > 0 && typeof getLast(newParts) === "string" && typeof part === "string") {
                    newParts[newParts.length - 1] += part;
                    continue;
                  }
                  newParts.push(part);
                }
                return newParts;
              }
              function normalizeDoc(doc) {
                return mapDoc(doc, (currentDoc) => {
                  if (Array.isArray(currentDoc)) {
                    return normalizeParts(currentDoc);
                  }
                  if (!currentDoc.parts) {
                    return currentDoc;
                  }
                  return Object.assign(Object.assign({}, currentDoc), {}, {
                    parts: normalizeParts(currentDoc.parts)
                  });
                });
              }
              function replaceEndOfLine(doc) {
                return mapDoc(doc, (currentDoc) => typeof currentDoc === "string" && currentDoc.includes("\n") ? replaceTextEndOfLine(currentDoc) : currentDoc);
              }
              function replaceTextEndOfLine(text) {
                let replacement = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : literalline;
                return join(replacement, text.split("\n")).parts;
              }
              function canBreakFn(doc) {
                if (doc.type === "line") {
                  return true;
                }
              }
              function canBreak(doc) {
                return findInDoc(doc, canBreakFn, false);
              }
              module22.exports = {
                isConcat,
                getDocParts,
                willBreak,
                traverseDoc,
                findInDoc,
                mapDoc,
                propagateBreaks,
                removeLines,
                stripTrailingHardline,
                normalizeParts,
                normalizeDoc,
                cleanDoc,
                replaceTextEndOfLine,
                replaceEndOfLine,
                canBreak
              };
            }
          });
          var require_doc_printer = __commonJS22({
            "src/document/doc-printer.js"(exports22, module22) {
              "use strict";
              init_define_process();
              var {
                convertEndOfLineToChars
              } = require_end_of_line();
              var getLast = require_get_last();
              var getStringWidth = require_get_string_width();
              var {
                fill,
                cursor,
                indent
              } = require_doc_builders();
              var {
                isConcat,
                getDocParts
              } = require_doc_utils();
              var groupModeMap;
              var MODE_BREAK = 1;
              var MODE_FLAT = 2;
              function rootIndent() {
                return {
                  value: "",
                  length: 0,
                  queue: []
                };
              }
              function makeIndent(ind, options) {
                return generateInd(ind, {
                  type: "indent"
                }, options);
              }
              function makeAlign(indent2, widthOrDoc, options) {
                if (widthOrDoc === Number.NEGATIVE_INFINITY) {
                  return indent2.root || rootIndent();
                }
                if (widthOrDoc < 0) {
                  return generateInd(indent2, {
                    type: "dedent"
                  }, options);
                }
                if (!widthOrDoc) {
                  return indent2;
                }
                if (widthOrDoc.type === "root") {
                  return Object.assign(Object.assign({}, indent2), {}, {
                    root: indent2
                  });
                }
                const alignType = typeof widthOrDoc === "string" ? "stringAlign" : "numberAlign";
                return generateInd(indent2, {
                  type: alignType,
                  n: widthOrDoc
                }, options);
              }
              function generateInd(ind, newPart, options) {
                const queue = newPart.type === "dedent" ? ind.queue.slice(0, -1) : [...ind.queue, newPart];
                let value2 = "";
                let length = 0;
                let lastTabs = 0;
                let lastSpaces = 0;
                for (const part of queue) {
                  switch (part.type) {
                    case "indent":
                      flush();
                      if (options.useTabs) {
                        addTabs(1);
                      } else {
                        addSpaces(options.tabWidth);
                      }
                      break;
                    case "stringAlign":
                      flush();
                      value2 += part.n;
                      length += part.n.length;
                      break;
                    case "numberAlign":
                      lastTabs += 1;
                      lastSpaces += part.n;
                      break;
                    default:
                      throw new Error(`Unexpected type '${part.type}'`);
                  }
                }
                flushSpaces();
                return Object.assign(Object.assign({}, ind), {}, {
                  value: value2,
                  length,
                  queue
                });
                function addTabs(count) {
                  value2 += "	".repeat(count);
                  length += options.tabWidth * count;
                }
                function addSpaces(count) {
                  value2 += " ".repeat(count);
                  length += count;
                }
                function flush() {
                  if (options.useTabs) {
                    flushTabs();
                  } else {
                    flushSpaces();
                  }
                }
                function flushTabs() {
                  if (lastTabs > 0) {
                    addTabs(lastTabs);
                  }
                  resetLast();
                }
                function flushSpaces() {
                  if (lastSpaces > 0) {
                    addSpaces(lastSpaces);
                  }
                  resetLast();
                }
                function resetLast() {
                  lastTabs = 0;
                  lastSpaces = 0;
                }
              }
              function trim(out) {
                if (out.length === 0) {
                  return 0;
                }
                let trimCount = 0;
                while (out.length > 0 && typeof getLast(out) === "string" && /^[\t ]*$/.test(getLast(out))) {
                  trimCount += out.pop().length;
                }
                if (out.length > 0 && typeof getLast(out) === "string") {
                  const trimmed = getLast(out).replace(/[\t ]*$/, "");
                  trimCount += getLast(out).length - trimmed.length;
                  out[out.length - 1] = trimmed;
                }
                return trimCount;
              }
              function fits(next, restCommands, width, hasLineSuffix, mustBeFlat) {
                let restIdx = restCommands.length;
                const cmds = [next];
                const out = [];
                while (width >= 0) {
                  if (cmds.length === 0) {
                    if (restIdx === 0) {
                      return true;
                    }
                    cmds.push(restCommands[--restIdx]);
                    continue;
                  }
                  const {
                    mode,
                    doc
                  } = cmds.pop();
                  if (typeof doc === "string") {
                    out.push(doc);
                    width -= getStringWidth(doc);
                  } else if (isConcat(doc) || doc.type === "fill") {
                    const parts = getDocParts(doc);
                    for (let i = parts.length - 1; i >= 0; i--) {
                      cmds.push({
                        mode,
                        doc: parts[i]
                      });
                    }
                  } else {
                    switch (doc.type) {
                      case "indent":
                      case "align":
                      case "indent-if-break":
                      case "label":
                        cmds.push({
                          mode,
                          doc: doc.contents
                        });
                        break;
                      case "trim":
                        width += trim(out);
                        break;
                      case "group": {
                        if (mustBeFlat && doc.break) {
                          return false;
                        }
                        const groupMode = doc.break ? MODE_BREAK : mode;
                        const contents = doc.expandedStates && groupMode === MODE_BREAK ? getLast(doc.expandedStates) : doc.contents;
                        cmds.push({
                          mode: groupMode,
                          doc: contents
                        });
                        break;
                      }
                      case "if-break": {
                        const groupMode = doc.groupId ? groupModeMap[doc.groupId] || MODE_FLAT : mode;
                        const contents = groupMode === MODE_BREAK ? doc.breakContents : doc.flatContents;
                        if (contents) {
                          cmds.push({
                            mode,
                            doc: contents
                          });
                        }
                        break;
                      }
                      case "line":
                        if (mode === MODE_BREAK || doc.hard) {
                          return true;
                        }
                        if (!doc.soft) {
                          out.push(" ");
                          width--;
                        }
                        break;
                      case "line-suffix":
                        hasLineSuffix = true;
                        break;
                      case "line-suffix-boundary":
                        if (hasLineSuffix) {
                          return false;
                        }
                        break;
                    }
                  }
                }
                return false;
              }
              function printDocToString(doc, options) {
                groupModeMap = {};
                const width = options.printWidth;
                const newLine = convertEndOfLineToChars(options.endOfLine);
                let pos = 0;
                const cmds = [{
                  ind: rootIndent(),
                  mode: MODE_BREAK,
                  doc
                }];
                const out = [];
                let shouldRemeasure = false;
                const lineSuffix = [];
                while (cmds.length > 0) {
                  const {
                    ind,
                    mode,
                    doc: doc2
                  } = cmds.pop();
                  if (typeof doc2 === "string") {
                    const formatted = newLine !== "\n" ? doc2.replace(/\n/g, newLine) : doc2;
                    out.push(formatted);
                    pos += getStringWidth(formatted);
                  } else if (isConcat(doc2)) {
                    const parts = getDocParts(doc2);
                    for (let i = parts.length - 1; i >= 0; i--) {
                      cmds.push({
                        ind,
                        mode,
                        doc: parts[i]
                      });
                    }
                  } else {
                    switch (doc2.type) {
                      case "cursor":
                        out.push(cursor.placeholder);
                        break;
                      case "indent":
                        cmds.push({
                          ind: makeIndent(ind, options),
                          mode,
                          doc: doc2.contents
                        });
                        break;
                      case "align":
                        cmds.push({
                          ind: makeAlign(ind, doc2.n, options),
                          mode,
                          doc: doc2.contents
                        });
                        break;
                      case "trim":
                        pos -= trim(out);
                        break;
                      case "group":
                        switch (mode) {
                          case MODE_FLAT:
                            if (!shouldRemeasure) {
                              cmds.push({
                                ind,
                                mode: doc2.break ? MODE_BREAK : MODE_FLAT,
                                doc: doc2.contents
                              });
                              break;
                            }
                          case MODE_BREAK: {
                            shouldRemeasure = false;
                            const next = {
                              ind,
                              mode: MODE_FLAT,
                              doc: doc2.contents
                            };
                            const rem = width - pos;
                            const hasLineSuffix = lineSuffix.length > 0;
                            if (!doc2.break && fits(next, cmds, rem, hasLineSuffix)) {
                              cmds.push(next);
                            } else {
                              if (doc2.expandedStates) {
                                const mostExpanded = getLast(doc2.expandedStates);
                                if (doc2.break) {
                                  cmds.push({
                                    ind,
                                    mode: MODE_BREAK,
                                    doc: mostExpanded
                                  });
                                  break;
                                } else {
                                  for (let i = 1; i < doc2.expandedStates.length + 1; i++) {
                                    if (i >= doc2.expandedStates.length) {
                                      cmds.push({
                                        ind,
                                        mode: MODE_BREAK,
                                        doc: mostExpanded
                                      });
                                      break;
                                    } else {
                                      const state = doc2.expandedStates[i];
                                      const cmd = {
                                        ind,
                                        mode: MODE_FLAT,
                                        doc: state
                                      };
                                      if (fits(cmd, cmds, rem, hasLineSuffix)) {
                                        cmds.push(cmd);
                                        break;
                                      }
                                    }
                                  }
                                }
                              } else {
                                cmds.push({
                                  ind,
                                  mode: MODE_BREAK,
                                  doc: doc2.contents
                                });
                              }
                            }
                            break;
                          }
                        }
                        if (doc2.id) {
                          groupModeMap[doc2.id] = getLast(cmds).mode;
                        }
                        break;
                      case "fill": {
                        const rem = width - pos;
                        const {
                          parts
                        } = doc2;
                        if (parts.length === 0) {
                          break;
                        }
                        const [content, whitespace] = parts;
                        const contentFlatCmd = {
                          ind,
                          mode: MODE_FLAT,
                          doc: content
                        };
                        const contentBreakCmd = {
                          ind,
                          mode: MODE_BREAK,
                          doc: content
                        };
                        const contentFits = fits(contentFlatCmd, [], rem, lineSuffix.length > 0, true);
                        if (parts.length === 1) {
                          if (contentFits) {
                            cmds.push(contentFlatCmd);
                          } else {
                            cmds.push(contentBreakCmd);
                          }
                          break;
                        }
                        const whitespaceFlatCmd = {
                          ind,
                          mode: MODE_FLAT,
                          doc: whitespace
                        };
                        const whitespaceBreakCmd = {
                          ind,
                          mode: MODE_BREAK,
                          doc: whitespace
                        };
                        if (parts.length === 2) {
                          if (contentFits) {
                            cmds.push(whitespaceFlatCmd, contentFlatCmd);
                          } else {
                            cmds.push(whitespaceBreakCmd, contentBreakCmd);
                          }
                          break;
                        }
                        parts.splice(0, 2);
                        const remainingCmd = {
                          ind,
                          mode,
                          doc: fill(parts)
                        };
                        const secondContent = parts[0];
                        const firstAndSecondContentFlatCmd = {
                          ind,
                          mode: MODE_FLAT,
                          doc: [content, whitespace, secondContent]
                        };
                        const firstAndSecondContentFits = fits(firstAndSecondContentFlatCmd, [], rem, lineSuffix.length > 0, true);
                        if (firstAndSecondContentFits) {
                          cmds.push(remainingCmd, whitespaceFlatCmd, contentFlatCmd);
                        } else if (contentFits) {
                          cmds.push(remainingCmd, whitespaceBreakCmd, contentFlatCmd);
                        } else {
                          cmds.push(remainingCmd, whitespaceBreakCmd, contentBreakCmd);
                        }
                        break;
                      }
                      case "if-break":
                      case "indent-if-break": {
                        const groupMode = doc2.groupId ? groupModeMap[doc2.groupId] : mode;
                        if (groupMode === MODE_BREAK) {
                          const breakContents = doc2.type === "if-break" ? doc2.breakContents : doc2.negate ? doc2.contents : indent(doc2.contents);
                          if (breakContents) {
                            cmds.push({
                              ind,
                              mode,
                              doc: breakContents
                            });
                          }
                        }
                        if (groupMode === MODE_FLAT) {
                          const flatContents = doc2.type === "if-break" ? doc2.flatContents : doc2.negate ? indent(doc2.contents) : doc2.contents;
                          if (flatContents) {
                            cmds.push({
                              ind,
                              mode,
                              doc: flatContents
                            });
                          }
                        }
                        break;
                      }
                      case "line-suffix":
                        lineSuffix.push({
                          ind,
                          mode,
                          doc: doc2.contents
                        });
                        break;
                      case "line-suffix-boundary":
                        if (lineSuffix.length > 0) {
                          cmds.push({
                            ind,
                            mode,
                            doc: {
                              type: "line",
                              hard: true
                            }
                          });
                        }
                        break;
                      case "line":
                        switch (mode) {
                          case MODE_FLAT:
                            if (!doc2.hard) {
                              if (!doc2.soft) {
                                out.push(" ");
                                pos += 1;
                              }
                              break;
                            } else {
                              shouldRemeasure = true;
                            }
                          case MODE_BREAK:
                            if (lineSuffix.length > 0) {
                              cmds.push({
                                ind,
                                mode,
                                doc: doc2
                              }, ...lineSuffix.reverse());
                              lineSuffix.length = 0;
                              break;
                            }
                            if (doc2.literal) {
                              if (ind.root) {
                                out.push(newLine, ind.root.value);
                                pos = ind.root.length;
                              } else {
                                out.push(newLine);
                                pos = 0;
                              }
                            } else {
                              pos -= trim(out);
                              out.push(newLine + ind.value);
                              pos = ind.length;
                            }
                            break;
                        }
                        break;
                      case "label":
                        cmds.push({
                          ind,
                          mode,
                          doc: doc2.contents
                        });
                        break;
                      default:
                    }
                  }
                  if (cmds.length === 0 && lineSuffix.length > 0) {
                    cmds.push(...lineSuffix.reverse());
                    lineSuffix.length = 0;
                  }
                }
                const cursorPlaceholderIndex = out.indexOf(cursor.placeholder);
                if (cursorPlaceholderIndex !== -1) {
                  const otherCursorPlaceholderIndex = out.indexOf(cursor.placeholder, cursorPlaceholderIndex + 1);
                  const beforeCursor = out.slice(0, cursorPlaceholderIndex).join("");
                  const aroundCursor = out.slice(cursorPlaceholderIndex + 1, otherCursorPlaceholderIndex).join("");
                  const afterCursor = out.slice(otherCursorPlaceholderIndex + 1).join("");
                  return {
                    formatted: beforeCursor + aroundCursor + afterCursor,
                    cursorNodeStart: beforeCursor.length,
                    cursorNodeText: aroundCursor
                  };
                }
                return {
                  formatted: out.join("")
                };
              }
              module22.exports = {
                printDocToString
              };
            }
          });
          var require_doc_debug = __commonJS22({
            "src/document/doc-debug.js"(exports22, module22) {
              "use strict";
              init_define_process();
              var {
                isConcat,
                getDocParts
              } = require_doc_utils();
              function flattenDoc(doc) {
                if (!doc) {
                  return "";
                }
                if (isConcat(doc)) {
                  const res = [];
                  for (const part of getDocParts(doc)) {
                    if (isConcat(part)) {
                      res.push(...flattenDoc(part).parts);
                    } else {
                      const flattened = flattenDoc(part);
                      if (flattened !== "") {
                        res.push(flattened);
                      }
                    }
                  }
                  return {
                    type: "concat",
                    parts: res
                  };
                }
                if (doc.type === "if-break") {
                  return Object.assign(Object.assign({}, doc), {}, {
                    breakContents: flattenDoc(doc.breakContents),
                    flatContents: flattenDoc(doc.flatContents)
                  });
                }
                if (doc.type === "group") {
                  return Object.assign(Object.assign({}, doc), {}, {
                    contents: flattenDoc(doc.contents),
                    expandedStates: doc.expandedStates && doc.expandedStates.map(flattenDoc)
                  });
                }
                if (doc.type === "fill") {
                  return {
                    type: "fill",
                    parts: doc.parts.map(flattenDoc)
                  };
                }
                if (doc.contents) {
                  return Object.assign(Object.assign({}, doc), {}, {
                    contents: flattenDoc(doc.contents)
                  });
                }
                return doc;
              }
              function printDocToDebug(doc) {
                const printedSymbols = /* @__PURE__ */ Object.create(null);
                const usedKeysForSymbols = /* @__PURE__ */ new Set();
                return printDoc(flattenDoc(doc));
                function printDoc(doc2, index, parentParts) {
                  if (typeof doc2 === "string") {
                    return JSON.stringify(doc2);
                  }
                  if (isConcat(doc2)) {
                    const printed = getDocParts(doc2).map(printDoc).filter(Boolean);
                    return printed.length === 1 ? printed[0] : `[${printed.join(", ")}]`;
                  }
                  if (doc2.type === "line") {
                    const withBreakParent = Array.isArray(parentParts) && parentParts[index + 1] && parentParts[index + 1].type === "break-parent";
                    if (doc2.literal) {
                      return withBreakParent ? "literalline" : "literallineWithoutBreakParent";
                    }
                    if (doc2.hard) {
                      return withBreakParent ? "hardline" : "hardlineWithoutBreakParent";
                    }
                    if (doc2.soft) {
                      return "softline";
                    }
                    return "line";
                  }
                  if (doc2.type === "break-parent") {
                    const afterHardline = Array.isArray(parentParts) && parentParts[index - 1] && parentParts[index - 1].type === "line" && parentParts[index - 1].hard;
                    return afterHardline ? void 0 : "breakParent";
                  }
                  if (doc2.type === "trim") {
                    return "trim";
                  }
                  if (doc2.type === "indent") {
                    return "indent(" + printDoc(doc2.contents) + ")";
                  }
                  if (doc2.type === "align") {
                    return doc2.n === Number.NEGATIVE_INFINITY ? "dedentToRoot(" + printDoc(doc2.contents) + ")" : doc2.n < 0 ? "dedent(" + printDoc(doc2.contents) + ")" : doc2.n.type === "root" ? "markAsRoot(" + printDoc(doc2.contents) + ")" : "align(" + JSON.stringify(doc2.n) + ", " + printDoc(doc2.contents) + ")";
                  }
                  if (doc2.type === "if-break") {
                    return "ifBreak(" + printDoc(doc2.breakContents) + (doc2.flatContents ? ", " + printDoc(doc2.flatContents) : "") + (doc2.groupId ? (!doc2.flatContents ? ', ""' : "") + `, { groupId: ${printGroupId(doc2.groupId)} }` : "") + ")";
                  }
                  if (doc2.type === "indent-if-break") {
                    const optionsParts = [];
                    if (doc2.negate) {
                      optionsParts.push("negate: true");
                    }
                    if (doc2.groupId) {
                      optionsParts.push(`groupId: ${printGroupId(doc2.groupId)}`);
                    }
                    const options = optionsParts.length > 0 ? `, { ${optionsParts.join(", ")} }` : "";
                    return `indentIfBreak(${printDoc(doc2.contents)}${options})`;
                  }
                  if (doc2.type === "group") {
                    const optionsParts = [];
                    if (doc2.break && doc2.break !== "propagated") {
                      optionsParts.push("shouldBreak: true");
                    }
                    if (doc2.id) {
                      optionsParts.push(`id: ${printGroupId(doc2.id)}`);
                    }
                    const options = optionsParts.length > 0 ? `, { ${optionsParts.join(", ")} }` : "";
                    if (doc2.expandedStates) {
                      return `conditionalGroup([${doc2.expandedStates.map((part) => printDoc(part)).join(",")}]${options})`;
                    }
                    return `group(${printDoc(doc2.contents)}${options})`;
                  }
                  if (doc2.type === "fill") {
                    return `fill([${doc2.parts.map((part) => printDoc(part)).join(", ")}])`;
                  }
                  if (doc2.type === "line-suffix") {
                    return "lineSuffix(" + printDoc(doc2.contents) + ")";
                  }
                  if (doc2.type === "line-suffix-boundary") {
                    return "lineSuffixBoundary";
                  }
                  if (doc2.type === "label") {
                    return `label(${JSON.stringify(doc2.label)}, ${printDoc(doc2.contents)})`;
                  }
                  throw new Error("Unknown doc type " + doc2.type);
                }
                function printGroupId(id) {
                  if (typeof id !== "symbol") {
                    return JSON.stringify(String(id));
                  }
                  if (id in printedSymbols) {
                    return printedSymbols[id];
                  }
                  const prefix = String(id).slice(7, -1) || "symbol";
                  for (let counter = 0; ; counter++) {
                    const key = prefix + (counter > 0 ? ` #${counter}` : "");
                    if (!usedKeysForSymbols.has(key)) {
                      usedKeysForSymbols.add(key);
                      return printedSymbols[id] = `Symbol.for(${JSON.stringify(key)})`;
                    }
                  }
                }
              }
              module22.exports = {
                printDocToDebug
              };
            }
          });
          init_define_process();
          module3.exports = {
            builders: require_doc_builders(),
            printer: require_doc_printer(),
            utils: require_doc_utils(),
            debug: require_doc_debug()
          };
        }
      });
      return require_doc_js_umd();
    });
  }
});

// node_modules/prettier/third-party.js
var require_third_party = __commonJS({
  "node_modules/prettier/third-party.js"(exports, module2) {
    "use strict";
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __commonJS2 = (cb, mod) => function __require() {
      return mod || (0, cb[__getOwnPropNames2(cb)[0]])((mod = {
        exports: {}
      }).exports, mod), mod.exports;
    };
    var require_resolve_from2 = __commonJS2({
      "node_modules/import-fresh/node_modules/resolve-from/index.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var Module = require("module");
        var fs2 = require("fs");
        var resolveFrom = (fromDir, moduleId, silent) => {
          if (typeof fromDir !== "string") {
            throw new TypeError(`Expected \`fromDir\` to be of type \`string\`, got \`${typeof fromDir}\``);
          }
          if (typeof moduleId !== "string") {
            throw new TypeError(`Expected \`moduleId\` to be of type \`string\`, got \`${typeof moduleId}\``);
          }
          try {
            fromDir = fs2.realpathSync(fromDir);
          } catch (err) {
            if (err.code === "ENOENT") {
              fromDir = path2.resolve(fromDir);
            } else if (silent) {
              return null;
            } else {
              throw err;
            }
          }
          const fromFile = path2.join(fromDir, "noop.js");
          const resolveFileName = () => Module._resolveFilename(moduleId, {
            id: fromFile,
            filename: fromFile,
            paths: Module._nodeModulePaths(fromDir)
          });
          if (silent) {
            try {
              return resolveFileName();
            } catch (err) {
              return null;
            }
          }
          return resolveFileName();
        };
        module22.exports = (fromDir, moduleId) => resolveFrom(fromDir, moduleId);
        module22.exports.silent = (fromDir, moduleId) => resolveFrom(fromDir, moduleId, true);
      }
    });
    var require_parent_module2 = __commonJS2({
      "scripts/build/shims/parent-module.cjs"(exports2, module22) {
        "use strict";
        module22.exports = (file) => file;
      }
    });
    var require_import_fresh2 = __commonJS2({
      "node_modules/import-fresh/index.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var resolveFrom = require_resolve_from2();
        var parentModule = require_parent_module2();
        module22.exports = (moduleId) => {
          if (typeof moduleId !== "string") {
            throw new TypeError("Expected a string");
          }
          const parentPath = parentModule(__filename);
          const cwd = parentPath ? path2.dirname(parentPath) : __dirname;
          const filePath = resolveFrom(cwd, moduleId);
          const oldModule = require.cache[filePath];
          if (oldModule && oldModule.parent) {
            let i = oldModule.parent.children.length;
            while (i--) {
              if (oldModule.parent.children[i].id === filePath) {
                oldModule.parent.children.splice(i, 1);
              }
            }
          }
          delete require.cache[filePath];
          const parent = require.cache[parentPath];
          return parent === void 0 ? require(filePath) : parent.require(filePath);
        };
      }
    });
    var require_is_arrayish = __commonJS2({
      "node_modules/is-arrayish/index.js"(exports2, module22) {
        "use strict";
        module22.exports = function isArrayish(obj) {
          if (!obj) {
            return false;
          }
          return obj instanceof Array || Array.isArray(obj) || obj.length >= 0 && obj.splice instanceof Function;
        };
      }
    });
    var require_error_ex = __commonJS2({
      "node_modules/error-ex/index.js"(exports2, module22) {
        "use strict";
        var util = require("util");
        var isArrayish = require_is_arrayish();
        var errorEx = function errorEx2(name, properties) {
          if (!name || name.constructor !== String) {
            properties = name || {};
            name = Error.name;
          }
          var errorExError = function ErrorEXError(message) {
            if (!this) {
              return new ErrorEXError(message);
            }
            message = message instanceof Error ? message.message : message || this.message;
            Error.call(this, message);
            Error.captureStackTrace(this, errorExError);
            this.name = name;
            Object.defineProperty(this, "message", {
              configurable: true,
              enumerable: false,
              get: function() {
                var newMessage = message.split(/\r?\n/g);
                for (var key in properties) {
                  if (!properties.hasOwnProperty(key)) {
                    continue;
                  }
                  var modifier = properties[key];
                  if ("message" in modifier) {
                    newMessage = modifier.message(this[key], newMessage) || newMessage;
                    if (!isArrayish(newMessage)) {
                      newMessage = [newMessage];
                    }
                  }
                }
                return newMessage.join("\n");
              },
              set: function(v) {
                message = v;
              }
            });
            var overwrittenStack = null;
            var stackDescriptor = Object.getOwnPropertyDescriptor(this, "stack");
            var stackGetter = stackDescriptor.get;
            var stackValue = stackDescriptor.value;
            delete stackDescriptor.value;
            delete stackDescriptor.writable;
            stackDescriptor.set = function(newstack) {
              overwrittenStack = newstack;
            };
            stackDescriptor.get = function() {
              var stack = (overwrittenStack || (stackGetter ? stackGetter.call(this) : stackValue)).split(/\r?\n+/g);
              if (!overwrittenStack) {
                stack[0] = this.name + ": " + this.message;
              }
              var lineCount = 1;
              for (var key in properties) {
                if (!properties.hasOwnProperty(key)) {
                  continue;
                }
                var modifier = properties[key];
                if ("line" in modifier) {
                  var line = modifier.line(this[key]);
                  if (line) {
                    stack.splice(lineCount++, 0, "    " + line);
                  }
                }
                if ("stack" in modifier) {
                  modifier.stack(this[key], stack);
                }
              }
              return stack.join("\n");
            };
            Object.defineProperty(this, "stack", stackDescriptor);
          };
          if (Object.setPrototypeOf) {
            Object.setPrototypeOf(errorExError.prototype, Error.prototype);
            Object.setPrototypeOf(errorExError, Error);
          } else {
            util.inherits(errorExError, Error);
          }
          return errorExError;
        };
        errorEx.append = function(str, def) {
          return {
            message: function(v, message) {
              v = v || def;
              if (v) {
                message[0] += " " + str.replace("%s", v.toString());
              }
              return message;
            }
          };
        };
        errorEx.line = function(str, def) {
          return {
            line: function(v) {
              v = v || def;
              if (v) {
                return str.replace("%s", v.toString());
              }
              return null;
            }
          };
        };
        module22.exports = errorEx;
      }
    });
    var require_json_parse_even_better_errors = __commonJS2({
      "node_modules/json-parse-even-better-errors/index.js"(exports2, module22) {
        "use strict";
        var hexify = (char) => {
          const h = char.charCodeAt(0).toString(16).toUpperCase();
          return "0x" + (h.length % 2 ? "0" : "") + h;
        };
        var parseError = (e, txt, context) => {
          if (!txt) {
            return {
              message: e.message + " while parsing empty string",
              position: 0
            };
          }
          const badToken = e.message.match(/^Unexpected token (.) .*position\s+(\d+)/i);
          const errIdx = badToken ? +badToken[2] : e.message.match(/^Unexpected end of JSON.*/i) ? txt.length - 1 : null;
          const msg = badToken ? e.message.replace(/^Unexpected token ./, `Unexpected token ${JSON.stringify(badToken[1])} (${hexify(badToken[1])})`) : e.message;
          if (errIdx !== null && errIdx !== void 0) {
            const start = errIdx <= context ? 0 : errIdx - context;
            const end = errIdx + context >= txt.length ? txt.length : errIdx + context;
            const slice = (start === 0 ? "" : "...") + txt.slice(start, end) + (end === txt.length ? "" : "...");
            const near = txt === slice ? "" : "near ";
            return {
              message: msg + ` while parsing ${near}${JSON.stringify(slice)}`,
              position: errIdx
            };
          } else {
            return {
              message: msg + ` while parsing '${txt.slice(0, context * 2)}'`,
              position: 0
            };
          }
        };
        var JSONParseError = class extends SyntaxError {
          constructor(er, txt, context, caller) {
            context = context || 20;
            const metadata = parseError(er, txt, context);
            super(metadata.message);
            Object.assign(this, metadata);
            this.code = "EJSONPARSE";
            this.systemError = er;
            Error.captureStackTrace(this, caller || this.constructor);
          }
          get name() {
            return this.constructor.name;
          }
          set name(n) {
          }
          get [Symbol.toStringTag]() {
            return this.constructor.name;
          }
        };
        var kIndent = Symbol.for("indent");
        var kNewline = Symbol.for("newline");
        var formatRE = /^\s*[{\[]((?:\r?\n)+)([\s\t]*)/;
        var emptyRE = /^(?:\{\}|\[\])((?:\r?\n)+)?$/;
        var parseJson = (txt, reviver, context) => {
          const parseText = stripBOM(txt);
          context = context || 20;
          try {
            const [, newline = "\n", indent = "  "] = parseText.match(emptyRE) || parseText.match(formatRE) || [, "", ""];
            const result = JSON.parse(parseText, reviver);
            if (result && typeof result === "object") {
              result[kNewline] = newline;
              result[kIndent] = indent;
            }
            return result;
          } catch (e) {
            if (typeof txt !== "string" && !Buffer.isBuffer(txt)) {
              const isEmptyArray = Array.isArray(txt) && txt.length === 0;
              throw Object.assign(new TypeError(`Cannot parse ${isEmptyArray ? "an empty array" : String(txt)}`), {
                code: "EJSONPARSE",
                systemError: e
              });
            }
            throw new JSONParseError(e, parseText, context, parseJson);
          }
        };
        var stripBOM = (txt) => String(txt).replace(/^\uFEFF/, "");
        module22.exports = parseJson;
        parseJson.JSONParseError = JSONParseError;
        parseJson.noExceptions = (txt, reviver) => {
          try {
            return JSON.parse(stripBOM(txt), reviver);
          } catch (e) {
          }
        };
      }
    });
    var require_build = __commonJS2({
      "node_modules/parse-json/node_modules/lines-and-columns/build/index.js"(exports2) {
        "use strict";
        exports2.__esModule = true;
        exports2.LinesAndColumns = void 0;
        var LF = "\n";
        var CR = "\r";
        var LinesAndColumns = function() {
          function LinesAndColumns2(string) {
            this.string = string;
            var offsets = [0];
            for (var offset = 0; offset < string.length; ) {
              switch (string[offset]) {
                case LF:
                  offset += LF.length;
                  offsets.push(offset);
                  break;
                case CR:
                  offset += CR.length;
                  if (string[offset] === LF) {
                    offset += LF.length;
                  }
                  offsets.push(offset);
                  break;
                default:
                  offset++;
                  break;
              }
            }
            this.offsets = offsets;
          }
          LinesAndColumns2.prototype.locationForIndex = function(index) {
            if (index < 0 || index > this.string.length) {
              return null;
            }
            var line = 0;
            var offsets = this.offsets;
            while (offsets[line + 1] <= index) {
              line++;
            }
            var column = index - offsets[line];
            return {
              line,
              column
            };
          };
          LinesAndColumns2.prototype.indexForLocation = function(location) {
            var line = location.line, column = location.column;
            if (line < 0 || line >= this.offsets.length) {
              return null;
            }
            if (column < 0 || column > this.lengthOfLine(line)) {
              return null;
            }
            return this.offsets[line] + column;
          };
          LinesAndColumns2.prototype.lengthOfLine = function(line) {
            var offset = this.offsets[line];
            var nextOffset = line === this.offsets.length - 1 ? this.string.length : this.offsets[line + 1];
            return nextOffset - offset;
          };
          return LinesAndColumns2;
        }();
        exports2.LinesAndColumns = LinesAndColumns;
        exports2["default"] = LinesAndColumns;
      }
    });
    var require_js_tokens2 = __commonJS2({
      "node_modules/js-tokens/index.js"(exports2) {
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.default = /((['"])(?:(?!\2|\\).|\\(?:\r\n|[\s\S]))*(\2)?|`(?:[^`\\$]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{[^}]*\}?)*\}?)*(`)?)|(\/\/.*)|(\/\*(?:[^*]|\*(?!\/))*(\*\/)?)|(\/(?!\*)(?:\[(?:(?![\]\\]).|\\.)*\]|(?![\/\]\\]).|\\.)+\/(?:(?!\s*(?:\b|[\u0080-\uFFFF$\\'"~({]|[+\-!](?!=)|\.?\d))|[gmiyus]{1,6}\b(?![\u0080-\uFFFF$\\]|\s*(?:[+\-*%&|^<>!=?({]|\/(?![\/*])))))|(0[xX][\da-fA-F]+|0[oO][0-7]+|0[bB][01]+|(?:\d*\.\d+|\d+\.?)(?:[eE][+-]?\d+)?)|((?!\d)(?:(?!\s)[$\w\u0080-\uFFFF]|\\u[\da-fA-F]{4}|\\u\{[\da-fA-F]+\})+)|(--|\+\+|&&|\|\||=>|\.{3}|(?:[+\-\/%&|^]|\*{1,2}|<{1,2}|>{1,3}|!=?|={1,2})=?|[?~.,:;[\](){}])|(\s+)|(^$|[\s\S])/g;
        exports2.matchToToken = function(match) {
          var token = {
            type: "invalid",
            value: match[0],
            closed: void 0
          };
          if (match[1])
            token.type = "string", token.closed = !!(match[3] || match[4]);
          else if (match[5])
            token.type = "comment";
          else if (match[6])
            token.type = "comment", token.closed = !!match[7];
          else if (match[8])
            token.type = "regex";
          else if (match[9])
            token.type = "number";
          else if (match[10])
            token.type = "name";
          else if (match[11])
            token.type = "punctuator";
          else if (match[12])
            token.type = "whitespace";
          return token;
        };
      }
    });
    var require_identifier3 = __commonJS2({
      "node_modules/@babel/helper-validator-identifier/lib/identifier.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isIdentifierChar = isIdentifierChar;
        exports2.isIdentifierName = isIdentifierName;
        exports2.isIdentifierStart = isIdentifierStart;
        var nonASCIIidentifierStartChars = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC";
        var nonASCIIidentifierChars = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F";
        var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
        var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
        nonASCIIidentifierStartChars = nonASCIIidentifierChars = null;
        var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
        var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
        function isInAstralSet(code, set) {
          let pos = 65536;
          for (let i = 0, length = set.length; i < length; i += 2) {
            pos += set[i];
            if (pos > code)
              return false;
            pos += set[i + 1];
            if (pos >= code)
              return true;
          }
          return false;
        }
        function isIdentifierStart(code) {
          if (code < 65)
            return code === 36;
          if (code <= 90)
            return true;
          if (code < 97)
            return code === 95;
          if (code <= 122)
            return true;
          if (code <= 65535) {
            return code >= 170 && nonASCIIidentifierStart.test(String.fromCharCode(code));
          }
          return isInAstralSet(code, astralIdentifierStartCodes);
        }
        function isIdentifierChar(code) {
          if (code < 48)
            return code === 36;
          if (code < 58)
            return true;
          if (code < 65)
            return false;
          if (code <= 90)
            return true;
          if (code < 97)
            return code === 95;
          if (code <= 122)
            return true;
          if (code <= 65535) {
            return code >= 170 && nonASCIIidentifier.test(String.fromCharCode(code));
          }
          return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
        }
        function isIdentifierName(name) {
          let isFirst = true;
          for (let i = 0; i < name.length; i++) {
            let cp = name.charCodeAt(i);
            if ((cp & 64512) === 55296 && i + 1 < name.length) {
              const trail = name.charCodeAt(++i);
              if ((trail & 64512) === 56320) {
                cp = 65536 + ((cp & 1023) << 10) + (trail & 1023);
              }
            }
            if (isFirst) {
              isFirst = false;
              if (!isIdentifierStart(cp)) {
                return false;
              }
            } else if (!isIdentifierChar(cp)) {
              return false;
            }
          }
          return !isFirst;
        }
      }
    });
    var require_keyword5 = __commonJS2({
      "node_modules/@babel/helper-validator-identifier/lib/keyword.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isKeyword = isKeyword;
        exports2.isReservedWord = isReservedWord;
        exports2.isStrictBindOnlyReservedWord = isStrictBindOnlyReservedWord;
        exports2.isStrictBindReservedWord = isStrictBindReservedWord;
        exports2.isStrictReservedWord = isStrictReservedWord;
        var reservedWords = {
          keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"],
          strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"],
          strictBind: ["eval", "arguments"]
        };
        var keywords = new Set(reservedWords.keyword);
        var reservedWordsStrictSet = new Set(reservedWords.strict);
        var reservedWordsStrictBindSet = new Set(reservedWords.strictBind);
        function isReservedWord(word, inModule) {
          return inModule && word === "await" || word === "enum";
        }
        function isStrictReservedWord(word, inModule) {
          return isReservedWord(word, inModule) || reservedWordsStrictSet.has(word);
        }
        function isStrictBindOnlyReservedWord(word) {
          return reservedWordsStrictBindSet.has(word);
        }
        function isStrictBindReservedWord(word, inModule) {
          return isStrictReservedWord(word, inModule) || isStrictBindOnlyReservedWord(word);
        }
        function isKeyword(word) {
          return keywords.has(word);
        }
      }
    });
    var require_lib33 = __commonJS2({
      "node_modules/@babel/helper-validator-identifier/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        Object.defineProperty(exports2, "isIdentifierChar", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierChar;
          }
        });
        Object.defineProperty(exports2, "isIdentifierName", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierName;
          }
        });
        Object.defineProperty(exports2, "isIdentifierStart", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierStart;
          }
        });
        Object.defineProperty(exports2, "isKeyword", {
          enumerable: true,
          get: function() {
            return _keyword.isKeyword;
          }
        });
        Object.defineProperty(exports2, "isReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictBindOnlyReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictBindOnlyReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictBindReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictBindReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictReservedWord;
          }
        });
        var _identifier = require_identifier3();
        var _keyword = require_keyword5();
      }
    });
    var require_escape_string_regexp3 = __commonJS2({
      "node_modules/@babel/highlight/node_modules/escape-string-regexp/index.js"(exports2, module22) {
        "use strict";
        var matchOperatorsRe = /[|\\{}()[\]^$+*?.]/g;
        module22.exports = function(str) {
          if (typeof str !== "string") {
            throw new TypeError("Expected a string");
          }
          return str.replace(matchOperatorsRe, "\\$&");
        };
      }
    });
    var require_color_name3 = __commonJS2({
      "node_modules/color-name/index.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          "aliceblue": [240, 248, 255],
          "antiquewhite": [250, 235, 215],
          "aqua": [0, 255, 255],
          "aquamarine": [127, 255, 212],
          "azure": [240, 255, 255],
          "beige": [245, 245, 220],
          "bisque": [255, 228, 196],
          "black": [0, 0, 0],
          "blanchedalmond": [255, 235, 205],
          "blue": [0, 0, 255],
          "blueviolet": [138, 43, 226],
          "brown": [165, 42, 42],
          "burlywood": [222, 184, 135],
          "cadetblue": [95, 158, 160],
          "chartreuse": [127, 255, 0],
          "chocolate": [210, 105, 30],
          "coral": [255, 127, 80],
          "cornflowerblue": [100, 149, 237],
          "cornsilk": [255, 248, 220],
          "crimson": [220, 20, 60],
          "cyan": [0, 255, 255],
          "darkblue": [0, 0, 139],
          "darkcyan": [0, 139, 139],
          "darkgoldenrod": [184, 134, 11],
          "darkgray": [169, 169, 169],
          "darkgreen": [0, 100, 0],
          "darkgrey": [169, 169, 169],
          "darkkhaki": [189, 183, 107],
          "darkmagenta": [139, 0, 139],
          "darkolivegreen": [85, 107, 47],
          "darkorange": [255, 140, 0],
          "darkorchid": [153, 50, 204],
          "darkred": [139, 0, 0],
          "darksalmon": [233, 150, 122],
          "darkseagreen": [143, 188, 143],
          "darkslateblue": [72, 61, 139],
          "darkslategray": [47, 79, 79],
          "darkslategrey": [47, 79, 79],
          "darkturquoise": [0, 206, 209],
          "darkviolet": [148, 0, 211],
          "deeppink": [255, 20, 147],
          "deepskyblue": [0, 191, 255],
          "dimgray": [105, 105, 105],
          "dimgrey": [105, 105, 105],
          "dodgerblue": [30, 144, 255],
          "firebrick": [178, 34, 34],
          "floralwhite": [255, 250, 240],
          "forestgreen": [34, 139, 34],
          "fuchsia": [255, 0, 255],
          "gainsboro": [220, 220, 220],
          "ghostwhite": [248, 248, 255],
          "gold": [255, 215, 0],
          "goldenrod": [218, 165, 32],
          "gray": [128, 128, 128],
          "green": [0, 128, 0],
          "greenyellow": [173, 255, 47],
          "grey": [128, 128, 128],
          "honeydew": [240, 255, 240],
          "hotpink": [255, 105, 180],
          "indianred": [205, 92, 92],
          "indigo": [75, 0, 130],
          "ivory": [255, 255, 240],
          "khaki": [240, 230, 140],
          "lavender": [230, 230, 250],
          "lavenderblush": [255, 240, 245],
          "lawngreen": [124, 252, 0],
          "lemonchiffon": [255, 250, 205],
          "lightblue": [173, 216, 230],
          "lightcoral": [240, 128, 128],
          "lightcyan": [224, 255, 255],
          "lightgoldenrodyellow": [250, 250, 210],
          "lightgray": [211, 211, 211],
          "lightgreen": [144, 238, 144],
          "lightgrey": [211, 211, 211],
          "lightpink": [255, 182, 193],
          "lightsalmon": [255, 160, 122],
          "lightseagreen": [32, 178, 170],
          "lightskyblue": [135, 206, 250],
          "lightslategray": [119, 136, 153],
          "lightslategrey": [119, 136, 153],
          "lightsteelblue": [176, 196, 222],
          "lightyellow": [255, 255, 224],
          "lime": [0, 255, 0],
          "limegreen": [50, 205, 50],
          "linen": [250, 240, 230],
          "magenta": [255, 0, 255],
          "maroon": [128, 0, 0],
          "mediumaquamarine": [102, 205, 170],
          "mediumblue": [0, 0, 205],
          "mediumorchid": [186, 85, 211],
          "mediumpurple": [147, 112, 219],
          "mediumseagreen": [60, 179, 113],
          "mediumslateblue": [123, 104, 238],
          "mediumspringgreen": [0, 250, 154],
          "mediumturquoise": [72, 209, 204],
          "mediumvioletred": [199, 21, 133],
          "midnightblue": [25, 25, 112],
          "mintcream": [245, 255, 250],
          "mistyrose": [255, 228, 225],
          "moccasin": [255, 228, 181],
          "navajowhite": [255, 222, 173],
          "navy": [0, 0, 128],
          "oldlace": [253, 245, 230],
          "olive": [128, 128, 0],
          "olivedrab": [107, 142, 35],
          "orange": [255, 165, 0],
          "orangered": [255, 69, 0],
          "orchid": [218, 112, 214],
          "palegoldenrod": [238, 232, 170],
          "palegreen": [152, 251, 152],
          "paleturquoise": [175, 238, 238],
          "palevioletred": [219, 112, 147],
          "papayawhip": [255, 239, 213],
          "peachpuff": [255, 218, 185],
          "peru": [205, 133, 63],
          "pink": [255, 192, 203],
          "plum": [221, 160, 221],
          "powderblue": [176, 224, 230],
          "purple": [128, 0, 128],
          "rebeccapurple": [102, 51, 153],
          "red": [255, 0, 0],
          "rosybrown": [188, 143, 143],
          "royalblue": [65, 105, 225],
          "saddlebrown": [139, 69, 19],
          "salmon": [250, 128, 114],
          "sandybrown": [244, 164, 96],
          "seagreen": [46, 139, 87],
          "seashell": [255, 245, 238],
          "sienna": [160, 82, 45],
          "silver": [192, 192, 192],
          "skyblue": [135, 206, 235],
          "slateblue": [106, 90, 205],
          "slategray": [112, 128, 144],
          "slategrey": [112, 128, 144],
          "snow": [255, 250, 250],
          "springgreen": [0, 255, 127],
          "steelblue": [70, 130, 180],
          "tan": [210, 180, 140],
          "teal": [0, 128, 128],
          "thistle": [216, 191, 216],
          "tomato": [255, 99, 71],
          "turquoise": [64, 224, 208],
          "violet": [238, 130, 238],
          "wheat": [245, 222, 179],
          "white": [255, 255, 255],
          "whitesmoke": [245, 245, 245],
          "yellow": [255, 255, 0],
          "yellowgreen": [154, 205, 50]
        };
      }
    });
    var require_conversions3 = __commonJS2({
      "node_modules/color-convert/conversions.js"(exports2, module22) {
        var cssKeywords = require_color_name3();
        var reverseKeywords = {};
        for (key in cssKeywords) {
          if (cssKeywords.hasOwnProperty(key)) {
            reverseKeywords[cssKeywords[key]] = key;
          }
        }
        var key;
        var convert = module22.exports = {
          rgb: {
            channels: 3,
            labels: "rgb"
          },
          hsl: {
            channels: 3,
            labels: "hsl"
          },
          hsv: {
            channels: 3,
            labels: "hsv"
          },
          hwb: {
            channels: 3,
            labels: "hwb"
          },
          cmyk: {
            channels: 4,
            labels: "cmyk"
          },
          xyz: {
            channels: 3,
            labels: "xyz"
          },
          lab: {
            channels: 3,
            labels: "lab"
          },
          lch: {
            channels: 3,
            labels: "lch"
          },
          hex: {
            channels: 1,
            labels: ["hex"]
          },
          keyword: {
            channels: 1,
            labels: ["keyword"]
          },
          ansi16: {
            channels: 1,
            labels: ["ansi16"]
          },
          ansi256: {
            channels: 1,
            labels: ["ansi256"]
          },
          hcg: {
            channels: 3,
            labels: ["h", "c", "g"]
          },
          apple: {
            channels: 3,
            labels: ["r16", "g16", "b16"]
          },
          gray: {
            channels: 1,
            labels: ["gray"]
          }
        };
        for (model in convert) {
          if (convert.hasOwnProperty(model)) {
            if (!("channels" in convert[model])) {
              throw new Error("missing channels property: " + model);
            }
            if (!("labels" in convert[model])) {
              throw new Error("missing channel labels property: " + model);
            }
            if (convert[model].labels.length !== convert[model].channels) {
              throw new Error("channel and label counts mismatch: " + model);
            }
            channels = convert[model].channels;
            labels = convert[model].labels;
            delete convert[model].channels;
            delete convert[model].labels;
            Object.defineProperty(convert[model], "channels", {
              value: channels
            });
            Object.defineProperty(convert[model], "labels", {
              value: labels
            });
          }
        }
        var channels;
        var labels;
        var model;
        convert.rgb.hsl = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var min2 = Math.min(r, g, b);
          var max2 = Math.max(r, g, b);
          var delta = max2 - min2;
          var h;
          var s;
          var l;
          if (max2 === min2) {
            h = 0;
          } else if (r === max2) {
            h = (g - b) / delta;
          } else if (g === max2) {
            h = 2 + (b - r) / delta;
          } else if (b === max2) {
            h = 4 + (r - g) / delta;
          }
          h = Math.min(h * 60, 360);
          if (h < 0) {
            h += 360;
          }
          l = (min2 + max2) / 2;
          if (max2 === min2) {
            s = 0;
          } else if (l <= 0.5) {
            s = delta / (max2 + min2);
          } else {
            s = delta / (2 - max2 - min2);
          }
          return [h, s * 100, l * 100];
        };
        convert.rgb.hsv = function(rgb) {
          var rdif;
          var gdif;
          var bdif;
          var h;
          var s;
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var v = Math.max(r, g, b);
          var diff = v - Math.min(r, g, b);
          var diffc = function(c) {
            return (v - c) / 6 / diff + 1 / 2;
          };
          if (diff === 0) {
            h = s = 0;
          } else {
            s = diff / v;
            rdif = diffc(r);
            gdif = diffc(g);
            bdif = diffc(b);
            if (r === v) {
              h = bdif - gdif;
            } else if (g === v) {
              h = 1 / 3 + rdif - bdif;
            } else if (b === v) {
              h = 2 / 3 + gdif - rdif;
            }
            if (h < 0) {
              h += 1;
            } else if (h > 1) {
              h -= 1;
            }
          }
          return [h * 360, s * 100, v * 100];
        };
        convert.rgb.hwb = function(rgb) {
          var r = rgb[0];
          var g = rgb[1];
          var b = rgb[2];
          var h = convert.rgb.hsl(rgb)[0];
          var w = 1 / 255 * Math.min(r, Math.min(g, b));
          b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
          return [h, w * 100, b * 100];
        };
        convert.rgb.cmyk = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var c;
          var m;
          var y;
          var k;
          k = Math.min(1 - r, 1 - g, 1 - b);
          c = (1 - r - k) / (1 - k) || 0;
          m = (1 - g - k) / (1 - k) || 0;
          y = (1 - b - k) / (1 - k) || 0;
          return [c * 100, m * 100, y * 100, k * 100];
        };
        function comparativeDistance(x, y) {
          return Math.pow(x[0] - y[0], 2) + Math.pow(x[1] - y[1], 2) + Math.pow(x[2] - y[2], 2);
        }
        convert.rgb.keyword = function(rgb) {
          var reversed = reverseKeywords[rgb];
          if (reversed) {
            return reversed;
          }
          var currentClosestDistance = Infinity;
          var currentClosestKeyword;
          for (var keyword in cssKeywords) {
            if (cssKeywords.hasOwnProperty(keyword)) {
              var value2 = cssKeywords[keyword];
              var distance = comparativeDistance(rgb, value2);
              if (distance < currentClosestDistance) {
                currentClosestDistance = distance;
                currentClosestKeyword = keyword;
              }
            }
          }
          return currentClosestKeyword;
        };
        convert.keyword.rgb = function(keyword) {
          return cssKeywords[keyword];
        };
        convert.rgb.xyz = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          r = r > 0.04045 ? Math.pow((r + 0.055) / 1.055, 2.4) : r / 12.92;
          g = g > 0.04045 ? Math.pow((g + 0.055) / 1.055, 2.4) : g / 12.92;
          b = b > 0.04045 ? Math.pow((b + 0.055) / 1.055, 2.4) : b / 12.92;
          var x = r * 0.4124 + g * 0.3576 + b * 0.1805;
          var y = r * 0.2126 + g * 0.7152 + b * 0.0722;
          var z = r * 0.0193 + g * 0.1192 + b * 0.9505;
          return [x * 100, y * 100, z * 100];
        };
        convert.rgb.lab = function(rgb) {
          var xyz = convert.rgb.xyz(rgb);
          var x = xyz[0];
          var y = xyz[1];
          var z = xyz[2];
          var l;
          var a;
          var b;
          x /= 95.047;
          y /= 100;
          z /= 108.883;
          x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
          y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
          z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
          l = 116 * y - 16;
          a = 500 * (x - y);
          b = 200 * (y - z);
          return [l, a, b];
        };
        convert.hsl.rgb = function(hsl) {
          var h = hsl[0] / 360;
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var t1;
          var t22;
          var t3;
          var rgb;
          var val;
          if (s === 0) {
            val = l * 255;
            return [val, val, val];
          }
          if (l < 0.5) {
            t22 = l * (1 + s);
          } else {
            t22 = l + s - l * s;
          }
          t1 = 2 * l - t22;
          rgb = [0, 0, 0];
          for (var i = 0; i < 3; i++) {
            t3 = h + 1 / 3 * -(i - 1);
            if (t3 < 0) {
              t3++;
            }
            if (t3 > 1) {
              t3--;
            }
            if (6 * t3 < 1) {
              val = t1 + (t22 - t1) * 6 * t3;
            } else if (2 * t3 < 1) {
              val = t22;
            } else if (3 * t3 < 2) {
              val = t1 + (t22 - t1) * (2 / 3 - t3) * 6;
            } else {
              val = t1;
            }
            rgb[i] = val * 255;
          }
          return rgb;
        };
        convert.hsl.hsv = function(hsl) {
          var h = hsl[0];
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var smin = s;
          var lmin = Math.max(l, 0.01);
          var sv;
          var v;
          l *= 2;
          s *= l <= 1 ? l : 2 - l;
          smin *= lmin <= 1 ? lmin : 2 - lmin;
          v = (l + s) / 2;
          sv = l === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l + s);
          return [h, sv * 100, v * 100];
        };
        convert.hsv.rgb = function(hsv) {
          var h = hsv[0] / 60;
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var hi = Math.floor(h) % 6;
          var f = h - Math.floor(h);
          var p = 255 * v * (1 - s);
          var q = 255 * v * (1 - s * f);
          var t3 = 255 * v * (1 - s * (1 - f));
          v *= 255;
          switch (hi) {
            case 0:
              return [v, t3, p];
            case 1:
              return [q, v, p];
            case 2:
              return [p, v, t3];
            case 3:
              return [p, q, v];
            case 4:
              return [t3, p, v];
            case 5:
              return [v, p, q];
          }
        };
        convert.hsv.hsl = function(hsv) {
          var h = hsv[0];
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var vmin = Math.max(v, 0.01);
          var lmin;
          var sl;
          var l;
          l = (2 - s) * v;
          lmin = (2 - s) * vmin;
          sl = s * vmin;
          sl /= lmin <= 1 ? lmin : 2 - lmin;
          sl = sl || 0;
          l /= 2;
          return [h, sl * 100, l * 100];
        };
        convert.hwb.rgb = function(hwb) {
          var h = hwb[0] / 360;
          var wh = hwb[1] / 100;
          var bl = hwb[2] / 100;
          var ratio = wh + bl;
          var i;
          var v;
          var f;
          var n;
          if (ratio > 1) {
            wh /= ratio;
            bl /= ratio;
          }
          i = Math.floor(6 * h);
          v = 1 - bl;
          f = 6 * h - i;
          if ((i & 1) !== 0) {
            f = 1 - f;
          }
          n = wh + f * (v - wh);
          var r;
          var g;
          var b;
          switch (i) {
            default:
            case 6:
            case 0:
              r = v;
              g = n;
              b = wh;
              break;
            case 1:
              r = n;
              g = v;
              b = wh;
              break;
            case 2:
              r = wh;
              g = v;
              b = n;
              break;
            case 3:
              r = wh;
              g = n;
              b = v;
              break;
            case 4:
              r = n;
              g = wh;
              b = v;
              break;
            case 5:
              r = v;
              g = wh;
              b = n;
              break;
          }
          return [r * 255, g * 255, b * 255];
        };
        convert.cmyk.rgb = function(cmyk) {
          var c = cmyk[0] / 100;
          var m = cmyk[1] / 100;
          var y = cmyk[2] / 100;
          var k = cmyk[3] / 100;
          var r;
          var g;
          var b;
          r = 1 - Math.min(1, c * (1 - k) + k);
          g = 1 - Math.min(1, m * (1 - k) + k);
          b = 1 - Math.min(1, y * (1 - k) + k);
          return [r * 255, g * 255, b * 255];
        };
        convert.xyz.rgb = function(xyz) {
          var x = xyz[0] / 100;
          var y = xyz[1] / 100;
          var z = xyz[2] / 100;
          var r;
          var g;
          var b;
          r = x * 3.2406 + y * -1.5372 + z * -0.4986;
          g = x * -0.9689 + y * 1.8758 + z * 0.0415;
          b = x * 0.0557 + y * -0.204 + z * 1.057;
          r = r > 31308e-7 ? 1.055 * Math.pow(r, 1 / 2.4) - 0.055 : r * 12.92;
          g = g > 31308e-7 ? 1.055 * Math.pow(g, 1 / 2.4) - 0.055 : g * 12.92;
          b = b > 31308e-7 ? 1.055 * Math.pow(b, 1 / 2.4) - 0.055 : b * 12.92;
          r = Math.min(Math.max(0, r), 1);
          g = Math.min(Math.max(0, g), 1);
          b = Math.min(Math.max(0, b), 1);
          return [r * 255, g * 255, b * 255];
        };
        convert.xyz.lab = function(xyz) {
          var x = xyz[0];
          var y = xyz[1];
          var z = xyz[2];
          var l;
          var a;
          var b;
          x /= 95.047;
          y /= 100;
          z /= 108.883;
          x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
          y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
          z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
          l = 116 * y - 16;
          a = 500 * (x - y);
          b = 200 * (y - z);
          return [l, a, b];
        };
        convert.lab.xyz = function(lab) {
          var l = lab[0];
          var a = lab[1];
          var b = lab[2];
          var x;
          var y;
          var z;
          y = (l + 16) / 116;
          x = a / 500 + y;
          z = y - b / 200;
          var y2 = Math.pow(y, 3);
          var x2 = Math.pow(x, 3);
          var z2 = Math.pow(z, 3);
          y = y2 > 8856e-6 ? y2 : (y - 16 / 116) / 7.787;
          x = x2 > 8856e-6 ? x2 : (x - 16 / 116) / 7.787;
          z = z2 > 8856e-6 ? z2 : (z - 16 / 116) / 7.787;
          x *= 95.047;
          y *= 100;
          z *= 108.883;
          return [x, y, z];
        };
        convert.lab.lch = function(lab) {
          var l = lab[0];
          var a = lab[1];
          var b = lab[2];
          var hr;
          var h;
          var c;
          hr = Math.atan2(b, a);
          h = hr * 360 / 2 / Math.PI;
          if (h < 0) {
            h += 360;
          }
          c = Math.sqrt(a * a + b * b);
          return [l, c, h];
        };
        convert.lch.lab = function(lch) {
          var l = lch[0];
          var c = lch[1];
          var h = lch[2];
          var a;
          var b;
          var hr;
          hr = h / 360 * 2 * Math.PI;
          a = c * Math.cos(hr);
          b = c * Math.sin(hr);
          return [l, a, b];
        };
        convert.rgb.ansi16 = function(args) {
          var r = args[0];
          var g = args[1];
          var b = args[2];
          var value2 = 1 in arguments ? arguments[1] : convert.rgb.hsv(args)[2];
          value2 = Math.round(value2 / 50);
          if (value2 === 0) {
            return 30;
          }
          var ansi = 30 + (Math.round(b / 255) << 2 | Math.round(g / 255) << 1 | Math.round(r / 255));
          if (value2 === 2) {
            ansi += 60;
          }
          return ansi;
        };
        convert.hsv.ansi16 = function(args) {
          return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
        };
        convert.rgb.ansi256 = function(args) {
          var r = args[0];
          var g = args[1];
          var b = args[2];
          if (r === g && g === b) {
            if (r < 8) {
              return 16;
            }
            if (r > 248) {
              return 231;
            }
            return Math.round((r - 8) / 247 * 24) + 232;
          }
          var ansi = 16 + 36 * Math.round(r / 255 * 5) + 6 * Math.round(g / 255 * 5) + Math.round(b / 255 * 5);
          return ansi;
        };
        convert.ansi16.rgb = function(args) {
          var color = args % 10;
          if (color === 0 || color === 7) {
            if (args > 50) {
              color += 3.5;
            }
            color = color / 10.5 * 255;
            return [color, color, color];
          }
          var mult = (~~(args > 50) + 1) * 0.5;
          var r = (color & 1) * mult * 255;
          var g = (color >> 1 & 1) * mult * 255;
          var b = (color >> 2 & 1) * mult * 255;
          return [r, g, b];
        };
        convert.ansi256.rgb = function(args) {
          if (args >= 232) {
            var c = (args - 232) * 10 + 8;
            return [c, c, c];
          }
          args -= 16;
          var rem;
          var r = Math.floor(args / 36) / 5 * 255;
          var g = Math.floor((rem = args % 36) / 6) / 5 * 255;
          var b = rem % 6 / 5 * 255;
          return [r, g, b];
        };
        convert.rgb.hex = function(args) {
          var integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
          var string = integer.toString(16).toUpperCase();
          return "000000".substring(string.length) + string;
        };
        convert.hex.rgb = function(args) {
          var match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
          if (!match) {
            return [0, 0, 0];
          }
          var colorString = match[0];
          if (match[0].length === 3) {
            colorString = colorString.split("").map(function(char) {
              return char + char;
            }).join("");
          }
          var integer = parseInt(colorString, 16);
          var r = integer >> 16 & 255;
          var g = integer >> 8 & 255;
          var b = integer & 255;
          return [r, g, b];
        };
        convert.rgb.hcg = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var max2 = Math.max(Math.max(r, g), b);
          var min2 = Math.min(Math.min(r, g), b);
          var chroma = max2 - min2;
          var grayscale;
          var hue;
          if (chroma < 1) {
            grayscale = min2 / (1 - chroma);
          } else {
            grayscale = 0;
          }
          if (chroma <= 0) {
            hue = 0;
          } else if (max2 === r) {
            hue = (g - b) / chroma % 6;
          } else if (max2 === g) {
            hue = 2 + (b - r) / chroma;
          } else {
            hue = 4 + (r - g) / chroma + 4;
          }
          hue /= 6;
          hue %= 1;
          return [hue * 360, chroma * 100, grayscale * 100];
        };
        convert.hsl.hcg = function(hsl) {
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var c = 1;
          var f = 0;
          if (l < 0.5) {
            c = 2 * s * l;
          } else {
            c = 2 * s * (1 - l);
          }
          if (c < 1) {
            f = (l - 0.5 * c) / (1 - c);
          }
          return [hsl[0], c * 100, f * 100];
        };
        convert.hsv.hcg = function(hsv) {
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var c = s * v;
          var f = 0;
          if (c < 1) {
            f = (v - c) / (1 - c);
          }
          return [hsv[0], c * 100, f * 100];
        };
        convert.hcg.rgb = function(hcg) {
          var h = hcg[0] / 360;
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          if (c === 0) {
            return [g * 255, g * 255, g * 255];
          }
          var pure = [0, 0, 0];
          var hi = h % 1 * 6;
          var v = hi % 1;
          var w = 1 - v;
          var mg = 0;
          switch (Math.floor(hi)) {
            case 0:
              pure[0] = 1;
              pure[1] = v;
              pure[2] = 0;
              break;
            case 1:
              pure[0] = w;
              pure[1] = 1;
              pure[2] = 0;
              break;
            case 2:
              pure[0] = 0;
              pure[1] = 1;
              pure[2] = v;
              break;
            case 3:
              pure[0] = 0;
              pure[1] = w;
              pure[2] = 1;
              break;
            case 4:
              pure[0] = v;
              pure[1] = 0;
              pure[2] = 1;
              break;
            default:
              pure[0] = 1;
              pure[1] = 0;
              pure[2] = w;
          }
          mg = (1 - c) * g;
          return [(c * pure[0] + mg) * 255, (c * pure[1] + mg) * 255, (c * pure[2] + mg) * 255];
        };
        convert.hcg.hsv = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var v = c + g * (1 - c);
          var f = 0;
          if (v > 0) {
            f = c / v;
          }
          return [hcg[0], f * 100, v * 100];
        };
        convert.hcg.hsl = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var l = g * (1 - c) + 0.5 * c;
          var s = 0;
          if (l > 0 && l < 0.5) {
            s = c / (2 * l);
          } else if (l >= 0.5 && l < 1) {
            s = c / (2 * (1 - l));
          }
          return [hcg[0], s * 100, l * 100];
        };
        convert.hcg.hwb = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var v = c + g * (1 - c);
          return [hcg[0], (v - c) * 100, (1 - v) * 100];
        };
        convert.hwb.hcg = function(hwb) {
          var w = hwb[1] / 100;
          var b = hwb[2] / 100;
          var v = 1 - b;
          var c = v - w;
          var g = 0;
          if (c < 1) {
            g = (v - c) / (1 - c);
          }
          return [hwb[0], c * 100, g * 100];
        };
        convert.apple.rgb = function(apple) {
          return [apple[0] / 65535 * 255, apple[1] / 65535 * 255, apple[2] / 65535 * 255];
        };
        convert.rgb.apple = function(rgb) {
          return [rgb[0] / 255 * 65535, rgb[1] / 255 * 65535, rgb[2] / 255 * 65535];
        };
        convert.gray.rgb = function(args) {
          return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
        };
        convert.gray.hsl = convert.gray.hsv = function(args) {
          return [0, 0, args[0]];
        };
        convert.gray.hwb = function(gray) {
          return [0, 100, gray[0]];
        };
        convert.gray.cmyk = function(gray) {
          return [0, 0, 0, gray[0]];
        };
        convert.gray.lab = function(gray) {
          return [gray[0], 0, 0];
        };
        convert.gray.hex = function(gray) {
          var val = Math.round(gray[0] / 100 * 255) & 255;
          var integer = (val << 16) + (val << 8) + val;
          var string = integer.toString(16).toUpperCase();
          return "000000".substring(string.length) + string;
        };
        convert.rgb.gray = function(rgb) {
          var val = (rgb[0] + rgb[1] + rgb[2]) / 3;
          return [val / 255 * 100];
        };
      }
    });
    var require_route3 = __commonJS2({
      "node_modules/color-convert/route.js"(exports2, module22) {
        var conversions = require_conversions3();
        function buildGraph() {
          var graph = {};
          var models = Object.keys(conversions);
          for (var len = models.length, i = 0; i < len; i++) {
            graph[models[i]] = {
              distance: -1,
              parent: null
            };
          }
          return graph;
        }
        function deriveBFS(fromModel) {
          var graph = buildGraph();
          var queue = [fromModel];
          graph[fromModel].distance = 0;
          while (queue.length) {
            var current = queue.pop();
            var adjacents = Object.keys(conversions[current]);
            for (var len = adjacents.length, i = 0; i < len; i++) {
              var adjacent = adjacents[i];
              var node = graph[adjacent];
              if (node.distance === -1) {
                node.distance = graph[current].distance + 1;
                node.parent = current;
                queue.unshift(adjacent);
              }
            }
          }
          return graph;
        }
        function link(from, to) {
          return function(args) {
            return to(from(args));
          };
        }
        function wrapConversion(toModel, graph) {
          var path2 = [graph[toModel].parent, toModel];
          var fn = conversions[graph[toModel].parent][toModel];
          var cur = graph[toModel].parent;
          while (graph[cur].parent) {
            path2.unshift(graph[cur].parent);
            fn = link(conversions[graph[cur].parent][cur], fn);
            cur = graph[cur].parent;
          }
          fn.conversion = path2;
          return fn;
        }
        module22.exports = function(fromModel) {
          var graph = deriveBFS(fromModel);
          var conversion = {};
          var models = Object.keys(graph);
          for (var len = models.length, i = 0; i < len; i++) {
            var toModel = models[i];
            var node = graph[toModel];
            if (node.parent === null) {
              continue;
            }
            conversion[toModel] = wrapConversion(toModel, graph);
          }
          return conversion;
        };
      }
    });
    var require_color_convert3 = __commonJS2({
      "node_modules/color-convert/index.js"(exports2, module22) {
        var conversions = require_conversions3();
        var route = require_route3();
        var convert = {};
        var models = Object.keys(conversions);
        function wrapRaw(fn) {
          var wrappedFn = function(args) {
            if (args === void 0 || args === null) {
              return args;
            }
            if (arguments.length > 1) {
              args = Array.prototype.slice.call(arguments);
            }
            return fn(args);
          };
          if ("conversion" in fn) {
            wrappedFn.conversion = fn.conversion;
          }
          return wrappedFn;
        }
        function wrapRounded(fn) {
          var wrappedFn = function(args) {
            if (args === void 0 || args === null) {
              return args;
            }
            if (arguments.length > 1) {
              args = Array.prototype.slice.call(arguments);
            }
            var result = fn(args);
            if (typeof result === "object") {
              for (var len = result.length, i = 0; i < len; i++) {
                result[i] = Math.round(result[i]);
              }
            }
            return result;
          };
          if ("conversion" in fn) {
            wrappedFn.conversion = fn.conversion;
          }
          return wrappedFn;
        }
        models.forEach(function(fromModel) {
          convert[fromModel] = {};
          Object.defineProperty(convert[fromModel], "channels", {
            value: conversions[fromModel].channels
          });
          Object.defineProperty(convert[fromModel], "labels", {
            value: conversions[fromModel].labels
          });
          var routes = route(fromModel);
          var routeModels = Object.keys(routes);
          routeModels.forEach(function(toModel) {
            var fn = routes[toModel];
            convert[fromModel][toModel] = wrapRounded(fn);
            convert[fromModel][toModel].raw = wrapRaw(fn);
          });
        });
        module22.exports = convert;
      }
    });
    var require_ansi_styles3 = __commonJS2({
      "node_modules/ansi-styles/index.js"(exports2, module22) {
        "use strict";
        var colorConvert = require_color_convert3();
        var wrapAnsi16 = (fn, offset) => function() {
          const code = fn.apply(colorConvert, arguments);
          return `\x1B[${code + offset}m`;
        };
        var wrapAnsi256 = (fn, offset) => function() {
          const code = fn.apply(colorConvert, arguments);
          return `\x1B[${38 + offset};5;${code}m`;
        };
        var wrapAnsi16m = (fn, offset) => function() {
          const rgb = fn.apply(colorConvert, arguments);
          return `\x1B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
        };
        function assembleStyles() {
          const codes = /* @__PURE__ */ new Map();
          const styles = {
            modifier: {
              reset: [0, 0],
              bold: [1, 22],
              dim: [2, 22],
              italic: [3, 23],
              underline: [4, 24],
              inverse: [7, 27],
              hidden: [8, 28],
              strikethrough: [9, 29]
            },
            color: {
              black: [30, 39],
              red: [31, 39],
              green: [32, 39],
              yellow: [33, 39],
              blue: [34, 39],
              magenta: [35, 39],
              cyan: [36, 39],
              white: [37, 39],
              gray: [90, 39],
              redBright: [91, 39],
              greenBright: [92, 39],
              yellowBright: [93, 39],
              blueBright: [94, 39],
              magentaBright: [95, 39],
              cyanBright: [96, 39],
              whiteBright: [97, 39]
            },
            bgColor: {
              bgBlack: [40, 49],
              bgRed: [41, 49],
              bgGreen: [42, 49],
              bgYellow: [43, 49],
              bgBlue: [44, 49],
              bgMagenta: [45, 49],
              bgCyan: [46, 49],
              bgWhite: [47, 49],
              bgBlackBright: [100, 49],
              bgRedBright: [101, 49],
              bgGreenBright: [102, 49],
              bgYellowBright: [103, 49],
              bgBlueBright: [104, 49],
              bgMagentaBright: [105, 49],
              bgCyanBright: [106, 49],
              bgWhiteBright: [107, 49]
            }
          };
          styles.color.grey = styles.color.gray;
          for (const groupName of Object.keys(styles)) {
            const group = styles[groupName];
            for (const styleName of Object.keys(group)) {
              const style = group[styleName];
              styles[styleName] = {
                open: `\x1B[${style[0]}m`,
                close: `\x1B[${style[1]}m`
              };
              group[styleName] = styles[styleName];
              codes.set(style[0], style[1]);
            }
            Object.defineProperty(styles, groupName, {
              value: group,
              enumerable: false
            });
            Object.defineProperty(styles, "codes", {
              value: codes,
              enumerable: false
            });
          }
          const ansi2ansi = (n) => n;
          const rgb2rgb = (r, g, b) => [r, g, b];
          styles.color.close = "\x1B[39m";
          styles.bgColor.close = "\x1B[49m";
          styles.color.ansi = {
            ansi: wrapAnsi16(ansi2ansi, 0)
          };
          styles.color.ansi256 = {
            ansi256: wrapAnsi256(ansi2ansi, 0)
          };
          styles.color.ansi16m = {
            rgb: wrapAnsi16m(rgb2rgb, 0)
          };
          styles.bgColor.ansi = {
            ansi: wrapAnsi16(ansi2ansi, 10)
          };
          styles.bgColor.ansi256 = {
            ansi256: wrapAnsi256(ansi2ansi, 10)
          };
          styles.bgColor.ansi16m = {
            rgb: wrapAnsi16m(rgb2rgb, 10)
          };
          for (let key of Object.keys(colorConvert)) {
            if (typeof colorConvert[key] !== "object") {
              continue;
            }
            const suite = colorConvert[key];
            if (key === "ansi16") {
              key = "ansi";
            }
            if ("ansi16" in suite) {
              styles.color.ansi[key] = wrapAnsi16(suite.ansi16, 0);
              styles.bgColor.ansi[key] = wrapAnsi16(suite.ansi16, 10);
            }
            if ("ansi256" in suite) {
              styles.color.ansi256[key] = wrapAnsi256(suite.ansi256, 0);
              styles.bgColor.ansi256[key] = wrapAnsi256(suite.ansi256, 10);
            }
            if ("rgb" in suite) {
              styles.color.ansi16m[key] = wrapAnsi16m(suite.rgb, 0);
              styles.bgColor.ansi16m[key] = wrapAnsi16m(suite.rgb, 10);
            }
          }
          return styles;
        }
        Object.defineProperty(module22, "exports", {
          enumerable: true,
          get: assembleStyles
        });
      }
    });
    var require_has_flag3 = __commonJS2({
      "node_modules/@babel/highlight/node_modules/has-flag/index.js"(exports2, module22) {
        "use strict";
        module22.exports = (flag, argv) => {
          argv = argv || process.argv;
          const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
          const pos = argv.indexOf(prefix + flag);
          const terminatorPos = argv.indexOf("--");
          return pos !== -1 && (terminatorPos === -1 ? true : pos < terminatorPos);
        };
      }
    });
    var require_supports_color3 = __commonJS2({
      "node_modules/@babel/highlight/node_modules/supports-color/index.js"(exports2, module22) {
        "use strict";
        var os = require("os");
        var hasFlag = require_has_flag3();
        var env = process.env;
        var forceColor;
        if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false")) {
          forceColor = false;
        } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
          forceColor = true;
        }
        if ("FORCE_COLOR" in env) {
          forceColor = env.FORCE_COLOR.length === 0 || parseInt(env.FORCE_COLOR, 10) !== 0;
        }
        function translateLevel(level) {
          if (level === 0) {
            return false;
          }
          return {
            level,
            hasBasic: true,
            has256: level >= 2,
            has16m: level >= 3
          };
        }
        function supportsColor(stream) {
          if (forceColor === false) {
            return 0;
          }
          if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
            return 3;
          }
          if (hasFlag("color=256")) {
            return 2;
          }
          if (stream && !stream.isTTY && forceColor !== true) {
            return 0;
          }
          const min2 = forceColor ? 1 : 0;
          if (process.platform === "win32") {
            const osRelease = os.release().split(".");
            if (Number(process.versions.node.split(".")[0]) >= 8 && Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
              return Number(osRelease[2]) >= 14931 ? 3 : 2;
            }
            return 1;
          }
          if ("CI" in env) {
            if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
              return 1;
            }
            return min2;
          }
          if ("TEAMCITY_VERSION" in env) {
            return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
          }
          if (env.COLORTERM === "truecolor") {
            return 3;
          }
          if ("TERM_PROGRAM" in env) {
            const version2 = parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
            switch (env.TERM_PROGRAM) {
              case "iTerm.app":
                return version2 >= 3 ? 3 : 2;
              case "Apple_Terminal":
                return 2;
            }
          }
          if (/-256(color)?$/i.test(env.TERM)) {
            return 2;
          }
          if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
            return 1;
          }
          if ("COLORTERM" in env) {
            return 1;
          }
          if (env.TERM === "dumb") {
            return min2;
          }
          return min2;
        }
        function getSupportLevel(stream) {
          const level = supportsColor(stream);
          return translateLevel(level);
        }
        module22.exports = {
          supportsColor: getSupportLevel,
          stdout: getSupportLevel(process.stdout),
          stderr: getSupportLevel(process.stderr)
        };
      }
    });
    var require_templates3 = __commonJS2({
      "node_modules/@babel/highlight/node_modules/chalk/templates.js"(exports2, module22) {
        "use strict";
        var TEMPLATE_REGEX = /(?:\\(u[a-f\d]{4}|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
        var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
        var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
        var ESCAPE_REGEX = /\\(u[a-f\d]{4}|x[a-f\d]{2}|.)|([^\\])/gi;
        var ESCAPES = /* @__PURE__ */ new Map([["n", "\n"], ["r", "\r"], ["t", "	"], ["b", "\b"], ["f", "\f"], ["v", "\v"], ["0", "\0"], ["\\", "\\"], ["e", "\x1B"], ["a", "\x07"]]);
        function unescape2(c) {
          if (c[0] === "u" && c.length === 5 || c[0] === "x" && c.length === 3) {
            return String.fromCharCode(parseInt(c.slice(1), 16));
          }
          return ESCAPES.get(c) || c;
        }
        function parseArguments(name, args) {
          const results = [];
          const chunks = args.trim().split(/\s*,\s*/g);
          let matches;
          for (const chunk of chunks) {
            if (!isNaN(chunk)) {
              results.push(Number(chunk));
            } else if (matches = chunk.match(STRING_REGEX)) {
              results.push(matches[2].replace(ESCAPE_REGEX, (m, escape2, chr) => escape2 ? unescape2(escape2) : chr));
            } else {
              throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
            }
          }
          return results;
        }
        function parseStyle(style) {
          STYLE_REGEX.lastIndex = 0;
          const results = [];
          let matches;
          while ((matches = STYLE_REGEX.exec(style)) !== null) {
            const name = matches[1];
            if (matches[2]) {
              const args = parseArguments(name, matches[2]);
              results.push([name].concat(args));
            } else {
              results.push([name]);
            }
          }
          return results;
        }
        function buildStyle(chalk3, styles) {
          const enabled = {};
          for (const layer of styles) {
            for (const style of layer.styles) {
              enabled[style[0]] = layer.inverse ? null : style.slice(1);
            }
          }
          let current = chalk3;
          for (const styleName of Object.keys(enabled)) {
            if (Array.isArray(enabled[styleName])) {
              if (!(styleName in current)) {
                throw new Error(`Unknown Chalk style: ${styleName}`);
              }
              if (enabled[styleName].length > 0) {
                current = current[styleName].apply(current, enabled[styleName]);
              } else {
                current = current[styleName];
              }
            }
          }
          return current;
        }
        module22.exports = (chalk3, tmp) => {
          const styles = [];
          const chunks = [];
          let chunk = [];
          tmp.replace(TEMPLATE_REGEX, (m, escapeChar, inverse, style, close, chr) => {
            if (escapeChar) {
              chunk.push(unescape2(escapeChar));
            } else if (style) {
              const str = chunk.join("");
              chunk = [];
              chunks.push(styles.length === 0 ? str : buildStyle(chalk3, styles)(str));
              styles.push({
                inverse,
                styles: parseStyle(style)
              });
            } else if (close) {
              if (styles.length === 0) {
                throw new Error("Found extraneous } in Chalk template literal");
              }
              chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
              chunk = [];
              styles.pop();
            } else {
              chunk.push(chr);
            }
          });
          chunks.push(chunk.join(""));
          if (styles.length > 0) {
            const errMsg = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
            throw new Error(errMsg);
          }
          return chunks.join("");
        };
      }
    });
    var require_chalk2 = __commonJS2({
      "node_modules/@babel/highlight/node_modules/chalk/index.js"(exports2, module22) {
        "use strict";
        var escapeStringRegexp = require_escape_string_regexp3();
        var ansiStyles = require_ansi_styles3();
        var stdoutColor = require_supports_color3().stdout;
        var template = require_templates3();
        var isSimpleWindowsTerm = process.platform === "win32" && !(process.env.TERM || "").toLowerCase().startsWith("xterm");
        var levelMapping = ["ansi", "ansi", "ansi256", "ansi16m"];
        var skipModels = /* @__PURE__ */ new Set(["gray"]);
        var styles = /* @__PURE__ */ Object.create(null);
        function applyOptions(obj, options) {
          options = options || {};
          const scLevel = stdoutColor ? stdoutColor.level : 0;
          obj.level = options.level === void 0 ? scLevel : options.level;
          obj.enabled = "enabled" in options ? options.enabled : obj.level > 0;
        }
        function Chalk(options) {
          if (!this || !(this instanceof Chalk) || this.template) {
            const chalk3 = {};
            applyOptions(chalk3, options);
            chalk3.template = function() {
              const args = [].slice.call(arguments);
              return chalkTag.apply(null, [chalk3.template].concat(args));
            };
            Object.setPrototypeOf(chalk3, Chalk.prototype);
            Object.setPrototypeOf(chalk3.template, chalk3);
            chalk3.template.constructor = Chalk;
            return chalk3.template;
          }
          applyOptions(this, options);
        }
        if (isSimpleWindowsTerm) {
          ansiStyles.blue.open = "\x1B[94m";
        }
        for (const key of Object.keys(ansiStyles)) {
          ansiStyles[key].closeRe = new RegExp(escapeStringRegexp(ansiStyles[key].close), "g");
          styles[key] = {
            get() {
              const codes = ansiStyles[key];
              return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, key);
            }
          };
        }
        styles.visible = {
          get() {
            return build.call(this, this._styles || [], true, "visible");
          }
        };
        ansiStyles.color.closeRe = new RegExp(escapeStringRegexp(ansiStyles.color.close), "g");
        for (const model of Object.keys(ansiStyles.color.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          styles[model] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.color[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.color.close,
                  closeRe: ansiStyles.color.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        ansiStyles.bgColor.closeRe = new RegExp(escapeStringRegexp(ansiStyles.bgColor.close), "g");
        for (const model of Object.keys(ansiStyles.bgColor.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
          styles[bgModel] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.bgColor[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.bgColor.close,
                  closeRe: ansiStyles.bgColor.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        var proto = Object.defineProperties(() => {
        }, styles);
        function build(_styles, _empty, key) {
          const builder = function() {
            return applyStyle.apply(builder, arguments);
          };
          builder._styles = _styles;
          builder._empty = _empty;
          const self2 = this;
          Object.defineProperty(builder, "level", {
            enumerable: true,
            get() {
              return self2.level;
            },
            set(level) {
              self2.level = level;
            }
          });
          Object.defineProperty(builder, "enabled", {
            enumerable: true,
            get() {
              return self2.enabled;
            },
            set(enabled) {
              self2.enabled = enabled;
            }
          });
          builder.hasGrey = this.hasGrey || key === "gray" || key === "grey";
          builder.__proto__ = proto;
          return builder;
        }
        function applyStyle() {
          const args = arguments;
          const argsLen = args.length;
          let str = String(arguments[0]);
          if (argsLen === 0) {
            return "";
          }
          if (argsLen > 1) {
            for (let a = 1; a < argsLen; a++) {
              str += " " + args[a];
            }
          }
          if (!this.enabled || this.level <= 0 || !str) {
            return this._empty ? "" : str;
          }
          const originalDim = ansiStyles.dim.open;
          if (isSimpleWindowsTerm && this.hasGrey) {
            ansiStyles.dim.open = "";
          }
          for (const code of this._styles.slice().reverse()) {
            str = code.open + str.replace(code.closeRe, code.open) + code.close;
            str = str.replace(/\r?\n/g, `${code.close}$&${code.open}`);
          }
          ansiStyles.dim.open = originalDim;
          return str;
        }
        function chalkTag(chalk3, strings) {
          if (!Array.isArray(strings)) {
            return [].slice.call(arguments, 1).join(" ");
          }
          const args = [].slice.call(arguments, 2);
          const parts = [strings.raw[0]];
          for (let i = 1; i < strings.length; i++) {
            parts.push(String(args[i - 1]).replace(/[{}\\]/g, "\\$&"));
            parts.push(String(strings.raw[i]));
          }
          return template(chalk3, parts.join(""));
        }
        Object.defineProperties(Chalk.prototype, styles);
        module22.exports = Chalk();
        module22.exports.supportsColor = stdoutColor;
        module22.exports.default = module22.exports;
      }
    });
    var require_lib210 = __commonJS2({
      "node_modules/@babel/highlight/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.default = highlight;
        exports2.getChalk = getChalk;
        exports2.shouldHighlight = shouldHighlight;
        var _jsTokens = require_js_tokens2();
        var _helperValidatorIdentifier = require_lib33();
        var _chalk = require_chalk2();
        var sometimesKeywords = /* @__PURE__ */ new Set(["as", "async", "from", "get", "of", "set"]);
        function getDefs(chalk3) {
          return {
            keyword: chalk3.cyan,
            capitalized: chalk3.yellow,
            jsxIdentifier: chalk3.yellow,
            punctuator: chalk3.yellow,
            number: chalk3.magenta,
            string: chalk3.green,
            regex: chalk3.magenta,
            comment: chalk3.grey,
            invalid: chalk3.white.bgRed.bold
          };
        }
        var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
        var BRACKET = /^[()[\]{}]$/;
        var tokenize;
        {
          const JSX_TAG = /^[a-z][\w-]*$/i;
          const getTokenType = function(token, offset, text) {
            if (token.type === "name") {
              if ((0, _helperValidatorIdentifier.isKeyword)(token.value) || (0, _helperValidatorIdentifier.isStrictReservedWord)(token.value, true) || sometimesKeywords.has(token.value)) {
                return "keyword";
              }
              if (JSX_TAG.test(token.value) && (text[offset - 1] === "<" || text.slice(offset - 2, offset) == "</")) {
                return "jsxIdentifier";
              }
              if (token.value[0] !== token.value[0].toLowerCase()) {
                return "capitalized";
              }
            }
            if (token.type === "punctuator" && BRACKET.test(token.value)) {
              return "bracket";
            }
            if (token.type === "invalid" && (token.value === "@" || token.value === "#")) {
              return "punctuator";
            }
            return token.type;
          };
          tokenize = function* (text) {
            let match;
            while (match = _jsTokens.default.exec(text)) {
              const token = _jsTokens.matchToToken(match);
              yield {
                type: getTokenType(token, match.index, text),
                value: token.value
              };
            }
          };
        }
        function highlightTokens(defs, text) {
          let highlighted = "";
          for (const {
            type,
            value: value2
          } of tokenize(text)) {
            const colorize = defs[type];
            if (colorize) {
              highlighted += value2.split(NEWLINE).map((str) => colorize(str)).join("\n");
            } else {
              highlighted += value2;
            }
          }
          return highlighted;
        }
        function shouldHighlight(options) {
          return !!_chalk.supportsColor || options.forceColor;
        }
        function getChalk(options) {
          return options.forceColor ? new _chalk.constructor({
            enabled: true,
            level: 1
          }) : _chalk;
        }
        function highlight(code, options = {}) {
          if (code !== "" && shouldHighlight(options)) {
            const chalk3 = getChalk(options);
            const defs = getDefs(chalk3);
            return highlightTokens(defs, code);
          } else {
            return code;
          }
        }
      }
    });
    var require_lib34 = __commonJS2({
      "node_modules/@babel/code-frame/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.codeFrameColumns = codeFrameColumns;
        exports2.default = _default;
        var _highlight = require_lib210();
        var deprecationWarningShown = false;
        function getDefs(chalk3) {
          return {
            gutter: chalk3.grey,
            marker: chalk3.red.bold,
            message: chalk3.red.bold
          };
        }
        var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
        function getMarkerLines(loc, source, opts) {
          const startLoc = Object.assign({
            column: 0,
            line: -1
          }, loc.start);
          const endLoc = Object.assign({}, startLoc, loc.end);
          const {
            linesAbove = 2,
            linesBelow = 3
          } = opts || {};
          const startLine = startLoc.line;
          const startColumn = startLoc.column;
          const endLine = endLoc.line;
          const endColumn = endLoc.column;
          let start = Math.max(startLine - (linesAbove + 1), 0);
          let end = Math.min(source.length, endLine + linesBelow);
          if (startLine === -1) {
            start = 0;
          }
          if (endLine === -1) {
            end = source.length;
          }
          const lineDiff = endLine - startLine;
          const markerLines = {};
          if (lineDiff) {
            for (let i = 0; i <= lineDiff; i++) {
              const lineNumber = i + startLine;
              if (!startColumn) {
                markerLines[lineNumber] = true;
              } else if (i === 0) {
                const sourceLength = source[lineNumber - 1].length;
                markerLines[lineNumber] = [startColumn, sourceLength - startColumn + 1];
              } else if (i === lineDiff) {
                markerLines[lineNumber] = [0, endColumn];
              } else {
                const sourceLength = source[lineNumber - i].length;
                markerLines[lineNumber] = [0, sourceLength];
              }
            }
          } else {
            if (startColumn === endColumn) {
              if (startColumn) {
                markerLines[startLine] = [startColumn, 0];
              } else {
                markerLines[startLine] = true;
              }
            } else {
              markerLines[startLine] = [startColumn, endColumn - startColumn];
            }
          }
          return {
            start,
            end,
            markerLines
          };
        }
        function codeFrameColumns(rawLines, loc, opts = {}) {
          const highlighted = (opts.highlightCode || opts.forceColor) && (0, _highlight.shouldHighlight)(opts);
          const chalk3 = (0, _highlight.getChalk)(opts);
          const defs = getDefs(chalk3);
          const maybeHighlight = (chalkFn, string) => {
            return highlighted ? chalkFn(string) : string;
          };
          const lines = rawLines.split(NEWLINE);
          const {
            start,
            end,
            markerLines
          } = getMarkerLines(loc, lines, opts);
          const hasColumns = loc.start && typeof loc.start.column === "number";
          const numberMaxWidth = String(end).length;
          const highlightedLines = highlighted ? (0, _highlight.default)(rawLines, opts) : rawLines;
          let frame = highlightedLines.split(NEWLINE, end).slice(start, end).map((line, index) => {
            const number = start + 1 + index;
            const paddedNumber = ` ${number}`.slice(-numberMaxWidth);
            const gutter = ` ${paddedNumber} |`;
            const hasMarker = markerLines[number];
            const lastMarkerLine = !markerLines[number + 1];
            if (hasMarker) {
              let markerLine = "";
              if (Array.isArray(hasMarker)) {
                const markerSpacing = line.slice(0, Math.max(hasMarker[0] - 1, 0)).replace(/[^\t]/g, " ");
                const numberOfMarkers = hasMarker[1] || 1;
                markerLine = ["\n ", maybeHighlight(defs.gutter, gutter.replace(/\d/g, " ")), " ", markerSpacing, maybeHighlight(defs.marker, "^").repeat(numberOfMarkers)].join("");
                if (lastMarkerLine && opts.message) {
                  markerLine += " " + maybeHighlight(defs.message, opts.message);
                }
              }
              return [maybeHighlight(defs.marker, ">"), maybeHighlight(defs.gutter, gutter), line.length > 0 ? ` ${line}` : "", markerLine].join("");
            } else {
              return ` ${maybeHighlight(defs.gutter, gutter)}${line.length > 0 ? ` ${line}` : ""}`;
            }
          }).join("\n");
          if (opts.message && !hasColumns) {
            frame = `${" ".repeat(numberMaxWidth + 1)}${opts.message}
${frame}`;
          }
          if (highlighted) {
            return chalk3.reset(frame);
          } else {
            return frame;
          }
        }
        function _default(rawLines, lineNumber, colNumber, opts = {}) {
          if (!deprecationWarningShown) {
            deprecationWarningShown = true;
            const message = "Passing lineNumber and colNumber is deprecated to @babel/code-frame. Please use `codeFrameColumns`.";
            if (process.emitWarning) {
              process.emitWarning(message, "DeprecationWarning");
            } else {
              const deprecationError = new Error(message);
              deprecationError.name = "DeprecationWarning";
              console.warn(new Error(message));
            }
          }
          colNumber = Math.max(colNumber, 0);
          const location = {
            start: {
              column: colNumber,
              line: lineNumber
            }
          };
          return codeFrameColumns(rawLines, location, opts);
        }
      }
    });
    var require_parse_json = __commonJS2({
      "node_modules/parse-json/index.js"(exports2, module22) {
        "use strict";
        var errorEx = require_error_ex();
        var fallback = require_json_parse_even_better_errors();
        var {
          default: LinesAndColumns
        } = require_build();
        var {
          codeFrameColumns
        } = require_lib34();
        var JSONError = errorEx("JSONError", {
          fileName: errorEx.append("in %s"),
          codeFrame: errorEx.append("\n\n%s\n")
        });
        var parseJson = (string, reviver, filename) => {
          if (typeof reviver === "string") {
            filename = reviver;
            reviver = null;
          }
          try {
            try {
              return JSON.parse(string, reviver);
            } catch (error) {
              fallback(string, reviver);
              throw error;
            }
          } catch (error) {
            error.message = error.message.replace(/\n/g, "");
            const indexMatch = error.message.match(/in JSON at position (\d+) while parsing/);
            const jsonError = new JSONError(error);
            if (filename) {
              jsonError.fileName = filename;
            }
            if (indexMatch && indexMatch.length > 0) {
              const lines = new LinesAndColumns(string);
              const index = Number(indexMatch[1]);
              const location = lines.locationForIndex(index);
              const codeFrame = codeFrameColumns(string, {
                start: {
                  line: location.line + 1,
                  column: location.column + 1
                }
              }, {
                highlightCode: true
              });
              jsonError.codeFrame = codeFrame;
            }
            throw jsonError;
          }
        };
        parseJson.JSONError = JSONError;
        module22.exports = parseJson;
      }
    });
    var require_PlainValue_ec8e588e = __commonJS2({
      "node_modules/yaml/dist/PlainValue-ec8e588e.js"(exports2) {
        "use strict";
        var Char = {
          ANCHOR: "&",
          COMMENT: "#",
          TAG: "!",
          DIRECTIVES_END: "-",
          DOCUMENT_END: "."
        };
        var Type = {
          ALIAS: "ALIAS",
          BLANK_LINE: "BLANK_LINE",
          BLOCK_FOLDED: "BLOCK_FOLDED",
          BLOCK_LITERAL: "BLOCK_LITERAL",
          COMMENT: "COMMENT",
          DIRECTIVE: "DIRECTIVE",
          DOCUMENT: "DOCUMENT",
          FLOW_MAP: "FLOW_MAP",
          FLOW_SEQ: "FLOW_SEQ",
          MAP: "MAP",
          MAP_KEY: "MAP_KEY",
          MAP_VALUE: "MAP_VALUE",
          PLAIN: "PLAIN",
          QUOTE_DOUBLE: "QUOTE_DOUBLE",
          QUOTE_SINGLE: "QUOTE_SINGLE",
          SEQ: "SEQ",
          SEQ_ITEM: "SEQ_ITEM"
        };
        var defaultTagPrefix = "tag:yaml.org,2002:";
        var defaultTags = {
          MAP: "tag:yaml.org,2002:map",
          SEQ: "tag:yaml.org,2002:seq",
          STR: "tag:yaml.org,2002:str"
        };
        function findLineStarts(src) {
          const ls = [0];
          let offset = src.indexOf("\n");
          while (offset !== -1) {
            offset += 1;
            ls.push(offset);
            offset = src.indexOf("\n", offset);
          }
          return ls;
        }
        function getSrcInfo(cst) {
          let lineStarts, src;
          if (typeof cst === "string") {
            lineStarts = findLineStarts(cst);
            src = cst;
          } else {
            if (Array.isArray(cst))
              cst = cst[0];
            if (cst && cst.context) {
              if (!cst.lineStarts)
                cst.lineStarts = findLineStarts(cst.context.src);
              lineStarts = cst.lineStarts;
              src = cst.context.src;
            }
          }
          return {
            lineStarts,
            src
          };
        }
        function getLinePos(offset, cst) {
          if (typeof offset !== "number" || offset < 0)
            return null;
          const {
            lineStarts,
            src
          } = getSrcInfo(cst);
          if (!lineStarts || !src || offset > src.length)
            return null;
          for (let i = 0; i < lineStarts.length; ++i) {
            const start = lineStarts[i];
            if (offset < start) {
              return {
                line: i,
                col: offset - lineStarts[i - 1] + 1
              };
            }
            if (offset === start)
              return {
                line: i + 1,
                col: 1
              };
          }
          const line = lineStarts.length;
          return {
            line,
            col: offset - lineStarts[line - 1] + 1
          };
        }
        function getLine(line, cst) {
          const {
            lineStarts,
            src
          } = getSrcInfo(cst);
          if (!lineStarts || !(line >= 1) || line > lineStarts.length)
            return null;
          const start = lineStarts[line - 1];
          let end = lineStarts[line];
          while (end && end > start && src[end - 1] === "\n")
            --end;
          return src.slice(start, end);
        }
        function getPrettyContext({
          start,
          end
        }, cst, maxWidth = 80) {
          let src = getLine(start.line, cst);
          if (!src)
            return null;
          let {
            col
          } = start;
          if (src.length > maxWidth) {
            if (col <= maxWidth - 10) {
              src = src.substr(0, maxWidth - 1) + "\u2026";
            } else {
              const halfWidth = Math.round(maxWidth / 2);
              if (src.length > col + halfWidth)
                src = src.substr(0, col + halfWidth - 1) + "\u2026";
              col -= src.length - maxWidth;
              src = "\u2026" + src.substr(1 - maxWidth);
            }
          }
          let errLen = 1;
          let errEnd = "";
          if (end) {
            if (end.line === start.line && col + (end.col - start.col) <= maxWidth + 1) {
              errLen = end.col - start.col;
            } else {
              errLen = Math.min(src.length + 1, maxWidth) - col;
              errEnd = "\u2026";
            }
          }
          const offset = col > 1 ? " ".repeat(col - 1) : "";
          const err = "^".repeat(errLen);
          return `${src}
${offset}${err}${errEnd}`;
        }
        var Range = class {
          static copy(orig) {
            return new Range(orig.start, orig.end);
          }
          constructor(start, end) {
            this.start = start;
            this.end = end || start;
          }
          isEmpty() {
            return typeof this.start !== "number" || !this.end || this.end <= this.start;
          }
          setOrigRange(cr, offset) {
            const {
              start,
              end
            } = this;
            if (cr.length === 0 || end <= cr[0]) {
              this.origStart = start;
              this.origEnd = end;
              return offset;
            }
            let i = offset;
            while (i < cr.length) {
              if (cr[i] > start)
                break;
              else
                ++i;
            }
            this.origStart = start + i;
            const nextOffset = i;
            while (i < cr.length) {
              if (cr[i] >= end)
                break;
              else
                ++i;
            }
            this.origEnd = end + i;
            return nextOffset;
          }
        };
        var Node2 = class {
          static addStringTerminator(src, offset, str) {
            if (str[str.length - 1] === "\n")
              return str;
            const next = Node2.endOfWhiteSpace(src, offset);
            return next >= src.length || src[next] === "\n" ? str + "\n" : str;
          }
          static atDocumentBoundary(src, offset, sep) {
            const ch0 = src[offset];
            if (!ch0)
              return true;
            const prev = src[offset - 1];
            if (prev && prev !== "\n")
              return false;
            if (sep) {
              if (ch0 !== sep)
                return false;
            } else {
              if (ch0 !== Char.DIRECTIVES_END && ch0 !== Char.DOCUMENT_END)
                return false;
            }
            const ch1 = src[offset + 1];
            const ch2 = src[offset + 2];
            if (ch1 !== ch0 || ch2 !== ch0)
              return false;
            const ch3 = src[offset + 3];
            return !ch3 || ch3 === "\n" || ch3 === "	" || ch3 === " ";
          }
          static endOfIdentifier(src, offset) {
            let ch = src[offset];
            const isVerbatim = ch === "<";
            const notOk = isVerbatim ? ["\n", "	", " ", ">"] : ["\n", "	", " ", "[", "]", "{", "}", ","];
            while (ch && notOk.indexOf(ch) === -1)
              ch = src[offset += 1];
            if (isVerbatim && ch === ">")
              offset += 1;
            return offset;
          }
          static endOfIndent(src, offset) {
            let ch = src[offset];
            while (ch === " ")
              ch = src[offset += 1];
            return offset;
          }
          static endOfLine(src, offset) {
            let ch = src[offset];
            while (ch && ch !== "\n")
              ch = src[offset += 1];
            return offset;
          }
          static endOfWhiteSpace(src, offset) {
            let ch = src[offset];
            while (ch === "	" || ch === " ")
              ch = src[offset += 1];
            return offset;
          }
          static startOfLine(src, offset) {
            let ch = src[offset - 1];
            if (ch === "\n")
              return offset;
            while (ch && ch !== "\n")
              ch = src[offset -= 1];
            return offset + 1;
          }
          static endOfBlockIndent(src, indent, lineStart) {
            const inEnd = Node2.endOfIndent(src, lineStart);
            if (inEnd > lineStart + indent) {
              return inEnd;
            } else {
              const wsEnd = Node2.endOfWhiteSpace(src, inEnd);
              const ch = src[wsEnd];
              if (!ch || ch === "\n")
                return wsEnd;
            }
            return null;
          }
          static atBlank(src, offset, endAsBlank) {
            const ch = src[offset];
            return ch === "\n" || ch === "	" || ch === " " || endAsBlank && !ch;
          }
          static nextNodeIsIndented(ch, indentDiff, indicatorAsIndent) {
            if (!ch || indentDiff < 0)
              return false;
            if (indentDiff > 0)
              return true;
            return indicatorAsIndent && ch === "-";
          }
          static normalizeOffset(src, offset) {
            const ch = src[offset];
            return !ch ? offset : ch !== "\n" && src[offset - 1] === "\n" ? offset - 1 : Node2.endOfWhiteSpace(src, offset);
          }
          static foldNewline(src, offset, indent) {
            let inCount = 0;
            let error = false;
            let fold = "";
            let ch = src[offset + 1];
            while (ch === " " || ch === "	" || ch === "\n") {
              switch (ch) {
                case "\n":
                  inCount = 0;
                  offset += 1;
                  fold += "\n";
                  break;
                case "	":
                  if (inCount <= indent)
                    error = true;
                  offset = Node2.endOfWhiteSpace(src, offset + 2) - 1;
                  break;
                case " ":
                  inCount += 1;
                  offset += 1;
                  break;
              }
              ch = src[offset + 1];
            }
            if (!fold)
              fold = " ";
            if (ch && inCount <= indent)
              error = true;
            return {
              fold,
              offset,
              error
            };
          }
          constructor(type, props, context) {
            Object.defineProperty(this, "context", {
              value: context || null,
              writable: true
            });
            this.error = null;
            this.range = null;
            this.valueRange = null;
            this.props = props || [];
            this.type = type;
            this.value = null;
          }
          getPropValue(idx, key, skipKey) {
            if (!this.context)
              return null;
            const {
              src
            } = this.context;
            const prop = this.props[idx];
            return prop && src[prop.start] === key ? src.slice(prop.start + (skipKey ? 1 : 0), prop.end) : null;
          }
          get anchor() {
            for (let i = 0; i < this.props.length; ++i) {
              const anchor = this.getPropValue(i, Char.ANCHOR, true);
              if (anchor != null)
                return anchor;
            }
            return null;
          }
          get comment() {
            const comments = [];
            for (let i = 0; i < this.props.length; ++i) {
              const comment = this.getPropValue(i, Char.COMMENT, true);
              if (comment != null)
                comments.push(comment);
            }
            return comments.length > 0 ? comments.join("\n") : null;
          }
          commentHasRequiredWhitespace(start) {
            const {
              src
            } = this.context;
            if (this.header && start === this.header.end)
              return false;
            if (!this.valueRange)
              return false;
            const {
              end
            } = this.valueRange;
            return start !== end || Node2.atBlank(src, end - 1);
          }
          get hasComment() {
            if (this.context) {
              const {
                src
              } = this.context;
              for (let i = 0; i < this.props.length; ++i) {
                if (src[this.props[i].start] === Char.COMMENT)
                  return true;
              }
            }
            return false;
          }
          get hasProps() {
            if (this.context) {
              const {
                src
              } = this.context;
              for (let i = 0; i < this.props.length; ++i) {
                if (src[this.props[i].start] !== Char.COMMENT)
                  return true;
              }
            }
            return false;
          }
          get includesTrailingLines() {
            return false;
          }
          get jsonLike() {
            const jsonLikeTypes = [Type.FLOW_MAP, Type.FLOW_SEQ, Type.QUOTE_DOUBLE, Type.QUOTE_SINGLE];
            return jsonLikeTypes.indexOf(this.type) !== -1;
          }
          get rangeAsLinePos() {
            if (!this.range || !this.context)
              return void 0;
            const start = getLinePos(this.range.start, this.context.root);
            if (!start)
              return void 0;
            const end = getLinePos(this.range.end, this.context.root);
            return {
              start,
              end
            };
          }
          get rawValue() {
            if (!this.valueRange || !this.context)
              return null;
            const {
              start,
              end
            } = this.valueRange;
            return this.context.src.slice(start, end);
          }
          get tag() {
            for (let i = 0; i < this.props.length; ++i) {
              const tag = this.getPropValue(i, Char.TAG, false);
              if (tag != null) {
                if (tag[1] === "<") {
                  return {
                    verbatim: tag.slice(2, -1)
                  };
                } else {
                  const [_, handle, suffix] = tag.match(/^(.*!)([^!]*)$/);
                  return {
                    handle,
                    suffix
                  };
                }
              }
            }
            return null;
          }
          get valueRangeContainsNewline() {
            if (!this.valueRange || !this.context)
              return false;
            const {
              start,
              end
            } = this.valueRange;
            const {
              src
            } = this.context;
            for (let i = start; i < end; ++i) {
              if (src[i] === "\n")
                return true;
            }
            return false;
          }
          parseComment(start) {
            const {
              src
            } = this.context;
            if (src[start] === Char.COMMENT) {
              const end = Node2.endOfLine(src, start + 1);
              const commentRange = new Range(start, end);
              this.props.push(commentRange);
              return end;
            }
            return start;
          }
          setOrigRanges(cr, offset) {
            if (this.range)
              offset = this.range.setOrigRange(cr, offset);
            if (this.valueRange)
              this.valueRange.setOrigRange(cr, offset);
            this.props.forEach((prop) => prop.setOrigRange(cr, offset));
            return offset;
          }
          toString() {
            const {
              context: {
                src
              },
              range,
              value: value2
            } = this;
            if (value2 != null)
              return value2;
            const str = src.slice(range.start, range.end);
            return Node2.addStringTerminator(src, range.end, str);
          }
        };
        var YAMLError = class extends Error {
          constructor(name, source, message) {
            if (!message || !(source instanceof Node2))
              throw new Error(`Invalid arguments for new ${name}`);
            super();
            this.name = name;
            this.message = message;
            this.source = source;
          }
          makePretty() {
            if (!this.source)
              return;
            this.nodeType = this.source.type;
            const cst = this.source.context && this.source.context.root;
            if (typeof this.offset === "number") {
              this.range = new Range(this.offset, this.offset + 1);
              const start = cst && getLinePos(this.offset, cst);
              if (start) {
                const end = {
                  line: start.line,
                  col: start.col + 1
                };
                this.linePos = {
                  start,
                  end
                };
              }
              delete this.offset;
            } else {
              this.range = this.source.range;
              this.linePos = this.source.rangeAsLinePos;
            }
            if (this.linePos) {
              const {
                line,
                col
              } = this.linePos.start;
              this.message += ` at line ${line}, column ${col}`;
              const ctx = cst && getPrettyContext(this.linePos, cst);
              if (ctx)
                this.message += `:

${ctx}
`;
            }
            delete this.source;
          }
        };
        var YAMLReferenceError = class extends YAMLError {
          constructor(source, message) {
            super("YAMLReferenceError", source, message);
          }
        };
        var YAMLSemanticError = class extends YAMLError {
          constructor(source, message) {
            super("YAMLSemanticError", source, message);
          }
        };
        var YAMLSyntaxError = class extends YAMLError {
          constructor(source, message) {
            super("YAMLSyntaxError", source, message);
          }
        };
        var YAMLWarning = class extends YAMLError {
          constructor(source, message) {
            super("YAMLWarning", source, message);
          }
        };
        function _defineProperty(obj, key, value2) {
          if (key in obj) {
            Object.defineProperty(obj, key, {
              value: value2,
              enumerable: true,
              configurable: true,
              writable: true
            });
          } else {
            obj[key] = value2;
          }
          return obj;
        }
        var PlainValue = class extends Node2 {
          static endOfLine(src, start, inFlow) {
            let ch = src[start];
            let offset = start;
            while (ch && ch !== "\n") {
              if (inFlow && (ch === "[" || ch === "]" || ch === "{" || ch === "}" || ch === ","))
                break;
              const next = src[offset + 1];
              if (ch === ":" && (!next || next === "\n" || next === "	" || next === " " || inFlow && next === ","))
                break;
              if ((ch === " " || ch === "	") && next === "#")
                break;
              offset += 1;
              ch = next;
            }
            return offset;
          }
          get strValue() {
            if (!this.valueRange || !this.context)
              return null;
            let {
              start,
              end
            } = this.valueRange;
            const {
              src
            } = this.context;
            let ch = src[end - 1];
            while (start < end && (ch === "\n" || ch === "	" || ch === " "))
              ch = src[--end - 1];
            let str = "";
            for (let i = start; i < end; ++i) {
              const ch2 = src[i];
              if (ch2 === "\n") {
                const {
                  fold,
                  offset
                } = Node2.foldNewline(src, i, -1);
                str += fold;
                i = offset;
              } else if (ch2 === " " || ch2 === "	") {
                const wsStart = i;
                let next = src[i + 1];
                while (i < end && (next === " " || next === "	")) {
                  i += 1;
                  next = src[i + 1];
                }
                if (next !== "\n")
                  str += i > wsStart ? src.slice(wsStart, i + 1) : ch2;
              } else {
                str += ch2;
              }
            }
            const ch0 = src[start];
            switch (ch0) {
              case "	": {
                const msg = "Plain value cannot start with a tab character";
                const errors = [new YAMLSemanticError(this, msg)];
                return {
                  errors,
                  str
                };
              }
              case "@":
              case "`": {
                const msg = `Plain value cannot start with reserved character ${ch0}`;
                const errors = [new YAMLSemanticError(this, msg)];
                return {
                  errors,
                  str
                };
              }
              default:
                return str;
            }
          }
          parseBlockValue(start) {
            const {
              indent,
              inFlow,
              src
            } = this.context;
            let offset = start;
            let valueEnd = start;
            for (let ch = src[offset]; ch === "\n"; ch = src[offset]) {
              if (Node2.atDocumentBoundary(src, offset + 1))
                break;
              const end = Node2.endOfBlockIndent(src, indent, offset + 1);
              if (end === null || src[end] === "#")
                break;
              if (src[end] === "\n") {
                offset = end;
              } else {
                valueEnd = PlainValue.endOfLine(src, end, inFlow);
                offset = valueEnd;
              }
            }
            if (this.valueRange.isEmpty())
              this.valueRange.start = start;
            this.valueRange.end = valueEnd;
            return valueEnd;
          }
          parse(context, start) {
            this.context = context;
            const {
              inFlow,
              src
            } = context;
            let offset = start;
            const ch = src[offset];
            if (ch && ch !== "#" && ch !== "\n") {
              offset = PlainValue.endOfLine(src, start, inFlow);
            }
            this.valueRange = new Range(start, offset);
            offset = Node2.endOfWhiteSpace(src, offset);
            offset = this.parseComment(offset);
            if (!this.hasComment || this.valueRange.isEmpty()) {
              offset = this.parseBlockValue(offset);
            }
            return offset;
          }
        };
        exports2.Char = Char;
        exports2.Node = Node2;
        exports2.PlainValue = PlainValue;
        exports2.Range = Range;
        exports2.Type = Type;
        exports2.YAMLError = YAMLError;
        exports2.YAMLReferenceError = YAMLReferenceError;
        exports2.YAMLSemanticError = YAMLSemanticError;
        exports2.YAMLSyntaxError = YAMLSyntaxError;
        exports2.YAMLWarning = YAMLWarning;
        exports2._defineProperty = _defineProperty;
        exports2.defaultTagPrefix = defaultTagPrefix;
        exports2.defaultTags = defaultTags;
      }
    });
    var require_parse_cst = __commonJS2({
      "node_modules/yaml/dist/parse-cst.js"(exports2) {
        "use strict";
        var PlainValue = require_PlainValue_ec8e588e();
        var BlankLine = class extends PlainValue.Node {
          constructor() {
            super(PlainValue.Type.BLANK_LINE);
          }
          get includesTrailingLines() {
            return true;
          }
          parse(context, start) {
            this.context = context;
            this.range = new PlainValue.Range(start, start + 1);
            return start + 1;
          }
        };
        var CollectionItem = class extends PlainValue.Node {
          constructor(type, props) {
            super(type, props);
            this.node = null;
          }
          get includesTrailingLines() {
            return !!this.node && this.node.includesTrailingLines;
          }
          parse(context, start) {
            this.context = context;
            const {
              parseNode,
              src
            } = context;
            let {
              atLineStart,
              lineStart
            } = context;
            if (!atLineStart && this.type === PlainValue.Type.SEQ_ITEM)
              this.error = new PlainValue.YAMLSemanticError(this, "Sequence items must not have preceding content on the same line");
            const indent = atLineStart ? start - lineStart : context.indent;
            let offset = PlainValue.Node.endOfWhiteSpace(src, start + 1);
            let ch = src[offset];
            const inlineComment = ch === "#";
            const comments = [];
            let blankLine = null;
            while (ch === "\n" || ch === "#") {
              if (ch === "#") {
                const end2 = PlainValue.Node.endOfLine(src, offset + 1);
                comments.push(new PlainValue.Range(offset, end2));
                offset = end2;
              } else {
                atLineStart = true;
                lineStart = offset + 1;
                const wsEnd = PlainValue.Node.endOfWhiteSpace(src, lineStart);
                if (src[wsEnd] === "\n" && comments.length === 0) {
                  blankLine = new BlankLine();
                  lineStart = blankLine.parse({
                    src
                  }, lineStart);
                }
                offset = PlainValue.Node.endOfIndent(src, lineStart);
              }
              ch = src[offset];
            }
            if (PlainValue.Node.nextNodeIsIndented(ch, offset - (lineStart + indent), this.type !== PlainValue.Type.SEQ_ITEM)) {
              this.node = parseNode({
                atLineStart,
                inCollection: false,
                indent,
                lineStart,
                parent: this
              }, offset);
            } else if (ch && lineStart > start + 1) {
              offset = lineStart - 1;
            }
            if (this.node) {
              if (blankLine) {
                const items = context.parent.items || context.parent.contents;
                if (items)
                  items.push(blankLine);
              }
              if (comments.length)
                Array.prototype.push.apply(this.props, comments);
              offset = this.node.range.end;
            } else {
              if (inlineComment) {
                const c = comments[0];
                this.props.push(c);
                offset = c.end;
              } else {
                offset = PlainValue.Node.endOfLine(src, start + 1);
              }
            }
            const end = this.node ? this.node.valueRange.end : offset;
            this.valueRange = new PlainValue.Range(start, end);
            return offset;
          }
          setOrigRanges(cr, offset) {
            offset = super.setOrigRanges(cr, offset);
            return this.node ? this.node.setOrigRanges(cr, offset) : offset;
          }
          toString() {
            const {
              context: {
                src
              },
              node,
              range,
              value: value2
            } = this;
            if (value2 != null)
              return value2;
            const str = node ? src.slice(range.start, node.range.start) + String(node) : src.slice(range.start, range.end);
            return PlainValue.Node.addStringTerminator(src, range.end, str);
          }
        };
        var Comment = class extends PlainValue.Node {
          constructor() {
            super(PlainValue.Type.COMMENT);
          }
          parse(context, start) {
            this.context = context;
            const offset = this.parseComment(start);
            this.range = new PlainValue.Range(start, offset);
            return offset;
          }
        };
        function grabCollectionEndComments(node) {
          let cnode = node;
          while (cnode instanceof CollectionItem)
            cnode = cnode.node;
          if (!(cnode instanceof Collection))
            return null;
          const len = cnode.items.length;
          let ci = -1;
          for (let i = len - 1; i >= 0; --i) {
            const n = cnode.items[i];
            if (n.type === PlainValue.Type.COMMENT) {
              const {
                indent,
                lineStart
              } = n.context;
              if (indent > 0 && n.range.start >= lineStart + indent)
                break;
              ci = i;
            } else if (n.type === PlainValue.Type.BLANK_LINE)
              ci = i;
            else
              break;
          }
          if (ci === -1)
            return null;
          const ca = cnode.items.splice(ci, len - ci);
          const prevEnd = ca[0].range.start;
          while (true) {
            cnode.range.end = prevEnd;
            if (cnode.valueRange && cnode.valueRange.end > prevEnd)
              cnode.valueRange.end = prevEnd;
            if (cnode === node)
              break;
            cnode = cnode.context.parent;
          }
          return ca;
        }
        var Collection = class extends PlainValue.Node {
          static nextContentHasIndent(src, offset, indent) {
            const lineStart = PlainValue.Node.endOfLine(src, offset) + 1;
            offset = PlainValue.Node.endOfWhiteSpace(src, lineStart);
            const ch = src[offset];
            if (!ch)
              return false;
            if (offset >= lineStart + indent)
              return true;
            if (ch !== "#" && ch !== "\n")
              return false;
            return Collection.nextContentHasIndent(src, offset, indent);
          }
          constructor(firstItem) {
            super(firstItem.type === PlainValue.Type.SEQ_ITEM ? PlainValue.Type.SEQ : PlainValue.Type.MAP);
            for (let i = firstItem.props.length - 1; i >= 0; --i) {
              if (firstItem.props[i].start < firstItem.context.lineStart) {
                this.props = firstItem.props.slice(0, i + 1);
                firstItem.props = firstItem.props.slice(i + 1);
                const itemRange = firstItem.props[0] || firstItem.valueRange;
                firstItem.range.start = itemRange.start;
                break;
              }
            }
            this.items = [firstItem];
            const ec = grabCollectionEndComments(firstItem);
            if (ec)
              Array.prototype.push.apply(this.items, ec);
          }
          get includesTrailingLines() {
            return this.items.length > 0;
          }
          parse(context, start) {
            this.context = context;
            const {
              parseNode,
              src
            } = context;
            let lineStart = PlainValue.Node.startOfLine(src, start);
            const firstItem = this.items[0];
            firstItem.context.parent = this;
            this.valueRange = PlainValue.Range.copy(firstItem.valueRange);
            const indent = firstItem.range.start - firstItem.context.lineStart;
            let offset = start;
            offset = PlainValue.Node.normalizeOffset(src, offset);
            let ch = src[offset];
            let atLineStart = PlainValue.Node.endOfWhiteSpace(src, lineStart) === offset;
            let prevIncludesTrailingLines = false;
            while (ch) {
              while (ch === "\n" || ch === "#") {
                if (atLineStart && ch === "\n" && !prevIncludesTrailingLines) {
                  const blankLine = new BlankLine();
                  offset = blankLine.parse({
                    src
                  }, offset);
                  this.valueRange.end = offset;
                  if (offset >= src.length) {
                    ch = null;
                    break;
                  }
                  this.items.push(blankLine);
                  offset -= 1;
                } else if (ch === "#") {
                  if (offset < lineStart + indent && !Collection.nextContentHasIndent(src, offset, indent)) {
                    return offset;
                  }
                  const comment = new Comment();
                  offset = comment.parse({
                    indent,
                    lineStart,
                    src
                  }, offset);
                  this.items.push(comment);
                  this.valueRange.end = offset;
                  if (offset >= src.length) {
                    ch = null;
                    break;
                  }
                }
                lineStart = offset + 1;
                offset = PlainValue.Node.endOfIndent(src, lineStart);
                if (PlainValue.Node.atBlank(src, offset)) {
                  const wsEnd = PlainValue.Node.endOfWhiteSpace(src, offset);
                  const next = src[wsEnd];
                  if (!next || next === "\n" || next === "#") {
                    offset = wsEnd;
                  }
                }
                ch = src[offset];
                atLineStart = true;
              }
              if (!ch) {
                break;
              }
              if (offset !== lineStart + indent && (atLineStart || ch !== ":")) {
                if (offset < lineStart + indent) {
                  if (lineStart > start)
                    offset = lineStart;
                  break;
                } else if (!this.error) {
                  const msg = "All collection items must start at the same column";
                  this.error = new PlainValue.YAMLSyntaxError(this, msg);
                }
              }
              if (firstItem.type === PlainValue.Type.SEQ_ITEM) {
                if (ch !== "-") {
                  if (lineStart > start)
                    offset = lineStart;
                  break;
                }
              } else if (ch === "-" && !this.error) {
                const next = src[offset + 1];
                if (!next || next === "\n" || next === "	" || next === " ") {
                  const msg = "A collection cannot be both a mapping and a sequence";
                  this.error = new PlainValue.YAMLSyntaxError(this, msg);
                }
              }
              const node = parseNode({
                atLineStart,
                inCollection: true,
                indent,
                lineStart,
                parent: this
              }, offset);
              if (!node)
                return offset;
              this.items.push(node);
              this.valueRange.end = node.valueRange.end;
              offset = PlainValue.Node.normalizeOffset(src, node.range.end);
              ch = src[offset];
              atLineStart = false;
              prevIncludesTrailingLines = node.includesTrailingLines;
              if (ch) {
                let ls = offset - 1;
                let prev = src[ls];
                while (prev === " " || prev === "	")
                  prev = src[--ls];
                if (prev === "\n") {
                  lineStart = ls + 1;
                  atLineStart = true;
                }
              }
              const ec = grabCollectionEndComments(node);
              if (ec)
                Array.prototype.push.apply(this.items, ec);
            }
            return offset;
          }
          setOrigRanges(cr, offset) {
            offset = super.setOrigRanges(cr, offset);
            this.items.forEach((node) => {
              offset = node.setOrigRanges(cr, offset);
            });
            return offset;
          }
          toString() {
            const {
              context: {
                src
              },
              items,
              range,
              value: value2
            } = this;
            if (value2 != null)
              return value2;
            let str = src.slice(range.start, items[0].range.start) + String(items[0]);
            for (let i = 1; i < items.length; ++i) {
              const item = items[i];
              const {
                atLineStart,
                indent
              } = item.context;
              if (atLineStart)
                for (let i2 = 0; i2 < indent; ++i2)
                  str += " ";
              str += String(item);
            }
            return PlainValue.Node.addStringTerminator(src, range.end, str);
          }
        };
        var Directive = class extends PlainValue.Node {
          constructor() {
            super(PlainValue.Type.DIRECTIVE);
            this.name = null;
          }
          get parameters() {
            const raw = this.rawValue;
            return raw ? raw.trim().split(/[ \t]+/) : [];
          }
          parseName(start) {
            const {
              src
            } = this.context;
            let offset = start;
            let ch = src[offset];
            while (ch && ch !== "\n" && ch !== "	" && ch !== " ")
              ch = src[offset += 1];
            this.name = src.slice(start, offset);
            return offset;
          }
          parseParameters(start) {
            const {
              src
            } = this.context;
            let offset = start;
            let ch = src[offset];
            while (ch && ch !== "\n" && ch !== "#")
              ch = src[offset += 1];
            this.valueRange = new PlainValue.Range(start, offset);
            return offset;
          }
          parse(context, start) {
            this.context = context;
            let offset = this.parseName(start + 1);
            offset = this.parseParameters(offset);
            offset = this.parseComment(offset);
            this.range = new PlainValue.Range(start, offset);
            return offset;
          }
        };
        var Document = class extends PlainValue.Node {
          static startCommentOrEndBlankLine(src, start) {
            const offset = PlainValue.Node.endOfWhiteSpace(src, start);
            const ch = src[offset];
            return ch === "#" || ch === "\n" ? offset : start;
          }
          constructor() {
            super(PlainValue.Type.DOCUMENT);
            this.directives = null;
            this.contents = null;
            this.directivesEndMarker = null;
            this.documentEndMarker = null;
          }
          parseDirectives(start) {
            const {
              src
            } = this.context;
            this.directives = [];
            let atLineStart = true;
            let hasDirectives = false;
            let offset = start;
            while (!PlainValue.Node.atDocumentBoundary(src, offset, PlainValue.Char.DIRECTIVES_END)) {
              offset = Document.startCommentOrEndBlankLine(src, offset);
              switch (src[offset]) {
                case "\n":
                  if (atLineStart) {
                    const blankLine = new BlankLine();
                    offset = blankLine.parse({
                      src
                    }, offset);
                    if (offset < src.length) {
                      this.directives.push(blankLine);
                    }
                  } else {
                    offset += 1;
                    atLineStart = true;
                  }
                  break;
                case "#":
                  {
                    const comment = new Comment();
                    offset = comment.parse({
                      src
                    }, offset);
                    this.directives.push(comment);
                    atLineStart = false;
                  }
                  break;
                case "%":
                  {
                    const directive = new Directive();
                    offset = directive.parse({
                      parent: this,
                      src
                    }, offset);
                    this.directives.push(directive);
                    hasDirectives = true;
                    atLineStart = false;
                  }
                  break;
                default:
                  if (hasDirectives) {
                    this.error = new PlainValue.YAMLSemanticError(this, "Missing directives-end indicator line");
                  } else if (this.directives.length > 0) {
                    this.contents = this.directives;
                    this.directives = [];
                  }
                  return offset;
              }
            }
            if (src[offset]) {
              this.directivesEndMarker = new PlainValue.Range(offset, offset + 3);
              return offset + 3;
            }
            if (hasDirectives) {
              this.error = new PlainValue.YAMLSemanticError(this, "Missing directives-end indicator line");
            } else if (this.directives.length > 0) {
              this.contents = this.directives;
              this.directives = [];
            }
            return offset;
          }
          parseContents(start) {
            const {
              parseNode,
              src
            } = this.context;
            if (!this.contents)
              this.contents = [];
            let lineStart = start;
            while (src[lineStart - 1] === "-")
              lineStart -= 1;
            let offset = PlainValue.Node.endOfWhiteSpace(src, start);
            let atLineStart = lineStart === start;
            this.valueRange = new PlainValue.Range(offset);
            while (!PlainValue.Node.atDocumentBoundary(src, offset, PlainValue.Char.DOCUMENT_END)) {
              switch (src[offset]) {
                case "\n":
                  if (atLineStart) {
                    const blankLine = new BlankLine();
                    offset = blankLine.parse({
                      src
                    }, offset);
                    if (offset < src.length) {
                      this.contents.push(blankLine);
                    }
                  } else {
                    offset += 1;
                    atLineStart = true;
                  }
                  lineStart = offset;
                  break;
                case "#":
                  {
                    const comment = new Comment();
                    offset = comment.parse({
                      src
                    }, offset);
                    this.contents.push(comment);
                    atLineStart = false;
                  }
                  break;
                default: {
                  const iEnd = PlainValue.Node.endOfIndent(src, offset);
                  const context = {
                    atLineStart,
                    indent: -1,
                    inFlow: false,
                    inCollection: false,
                    lineStart,
                    parent: this
                  };
                  const node = parseNode(context, iEnd);
                  if (!node)
                    return this.valueRange.end = iEnd;
                  this.contents.push(node);
                  offset = node.range.end;
                  atLineStart = false;
                  const ec = grabCollectionEndComments(node);
                  if (ec)
                    Array.prototype.push.apply(this.contents, ec);
                }
              }
              offset = Document.startCommentOrEndBlankLine(src, offset);
            }
            this.valueRange.end = offset;
            if (src[offset]) {
              this.documentEndMarker = new PlainValue.Range(offset, offset + 3);
              offset += 3;
              if (src[offset]) {
                offset = PlainValue.Node.endOfWhiteSpace(src, offset);
                if (src[offset] === "#") {
                  const comment = new Comment();
                  offset = comment.parse({
                    src
                  }, offset);
                  this.contents.push(comment);
                }
                switch (src[offset]) {
                  case "\n":
                    offset += 1;
                    break;
                  case void 0:
                    break;
                  default:
                    this.error = new PlainValue.YAMLSyntaxError(this, "Document end marker line cannot have a non-comment suffix");
                }
              }
            }
            return offset;
          }
          parse(context, start) {
            context.root = this;
            this.context = context;
            const {
              src
            } = context;
            let offset = src.charCodeAt(start) === 65279 ? start + 1 : start;
            offset = this.parseDirectives(offset);
            offset = this.parseContents(offset);
            return offset;
          }
          setOrigRanges(cr, offset) {
            offset = super.setOrigRanges(cr, offset);
            this.directives.forEach((node) => {
              offset = node.setOrigRanges(cr, offset);
            });
            if (this.directivesEndMarker)
              offset = this.directivesEndMarker.setOrigRange(cr, offset);
            this.contents.forEach((node) => {
              offset = node.setOrigRanges(cr, offset);
            });
            if (this.documentEndMarker)
              offset = this.documentEndMarker.setOrigRange(cr, offset);
            return offset;
          }
          toString() {
            const {
              contents,
              directives,
              value: value2
            } = this;
            if (value2 != null)
              return value2;
            let str = directives.join("");
            if (contents.length > 0) {
              if (directives.length > 0 || contents[0].type === PlainValue.Type.COMMENT)
                str += "---\n";
              str += contents.join("");
            }
            if (str[str.length - 1] !== "\n")
              str += "\n";
            return str;
          }
        };
        var Alias = class extends PlainValue.Node {
          parse(context, start) {
            this.context = context;
            const {
              src
            } = context;
            let offset = PlainValue.Node.endOfIdentifier(src, start + 1);
            this.valueRange = new PlainValue.Range(start + 1, offset);
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            offset = this.parseComment(offset);
            return offset;
          }
        };
        var Chomp = {
          CLIP: "CLIP",
          KEEP: "KEEP",
          STRIP: "STRIP"
        };
        var BlockValue = class extends PlainValue.Node {
          constructor(type, props) {
            super(type, props);
            this.blockIndent = null;
            this.chomping = Chomp.CLIP;
            this.header = null;
          }
          get includesTrailingLines() {
            return this.chomping === Chomp.KEEP;
          }
          get strValue() {
            if (!this.valueRange || !this.context)
              return null;
            let {
              start,
              end
            } = this.valueRange;
            const {
              indent,
              src
            } = this.context;
            if (this.valueRange.isEmpty())
              return "";
            let lastNewLine = null;
            let ch = src[end - 1];
            while (ch === "\n" || ch === "	" || ch === " ") {
              end -= 1;
              if (end <= start) {
                if (this.chomping === Chomp.KEEP)
                  break;
                else
                  return "";
              }
              if (ch === "\n")
                lastNewLine = end;
              ch = src[end - 1];
            }
            let keepStart = end + 1;
            if (lastNewLine) {
              if (this.chomping === Chomp.KEEP) {
                keepStart = lastNewLine;
                end = this.valueRange.end;
              } else {
                end = lastNewLine;
              }
            }
            const bi = indent + this.blockIndent;
            const folded = this.type === PlainValue.Type.BLOCK_FOLDED;
            let atStart = true;
            let str = "";
            let sep = "";
            let prevMoreIndented = false;
            for (let i = start; i < end; ++i) {
              for (let j = 0; j < bi; ++j) {
                if (src[i] !== " ")
                  break;
                i += 1;
              }
              const ch2 = src[i];
              if (ch2 === "\n") {
                if (sep === "\n")
                  str += "\n";
                else
                  sep = "\n";
              } else {
                const lineEnd = PlainValue.Node.endOfLine(src, i);
                const line = src.slice(i, lineEnd);
                i = lineEnd;
                if (folded && (ch2 === " " || ch2 === "	") && i < keepStart) {
                  if (sep === " ")
                    sep = "\n";
                  else if (!prevMoreIndented && !atStart && sep === "\n")
                    sep = "\n\n";
                  str += sep + line;
                  sep = lineEnd < end && src[lineEnd] || "";
                  prevMoreIndented = true;
                } else {
                  str += sep + line;
                  sep = folded && i < keepStart ? " " : "\n";
                  prevMoreIndented = false;
                }
                if (atStart && line !== "")
                  atStart = false;
              }
            }
            return this.chomping === Chomp.STRIP ? str : str + "\n";
          }
          parseBlockHeader(start) {
            const {
              src
            } = this.context;
            let offset = start + 1;
            let bi = "";
            while (true) {
              const ch = src[offset];
              switch (ch) {
                case "-":
                  this.chomping = Chomp.STRIP;
                  break;
                case "+":
                  this.chomping = Chomp.KEEP;
                  break;
                case "0":
                case "1":
                case "2":
                case "3":
                case "4":
                case "5":
                case "6":
                case "7":
                case "8":
                case "9":
                  bi += ch;
                  break;
                default:
                  this.blockIndent = Number(bi) || null;
                  this.header = new PlainValue.Range(start, offset);
                  return offset;
              }
              offset += 1;
            }
          }
          parseBlockValue(start) {
            const {
              indent,
              src
            } = this.context;
            const explicit = !!this.blockIndent;
            let offset = start;
            let valueEnd = start;
            let minBlockIndent = 1;
            for (let ch = src[offset]; ch === "\n"; ch = src[offset]) {
              offset += 1;
              if (PlainValue.Node.atDocumentBoundary(src, offset))
                break;
              const end = PlainValue.Node.endOfBlockIndent(src, indent, offset);
              if (end === null)
                break;
              const ch2 = src[end];
              const lineIndent = end - (offset + indent);
              if (!this.blockIndent) {
                if (src[end] !== "\n") {
                  if (lineIndent < minBlockIndent) {
                    const msg = "Block scalars with more-indented leading empty lines must use an explicit indentation indicator";
                    this.error = new PlainValue.YAMLSemanticError(this, msg);
                  }
                  this.blockIndent = lineIndent;
                } else if (lineIndent > minBlockIndent) {
                  minBlockIndent = lineIndent;
                }
              } else if (ch2 && ch2 !== "\n" && lineIndent < this.blockIndent) {
                if (src[end] === "#")
                  break;
                if (!this.error) {
                  const src2 = explicit ? "explicit indentation indicator" : "first line";
                  const msg = `Block scalars must not be less indented than their ${src2}`;
                  this.error = new PlainValue.YAMLSemanticError(this, msg);
                }
              }
              if (src[end] === "\n") {
                offset = end;
              } else {
                offset = valueEnd = PlainValue.Node.endOfLine(src, end);
              }
            }
            if (this.chomping !== Chomp.KEEP) {
              offset = src[valueEnd] ? valueEnd + 1 : valueEnd;
            }
            this.valueRange = new PlainValue.Range(start + 1, offset);
            return offset;
          }
          parse(context, start) {
            this.context = context;
            const {
              src
            } = context;
            let offset = this.parseBlockHeader(start);
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            offset = this.parseComment(offset);
            offset = this.parseBlockValue(offset);
            return offset;
          }
          setOrigRanges(cr, offset) {
            offset = super.setOrigRanges(cr, offset);
            return this.header ? this.header.setOrigRange(cr, offset) : offset;
          }
        };
        var FlowCollection = class extends PlainValue.Node {
          constructor(type, props) {
            super(type, props);
            this.items = null;
          }
          prevNodeIsJsonLike(idx = this.items.length) {
            const node = this.items[idx - 1];
            return !!node && (node.jsonLike || node.type === PlainValue.Type.COMMENT && this.prevNodeIsJsonLike(idx - 1));
          }
          parse(context, start) {
            this.context = context;
            const {
              parseNode,
              src
            } = context;
            let {
              indent,
              lineStart
            } = context;
            let char = src[start];
            this.items = [{
              char,
              offset: start
            }];
            let offset = PlainValue.Node.endOfWhiteSpace(src, start + 1);
            char = src[offset];
            while (char && char !== "]" && char !== "}") {
              switch (char) {
                case "\n":
                  {
                    lineStart = offset + 1;
                    const wsEnd = PlainValue.Node.endOfWhiteSpace(src, lineStart);
                    if (src[wsEnd] === "\n") {
                      const blankLine = new BlankLine();
                      lineStart = blankLine.parse({
                        src
                      }, lineStart);
                      this.items.push(blankLine);
                    }
                    offset = PlainValue.Node.endOfIndent(src, lineStart);
                    if (offset <= lineStart + indent) {
                      char = src[offset];
                      if (offset < lineStart + indent || char !== "]" && char !== "}") {
                        const msg = "Insufficient indentation in flow collection";
                        this.error = new PlainValue.YAMLSemanticError(this, msg);
                      }
                    }
                  }
                  break;
                case ",":
                  {
                    this.items.push({
                      char,
                      offset
                    });
                    offset += 1;
                  }
                  break;
                case "#":
                  {
                    const comment = new Comment();
                    offset = comment.parse({
                      src
                    }, offset);
                    this.items.push(comment);
                  }
                  break;
                case "?":
                case ":": {
                  const next = src[offset + 1];
                  if (next === "\n" || next === "	" || next === " " || next === "," || char === ":" && this.prevNodeIsJsonLike()) {
                    this.items.push({
                      char,
                      offset
                    });
                    offset += 1;
                    break;
                  }
                }
                default: {
                  const node = parseNode({
                    atLineStart: false,
                    inCollection: false,
                    inFlow: true,
                    indent: -1,
                    lineStart,
                    parent: this
                  }, offset);
                  if (!node) {
                    this.valueRange = new PlainValue.Range(start, offset);
                    return offset;
                  }
                  this.items.push(node);
                  offset = PlainValue.Node.normalizeOffset(src, node.range.end);
                }
              }
              offset = PlainValue.Node.endOfWhiteSpace(src, offset);
              char = src[offset];
            }
            this.valueRange = new PlainValue.Range(start, offset + 1);
            if (char) {
              this.items.push({
                char,
                offset
              });
              offset = PlainValue.Node.endOfWhiteSpace(src, offset + 1);
              offset = this.parseComment(offset);
            }
            return offset;
          }
          setOrigRanges(cr, offset) {
            offset = super.setOrigRanges(cr, offset);
            this.items.forEach((node) => {
              if (node instanceof PlainValue.Node) {
                offset = node.setOrigRanges(cr, offset);
              } else if (cr.length === 0) {
                node.origOffset = node.offset;
              } else {
                let i = offset;
                while (i < cr.length) {
                  if (cr[i] > node.offset)
                    break;
                  else
                    ++i;
                }
                node.origOffset = node.offset + i;
                offset = i;
              }
            });
            return offset;
          }
          toString() {
            const {
              context: {
                src
              },
              items,
              range,
              value: value2
            } = this;
            if (value2 != null)
              return value2;
            const nodes = items.filter((item) => item instanceof PlainValue.Node);
            let str = "";
            let prevEnd = range.start;
            nodes.forEach((node) => {
              const prefix = src.slice(prevEnd, node.range.start);
              prevEnd = node.range.end;
              str += prefix + String(node);
              if (str[str.length - 1] === "\n" && src[prevEnd - 1] !== "\n" && src[prevEnd] === "\n") {
                prevEnd += 1;
              }
            });
            str += src.slice(prevEnd, range.end);
            return PlainValue.Node.addStringTerminator(src, range.end, str);
          }
        };
        var QuoteDouble = class extends PlainValue.Node {
          static endOfQuote(src, offset) {
            let ch = src[offset];
            while (ch && ch !== '"') {
              offset += ch === "\\" ? 2 : 1;
              ch = src[offset];
            }
            return offset + 1;
          }
          get strValue() {
            if (!this.valueRange || !this.context)
              return null;
            const errors = [];
            const {
              start,
              end
            } = this.valueRange;
            const {
              indent,
              src
            } = this.context;
            if (src[end - 1] !== '"')
              errors.push(new PlainValue.YAMLSyntaxError(this, 'Missing closing "quote'));
            let str = "";
            for (let i = start + 1; i < end - 1; ++i) {
              const ch = src[i];
              if (ch === "\n") {
                if (PlainValue.Node.atDocumentBoundary(src, i + 1))
                  errors.push(new PlainValue.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
                const {
                  fold,
                  offset,
                  error
                } = PlainValue.Node.foldNewline(src, i, indent);
                str += fold;
                i = offset;
                if (error)
                  errors.push(new PlainValue.YAMLSemanticError(this, "Multi-line double-quoted string needs to be sufficiently indented"));
              } else if (ch === "\\") {
                i += 1;
                switch (src[i]) {
                  case "0":
                    str += "\0";
                    break;
                  case "a":
                    str += "\x07";
                    break;
                  case "b":
                    str += "\b";
                    break;
                  case "e":
                    str += "\x1B";
                    break;
                  case "f":
                    str += "\f";
                    break;
                  case "n":
                    str += "\n";
                    break;
                  case "r":
                    str += "\r";
                    break;
                  case "t":
                    str += "	";
                    break;
                  case "v":
                    str += "\v";
                    break;
                  case "N":
                    str += "\x85";
                    break;
                  case "_":
                    str += "\xA0";
                    break;
                  case "L":
                    str += "\u2028";
                    break;
                  case "P":
                    str += "\u2029";
                    break;
                  case " ":
                    str += " ";
                    break;
                  case '"':
                    str += '"';
                    break;
                  case "/":
                    str += "/";
                    break;
                  case "\\":
                    str += "\\";
                    break;
                  case "	":
                    str += "	";
                    break;
                  case "x":
                    str += this.parseCharCode(i + 1, 2, errors);
                    i += 2;
                    break;
                  case "u":
                    str += this.parseCharCode(i + 1, 4, errors);
                    i += 4;
                    break;
                  case "U":
                    str += this.parseCharCode(i + 1, 8, errors);
                    i += 8;
                    break;
                  case "\n":
                    while (src[i + 1] === " " || src[i + 1] === "	")
                      i += 1;
                    break;
                  default:
                    errors.push(new PlainValue.YAMLSyntaxError(this, `Invalid escape sequence ${src.substr(i - 1, 2)}`));
                    str += "\\" + src[i];
                }
              } else if (ch === " " || ch === "	") {
                const wsStart = i;
                let next = src[i + 1];
                while (next === " " || next === "	") {
                  i += 1;
                  next = src[i + 1];
                }
                if (next !== "\n")
                  str += i > wsStart ? src.slice(wsStart, i + 1) : ch;
              } else {
                str += ch;
              }
            }
            return errors.length > 0 ? {
              errors,
              str
            } : str;
          }
          parseCharCode(offset, length, errors) {
            const {
              src
            } = this.context;
            const cc = src.substr(offset, length);
            const ok = cc.length === length && /^[0-9a-fA-F]+$/.test(cc);
            const code = ok ? parseInt(cc, 16) : NaN;
            if (isNaN(code)) {
              errors.push(new PlainValue.YAMLSyntaxError(this, `Invalid escape sequence ${src.substr(offset - 2, length + 2)}`));
              return src.substr(offset - 2, length + 2);
            }
            return String.fromCodePoint(code);
          }
          parse(context, start) {
            this.context = context;
            const {
              src
            } = context;
            let offset = QuoteDouble.endOfQuote(src, start + 1);
            this.valueRange = new PlainValue.Range(start, offset);
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            offset = this.parseComment(offset);
            return offset;
          }
        };
        var QuoteSingle = class extends PlainValue.Node {
          static endOfQuote(src, offset) {
            let ch = src[offset];
            while (ch) {
              if (ch === "'") {
                if (src[offset + 1] !== "'")
                  break;
                ch = src[offset += 2];
              } else {
                ch = src[offset += 1];
              }
            }
            return offset + 1;
          }
          get strValue() {
            if (!this.valueRange || !this.context)
              return null;
            const errors = [];
            const {
              start,
              end
            } = this.valueRange;
            const {
              indent,
              src
            } = this.context;
            if (src[end - 1] !== "'")
              errors.push(new PlainValue.YAMLSyntaxError(this, "Missing closing 'quote"));
            let str = "";
            for (let i = start + 1; i < end - 1; ++i) {
              const ch = src[i];
              if (ch === "\n") {
                if (PlainValue.Node.atDocumentBoundary(src, i + 1))
                  errors.push(new PlainValue.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
                const {
                  fold,
                  offset,
                  error
                } = PlainValue.Node.foldNewline(src, i, indent);
                str += fold;
                i = offset;
                if (error)
                  errors.push(new PlainValue.YAMLSemanticError(this, "Multi-line single-quoted string needs to be sufficiently indented"));
              } else if (ch === "'") {
                str += ch;
                i += 1;
                if (src[i] !== "'")
                  errors.push(new PlainValue.YAMLSyntaxError(this, "Unescaped single quote? This should not happen."));
              } else if (ch === " " || ch === "	") {
                const wsStart = i;
                let next = src[i + 1];
                while (next === " " || next === "	") {
                  i += 1;
                  next = src[i + 1];
                }
                if (next !== "\n")
                  str += i > wsStart ? src.slice(wsStart, i + 1) : ch;
              } else {
                str += ch;
              }
            }
            return errors.length > 0 ? {
              errors,
              str
            } : str;
          }
          parse(context, start) {
            this.context = context;
            const {
              src
            } = context;
            let offset = QuoteSingle.endOfQuote(src, start + 1);
            this.valueRange = new PlainValue.Range(start, offset);
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            offset = this.parseComment(offset);
            return offset;
          }
        };
        function createNewNode(type, props) {
          switch (type) {
            case PlainValue.Type.ALIAS:
              return new Alias(type, props);
            case PlainValue.Type.BLOCK_FOLDED:
            case PlainValue.Type.BLOCK_LITERAL:
              return new BlockValue(type, props);
            case PlainValue.Type.FLOW_MAP:
            case PlainValue.Type.FLOW_SEQ:
              return new FlowCollection(type, props);
            case PlainValue.Type.MAP_KEY:
            case PlainValue.Type.MAP_VALUE:
            case PlainValue.Type.SEQ_ITEM:
              return new CollectionItem(type, props);
            case PlainValue.Type.COMMENT:
            case PlainValue.Type.PLAIN:
              return new PlainValue.PlainValue(type, props);
            case PlainValue.Type.QUOTE_DOUBLE:
              return new QuoteDouble(type, props);
            case PlainValue.Type.QUOTE_SINGLE:
              return new QuoteSingle(type, props);
            default:
              return null;
          }
        }
        var ParseContext = class {
          static parseType(src, offset, inFlow) {
            switch (src[offset]) {
              case "*":
                return PlainValue.Type.ALIAS;
              case ">":
                return PlainValue.Type.BLOCK_FOLDED;
              case "|":
                return PlainValue.Type.BLOCK_LITERAL;
              case "{":
                return PlainValue.Type.FLOW_MAP;
              case "[":
                return PlainValue.Type.FLOW_SEQ;
              case "?":
                return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.MAP_KEY : PlainValue.Type.PLAIN;
              case ":":
                return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.MAP_VALUE : PlainValue.Type.PLAIN;
              case "-":
                return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.SEQ_ITEM : PlainValue.Type.PLAIN;
              case '"':
                return PlainValue.Type.QUOTE_DOUBLE;
              case "'":
                return PlainValue.Type.QUOTE_SINGLE;
              default:
                return PlainValue.Type.PLAIN;
            }
          }
          constructor(orig = {}, {
            atLineStart,
            inCollection,
            inFlow,
            indent,
            lineStart,
            parent
          } = {}) {
            PlainValue._defineProperty(this, "parseNode", (overlay, start) => {
              if (PlainValue.Node.atDocumentBoundary(this.src, start))
                return null;
              const context = new ParseContext(this, overlay);
              const {
                props,
                type,
                valueStart
              } = context.parseProps(start);
              const node = createNewNode(type, props);
              let offset = node.parse(context, valueStart);
              node.range = new PlainValue.Range(start, offset);
              if (offset <= start) {
                node.error = new Error(`Node#parse consumed no characters`);
                node.error.parseEnd = offset;
                node.error.source = node;
                node.range.end = start + 1;
              }
              if (context.nodeStartsCollection(node)) {
                if (!node.error && !context.atLineStart && context.parent.type === PlainValue.Type.DOCUMENT) {
                  node.error = new PlainValue.YAMLSyntaxError(node, "Block collection must not have preceding content here (e.g. directives-end indicator)");
                }
                const collection = new Collection(node);
                offset = collection.parse(new ParseContext(context), offset);
                collection.range = new PlainValue.Range(start, offset);
                return collection;
              }
              return node;
            });
            this.atLineStart = atLineStart != null ? atLineStart : orig.atLineStart || false;
            this.inCollection = inCollection != null ? inCollection : orig.inCollection || false;
            this.inFlow = inFlow != null ? inFlow : orig.inFlow || false;
            this.indent = indent != null ? indent : orig.indent;
            this.lineStart = lineStart != null ? lineStart : orig.lineStart;
            this.parent = parent != null ? parent : orig.parent || {};
            this.root = orig.root;
            this.src = orig.src;
          }
          nodeStartsCollection(node) {
            const {
              inCollection,
              inFlow,
              src
            } = this;
            if (inCollection || inFlow)
              return false;
            if (node instanceof CollectionItem)
              return true;
            let offset = node.range.end;
            if (src[offset] === "\n" || src[offset - 1] === "\n")
              return false;
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            return src[offset] === ":";
          }
          parseProps(offset) {
            const {
              inFlow,
              parent,
              src
            } = this;
            const props = [];
            let lineHasProps = false;
            offset = this.atLineStart ? PlainValue.Node.endOfIndent(src, offset) : PlainValue.Node.endOfWhiteSpace(src, offset);
            let ch = src[offset];
            while (ch === PlainValue.Char.ANCHOR || ch === PlainValue.Char.COMMENT || ch === PlainValue.Char.TAG || ch === "\n") {
              if (ch === "\n") {
                let inEnd = offset;
                let lineStart;
                do {
                  lineStart = inEnd + 1;
                  inEnd = PlainValue.Node.endOfIndent(src, lineStart);
                } while (src[inEnd] === "\n");
                const indentDiff = inEnd - (lineStart + this.indent);
                const noIndicatorAsIndent = parent.type === PlainValue.Type.SEQ_ITEM && parent.context.atLineStart;
                if (src[inEnd] !== "#" && !PlainValue.Node.nextNodeIsIndented(src[inEnd], indentDiff, !noIndicatorAsIndent))
                  break;
                this.atLineStart = true;
                this.lineStart = lineStart;
                lineHasProps = false;
                offset = inEnd;
              } else if (ch === PlainValue.Char.COMMENT) {
                const end = PlainValue.Node.endOfLine(src, offset + 1);
                props.push(new PlainValue.Range(offset, end));
                offset = end;
              } else {
                let end = PlainValue.Node.endOfIdentifier(src, offset + 1);
                if (ch === PlainValue.Char.TAG && src[end] === "," && /^[a-zA-Z0-9-]+\.[a-zA-Z0-9-]+,\d\d\d\d(-\d\d){0,2}\/\S/.test(src.slice(offset + 1, end + 13))) {
                  end = PlainValue.Node.endOfIdentifier(src, end + 5);
                }
                props.push(new PlainValue.Range(offset, end));
                lineHasProps = true;
                offset = PlainValue.Node.endOfWhiteSpace(src, end);
              }
              ch = src[offset];
            }
            if (lineHasProps && ch === ":" && PlainValue.Node.atBlank(src, offset + 1, true))
              offset -= 1;
            const type = ParseContext.parseType(src, offset, inFlow);
            return {
              props,
              type,
              valueStart: offset
            };
          }
        };
        function parse3(src) {
          const cr = [];
          if (src.indexOf("\r") !== -1) {
            src = src.replace(/\r\n?/g, (match, offset2) => {
              if (match.length > 1)
                cr.push(offset2);
              return "\n";
            });
          }
          const documents = [];
          let offset = 0;
          do {
            const doc = new Document();
            const context = new ParseContext({
              src
            });
            offset = doc.parse(context, offset);
            documents.push(doc);
          } while (offset < src.length);
          documents.setOrigRanges = () => {
            if (cr.length === 0)
              return false;
            for (let i = 1; i < cr.length; ++i)
              cr[i] -= i;
            let crOffset = 0;
            for (let i = 0; i < documents.length; ++i) {
              crOffset = documents[i].setOrigRanges(cr, crOffset);
            }
            cr.splice(0, cr.length);
            return true;
          };
          documents.toString = () => documents.join("...\n");
          return documents;
        }
        exports2.parse = parse3;
      }
    });
    var require_resolveSeq_d03cb037 = __commonJS2({
      "node_modules/yaml/dist/resolveSeq-d03cb037.js"(exports2) {
        "use strict";
        var PlainValue = require_PlainValue_ec8e588e();
        function addCommentBefore(str, indent, comment) {
          if (!comment)
            return str;
          const cc = comment.replace(/[\s\S]^/gm, `$&${indent}#`);
          return `#${cc}
${indent}${str}`;
        }
        function addComment(str, indent, comment) {
          return !comment ? str : comment.indexOf("\n") === -1 ? `${str} #${comment}` : `${str}
` + comment.replace(/^/gm, `${indent || ""}#`);
        }
        var Node2 = class {
        };
        function toJSON(value2, arg, ctx) {
          if (Array.isArray(value2))
            return value2.map((v, i) => toJSON(v, String(i), ctx));
          if (value2 && typeof value2.toJSON === "function") {
            const anchor = ctx && ctx.anchors && ctx.anchors.get(value2);
            if (anchor)
              ctx.onCreate = (res2) => {
                anchor.res = res2;
                delete ctx.onCreate;
              };
            const res = value2.toJSON(arg, ctx);
            if (anchor && ctx.onCreate)
              ctx.onCreate(res);
            return res;
          }
          if ((!ctx || !ctx.keep) && typeof value2 === "bigint")
            return Number(value2);
          return value2;
        }
        var Scalar = class extends Node2 {
          constructor(value2) {
            super();
            this.value = value2;
          }
          toJSON(arg, ctx) {
            return ctx && ctx.keep ? this.value : toJSON(this.value, arg, ctx);
          }
          toString() {
            return String(this.value);
          }
        };
        function collectionFromPath(schema, path2, value2) {
          let v = value2;
          for (let i = path2.length - 1; i >= 0; --i) {
            const k = path2[i];
            if (Number.isInteger(k) && k >= 0) {
              const a = [];
              a[k] = v;
              v = a;
            } else {
              const o = {};
              Object.defineProperty(o, k, {
                value: v,
                writable: true,
                enumerable: true,
                configurable: true
              });
              v = o;
            }
          }
          return schema.createNode(v, false);
        }
        var isEmptyPath = (path2) => path2 == null || typeof path2 === "object" && path2[Symbol.iterator]().next().done;
        var Collection = class extends Node2 {
          constructor(schema) {
            super();
            PlainValue._defineProperty(this, "items", []);
            this.schema = schema;
          }
          addIn(path2, value2) {
            if (isEmptyPath(path2))
              this.add(value2);
            else {
              const [key, ...rest] = path2;
              const node = this.get(key, true);
              if (node instanceof Collection)
                node.addIn(rest, value2);
              else if (node === void 0 && this.schema)
                this.set(key, collectionFromPath(this.schema, rest, value2));
              else
                throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
            }
          }
          deleteIn([key, ...rest]) {
            if (rest.length === 0)
              return this.delete(key);
            const node = this.get(key, true);
            if (node instanceof Collection)
              return node.deleteIn(rest);
            else
              throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
          }
          getIn([key, ...rest], keepScalar) {
            const node = this.get(key, true);
            if (rest.length === 0)
              return !keepScalar && node instanceof Scalar ? node.value : node;
            else
              return node instanceof Collection ? node.getIn(rest, keepScalar) : void 0;
          }
          hasAllNullValues() {
            return this.items.every((node) => {
              if (!node || node.type !== "PAIR")
                return false;
              const n = node.value;
              return n == null || n instanceof Scalar && n.value == null && !n.commentBefore && !n.comment && !n.tag;
            });
          }
          hasIn([key, ...rest]) {
            if (rest.length === 0)
              return this.has(key);
            const node = this.get(key, true);
            return node instanceof Collection ? node.hasIn(rest) : false;
          }
          setIn([key, ...rest], value2) {
            if (rest.length === 0) {
              this.set(key, value2);
            } else {
              const node = this.get(key, true);
              if (node instanceof Collection)
                node.setIn(rest, value2);
              else if (node === void 0 && this.schema)
                this.set(key, collectionFromPath(this.schema, rest, value2));
              else
                throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
            }
          }
          toJSON() {
            return null;
          }
          toString(ctx, {
            blockItem,
            flowChars,
            isMap,
            itemIndent
          }, onComment, onChompKeep) {
            const {
              indent,
              indentStep,
              stringify
            } = ctx;
            const inFlow = this.type === PlainValue.Type.FLOW_MAP || this.type === PlainValue.Type.FLOW_SEQ || ctx.inFlow;
            if (inFlow)
              itemIndent += indentStep;
            const allNullValues = isMap && this.hasAllNullValues();
            ctx = Object.assign({}, ctx, {
              allNullValues,
              indent: itemIndent,
              inFlow,
              type: null
            });
            let chompKeep = false;
            let hasItemWithNewLine = false;
            const nodes = this.items.reduce((nodes2, item, i) => {
              let comment;
              if (item) {
                if (!chompKeep && item.spaceBefore)
                  nodes2.push({
                    type: "comment",
                    str: ""
                  });
                if (item.commentBefore)
                  item.commentBefore.match(/^.*$/gm).forEach((line) => {
                    nodes2.push({
                      type: "comment",
                      str: `#${line}`
                    });
                  });
                if (item.comment)
                  comment = item.comment;
                if (inFlow && (!chompKeep && item.spaceBefore || item.commentBefore || item.comment || item.key && (item.key.commentBefore || item.key.comment) || item.value && (item.value.commentBefore || item.value.comment)))
                  hasItemWithNewLine = true;
              }
              chompKeep = false;
              let str2 = stringify(item, ctx, () => comment = null, () => chompKeep = true);
              if (inFlow && !hasItemWithNewLine && str2.includes("\n"))
                hasItemWithNewLine = true;
              if (inFlow && i < this.items.length - 1)
                str2 += ",";
              str2 = addComment(str2, itemIndent, comment);
              if (chompKeep && (comment || inFlow))
                chompKeep = false;
              nodes2.push({
                type: "item",
                str: str2
              });
              return nodes2;
            }, []);
            let str;
            if (nodes.length === 0) {
              str = flowChars.start + flowChars.end;
            } else if (inFlow) {
              const {
                start,
                end
              } = flowChars;
              const strings = nodes.map((n) => n.str);
              if (hasItemWithNewLine || strings.reduce((sum, str2) => sum + str2.length + 2, 2) > Collection.maxFlowStringSingleLineLength) {
                str = start;
                for (const s of strings) {
                  str += s ? `
${indentStep}${indent}${s}` : "\n";
                }
                str += `
${indent}${end}`;
              } else {
                str = `${start} ${strings.join(" ")} ${end}`;
              }
            } else {
              const strings = nodes.map(blockItem);
              str = strings.shift();
              for (const s of strings)
                str += s ? `
${indent}${s}` : "\n";
            }
            if (this.comment) {
              str += "\n" + this.comment.replace(/^/gm, `${indent}#`);
              if (onComment)
                onComment();
            } else if (chompKeep && onChompKeep)
              onChompKeep();
            return str;
          }
        };
        PlainValue._defineProperty(Collection, "maxFlowStringSingleLineLength", 60);
        function asItemIndex(key) {
          let idx = key instanceof Scalar ? key.value : key;
          if (idx && typeof idx === "string")
            idx = Number(idx);
          return Number.isInteger(idx) && idx >= 0 ? idx : null;
        }
        var YAMLSeq = class extends Collection {
          add(value2) {
            this.items.push(value2);
          }
          delete(key) {
            const idx = asItemIndex(key);
            if (typeof idx !== "number")
              return false;
            const del = this.items.splice(idx, 1);
            return del.length > 0;
          }
          get(key, keepScalar) {
            const idx = asItemIndex(key);
            if (typeof idx !== "number")
              return void 0;
            const it2 = this.items[idx];
            return !keepScalar && it2 instanceof Scalar ? it2.value : it2;
          }
          has(key) {
            const idx = asItemIndex(key);
            return typeof idx === "number" && idx < this.items.length;
          }
          set(key, value2) {
            const idx = asItemIndex(key);
            if (typeof idx !== "number")
              throw new Error(`Expected a valid index, not ${key}.`);
            this.items[idx] = value2;
          }
          toJSON(_, ctx) {
            const seq = [];
            if (ctx && ctx.onCreate)
              ctx.onCreate(seq);
            let i = 0;
            for (const item of this.items)
              seq.push(toJSON(item, String(i++), ctx));
            return seq;
          }
          toString(ctx, onComment, onChompKeep) {
            if (!ctx)
              return JSON.stringify(this);
            return super.toString(ctx, {
              blockItem: (n) => n.type === "comment" ? n.str : `- ${n.str}`,
              flowChars: {
                start: "[",
                end: "]"
              },
              isMap: false,
              itemIndent: (ctx.indent || "") + "  "
            }, onComment, onChompKeep);
          }
        };
        var stringifyKey = (key, jsKey, ctx) => {
          if (jsKey === null)
            return "";
          if (typeof jsKey !== "object")
            return String(jsKey);
          if (key instanceof Node2 && ctx && ctx.doc)
            return key.toString({
              anchors: /* @__PURE__ */ Object.create(null),
              doc: ctx.doc,
              indent: "",
              indentStep: ctx.indentStep,
              inFlow: true,
              inStringifyKey: true,
              stringify: ctx.stringify
            });
          return JSON.stringify(jsKey);
        };
        var Pair = class extends Node2 {
          constructor(key, value2 = null) {
            super();
            this.key = key;
            this.value = value2;
            this.type = Pair.Type.PAIR;
          }
          get commentBefore() {
            return this.key instanceof Node2 ? this.key.commentBefore : void 0;
          }
          set commentBefore(cb) {
            if (this.key == null)
              this.key = new Scalar(null);
            if (this.key instanceof Node2)
              this.key.commentBefore = cb;
            else {
              const msg = "Pair.commentBefore is an alias for Pair.key.commentBefore. To set it, the key must be a Node.";
              throw new Error(msg);
            }
          }
          addToJSMap(ctx, map) {
            const key = toJSON(this.key, "", ctx);
            if (map instanceof Map) {
              const value2 = toJSON(this.value, key, ctx);
              map.set(key, value2);
            } else if (map instanceof Set) {
              map.add(key);
            } else {
              const stringKey = stringifyKey(this.key, key, ctx);
              const value2 = toJSON(this.value, stringKey, ctx);
              if (stringKey in map)
                Object.defineProperty(map, stringKey, {
                  value: value2,
                  writable: true,
                  enumerable: true,
                  configurable: true
                });
              else
                map[stringKey] = value2;
            }
            return map;
          }
          toJSON(_, ctx) {
            const pair = ctx && ctx.mapAsMap ? /* @__PURE__ */ new Map() : {};
            return this.addToJSMap(ctx, pair);
          }
          toString(ctx, onComment, onChompKeep) {
            if (!ctx || !ctx.doc)
              return JSON.stringify(this);
            const {
              indent: indentSize,
              indentSeq,
              simpleKeys
            } = ctx.doc.options;
            let {
              key,
              value: value2
            } = this;
            let keyComment = key instanceof Node2 && key.comment;
            if (simpleKeys) {
              if (keyComment) {
                throw new Error("With simple keys, key nodes cannot have comments");
              }
              if (key instanceof Collection) {
                const msg = "With simple keys, collection cannot be used as a key value";
                throw new Error(msg);
              }
            }
            let explicitKey = !simpleKeys && (!key || keyComment || (key instanceof Node2 ? key instanceof Collection || key.type === PlainValue.Type.BLOCK_FOLDED || key.type === PlainValue.Type.BLOCK_LITERAL : typeof key === "object"));
            const {
              doc,
              indent,
              indentStep,
              stringify
            } = ctx;
            ctx = Object.assign({}, ctx, {
              implicitKey: !explicitKey,
              indent: indent + indentStep
            });
            let chompKeep = false;
            let str = stringify(key, ctx, () => keyComment = null, () => chompKeep = true);
            str = addComment(str, ctx.indent, keyComment);
            if (!explicitKey && str.length > 1024) {
              if (simpleKeys)
                throw new Error("With simple keys, single line scalar must not span more than 1024 characters");
              explicitKey = true;
            }
            if (ctx.allNullValues && !simpleKeys) {
              if (this.comment) {
                str = addComment(str, ctx.indent, this.comment);
                if (onComment)
                  onComment();
              } else if (chompKeep && !keyComment && onChompKeep)
                onChompKeep();
              return ctx.inFlow && !explicitKey ? str : `? ${str}`;
            }
            str = explicitKey ? `? ${str}
${indent}:` : `${str}:`;
            if (this.comment) {
              str = addComment(str, ctx.indent, this.comment);
              if (onComment)
                onComment();
            }
            let vcb = "";
            let valueComment = null;
            if (value2 instanceof Node2) {
              if (value2.spaceBefore)
                vcb = "\n";
              if (value2.commentBefore) {
                const cs = value2.commentBefore.replace(/^/gm, `${ctx.indent}#`);
                vcb += `
${cs}`;
              }
              valueComment = value2.comment;
            } else if (value2 && typeof value2 === "object") {
              value2 = doc.schema.createNode(value2, true);
            }
            ctx.implicitKey = false;
            if (!explicitKey && !this.comment && value2 instanceof Scalar)
              ctx.indentAtStart = str.length + 1;
            chompKeep = false;
            if (!indentSeq && indentSize >= 2 && !ctx.inFlow && !explicitKey && value2 instanceof YAMLSeq && value2.type !== PlainValue.Type.FLOW_SEQ && !value2.tag && !doc.anchors.getName(value2)) {
              ctx.indent = ctx.indent.substr(2);
            }
            const valueStr = stringify(value2, ctx, () => valueComment = null, () => chompKeep = true);
            let ws = " ";
            if (vcb || this.comment) {
              ws = `${vcb}
${ctx.indent}`;
            } else if (!explicitKey && value2 instanceof Collection) {
              const flow = valueStr[0] === "[" || valueStr[0] === "{";
              if (!flow || valueStr.includes("\n"))
                ws = `
${ctx.indent}`;
            } else if (valueStr[0] === "\n")
              ws = "";
            if (chompKeep && !valueComment && onChompKeep)
              onChompKeep();
            return addComment(str + ws + valueStr, ctx.indent, valueComment);
          }
        };
        PlainValue._defineProperty(Pair, "Type", {
          PAIR: "PAIR",
          MERGE_PAIR: "MERGE_PAIR"
        });
        var getAliasCount = (node, anchors) => {
          if (node instanceof Alias) {
            const anchor = anchors.get(node.source);
            return anchor.count * anchor.aliasCount;
          } else if (node instanceof Collection) {
            let count = 0;
            for (const item of node.items) {
              const c = getAliasCount(item, anchors);
              if (c > count)
                count = c;
            }
            return count;
          } else if (node instanceof Pair) {
            const kc = getAliasCount(node.key, anchors);
            const vc = getAliasCount(node.value, anchors);
            return Math.max(kc, vc);
          }
          return 1;
        };
        var Alias = class extends Node2 {
          static stringify({
            range,
            source
          }, {
            anchors,
            doc,
            implicitKey,
            inStringifyKey
          }) {
            let anchor = Object.keys(anchors).find((a) => anchors[a] === source);
            if (!anchor && inStringifyKey)
              anchor = doc.anchors.getName(source) || doc.anchors.newName();
            if (anchor)
              return `*${anchor}${implicitKey ? " " : ""}`;
            const msg = doc.anchors.getName(source) ? "Alias node must be after source node" : "Source node not found for alias node";
            throw new Error(`${msg} [${range}]`);
          }
          constructor(source) {
            super();
            this.source = source;
            this.type = PlainValue.Type.ALIAS;
          }
          set tag(t3) {
            throw new Error("Alias nodes cannot have tags");
          }
          toJSON(arg, ctx) {
            if (!ctx)
              return toJSON(this.source, arg, ctx);
            const {
              anchors,
              maxAliasCount
            } = ctx;
            const anchor = anchors.get(this.source);
            if (!anchor || anchor.res === void 0) {
              const msg = "This should not happen: Alias anchor was not resolved?";
              if (this.cstNode)
                throw new PlainValue.YAMLReferenceError(this.cstNode, msg);
              else
                throw new ReferenceError(msg);
            }
            if (maxAliasCount >= 0) {
              anchor.count += 1;
              if (anchor.aliasCount === 0)
                anchor.aliasCount = getAliasCount(this.source, anchors);
              if (anchor.count * anchor.aliasCount > maxAliasCount) {
                const msg = "Excessive alias count indicates a resource exhaustion attack";
                if (this.cstNode)
                  throw new PlainValue.YAMLReferenceError(this.cstNode, msg);
                else
                  throw new ReferenceError(msg);
              }
            }
            return anchor.res;
          }
          toString(ctx) {
            return Alias.stringify(this, ctx);
          }
        };
        PlainValue._defineProperty(Alias, "default", true);
        function findPair(items, key) {
          const k = key instanceof Scalar ? key.value : key;
          for (const it2 of items) {
            if (it2 instanceof Pair) {
              if (it2.key === key || it2.key === k)
                return it2;
              if (it2.key && it2.key.value === k)
                return it2;
            }
          }
          return void 0;
        }
        var YAMLMap = class extends Collection {
          add(pair, overwrite) {
            if (!pair)
              pair = new Pair(pair);
            else if (!(pair instanceof Pair))
              pair = new Pair(pair.key || pair, pair.value);
            const prev = findPair(this.items, pair.key);
            const sortEntries = this.schema && this.schema.sortMapEntries;
            if (prev) {
              if (overwrite)
                prev.value = pair.value;
              else
                throw new Error(`Key ${pair.key} already set`);
            } else if (sortEntries) {
              const i = this.items.findIndex((item) => sortEntries(pair, item) < 0);
              if (i === -1)
                this.items.push(pair);
              else
                this.items.splice(i, 0, pair);
            } else {
              this.items.push(pair);
            }
          }
          delete(key) {
            const it2 = findPair(this.items, key);
            if (!it2)
              return false;
            const del = this.items.splice(this.items.indexOf(it2), 1);
            return del.length > 0;
          }
          get(key, keepScalar) {
            const it2 = findPair(this.items, key);
            const node = it2 && it2.value;
            return !keepScalar && node instanceof Scalar ? node.value : node;
          }
          has(key) {
            return !!findPair(this.items, key);
          }
          set(key, value2) {
            this.add(new Pair(key, value2), true);
          }
          toJSON(_, ctx, Type) {
            const map = Type ? new Type() : ctx && ctx.mapAsMap ? /* @__PURE__ */ new Map() : {};
            if (ctx && ctx.onCreate)
              ctx.onCreate(map);
            for (const item of this.items)
              item.addToJSMap(ctx, map);
            return map;
          }
          toString(ctx, onComment, onChompKeep) {
            if (!ctx)
              return JSON.stringify(this);
            for (const item of this.items) {
              if (!(item instanceof Pair))
                throw new Error(`Map items must all be pairs; found ${JSON.stringify(item)} instead`);
            }
            return super.toString(ctx, {
              blockItem: (n) => n.str,
              flowChars: {
                start: "{",
                end: "}"
              },
              isMap: true,
              itemIndent: ctx.indent || ""
            }, onComment, onChompKeep);
          }
        };
        var MERGE_KEY = "<<";
        var Merge = class extends Pair {
          constructor(pair) {
            if (pair instanceof Pair) {
              let seq = pair.value;
              if (!(seq instanceof YAMLSeq)) {
                seq = new YAMLSeq();
                seq.items.push(pair.value);
                seq.range = pair.value.range;
              }
              super(pair.key, seq);
              this.range = pair.range;
            } else {
              super(new Scalar(MERGE_KEY), new YAMLSeq());
            }
            this.type = Pair.Type.MERGE_PAIR;
          }
          addToJSMap(ctx, map) {
            for (const {
              source
            } of this.value.items) {
              if (!(source instanceof YAMLMap))
                throw new Error("Merge sources must be maps");
              const srcMap = source.toJSON(null, ctx, Map);
              for (const [key, value2] of srcMap) {
                if (map instanceof Map) {
                  if (!map.has(key))
                    map.set(key, value2);
                } else if (map instanceof Set) {
                  map.add(key);
                } else if (!Object.prototype.hasOwnProperty.call(map, key)) {
                  Object.defineProperty(map, key, {
                    value: value2,
                    writable: true,
                    enumerable: true,
                    configurable: true
                  });
                }
              }
            }
            return map;
          }
          toString(ctx, onComment) {
            const seq = this.value;
            if (seq.items.length > 1)
              return super.toString(ctx, onComment);
            this.value = seq.items[0];
            const str = super.toString(ctx, onComment);
            this.value = seq;
            return str;
          }
        };
        var binaryOptions = {
          defaultType: PlainValue.Type.BLOCK_LITERAL,
          lineWidth: 76
        };
        var boolOptions = {
          trueStr: "true",
          falseStr: "false"
        };
        var intOptions = {
          asBigInt: false
        };
        var nullOptions = {
          nullStr: "null"
        };
        var strOptions = {
          defaultType: PlainValue.Type.PLAIN,
          doubleQuoted: {
            jsonEncoding: false,
            minMultiLineLength: 40
          },
          fold: {
            lineWidth: 80,
            minContentWidth: 20
          }
        };
        function resolveScalar(str, tags, scalarFallback) {
          for (const {
            format: format2,
            test,
            resolve
          } of tags) {
            if (test) {
              const match = str.match(test);
              if (match) {
                let res = resolve.apply(null, match);
                if (!(res instanceof Scalar))
                  res = new Scalar(res);
                if (format2)
                  res.format = format2;
                return res;
              }
            }
          }
          if (scalarFallback)
            str = scalarFallback(str);
          return new Scalar(str);
        }
        var FOLD_FLOW = "flow";
        var FOLD_BLOCK = "block";
        var FOLD_QUOTED = "quoted";
        var consumeMoreIndentedLines = (text, i) => {
          let ch = text[i + 1];
          while (ch === " " || ch === "	") {
            do {
              ch = text[i += 1];
            } while (ch && ch !== "\n");
            ch = text[i + 1];
          }
          return i;
        };
        function foldFlowLines(text, indent, mode, {
          indentAtStart,
          lineWidth = 80,
          minContentWidth = 20,
          onFold,
          onOverflow
        }) {
          if (!lineWidth || lineWidth < 0)
            return text;
          const endStep = Math.max(1 + minContentWidth, 1 + lineWidth - indent.length);
          if (text.length <= endStep)
            return text;
          const folds = [];
          const escapedFolds = {};
          let end = lineWidth - indent.length;
          if (typeof indentAtStart === "number") {
            if (indentAtStart > lineWidth - Math.max(2, minContentWidth))
              folds.push(0);
            else
              end = lineWidth - indentAtStart;
          }
          let split = void 0;
          let prev = void 0;
          let overflow = false;
          let i = -1;
          let escStart = -1;
          let escEnd = -1;
          if (mode === FOLD_BLOCK) {
            i = consumeMoreIndentedLines(text, i);
            if (i !== -1)
              end = i + endStep;
          }
          for (let ch; ch = text[i += 1]; ) {
            if (mode === FOLD_QUOTED && ch === "\\") {
              escStart = i;
              switch (text[i + 1]) {
                case "x":
                  i += 3;
                  break;
                case "u":
                  i += 5;
                  break;
                case "U":
                  i += 9;
                  break;
                default:
                  i += 1;
              }
              escEnd = i;
            }
            if (ch === "\n") {
              if (mode === FOLD_BLOCK)
                i = consumeMoreIndentedLines(text, i);
              end = i + endStep;
              split = void 0;
            } else {
              if (ch === " " && prev && prev !== " " && prev !== "\n" && prev !== "	") {
                const next = text[i + 1];
                if (next && next !== " " && next !== "\n" && next !== "	")
                  split = i;
              }
              if (i >= end) {
                if (split) {
                  folds.push(split);
                  end = split + endStep;
                  split = void 0;
                } else if (mode === FOLD_QUOTED) {
                  while (prev === " " || prev === "	") {
                    prev = ch;
                    ch = text[i += 1];
                    overflow = true;
                  }
                  const j = i > escEnd + 1 ? i - 2 : escStart - 1;
                  if (escapedFolds[j])
                    return text;
                  folds.push(j);
                  escapedFolds[j] = true;
                  end = j + endStep;
                  split = void 0;
                } else {
                  overflow = true;
                }
              }
            }
            prev = ch;
          }
          if (overflow && onOverflow)
            onOverflow();
          if (folds.length === 0)
            return text;
          if (onFold)
            onFold();
          let res = text.slice(0, folds[0]);
          for (let i2 = 0; i2 < folds.length; ++i2) {
            const fold = folds[i2];
            const end2 = folds[i2 + 1] || text.length;
            if (fold === 0)
              res = `
${indent}${text.slice(0, end2)}`;
            else {
              if (mode === FOLD_QUOTED && escapedFolds[fold])
                res += `${text[fold]}\\`;
              res += `
${indent}${text.slice(fold + 1, end2)}`;
            }
          }
          return res;
        }
        var getFoldOptions = ({
          indentAtStart
        }) => indentAtStart ? Object.assign({
          indentAtStart
        }, strOptions.fold) : strOptions.fold;
        var containsDocumentMarker = (str) => /^(%|---|\.\.\.)/m.test(str);
        function lineLengthOverLimit(str, lineWidth, indentLength) {
          if (!lineWidth || lineWidth < 0)
            return false;
          const limit = lineWidth - indentLength;
          const strLen = str.length;
          if (strLen <= limit)
            return false;
          for (let i = 0, start = 0; i < strLen; ++i) {
            if (str[i] === "\n") {
              if (i - start > limit)
                return true;
              start = i + 1;
              if (strLen - start <= limit)
                return false;
            }
          }
          return true;
        }
        function doubleQuotedString(value2, ctx) {
          const {
            implicitKey
          } = ctx;
          const {
            jsonEncoding,
            minMultiLineLength
          } = strOptions.doubleQuoted;
          const json = JSON.stringify(value2);
          if (jsonEncoding)
            return json;
          const indent = ctx.indent || (containsDocumentMarker(value2) ? "  " : "");
          let str = "";
          let start = 0;
          for (let i = 0, ch = json[i]; ch; ch = json[++i]) {
            if (ch === " " && json[i + 1] === "\\" && json[i + 2] === "n") {
              str += json.slice(start, i) + "\\ ";
              i += 1;
              start = i;
              ch = "\\";
            }
            if (ch === "\\")
              switch (json[i + 1]) {
                case "u":
                  {
                    str += json.slice(start, i);
                    const code = json.substr(i + 2, 4);
                    switch (code) {
                      case "0000":
                        str += "\\0";
                        break;
                      case "0007":
                        str += "\\a";
                        break;
                      case "000b":
                        str += "\\v";
                        break;
                      case "001b":
                        str += "\\e";
                        break;
                      case "0085":
                        str += "\\N";
                        break;
                      case "00a0":
                        str += "\\_";
                        break;
                      case "2028":
                        str += "\\L";
                        break;
                      case "2029":
                        str += "\\P";
                        break;
                      default:
                        if (code.substr(0, 2) === "00")
                          str += "\\x" + code.substr(2);
                        else
                          str += json.substr(i, 6);
                    }
                    i += 5;
                    start = i + 1;
                  }
                  break;
                case "n":
                  if (implicitKey || json[i + 2] === '"' || json.length < minMultiLineLength) {
                    i += 1;
                  } else {
                    str += json.slice(start, i) + "\n\n";
                    while (json[i + 2] === "\\" && json[i + 3] === "n" && json[i + 4] !== '"') {
                      str += "\n";
                      i += 2;
                    }
                    str += indent;
                    if (json[i + 2] === " ")
                      str += "\\";
                    i += 1;
                    start = i + 1;
                  }
                  break;
                default:
                  i += 1;
              }
          }
          str = start ? str + json.slice(start) : json;
          return implicitKey ? str : foldFlowLines(str, indent, FOLD_QUOTED, getFoldOptions(ctx));
        }
        function singleQuotedString(value2, ctx) {
          if (ctx.implicitKey) {
            if (/\n/.test(value2))
              return doubleQuotedString(value2, ctx);
          } else {
            if (/[ \t]\n|\n[ \t]/.test(value2))
              return doubleQuotedString(value2, ctx);
          }
          const indent = ctx.indent || (containsDocumentMarker(value2) ? "  " : "");
          const res = "'" + value2.replace(/'/g, "''").replace(/\n+/g, `$&
${indent}`) + "'";
          return ctx.implicitKey ? res : foldFlowLines(res, indent, FOLD_FLOW, getFoldOptions(ctx));
        }
        function blockString({
          comment,
          type,
          value: value2
        }, ctx, onComment, onChompKeep) {
          if (/\n[\t ]+$/.test(value2) || /^\s*$/.test(value2)) {
            return doubleQuotedString(value2, ctx);
          }
          const indent = ctx.indent || (ctx.forceBlockIndent || containsDocumentMarker(value2) ? "  " : "");
          const indentSize = indent ? "2" : "1";
          const literal = type === PlainValue.Type.BLOCK_FOLDED ? false : type === PlainValue.Type.BLOCK_LITERAL ? true : !lineLengthOverLimit(value2, strOptions.fold.lineWidth, indent.length);
          let header = literal ? "|" : ">";
          if (!value2)
            return header + "\n";
          let wsStart = "";
          let wsEnd = "";
          value2 = value2.replace(/[\n\t ]*$/, (ws) => {
            const n = ws.indexOf("\n");
            if (n === -1) {
              header += "-";
            } else if (value2 === ws || n !== ws.length - 1) {
              header += "+";
              if (onChompKeep)
                onChompKeep();
            }
            wsEnd = ws.replace(/\n$/, "");
            return "";
          }).replace(/^[\n ]*/, (ws) => {
            if (ws.indexOf(" ") !== -1)
              header += indentSize;
            const m = ws.match(/ +$/);
            if (m) {
              wsStart = ws.slice(0, -m[0].length);
              return m[0];
            } else {
              wsStart = ws;
              return "";
            }
          });
          if (wsEnd)
            wsEnd = wsEnd.replace(/\n+(?!\n|$)/g, `$&${indent}`);
          if (wsStart)
            wsStart = wsStart.replace(/\n+/g, `$&${indent}`);
          if (comment) {
            header += " #" + comment.replace(/ ?[\r\n]+/g, " ");
            if (onComment)
              onComment();
          }
          if (!value2)
            return `${header}${indentSize}
${indent}${wsEnd}`;
          if (literal) {
            value2 = value2.replace(/\n+/g, `$&${indent}`);
            return `${header}
${indent}${wsStart}${value2}${wsEnd}`;
          }
          value2 = value2.replace(/\n+/g, "\n$&").replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g, "$1$2").replace(/\n+/g, `$&${indent}`);
          const body = foldFlowLines(`${wsStart}${value2}${wsEnd}`, indent, FOLD_BLOCK, strOptions.fold);
          return `${header}
${indent}${body}`;
        }
        function plainString(item, ctx, onComment, onChompKeep) {
          const {
            comment,
            type,
            value: value2
          } = item;
          const {
            actualString,
            implicitKey,
            indent,
            inFlow
          } = ctx;
          if (implicitKey && /[\n[\]{},]/.test(value2) || inFlow && /[[\]{},]/.test(value2)) {
            return doubleQuotedString(value2, ctx);
          }
          if (!value2 || /^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(value2)) {
            return implicitKey || inFlow || value2.indexOf("\n") === -1 ? value2.indexOf('"') !== -1 && value2.indexOf("'") === -1 ? singleQuotedString(value2, ctx) : doubleQuotedString(value2, ctx) : blockString(item, ctx, onComment, onChompKeep);
          }
          if (!implicitKey && !inFlow && type !== PlainValue.Type.PLAIN && value2.indexOf("\n") !== -1) {
            return blockString(item, ctx, onComment, onChompKeep);
          }
          if (indent === "" && containsDocumentMarker(value2)) {
            ctx.forceBlockIndent = true;
            return blockString(item, ctx, onComment, onChompKeep);
          }
          const str = value2.replace(/\n+/g, `$&
${indent}`);
          if (actualString) {
            const {
              tags
            } = ctx.doc.schema;
            const resolved = resolveScalar(str, tags, tags.scalarFallback).value;
            if (typeof resolved !== "string")
              return doubleQuotedString(value2, ctx);
          }
          const body = implicitKey ? str : foldFlowLines(str, indent, FOLD_FLOW, getFoldOptions(ctx));
          if (comment && !inFlow && (body.indexOf("\n") !== -1 || comment.indexOf("\n") !== -1)) {
            if (onComment)
              onComment();
            return addCommentBefore(body, indent, comment);
          }
          return body;
        }
        function stringifyString(item, ctx, onComment, onChompKeep) {
          const {
            defaultType
          } = strOptions;
          const {
            implicitKey,
            inFlow
          } = ctx;
          let {
            type,
            value: value2
          } = item;
          if (typeof value2 !== "string") {
            value2 = String(value2);
            item = Object.assign({}, item, {
              value: value2
            });
          }
          const _stringify = (_type) => {
            switch (_type) {
              case PlainValue.Type.BLOCK_FOLDED:
              case PlainValue.Type.BLOCK_LITERAL:
                return blockString(item, ctx, onComment, onChompKeep);
              case PlainValue.Type.QUOTE_DOUBLE:
                return doubleQuotedString(value2, ctx);
              case PlainValue.Type.QUOTE_SINGLE:
                return singleQuotedString(value2, ctx);
              case PlainValue.Type.PLAIN:
                return plainString(item, ctx, onComment, onChompKeep);
              default:
                return null;
            }
          };
          if (type !== PlainValue.Type.QUOTE_DOUBLE && /[\x00-\x08\x0b-\x1f\x7f-\x9f]/.test(value2)) {
            type = PlainValue.Type.QUOTE_DOUBLE;
          } else if ((implicitKey || inFlow) && (type === PlainValue.Type.BLOCK_FOLDED || type === PlainValue.Type.BLOCK_LITERAL)) {
            type = PlainValue.Type.QUOTE_DOUBLE;
          }
          let res = _stringify(type);
          if (res === null) {
            res = _stringify(defaultType);
            if (res === null)
              throw new Error(`Unsupported default string type ${defaultType}`);
          }
          return res;
        }
        function stringifyNumber({
          format: format2,
          minFractionDigits,
          tag,
          value: value2
        }) {
          if (typeof value2 === "bigint")
            return String(value2);
          if (!isFinite(value2))
            return isNaN(value2) ? ".nan" : value2 < 0 ? "-.inf" : ".inf";
          let n = JSON.stringify(value2);
          if (!format2 && minFractionDigits && (!tag || tag === "tag:yaml.org,2002:float") && /^\d/.test(n)) {
            let i = n.indexOf(".");
            if (i < 0) {
              i = n.length;
              n += ".";
            }
            let d = minFractionDigits - (n.length - i - 1);
            while (d-- > 0)
              n += "0";
          }
          return n;
        }
        function checkFlowCollectionEnd(errors, cst) {
          let char, name;
          switch (cst.type) {
            case PlainValue.Type.FLOW_MAP:
              char = "}";
              name = "flow map";
              break;
            case PlainValue.Type.FLOW_SEQ:
              char = "]";
              name = "flow sequence";
              break;
            default:
              errors.push(new PlainValue.YAMLSemanticError(cst, "Not a flow collection!?"));
              return;
          }
          let lastItem;
          for (let i = cst.items.length - 1; i >= 0; --i) {
            const item = cst.items[i];
            if (!item || item.type !== PlainValue.Type.COMMENT) {
              lastItem = item;
              break;
            }
          }
          if (lastItem && lastItem.char !== char) {
            const msg = `Expected ${name} to end with ${char}`;
            let err;
            if (typeof lastItem.offset === "number") {
              err = new PlainValue.YAMLSemanticError(cst, msg);
              err.offset = lastItem.offset + 1;
            } else {
              err = new PlainValue.YAMLSemanticError(lastItem, msg);
              if (lastItem.range && lastItem.range.end)
                err.offset = lastItem.range.end - lastItem.range.start;
            }
            errors.push(err);
          }
        }
        function checkFlowCommentSpace(errors, comment) {
          const prev = comment.context.src[comment.range.start - 1];
          if (prev !== "\n" && prev !== "	" && prev !== " ") {
            const msg = "Comments must be separated from other tokens by white space characters";
            errors.push(new PlainValue.YAMLSemanticError(comment, msg));
          }
        }
        function getLongKeyError(source, key) {
          const sk = String(key);
          const k = sk.substr(0, 8) + "..." + sk.substr(-8);
          return new PlainValue.YAMLSemanticError(source, `The "${k}" key is too long`);
        }
        function resolveComments(collection, comments) {
          for (const {
            afterKey,
            before,
            comment
          } of comments) {
            let item = collection.items[before];
            if (!item) {
              if (comment !== void 0) {
                if (collection.comment)
                  collection.comment += "\n" + comment;
                else
                  collection.comment = comment;
              }
            } else {
              if (afterKey && item.value)
                item = item.value;
              if (comment === void 0) {
                if (afterKey || !item.commentBefore)
                  item.spaceBefore = true;
              } else {
                if (item.commentBefore)
                  item.commentBefore += "\n" + comment;
                else
                  item.commentBefore = comment;
              }
            }
          }
        }
        function resolveString(doc, node) {
          const res = node.strValue;
          if (!res)
            return "";
          if (typeof res === "string")
            return res;
          res.errors.forEach((error) => {
            if (!error.source)
              error.source = node;
            doc.errors.push(error);
          });
          return res.str;
        }
        function resolveTagHandle(doc, node) {
          const {
            handle,
            suffix
          } = node.tag;
          let prefix = doc.tagPrefixes.find((p) => p.handle === handle);
          if (!prefix) {
            const dtp = doc.getDefaults().tagPrefixes;
            if (dtp)
              prefix = dtp.find((p) => p.handle === handle);
            if (!prefix)
              throw new PlainValue.YAMLSemanticError(node, `The ${handle} tag handle is non-default and was not declared.`);
          }
          if (!suffix)
            throw new PlainValue.YAMLSemanticError(node, `The ${handle} tag has no suffix.`);
          if (handle === "!" && (doc.version || doc.options.version) === "1.0") {
            if (suffix[0] === "^") {
              doc.warnings.push(new PlainValue.YAMLWarning(node, "YAML 1.0 ^ tag expansion is not supported"));
              return suffix;
            }
            if (/[:/]/.test(suffix)) {
              const vocab = suffix.match(/^([a-z0-9-]+)\/(.*)/i);
              return vocab ? `tag:${vocab[1]}.yaml.org,2002:${vocab[2]}` : `tag:${suffix}`;
            }
          }
          return prefix.prefix + decodeURIComponent(suffix);
        }
        function resolveTagName(doc, node) {
          const {
            tag,
            type
          } = node;
          let nonSpecific = false;
          if (tag) {
            const {
              handle,
              suffix,
              verbatim
            } = tag;
            if (verbatim) {
              if (verbatim !== "!" && verbatim !== "!!")
                return verbatim;
              const msg = `Verbatim tags aren't resolved, so ${verbatim} is invalid.`;
              doc.errors.push(new PlainValue.YAMLSemanticError(node, msg));
            } else if (handle === "!" && !suffix) {
              nonSpecific = true;
            } else {
              try {
                return resolveTagHandle(doc, node);
              } catch (error) {
                doc.errors.push(error);
              }
            }
          }
          switch (type) {
            case PlainValue.Type.BLOCK_FOLDED:
            case PlainValue.Type.BLOCK_LITERAL:
            case PlainValue.Type.QUOTE_DOUBLE:
            case PlainValue.Type.QUOTE_SINGLE:
              return PlainValue.defaultTags.STR;
            case PlainValue.Type.FLOW_MAP:
            case PlainValue.Type.MAP:
              return PlainValue.defaultTags.MAP;
            case PlainValue.Type.FLOW_SEQ:
            case PlainValue.Type.SEQ:
              return PlainValue.defaultTags.SEQ;
            case PlainValue.Type.PLAIN:
              return nonSpecific ? PlainValue.defaultTags.STR : null;
            default:
              return null;
          }
        }
        function resolveByTagName(doc, node, tagName) {
          const {
            tags
          } = doc.schema;
          const matchWithTest = [];
          for (const tag of tags) {
            if (tag.tag === tagName) {
              if (tag.test)
                matchWithTest.push(tag);
              else {
                const res = tag.resolve(doc, node);
                return res instanceof Collection ? res : new Scalar(res);
              }
            }
          }
          const str = resolveString(doc, node);
          if (typeof str === "string" && matchWithTest.length > 0)
            return resolveScalar(str, matchWithTest, tags.scalarFallback);
          return null;
        }
        function getFallbackTagName({
          type
        }) {
          switch (type) {
            case PlainValue.Type.FLOW_MAP:
            case PlainValue.Type.MAP:
              return PlainValue.defaultTags.MAP;
            case PlainValue.Type.FLOW_SEQ:
            case PlainValue.Type.SEQ:
              return PlainValue.defaultTags.SEQ;
            default:
              return PlainValue.defaultTags.STR;
          }
        }
        function resolveTag(doc, node, tagName) {
          try {
            const res = resolveByTagName(doc, node, tagName);
            if (res) {
              if (tagName && node.tag)
                res.tag = tagName;
              return res;
            }
          } catch (error) {
            if (!error.source)
              error.source = node;
            doc.errors.push(error);
            return null;
          }
          try {
            const fallback = getFallbackTagName(node);
            if (!fallback)
              throw new Error(`The tag ${tagName} is unavailable`);
            const msg = `The tag ${tagName} is unavailable, falling back to ${fallback}`;
            doc.warnings.push(new PlainValue.YAMLWarning(node, msg));
            const res = resolveByTagName(doc, node, fallback);
            res.tag = tagName;
            return res;
          } catch (error) {
            const refError = new PlainValue.YAMLReferenceError(node, error.message);
            refError.stack = error.stack;
            doc.errors.push(refError);
            return null;
          }
        }
        var isCollectionItem = (node) => {
          if (!node)
            return false;
          const {
            type
          } = node;
          return type === PlainValue.Type.MAP_KEY || type === PlainValue.Type.MAP_VALUE || type === PlainValue.Type.SEQ_ITEM;
        };
        function resolveNodeProps(errors, node) {
          const comments = {
            before: [],
            after: []
          };
          let hasAnchor = false;
          let hasTag = false;
          const props = isCollectionItem(node.context.parent) ? node.context.parent.props.concat(node.props) : node.props;
          for (const {
            start,
            end
          } of props) {
            switch (node.context.src[start]) {
              case PlainValue.Char.COMMENT: {
                if (!node.commentHasRequiredWhitespace(start)) {
                  const msg = "Comments must be separated from other tokens by white space characters";
                  errors.push(new PlainValue.YAMLSemanticError(node, msg));
                }
                const {
                  header,
                  valueRange
                } = node;
                const cc = valueRange && (start > valueRange.start || header && start > header.start) ? comments.after : comments.before;
                cc.push(node.context.src.slice(start + 1, end));
                break;
              }
              case PlainValue.Char.ANCHOR:
                if (hasAnchor) {
                  const msg = "A node can have at most one anchor";
                  errors.push(new PlainValue.YAMLSemanticError(node, msg));
                }
                hasAnchor = true;
                break;
              case PlainValue.Char.TAG:
                if (hasTag) {
                  const msg = "A node can have at most one tag";
                  errors.push(new PlainValue.YAMLSemanticError(node, msg));
                }
                hasTag = true;
                break;
            }
          }
          return {
            comments,
            hasAnchor,
            hasTag
          };
        }
        function resolveNodeValue(doc, node) {
          const {
            anchors,
            errors,
            schema
          } = doc;
          if (node.type === PlainValue.Type.ALIAS) {
            const name = node.rawValue;
            const src = anchors.getNode(name);
            if (!src) {
              const msg = `Aliased anchor not found: ${name}`;
              errors.push(new PlainValue.YAMLReferenceError(node, msg));
              return null;
            }
            const res = new Alias(src);
            anchors._cstAliases.push(res);
            return res;
          }
          const tagName = resolveTagName(doc, node);
          if (tagName)
            return resolveTag(doc, node, tagName);
          if (node.type !== PlainValue.Type.PLAIN) {
            const msg = `Failed to resolve ${node.type} node here`;
            errors.push(new PlainValue.YAMLSyntaxError(node, msg));
            return null;
          }
          try {
            const str = resolveString(doc, node);
            return resolveScalar(str, schema.tags, schema.tags.scalarFallback);
          } catch (error) {
            if (!error.source)
              error.source = node;
            errors.push(error);
            return null;
          }
        }
        function resolveNode(doc, node) {
          if (!node)
            return null;
          if (node.error)
            doc.errors.push(node.error);
          const {
            comments,
            hasAnchor,
            hasTag
          } = resolveNodeProps(doc.errors, node);
          if (hasAnchor) {
            const {
              anchors
            } = doc;
            const name = node.anchor;
            const prev = anchors.getNode(name);
            if (prev)
              anchors.map[anchors.newName(name)] = prev;
            anchors.map[name] = node;
          }
          if (node.type === PlainValue.Type.ALIAS && (hasAnchor || hasTag)) {
            const msg = "An alias node must not specify any properties";
            doc.errors.push(new PlainValue.YAMLSemanticError(node, msg));
          }
          const res = resolveNodeValue(doc, node);
          if (res) {
            res.range = [node.range.start, node.range.end];
            if (doc.options.keepCstNodes)
              res.cstNode = node;
            if (doc.options.keepNodeTypes)
              res.type = node.type;
            const cb = comments.before.join("\n");
            if (cb) {
              res.commentBefore = res.commentBefore ? `${res.commentBefore}
${cb}` : cb;
            }
            const ca = comments.after.join("\n");
            if (ca)
              res.comment = res.comment ? `${res.comment}
${ca}` : ca;
          }
          return node.resolved = res;
        }
        function resolveMap(doc, cst) {
          if (cst.type !== PlainValue.Type.MAP && cst.type !== PlainValue.Type.FLOW_MAP) {
            const msg = `A ${cst.type} node cannot be resolved as a mapping`;
            doc.errors.push(new PlainValue.YAMLSyntaxError(cst, msg));
            return null;
          }
          const {
            comments,
            items
          } = cst.type === PlainValue.Type.FLOW_MAP ? resolveFlowMapItems(doc, cst) : resolveBlockMapItems(doc, cst);
          const map = new YAMLMap();
          map.items = items;
          resolveComments(map, comments);
          let hasCollectionKey = false;
          for (let i = 0; i < items.length; ++i) {
            const {
              key: iKey
            } = items[i];
            if (iKey instanceof Collection)
              hasCollectionKey = true;
            if (doc.schema.merge && iKey && iKey.value === MERGE_KEY) {
              items[i] = new Merge(items[i]);
              const sources = items[i].value.items;
              let error = null;
              sources.some((node) => {
                if (node instanceof Alias) {
                  const {
                    type
                  } = node.source;
                  if (type === PlainValue.Type.MAP || type === PlainValue.Type.FLOW_MAP)
                    return false;
                  return error = "Merge nodes aliases can only point to maps";
                }
                return error = "Merge nodes can only have Alias nodes as values";
              });
              if (error)
                doc.errors.push(new PlainValue.YAMLSemanticError(cst, error));
            } else {
              for (let j = i + 1; j < items.length; ++j) {
                const {
                  key: jKey
                } = items[j];
                if (iKey === jKey || iKey && jKey && Object.prototype.hasOwnProperty.call(iKey, "value") && iKey.value === jKey.value) {
                  const msg = `Map keys must be unique; "${iKey}" is repeated`;
                  doc.errors.push(new PlainValue.YAMLSemanticError(cst, msg));
                  break;
                }
              }
            }
          }
          if (hasCollectionKey && !doc.options.mapAsMap) {
            const warn = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
            doc.warnings.push(new PlainValue.YAMLWarning(cst, warn));
          }
          cst.resolved = map;
          return map;
        }
        var valueHasPairComment = ({
          context: {
            lineStart,
            node,
            src
          },
          props
        }) => {
          if (props.length === 0)
            return false;
          const {
            start
          } = props[0];
          if (node && start > node.valueRange.start)
            return false;
          if (src[start] !== PlainValue.Char.COMMENT)
            return false;
          for (let i = lineStart; i < start; ++i)
            if (src[i] === "\n")
              return false;
          return true;
        };
        function resolvePairComment(item, pair) {
          if (!valueHasPairComment(item))
            return;
          const comment = item.getPropValue(0, PlainValue.Char.COMMENT, true);
          let found = false;
          const cb = pair.value.commentBefore;
          if (cb && cb.startsWith(comment)) {
            pair.value.commentBefore = cb.substr(comment.length + 1);
            found = true;
          } else {
            const cc = pair.value.comment;
            if (!item.node && cc && cc.startsWith(comment)) {
              pair.value.comment = cc.substr(comment.length + 1);
              found = true;
            }
          }
          if (found)
            pair.comment = comment;
        }
        function resolveBlockMapItems(doc, cst) {
          const comments = [];
          const items = [];
          let key = void 0;
          let keyStart = null;
          for (let i = 0; i < cst.items.length; ++i) {
            const item = cst.items[i];
            switch (item.type) {
              case PlainValue.Type.BLANK_LINE:
                comments.push({
                  afterKey: !!key,
                  before: items.length
                });
                break;
              case PlainValue.Type.COMMENT:
                comments.push({
                  afterKey: !!key,
                  before: items.length,
                  comment: item.comment
                });
                break;
              case PlainValue.Type.MAP_KEY:
                if (key !== void 0)
                  items.push(new Pair(key));
                if (item.error)
                  doc.errors.push(item.error);
                key = resolveNode(doc, item.node);
                keyStart = null;
                break;
              case PlainValue.Type.MAP_VALUE:
                {
                  if (key === void 0)
                    key = null;
                  if (item.error)
                    doc.errors.push(item.error);
                  if (!item.context.atLineStart && item.node && item.node.type === PlainValue.Type.MAP && !item.node.context.atLineStart) {
                    const msg = "Nested mappings are not allowed in compact mappings";
                    doc.errors.push(new PlainValue.YAMLSemanticError(item.node, msg));
                  }
                  let valueNode = item.node;
                  if (!valueNode && item.props.length > 0) {
                    valueNode = new PlainValue.PlainValue(PlainValue.Type.PLAIN, []);
                    valueNode.context = {
                      parent: item,
                      src: item.context.src
                    };
                    const pos = item.range.start + 1;
                    valueNode.range = {
                      start: pos,
                      end: pos
                    };
                    valueNode.valueRange = {
                      start: pos,
                      end: pos
                    };
                    if (typeof item.range.origStart === "number") {
                      const origPos = item.range.origStart + 1;
                      valueNode.range.origStart = valueNode.range.origEnd = origPos;
                      valueNode.valueRange.origStart = valueNode.valueRange.origEnd = origPos;
                    }
                  }
                  const pair = new Pair(key, resolveNode(doc, valueNode));
                  resolvePairComment(item, pair);
                  items.push(pair);
                  if (key && typeof keyStart === "number") {
                    if (item.range.start > keyStart + 1024)
                      doc.errors.push(getLongKeyError(cst, key));
                  }
                  key = void 0;
                  keyStart = null;
                }
                break;
              default:
                if (key !== void 0)
                  items.push(new Pair(key));
                key = resolveNode(doc, item);
                keyStart = item.range.start;
                if (item.error)
                  doc.errors.push(item.error);
                next:
                  for (let j = i + 1; ; ++j) {
                    const nextItem = cst.items[j];
                    switch (nextItem && nextItem.type) {
                      case PlainValue.Type.BLANK_LINE:
                      case PlainValue.Type.COMMENT:
                        continue next;
                      case PlainValue.Type.MAP_VALUE:
                        break next;
                      default: {
                        const msg = "Implicit map keys need to be followed by map values";
                        doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
                        break next;
                      }
                    }
                  }
                if (item.valueRangeContainsNewline) {
                  const msg = "Implicit map keys need to be on a single line";
                  doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
                }
            }
          }
          if (key !== void 0)
            items.push(new Pair(key));
          return {
            comments,
            items
          };
        }
        function resolveFlowMapItems(doc, cst) {
          const comments = [];
          const items = [];
          let key = void 0;
          let explicitKey = false;
          let next = "{";
          for (let i = 0; i < cst.items.length; ++i) {
            const item = cst.items[i];
            if (typeof item.char === "string") {
              const {
                char,
                offset
              } = item;
              if (char === "?" && key === void 0 && !explicitKey) {
                explicitKey = true;
                next = ":";
                continue;
              }
              if (char === ":") {
                if (key === void 0)
                  key = null;
                if (next === ":") {
                  next = ",";
                  continue;
                }
              } else {
                if (explicitKey) {
                  if (key === void 0 && char !== ",")
                    key = null;
                  explicitKey = false;
                }
                if (key !== void 0) {
                  items.push(new Pair(key));
                  key = void 0;
                  if (char === ",") {
                    next = ":";
                    continue;
                  }
                }
              }
              if (char === "}") {
                if (i === cst.items.length - 1)
                  continue;
              } else if (char === next) {
                next = ":";
                continue;
              }
              const msg = `Flow map contains an unexpected ${char}`;
              const err = new PlainValue.YAMLSyntaxError(cst, msg);
              err.offset = offset;
              doc.errors.push(err);
            } else if (item.type === PlainValue.Type.BLANK_LINE) {
              comments.push({
                afterKey: !!key,
                before: items.length
              });
            } else if (item.type === PlainValue.Type.COMMENT) {
              checkFlowCommentSpace(doc.errors, item);
              comments.push({
                afterKey: !!key,
                before: items.length,
                comment: item.comment
              });
            } else if (key === void 0) {
              if (next === ",")
                doc.errors.push(new PlainValue.YAMLSemanticError(item, "Separator , missing in flow map"));
              key = resolveNode(doc, item);
            } else {
              if (next !== ",")
                doc.errors.push(new PlainValue.YAMLSemanticError(item, "Indicator : missing in flow map entry"));
              items.push(new Pair(key, resolveNode(doc, item)));
              key = void 0;
              explicitKey = false;
            }
          }
          checkFlowCollectionEnd(doc.errors, cst);
          if (key !== void 0)
            items.push(new Pair(key));
          return {
            comments,
            items
          };
        }
        function resolveSeq(doc, cst) {
          if (cst.type !== PlainValue.Type.SEQ && cst.type !== PlainValue.Type.FLOW_SEQ) {
            const msg = `A ${cst.type} node cannot be resolved as a sequence`;
            doc.errors.push(new PlainValue.YAMLSyntaxError(cst, msg));
            return null;
          }
          const {
            comments,
            items
          } = cst.type === PlainValue.Type.FLOW_SEQ ? resolveFlowSeqItems(doc, cst) : resolveBlockSeqItems(doc, cst);
          const seq = new YAMLSeq();
          seq.items = items;
          resolveComments(seq, comments);
          if (!doc.options.mapAsMap && items.some((it2) => it2 instanceof Pair && it2.key instanceof Collection)) {
            const warn = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
            doc.warnings.push(new PlainValue.YAMLWarning(cst, warn));
          }
          cst.resolved = seq;
          return seq;
        }
        function resolveBlockSeqItems(doc, cst) {
          const comments = [];
          const items = [];
          for (let i = 0; i < cst.items.length; ++i) {
            const item = cst.items[i];
            switch (item.type) {
              case PlainValue.Type.BLANK_LINE:
                comments.push({
                  before: items.length
                });
                break;
              case PlainValue.Type.COMMENT:
                comments.push({
                  comment: item.comment,
                  before: items.length
                });
                break;
              case PlainValue.Type.SEQ_ITEM:
                if (item.error)
                  doc.errors.push(item.error);
                items.push(resolveNode(doc, item.node));
                if (item.hasProps) {
                  const msg = "Sequence items cannot have tags or anchors before the - indicator";
                  doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
                }
                break;
              default:
                if (item.error)
                  doc.errors.push(item.error);
                doc.errors.push(new PlainValue.YAMLSyntaxError(item, `Unexpected ${item.type} node in sequence`));
            }
          }
          return {
            comments,
            items
          };
        }
        function resolveFlowSeqItems(doc, cst) {
          const comments = [];
          const items = [];
          let explicitKey = false;
          let key = void 0;
          let keyStart = null;
          let next = "[";
          let prevItem = null;
          for (let i = 0; i < cst.items.length; ++i) {
            const item = cst.items[i];
            if (typeof item.char === "string") {
              const {
                char,
                offset
              } = item;
              if (char !== ":" && (explicitKey || key !== void 0)) {
                if (explicitKey && key === void 0)
                  key = next ? items.pop() : null;
                items.push(new Pair(key));
                explicitKey = false;
                key = void 0;
                keyStart = null;
              }
              if (char === next) {
                next = null;
              } else if (!next && char === "?") {
                explicitKey = true;
              } else if (next !== "[" && char === ":" && key === void 0) {
                if (next === ",") {
                  key = items.pop();
                  if (key instanceof Pair) {
                    const msg = "Chaining flow sequence pairs is invalid";
                    const err = new PlainValue.YAMLSemanticError(cst, msg);
                    err.offset = offset;
                    doc.errors.push(err);
                  }
                  if (!explicitKey && typeof keyStart === "number") {
                    const keyEnd = item.range ? item.range.start : item.offset;
                    if (keyEnd > keyStart + 1024)
                      doc.errors.push(getLongKeyError(cst, key));
                    const {
                      src
                    } = prevItem.context;
                    for (let i2 = keyStart; i2 < keyEnd; ++i2)
                      if (src[i2] === "\n") {
                        const msg = "Implicit keys of flow sequence pairs need to be on a single line";
                        doc.errors.push(new PlainValue.YAMLSemanticError(prevItem, msg));
                        break;
                      }
                  }
                } else {
                  key = null;
                }
                keyStart = null;
                explicitKey = false;
                next = null;
              } else if (next === "[" || char !== "]" || i < cst.items.length - 1) {
                const msg = `Flow sequence contains an unexpected ${char}`;
                const err = new PlainValue.YAMLSyntaxError(cst, msg);
                err.offset = offset;
                doc.errors.push(err);
              }
            } else if (item.type === PlainValue.Type.BLANK_LINE) {
              comments.push({
                before: items.length
              });
            } else if (item.type === PlainValue.Type.COMMENT) {
              checkFlowCommentSpace(doc.errors, item);
              comments.push({
                comment: item.comment,
                before: items.length
              });
            } else {
              if (next) {
                const msg = `Expected a ${next} in flow sequence`;
                doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
              }
              const value2 = resolveNode(doc, item);
              if (key === void 0) {
                items.push(value2);
                prevItem = item;
              } else {
                items.push(new Pair(key, value2));
                key = void 0;
              }
              keyStart = item.range.start;
              next = ",";
            }
          }
          checkFlowCollectionEnd(doc.errors, cst);
          if (key !== void 0)
            items.push(new Pair(key));
          return {
            comments,
            items
          };
        }
        exports2.Alias = Alias;
        exports2.Collection = Collection;
        exports2.Merge = Merge;
        exports2.Node = Node2;
        exports2.Pair = Pair;
        exports2.Scalar = Scalar;
        exports2.YAMLMap = YAMLMap;
        exports2.YAMLSeq = YAMLSeq;
        exports2.addComment = addComment;
        exports2.binaryOptions = binaryOptions;
        exports2.boolOptions = boolOptions;
        exports2.findPair = findPair;
        exports2.intOptions = intOptions;
        exports2.isEmptyPath = isEmptyPath;
        exports2.nullOptions = nullOptions;
        exports2.resolveMap = resolveMap;
        exports2.resolveNode = resolveNode;
        exports2.resolveSeq = resolveSeq;
        exports2.resolveString = resolveString;
        exports2.strOptions = strOptions;
        exports2.stringifyNumber = stringifyNumber;
        exports2.stringifyString = stringifyString;
        exports2.toJSON = toJSON;
      }
    });
    var require_warnings_1000a372 = __commonJS2({
      "node_modules/yaml/dist/warnings-1000a372.js"(exports2) {
        "use strict";
        var PlainValue = require_PlainValue_ec8e588e();
        var resolveSeq = require_resolveSeq_d03cb037();
        var binary = {
          identify: (value2) => value2 instanceof Uint8Array,
          default: false,
          tag: "tag:yaml.org,2002:binary",
          resolve: (doc, node) => {
            const src = resolveSeq.resolveString(doc, node);
            if (typeof Buffer === "function") {
              return Buffer.from(src, "base64");
            } else if (typeof atob === "function") {
              const str = atob(src.replace(/[\n\r]/g, ""));
              const buffer = new Uint8Array(str.length);
              for (let i = 0; i < str.length; ++i)
                buffer[i] = str.charCodeAt(i);
              return buffer;
            } else {
              const msg = "This environment does not support reading binary tags; either Buffer or atob is required";
              doc.errors.push(new PlainValue.YAMLReferenceError(node, msg));
              return null;
            }
          },
          options: resolveSeq.binaryOptions,
          stringify: ({
            comment,
            type,
            value: value2
          }, ctx, onComment, onChompKeep) => {
            let src;
            if (typeof Buffer === "function") {
              src = value2 instanceof Buffer ? value2.toString("base64") : Buffer.from(value2.buffer).toString("base64");
            } else if (typeof btoa === "function") {
              let s = "";
              for (let i = 0; i < value2.length; ++i)
                s += String.fromCharCode(value2[i]);
              src = btoa(s);
            } else {
              throw new Error("This environment does not support writing binary tags; either Buffer or btoa is required");
            }
            if (!type)
              type = resolveSeq.binaryOptions.defaultType;
            if (type === PlainValue.Type.QUOTE_DOUBLE) {
              value2 = src;
            } else {
              const {
                lineWidth
              } = resolveSeq.binaryOptions;
              const n = Math.ceil(src.length / lineWidth);
              const lines = new Array(n);
              for (let i = 0, o = 0; i < n; ++i, o += lineWidth) {
                lines[i] = src.substr(o, lineWidth);
              }
              value2 = lines.join(type === PlainValue.Type.BLOCK_LITERAL ? "\n" : " ");
            }
            return resolveSeq.stringifyString({
              comment,
              type,
              value: value2
            }, ctx, onComment, onChompKeep);
          }
        };
        function parsePairs(doc, cst) {
          const seq = resolveSeq.resolveSeq(doc, cst);
          for (let i = 0; i < seq.items.length; ++i) {
            let item = seq.items[i];
            if (item instanceof resolveSeq.Pair)
              continue;
            else if (item instanceof resolveSeq.YAMLMap) {
              if (item.items.length > 1) {
                const msg = "Each pair must have its own sequence indicator";
                throw new PlainValue.YAMLSemanticError(cst, msg);
              }
              const pair = item.items[0] || new resolveSeq.Pair();
              if (item.commentBefore)
                pair.commentBefore = pair.commentBefore ? `${item.commentBefore}
${pair.commentBefore}` : item.commentBefore;
              if (item.comment)
                pair.comment = pair.comment ? `${item.comment}
${pair.comment}` : item.comment;
              item = pair;
            }
            seq.items[i] = item instanceof resolveSeq.Pair ? item : new resolveSeq.Pair(item);
          }
          return seq;
        }
        function createPairs(schema, iterable, ctx) {
          const pairs2 = new resolveSeq.YAMLSeq(schema);
          pairs2.tag = "tag:yaml.org,2002:pairs";
          for (const it2 of iterable) {
            let key, value2;
            if (Array.isArray(it2)) {
              if (it2.length === 2) {
                key = it2[0];
                value2 = it2[1];
              } else
                throw new TypeError(`Expected [key, value] tuple: ${it2}`);
            } else if (it2 && it2 instanceof Object) {
              const keys3 = Object.keys(it2);
              if (keys3.length === 1) {
                key = keys3[0];
                value2 = it2[key];
              } else
                throw new TypeError(`Expected { key: value } tuple: ${it2}`);
            } else {
              key = it2;
            }
            const pair = schema.createPair(key, value2, ctx);
            pairs2.items.push(pair);
          }
          return pairs2;
        }
        var pairs = {
          default: false,
          tag: "tag:yaml.org,2002:pairs",
          resolve: parsePairs,
          createNode: createPairs
        };
        var YAMLOMap = class extends resolveSeq.YAMLSeq {
          constructor() {
            super();
            PlainValue._defineProperty(this, "add", resolveSeq.YAMLMap.prototype.add.bind(this));
            PlainValue._defineProperty(this, "delete", resolveSeq.YAMLMap.prototype.delete.bind(this));
            PlainValue._defineProperty(this, "get", resolveSeq.YAMLMap.prototype.get.bind(this));
            PlainValue._defineProperty(this, "has", resolveSeq.YAMLMap.prototype.has.bind(this));
            PlainValue._defineProperty(this, "set", resolveSeq.YAMLMap.prototype.set.bind(this));
            this.tag = YAMLOMap.tag;
          }
          toJSON(_, ctx) {
            const map = /* @__PURE__ */ new Map();
            if (ctx && ctx.onCreate)
              ctx.onCreate(map);
            for (const pair of this.items) {
              let key, value2;
              if (pair instanceof resolveSeq.Pair) {
                key = resolveSeq.toJSON(pair.key, "", ctx);
                value2 = resolveSeq.toJSON(pair.value, key, ctx);
              } else {
                key = resolveSeq.toJSON(pair, "", ctx);
              }
              if (map.has(key))
                throw new Error("Ordered maps must not include duplicate keys");
              map.set(key, value2);
            }
            return map;
          }
        };
        PlainValue._defineProperty(YAMLOMap, "tag", "tag:yaml.org,2002:omap");
        function parseOMap(doc, cst) {
          const pairs2 = parsePairs(doc, cst);
          const seenKeys = [];
          for (const {
            key
          } of pairs2.items) {
            if (key instanceof resolveSeq.Scalar) {
              if (seenKeys.includes(key.value)) {
                const msg = "Ordered maps must not include duplicate keys";
                throw new PlainValue.YAMLSemanticError(cst, msg);
              } else {
                seenKeys.push(key.value);
              }
            }
          }
          return Object.assign(new YAMLOMap(), pairs2);
        }
        function createOMap(schema, iterable, ctx) {
          const pairs2 = createPairs(schema, iterable, ctx);
          const omap2 = new YAMLOMap();
          omap2.items = pairs2.items;
          return omap2;
        }
        var omap = {
          identify: (value2) => value2 instanceof Map,
          nodeClass: YAMLOMap,
          default: false,
          tag: "tag:yaml.org,2002:omap",
          resolve: parseOMap,
          createNode: createOMap
        };
        var YAMLSet = class extends resolveSeq.YAMLMap {
          constructor() {
            super();
            this.tag = YAMLSet.tag;
          }
          add(key) {
            const pair = key instanceof resolveSeq.Pair ? key : new resolveSeq.Pair(key);
            const prev = resolveSeq.findPair(this.items, pair.key);
            if (!prev)
              this.items.push(pair);
          }
          get(key, keepPair) {
            const pair = resolveSeq.findPair(this.items, key);
            return !keepPair && pair instanceof resolveSeq.Pair ? pair.key instanceof resolveSeq.Scalar ? pair.key.value : pair.key : pair;
          }
          set(key, value2) {
            if (typeof value2 !== "boolean")
              throw new Error(`Expected boolean value for set(key, value) in a YAML set, not ${typeof value2}`);
            const prev = resolveSeq.findPair(this.items, key);
            if (prev && !value2) {
              this.items.splice(this.items.indexOf(prev), 1);
            } else if (!prev && value2) {
              this.items.push(new resolveSeq.Pair(key));
            }
          }
          toJSON(_, ctx) {
            return super.toJSON(_, ctx, Set);
          }
          toString(ctx, onComment, onChompKeep) {
            if (!ctx)
              return JSON.stringify(this);
            if (this.hasAllNullValues())
              return super.toString(ctx, onComment, onChompKeep);
            else
              throw new Error("Set items must all have null values");
          }
        };
        PlainValue._defineProperty(YAMLSet, "tag", "tag:yaml.org,2002:set");
        function parseSet(doc, cst) {
          const map = resolveSeq.resolveMap(doc, cst);
          if (!map.hasAllNullValues())
            throw new PlainValue.YAMLSemanticError(cst, "Set items must all have null values");
          return Object.assign(new YAMLSet(), map);
        }
        function createSet(schema, iterable, ctx) {
          const set2 = new YAMLSet();
          for (const value2 of iterable)
            set2.items.push(schema.createPair(value2, null, ctx));
          return set2;
        }
        var set = {
          identify: (value2) => value2 instanceof Set,
          nodeClass: YAMLSet,
          default: false,
          tag: "tag:yaml.org,2002:set",
          resolve: parseSet,
          createNode: createSet
        };
        var parseSexagesimal = (sign, parts) => {
          const n = parts.split(":").reduce((n2, p) => n2 * 60 + Number(p), 0);
          return sign === "-" ? -n : n;
        };
        var stringifySexagesimal = ({
          value: value2
        }) => {
          if (isNaN(value2) || !isFinite(value2))
            return resolveSeq.stringifyNumber(value2);
          let sign = "";
          if (value2 < 0) {
            sign = "-";
            value2 = Math.abs(value2);
          }
          const parts = [value2 % 60];
          if (value2 < 60) {
            parts.unshift(0);
          } else {
            value2 = Math.round((value2 - parts[0]) / 60);
            parts.unshift(value2 % 60);
            if (value2 >= 60) {
              value2 = Math.round((value2 - parts[0]) / 60);
              parts.unshift(value2);
            }
          }
          return sign + parts.map((n) => n < 10 ? "0" + String(n) : String(n)).join(":").replace(/000000\d*$/, "");
        };
        var intTime = {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "TIME",
          test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+)$/,
          resolve: (str, sign, parts) => parseSexagesimal(sign, parts.replace(/_/g, "")),
          stringify: stringifySexagesimal
        };
        var floatTime = {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          format: "TIME",
          test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*)$/,
          resolve: (str, sign, parts) => parseSexagesimal(sign, parts.replace(/_/g, "")),
          stringify: stringifySexagesimal
        };
        var timestamp = {
          identify: (value2) => value2 instanceof Date,
          default: true,
          tag: "tag:yaml.org,2002:timestamp",
          test: RegExp("^(?:([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?)$"),
          resolve: (str, year, month, day, hour, minute, second, millisec, tz) => {
            if (millisec)
              millisec = (millisec + "00").substr(1, 3);
            let date = Date.UTC(year, month - 1, day, hour || 0, minute || 0, second || 0, millisec || 0);
            if (tz && tz !== "Z") {
              let d = parseSexagesimal(tz[0], tz.slice(1));
              if (Math.abs(d) < 30)
                d *= 60;
              date -= 6e4 * d;
            }
            return new Date(date);
          },
          stringify: ({
            value: value2
          }) => value2.toISOString().replace(/((T00:00)?:00)?\.000Z$/, "")
        };
        function shouldWarn(deprecation) {
          const env = typeof process !== "undefined" && process.env || {};
          if (deprecation) {
            if (typeof YAML_SILENCE_DEPRECATION_WARNINGS !== "undefined")
              return !YAML_SILENCE_DEPRECATION_WARNINGS;
            return !env.YAML_SILENCE_DEPRECATION_WARNINGS;
          }
          if (typeof YAML_SILENCE_WARNINGS !== "undefined")
            return !YAML_SILENCE_WARNINGS;
          return !env.YAML_SILENCE_WARNINGS;
        }
        function warn(warning, type) {
          if (shouldWarn(false)) {
            const emit = typeof process !== "undefined" && process.emitWarning;
            if (emit)
              emit(warning, type);
            else {
              console.warn(type ? `${type}: ${warning}` : warning);
            }
          }
        }
        function warnFileDeprecation(filename) {
          if (shouldWarn(true)) {
            const path2 = filename.replace(/.*yaml[/\\]/i, "").replace(/\.js$/, "").replace(/\\/g, "/");
            warn(`The endpoint 'yaml/${path2}' will be removed in a future release.`, "DeprecationWarning");
          }
        }
        var warned = {};
        function warnOptionDeprecation(name, alternative) {
          if (!warned[name] && shouldWarn(true)) {
            warned[name] = true;
            let msg = `The option '${name}' will be removed in a future release`;
            msg += alternative ? `, use '${alternative}' instead.` : ".";
            warn(msg, "DeprecationWarning");
          }
        }
        exports2.binary = binary;
        exports2.floatTime = floatTime;
        exports2.intTime = intTime;
        exports2.omap = omap;
        exports2.pairs = pairs;
        exports2.set = set;
        exports2.timestamp = timestamp;
        exports2.warn = warn;
        exports2.warnFileDeprecation = warnFileDeprecation;
        exports2.warnOptionDeprecation = warnOptionDeprecation;
      }
    });
    var require_Schema_88e323a7 = __commonJS2({
      "node_modules/yaml/dist/Schema-88e323a7.js"(exports2) {
        "use strict";
        var PlainValue = require_PlainValue_ec8e588e();
        var resolveSeq = require_resolveSeq_d03cb037();
        var warnings = require_warnings_1000a372();
        function createMap(schema, obj, ctx) {
          const map2 = new resolveSeq.YAMLMap(schema);
          if (obj instanceof Map) {
            for (const [key, value2] of obj)
              map2.items.push(schema.createPair(key, value2, ctx));
          } else if (obj && typeof obj === "object") {
            for (const key of Object.keys(obj))
              map2.items.push(schema.createPair(key, obj[key], ctx));
          }
          if (typeof schema.sortMapEntries === "function") {
            map2.items.sort(schema.sortMapEntries);
          }
          return map2;
        }
        var map = {
          createNode: createMap,
          default: true,
          nodeClass: resolveSeq.YAMLMap,
          tag: "tag:yaml.org,2002:map",
          resolve: resolveSeq.resolveMap
        };
        function createSeq(schema, obj, ctx) {
          const seq2 = new resolveSeq.YAMLSeq(schema);
          if (obj && obj[Symbol.iterator]) {
            for (const it2 of obj) {
              const v = schema.createNode(it2, ctx.wrapScalars, null, ctx);
              seq2.items.push(v);
            }
          }
          return seq2;
        }
        var seq = {
          createNode: createSeq,
          default: true,
          nodeClass: resolveSeq.YAMLSeq,
          tag: "tag:yaml.org,2002:seq",
          resolve: resolveSeq.resolveSeq
        };
        var string = {
          identify: (value2) => typeof value2 === "string",
          default: true,
          tag: "tag:yaml.org,2002:str",
          resolve: resolveSeq.resolveString,
          stringify(item, ctx, onComment, onChompKeep) {
            ctx = Object.assign({
              actualString: true
            }, ctx);
            return resolveSeq.stringifyString(item, ctx, onComment, onChompKeep);
          },
          options: resolveSeq.strOptions
        };
        var failsafe = [map, seq, string];
        var intIdentify$2 = (value2) => typeof value2 === "bigint" || Number.isInteger(value2);
        var intResolve$1 = (src, part, radix) => resolveSeq.intOptions.asBigInt ? BigInt(src) : parseInt(part, radix);
        function intStringify$1(node, radix, prefix) {
          const {
            value: value2
          } = node;
          if (intIdentify$2(value2) && value2 >= 0)
            return prefix + value2.toString(radix);
          return resolveSeq.stringifyNumber(node);
        }
        var nullObj = {
          identify: (value2) => value2 == null,
          createNode: (schema, value2, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null,
          default: true,
          tag: "tag:yaml.org,2002:null",
          test: /^(?:~|[Nn]ull|NULL)?$/,
          resolve: () => null,
          options: resolveSeq.nullOptions,
          stringify: () => resolveSeq.nullOptions.nullStr
        };
        var boolObj = {
          identify: (value2) => typeof value2 === "boolean",
          default: true,
          tag: "tag:yaml.org,2002:bool",
          test: /^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/,
          resolve: (str) => str[0] === "t" || str[0] === "T",
          options: resolveSeq.boolOptions,
          stringify: ({
            value: value2
          }) => value2 ? resolveSeq.boolOptions.trueStr : resolveSeq.boolOptions.falseStr
        };
        var octObj = {
          identify: (value2) => intIdentify$2(value2) && value2 >= 0,
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "OCT",
          test: /^0o([0-7]+)$/,
          resolve: (str, oct) => intResolve$1(str, oct, 8),
          options: resolveSeq.intOptions,
          stringify: (node) => intStringify$1(node, 8, "0o")
        };
        var intObj = {
          identify: intIdentify$2,
          default: true,
          tag: "tag:yaml.org,2002:int",
          test: /^[-+]?[0-9]+$/,
          resolve: (str) => intResolve$1(str, str, 10),
          options: resolveSeq.intOptions,
          stringify: resolveSeq.stringifyNumber
        };
        var hexObj = {
          identify: (value2) => intIdentify$2(value2) && value2 >= 0,
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "HEX",
          test: /^0x([0-9a-fA-F]+)$/,
          resolve: (str, hex) => intResolve$1(str, hex, 16),
          options: resolveSeq.intOptions,
          stringify: (node) => intStringify$1(node, 16, "0x")
        };
        var nanObj = {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          test: /^(?:[-+]?\.inf|(\.nan))$/i,
          resolve: (str, nan) => nan ? NaN : str[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY,
          stringify: resolveSeq.stringifyNumber
        };
        var expObj = {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          format: "EXP",
          test: /^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/,
          resolve: (str) => parseFloat(str),
          stringify: ({
            value: value2
          }) => Number(value2).toExponential()
        };
        var floatObj = {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          test: /^[-+]?(?:\.([0-9]+)|[0-9]+\.([0-9]*))$/,
          resolve(str, frac1, frac2) {
            const frac = frac1 || frac2;
            const node = new resolveSeq.Scalar(parseFloat(str));
            if (frac && frac[frac.length - 1] === "0")
              node.minFractionDigits = frac.length;
            return node;
          },
          stringify: resolveSeq.stringifyNumber
        };
        var core = failsafe.concat([nullObj, boolObj, octObj, intObj, hexObj, nanObj, expObj, floatObj]);
        var intIdentify$1 = (value2) => typeof value2 === "bigint" || Number.isInteger(value2);
        var stringifyJSON = ({
          value: value2
        }) => JSON.stringify(value2);
        var json = [map, seq, {
          identify: (value2) => typeof value2 === "string",
          default: true,
          tag: "tag:yaml.org,2002:str",
          resolve: resolveSeq.resolveString,
          stringify: stringifyJSON
        }, {
          identify: (value2) => value2 == null,
          createNode: (schema, value2, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null,
          default: true,
          tag: "tag:yaml.org,2002:null",
          test: /^null$/,
          resolve: () => null,
          stringify: stringifyJSON
        }, {
          identify: (value2) => typeof value2 === "boolean",
          default: true,
          tag: "tag:yaml.org,2002:bool",
          test: /^true|false$/,
          resolve: (str) => str === "true",
          stringify: stringifyJSON
        }, {
          identify: intIdentify$1,
          default: true,
          tag: "tag:yaml.org,2002:int",
          test: /^-?(?:0|[1-9][0-9]*)$/,
          resolve: (str) => resolveSeq.intOptions.asBigInt ? BigInt(str) : parseInt(str, 10),
          stringify: ({
            value: value2
          }) => intIdentify$1(value2) ? value2.toString() : JSON.stringify(value2)
        }, {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          test: /^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/,
          resolve: (str) => parseFloat(str),
          stringify: stringifyJSON
        }];
        json.scalarFallback = (str) => {
          throw new SyntaxError(`Unresolved plain scalar ${JSON.stringify(str)}`);
        };
        var boolStringify = ({
          value: value2
        }) => value2 ? resolveSeq.boolOptions.trueStr : resolveSeq.boolOptions.falseStr;
        var intIdentify = (value2) => typeof value2 === "bigint" || Number.isInteger(value2);
        function intResolve(sign, src, radix) {
          let str = src.replace(/_/g, "");
          if (resolveSeq.intOptions.asBigInt) {
            switch (radix) {
              case 2:
                str = `0b${str}`;
                break;
              case 8:
                str = `0o${str}`;
                break;
              case 16:
                str = `0x${str}`;
                break;
            }
            const n2 = BigInt(str);
            return sign === "-" ? BigInt(-1) * n2 : n2;
          }
          const n = parseInt(str, radix);
          return sign === "-" ? -1 * n : n;
        }
        function intStringify(node, radix, prefix) {
          const {
            value: value2
          } = node;
          if (intIdentify(value2)) {
            const str = value2.toString(radix);
            return value2 < 0 ? "-" + prefix + str.substr(1) : prefix + str;
          }
          return resolveSeq.stringifyNumber(node);
        }
        var yaml11 = failsafe.concat([{
          identify: (value2) => value2 == null,
          createNode: (schema, value2, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null,
          default: true,
          tag: "tag:yaml.org,2002:null",
          test: /^(?:~|[Nn]ull|NULL)?$/,
          resolve: () => null,
          options: resolveSeq.nullOptions,
          stringify: () => resolveSeq.nullOptions.nullStr
        }, {
          identify: (value2) => typeof value2 === "boolean",
          default: true,
          tag: "tag:yaml.org,2002:bool",
          test: /^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/,
          resolve: () => true,
          options: resolveSeq.boolOptions,
          stringify: boolStringify
        }, {
          identify: (value2) => typeof value2 === "boolean",
          default: true,
          tag: "tag:yaml.org,2002:bool",
          test: /^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/i,
          resolve: () => false,
          options: resolveSeq.boolOptions,
          stringify: boolStringify
        }, {
          identify: intIdentify,
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "BIN",
          test: /^([-+]?)0b([0-1_]+)$/,
          resolve: (str, sign, bin) => intResolve(sign, bin, 2),
          stringify: (node) => intStringify(node, 2, "0b")
        }, {
          identify: intIdentify,
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "OCT",
          test: /^([-+]?)0([0-7_]+)$/,
          resolve: (str, sign, oct) => intResolve(sign, oct, 8),
          stringify: (node) => intStringify(node, 8, "0")
        }, {
          identify: intIdentify,
          default: true,
          tag: "tag:yaml.org,2002:int",
          test: /^([-+]?)([0-9][0-9_]*)$/,
          resolve: (str, sign, abs) => intResolve(sign, abs, 10),
          stringify: resolveSeq.stringifyNumber
        }, {
          identify: intIdentify,
          default: true,
          tag: "tag:yaml.org,2002:int",
          format: "HEX",
          test: /^([-+]?)0x([0-9a-fA-F_]+)$/,
          resolve: (str, sign, hex) => intResolve(sign, hex, 16),
          stringify: (node) => intStringify(node, 16, "0x")
        }, {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          test: /^(?:[-+]?\.inf|(\.nan))$/i,
          resolve: (str, nan) => nan ? NaN : str[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY,
          stringify: resolveSeq.stringifyNumber
        }, {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          format: "EXP",
          test: /^[-+]?([0-9][0-9_]*)?(\.[0-9_]*)?[eE][-+]?[0-9]+$/,
          resolve: (str) => parseFloat(str.replace(/_/g, "")),
          stringify: ({
            value: value2
          }) => Number(value2).toExponential()
        }, {
          identify: (value2) => typeof value2 === "number",
          default: true,
          tag: "tag:yaml.org,2002:float",
          test: /^[-+]?(?:[0-9][0-9_]*)?\.([0-9_]*)$/,
          resolve(str, frac) {
            const node = new resolveSeq.Scalar(parseFloat(str.replace(/_/g, "")));
            if (frac) {
              const f = frac.replace(/_/g, "");
              if (f[f.length - 1] === "0")
                node.minFractionDigits = f.length;
            }
            return node;
          },
          stringify: resolveSeq.stringifyNumber
        }], warnings.binary, warnings.omap, warnings.pairs, warnings.set, warnings.intTime, warnings.floatTime, warnings.timestamp);
        var schemas = {
          core,
          failsafe,
          json,
          yaml11
        };
        var tags = {
          binary: warnings.binary,
          bool: boolObj,
          float: floatObj,
          floatExp: expObj,
          floatNaN: nanObj,
          floatTime: warnings.floatTime,
          int: intObj,
          intHex: hexObj,
          intOct: octObj,
          intTime: warnings.intTime,
          map,
          null: nullObj,
          omap: warnings.omap,
          pairs: warnings.pairs,
          seq,
          set: warnings.set,
          timestamp: warnings.timestamp
        };
        function findTagObject(value2, tagName, tags2) {
          if (tagName) {
            const match = tags2.filter((t3) => t3.tag === tagName);
            const tagObj = match.find((t3) => !t3.format) || match[0];
            if (!tagObj)
              throw new Error(`Tag ${tagName} not found`);
            return tagObj;
          }
          return tags2.find((t3) => (t3.identify && t3.identify(value2) || t3.class && value2 instanceof t3.class) && !t3.format);
        }
        function createNode(value2, tagName, ctx) {
          if (value2 instanceof resolveSeq.Node)
            return value2;
          const {
            defaultPrefix,
            onTagObj,
            prevObjects,
            schema,
            wrapScalars
          } = ctx;
          if (tagName && tagName.startsWith("!!"))
            tagName = defaultPrefix + tagName.slice(2);
          let tagObj = findTagObject(value2, tagName, schema.tags);
          if (!tagObj) {
            if (typeof value2.toJSON === "function")
              value2 = value2.toJSON();
            if (!value2 || typeof value2 !== "object")
              return wrapScalars ? new resolveSeq.Scalar(value2) : value2;
            tagObj = value2 instanceof Map ? map : value2[Symbol.iterator] ? seq : map;
          }
          if (onTagObj) {
            onTagObj(tagObj);
            delete ctx.onTagObj;
          }
          const obj = {
            value: void 0,
            node: void 0
          };
          if (value2 && typeof value2 === "object" && prevObjects) {
            const prev = prevObjects.get(value2);
            if (prev) {
              const alias = new resolveSeq.Alias(prev);
              ctx.aliasNodes.push(alias);
              return alias;
            }
            obj.value = value2;
            prevObjects.set(value2, obj);
          }
          obj.node = tagObj.createNode ? tagObj.createNode(ctx.schema, value2, ctx) : wrapScalars ? new resolveSeq.Scalar(value2) : value2;
          if (tagName && obj.node instanceof resolveSeq.Node)
            obj.node.tag = tagName;
          return obj.node;
        }
        function getSchemaTags(schemas2, knownTags, customTags, schemaId) {
          let tags2 = schemas2[schemaId.replace(/\W/g, "")];
          if (!tags2) {
            const keys3 = Object.keys(schemas2).map((key) => JSON.stringify(key)).join(", ");
            throw new Error(`Unknown schema "${schemaId}"; use one of ${keys3}`);
          }
          if (Array.isArray(customTags)) {
            for (const tag of customTags)
              tags2 = tags2.concat(tag);
          } else if (typeof customTags === "function") {
            tags2 = customTags(tags2.slice());
          }
          for (let i = 0; i < tags2.length; ++i) {
            const tag = tags2[i];
            if (typeof tag === "string") {
              const tagObj = knownTags[tag];
              if (!tagObj) {
                const keys3 = Object.keys(knownTags).map((key) => JSON.stringify(key)).join(", ");
                throw new Error(`Unknown custom tag "${tag}"; use one of ${keys3}`);
              }
              tags2[i] = tagObj;
            }
          }
          return tags2;
        }
        var sortMapEntriesByKey = (a, b) => a.key < b.key ? -1 : a.key > b.key ? 1 : 0;
        var Schema = class {
          constructor({
            customTags,
            merge: merge4,
            schema,
            sortMapEntries,
            tags: deprecatedCustomTags
          }) {
            this.merge = !!merge4;
            this.name = schema;
            this.sortMapEntries = sortMapEntries === true ? sortMapEntriesByKey : sortMapEntries || null;
            if (!customTags && deprecatedCustomTags)
              warnings.warnOptionDeprecation("tags", "customTags");
            this.tags = getSchemaTags(schemas, tags, customTags || deprecatedCustomTags, schema);
          }
          createNode(value2, wrapScalars, tagName, ctx) {
            const baseCtx = {
              defaultPrefix: Schema.defaultPrefix,
              schema: this,
              wrapScalars
            };
            const createCtx = ctx ? Object.assign(ctx, baseCtx) : baseCtx;
            return createNode(value2, tagName, createCtx);
          }
          createPair(key, value2, ctx) {
            if (!ctx)
              ctx = {
                wrapScalars: true
              };
            const k = this.createNode(key, ctx.wrapScalars, null, ctx);
            const v = this.createNode(value2, ctx.wrapScalars, null, ctx);
            return new resolveSeq.Pair(k, v);
          }
        };
        PlainValue._defineProperty(Schema, "defaultPrefix", PlainValue.defaultTagPrefix);
        PlainValue._defineProperty(Schema, "defaultTags", PlainValue.defaultTags);
        exports2.Schema = Schema;
      }
    });
    var require_Document_9b4560a1 = __commonJS2({
      "node_modules/yaml/dist/Document-9b4560a1.js"(exports2) {
        "use strict";
        var PlainValue = require_PlainValue_ec8e588e();
        var resolveSeq = require_resolveSeq_d03cb037();
        var Schema = require_Schema_88e323a7();
        var defaultOptions2 = {
          anchorPrefix: "a",
          customTags: null,
          indent: 2,
          indentSeq: true,
          keepCstNodes: false,
          keepNodeTypes: true,
          keepBlobsInJSON: true,
          mapAsMap: false,
          maxAliasCount: 100,
          prettyErrors: false,
          simpleKeys: false,
          version: "1.2"
        };
        var scalarOptions = {
          get binary() {
            return resolveSeq.binaryOptions;
          },
          set binary(opt) {
            Object.assign(resolveSeq.binaryOptions, opt);
          },
          get bool() {
            return resolveSeq.boolOptions;
          },
          set bool(opt) {
            Object.assign(resolveSeq.boolOptions, opt);
          },
          get int() {
            return resolveSeq.intOptions;
          },
          set int(opt) {
            Object.assign(resolveSeq.intOptions, opt);
          },
          get null() {
            return resolveSeq.nullOptions;
          },
          set null(opt) {
            Object.assign(resolveSeq.nullOptions, opt);
          },
          get str() {
            return resolveSeq.strOptions;
          },
          set str(opt) {
            Object.assign(resolveSeq.strOptions, opt);
          }
        };
        var documentOptions = {
          "1.0": {
            schema: "yaml-1.1",
            merge: true,
            tagPrefixes: [{
              handle: "!",
              prefix: PlainValue.defaultTagPrefix
            }, {
              handle: "!!",
              prefix: "tag:private.yaml.org,2002:"
            }]
          },
          1.1: {
            schema: "yaml-1.1",
            merge: true,
            tagPrefixes: [{
              handle: "!",
              prefix: "!"
            }, {
              handle: "!!",
              prefix: PlainValue.defaultTagPrefix
            }]
          },
          1.2: {
            schema: "core",
            merge: false,
            tagPrefixes: [{
              handle: "!",
              prefix: "!"
            }, {
              handle: "!!",
              prefix: PlainValue.defaultTagPrefix
            }]
          }
        };
        function stringifyTag(doc, tag) {
          if ((doc.version || doc.options.version) === "1.0") {
            const priv = tag.match(/^tag:private\.yaml\.org,2002:([^:/]+)$/);
            if (priv)
              return "!" + priv[1];
            const vocab = tag.match(/^tag:([a-zA-Z0-9-]+)\.yaml\.org,2002:(.*)/);
            return vocab ? `!${vocab[1]}/${vocab[2]}` : `!${tag.replace(/^tag:/, "")}`;
          }
          let p = doc.tagPrefixes.find((p2) => tag.indexOf(p2.prefix) === 0);
          if (!p) {
            const dtp = doc.getDefaults().tagPrefixes;
            p = dtp && dtp.find((p2) => tag.indexOf(p2.prefix) === 0);
          }
          if (!p)
            return tag[0] === "!" ? tag : `!<${tag}>`;
          const suffix = tag.substr(p.prefix.length).replace(/[!,[\]{}]/g, (ch) => ({
            "!": "%21",
            ",": "%2C",
            "[": "%5B",
            "]": "%5D",
            "{": "%7B",
            "}": "%7D"
          })[ch]);
          return p.handle + suffix;
        }
        function getTagObject(tags, item) {
          if (item instanceof resolveSeq.Alias)
            return resolveSeq.Alias;
          if (item.tag) {
            const match = tags.filter((t3) => t3.tag === item.tag);
            if (match.length > 0)
              return match.find((t3) => t3.format === item.format) || match[0];
          }
          let tagObj, obj;
          if (item instanceof resolveSeq.Scalar) {
            obj = item.value;
            const match = tags.filter((t3) => t3.identify && t3.identify(obj) || t3.class && obj instanceof t3.class);
            tagObj = match.find((t3) => t3.format === item.format) || match.find((t3) => !t3.format);
          } else {
            obj = item;
            tagObj = tags.find((t3) => t3.nodeClass && obj instanceof t3.nodeClass);
          }
          if (!tagObj) {
            const name = obj && obj.constructor ? obj.constructor.name : typeof obj;
            throw new Error(`Tag not resolved for ${name} value`);
          }
          return tagObj;
        }
        function stringifyProps(node, tagObj, {
          anchors,
          doc
        }) {
          const props = [];
          const anchor = doc.anchors.getName(node);
          if (anchor) {
            anchors[anchor] = node;
            props.push(`&${anchor}`);
          }
          if (node.tag) {
            props.push(stringifyTag(doc, node.tag));
          } else if (!tagObj.default) {
            props.push(stringifyTag(doc, tagObj.tag));
          }
          return props.join(" ");
        }
        function stringify(item, ctx, onComment, onChompKeep) {
          const {
            anchors,
            schema
          } = ctx.doc;
          let tagObj;
          if (!(item instanceof resolveSeq.Node)) {
            const createCtx = {
              aliasNodes: [],
              onTagObj: (o) => tagObj = o,
              prevObjects: /* @__PURE__ */ new Map()
            };
            item = schema.createNode(item, true, null, createCtx);
            for (const alias of createCtx.aliasNodes) {
              alias.source = alias.source.node;
              let name = anchors.getName(alias.source);
              if (!name) {
                name = anchors.newName();
                anchors.map[name] = alias.source;
              }
            }
          }
          if (item instanceof resolveSeq.Pair)
            return item.toString(ctx, onComment, onChompKeep);
          if (!tagObj)
            tagObj = getTagObject(schema.tags, item);
          const props = stringifyProps(item, tagObj, ctx);
          if (props.length > 0)
            ctx.indentAtStart = (ctx.indentAtStart || 0) + props.length + 1;
          const str = typeof tagObj.stringify === "function" ? tagObj.stringify(item, ctx, onComment, onChompKeep) : item instanceof resolveSeq.Scalar ? resolveSeq.stringifyString(item, ctx, onComment, onChompKeep) : item.toString(ctx, onComment, onChompKeep);
          if (!props)
            return str;
          return item instanceof resolveSeq.Scalar || str[0] === "{" || str[0] === "[" ? `${props} ${str}` : `${props}
${ctx.indent}${str}`;
        }
        var Anchors = class {
          static validAnchorNode(node) {
            return node instanceof resolveSeq.Scalar || node instanceof resolveSeq.YAMLSeq || node instanceof resolveSeq.YAMLMap;
          }
          constructor(prefix) {
            PlainValue._defineProperty(this, "map", /* @__PURE__ */ Object.create(null));
            this.prefix = prefix;
          }
          createAlias(node, name) {
            this.setAnchor(node, name);
            return new resolveSeq.Alias(node);
          }
          createMergePair(...sources) {
            const merge4 = new resolveSeq.Merge();
            merge4.value.items = sources.map((s) => {
              if (s instanceof resolveSeq.Alias) {
                if (s.source instanceof resolveSeq.YAMLMap)
                  return s;
              } else if (s instanceof resolveSeq.YAMLMap) {
                return this.createAlias(s);
              }
              throw new Error("Merge sources must be Map nodes or their Aliases");
            });
            return merge4;
          }
          getName(node) {
            const {
              map
            } = this;
            return Object.keys(map).find((a) => map[a] === node);
          }
          getNames() {
            return Object.keys(this.map);
          }
          getNode(name) {
            return this.map[name];
          }
          newName(prefix) {
            if (!prefix)
              prefix = this.prefix;
            const names = Object.keys(this.map);
            for (let i = 1; true; ++i) {
              const name = `${prefix}${i}`;
              if (!names.includes(name))
                return name;
            }
          }
          resolveNodes() {
            const {
              map,
              _cstAliases
            } = this;
            Object.keys(map).forEach((a) => {
              map[a] = map[a].resolved;
            });
            _cstAliases.forEach((a) => {
              a.source = a.source.resolved;
            });
            delete this._cstAliases;
          }
          setAnchor(node, name) {
            if (node != null && !Anchors.validAnchorNode(node)) {
              throw new Error("Anchors may only be set for Scalar, Seq and Map nodes");
            }
            if (name && /[\x00-\x19\s,[\]{}]/.test(name)) {
              throw new Error("Anchor names must not contain whitespace or control characters");
            }
            const {
              map
            } = this;
            const prev = node && Object.keys(map).find((a) => map[a] === node);
            if (prev) {
              if (!name) {
                return prev;
              } else if (prev !== name) {
                delete map[prev];
                map[name] = node;
              }
            } else {
              if (!name) {
                if (!node)
                  return null;
                name = this.newName();
              }
              map[name] = node;
            }
            return name;
          }
        };
        var visit = (node, tags) => {
          if (node && typeof node === "object") {
            const {
              tag
            } = node;
            if (node instanceof resolveSeq.Collection) {
              if (tag)
                tags[tag] = true;
              node.items.forEach((n) => visit(n, tags));
            } else if (node instanceof resolveSeq.Pair) {
              visit(node.key, tags);
              visit(node.value, tags);
            } else if (node instanceof resolveSeq.Scalar) {
              if (tag)
                tags[tag] = true;
            }
          }
          return tags;
        };
        var listTagNames = (node) => Object.keys(visit(node, {}));
        function parseContents(doc, contents) {
          const comments = {
            before: [],
            after: []
          };
          let body = void 0;
          let spaceBefore = false;
          for (const node of contents) {
            if (node.valueRange) {
              if (body !== void 0) {
                const msg = "Document contains trailing content not separated by a ... or --- line";
                doc.errors.push(new PlainValue.YAMLSyntaxError(node, msg));
                break;
              }
              const res = resolveSeq.resolveNode(doc, node);
              if (spaceBefore) {
                res.spaceBefore = true;
                spaceBefore = false;
              }
              body = res;
            } else if (node.comment !== null) {
              const cc = body === void 0 ? comments.before : comments.after;
              cc.push(node.comment);
            } else if (node.type === PlainValue.Type.BLANK_LINE) {
              spaceBefore = true;
              if (body === void 0 && comments.before.length > 0 && !doc.commentBefore) {
                doc.commentBefore = comments.before.join("\n");
                comments.before = [];
              }
            }
          }
          doc.contents = body || null;
          if (!body) {
            doc.comment = comments.before.concat(comments.after).join("\n") || null;
          } else {
            const cb = comments.before.join("\n");
            if (cb) {
              const cbNode = body instanceof resolveSeq.Collection && body.items[0] ? body.items[0] : body;
              cbNode.commentBefore = cbNode.commentBefore ? `${cb}
${cbNode.commentBefore}` : cb;
            }
            doc.comment = comments.after.join("\n") || null;
          }
        }
        function resolveTagDirective({
          tagPrefixes
        }, directive) {
          const [handle, prefix] = directive.parameters;
          if (!handle || !prefix) {
            const msg = "Insufficient parameters given for %TAG directive";
            throw new PlainValue.YAMLSemanticError(directive, msg);
          }
          if (tagPrefixes.some((p) => p.handle === handle)) {
            const msg = "The %TAG directive must only be given at most once per handle in the same document.";
            throw new PlainValue.YAMLSemanticError(directive, msg);
          }
          return {
            handle,
            prefix
          };
        }
        function resolveYamlDirective(doc, directive) {
          let [version2] = directive.parameters;
          if (directive.name === "YAML:1.0")
            version2 = "1.0";
          if (!version2) {
            const msg = "Insufficient parameters given for %YAML directive";
            throw new PlainValue.YAMLSemanticError(directive, msg);
          }
          if (!documentOptions[version2]) {
            const v0 = doc.version || doc.options.version;
            const msg = `Document will be parsed as YAML ${v0} rather than YAML ${version2}`;
            doc.warnings.push(new PlainValue.YAMLWarning(directive, msg));
          }
          return version2;
        }
        function parseDirectives(doc, directives, prevDoc) {
          const directiveComments = [];
          let hasDirectives = false;
          for (const directive of directives) {
            const {
              comment,
              name
            } = directive;
            switch (name) {
              case "TAG":
                try {
                  doc.tagPrefixes.push(resolveTagDirective(doc, directive));
                } catch (error) {
                  doc.errors.push(error);
                }
                hasDirectives = true;
                break;
              case "YAML":
              case "YAML:1.0":
                if (doc.version) {
                  const msg = "The %YAML directive must only be given at most once per document.";
                  doc.errors.push(new PlainValue.YAMLSemanticError(directive, msg));
                }
                try {
                  doc.version = resolveYamlDirective(doc, directive);
                } catch (error) {
                  doc.errors.push(error);
                }
                hasDirectives = true;
                break;
              default:
                if (name) {
                  const msg = `YAML only supports %TAG and %YAML directives, and not %${name}`;
                  doc.warnings.push(new PlainValue.YAMLWarning(directive, msg));
                }
            }
            if (comment)
              directiveComments.push(comment);
          }
          if (prevDoc && !hasDirectives && "1.1" === (doc.version || prevDoc.version || doc.options.version)) {
            const copyTagPrefix = ({
              handle,
              prefix
            }) => ({
              handle,
              prefix
            });
            doc.tagPrefixes = prevDoc.tagPrefixes.map(copyTagPrefix);
            doc.version = prevDoc.version;
          }
          doc.commentBefore = directiveComments.join("\n") || null;
        }
        function assertCollection(contents) {
          if (contents instanceof resolveSeq.Collection)
            return true;
          throw new Error("Expected a YAML collection as document contents");
        }
        var Document = class {
          constructor(options) {
            this.anchors = new Anchors(options.anchorPrefix);
            this.commentBefore = null;
            this.comment = null;
            this.contents = null;
            this.directivesEndMarker = null;
            this.errors = [];
            this.options = options;
            this.schema = null;
            this.tagPrefixes = [];
            this.version = null;
            this.warnings = [];
          }
          add(value2) {
            assertCollection(this.contents);
            return this.contents.add(value2);
          }
          addIn(path2, value2) {
            assertCollection(this.contents);
            this.contents.addIn(path2, value2);
          }
          delete(key) {
            assertCollection(this.contents);
            return this.contents.delete(key);
          }
          deleteIn(path2) {
            if (resolveSeq.isEmptyPath(path2)) {
              if (this.contents == null)
                return false;
              this.contents = null;
              return true;
            }
            assertCollection(this.contents);
            return this.contents.deleteIn(path2);
          }
          getDefaults() {
            return Document.defaults[this.version] || Document.defaults[this.options.version] || {};
          }
          get(key, keepScalar) {
            return this.contents instanceof resolveSeq.Collection ? this.contents.get(key, keepScalar) : void 0;
          }
          getIn(path2, keepScalar) {
            if (resolveSeq.isEmptyPath(path2))
              return !keepScalar && this.contents instanceof resolveSeq.Scalar ? this.contents.value : this.contents;
            return this.contents instanceof resolveSeq.Collection ? this.contents.getIn(path2, keepScalar) : void 0;
          }
          has(key) {
            return this.contents instanceof resolveSeq.Collection ? this.contents.has(key) : false;
          }
          hasIn(path2) {
            if (resolveSeq.isEmptyPath(path2))
              return this.contents !== void 0;
            return this.contents instanceof resolveSeq.Collection ? this.contents.hasIn(path2) : false;
          }
          set(key, value2) {
            assertCollection(this.contents);
            this.contents.set(key, value2);
          }
          setIn(path2, value2) {
            if (resolveSeq.isEmptyPath(path2))
              this.contents = value2;
            else {
              assertCollection(this.contents);
              this.contents.setIn(path2, value2);
            }
          }
          setSchema(id, customTags) {
            if (!id && !customTags && this.schema)
              return;
            if (typeof id === "number")
              id = id.toFixed(1);
            if (id === "1.0" || id === "1.1" || id === "1.2") {
              if (this.version)
                this.version = id;
              else
                this.options.version = id;
              delete this.options.schema;
            } else if (id && typeof id === "string") {
              this.options.schema = id;
            }
            if (Array.isArray(customTags))
              this.options.customTags = customTags;
            const opt = Object.assign({}, this.getDefaults(), this.options);
            this.schema = new Schema.Schema(opt);
          }
          parse(node, prevDoc) {
            if (this.options.keepCstNodes)
              this.cstNode = node;
            if (this.options.keepNodeTypes)
              this.type = "DOCUMENT";
            const {
              directives = [],
              contents = [],
              directivesEndMarker,
              error,
              valueRange
            } = node;
            if (error) {
              if (!error.source)
                error.source = this;
              this.errors.push(error);
            }
            parseDirectives(this, directives, prevDoc);
            if (directivesEndMarker)
              this.directivesEndMarker = true;
            this.range = valueRange ? [valueRange.start, valueRange.end] : null;
            this.setSchema();
            this.anchors._cstAliases = [];
            parseContents(this, contents);
            this.anchors.resolveNodes();
            if (this.options.prettyErrors) {
              for (const error2 of this.errors)
                if (error2 instanceof PlainValue.YAMLError)
                  error2.makePretty();
              for (const warn of this.warnings)
                if (warn instanceof PlainValue.YAMLError)
                  warn.makePretty();
            }
            return this;
          }
          listNonDefaultTags() {
            return listTagNames(this.contents).filter((t3) => t3.indexOf(Schema.Schema.defaultPrefix) !== 0);
          }
          setTagPrefix(handle, prefix) {
            if (handle[0] !== "!" || handle[handle.length - 1] !== "!")
              throw new Error("Handle must start and end with !");
            if (prefix) {
              const prev = this.tagPrefixes.find((p) => p.handle === handle);
              if (prev)
                prev.prefix = prefix;
              else
                this.tagPrefixes.push({
                  handle,
                  prefix
                });
            } else {
              this.tagPrefixes = this.tagPrefixes.filter((p) => p.handle !== handle);
            }
          }
          toJSON(arg, onAnchor) {
            const {
              keepBlobsInJSON,
              mapAsMap,
              maxAliasCount
            } = this.options;
            const keep = keepBlobsInJSON && (typeof arg !== "string" || !(this.contents instanceof resolveSeq.Scalar));
            const ctx = {
              doc: this,
              indentStep: "  ",
              keep,
              mapAsMap: keep && !!mapAsMap,
              maxAliasCount,
              stringify
            };
            const anchorNames = Object.keys(this.anchors.map);
            if (anchorNames.length > 0)
              ctx.anchors = new Map(anchorNames.map((name) => [this.anchors.map[name], {
                alias: [],
                aliasCount: 0,
                count: 1
              }]));
            const res = resolveSeq.toJSON(this.contents, arg, ctx);
            if (typeof onAnchor === "function" && ctx.anchors)
              for (const {
                count,
                res: res2
              } of ctx.anchors.values())
                onAnchor(res2, count);
            return res;
          }
          toString() {
            if (this.errors.length > 0)
              throw new Error("Document with errors cannot be stringified");
            const indentSize = this.options.indent;
            if (!Number.isInteger(indentSize) || indentSize <= 0) {
              const s = JSON.stringify(indentSize);
              throw new Error(`"indent" option must be a positive integer, not ${s}`);
            }
            this.setSchema();
            const lines = [];
            let hasDirectives = false;
            if (this.version) {
              let vd = "%YAML 1.2";
              if (this.schema.name === "yaml-1.1") {
                if (this.version === "1.0")
                  vd = "%YAML:1.0";
                else if (this.version === "1.1")
                  vd = "%YAML 1.1";
              }
              lines.push(vd);
              hasDirectives = true;
            }
            const tagNames = this.listNonDefaultTags();
            this.tagPrefixes.forEach(({
              handle,
              prefix
            }) => {
              if (tagNames.some((t3) => t3.indexOf(prefix) === 0)) {
                lines.push(`%TAG ${handle} ${prefix}`);
                hasDirectives = true;
              }
            });
            if (hasDirectives || this.directivesEndMarker)
              lines.push("---");
            if (this.commentBefore) {
              if (hasDirectives || !this.directivesEndMarker)
                lines.unshift("");
              lines.unshift(this.commentBefore.replace(/^/gm, "#"));
            }
            const ctx = {
              anchors: /* @__PURE__ */ Object.create(null),
              doc: this,
              indent: "",
              indentStep: " ".repeat(indentSize),
              stringify
            };
            let chompKeep = false;
            let contentComment = null;
            if (this.contents) {
              if (this.contents instanceof resolveSeq.Node) {
                if (this.contents.spaceBefore && (hasDirectives || this.directivesEndMarker))
                  lines.push("");
                if (this.contents.commentBefore)
                  lines.push(this.contents.commentBefore.replace(/^/gm, "#"));
                ctx.forceBlockIndent = !!this.comment;
                contentComment = this.contents.comment;
              }
              const onChompKeep = contentComment ? null : () => chompKeep = true;
              const body = stringify(this.contents, ctx, () => contentComment = null, onChompKeep);
              lines.push(resolveSeq.addComment(body, "", contentComment));
            } else if (this.contents !== void 0) {
              lines.push(stringify(this.contents, ctx));
            }
            if (this.comment) {
              if ((!chompKeep || contentComment) && lines[lines.length - 1] !== "")
                lines.push("");
              lines.push(this.comment.replace(/^/gm, "#"));
            }
            return lines.join("\n") + "\n";
          }
        };
        PlainValue._defineProperty(Document, "defaults", documentOptions);
        exports2.Document = Document;
        exports2.defaultOptions = defaultOptions2;
        exports2.scalarOptions = scalarOptions;
      }
    });
    var require_dist = __commonJS2({
      "node_modules/yaml/dist/index.js"(exports2) {
        "use strict";
        var parseCst = require_parse_cst();
        var Document$1 = require_Document_9b4560a1();
        var Schema = require_Schema_88e323a7();
        var PlainValue = require_PlainValue_ec8e588e();
        var warnings = require_warnings_1000a372();
        require_resolveSeq_d03cb037();
        function createNode(value2, wrapScalars = true, tag) {
          if (tag === void 0 && typeof wrapScalars === "string") {
            tag = wrapScalars;
            wrapScalars = true;
          }
          const options = Object.assign({}, Document$1.Document.defaults[Document$1.defaultOptions.version], Document$1.defaultOptions);
          const schema = new Schema.Schema(options);
          return schema.createNode(value2, wrapScalars, tag);
        }
        var Document = class extends Document$1.Document {
          constructor(options) {
            super(Object.assign({}, Document$1.defaultOptions, options));
          }
        };
        function parseAllDocuments(src, options) {
          const stream = [];
          let prev;
          for (const cstDoc of parseCst.parse(src)) {
            const doc = new Document(options);
            doc.parse(cstDoc, prev);
            stream.push(doc);
            prev = doc;
          }
          return stream;
        }
        function parseDocument(src, options) {
          const cst = parseCst.parse(src);
          const doc = new Document(options).parse(cst[0]);
          if (cst.length > 1) {
            const errMsg = "Source contains multiple documents; please use YAML.parseAllDocuments()";
            doc.errors.unshift(new PlainValue.YAMLSemanticError(cst[1], errMsg));
          }
          return doc;
        }
        function parse3(src, options) {
          const doc = parseDocument(src, options);
          doc.warnings.forEach((warning) => warnings.warn(warning));
          if (doc.errors.length > 0)
            throw doc.errors[0];
          return doc.toJSON();
        }
        function stringify(value2, options) {
          const doc = new Document(options);
          doc.contents = value2;
          return String(doc);
        }
        var YAML = {
          createNode,
          defaultOptions: Document$1.defaultOptions,
          Document,
          parse: parse3,
          parseAllDocuments,
          parseCST: parseCst.parse,
          parseDocument,
          scalarOptions: Document$1.scalarOptions,
          stringify
        };
        exports2.YAML = YAML;
      }
    });
    var require_yaml = __commonJS2({
      "node_modules/yaml/index.js"(exports2, module22) {
        module22.exports = require_dist().YAML;
      }
    });
    var require_loaders = __commonJS2({
      "node_modules/cosmiconfig/dist/loaders.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.loaders = void 0;
        var importFresh;
        var loadJs = function loadJs2(filepath) {
          if (importFresh === void 0) {
            importFresh = require_import_fresh2();
          }
          const result = importFresh(filepath);
          return result;
        };
        var parseJson;
        var loadJson = function loadJson2(filepath, content) {
          if (parseJson === void 0) {
            parseJson = require_parse_json();
          }
          try {
            const result = parseJson(content);
            return result;
          } catch (error) {
            error.message = `JSON Error in ${filepath}:
${error.message}`;
            throw error;
          }
        };
        var yaml;
        var loadYaml = function loadYaml2(filepath, content) {
          if (yaml === void 0) {
            yaml = require_yaml();
          }
          try {
            const result = yaml.parse(content, {
              prettyErrors: true
            });
            return result;
          } catch (error) {
            error.message = `YAML Error in ${filepath}:
${error.message}`;
            throw error;
          }
        };
        var loaders = {
          loadJs,
          loadJson,
          loadYaml
        };
        exports2.loaders = loaders;
      }
    });
    var require_getPropertyByPath = __commonJS2({
      "node_modules/cosmiconfig/dist/getPropertyByPath.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.getPropertyByPath = getPropertyByPath;
        function getPropertyByPath(source, path2) {
          if (typeof path2 === "string" && Object.prototype.hasOwnProperty.call(source, path2)) {
            return source[path2];
          }
          const parsedPath = typeof path2 === "string" ? path2.split(".") : path2;
          return parsedPath.reduce((previous, key) => {
            if (previous === void 0) {
              return previous;
            }
            return previous[key];
          }, source);
        }
      }
    });
    var require_ExplorerBase = __commonJS2({
      "node_modules/cosmiconfig/dist/ExplorerBase.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.getExtensionDescription = getExtensionDescription;
        exports2.ExplorerBase = void 0;
        var _path = _interopRequireDefault(require("path"));
        var _loaders = require_loaders();
        var _getPropertyByPath = require_getPropertyByPath();
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        var ExplorerBase = class {
          constructor(options) {
            if (options.cache === true) {
              this.loadCache = /* @__PURE__ */ new Map();
              this.searchCache = /* @__PURE__ */ new Map();
            }
            this.config = options;
            this.validateConfig();
          }
          clearLoadCache() {
            if (this.loadCache) {
              this.loadCache.clear();
            }
          }
          clearSearchCache() {
            if (this.searchCache) {
              this.searchCache.clear();
            }
          }
          clearCaches() {
            this.clearLoadCache();
            this.clearSearchCache();
          }
          validateConfig() {
            const config = this.config;
            config.searchPlaces.forEach((place) => {
              const loaderKey = _path.default.extname(place) || "noExt";
              const loader = config.loaders[loaderKey];
              if (!loader) {
                throw new Error(`No loader specified for ${getExtensionDescription(place)}, so searchPlaces item "${place}" is invalid`);
              }
              if (typeof loader !== "function") {
                throw new Error(`loader for ${getExtensionDescription(place)} is not a function (type provided: "${typeof loader}"), so searchPlaces item "${place}" is invalid`);
              }
            });
          }
          shouldSearchStopWithResult(result) {
            if (result === null)
              return false;
            if (result.isEmpty && this.config.ignoreEmptySearchPlaces)
              return false;
            return true;
          }
          nextDirectoryToSearch(currentDir, currentResult) {
            if (this.shouldSearchStopWithResult(currentResult)) {
              return null;
            }
            const nextDir = nextDirUp(currentDir);
            if (nextDir === currentDir || currentDir === this.config.stopDir) {
              return null;
            }
            return nextDir;
          }
          loadPackageProp(filepath, content) {
            const parsedContent = _loaders.loaders.loadJson(filepath, content);
            const packagePropValue = (0, _getPropertyByPath.getPropertyByPath)(parsedContent, this.config.packageProp);
            return packagePropValue || null;
          }
          getLoaderEntryForFile(filepath) {
            if (_path.default.basename(filepath) === "package.json") {
              const loader2 = this.loadPackageProp.bind(this);
              return loader2;
            }
            const loaderKey = _path.default.extname(filepath) || "noExt";
            const loader = this.config.loaders[loaderKey];
            if (!loader) {
              throw new Error(`No loader specified for ${getExtensionDescription(filepath)}`);
            }
            return loader;
          }
          loadedContentToCosmiconfigResult(filepath, loadedContent) {
            if (loadedContent === null) {
              return null;
            }
            if (loadedContent === void 0) {
              return {
                filepath,
                config: void 0,
                isEmpty: true
              };
            }
            return {
              config: loadedContent,
              filepath
            };
          }
          validateFilePath(filepath) {
            if (!filepath) {
              throw new Error("load must pass a non-empty string");
            }
          }
        };
        exports2.ExplorerBase = ExplorerBase;
        function nextDirUp(dir) {
          return _path.default.dirname(dir);
        }
        function getExtensionDescription(filepath) {
          const ext = _path.default.extname(filepath);
          return ext ? `extension "${ext}"` : "files without extensions";
        }
      }
    });
    var require_readFile = __commonJS2({
      "node_modules/cosmiconfig/dist/readFile.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.readFile = readFile;
        exports2.readFileSync = readFileSync;
        var _fs = _interopRequireDefault(require("fs"));
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        async function fsReadFileAsync(pathname, encoding) {
          return new Promise((resolve, reject) => {
            _fs.default.readFile(pathname, encoding, (error, contents) => {
              if (error) {
                reject(error);
                return;
              }
              resolve(contents);
            });
          });
        }
        async function readFile(filepath, options = {}) {
          const throwNotFound = options.throwNotFound === true;
          try {
            const content = await fsReadFileAsync(filepath, "utf8");
            return content;
          } catch (error) {
            if (throwNotFound === false && (error.code === "ENOENT" || error.code === "EISDIR")) {
              return null;
            }
            throw error;
          }
        }
        function readFileSync(filepath, options = {}) {
          const throwNotFound = options.throwNotFound === true;
          try {
            const content = _fs.default.readFileSync(filepath, "utf8");
            return content;
          } catch (error) {
            if (throwNotFound === false && (error.code === "ENOENT" || error.code === "EISDIR")) {
              return null;
            }
            throw error;
          }
        }
      }
    });
    var require_cacheWrapper = __commonJS2({
      "node_modules/cosmiconfig/dist/cacheWrapper.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.cacheWrapper = cacheWrapper;
        exports2.cacheWrapperSync = cacheWrapperSync;
        async function cacheWrapper(cache, key, fn) {
          const cached = cache.get(key);
          if (cached !== void 0) {
            return cached;
          }
          const result = await fn();
          cache.set(key, result);
          return result;
        }
        function cacheWrapperSync(cache, key, fn) {
          const cached = cache.get(key);
          if (cached !== void 0) {
            return cached;
          }
          const result = fn();
          cache.set(key, result);
          return result;
        }
      }
    });
    var require_path_type = __commonJS2({
      "node_modules/path-type/index.js"(exports2) {
        "use strict";
        var {
          promisify
        } = require("util");
        var fs2 = require("fs");
        async function isType(fsStatType, statsMethodName, filePath) {
          if (typeof filePath !== "string") {
            throw new TypeError(`Expected a string, got ${typeof filePath}`);
          }
          try {
            const stats = await promisify(fs2[fsStatType])(filePath);
            return stats[statsMethodName]();
          } catch (error) {
            if (error.code === "ENOENT") {
              return false;
            }
            throw error;
          }
        }
        function isTypeSync(fsStatType, statsMethodName, filePath) {
          if (typeof filePath !== "string") {
            throw new TypeError(`Expected a string, got ${typeof filePath}`);
          }
          try {
            return fs2[fsStatType](filePath)[statsMethodName]();
          } catch (error) {
            if (error.code === "ENOENT") {
              return false;
            }
            throw error;
          }
        }
        exports2.isFile = isType.bind(null, "stat", "isFile");
        exports2.isDirectory = isType.bind(null, "stat", "isDirectory");
        exports2.isSymlink = isType.bind(null, "lstat", "isSymbolicLink");
        exports2.isFileSync = isTypeSync.bind(null, "statSync", "isFile");
        exports2.isDirectorySync = isTypeSync.bind(null, "statSync", "isDirectory");
        exports2.isSymlinkSync = isTypeSync.bind(null, "lstatSync", "isSymbolicLink");
      }
    });
    var require_getDirectory = __commonJS2({
      "node_modules/cosmiconfig/dist/getDirectory.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.getDirectory = getDirectory;
        exports2.getDirectorySync = getDirectorySync;
        var _path = _interopRequireDefault(require("path"));
        var _pathType = require_path_type();
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        async function getDirectory(filepath) {
          const filePathIsDirectory = await (0, _pathType.isDirectory)(filepath);
          if (filePathIsDirectory === true) {
            return filepath;
          }
          const directory = _path.default.dirname(filepath);
          return directory;
        }
        function getDirectorySync(filepath) {
          const filePathIsDirectory = (0, _pathType.isDirectorySync)(filepath);
          if (filePathIsDirectory === true) {
            return filepath;
          }
          const directory = _path.default.dirname(filepath);
          return directory;
        }
      }
    });
    var require_Explorer = __commonJS2({
      "node_modules/cosmiconfig/dist/Explorer.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.Explorer = void 0;
        var _path = _interopRequireDefault(require("path"));
        var _ExplorerBase = require_ExplorerBase();
        var _readFile = require_readFile();
        var _cacheWrapper = require_cacheWrapper();
        var _getDirectory = require_getDirectory();
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        var Explorer = class extends _ExplorerBase.ExplorerBase {
          constructor(options) {
            super(options);
          }
          async search(searchFrom = process.cwd()) {
            const startDirectory = await (0, _getDirectory.getDirectory)(searchFrom);
            const result = await this.searchFromDirectory(startDirectory);
            return result;
          }
          async searchFromDirectory(dir) {
            const absoluteDir = _path.default.resolve(process.cwd(), dir);
            const run = async () => {
              const result = await this.searchDirectory(absoluteDir);
              const nextDir = this.nextDirectoryToSearch(absoluteDir, result);
              if (nextDir) {
                return this.searchFromDirectory(nextDir);
              }
              const transformResult = await this.config.transform(result);
              return transformResult;
            };
            if (this.searchCache) {
              return (0, _cacheWrapper.cacheWrapper)(this.searchCache, absoluteDir, run);
            }
            return run();
          }
          async searchDirectory(dir) {
            for await (const place of this.config.searchPlaces) {
              const placeResult = await this.loadSearchPlace(dir, place);
              if (this.shouldSearchStopWithResult(placeResult) === true) {
                return placeResult;
              }
            }
            return null;
          }
          async loadSearchPlace(dir, place) {
            const filepath = _path.default.join(dir, place);
            const fileContents = await (0, _readFile.readFile)(filepath);
            const result = await this.createCosmiconfigResult(filepath, fileContents);
            return result;
          }
          async loadFileContent(filepath, content) {
            if (content === null) {
              return null;
            }
            if (content.trim() === "") {
              return void 0;
            }
            const loader = this.getLoaderEntryForFile(filepath);
            const loaderResult = await loader(filepath, content);
            return loaderResult;
          }
          async createCosmiconfigResult(filepath, content) {
            const fileContent = await this.loadFileContent(filepath, content);
            const result = this.loadedContentToCosmiconfigResult(filepath, fileContent);
            return result;
          }
          async load(filepath) {
            this.validateFilePath(filepath);
            const absoluteFilePath = _path.default.resolve(process.cwd(), filepath);
            const runLoad = async () => {
              const fileContents = await (0, _readFile.readFile)(absoluteFilePath, {
                throwNotFound: true
              });
              const result = await this.createCosmiconfigResult(absoluteFilePath, fileContents);
              const transformResult = await this.config.transform(result);
              return transformResult;
            };
            if (this.loadCache) {
              return (0, _cacheWrapper.cacheWrapper)(this.loadCache, absoluteFilePath, runLoad);
            }
            return runLoad();
          }
        };
        exports2.Explorer = Explorer;
      }
    });
    var require_ExplorerSync = __commonJS2({
      "node_modules/cosmiconfig/dist/ExplorerSync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.ExplorerSync = void 0;
        var _path = _interopRequireDefault(require("path"));
        var _ExplorerBase = require_ExplorerBase();
        var _readFile = require_readFile();
        var _cacheWrapper = require_cacheWrapper();
        var _getDirectory = require_getDirectory();
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        var ExplorerSync = class extends _ExplorerBase.ExplorerBase {
          constructor(options) {
            super(options);
          }
          searchSync(searchFrom = process.cwd()) {
            const startDirectory = (0, _getDirectory.getDirectorySync)(searchFrom);
            const result = this.searchFromDirectorySync(startDirectory);
            return result;
          }
          searchFromDirectorySync(dir) {
            const absoluteDir = _path.default.resolve(process.cwd(), dir);
            const run = () => {
              const result = this.searchDirectorySync(absoluteDir);
              const nextDir = this.nextDirectoryToSearch(absoluteDir, result);
              if (nextDir) {
                return this.searchFromDirectorySync(nextDir);
              }
              const transformResult = this.config.transform(result);
              return transformResult;
            };
            if (this.searchCache) {
              return (0, _cacheWrapper.cacheWrapperSync)(this.searchCache, absoluteDir, run);
            }
            return run();
          }
          searchDirectorySync(dir) {
            for (const place of this.config.searchPlaces) {
              const placeResult = this.loadSearchPlaceSync(dir, place);
              if (this.shouldSearchStopWithResult(placeResult) === true) {
                return placeResult;
              }
            }
            return null;
          }
          loadSearchPlaceSync(dir, place) {
            const filepath = _path.default.join(dir, place);
            const content = (0, _readFile.readFileSync)(filepath);
            const result = this.createCosmiconfigResultSync(filepath, content);
            return result;
          }
          loadFileContentSync(filepath, content) {
            if (content === null) {
              return null;
            }
            if (content.trim() === "") {
              return void 0;
            }
            const loader = this.getLoaderEntryForFile(filepath);
            const loaderResult = loader(filepath, content);
            return loaderResult;
          }
          createCosmiconfigResultSync(filepath, content) {
            const fileContent = this.loadFileContentSync(filepath, content);
            const result = this.loadedContentToCosmiconfigResult(filepath, fileContent);
            return result;
          }
          loadSync(filepath) {
            this.validateFilePath(filepath);
            const absoluteFilePath = _path.default.resolve(process.cwd(), filepath);
            const runLoadSync = () => {
              const content = (0, _readFile.readFileSync)(absoluteFilePath, {
                throwNotFound: true
              });
              const cosmiconfigResult = this.createCosmiconfigResultSync(absoluteFilePath, content);
              const transformResult = this.config.transform(cosmiconfigResult);
              return transformResult;
            };
            if (this.loadCache) {
              return (0, _cacheWrapper.cacheWrapperSync)(this.loadCache, absoluteFilePath, runLoadSync);
            }
            return runLoadSync();
          }
        };
        exports2.ExplorerSync = ExplorerSync;
      }
    });
    var require_types3 = __commonJS2({
      "node_modules/cosmiconfig/dist/types.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
      }
    });
    var require_dist2 = __commonJS2({
      "node_modules/cosmiconfig/dist/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.cosmiconfig = cosmiconfig;
        exports2.cosmiconfigSync = cosmiconfigSync;
        exports2.defaultLoaders = void 0;
        var _os = _interopRequireDefault(require("os"));
        var _Explorer = require_Explorer();
        var _ExplorerSync = require_ExplorerSync();
        var _loaders = require_loaders();
        var _types = require_types3();
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        function cosmiconfig(moduleName, options = {}) {
          const normalizedOptions = normalizeOptions(moduleName, options);
          const explorer = new _Explorer.Explorer(normalizedOptions);
          return {
            search: explorer.search.bind(explorer),
            load: explorer.load.bind(explorer),
            clearLoadCache: explorer.clearLoadCache.bind(explorer),
            clearSearchCache: explorer.clearSearchCache.bind(explorer),
            clearCaches: explorer.clearCaches.bind(explorer)
          };
        }
        function cosmiconfigSync(moduleName, options = {}) {
          const normalizedOptions = normalizeOptions(moduleName, options);
          const explorerSync = new _ExplorerSync.ExplorerSync(normalizedOptions);
          return {
            search: explorerSync.searchSync.bind(explorerSync),
            load: explorerSync.loadSync.bind(explorerSync),
            clearLoadCache: explorerSync.clearLoadCache.bind(explorerSync),
            clearSearchCache: explorerSync.clearSearchCache.bind(explorerSync),
            clearCaches: explorerSync.clearCaches.bind(explorerSync)
          };
        }
        var defaultLoaders = Object.freeze({
          ".cjs": _loaders.loaders.loadJs,
          ".js": _loaders.loaders.loadJs,
          ".json": _loaders.loaders.loadJson,
          ".yaml": _loaders.loaders.loadYaml,
          ".yml": _loaders.loaders.loadYaml,
          noExt: _loaders.loaders.loadYaml
        });
        exports2.defaultLoaders = defaultLoaders;
        var identity = function identity2(x) {
          return x;
        };
        function normalizeOptions(moduleName, options) {
          const defaults = {
            packageProp: moduleName,
            searchPlaces: ["package.json", `.${moduleName}rc`, `.${moduleName}rc.json`, `.${moduleName}rc.yaml`, `.${moduleName}rc.yml`, `.${moduleName}rc.js`, `.${moduleName}rc.cjs`, `${moduleName}.config.js`, `${moduleName}.config.cjs`],
            ignoreEmptySearchPlaces: true,
            stopDir: _os.default.homedir(),
            cache: true,
            transform: identity,
            loaders: defaultLoaders
          };
          const normalizedOptions = Object.assign(Object.assign(Object.assign({}, defaults), options), {}, {
            loaders: Object.assign(Object.assign({}, defaults.loaders), options.loaders)
          });
          return normalizedOptions;
        }
      }
    });
    var require_find_parent_dir = __commonJS2({
      "node_modules/find-parent-dir/index.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var fs2 = require("fs");
        var exists = fs2.exists || path2.exists;
        var existsSync = fs2.existsSync || path2.existsSync;
        function splitPath(path22) {
          var parts = path22.split(/(\/|\\)/);
          if (!parts.length)
            return parts;
          return !parts[0].length ? parts.slice(1) : parts;
        }
        exports2 = module22.exports = function(currentFullPath, clue, cb) {
          function testDir(parts) {
            if (parts.length === 0)
              return cb(null, null);
            var p = parts.join("");
            exists(path2.join(p, clue), function(itdoes) {
              if (itdoes)
                return cb(null, p);
              testDir(parts.slice(0, -1));
            });
          }
          testDir(splitPath(currentFullPath));
        };
        exports2.sync = function(currentFullPath, clue) {
          function testDir(parts) {
            if (parts.length === 0)
              return null;
            var p = parts.join("");
            var itdoes = existsSync(path2.join(p, clue));
            return itdoes ? p : testDir(parts.slice(0, -1));
          }
          return testDir(splitPath(currentFullPath));
        };
      }
    });
    var require_get_stdin = __commonJS2({
      "node_modules/get-stdin/index.js"(exports2, module22) {
        "use strict";
        var {
          stdin
        } = process;
        module22.exports = async () => {
          let result = "";
          if (stdin.isTTY) {
            return result;
          }
          stdin.setEncoding("utf8");
          for await (const chunk of stdin) {
            result += chunk;
          }
          return result;
        };
        module22.exports.buffer = async () => {
          const result = [];
          let length = 0;
          if (stdin.isTTY) {
            return Buffer.concat([]);
          }
          for await (const chunk of stdin) {
            result.push(chunk);
            length += chunk.length;
          }
          return Buffer.concat(result, length);
        };
      }
    });
    var require_vendors = __commonJS2({
      "node_modules/ci-info/vendors.json"(exports2, module22) {
        module22.exports = [{
          name: "AppVeyor",
          constant: "APPVEYOR",
          env: "APPVEYOR",
          pr: "APPVEYOR_PULL_REQUEST_NUMBER"
        }, {
          name: "Azure Pipelines",
          constant: "AZURE_PIPELINES",
          env: "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI",
          pr: "SYSTEM_PULLREQUEST_PULLREQUESTID"
        }, {
          name: "Appcircle",
          constant: "APPCIRCLE",
          env: "AC_APPCIRCLE"
        }, {
          name: "Bamboo",
          constant: "BAMBOO",
          env: "bamboo_planKey"
        }, {
          name: "Bitbucket Pipelines",
          constant: "BITBUCKET",
          env: "BITBUCKET_COMMIT",
          pr: "BITBUCKET_PR_ID"
        }, {
          name: "Bitrise",
          constant: "BITRISE",
          env: "BITRISE_IO",
          pr: "BITRISE_PULL_REQUEST"
        }, {
          name: "Buddy",
          constant: "BUDDY",
          env: "BUDDY_WORKSPACE_ID",
          pr: "BUDDY_EXECUTION_PULL_REQUEST_ID"
        }, {
          name: "Buildkite",
          constant: "BUILDKITE",
          env: "BUILDKITE",
          pr: {
            env: "BUILDKITE_PULL_REQUEST",
            ne: "false"
          }
        }, {
          name: "CircleCI",
          constant: "CIRCLE",
          env: "CIRCLECI",
          pr: "CIRCLE_PULL_REQUEST"
        }, {
          name: "Cirrus CI",
          constant: "CIRRUS",
          env: "CIRRUS_CI",
          pr: "CIRRUS_PR"
        }, {
          name: "AWS CodeBuild",
          constant: "CODEBUILD",
          env: "CODEBUILD_BUILD_ARN"
        }, {
          name: "Codefresh",
          constant: "CODEFRESH",
          env: "CF_BUILD_ID",
          pr: {
            any: ["CF_PULL_REQUEST_NUMBER", "CF_PULL_REQUEST_ID"]
          }
        }, {
          name: "Codeship",
          constant: "CODESHIP",
          env: {
            CI_NAME: "codeship"
          }
        }, {
          name: "Drone",
          constant: "DRONE",
          env: "DRONE",
          pr: {
            DRONE_BUILD_EVENT: "pull_request"
          }
        }, {
          name: "dsari",
          constant: "DSARI",
          env: "DSARI"
        }, {
          name: "Expo Application Services",
          constant: "EAS",
          env: "EAS_BUILD"
        }, {
          name: "GitHub Actions",
          constant: "GITHUB_ACTIONS",
          env: "GITHUB_ACTIONS",
          pr: {
            GITHUB_EVENT_NAME: "pull_request"
          }
        }, {
          name: "GitLab CI",
          constant: "GITLAB",
          env: "GITLAB_CI",
          pr: "CI_MERGE_REQUEST_ID"
        }, {
          name: "GoCD",
          constant: "GOCD",
          env: "GO_PIPELINE_LABEL"
        }, {
          name: "LayerCI",
          constant: "LAYERCI",
          env: "LAYERCI",
          pr: "LAYERCI_PULL_REQUEST"
        }, {
          name: "Hudson",
          constant: "HUDSON",
          env: "HUDSON_URL"
        }, {
          name: "Jenkins",
          constant: "JENKINS",
          env: ["JENKINS_URL", "BUILD_ID"],
          pr: {
            any: ["ghprbPullId", "CHANGE_ID"]
          }
        }, {
          name: "Magnum CI",
          constant: "MAGNUM",
          env: "MAGNUM"
        }, {
          name: "Netlify CI",
          constant: "NETLIFY",
          env: "NETLIFY",
          pr: {
            env: "PULL_REQUEST",
            ne: "false"
          }
        }, {
          name: "Nevercode",
          constant: "NEVERCODE",
          env: "NEVERCODE",
          pr: {
            env: "NEVERCODE_PULL_REQUEST",
            ne: "false"
          }
        }, {
          name: "Render",
          constant: "RENDER",
          env: "RENDER",
          pr: {
            IS_PULL_REQUEST: "true"
          }
        }, {
          name: "Sail CI",
          constant: "SAIL",
          env: "SAILCI",
          pr: "SAIL_PULL_REQUEST_NUMBER"
        }, {
          name: "Semaphore",
          constant: "SEMAPHORE",
          env: "SEMAPHORE",
          pr: "PULL_REQUEST_NUMBER"
        }, {
          name: "Screwdriver",
          constant: "SCREWDRIVER",
          env: "SCREWDRIVER",
          pr: {
            env: "SD_PULL_REQUEST",
            ne: "false"
          }
        }, {
          name: "Shippable",
          constant: "SHIPPABLE",
          env: "SHIPPABLE",
          pr: {
            IS_PULL_REQUEST: "true"
          }
        }, {
          name: "Solano CI",
          constant: "SOLANO",
          env: "TDDIUM",
          pr: "TDDIUM_PR_ID"
        }, {
          name: "Strider CD",
          constant: "STRIDER",
          env: "STRIDER"
        }, {
          name: "TaskCluster",
          constant: "TASKCLUSTER",
          env: ["TASK_ID", "RUN_ID"]
        }, {
          name: "TeamCity",
          constant: "TEAMCITY",
          env: "TEAMCITY_VERSION"
        }, {
          name: "Travis CI",
          constant: "TRAVIS",
          env: "TRAVIS",
          pr: {
            env: "TRAVIS_PULL_REQUEST",
            ne: "false"
          }
        }, {
          name: "Vercel",
          constant: "VERCEL",
          env: "NOW_BUILDER"
        }, {
          name: "Visual Studio App Center",
          constant: "APPCENTER",
          env: "APPCENTER_BUILD_ID"
        }];
      }
    });
    var require_ci_info = __commonJS2({
      "node_modules/ci-info/index.js"(exports2) {
        "use strict";
        var vendors = require_vendors();
        var env = process.env;
        Object.defineProperty(exports2, "_vendors", {
          value: vendors.map(function(v) {
            return v.constant;
          })
        });
        exports2.name = null;
        exports2.isPR = null;
        vendors.forEach(function(vendor) {
          const envs = Array.isArray(vendor.env) ? vendor.env : [vendor.env];
          const isCI = envs.every(function(obj) {
            return checkEnv(obj);
          });
          exports2[vendor.constant] = isCI;
          if (isCI) {
            exports2.name = vendor.name;
            switch (typeof vendor.pr) {
              case "string":
                exports2.isPR = !!env[vendor.pr];
                break;
              case "object":
                if ("env" in vendor.pr) {
                  exports2.isPR = vendor.pr.env in env && env[vendor.pr.env] !== vendor.pr.ne;
                } else if ("any" in vendor.pr) {
                  exports2.isPR = vendor.pr.any.some(function(key) {
                    return !!env[key];
                  });
                } else {
                  exports2.isPR = checkEnv(vendor.pr);
                }
                break;
              default:
                exports2.isPR = null;
            }
          }
        });
        exports2.isCI = !!(env.CI || env.CONTINUOUS_INTEGRATION || env.BUILD_NUMBER || env.RUN_ID || exports2.name || false);
        function checkEnv(obj) {
          if (typeof obj === "string")
            return !!env[obj];
          return Object.keys(obj).every(function(k) {
            return env[k] === obj[k];
          });
        }
      }
    });
    module2.exports = {
      cosmiconfig: require_dist2().cosmiconfig,
      cosmiconfigSync: require_dist2().cosmiconfigSync,
      findParentDir: require_find_parent_dir().sync,
      getStdin: require_get_stdin(),
      isCI: () => require_ci_info().isCI
    };
  }
});

// node_modules/prettier/parser-babel.js
var require_parser_babel = __commonJS({
  "node_modules/prettier/parser-babel.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.babel = e();
      }
    })(function() {
      "use strict";
      var v = (l, h) => () => (h || l((h = { exports: {} }).exports, h), h.exports);
      var le = v((md, oi) => {
        var St = function(l) {
          return l && l.Math == Math && l;
        };
        oi.exports = St(typeof globalThis == "object" && globalThis) || St(typeof window == "object" && window) || St(typeof self == "object" && self) || St(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var he = v((yd, li) => {
        li.exports = function(l) {
          try {
            return !!l();
          } catch {
            return true;
          }
        };
      });
      var ve = v((xd, hi) => {
        var Nh = he();
        hi.exports = !Nh(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var wt = v((gd, ui) => {
        var kh = he();
        ui.exports = !kh(function() {
          var l = function() {
          }.bind();
          return typeof l != "function" || l.hasOwnProperty("prototype");
        });
      });
      var Nt = v((Pd, ci) => {
        var Dh = wt(), It = Function.prototype.call;
        ci.exports = Dh ? It.bind(It) : function() {
          return It.apply(It, arguments);
        };
      });
      var mi = v((di) => {
        "use strict";
        var pi = {}.propertyIsEnumerable, fi = Object.getOwnPropertyDescriptor, Fh = fi && !pi.call({ 1: 2 }, 1);
        di.f = Fh ? function(h) {
          var f = fi(this, h);
          return !!f && f.enumerable;
        } : pi;
      });
      var As = v((Td, yi) => {
        yi.exports = function(l, h) {
          return { enumerable: !(l & 1), configurable: !(l & 2), writable: !(l & 4), value: h };
        };
      });
      var ue = v((vd, Pi) => {
        var xi = wt(), gi = Function.prototype, Ts = gi.call, Lh = xi && gi.bind.bind(Ts, Ts);
        Pi.exports = xi ? Lh : function(l) {
          return function() {
            return Ts.apply(l, arguments);
          };
        };
      });
      var rt = v((Ed, Ti) => {
        var Ai = ue(), Oh = Ai({}.toString), Bh = Ai("".slice);
        Ti.exports = function(l) {
          return Bh(Oh(l), 8, -1);
        };
      });
      var Ei = v((Cd, vi) => {
        var Mh = ue(), _h = he(), Rh = rt(), vs = Object, jh = Mh("".split);
        vi.exports = _h(function() {
          return !vs("z").propertyIsEnumerable(0);
        }) ? function(l) {
          return Rh(l) == "String" ? jh(l, "") : vs(l);
        } : vs;
      });
      var Es = v((bd, Ci) => {
        Ci.exports = function(l) {
          return l == null;
        };
      });
      var Cs = v((Sd, bi) => {
        var qh = Es(), Uh = TypeError;
        bi.exports = function(l) {
          if (qh(l))
            throw Uh("Can't call method on " + l);
          return l;
        };
      });
      var kt = v((wd, Si) => {
        var $h = Ei(), Hh = Cs();
        Si.exports = function(l) {
          return $h(Hh(l));
        };
      });
      var Ss = v((Id, wi) => {
        var bs = typeof document == "object" && document.all, zh = typeof bs > "u" && bs !== void 0;
        wi.exports = { all: bs, IS_HTMLDDA: zh };
      });
      var ne = v((Nd, Ni) => {
        var Ii = Ss(), Vh = Ii.all;
        Ni.exports = Ii.IS_HTMLDDA ? function(l) {
          return typeof l == "function" || l === Vh;
        } : function(l) {
          return typeof l == "function";
        };
      });
      var Oe = v((kd, Fi) => {
        var ki = ne(), Di = Ss(), Kh = Di.all;
        Fi.exports = Di.IS_HTMLDDA ? function(l) {
          return typeof l == "object" ? l !== null : ki(l) || l === Kh;
        } : function(l) {
          return typeof l == "object" ? l !== null : ki(l);
        };
      });
      var it2 = v((Dd, Li) => {
        var ws = le(), Wh = ne(), Gh = function(l) {
          return Wh(l) ? l : void 0;
        };
        Li.exports = function(l, h) {
          return arguments.length < 2 ? Gh(ws[l]) : ws[l] && ws[l][h];
        };
      });
      var Bi = v((Fd, Oi) => {
        var Jh = ue();
        Oi.exports = Jh({}.isPrototypeOf);
      });
      var _i = v((Ld, Mi) => {
        var Xh = it2();
        Mi.exports = Xh("navigator", "userAgent") || "";
      });
      var zi = v((Od, Hi) => {
        var $i = le(), Is = _i(), Ri = $i.process, ji = $i.Deno, qi = Ri && Ri.versions || ji && ji.version, Ui = qi && qi.v8, ce, Dt;
        Ui && (ce = Ui.split("."), Dt = ce[0] > 0 && ce[0] < 4 ? 1 : +(ce[0] + ce[1]));
        !Dt && Is && (ce = Is.match(/Edge\/(\d+)/), (!ce || ce[1] >= 74) && (ce = Is.match(/Chrome\/(\d+)/), ce && (Dt = +ce[1])));
        Hi.exports = Dt;
      });
      var Ns = v((Bd, Ki) => {
        var Vi = zi(), Yh = he();
        Ki.exports = !!Object.getOwnPropertySymbols && !Yh(function() {
          var l = Symbol();
          return !String(l) || !(Object(l) instanceof Symbol) || !Symbol.sham && Vi && Vi < 41;
        });
      });
      var ks = v((Md, Wi) => {
        var Qh = Ns();
        Wi.exports = Qh && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var Ds = v((_d, Gi) => {
        var Zh = it2(), eu = ne(), tu = Bi(), su = ks(), ru = Object;
        Gi.exports = su ? function(l) {
          return typeof l == "symbol";
        } : function(l) {
          var h = Zh("Symbol");
          return eu(h) && tu(h.prototype, ru(l));
        };
      });
      var Xi = v((Rd, Ji) => {
        var iu = String;
        Ji.exports = function(l) {
          try {
            return iu(l);
          } catch {
            return "Object";
          }
        };
      });
      var Ft = v((jd, Yi) => {
        var au = ne(), nu = Xi(), ou = TypeError;
        Yi.exports = function(l) {
          if (au(l))
            return l;
          throw ou(nu(l) + " is not a function");
        };
      });
      var Zi = v((qd, Qi) => {
        var lu = Ft(), hu = Es();
        Qi.exports = function(l, h) {
          var f = l[h];
          return hu(f) ? void 0 : lu(f);
        };
      });
      var ta = v((Ud, ea) => {
        var Fs = Nt(), Ls = ne(), Os = Oe(), uu = TypeError;
        ea.exports = function(l, h) {
          var f, d;
          if (h === "string" && Ls(f = l.toString) && !Os(d = Fs(f, l)) || Ls(f = l.valueOf) && !Os(d = Fs(f, l)) || h !== "string" && Ls(f = l.toString) && !Os(d = Fs(f, l)))
            return d;
          throw uu("Can't convert object to primitive value");
        };
      });
      var ra = v(($d, sa) => {
        sa.exports = false;
      });
      var Lt = v((Hd, aa) => {
        var ia = le(), cu = Object.defineProperty;
        aa.exports = function(l, h) {
          try {
            cu(ia, l, { value: h, configurable: true, writable: true });
          } catch {
            ia[l] = h;
          }
          return h;
        };
      });
      var Ot = v((zd, oa) => {
        var pu = le(), fu = Lt(), na = "__core-js_shared__", du = pu[na] || fu(na, {});
        oa.exports = du;
      });
      var Bs = v((Vd, ha) => {
        var mu = ra(), la = Ot();
        (ha.exports = function(l, h) {
          return la[l] || (la[l] = h !== void 0 ? h : {});
        })("versions", []).push({ version: "3.26.1", mode: mu ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var Ms = v((Kd, ua) => {
        var yu = Cs(), xu = Object;
        ua.exports = function(l) {
          return xu(yu(l));
        };
      });
      var Ie = v((Wd, ca) => {
        var gu = ue(), Pu = Ms(), Au = gu({}.hasOwnProperty);
        ca.exports = Object.hasOwn || function(h, f) {
          return Au(Pu(h), f);
        };
      });
      var _s = v((Gd, pa) => {
        var Tu = ue(), vu = 0, Eu = Math.random(), Cu = Tu(1 .toString);
        pa.exports = function(l) {
          return "Symbol(" + (l === void 0 ? "" : l) + ")_" + Cu(++vu + Eu, 36);
        };
      });
      var at = v((Jd, xa) => {
        var bu = le(), Su = Bs(), fa = Ie(), wu = _s(), da = Ns(), ya = ks(), Ke = Su("wks"), Be = bu.Symbol, ma = Be && Be.for, Iu = ya ? Be : Be && Be.withoutSetter || wu;
        xa.exports = function(l) {
          if (!fa(Ke, l) || !(da || typeof Ke[l] == "string")) {
            var h = "Symbol." + l;
            da && fa(Be, l) ? Ke[l] = Be[l] : ya && ma ? Ke[l] = ma(h) : Ke[l] = Iu(h);
          }
          return Ke[l];
        };
      });
      var Ta = v((Xd, Aa) => {
        var Nu = Nt(), ga = Oe(), Pa = Ds(), ku = Zi(), Du = ta(), Fu = at(), Lu = TypeError, Ou = Fu("toPrimitive");
        Aa.exports = function(l, h) {
          if (!ga(l) || Pa(l))
            return l;
          var f = ku(l, Ou), d;
          if (f) {
            if (h === void 0 && (h = "default"), d = Nu(f, l, h), !ga(d) || Pa(d))
              return d;
            throw Lu("Can't convert object to primitive value");
          }
          return h === void 0 && (h = "number"), Du(l, h);
        };
      });
      var Rs = v((Yd, va) => {
        var Bu = Ta(), Mu = Ds();
        va.exports = function(l) {
          var h = Bu(l, "string");
          return Mu(h) ? h : h + "";
        };
      });
      var ba = v((Qd, Ca) => {
        var _u = le(), Ea = Oe(), js = _u.document, Ru = Ea(js) && Ea(js.createElement);
        Ca.exports = function(l) {
          return Ru ? js.createElement(l) : {};
        };
      });
      var qs = v((Zd, Sa) => {
        var ju = ve(), qu = he(), Uu = ba();
        Sa.exports = !ju && !qu(function() {
          return Object.defineProperty(Uu("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Us = v((Ia) => {
        var $u = ve(), Hu = Nt(), zu = mi(), Vu = As(), Ku = kt(), Wu = Rs(), Gu = Ie(), Ju = qs(), wa = Object.getOwnPropertyDescriptor;
        Ia.f = $u ? wa : function(h, f) {
          if (h = Ku(h), f = Wu(f), Ju)
            try {
              return wa(h, f);
            } catch {
            }
          if (Gu(h, f))
            return Vu(!Hu(zu.f, h, f), h[f]);
        };
      });
      var ka = v((tm, Na) => {
        var Xu = ve(), Yu = he();
        Na.exports = Xu && Yu(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var Bt = v((sm, Da) => {
        var Qu = Oe(), Zu = String, ec = TypeError;
        Da.exports = function(l) {
          if (Qu(l))
            return l;
          throw ec(Zu(l) + " is not an object");
        };
      });
      var nt = v((La) => {
        var tc = ve(), sc = qs(), rc = ka(), Mt = Bt(), Fa = Rs(), ic = TypeError, $s = Object.defineProperty, ac = Object.getOwnPropertyDescriptor, Hs = "enumerable", zs = "configurable", Vs = "writable";
        La.f = tc ? rc ? function(h, f, d) {
          if (Mt(h), f = Fa(f), Mt(d), typeof h == "function" && f === "prototype" && "value" in d && Vs in d && !d[Vs]) {
            var y = ac(h, f);
            y && y[Vs] && (h[f] = d.value, d = { configurable: zs in d ? d[zs] : y[zs], enumerable: Hs in d ? d[Hs] : y[Hs], writable: false });
          }
          return $s(h, f, d);
        } : $s : function(h, f, d) {
          if (Mt(h), f = Fa(f), Mt(d), sc)
            try {
              return $s(h, f, d);
            } catch {
            }
          if ("get" in d || "set" in d)
            throw ic("Accessors not supported");
          return "value" in d && (h[f] = d.value), h;
        };
      });
      var Ks = v((im, Oa) => {
        var nc = ve(), oc = nt(), lc = As();
        Oa.exports = nc ? function(l, h, f) {
          return oc.f(l, h, lc(1, f));
        } : function(l, h, f) {
          return l[h] = f, l;
        };
      });
      var _a = v((am, Ma) => {
        var Ws = ve(), hc = Ie(), Ba = Function.prototype, uc = Ws && Object.getOwnPropertyDescriptor, Gs = hc(Ba, "name"), cc = Gs && function() {
        }.name === "something", pc = Gs && (!Ws || Ws && uc(Ba, "name").configurable);
        Ma.exports = { EXISTS: Gs, PROPER: cc, CONFIGURABLE: pc };
      });
      var Xs = v((nm, Ra) => {
        var fc = ue(), dc = ne(), Js = Ot(), mc = fc(Function.toString);
        dc(Js.inspectSource) || (Js.inspectSource = function(l) {
          return mc(l);
        });
        Ra.exports = Js.inspectSource;
      });
      var Ua = v((om, qa) => {
        var yc = le(), xc = ne(), ja = yc.WeakMap;
        qa.exports = xc(ja) && /native code/.test(String(ja));
      });
      var za = v((lm, Ha) => {
        var gc = Bs(), Pc = _s(), $a = gc("keys");
        Ha.exports = function(l) {
          return $a[l] || ($a[l] = Pc(l));
        };
      });
      var Ys = v((hm, Va) => {
        Va.exports = {};
      });
      var Ja = v((um, Ga) => {
        var Ac = Ua(), Wa = le(), Tc = Oe(), vc = Ks(), Qs = Ie(), Zs = Ot(), Ec = za(), Cc = Ys(), Ka = "Object already initialized", er = Wa.TypeError, bc = Wa.WeakMap, _t, ot, Rt, Sc = function(l) {
          return Rt(l) ? ot(l) : _t(l, {});
        }, wc = function(l) {
          return function(h) {
            var f;
            if (!Tc(h) || (f = ot(h)).type !== l)
              throw er("Incompatible receiver, " + l + " required");
            return f;
          };
        };
        Ac || Zs.state ? (pe = Zs.state || (Zs.state = new bc()), pe.get = pe.get, pe.has = pe.has, pe.set = pe.set, _t = function(l, h) {
          if (pe.has(l))
            throw er(Ka);
          return h.facade = l, pe.set(l, h), h;
        }, ot = function(l) {
          return pe.get(l) || {};
        }, Rt = function(l) {
          return pe.has(l);
        }) : (Me = Ec("state"), Cc[Me] = true, _t = function(l, h) {
          if (Qs(l, Me))
            throw er(Ka);
          return h.facade = l, vc(l, Me, h), h;
        }, ot = function(l) {
          return Qs(l, Me) ? l[Me] : {};
        }, Rt = function(l) {
          return Qs(l, Me);
        });
        var pe, Me;
        Ga.exports = { set: _t, get: ot, has: Rt, enforce: Sc, getterFor: wc };
      });
      var sr = v((cm, Ya) => {
        var Ic = he(), Nc = ne(), jt = Ie(), tr = ve(), kc = _a().CONFIGURABLE, Dc = Xs(), Xa = Ja(), Fc = Xa.enforce, Lc = Xa.get, qt = Object.defineProperty, Oc = tr && !Ic(function() {
          return qt(function() {
          }, "length", { value: 8 }).length !== 8;
        }), Bc = String(String).split("String"), Mc = Ya.exports = function(l, h, f) {
          String(h).slice(0, 7) === "Symbol(" && (h = "[" + String(h).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), f && f.getter && (h = "get " + h), f && f.setter && (h = "set " + h), (!jt(l, "name") || kc && l.name !== h) && (tr ? qt(l, "name", { value: h, configurable: true }) : l.name = h), Oc && f && jt(f, "arity") && l.length !== f.arity && qt(l, "length", { value: f.arity });
          try {
            f && jt(f, "constructor") && f.constructor ? tr && qt(l, "prototype", { writable: false }) : l.prototype && (l.prototype = void 0);
          } catch {
          }
          var d = Fc(l);
          return jt(d, "source") || (d.source = Bc.join(typeof h == "string" ? h : "")), l;
        };
        Function.prototype.toString = Mc(function() {
          return Nc(this) && Lc(this).source || Dc(this);
        }, "toString");
      });
      var Za = v((pm, Qa) => {
        var _c = ne(), Rc = nt(), jc = sr(), qc = Lt();
        Qa.exports = function(l, h, f, d) {
          d || (d = {});
          var y = d.enumerable, P = d.name !== void 0 ? d.name : h;
          if (_c(f) && jc(f, P, d), d.global)
            y ? l[h] = f : qc(h, f);
          else {
            try {
              d.unsafe ? l[h] && (y = true) : delete l[h];
            } catch {
            }
            y ? l[h] = f : Rc.f(l, h, { value: f, enumerable: false, configurable: !d.nonConfigurable, writable: !d.nonWritable });
          }
          return l;
        };
      });
      var tn = v((fm, en) => {
        var Uc = Math.ceil, $c = Math.floor;
        en.exports = Math.trunc || function(h) {
          var f = +h;
          return (f > 0 ? $c : Uc)(f);
        };
      });
      var rr = v((dm, sn) => {
        var Hc = tn();
        sn.exports = function(l) {
          var h = +l;
          return h !== h || h === 0 ? 0 : Hc(h);
        };
      });
      var an = v((mm, rn) => {
        var zc = rr(), Vc = Math.max, Kc = Math.min;
        rn.exports = function(l, h) {
          var f = zc(l);
          return f < 0 ? Vc(f + h, 0) : Kc(f, h);
        };
      });
      var on = v((ym, nn) => {
        var Wc = rr(), Gc = Math.min;
        nn.exports = function(l) {
          return l > 0 ? Gc(Wc(l), 9007199254740991) : 0;
        };
      });
      var Ut = v((xm, ln) => {
        var Jc = on();
        ln.exports = function(l) {
          return Jc(l.length);
        };
      });
      var cn = v((gm, un) => {
        var Xc = kt(), Yc = an(), Qc = Ut(), hn = function(l) {
          return function(h, f, d) {
            var y = Xc(h), P = Qc(y), g = Yc(d, P), T;
            if (l && f != f) {
              for (; P > g; )
                if (T = y[g++], T != T)
                  return true;
            } else
              for (; P > g; g++)
                if ((l || g in y) && y[g] === f)
                  return l || g || 0;
            return !l && -1;
          };
        };
        un.exports = { includes: hn(true), indexOf: hn(false) };
      });
      var dn = v((Pm, fn) => {
        var Zc = ue(), ir = Ie(), ep = kt(), tp = cn().indexOf, sp = Ys(), pn = Zc([].push);
        fn.exports = function(l, h) {
          var f = ep(l), d = 0, y = [], P;
          for (P in f)
            !ir(sp, P) && ir(f, P) && pn(y, P);
          for (; h.length > d; )
            ir(f, P = h[d++]) && (~tp(y, P) || pn(y, P));
          return y;
        };
      });
      var yn = v((Am, mn) => {
        mn.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var gn = v((xn) => {
        var rp = dn(), ip = yn(), ap = ip.concat("length", "prototype");
        xn.f = Object.getOwnPropertyNames || function(h) {
          return rp(h, ap);
        };
      });
      var An = v((Pn) => {
        Pn.f = Object.getOwnPropertySymbols;
      });
      var vn = v((Em, Tn) => {
        var np = it2(), op = ue(), lp = gn(), hp = An(), up = Bt(), cp = op([].concat);
        Tn.exports = np("Reflect", "ownKeys") || function(h) {
          var f = lp.f(up(h)), d = hp.f;
          return d ? cp(f, d(h)) : f;
        };
      });
      var bn = v((Cm, Cn) => {
        var En = Ie(), pp = vn(), fp = Us(), dp = nt();
        Cn.exports = function(l, h, f) {
          for (var d = pp(h), y = dp.f, P = fp.f, g = 0; g < d.length; g++) {
            var T = d[g];
            !En(l, T) && !(f && En(f, T)) && y(l, T, P(h, T));
          }
        };
      });
      var wn = v((bm, Sn) => {
        var mp = he(), yp = ne(), xp = /#|\.prototype\./, lt = function(l, h) {
          var f = Pp[gp(l)];
          return f == Tp ? true : f == Ap ? false : yp(h) ? mp(h) : !!h;
        }, gp = lt.normalize = function(l) {
          return String(l).replace(xp, ".").toLowerCase();
        }, Pp = lt.data = {}, Ap = lt.NATIVE = "N", Tp = lt.POLYFILL = "P";
        Sn.exports = lt;
      });
      var nr = v((Sm, In) => {
        var ar = le(), vp = Us().f, Ep = Ks(), Cp = Za(), bp = Lt(), Sp = bn(), wp = wn();
        In.exports = function(l, h) {
          var f = l.target, d = l.global, y = l.stat, P, g, T, S, F, I;
          if (d ? g = ar : y ? g = ar[f] || bp(f, {}) : g = (ar[f] || {}).prototype, g)
            for (T in h) {
              if (F = h[T], l.dontCallGetSet ? (I = vp(g, T), S = I && I.value) : S = g[T], P = wp(d ? T : f + (y ? "." : "#") + T, l.forced), !P && S !== void 0) {
                if (typeof F == typeof S)
                  continue;
                Sp(F, S);
              }
              (l.sham || S && S.sham) && Ep(F, "sham", true), Cp(g, T, F, l);
            }
        };
      });
      var Nn = v(() => {
        var Ip = nr(), or = le();
        Ip({ global: true, forced: or.globalThis !== or }, { globalThis: or });
      });
      var kn = v(() => {
        Nn();
      });
      var Ln = v((Dm, Fn) => {
        var Dn = sr(), Np = nt();
        Fn.exports = function(l, h, f) {
          return f.get && Dn(f.get, h, { getter: true }), f.set && Dn(f.set, h, { setter: true }), Np.f(l, h, f);
        };
      });
      var Bn = v((Fm, On) => {
        "use strict";
        var kp = Bt();
        On.exports = function() {
          var l = kp(this), h = "";
          return l.hasIndices && (h += "d"), l.global && (h += "g"), l.ignoreCase && (h += "i"), l.multiline && (h += "m"), l.dotAll && (h += "s"), l.unicode && (h += "u"), l.unicodeSets && (h += "v"), l.sticky && (h += "y"), h;
        };
      });
      var Rn = v(() => {
        var Dp = le(), Fp = ve(), Lp = Ln(), Op = Bn(), Bp = he(), Mn = Dp.RegExp, _n = Mn.prototype, Mp = Fp && Bp(function() {
          var l = true;
          try {
            Mn(".", "d");
          } catch {
            l = false;
          }
          var h = {}, f = "", d = l ? "dgimsy" : "gimsy", y = function(S, F) {
            Object.defineProperty(h, S, { get: function() {
              return f += F, true;
            } });
          }, P = { dotAll: "s", global: "g", ignoreCase: "i", multiline: "m", sticky: "y" };
          l && (P.hasIndices = "d");
          for (var g in P)
            y(g, P[g]);
          var T = Object.getOwnPropertyDescriptor(_n, "flags").get.call(h);
          return T !== d || f !== d;
        });
        Mp && Lp(_n, "flags", { configurable: true, get: Op });
      });
      var lr = v((Bm, jn) => {
        var _p = rt();
        jn.exports = Array.isArray || function(h) {
          return _p(h) == "Array";
        };
      });
      var Un = v((Mm, qn) => {
        var Rp = TypeError, jp = 9007199254740991;
        qn.exports = function(l) {
          if (l > jp)
            throw Rp("Maximum allowed index exceeded");
          return l;
        };
      });
      var Hn = v((_m, $n) => {
        var qp = rt(), Up = ue();
        $n.exports = function(l) {
          if (qp(l) === "Function")
            return Up(l);
        };
      });
      var Kn = v((Rm, Vn) => {
        var zn = Hn(), $p = Ft(), Hp = wt(), zp = zn(zn.bind);
        Vn.exports = function(l, h) {
          return $p(l), h === void 0 ? l : Hp ? zp(l, h) : function() {
            return l.apply(h, arguments);
          };
        };
      });
      var Jn = v((jm, Gn) => {
        "use strict";
        var Vp = lr(), Kp = Ut(), Wp = Un(), Gp = Kn(), Wn = function(l, h, f, d, y, P, g, T) {
          for (var S = y, F = 0, I = g ? Gp(g, T) : false, C, L; F < d; )
            F in f && (C = I ? I(f[F], F, h) : f[F], P > 0 && Vp(C) ? (L = Kp(C), S = Wn(l, h, C, L, S, P - 1) - 1) : (Wp(S + 1), l[S] = C), S++), F++;
          return S;
        };
        Gn.exports = Wn;
      });
      var Qn = v((qm, Yn) => {
        var Jp = at(), Xp = Jp("toStringTag"), Xn = {};
        Xn[Xp] = "z";
        Yn.exports = String(Xn) === "[object z]";
      });
      var eo = v((Um, Zn) => {
        var Yp = Qn(), Qp = ne(), $t = rt(), Zp = at(), ef = Zp("toStringTag"), tf = Object, sf = $t(function() {
          return arguments;
        }()) == "Arguments", rf = function(l, h) {
          try {
            return l[h];
          } catch {
          }
        };
        Zn.exports = Yp ? $t : function(l) {
          var h, f, d;
          return l === void 0 ? "Undefined" : l === null ? "Null" : typeof (f = rf(h = tf(l), ef)) == "string" ? f : sf ? $t(h) : (d = $t(h)) == "Object" && Qp(h.callee) ? "Arguments" : d;
        };
      });
      var no = v(($m, ao) => {
        var af = ue(), nf = he(), to = ne(), of = eo(), lf = it2(), hf = Xs(), so = function() {
        }, uf = [], ro = lf("Reflect", "construct"), hr = /^\s*(?:class|function)\b/, cf = af(hr.exec), pf = !hr.exec(so), ht = function(h) {
          if (!to(h))
            return false;
          try {
            return ro(so, uf, h), true;
          } catch {
            return false;
          }
        }, io = function(h) {
          if (!to(h))
            return false;
          switch (of(h)) {
            case "AsyncFunction":
            case "GeneratorFunction":
            case "AsyncGeneratorFunction":
              return false;
          }
          try {
            return pf || !!cf(hr, hf(h));
          } catch {
            return true;
          }
        };
        io.sham = true;
        ao.exports = !ro || nf(function() {
          var l;
          return ht(ht.call) || !ht(Object) || !ht(function() {
            l = true;
          }) || l;
        }) ? io : ht;
      });
      var uo = v((Hm, ho) => {
        var oo = lr(), ff = no(), df = Oe(), mf = at(), yf = mf("species"), lo = Array;
        ho.exports = function(l) {
          var h;
          return oo(l) && (h = l.constructor, ff(h) && (h === lo || oo(h.prototype)) ? h = void 0 : df(h) && (h = h[yf], h === null && (h = void 0))), h === void 0 ? lo : h;
        };
      });
      var po = v((zm, co) => {
        var xf = uo();
        co.exports = function(l, h) {
          return new (xf(l))(h === 0 ? 0 : h);
        };
      });
      var fo = v(() => {
        "use strict";
        var gf = nr(), Pf = Jn(), Af = Ft(), Tf = Ms(), vf = Ut(), Ef = po();
        gf({ target: "Array", proto: true }, { flatMap: function(h) {
          var f = Tf(this), d = vf(f), y;
          return Af(h), y = Ef(f, 0), y.length = Pf(y, f, f, d, 0, 1, h, arguments.length > 1 ? arguments[1] : void 0), y;
        } });
      });
      var fd = v((Zm, Ho) => {
        kn();
        Rn();
        fo();
        var fr = Object.defineProperty, Cf = Object.getOwnPropertyDescriptor, dr = Object.getOwnPropertyNames, bf = Object.prototype.hasOwnProperty, Ao = (l, h) => function() {
          return l && (h = (0, l[dr(l)[0]])(l = 0)), h;
        }, K = (l, h) => function() {
          return h || (0, l[dr(l)[0]])((h = { exports: {} }).exports, h), h.exports;
        }, Sf = (l, h) => {
          for (var f in h)
            fr(l, f, { get: h[f], enumerable: true });
        }, wf = (l, h, f, d) => {
          if (h && typeof h == "object" || typeof h == "function")
            for (let y of dr(h))
              !bf.call(l, y) && y !== f && fr(l, y, { get: () => h[y], enumerable: !(d = Cf(h, y)) || d.enumerable });
          return l;
        }, If = (l) => wf(fr({}, "__esModule", { value: true }), l), V = Ao({ "<define:process>"() {
        } }), Nf = K({ "src/utils/try-combinations.js"(l, h) {
          "use strict";
          V();
          function f() {
            let d;
            for (var y = arguments.length, P = new Array(y), g = 0; g < y; g++)
              P[g] = arguments[g];
            for (let [T, S] of P.entries())
              try {
                return { result: S() };
              } catch (F) {
                T === 0 && (d = F);
              }
            return { error: d };
          }
          h.exports = f;
        } }), To = K({ "src/language-js/utils/get-shebang.js"(l, h) {
          "use strict";
          V();
          function f(d) {
            if (!d.startsWith("#!"))
              return "";
            let y = d.indexOf(`
`);
            return y === -1 ? d : d.slice(0, y);
          }
          h.exports = f;
        } }), kf = K({ "src/utils/text/skip-inline-comment.js"(l, h) {
          "use strict";
          V();
          function f(d, y) {
            if (y === false)
              return false;
            if (d.charAt(y) === "/" && d.charAt(y + 1) === "*") {
              for (let P = y + 2; P < d.length; ++P)
                if (d.charAt(P) === "*" && d.charAt(P + 1) === "/")
                  return P + 2;
            }
            return y;
          }
          h.exports = f;
        } }), Df = K({ "src/utils/text/skip-newline.js"(l, h) {
          "use strict";
          V();
          function f(d, y, P) {
            let g = P && P.backwards;
            if (y === false)
              return false;
            let T = d.charAt(y);
            if (g) {
              if (d.charAt(y - 1) === "\r" && T === `
`)
                return y - 2;
              if (T === `
` || T === "\r" || T === "\u2028" || T === "\u2029")
                return y - 1;
            } else {
              if (T === "\r" && d.charAt(y + 1) === `
`)
                return y + 2;
              if (T === `
` || T === "\r" || T === "\u2028" || T === "\u2029")
                return y + 1;
            }
            return y;
          }
          h.exports = f;
        } }), vo = K({ "src/utils/text/skip.js"(l, h) {
          "use strict";
          V();
          function f(T) {
            return (S, F, I) => {
              let C = I && I.backwards;
              if (F === false)
                return false;
              let { length: L } = S, j = F;
              for (; j >= 0 && j < L; ) {
                let k = S.charAt(j);
                if (T instanceof RegExp) {
                  if (!T.test(k))
                    return j;
                } else if (!T.includes(k))
                  return j;
                C ? j-- : j++;
              }
              return j === -1 || j === L ? j : false;
            };
          }
          var d = f(/\s/), y = f(" 	"), P = f(",; 	"), g = f(/[^\n\r]/);
          h.exports = { skipWhitespace: d, skipSpaces: y, skipToLineEnd: P, skipEverythingButNewLine: g };
        } }), Ff = K({ "src/utils/text/skip-trailing-comment.js"(l, h) {
          "use strict";
          V();
          var { skipEverythingButNewLine: f } = vo();
          function d(y, P) {
            return P === false ? false : y.charAt(P) === "/" && y.charAt(P + 1) === "/" ? f(y, P) : P;
          }
          h.exports = d;
        } }), Lf = K({ "src/utils/text/get-next-non-space-non-comment-character-index-with-start-index.js"(l, h) {
          "use strict";
          V();
          var f = kf(), d = Df(), y = Ff(), { skipSpaces: P } = vo();
          function g(T, S) {
            let F = null, I = S;
            for (; I !== F; )
              F = I, I = P(T, I), I = f(T, I), I = y(T, I), I = d(T, I);
            return I;
          }
          h.exports = g;
        } }), Eo = {};
        Sf(Eo, { EOL: () => pr, arch: () => Of, cpus: () => ko, default: () => Bo, endianness: () => Co, freemem: () => Io, getNetworkInterfaces: () => Oo, hostname: () => bo, loadavg: () => So, networkInterfaces: () => Lo, platform: () => Bf, release: () => Fo, tmpDir: () => ur, tmpdir: () => cr, totalmem: () => No, type: () => Do, uptime: () => wo });
        function Co() {
          if (typeof Ht > "u") {
            var l = new ArrayBuffer(2), h = new Uint8Array(l), f = new Uint16Array(l);
            if (h[0] = 1, h[1] = 2, f[0] === 258)
              Ht = "BE";
            else if (f[0] === 513)
              Ht = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return Ht;
        }
        function bo() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function So() {
          return [];
        }
        function wo() {
          return 0;
        }
        function Io() {
          return Number.MAX_VALUE;
        }
        function No() {
          return Number.MAX_VALUE;
        }
        function ko() {
          return [];
        }
        function Do() {
          return "Browser";
        }
        function Fo() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function Lo() {
        }
        function Oo() {
        }
        function Of() {
          return "javascript";
        }
        function Bf() {
          return "browser";
        }
        function ur() {
          return "/tmp";
        }
        var Ht, cr, pr, Bo, Mf = Ao({ "node-modules-polyfills:os"() {
          V(), cr = ur, pr = `
`, Bo = { EOL: pr, tmpdir: cr, tmpDir: ur, networkInterfaces: Lo, getNetworkInterfaces: Oo, release: Fo, type: Do, cpus: ko, totalmem: No, freemem: Io, uptime: wo, loadavg: So, hostname: bo, endianness: Co };
        } }), _f = K({ "node-modules-polyfills-commonjs:os"(l, h) {
          V();
          var f = (Mf(), If(Eo));
          if (f && f.default) {
            h.exports = f.default;
            for (let d in f)
              h.exports[d] = f[d];
          } else
            f && (h.exports = f);
        } }), Rf = K({ "node_modules/detect-newline/index.js"(l, h) {
          "use strict";
          V();
          var f = (d) => {
            if (typeof d != "string")
              throw new TypeError("Expected a string");
            let y = d.match(/(?:\r?\n)/g) || [];
            if (y.length === 0)
              return;
            let P = y.filter((T) => T === `\r
`).length, g = y.length - P;
            return P > g ? `\r
` : `
`;
          };
          h.exports = f, h.exports.graceful = (d) => typeof d == "string" && f(d) || `
`;
        } }), jf = K({ "node_modules/jest-docblock/build/index.js"(l) {
          "use strict";
          V(), Object.defineProperty(l, "__esModule", { value: true }), l.extract = j, l.parse = H, l.parseWithComments = W, l.print = B, l.strip = k;
          function h() {
            let u = _f();
            return h = function() {
              return u;
            }, u;
          }
          function f() {
            let u = d(Rf());
            return f = function() {
              return u;
            }, u;
          }
          function d(u) {
            return u && u.__esModule ? u : { default: u };
          }
          var y = /\*\/$/, P = /^\/\*\*?/, g = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, T = /(^|\s+)\/\/([^\r\n]*)/g, S = /^(\r?\n)+/, F = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, I = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, C = /(\r?\n|^) *\* ?/g, L = [];
          function j(u) {
            let G = u.match(g);
            return G ? G[0].trimLeft() : "";
          }
          function k(u) {
            let G = u.match(g);
            return G && G[0] ? u.substring(G[0].length) : u;
          }
          function H(u) {
            return W(u).pragmas;
          }
          function W(u) {
            let G = (0, f().default)(u) || h().EOL;
            u = u.replace(P, "").replace(y, "").replace(C, "$1");
            let oe = "";
            for (; oe !== u; )
              oe = u, u = u.replace(F, `${G}$1 $2${G}`);
            u = u.replace(S, "").trimRight();
            let X = /* @__PURE__ */ Object.create(null), _e = u.replace(I, "").replace(S, "").trimRight(), Z;
            for (; Z = I.exec(u); ) {
              let $2 = Z[2].replace(T, "");
              typeof X[Z[1]] == "string" || Array.isArray(X[Z[1]]) ? X[Z[1]] = L.concat(X[Z[1]], $2) : X[Z[1]] = $2;
            }
            return { comments: _e, pragmas: X };
          }
          function B(u) {
            let { comments: G = "", pragmas: oe = {} } = u, X = (0, f().default)(G) || h().EOL, _e = "/**", Z = " *", $2 = " */", M = Object.keys(oe), E = M.map((ee) => _(ee, oe[ee])).reduce((ee, fe) => ee.concat(fe), []).map((ee) => `${Z} ${ee}${X}`).join("");
            if (!G) {
              if (M.length === 0)
                return "";
              if (M.length === 1 && !Array.isArray(oe[M[0]])) {
                let ee = oe[M[0]];
                return `${_e} ${_(M[0], ee)[0]}${$2}`;
              }
            }
            let Je = G.split(X).map((ee) => `${Z} ${ee}`).join(X) + X;
            return _e + X + (G ? Je : "") + (G && M.length ? Z + X : "") + E + $2;
          }
          function _(u, G) {
            return L.concat(G).map((oe) => `@${u} ${oe}`.trim());
          }
        } }), qf = K({ "src/common/end-of-line.js"(l, h) {
          "use strict";
          V();
          function f(g) {
            let T = g.indexOf("\r");
            return T >= 0 ? g.charAt(T + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function d(g) {
            switch (g) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function y(g, T) {
            let S;
            switch (T) {
              case `
`:
                S = /\n/g;
                break;
              case "\r":
                S = /\r/g;
                break;
              case `\r
`:
                S = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(T)}.`);
            }
            let F = g.match(S);
            return F ? F.length : 0;
          }
          function P(g) {
            return g.replace(/\r\n?/g, `
`);
          }
          h.exports = { guessEndOfLine: f, convertEndOfLineToChars: d, countEndOfLineChars: y, normalizeEndOfLine: P };
        } }), Uf = K({ "src/language-js/pragma.js"(l, h) {
          "use strict";
          V();
          var { parseWithComments: f, strip: d, extract: y, print: P } = jf(), { normalizeEndOfLine: g } = qf(), T = To();
          function S(C) {
            let L = T(C);
            L && (C = C.slice(L.length + 1));
            let j = y(C), { pragmas: k, comments: H } = f(j);
            return { shebang: L, text: C, pragmas: k, comments: H };
          }
          function F(C) {
            let L = Object.keys(S(C).pragmas);
            return L.includes("prettier") || L.includes("format");
          }
          function I(C) {
            let { shebang: L, text: j, pragmas: k, comments: H } = S(C), W = d(j), B = P({ pragmas: Object.assign({ format: "" }, k), comments: H.trimStart() });
            return (L ? `${L}
` : "") + g(B) + (W.startsWith(`
`) ? `
` : `

`) + W;
          }
          h.exports = { hasPragma: F, insertPragma: I };
        } }), mr = K({ "src/utils/is-non-empty-array.js"(l, h) {
          "use strict";
          V();
          function f(d) {
            return Array.isArray(d) && d.length > 0;
          }
          h.exports = f;
        } }), Mo = K({ "src/language-js/loc.js"(l, h) {
          "use strict";
          V();
          var f = mr();
          function d(S) {
            var F, I;
            let C = S.range ? S.range[0] : S.start, L = (F = (I = S.declaration) === null || I === void 0 ? void 0 : I.decorators) !== null && F !== void 0 ? F : S.decorators;
            return f(L) ? Math.min(d(L[0]), C) : C;
          }
          function y(S) {
            return S.range ? S.range[1] : S.end;
          }
          function P(S, F) {
            let I = d(S);
            return Number.isInteger(I) && I === d(F);
          }
          function g(S, F) {
            let I = y(S);
            return Number.isInteger(I) && I === y(F);
          }
          function T(S, F) {
            return P(S, F) && g(S, F);
          }
          h.exports = { locStart: d, locEnd: y, hasSameLocStart: P, hasSameLoc: T };
        } }), _o = K({ "src/language-js/parse/utils/create-parser.js"(l, h) {
          "use strict";
          V();
          var { hasPragma: f } = Uf(), { locStart: d, locEnd: y } = Mo();
          function P(g) {
            return g = typeof g == "function" ? { parse: g } : g, Object.assign({ astFormat: "estree", hasPragma: f, locStart: d, locEnd: y }, g);
          }
          h.exports = P;
        } }), yr = K({ "src/common/parser-create-error.js"(l, h) {
          "use strict";
          V();
          function f(d, y) {
            let P = new SyntaxError(d + " (" + y.start.line + ":" + y.start.column + ")");
            return P.loc = y, P;
          }
          h.exports = f;
        } }), Ro = K({ "src/language-js/parse/utils/create-babel-parse-error.js"(l, h) {
          "use strict";
          V();
          var f = yr();
          function d(y) {
            let { message: P, loc: g } = y;
            return f(P.replace(/ \(.*\)/, ""), { start: { line: g ? g.line : 0, column: g ? g.column + 1 : 0 } });
          }
          h.exports = d;
        } }), $f = K({ "src/language-js/utils/is-ts-keyword-type.js"(l, h) {
          "use strict";
          V();
          function f(d) {
            let { type: y } = d;
            return y.startsWith("TS") && y.endsWith("Keyword");
          }
          h.exports = f;
        } }), Hf = K({ "src/language-js/utils/is-block-comment.js"(l, h) {
          "use strict";
          V();
          var f = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]), d = (y) => f.has(y == null ? void 0 : y.type);
          h.exports = d;
        } }), zf = K({ "src/language-js/utils/is-type-cast-comment.js"(l, h) {
          "use strict";
          V();
          var f = Hf();
          function d(y) {
            return f(y) && y.value[0] === "*" && /@type\b/.test(y.value);
          }
          h.exports = d;
        } }), Vf = K({ "src/utils/get-last.js"(l, h) {
          "use strict";
          V();
          var f = (d) => d[d.length - 1];
          h.exports = f;
        } }), jo = K({ "src/language-js/parse/postprocess/visit-node.js"(l, h) {
          "use strict";
          V();
          function f(d, y) {
            if (Array.isArray(d)) {
              for (let P = 0; P < d.length; P++)
                d[P] = f(d[P], y);
              return d;
            }
            if (d && typeof d == "object" && typeof d.type == "string") {
              let P = Object.keys(d);
              for (let g = 0; g < P.length; g++)
                d[P[g]] = f(d[P[g]], y);
              return y(d) || d;
            }
            return d;
          }
          h.exports = f;
        } }), qo = K({ "src/language-js/parse/postprocess/throw-syntax-error.js"(l, h) {
          "use strict";
          V();
          var f = yr();
          function d(y, P) {
            let { start: g, end: T } = y.loc;
            throw f(P, { start: { line: g.line, column: g.column + 1 }, end: { line: T.line, column: T.column + 1 } });
          }
          h.exports = d;
        } }), Kf = K({ "src/language-js/parse/postprocess/typescript.js"(l, h) {
          "use strict";
          V();
          var f = mr(), d = jo(), y = qo(), P = { AbstractKeyword: 126, SourceFile: 308, PropertyDeclaration: 169 };
          function g(I) {
            for (; I && I.kind !== P.SourceFile; )
              I = I.parent;
            return I;
          }
          function T(I) {
            let { illegalDecorators: C } = I;
            if (!f(C))
              return;
            let [{ expression: L }] = C, j = g(L), [k, H] = [L.pos, L.end].map((W) => {
              let { line: B, character: _ } = j.getLineAndCharacterOfPosition(W);
              return { line: B + 1, column: _ };
            });
            y({ loc: { start: k, end: H } }, "Decorators are not valid here.");
          }
          function S(I, C) {
            I.kind !== P.PropertyDeclaration || I.modifiers && !I.modifiers.some((L) => L.kind === P.AbstractKeyword) || I.initializer && C.value === null && y(C, "Abstract property cannot have an initializer");
          }
          function F(I, C) {
            let { esTreeNodeToTSNodeMap: L, tsNodeToESTreeNodeMap: j } = C.tsParseResult;
            d(I, (k) => {
              let H = L.get(k);
              if (!H)
                return;
              let W = j.get(H);
              W === k && (T(H), S(H, W));
            });
          }
          h.exports = { throwErrorForInvalidNodes: F };
        } }), Wf = K({ "src/language-js/parse/postprocess/index.js"(l, h) {
          "use strict";
          V();
          var { locStart: f, locEnd: d } = Mo(), y = $f(), P = zf(), g = Vf(), T = jo(), { throwErrorForInvalidNodes: S } = Kf(), F = qo();
          function I(k, H) {
            if (H.parser === "typescript" && /@|abstract/.test(H.originalText) && S(k, H), H.parser !== "typescript" && H.parser !== "flow" && H.parser !== "acorn" && H.parser !== "espree" && H.parser !== "meriyah") {
              let B = /* @__PURE__ */ new Set();
              k = T(k, (_) => {
                _.leadingComments && _.leadingComments.some(P) && B.add(f(_));
              }), k = T(k, (_) => {
                if (_.type === "ParenthesizedExpression") {
                  let { expression: u } = _;
                  if (u.type === "TypeCastExpression")
                    return u.range = _.range, u;
                  let G = f(_);
                  if (!B.has(G))
                    return u.extra = Object.assign(Object.assign({}, u.extra), {}, { parenthesized: true }), u;
                }
              });
            }
            return k = T(k, (B) => {
              switch (B.type) {
                case "ChainExpression":
                  return C(B.expression);
                case "LogicalExpression": {
                  if (L(B))
                    return j(B);
                  break;
                }
                case "VariableDeclaration": {
                  let _ = g(B.declarations);
                  _ && _.init && W(B, _);
                  break;
                }
                case "TSParenthesizedType":
                  return y(B.typeAnnotation) || B.typeAnnotation.type === "TSThisType" || (B.typeAnnotation.range = [f(B), d(B)]), B.typeAnnotation;
                case "TSTypeParameter":
                  if (typeof B.name == "string") {
                    let _ = f(B);
                    B.name = { type: "Identifier", name: B.name, range: [_, _ + B.name.length] };
                  }
                  break;
                case "ObjectExpression":
                  if (H.parser === "typescript") {
                    let _ = B.properties.find((u) => u.type === "Property" && u.value.type === "TSEmptyBodyFunctionExpression");
                    _ && F(_.value, "Unexpected token.");
                  }
                  break;
                case "SequenceExpression": {
                  let _ = g(B.expressions);
                  B.range = [f(B), Math.min(d(_), d(B))];
                  break;
                }
                case "TopicReference":
                  H.__isUsingHackPipeline = true;
                  break;
                case "ExportAllDeclaration": {
                  let { exported: _ } = B;
                  if (H.parser === "meriyah" && _ && _.type === "Identifier") {
                    let u = H.originalText.slice(f(_), d(_));
                    (u.startsWith('"') || u.startsWith("'")) && (B.exported = Object.assign(Object.assign({}, B.exported), {}, { type: "Literal", value: B.exported.name, raw: u }));
                  }
                  break;
                }
                case "PropertyDefinition":
                  if (H.parser === "meriyah" && B.static && !B.computed && !B.key) {
                    let _ = "static", u = f(B);
                    Object.assign(B, { static: false, key: { type: "Identifier", name: _, range: [u, u + _.length] } });
                  }
                  break;
              }
            }), k;
            function W(B, _) {
              H.originalText[d(_)] !== ";" && (B.range = [f(B), d(_)]);
            }
          }
          function C(k) {
            switch (k.type) {
              case "CallExpression":
                k.type = "OptionalCallExpression", k.callee = C(k.callee);
                break;
              case "MemberExpression":
                k.type = "OptionalMemberExpression", k.object = C(k.object);
                break;
              case "TSNonNullExpression":
                k.expression = C(k.expression);
                break;
            }
            return k;
          }
          function L(k) {
            return k.type === "LogicalExpression" && k.right.type === "LogicalExpression" && k.operator === k.right.operator;
          }
          function j(k) {
            return L(k) ? j({ type: "LogicalExpression", operator: k.operator, left: j({ type: "LogicalExpression", operator: k.operator, left: k.left, right: k.right.left, range: [f(k.left), d(k.right.left)] }), right: k.right.right, range: [f(k), d(k)] }) : k;
          }
          h.exports = I;
        } }), Uo = K({ "node_modules/@babel/parser/lib/index.js"(l) {
          "use strict";
          V(), Object.defineProperty(l, "__esModule", { value: true });
          function h(t3, r) {
            if (t3 == null)
              return {};
            var e = {}, s = Object.keys(t3), i, a;
            for (a = 0; a < s.length; a++)
              i = s[a], !(r.indexOf(i) >= 0) && (e[i] = t3[i]);
            return e;
          }
          var f = class {
            constructor(t3, r, e) {
              this.line = void 0, this.column = void 0, this.index = void 0, this.line = t3, this.column = r, this.index = e;
            }
          }, d = class {
            constructor(t3, r) {
              this.start = void 0, this.end = void 0, this.filename = void 0, this.identifierName = void 0, this.start = t3, this.end = r;
            }
          };
          function y(t3, r) {
            let { line: e, column: s, index: i } = t3;
            return new f(e, s + r, i + r);
          }
          var P = { SyntaxError: "BABEL_PARSER_SYNTAX_ERROR", SourceTypeModuleError: "BABEL_PARSER_SOURCETYPE_MODULE_REQUIRED" }, g = function(t3) {
            let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : t3.length - 1;
            return { get() {
              return t3.reduce((e, s) => e[s], this);
            }, set(e) {
              t3.reduce((s, i, a) => a === r ? s[i] = e : s[i], this);
            } };
          }, T = (t3, r, e) => Object.keys(e).map((s) => [s, e[s]]).filter((s) => {
            let [, i] = s;
            return !!i;
          }).map((s) => {
            let [i, a] = s;
            return [i, typeof a == "function" ? { value: a, enumerable: false } : typeof a.reflect == "string" ? Object.assign({}, a, g(a.reflect.split("."))) : a];
          }).reduce((s, i) => {
            let [a, n] = i;
            return Object.defineProperty(s, a, Object.assign({ configurable: true }, n));
          }, Object.assign(new t3(), r)), S = { ImportMetaOutsideModule: { message: `import.meta may appear only with 'sourceType: "module"'`, code: P.SourceTypeModuleError }, ImportOutsideModule: { message: `'import' and 'export' may appear only with 'sourceType: "module"'`, code: P.SourceTypeModuleError } }, F = { ArrayPattern: "array destructuring pattern", AssignmentExpression: "assignment expression", AssignmentPattern: "assignment expression", ArrowFunctionExpression: "arrow function expression", ConditionalExpression: "conditional expression", CatchClause: "catch clause", ForOfStatement: "for-of statement", ForInStatement: "for-in statement", ForStatement: "for-loop", FormalParameters: "function parameter list", Identifier: "identifier", ImportSpecifier: "import specifier", ImportDefaultSpecifier: "import default specifier", ImportNamespaceSpecifier: "import namespace specifier", ObjectPattern: "object destructuring pattern", ParenthesizedExpression: "parenthesized expression", RestElement: "rest element", UpdateExpression: { true: "prefix operation", false: "postfix operation" }, VariableDeclarator: "variable declaration", YieldExpression: "yield expression" }, I = (t3) => {
            let { type: r, prefix: e } = t3;
            return r === "UpdateExpression" ? F.UpdateExpression[String(e)] : F[r];
          }, C = { AccessorIsGenerator: (t3) => {
            let { kind: r } = t3;
            return `A ${r}ter cannot be a generator.`;
          }, ArgumentsInClass: "'arguments' is only allowed in functions and class methods.", AsyncFunctionInSingleStatementContext: "Async functions can only be declared at the top level or inside a block.", AwaitBindingIdentifier: "Can not use 'await' as identifier inside an async function.", AwaitBindingIdentifierInStaticBlock: "Can not use 'await' as identifier inside a static block.", AwaitExpressionFormalParameter: "'await' is not allowed in async function parameters.", AwaitNotInAsyncContext: "'await' is only allowed within async functions and at the top levels of modules.", AwaitNotInAsyncFunction: "'await' is only allowed within async functions.", BadGetterArity: "A 'get' accessor must not have any formal parameters.", BadSetterArity: "A 'set' accessor must have exactly one formal parameter.", BadSetterRestParameter: "A 'set' accessor function argument must not be a rest parameter.", ConstructorClassField: "Classes may not have a field named 'constructor'.", ConstructorClassPrivateField: "Classes may not have a private field named '#constructor'.", ConstructorIsAccessor: "Class constructor may not be an accessor.", ConstructorIsAsync: "Constructor can't be an async function.", ConstructorIsGenerator: "Constructor can't be a generator.", DeclarationMissingInitializer: (t3) => {
            let { kind: r } = t3;
            return `Missing initializer in ${r} declaration.`;
          }, DecoratorArgumentsOutsideParentheses: "Decorator arguments must be moved inside parentheses: use '@(decorator(args))' instead of '@(decorator)(args)'.", DecoratorBeforeExport: "Decorators must be placed *before* the 'export' keyword. You can set the 'decoratorsBeforeExport' option to false to use the 'export @decorator class {}' syntax.", DecoratorConstructor: "Decorators can't be used with a constructor. Did you mean '@dec class { ... }'?", DecoratorExportClass: "Using the export keyword between a decorator and a class is not allowed. Please use `export @dec class` instead.", DecoratorSemicolon: "Decorators must not be followed by a semicolon.", DecoratorStaticBlock: "Decorators can't be used with a static block.", DeletePrivateField: "Deleting a private field is not allowed.", DestructureNamedImport: "ES2015 named imports do not destructure. Use another statement for destructuring after the import.", DuplicateConstructor: "Duplicate constructor in the same class.", DuplicateDefaultExport: "Only one default export allowed per module.", DuplicateExport: (t3) => {
            let { exportName: r } = t3;
            return `\`${r}\` has already been exported. Exported identifiers must be unique.`;
          }, DuplicateProto: "Redefinition of __proto__ property.", DuplicateRegExpFlags: "Duplicate regular expression flag.", ElementAfterRest: "Rest element must be last element.", EscapedCharNotAnIdentifier: "Invalid Unicode escape.", ExportBindingIsString: (t3) => {
            let { localName: r, exportName: e } = t3;
            return `A string literal cannot be used as an exported binding without \`from\`.
- Did you mean \`export { '${r}' as '${e}' } from 'some-module'\`?`;
          }, ExportDefaultFromAsIdentifier: "'from' is not allowed as an identifier after 'export default'.", ForInOfLoopInitializer: (t3) => {
            let { type: r } = t3;
            return `'${r === "ForInStatement" ? "for-in" : "for-of"}' loop variable declaration may not have an initializer.`;
          }, ForInUsing: "For-in loop may not start with 'using' declaration.", ForOfAsync: "The left-hand side of a for-of loop may not be 'async'.", ForOfLet: "The left-hand side of a for-of loop may not start with 'let'.", GeneratorInSingleStatementContext: "Generators can only be declared at the top level or inside a block.", IllegalBreakContinue: (t3) => {
            let { type: r } = t3;
            return `Unsyntactic ${r === "BreakStatement" ? "break" : "continue"}.`;
          }, IllegalLanguageModeDirective: "Illegal 'use strict' directive in function with non-simple parameter list.", IllegalReturn: "'return' outside of function.", ImportBindingIsString: (t3) => {
            let { importName: r } = t3;
            return `A string literal cannot be used as an imported binding.
- Did you mean \`import { "${r}" as foo }\`?`;
          }, ImportCallArgumentTrailingComma: "Trailing comma is disallowed inside import(...) arguments.", ImportCallArity: (t3) => {
            let { maxArgumentCount: r } = t3;
            return `\`import()\` requires exactly ${r === 1 ? "one argument" : "one or two arguments"}.`;
          }, ImportCallNotNewExpression: "Cannot use new with import(...).", ImportCallSpreadArgument: "`...` is not allowed in `import()`.", ImportJSONBindingNotDefault: "A JSON module can only be imported with `default`.", ImportReflectionHasAssertion: "`import module x` cannot have assertions.", ImportReflectionNotBinding: 'Only `import module x from "./module"` is valid.', IncompatibleRegExpUVFlags: "The 'u' and 'v' regular expression flags cannot be enabled at the same time.", InvalidBigIntLiteral: "Invalid BigIntLiteral.", InvalidCodePoint: "Code point out of bounds.", InvalidCoverInitializedName: "Invalid shorthand property initializer.", InvalidDecimal: "Invalid decimal.", InvalidDigit: (t3) => {
            let { radix: r } = t3;
            return `Expected number in radix ${r}.`;
          }, InvalidEscapeSequence: "Bad character escape sequence.", InvalidEscapeSequenceTemplate: "Invalid escape sequence in template.", InvalidEscapedReservedWord: (t3) => {
            let { reservedWord: r } = t3;
            return `Escape sequence in keyword ${r}.`;
          }, InvalidIdentifier: (t3) => {
            let { identifierName: r } = t3;
            return `Invalid identifier ${r}.`;
          }, InvalidLhs: (t3) => {
            let { ancestor: r } = t3;
            return `Invalid left-hand side in ${I(r)}.`;
          }, InvalidLhsBinding: (t3) => {
            let { ancestor: r } = t3;
            return `Binding invalid left-hand side in ${I(r)}.`;
          }, InvalidNumber: "Invalid number.", InvalidOrMissingExponent: "Floating-point numbers require a valid exponent after the 'e'.", InvalidOrUnexpectedToken: (t3) => {
            let { unexpected: r } = t3;
            return `Unexpected character '${r}'.`;
          }, InvalidParenthesizedAssignment: "Invalid parenthesized assignment pattern.", InvalidPrivateFieldResolution: (t3) => {
            let { identifierName: r } = t3;
            return `Private name #${r} is not defined.`;
          }, InvalidPropertyBindingPattern: "Binding member expression.", InvalidRecordProperty: "Only properties and spread elements are allowed in record definitions.", InvalidRestAssignmentPattern: "Invalid rest operator's argument.", LabelRedeclaration: (t3) => {
            let { labelName: r } = t3;
            return `Label '${r}' is already declared.`;
          }, LetInLexicalBinding: "'let' is not allowed to be used as a name in 'let' or 'const' declarations.", LineTerminatorBeforeArrow: "No line break is allowed before '=>'.", MalformedRegExpFlags: "Invalid regular expression flag.", MissingClassName: "A class name is required.", MissingEqInAssignment: "Only '=' operator can be used for specifying default value.", MissingSemicolon: "Missing semicolon.", MissingPlugin: (t3) => {
            let { missingPlugin: r } = t3;
            return `This experimental syntax requires enabling the parser plugin: ${r.map((e) => JSON.stringify(e)).join(", ")}.`;
          }, MissingOneOfPlugins: (t3) => {
            let { missingPlugin: r } = t3;
            return `This experimental syntax requires enabling one of the following parser plugin(s): ${r.map((e) => JSON.stringify(e)).join(", ")}.`;
          }, MissingUnicodeEscape: "Expecting Unicode escape sequence \\uXXXX.", MixingCoalesceWithLogical: "Nullish coalescing operator(??) requires parens when mixing with logical operators.", ModuleAttributeDifferentFromType: "The only accepted module attribute is `type`.", ModuleAttributeInvalidValue: "Only string literals are allowed as module attribute values.", ModuleAttributesWithDuplicateKeys: (t3) => {
            let { key: r } = t3;
            return `Duplicate key "${r}" is not allowed in module attributes.`;
          }, ModuleExportNameHasLoneSurrogate: (t3) => {
            let { surrogateCharCode: r } = t3;
            return `An export name cannot include a lone surrogate, found '\\u${r.toString(16)}'.`;
          }, ModuleExportUndefined: (t3) => {
            let { localName: r } = t3;
            return `Export '${r}' is not defined.`;
          }, MultipleDefaultsInSwitch: "Multiple default clauses.", NewlineAfterThrow: "Illegal newline after throw.", NoCatchOrFinally: "Missing catch or finally clause.", NumberIdentifier: "Identifier directly after number.", NumericSeparatorInEscapeSequence: "Numeric separators are not allowed inside unicode escape sequences or hex escape sequences.", ObsoleteAwaitStar: "'await*' has been removed from the async functions proposal. Use Promise.all() instead.", OptionalChainingNoNew: "Constructors in/after an Optional Chain are not allowed.", OptionalChainingNoTemplate: "Tagged Template Literals are not allowed in optionalChain.", OverrideOnConstructor: "'override' modifier cannot appear on a constructor declaration.", ParamDupe: "Argument name clash.", PatternHasAccessor: "Object pattern can't contain getter or setter.", PatternHasMethod: "Object pattern can't contain methods.", PrivateInExpectedIn: (t3) => {
            let { identifierName: r } = t3;
            return `Private names are only allowed in property accesses (\`obj.#${r}\`) or in \`in\` expressions (\`#${r} in obj\`).`;
          }, PrivateNameRedeclaration: (t3) => {
            let { identifierName: r } = t3;
            return `Duplicate private name #${r}.`;
          }, RecordExpressionBarIncorrectEndSyntaxType: "Record expressions ending with '|}' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.", RecordExpressionBarIncorrectStartSyntaxType: "Record expressions starting with '{|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.", RecordExpressionHashIncorrectStartSyntaxType: "Record expressions starting with '#{' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.", RecordNoProto: "'__proto__' is not allowed in Record expressions.", RestTrailingComma: "Unexpected trailing comma after rest element.", SloppyFunction: "In non-strict mode code, functions can only be declared at top level, inside a block, or as the body of an if statement.", StaticPrototype: "Classes may not have static property named prototype.", SuperNotAllowed: "`super()` is only valid inside a class constructor of a subclass. Maybe a typo in the method name ('constructor') or not extending another class?", SuperPrivateField: "Private fields can't be accessed on super.", TrailingDecorator: "Decorators must be attached to a class element.", TupleExpressionBarIncorrectEndSyntaxType: "Tuple expressions ending with '|]' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.", TupleExpressionBarIncorrectStartSyntaxType: "Tuple expressions starting with '[|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.", TupleExpressionHashIncorrectStartSyntaxType: "Tuple expressions starting with '#[' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.", UnexpectedArgumentPlaceholder: "Unexpected argument placeholder.", UnexpectedAwaitAfterPipelineBody: 'Unexpected "await" after pipeline body; await must have parentheses in minimal proposal.', UnexpectedDigitAfterHash: "Unexpected digit after hash token.", UnexpectedImportExport: "'import' and 'export' may only appear at the top level.", UnexpectedKeyword: (t3) => {
            let { keyword: r } = t3;
            return `Unexpected keyword '${r}'.`;
          }, UnexpectedLeadingDecorator: "Leading decorators must be attached to a class declaration.", UnexpectedLexicalDeclaration: "Lexical declaration cannot appear in a single-statement context.", UnexpectedNewTarget: "`new.target` can only be used in functions or class properties.", UnexpectedNumericSeparator: "A numeric separator is only allowed between two digits.", UnexpectedPrivateField: "Unexpected private name.", UnexpectedReservedWord: (t3) => {
            let { reservedWord: r } = t3;
            return `Unexpected reserved word '${r}'.`;
          }, UnexpectedSuper: "'super' is only allowed in object methods and classes.", UnexpectedToken: (t3) => {
            let { expected: r, unexpected: e } = t3;
            return `Unexpected token${e ? ` '${e}'.` : ""}${r ? `, expected "${r}"` : ""}`;
          }, UnexpectedTokenUnaryExponentiation: "Illegal expression. Wrap left hand side or entire exponentiation in parentheses.", UnexpectedUsingDeclaration: "Using declaration cannot appear in the top level when source type is `script`.", UnsupportedBind: "Binding should be performed on object property.", UnsupportedDecoratorExport: "A decorated export must export a class declaration.", UnsupportedDefaultExport: "Only expressions, functions or classes are allowed as the `default` export.", UnsupportedImport: "`import` can only be used in `import()` or `import.meta`.", UnsupportedMetaProperty: (t3) => {
            let { target: r, onlyValidPropertyName: e } = t3;
            return `The only valid meta property for ${r} is ${r}.${e}.`;
          }, UnsupportedParameterDecorator: "Decorators cannot be used to decorate parameters.", UnsupportedPropertyDecorator: "Decorators cannot be used to decorate object literal properties.", UnsupportedSuper: "'super' can only be used with function calls (i.e. super()) or in property accesses (i.e. super.prop or super[prop]).", UnterminatedComment: "Unterminated comment.", UnterminatedRegExp: "Unterminated regular expression.", UnterminatedString: "Unterminated string constant.", UnterminatedTemplate: "Unterminated template.", UsingDeclarationHasBindingPattern: "Using declaration cannot have destructuring patterns.", VarRedeclaration: (t3) => {
            let { identifierName: r } = t3;
            return `Identifier '${r}' has already been declared.`;
          }, YieldBindingIdentifier: "Can not use 'yield' as identifier inside a generator.", YieldInParameter: "Yield expression is not allowed in formal parameters.", ZeroDigitNumericSeparator: "Numeric separator can not be used after leading 0." }, L = { StrictDelete: "Deleting local variable in strict mode.", StrictEvalArguments: (t3) => {
            let { referenceName: r } = t3;
            return `Assigning to '${r}' in strict mode.`;
          }, StrictEvalArgumentsBinding: (t3) => {
            let { bindingName: r } = t3;
            return `Binding '${r}' in strict mode.`;
          }, StrictFunction: "In strict mode code, functions can only be declared at top level or inside a block.", StrictNumericEscape: "The only valid numeric escape in strict mode is '\\0'.", StrictOctalLiteral: "Legacy octal literals are not allowed in strict mode.", StrictWith: "'with' in strict mode." }, j = /* @__PURE__ */ new Set(["ArrowFunctionExpression", "AssignmentExpression", "ConditionalExpression", "YieldExpression"]), k = { PipeBodyIsTighter: "Unexpected yield after pipeline body; any yield expression acting as Hack-style pipe body must be parenthesized due to its loose operator precedence.", PipeTopicRequiresHackPipes: 'Topic reference is used, but the pipelineOperator plugin was not passed a "proposal": "hack" or "smart" option.', PipeTopicUnbound: "Topic reference is unbound; it must be inside a pipe body.", PipeTopicUnconfiguredToken: (t3) => {
            let { token: r } = t3;
            return `Invalid topic token ${r}. In order to use ${r} as a topic reference, the pipelineOperator plugin must be configured with { "proposal": "hack", "topicToken": "${r}" }.`;
          }, PipeTopicUnused: "Hack-style pipe body does not contain a topic reference; Hack-style pipes must use topic at least once.", PipeUnparenthesizedBody: (t3) => {
            let { type: r } = t3;
            return `Hack-style pipe body cannot be an unparenthesized ${I({ type: r })}; please wrap it in parentheses.`;
          }, PipelineBodyNoArrow: 'Unexpected arrow "=>" after pipeline body; arrow function in pipeline body must be parenthesized.', PipelineBodySequenceExpression: "Pipeline body may not be a comma-separated sequence expression.", PipelineHeadSequenceExpression: "Pipeline head should not be a comma-separated sequence expression.", PipelineTopicUnused: "Pipeline is in topic style but does not use topic reference.", PrimaryTopicNotAllowed: "Topic reference was used in a lexical context without topic binding.", PrimaryTopicRequiresSmartPipeline: 'Topic reference is used, but the pipelineOperator plugin was not passed a "proposal": "hack" or "smart" option.' }, H = ["toMessage"], W = ["message"];
          function B(t3) {
            let { toMessage: r } = t3, e = h(t3, H);
            return function s(i) {
              let { loc: a, details: n } = i;
              return T(SyntaxError, Object.assign({}, e, { loc: a }), { clone() {
                let o = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, c = o.loc || {};
                return s({ loc: new f("line" in c ? c.line : this.loc.line, "column" in c ? c.column : this.loc.column, "index" in c ? c.index : this.loc.index), details: Object.assign({}, this.details, o.details) });
              }, details: { value: n, enumerable: false }, message: { get() {
                return `${r(this.details)} (${this.loc.line}:${this.loc.column})`;
              }, set(o) {
                Object.defineProperty(this, "message", { value: o });
              } }, pos: { reflect: "loc.index", enumerable: true }, missingPlugin: "missingPlugin" in n && { reflect: "details.missingPlugin", enumerable: true } });
            };
          }
          function _(t3, r) {
            if (Array.isArray(t3))
              return (s) => _(s, t3[0]);
            let e = {};
            for (let s of Object.keys(t3)) {
              let i = t3[s], a = typeof i == "string" ? { message: () => i } : typeof i == "function" ? { message: i } : i, { message: n } = a, o = h(a, W), c = typeof n == "string" ? () => n : n;
              e[s] = B(Object.assign({ code: P.SyntaxError, reasonCode: s, toMessage: c }, r ? { syntaxPlugin: r } : {}, o));
            }
            return e;
          }
          var u = Object.assign({}, _(S), _(C), _(L), _`pipelineOperator`(k)), { defineProperty: G } = Object, oe = (t3, r) => G(t3, r, { enumerable: false, value: t3[r] });
          function X(t3) {
            return t3.loc.start && oe(t3.loc.start, "index"), t3.loc.end && oe(t3.loc.end, "index"), t3;
          }
          var _e = (t3) => class extends t3 {
            parse() {
              let e = X(super.parse());
              return this.options.tokens && (e.tokens = e.tokens.map(X)), e;
            }
            parseRegExpLiteral(e) {
              let { pattern: s, flags: i } = e, a = null;
              try {
                a = new RegExp(s, i);
              } catch {
              }
              let n = this.estreeParseLiteral(a);
              return n.regex = { pattern: s, flags: i }, n;
            }
            parseBigIntLiteral(e) {
              let s;
              try {
                s = BigInt(e);
              } catch {
                s = null;
              }
              let i = this.estreeParseLiteral(s);
              return i.bigint = String(i.value || e), i;
            }
            parseDecimalLiteral(e) {
              let i = this.estreeParseLiteral(null);
              return i.decimal = String(i.value || e), i;
            }
            estreeParseLiteral(e) {
              return this.parseLiteral(e, "Literal");
            }
            parseStringLiteral(e) {
              return this.estreeParseLiteral(e);
            }
            parseNumericLiteral(e) {
              return this.estreeParseLiteral(e);
            }
            parseNullLiteral() {
              return this.estreeParseLiteral(null);
            }
            parseBooleanLiteral(e) {
              return this.estreeParseLiteral(e);
            }
            directiveToStmt(e) {
              let s = e.value;
              delete e.value, s.type = "Literal", s.raw = s.extra.raw, s.value = s.extra.expressionValue;
              let i = e;
              return i.type = "ExpressionStatement", i.expression = s, i.directive = s.extra.rawValue, delete s.extra, i;
            }
            initFunction(e, s) {
              super.initFunction(e, s), e.expression = false;
            }
            checkDeclaration(e) {
              e != null && this.isObjectProperty(e) ? this.checkDeclaration(e.value) : super.checkDeclaration(e);
            }
            getObjectOrClassMethodParams(e) {
              return e.value.params;
            }
            isValidDirective(e) {
              var s;
              return e.type === "ExpressionStatement" && e.expression.type === "Literal" && typeof e.expression.value == "string" && !((s = e.expression.extra) != null && s.parenthesized);
            }
            parseBlockBody(e, s, i, a, n) {
              super.parseBlockBody(e, s, i, a, n);
              let o = e.directives.map((c) => this.directiveToStmt(c));
              e.body = o.concat(e.body), delete e.directives;
            }
            pushClassMethod(e, s, i, a, n, o) {
              this.parseMethod(s, i, a, n, o, "ClassMethod", true), s.typeParameters && (s.value.typeParameters = s.typeParameters, delete s.typeParameters), e.body.push(s);
            }
            parsePrivateName() {
              let e = super.parsePrivateName();
              return this.getPluginOption("estree", "classFeatures") ? this.convertPrivateNameToPrivateIdentifier(e) : e;
            }
            convertPrivateNameToPrivateIdentifier(e) {
              let s = super.getPrivateNameSV(e);
              return e = e, delete e.id, e.name = s, e.type = "PrivateIdentifier", e;
            }
            isPrivateName(e) {
              return this.getPluginOption("estree", "classFeatures") ? e.type === "PrivateIdentifier" : super.isPrivateName(e);
            }
            getPrivateNameSV(e) {
              return this.getPluginOption("estree", "classFeatures") ? e.name : super.getPrivateNameSV(e);
            }
            parseLiteral(e, s) {
              let i = super.parseLiteral(e, s);
              return i.raw = i.extra.raw, delete i.extra, i;
            }
            parseFunctionBody(e, s) {
              let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              super.parseFunctionBody(e, s, i), e.expression = e.body.type !== "BlockStatement";
            }
            parseMethod(e, s, i, a, n, o) {
              let c = arguments.length > 6 && arguments[6] !== void 0 ? arguments[6] : false, p = this.startNode();
              return p.kind = e.kind, p = super.parseMethod(p, s, i, a, n, o, c), p.type = "FunctionExpression", delete p.kind, e.value = p, o === "ClassPrivateMethod" && (e.computed = false), this.finishNode(e, "MethodDefinition");
            }
            parseClassProperty() {
              let e = super.parseClassProperty(...arguments);
              return this.getPluginOption("estree", "classFeatures") && (e.type = "PropertyDefinition"), e;
            }
            parseClassPrivateProperty() {
              let e = super.parseClassPrivateProperty(...arguments);
              return this.getPluginOption("estree", "classFeatures") && (e.type = "PropertyDefinition", e.computed = false), e;
            }
            parseObjectMethod(e, s, i, a, n) {
              let o = super.parseObjectMethod(e, s, i, a, n);
              return o && (o.type = "Property", o.kind === "method" && (o.kind = "init"), o.shorthand = false), o;
            }
            parseObjectProperty(e, s, i, a) {
              let n = super.parseObjectProperty(e, s, i, a);
              return n && (n.kind = "init", n.type = "Property"), n;
            }
            isValidLVal(e, s, i) {
              return e === "Property" ? "value" : super.isValidLVal(e, s, i);
            }
            isAssignable(e, s) {
              return e != null && this.isObjectProperty(e) ? this.isAssignable(e.value, s) : super.isAssignable(e, s);
            }
            toAssignable(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              if (e != null && this.isObjectProperty(e)) {
                let { key: i, value: a } = e;
                this.isPrivateName(i) && this.classScope.usePrivateName(this.getPrivateNameSV(i), i.loc.start), this.toAssignable(a, s);
              } else
                super.toAssignable(e, s);
            }
            toAssignableObjectExpressionProp(e, s, i) {
              e.kind === "get" || e.kind === "set" ? this.raise(u.PatternHasAccessor, { at: e.key }) : e.method ? this.raise(u.PatternHasMethod, { at: e.key }) : super.toAssignableObjectExpressionProp(e, s, i);
            }
            finishCallExpression(e, s) {
              let i = super.finishCallExpression(e, s);
              if (i.callee.type === "Import") {
                if (i.type = "ImportExpression", i.source = i.arguments[0], this.hasPlugin("importAssertions")) {
                  var a;
                  i.attributes = (a = i.arguments[1]) != null ? a : null;
                }
                delete i.arguments, delete i.callee;
              }
              return i;
            }
            toReferencedArguments(e) {
              e.type !== "ImportExpression" && super.toReferencedArguments(e);
            }
            parseExport(e, s) {
              let i = this.state.lastTokStartLoc, a = super.parseExport(e, s);
              switch (a.type) {
                case "ExportAllDeclaration":
                  a.exported = null;
                  break;
                case "ExportNamedDeclaration":
                  a.specifiers.length === 1 && a.specifiers[0].type === "ExportNamespaceSpecifier" && (a.type = "ExportAllDeclaration", a.exported = a.specifiers[0].exported, delete a.specifiers);
                case "ExportDefaultDeclaration":
                  {
                    var n;
                    let { declaration: o } = a;
                    (o == null ? void 0 : o.type) === "ClassDeclaration" && ((n = o.decorators) == null ? void 0 : n.length) > 0 && o.start === a.start && this.resetStartLocation(a, i);
                  }
                  break;
              }
              return a;
            }
            parseSubscript(e, s, i, a) {
              let n = super.parseSubscript(e, s, i, a);
              if (a.optionalChainMember) {
                if ((n.type === "OptionalMemberExpression" || n.type === "OptionalCallExpression") && (n.type = n.type.substring(8)), a.stop) {
                  let o = this.startNodeAtNode(n);
                  return o.expression = n, this.finishNode(o, "ChainExpression");
                }
              } else
                (n.type === "MemberExpression" || n.type === "CallExpression") && (n.optional = false);
              return n;
            }
            hasPropertyAsPrivateName(e) {
              return e.type === "ChainExpression" && (e = e.expression), super.hasPropertyAsPrivateName(e);
            }
            isOptionalChain(e) {
              return e.type === "ChainExpression";
            }
            isObjectProperty(e) {
              return e.type === "Property" && e.kind === "init" && !e.method;
            }
            isObjectMethod(e) {
              return e.method || e.kind === "get" || e.kind === "set";
            }
            finishNodeAt(e, s, i) {
              return X(super.finishNodeAt(e, s, i));
            }
            resetStartLocation(e, s) {
              super.resetStartLocation(e, s), X(e);
            }
            resetEndLocation(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this.state.lastTokEndLoc;
              super.resetEndLocation(e, s), X(e);
            }
          }, Z = class {
            constructor(t3, r) {
              this.token = void 0, this.preserveSpace = void 0, this.token = t3, this.preserveSpace = !!r;
            }
          }, $2 = { brace: new Z("{"), j_oTag: new Z("<tag"), j_cTag: new Z("</tag"), j_expr: new Z("<tag>...</tag>", true) };
          $2.template = new Z("`", true);
          var M = true, E = true, Je = true, ee = true, fe = true, zo = true, xr = class {
            constructor(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
              this.label = void 0, this.keyword = void 0, this.beforeExpr = void 0, this.startsExpr = void 0, this.rightAssociative = void 0, this.isLoop = void 0, this.isAssign = void 0, this.prefix = void 0, this.postfix = void 0, this.binop = void 0, this.label = t3, this.keyword = r.keyword, this.beforeExpr = !!r.beforeExpr, this.startsExpr = !!r.startsExpr, this.rightAssociative = !!r.rightAssociative, this.isLoop = !!r.isLoop, this.isAssign = !!r.isAssign, this.prefix = !!r.prefix, this.postfix = !!r.postfix, this.binop = r.binop != null ? r.binop : null, this.updateContext = null;
            }
          }, zt = /* @__PURE__ */ new Map();
          function U(t3) {
            let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            r.keyword = t3;
            let e = N(t3, r);
            return zt.set(t3, e), e;
          }
          function re(t3, r) {
            return N(t3, { beforeExpr: M, binop: r });
          }
          var Xe = -1, me = [], Vt = [], Kt = [], Wt = [], Gt = [], Jt = [];
          function N(t3) {
            let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            var e, s, i, a;
            return ++Xe, Vt.push(t3), Kt.push((e = r.binop) != null ? e : -1), Wt.push((s = r.beforeExpr) != null ? s : false), Gt.push((i = r.startsExpr) != null ? i : false), Jt.push((a = r.prefix) != null ? a : false), me.push(new xr(t3, r)), Xe;
          }
          function q(t3) {
            let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            var e, s, i, a;
            return ++Xe, zt.set(t3, Xe), Vt.push(t3), Kt.push((e = r.binop) != null ? e : -1), Wt.push((s = r.beforeExpr) != null ? s : false), Gt.push((i = r.startsExpr) != null ? i : false), Jt.push((a = r.prefix) != null ? a : false), me.push(new xr("name", r)), Xe;
          }
          var Vo = { bracketL: N("[", { beforeExpr: M, startsExpr: E }), bracketHashL: N("#[", { beforeExpr: M, startsExpr: E }), bracketBarL: N("[|", { beforeExpr: M, startsExpr: E }), bracketR: N("]"), bracketBarR: N("|]"), braceL: N("{", { beforeExpr: M, startsExpr: E }), braceBarL: N("{|", { beforeExpr: M, startsExpr: E }), braceHashL: N("#{", { beforeExpr: M, startsExpr: E }), braceR: N("}"), braceBarR: N("|}"), parenL: N("(", { beforeExpr: M, startsExpr: E }), parenR: N(")"), comma: N(",", { beforeExpr: M }), semi: N(";", { beforeExpr: M }), colon: N(":", { beforeExpr: M }), doubleColon: N("::", { beforeExpr: M }), dot: N("."), question: N("?", { beforeExpr: M }), questionDot: N("?."), arrow: N("=>", { beforeExpr: M }), template: N("template"), ellipsis: N("...", { beforeExpr: M }), backQuote: N("`", { startsExpr: E }), dollarBraceL: N("${", { beforeExpr: M, startsExpr: E }), templateTail: N("...`", { startsExpr: E }), templateNonTail: N("...${", { beforeExpr: M, startsExpr: E }), at: N("@"), hash: N("#", { startsExpr: E }), interpreterDirective: N("#!..."), eq: N("=", { beforeExpr: M, isAssign: ee }), assign: N("_=", { beforeExpr: M, isAssign: ee }), slashAssign: N("_=", { beforeExpr: M, isAssign: ee }), xorAssign: N("_=", { beforeExpr: M, isAssign: ee }), moduloAssign: N("_=", { beforeExpr: M, isAssign: ee }), incDec: N("++/--", { prefix: fe, postfix: zo, startsExpr: E }), bang: N("!", { beforeExpr: M, prefix: fe, startsExpr: E }), tilde: N("~", { beforeExpr: M, prefix: fe, startsExpr: E }), doubleCaret: N("^^", { startsExpr: E }), doubleAt: N("@@", { startsExpr: E }), pipeline: re("|>", 0), nullishCoalescing: re("??", 1), logicalOR: re("||", 1), logicalAND: re("&&", 2), bitwiseOR: re("|", 3), bitwiseXOR: re("^", 4), bitwiseAND: re("&", 5), equality: re("==/!=/===/!==", 6), lt: re("</>/<=/>=", 7), gt: re("</>/<=/>=", 7), relational: re("</>/<=/>=", 7), bitShift: re("<</>>/>>>", 8), bitShiftL: re("<</>>/>>>", 8), bitShiftR: re("<</>>/>>>", 8), plusMin: N("+/-", { beforeExpr: M, binop: 9, prefix: fe, startsExpr: E }), modulo: N("%", { binop: 10, startsExpr: E }), star: N("*", { binop: 10 }), slash: re("/", 10), exponent: N("**", { beforeExpr: M, binop: 11, rightAssociative: true }), _in: U("in", { beforeExpr: M, binop: 7 }), _instanceof: U("instanceof", { beforeExpr: M, binop: 7 }), _break: U("break"), _case: U("case", { beforeExpr: M }), _catch: U("catch"), _continue: U("continue"), _debugger: U("debugger"), _default: U("default", { beforeExpr: M }), _else: U("else", { beforeExpr: M }), _finally: U("finally"), _function: U("function", { startsExpr: E }), _if: U("if"), _return: U("return", { beforeExpr: M }), _switch: U("switch"), _throw: U("throw", { beforeExpr: M, prefix: fe, startsExpr: E }), _try: U("try"), _var: U("var"), _const: U("const"), _with: U("with"), _new: U("new", { beforeExpr: M, startsExpr: E }), _this: U("this", { startsExpr: E }), _super: U("super", { startsExpr: E }), _class: U("class", { startsExpr: E }), _extends: U("extends", { beforeExpr: M }), _export: U("export"), _import: U("import", { startsExpr: E }), _null: U("null", { startsExpr: E }), _true: U("true", { startsExpr: E }), _false: U("false", { startsExpr: E }), _typeof: U("typeof", { beforeExpr: M, prefix: fe, startsExpr: E }), _void: U("void", { beforeExpr: M, prefix: fe, startsExpr: E }), _delete: U("delete", { beforeExpr: M, prefix: fe, startsExpr: E }), _do: U("do", { isLoop: Je, beforeExpr: M }), _for: U("for", { isLoop: Je }), _while: U("while", { isLoop: Je }), _as: q("as", { startsExpr: E }), _assert: q("assert", { startsExpr: E }), _async: q("async", { startsExpr: E }), _await: q("await", { startsExpr: E }), _from: q("from", { startsExpr: E }), _get: q("get", { startsExpr: E }), _let: q("let", { startsExpr: E }), _meta: q("meta", { startsExpr: E }), _of: q("of", { startsExpr: E }), _sent: q("sent", { startsExpr: E }), _set: q("set", { startsExpr: E }), _static: q("static", { startsExpr: E }), _using: q("using", { startsExpr: E }), _yield: q("yield", { startsExpr: E }), _asserts: q("asserts", { startsExpr: E }), _checks: q("checks", { startsExpr: E }), _exports: q("exports", { startsExpr: E }), _global: q("global", { startsExpr: E }), _implements: q("implements", { startsExpr: E }), _intrinsic: q("intrinsic", { startsExpr: E }), _infer: q("infer", { startsExpr: E }), _is: q("is", { startsExpr: E }), _mixins: q("mixins", { startsExpr: E }), _proto: q("proto", { startsExpr: E }), _require: q("require", { startsExpr: E }), _satisfies: q("satisfies", { startsExpr: E }), _keyof: q("keyof", { startsExpr: E }), _readonly: q("readonly", { startsExpr: E }), _unique: q("unique", { startsExpr: E }), _abstract: q("abstract", { startsExpr: E }), _declare: q("declare", { startsExpr: E }), _enum: q("enum", { startsExpr: E }), _module: q("module", { startsExpr: E }), _namespace: q("namespace", { startsExpr: E }), _interface: q("interface", { startsExpr: E }), _type: q("type", { startsExpr: E }), _opaque: q("opaque", { startsExpr: E }), name: N("name", { startsExpr: E }), string: N("string", { startsExpr: E }), num: N("num", { startsExpr: E }), bigint: N("bigint", { startsExpr: E }), decimal: N("decimal", { startsExpr: E }), regexp: N("regexp", { startsExpr: E }), privateName: N("#name", { startsExpr: E }), eof: N("eof"), jsxName: N("jsxName"), jsxText: N("jsxText", { beforeExpr: true }), jsxTagStart: N("jsxTagStart", { startsExpr: true }), jsxTagEnd: N("jsxTagEnd"), placeholder: N("%%", { startsExpr: true }) };
          function z(t3) {
            return t3 >= 93 && t3 <= 130;
          }
          function Ko(t3) {
            return t3 <= 92;
          }
          function ye(t3) {
            return t3 >= 58 && t3 <= 130;
          }
          function gr(t3) {
            return t3 >= 58 && t3 <= 134;
          }
          function Wo(t3) {
            return Wt[t3];
          }
          function Xt(t3) {
            return Gt[t3];
          }
          function Go(t3) {
            return t3 >= 29 && t3 <= 33;
          }
          function Pr(t3) {
            return t3 >= 127 && t3 <= 129;
          }
          function Jo(t3) {
            return t3 >= 90 && t3 <= 92;
          }
          function Yt(t3) {
            return t3 >= 58 && t3 <= 92;
          }
          function Xo(t3) {
            return t3 >= 39 && t3 <= 59;
          }
          function Yo(t3) {
            return t3 === 34;
          }
          function Qo(t3) {
            return Jt[t3];
          }
          function Zo(t3) {
            return t3 >= 119 && t3 <= 121;
          }
          function el(t3) {
            return t3 >= 122 && t3 <= 128;
          }
          function Ee(t3) {
            return Vt[t3];
          }
          function ut(t3) {
            return Kt[t3];
          }
          function tl(t3) {
            return t3 === 57;
          }
          function ct(t3) {
            return t3 >= 24 && t3 <= 25;
          }
          function xe(t3) {
            return me[t3];
          }
          me[8].updateContext = (t3) => {
            t3.pop();
          }, me[5].updateContext = me[7].updateContext = me[23].updateContext = (t3) => {
            t3.push($2.brace);
          }, me[22].updateContext = (t3) => {
            t3[t3.length - 1] === $2.template ? t3.pop() : t3.push($2.template);
          }, me[140].updateContext = (t3) => {
            t3.push($2.j_expr, $2.j_oTag);
          };
          var Qt = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC", Ar = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F", sl = new RegExp("[" + Qt + "]"), rl = new RegExp("[" + Qt + Ar + "]");
          Qt = Ar = null;
          var Tr = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191], il = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
          function Zt(t3, r) {
            let e = 65536;
            for (let s = 0, i = r.length; s < i; s += 2) {
              if (e += r[s], e > t3)
                return false;
              if (e += r[s + 1], e >= t3)
                return true;
            }
            return false;
          }
          function ge(t3) {
            return t3 < 65 ? t3 === 36 : t3 <= 90 ? true : t3 < 97 ? t3 === 95 : t3 <= 122 ? true : t3 <= 65535 ? t3 >= 170 && sl.test(String.fromCharCode(t3)) : Zt(t3, Tr);
          }
          function Re(t3) {
            return t3 < 48 ? t3 === 36 : t3 < 58 ? true : t3 < 65 ? false : t3 <= 90 ? true : t3 < 97 ? t3 === 95 : t3 <= 122 ? true : t3 <= 65535 ? t3 >= 170 && rl.test(String.fromCharCode(t3)) : Zt(t3, Tr) || Zt(t3, il);
          }
          var es = { keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"], strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"], strictBind: ["eval", "arguments"] }, al = new Set(es.keyword), nl = new Set(es.strict), ol = new Set(es.strictBind);
          function vr(t3, r) {
            return r && t3 === "await" || t3 === "enum";
          }
          function Er(t3, r) {
            return vr(t3, r) || nl.has(t3);
          }
          function Cr(t3) {
            return ol.has(t3);
          }
          function br(t3, r) {
            return Er(t3, r) || Cr(t3);
          }
          function ll(t3) {
            return al.has(t3);
          }
          function hl(t3, r, e) {
            return t3 === 64 && r === 64 && ge(e);
          }
          var ul = /* @__PURE__ */ new Set(["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete", "implements", "interface", "let", "package", "private", "protected", "public", "static", "yield", "eval", "arguments", "enum", "await"]);
          function cl(t3) {
            return ul.has(t3);
          }
          var je = 0, qe = 1, Pe = 2, ts = 4, Sr = 8, pt = 16, wr = 32, Ne = 64, ft = 128, Ue = 256, dt = qe | Pe | ft | Ue, Ae = 1, ke = 2, Ir = 4, Ce = 8, mt = 16, Nr = 64, yt = 128, ss = 256, rs = 512, is = 1024, as = 2048, Ye = 4096, kr = Ae | ke | Ce | yt, De = Ae | 0 | Ce | 0, xt = Ae | 0 | Ir | 0, Dr = Ae | 0 | mt | 0, pl = 0 | ke | 0 | yt, fl = 0 | ke | 0 | 0, Fr = Ae | ke | Ce | ss, Lr = 0 | is, be = 0 | Nr, dl = Ae | 0 | 0 | Nr, ml = Fr | rs, yl = 0 | is, Or = 0 | ke | 0 | Ye, xl = as, gt = 4, ns = 2, os = 1, ls = ns | os, gl = ns | gt, Pl = os | gt, Al = ns, Tl = os, hs = 0, us = class {
            constructor(t3) {
              this.var = /* @__PURE__ */ new Set(), this.lexical = /* @__PURE__ */ new Set(), this.functions = /* @__PURE__ */ new Set(), this.flags = t3;
            }
          }, cs = class {
            constructor(t3, r) {
              this.parser = void 0, this.scopeStack = [], this.inModule = void 0, this.undefinedExports = /* @__PURE__ */ new Map(), this.parser = t3, this.inModule = r;
            }
            get inTopLevel() {
              return (this.currentScope().flags & qe) > 0;
            }
            get inFunction() {
              return (this.currentVarScopeFlags() & Pe) > 0;
            }
            get allowSuper() {
              return (this.currentThisScopeFlags() & pt) > 0;
            }
            get allowDirectSuper() {
              return (this.currentThisScopeFlags() & wr) > 0;
            }
            get inClass() {
              return (this.currentThisScopeFlags() & Ne) > 0;
            }
            get inClassAndNotInNonArrowFunction() {
              let t3 = this.currentThisScopeFlags();
              return (t3 & Ne) > 0 && (t3 & Pe) === 0;
            }
            get inStaticBlock() {
              for (let t3 = this.scopeStack.length - 1; ; t3--) {
                let { flags: r } = this.scopeStack[t3];
                if (r & ft)
                  return true;
                if (r & (dt | Ne))
                  return false;
              }
            }
            get inNonArrowFunction() {
              return (this.currentThisScopeFlags() & Pe) > 0;
            }
            get treatFunctionsAsVar() {
              return this.treatFunctionsAsVarInScope(this.currentScope());
            }
            createScope(t3) {
              return new us(t3);
            }
            enter(t3) {
              this.scopeStack.push(this.createScope(t3));
            }
            exit() {
              return this.scopeStack.pop().flags;
            }
            treatFunctionsAsVarInScope(t3) {
              return !!(t3.flags & (Pe | ft) || !this.parser.inModule && t3.flags & qe);
            }
            declareName(t3, r, e) {
              let s = this.currentScope();
              if (r & Ce || r & mt)
                this.checkRedeclarationInScope(s, t3, r, e), r & mt ? s.functions.add(t3) : s.lexical.add(t3), r & Ce && this.maybeExportDefined(s, t3);
              else if (r & Ir)
                for (let i = this.scopeStack.length - 1; i >= 0 && (s = this.scopeStack[i], this.checkRedeclarationInScope(s, t3, r, e), s.var.add(t3), this.maybeExportDefined(s, t3), !(s.flags & dt)); --i)
                  ;
              this.parser.inModule && s.flags & qe && this.undefinedExports.delete(t3);
            }
            maybeExportDefined(t3, r) {
              this.parser.inModule && t3.flags & qe && this.undefinedExports.delete(r);
            }
            checkRedeclarationInScope(t3, r, e, s) {
              this.isRedeclaredInScope(t3, r, e) && this.parser.raise(u.VarRedeclaration, { at: s, identifierName: r });
            }
            isRedeclaredInScope(t3, r, e) {
              return e & Ae ? e & Ce ? t3.lexical.has(r) || t3.functions.has(r) || t3.var.has(r) : e & mt ? t3.lexical.has(r) || !this.treatFunctionsAsVarInScope(t3) && t3.var.has(r) : t3.lexical.has(r) && !(t3.flags & Sr && t3.lexical.values().next().value === r) || !this.treatFunctionsAsVarInScope(t3) && t3.functions.has(r) : false;
            }
            checkLocalExport(t3) {
              let { name: r } = t3, e = this.scopeStack[0];
              !e.lexical.has(r) && !e.var.has(r) && !e.functions.has(r) && this.undefinedExports.set(r, t3.loc.start);
            }
            currentScope() {
              return this.scopeStack[this.scopeStack.length - 1];
            }
            currentVarScopeFlags() {
              for (let t3 = this.scopeStack.length - 1; ; t3--) {
                let { flags: r } = this.scopeStack[t3];
                if (r & dt)
                  return r;
              }
            }
            currentThisScopeFlags() {
              for (let t3 = this.scopeStack.length - 1; ; t3--) {
                let { flags: r } = this.scopeStack[t3];
                if (r & (dt | Ne) && !(r & ts))
                  return r;
              }
            }
          }, vl = class extends us {
            constructor() {
              super(...arguments), this.declareFunctions = /* @__PURE__ */ new Set();
            }
          }, El = class extends cs {
            createScope(t3) {
              return new vl(t3);
            }
            declareName(t3, r, e) {
              let s = this.currentScope();
              if (r & as) {
                this.checkRedeclarationInScope(s, t3, r, e), this.maybeExportDefined(s, t3), s.declareFunctions.add(t3);
                return;
              }
              super.declareName(t3, r, e);
            }
            isRedeclaredInScope(t3, r, e) {
              return super.isRedeclaredInScope(t3, r, e) ? true : e & as ? !t3.declareFunctions.has(r) && (t3.lexical.has(r) || t3.functions.has(r)) : false;
            }
            checkLocalExport(t3) {
              this.scopeStack[0].declareFunctions.has(t3.name) || super.checkLocalExport(t3);
            }
          }, Cl = class {
            constructor() {
              this.sawUnambiguousESM = false, this.ambiguousScriptDifferentAst = false;
            }
            hasPlugin(t3) {
              if (typeof t3 == "string")
                return this.plugins.has(t3);
              {
                let [r, e] = t3;
                if (!this.hasPlugin(r))
                  return false;
                let s = this.plugins.get(r);
                for (let i of Object.keys(e))
                  if ((s == null ? void 0 : s[i]) !== e[i])
                    return false;
                return true;
              }
            }
            getPluginOption(t3, r) {
              var e;
              return (e = this.plugins.get(t3)) == null ? void 0 : e[r];
            }
          };
          function Br(t3, r) {
            t3.trailingComments === void 0 ? t3.trailingComments = r : t3.trailingComments.unshift(...r);
          }
          function bl(t3, r) {
            t3.leadingComments === void 0 ? t3.leadingComments = r : t3.leadingComments.unshift(...r);
          }
          function Qe(t3, r) {
            t3.innerComments === void 0 ? t3.innerComments = r : t3.innerComments.unshift(...r);
          }
          function Ze(t3, r, e) {
            let s = null, i = r.length;
            for (; s === null && i > 0; )
              s = r[--i];
            s === null || s.start > e.start ? Qe(t3, e.comments) : Br(s, e.comments);
          }
          var Sl = class extends Cl {
            addComment(t3) {
              this.filename && (t3.loc.filename = this.filename), this.state.comments.push(t3);
            }
            processComment(t3) {
              let { commentStack: r } = this.state, e = r.length;
              if (e === 0)
                return;
              let s = e - 1, i = r[s];
              i.start === t3.end && (i.leadingNode = t3, s--);
              let { start: a } = t3;
              for (; s >= 0; s--) {
                let n = r[s], o = n.end;
                if (o > a)
                  n.containingNode = t3, this.finalizeComment(n), r.splice(s, 1);
                else {
                  o === a && (n.trailingNode = t3);
                  break;
                }
              }
            }
            finalizeComment(t3) {
              let { comments: r } = t3;
              if (t3.leadingNode !== null || t3.trailingNode !== null)
                t3.leadingNode !== null && Br(t3.leadingNode, r), t3.trailingNode !== null && bl(t3.trailingNode, r);
              else {
                let { containingNode: e, start: s } = t3;
                if (this.input.charCodeAt(s - 1) === 44)
                  switch (e.type) {
                    case "ObjectExpression":
                    case "ObjectPattern":
                    case "RecordExpression":
                      Ze(e, e.properties, t3);
                      break;
                    case "CallExpression":
                    case "OptionalCallExpression":
                      Ze(e, e.arguments, t3);
                      break;
                    case "FunctionDeclaration":
                    case "FunctionExpression":
                    case "ArrowFunctionExpression":
                    case "ObjectMethod":
                    case "ClassMethod":
                    case "ClassPrivateMethod":
                      Ze(e, e.params, t3);
                      break;
                    case "ArrayExpression":
                    case "ArrayPattern":
                    case "TupleExpression":
                      Ze(e, e.elements, t3);
                      break;
                    case "ExportNamedDeclaration":
                    case "ImportDeclaration":
                      Ze(e, e.specifiers, t3);
                      break;
                    default:
                      Qe(e, r);
                  }
                else
                  Qe(e, r);
              }
            }
            finalizeRemainingComments() {
              let { commentStack: t3 } = this.state;
              for (let r = t3.length - 1; r >= 0; r--)
                this.finalizeComment(t3[r]);
              this.state.commentStack = [];
            }
            resetPreviousNodeTrailingComments(t3) {
              let { commentStack: r } = this.state, { length: e } = r;
              if (e === 0)
                return;
              let s = r[e - 1];
              s.leadingNode === t3 && (s.leadingNode = null);
            }
            takeSurroundingComments(t3, r, e) {
              let { commentStack: s } = this.state, i = s.length;
              if (i === 0)
                return;
              let a = i - 1;
              for (; a >= 0; a--) {
                let n = s[a], o = n.end;
                if (n.start === e)
                  n.leadingNode = t3;
                else if (o === r)
                  n.trailingNode = t3;
                else if (o < r)
                  break;
              }
            }
          }, ps = /\r\n?|[\n\u2028\u2029]/, Pt = new RegExp(ps.source, "g");
          function et(t3) {
            switch (t3) {
              case 10:
              case 13:
              case 8232:
              case 8233:
                return true;
              default:
                return false;
            }
          }
          var fs2 = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, wl = /(?:[^\S\n\r\u2028\u2029]|\/\/.*|\/\*.*?\*\/)*/y, Mr = new RegExp("(?=(" + wl.source + "))\\1" + /(?=[\n\r\u2028\u2029]|\/\*(?!.*?\*\/)|$)/.source, "y");
          function Il(t3) {
            switch (t3) {
              case 9:
              case 11:
              case 12:
              case 32:
              case 160:
              case 5760:
              case 8192:
              case 8193:
              case 8194:
              case 8195:
              case 8196:
              case 8197:
              case 8198:
              case 8199:
              case 8200:
              case 8201:
              case 8202:
              case 8239:
              case 8287:
              case 12288:
              case 65279:
                return true;
              default:
                return false;
            }
          }
          var _r = class {
            constructor() {
              this.strict = void 0, this.curLine = void 0, this.lineStart = void 0, this.startLoc = void 0, this.endLoc = void 0, this.errors = [], this.potentialArrowAt = -1, this.noArrowAt = [], this.noArrowParamsConversionAt = [], this.maybeInArrowParameters = false, this.inType = false, this.noAnonFunctionType = false, this.hasFlowComment = false, this.isAmbientContext = false, this.inAbstractClass = false, this.inDisallowConditionalTypesContext = false, this.topicContext = { maxNumOfResolvableTopics: 0, maxTopicIndex: null }, this.soloAwait = false, this.inFSharpPipelineDirectBody = false, this.labels = [], this.comments = [], this.commentStack = [], this.pos = 0, this.type = 137, this.value = null, this.start = 0, this.end = 0, this.lastTokEndLoc = null, this.lastTokStartLoc = null, this.lastTokStart = 0, this.context = [$2.brace], this.canStartJSXElement = true, this.containsEsc = false, this.firstInvalidTemplateEscapePos = null, this.strictErrors = /* @__PURE__ */ new Map(), this.tokensLength = 0;
            }
            init(t3) {
              let { strictMode: r, sourceType: e, startLine: s, startColumn: i } = t3;
              this.strict = r === false ? false : r === true ? true : e === "module", this.curLine = s, this.lineStart = -i, this.startLoc = this.endLoc = new f(s, i, 0);
            }
            curPosition() {
              return new f(this.curLine, this.pos - this.lineStart, this.pos);
            }
            clone(t3) {
              let r = new _r(), e = Object.keys(this);
              for (let s = 0, i = e.length; s < i; s++) {
                let a = e[s], n = this[a];
                !t3 && Array.isArray(n) && (n = n.slice()), r[a] = n;
              }
              return r;
            }
          }, Nl = function(r) {
            return r >= 48 && r <= 57;
          }, Rr = { decBinOct: /* @__PURE__ */ new Set([46, 66, 69, 79, 95, 98, 101, 111]), hex: /* @__PURE__ */ new Set([46, 88, 95, 120]) }, At = { bin: (t3) => t3 === 48 || t3 === 49, oct: (t3) => t3 >= 48 && t3 <= 55, dec: (t3) => t3 >= 48 && t3 <= 57, hex: (t3) => t3 >= 48 && t3 <= 57 || t3 >= 65 && t3 <= 70 || t3 >= 97 && t3 <= 102 };
          function jr(t3, r, e, s, i, a) {
            let n = e, o = s, c = i, p = "", m = null, x = e, { length: A } = r;
            for (; ; ) {
              if (e >= A) {
                a.unterminated(n, o, c), p += r.slice(x, e);
                break;
              }
              let b = r.charCodeAt(e);
              if (kl(t3, b, r, e)) {
                p += r.slice(x, e);
                break;
              }
              if (b === 92) {
                p += r.slice(x, e);
                let O = Dl(r, e, s, i, t3 === "template", a);
                O.ch === null && !m ? m = { pos: e, lineStart: s, curLine: i } : p += O.ch, { pos: e, lineStart: s, curLine: i } = O, x = e;
              } else
                b === 8232 || b === 8233 ? (++e, ++i, s = e) : b === 10 || b === 13 ? t3 === "template" ? (p += r.slice(x, e) + `
`, ++e, b === 13 && r.charCodeAt(e) === 10 && ++e, ++i, x = s = e) : a.unterminated(n, o, c) : ++e;
            }
            return { pos: e, str: p, firstInvalidLoc: m, lineStart: s, curLine: i, containsInvalid: !!m };
          }
          function kl(t3, r, e, s) {
            return t3 === "template" ? r === 96 || r === 36 && e.charCodeAt(s + 1) === 123 : r === (t3 === "double" ? 34 : 39);
          }
          function Dl(t3, r, e, s, i, a) {
            let n = !i;
            r++;
            let o = (p) => ({ pos: r, ch: p, lineStart: e, curLine: s }), c = t3.charCodeAt(r++);
            switch (c) {
              case 110:
                return o(`
`);
              case 114:
                return o("\r");
              case 120: {
                let p;
                return { code: p, pos: r } = ds(t3, r, e, s, 2, false, n, a), o(p === null ? null : String.fromCharCode(p));
              }
              case 117: {
                let p;
                return { code: p, pos: r } = Ur(t3, r, e, s, n, a), o(p === null ? null : String.fromCodePoint(p));
              }
              case 116:
                return o("	");
              case 98:
                return o("\b");
              case 118:
                return o("\v");
              case 102:
                return o("\f");
              case 13:
                t3.charCodeAt(r) === 10 && ++r;
              case 10:
                e = r, ++s;
              case 8232:
              case 8233:
                return o("");
              case 56:
              case 57:
                if (i)
                  return o(null);
                a.strictNumericEscape(r - 1, e, s);
              default:
                if (c >= 48 && c <= 55) {
                  let p = r - 1, x = t3.slice(p, r + 2).match(/^[0-7]+/)[0], A = parseInt(x, 8);
                  A > 255 && (x = x.slice(0, -1), A = parseInt(x, 8)), r += x.length - 1;
                  let b = t3.charCodeAt(r);
                  if (x !== "0" || b === 56 || b === 57) {
                    if (i)
                      return o(null);
                    a.strictNumericEscape(p, e, s);
                  }
                  return o(String.fromCharCode(A));
                }
                return o(String.fromCharCode(c));
            }
          }
          function ds(t3, r, e, s, i, a, n, o) {
            let c = r, p;
            return { n: p, pos: r } = qr(t3, r, e, s, 16, i, a, false, o, !n), p === null && (n ? o.invalidEscapeSequence(c, e, s) : r = c - 1), { code: p, pos: r };
          }
          function qr(t3, r, e, s, i, a, n, o, c, p) {
            let m = r, x = i === 16 ? Rr.hex : Rr.decBinOct, A = i === 16 ? At.hex : i === 10 ? At.dec : i === 8 ? At.oct : At.bin, b = false, O = 0;
            for (let R = 0, Y = a == null ? 1 / 0 : a; R < Y; ++R) {
              let Q = t3.charCodeAt(r), J;
              if (Q === 95 && o !== "bail") {
                let se = t3.charCodeAt(r - 1), Ve = t3.charCodeAt(r + 1);
                if (o) {
                  if (Number.isNaN(Ve) || !A(Ve) || x.has(se) || x.has(Ve)) {
                    if (p)
                      return { n: null, pos: r };
                    c.unexpectedNumericSeparator(r, e, s);
                  }
                } else {
                  if (p)
                    return { n: null, pos: r };
                  c.numericSeparatorInEscapeSequence(r, e, s);
                }
                ++r;
                continue;
              }
              if (Q >= 97 ? J = Q - 97 + 10 : Q >= 65 ? J = Q - 65 + 10 : Nl(Q) ? J = Q - 48 : J = 1 / 0, J >= i) {
                if (J <= 9 && p)
                  return { n: null, pos: r };
                if (J <= 9 && c.invalidDigit(r, e, s, i))
                  J = 0;
                else if (n)
                  J = 0, b = true;
                else
                  break;
              }
              ++r, O = O * i + J;
            }
            return r === m || a != null && r - m !== a || b ? { n: null, pos: r } : { n: O, pos: r };
          }
          function Ur(t3, r, e, s, i, a) {
            let n = t3.charCodeAt(r), o;
            if (n === 123) {
              if (++r, { code: o, pos: r } = ds(t3, r, e, s, t3.indexOf("}", r) - r, true, i, a), ++r, o !== null && o > 1114111)
                if (i)
                  a.invalidCodePoint(r, e, s);
                else
                  return { code: null, pos: r };
            } else
              ({ code: o, pos: r } = ds(t3, r, e, s, 4, false, i, a));
            return { code: o, pos: r };
          }
          var Fl = ["at"], Ll = ["at"];
          function tt(t3, r, e) {
            return new f(e, t3 - r, t3);
          }
          var Ol = /* @__PURE__ */ new Set([103, 109, 115, 105, 121, 117, 100, 118]), Se = class {
            constructor(t3) {
              this.type = t3.type, this.value = t3.value, this.start = t3.start, this.end = t3.end, this.loc = new d(t3.startLoc, t3.endLoc);
            }
          }, Bl = class extends Sl {
            constructor(t3, r) {
              super(), this.isLookahead = void 0, this.tokens = [], this.errorHandlers_readInt = { invalidDigit: (e, s, i, a) => this.options.errorRecovery ? (this.raise(u.InvalidDigit, { at: tt(e, s, i), radix: a }), true) : false, numericSeparatorInEscapeSequence: this.errorBuilder(u.NumericSeparatorInEscapeSequence), unexpectedNumericSeparator: this.errorBuilder(u.UnexpectedNumericSeparator) }, this.errorHandlers_readCodePoint = Object.assign({}, this.errorHandlers_readInt, { invalidEscapeSequence: this.errorBuilder(u.InvalidEscapeSequence), invalidCodePoint: this.errorBuilder(u.InvalidCodePoint) }), this.errorHandlers_readStringContents_string = Object.assign({}, this.errorHandlers_readCodePoint, { strictNumericEscape: (e, s, i) => {
                this.recordStrictModeErrors(u.StrictNumericEscape, { at: tt(e, s, i) });
              }, unterminated: (e, s, i) => {
                throw this.raise(u.UnterminatedString, { at: tt(e - 1, s, i) });
              } }), this.errorHandlers_readStringContents_template = Object.assign({}, this.errorHandlers_readCodePoint, { strictNumericEscape: this.errorBuilder(u.StrictNumericEscape), unterminated: (e, s, i) => {
                throw this.raise(u.UnterminatedTemplate, { at: tt(e, s, i) });
              } }), this.state = new _r(), this.state.init(t3), this.input = r, this.length = r.length, this.isLookahead = false;
            }
            pushToken(t3) {
              this.tokens.length = this.state.tokensLength, this.tokens.push(t3), ++this.state.tokensLength;
            }
            next() {
              this.checkKeywordEscapes(), this.options.tokens && this.pushToken(new Se(this.state)), this.state.lastTokStart = this.state.start, this.state.lastTokEndLoc = this.state.endLoc, this.state.lastTokStartLoc = this.state.startLoc, this.nextToken();
            }
            eat(t3) {
              return this.match(t3) ? (this.next(), true) : false;
            }
            match(t3) {
              return this.state.type === t3;
            }
            createLookaheadState(t3) {
              return { pos: t3.pos, value: null, type: t3.type, start: t3.start, end: t3.end, context: [this.curContext()], inType: t3.inType, startLoc: t3.startLoc, lastTokEndLoc: t3.lastTokEndLoc, curLine: t3.curLine, lineStart: t3.lineStart, curPosition: t3.curPosition };
            }
            lookahead() {
              let t3 = this.state;
              this.state = this.createLookaheadState(t3), this.isLookahead = true, this.nextToken(), this.isLookahead = false;
              let r = this.state;
              return this.state = t3, r;
            }
            nextTokenStart() {
              return this.nextTokenStartSince(this.state.pos);
            }
            nextTokenStartSince(t3) {
              return fs2.lastIndex = t3, fs2.test(this.input) ? fs2.lastIndex : t3;
            }
            lookaheadCharCode() {
              return this.input.charCodeAt(this.nextTokenStart());
            }
            codePointAtPos(t3) {
              let r = this.input.charCodeAt(t3);
              if ((r & 64512) === 55296 && ++t3 < this.input.length) {
                let e = this.input.charCodeAt(t3);
                (e & 64512) === 56320 && (r = 65536 + ((r & 1023) << 10) + (e & 1023));
              }
              return r;
            }
            setStrict(t3) {
              this.state.strict = t3, t3 && (this.state.strictErrors.forEach((r) => {
                let [e, s] = r;
                return this.raise(e, { at: s });
              }), this.state.strictErrors.clear());
            }
            curContext() {
              return this.state.context[this.state.context.length - 1];
            }
            nextToken() {
              if (this.skipSpace(), this.state.start = this.state.pos, this.isLookahead || (this.state.startLoc = this.state.curPosition()), this.state.pos >= this.length) {
                this.finishToken(137);
                return;
              }
              this.getTokenFromCode(this.codePointAtPos(this.state.pos));
            }
            skipBlockComment(t3) {
              let r;
              this.isLookahead || (r = this.state.curPosition());
              let e = this.state.pos, s = this.input.indexOf(t3, e + 2);
              if (s === -1)
                throw this.raise(u.UnterminatedComment, { at: this.state.curPosition() });
              for (this.state.pos = s + t3.length, Pt.lastIndex = e + 2; Pt.test(this.input) && Pt.lastIndex <= s; )
                ++this.state.curLine, this.state.lineStart = Pt.lastIndex;
              if (this.isLookahead)
                return;
              let i = { type: "CommentBlock", value: this.input.slice(e + 2, s), start: e, end: s + t3.length, loc: new d(r, this.state.curPosition()) };
              return this.options.tokens && this.pushToken(i), i;
            }
            skipLineComment(t3) {
              let r = this.state.pos, e;
              this.isLookahead || (e = this.state.curPosition());
              let s = this.input.charCodeAt(this.state.pos += t3);
              if (this.state.pos < this.length)
                for (; !et(s) && ++this.state.pos < this.length; )
                  s = this.input.charCodeAt(this.state.pos);
              if (this.isLookahead)
                return;
              let i = this.state.pos, n = { type: "CommentLine", value: this.input.slice(r + t3, i), start: r, end: i, loc: new d(e, this.state.curPosition()) };
              return this.options.tokens && this.pushToken(n), n;
            }
            skipSpace() {
              let t3 = this.state.pos, r = [];
              e:
                for (; this.state.pos < this.length; ) {
                  let e = this.input.charCodeAt(this.state.pos);
                  switch (e) {
                    case 32:
                    case 160:
                    case 9:
                      ++this.state.pos;
                      break;
                    case 13:
                      this.input.charCodeAt(this.state.pos + 1) === 10 && ++this.state.pos;
                    case 10:
                    case 8232:
                    case 8233:
                      ++this.state.pos, ++this.state.curLine, this.state.lineStart = this.state.pos;
                      break;
                    case 47:
                      switch (this.input.charCodeAt(this.state.pos + 1)) {
                        case 42: {
                          let s = this.skipBlockComment("*/");
                          s !== void 0 && (this.addComment(s), this.options.attachComment && r.push(s));
                          break;
                        }
                        case 47: {
                          let s = this.skipLineComment(2);
                          s !== void 0 && (this.addComment(s), this.options.attachComment && r.push(s));
                          break;
                        }
                        default:
                          break e;
                      }
                      break;
                    default:
                      if (Il(e))
                        ++this.state.pos;
                      else if (e === 45 && !this.inModule) {
                        let s = this.state.pos;
                        if (this.input.charCodeAt(s + 1) === 45 && this.input.charCodeAt(s + 2) === 62 && (t3 === 0 || this.state.lineStart > t3)) {
                          let i = this.skipLineComment(3);
                          i !== void 0 && (this.addComment(i), this.options.attachComment && r.push(i));
                        } else
                          break e;
                      } else if (e === 60 && !this.inModule) {
                        let s = this.state.pos;
                        if (this.input.charCodeAt(s + 1) === 33 && this.input.charCodeAt(s + 2) === 45 && this.input.charCodeAt(s + 3) === 45) {
                          let i = this.skipLineComment(4);
                          i !== void 0 && (this.addComment(i), this.options.attachComment && r.push(i));
                        } else
                          break e;
                      } else
                        break e;
                  }
                }
              if (r.length > 0) {
                let e = this.state.pos, s = { start: t3, end: e, comments: r, leadingNode: null, trailingNode: null, containingNode: null };
                this.state.commentStack.push(s);
              }
            }
            finishToken(t3, r) {
              this.state.end = this.state.pos, this.state.endLoc = this.state.curPosition();
              let e = this.state.type;
              this.state.type = t3, this.state.value = r, this.isLookahead || this.updateContext(e);
            }
            replaceToken(t3) {
              this.state.type = t3, this.updateContext();
            }
            readToken_numberSign() {
              if (this.state.pos === 0 && this.readToken_interpreter())
                return;
              let t3 = this.state.pos + 1, r = this.codePointAtPos(t3);
              if (r >= 48 && r <= 57)
                throw this.raise(u.UnexpectedDigitAfterHash, { at: this.state.curPosition() });
              if (r === 123 || r === 91 && this.hasPlugin("recordAndTuple")) {
                if (this.expectPlugin("recordAndTuple"), this.getPluginOption("recordAndTuple", "syntaxType") === "bar")
                  throw this.raise(r === 123 ? u.RecordExpressionHashIncorrectStartSyntaxType : u.TupleExpressionHashIncorrectStartSyntaxType, { at: this.state.curPosition() });
                this.state.pos += 2, r === 123 ? this.finishToken(7) : this.finishToken(1);
              } else
                ge(r) ? (++this.state.pos, this.finishToken(136, this.readWord1(r))) : r === 92 ? (++this.state.pos, this.finishToken(136, this.readWord1())) : this.finishOp(27, 1);
            }
            readToken_dot() {
              let t3 = this.input.charCodeAt(this.state.pos + 1);
              if (t3 >= 48 && t3 <= 57) {
                this.readNumber(true);
                return;
              }
              t3 === 46 && this.input.charCodeAt(this.state.pos + 2) === 46 ? (this.state.pos += 3, this.finishToken(21)) : (++this.state.pos, this.finishToken(16));
            }
            readToken_slash() {
              this.input.charCodeAt(this.state.pos + 1) === 61 ? this.finishOp(31, 2) : this.finishOp(56, 1);
            }
            readToken_interpreter() {
              if (this.state.pos !== 0 || this.length < 2)
                return false;
              let t3 = this.input.charCodeAt(this.state.pos + 1);
              if (t3 !== 33)
                return false;
              let r = this.state.pos;
              for (this.state.pos += 1; !et(t3) && ++this.state.pos < this.length; )
                t3 = this.input.charCodeAt(this.state.pos);
              let e = this.input.slice(r + 2, this.state.pos);
              return this.finishToken(28, e), true;
            }
            readToken_mult_modulo(t3) {
              let r = t3 === 42 ? 55 : 54, e = 1, s = this.input.charCodeAt(this.state.pos + 1);
              t3 === 42 && s === 42 && (e++, s = this.input.charCodeAt(this.state.pos + 2), r = 57), s === 61 && !this.state.inType && (e++, r = t3 === 37 ? 33 : 30), this.finishOp(r, e);
            }
            readToken_pipe_amp(t3) {
              let r = this.input.charCodeAt(this.state.pos + 1);
              if (r === t3) {
                this.input.charCodeAt(this.state.pos + 2) === 61 ? this.finishOp(30, 3) : this.finishOp(t3 === 124 ? 41 : 42, 2);
                return;
              }
              if (t3 === 124) {
                if (r === 62) {
                  this.finishOp(39, 2);
                  return;
                }
                if (this.hasPlugin("recordAndTuple") && r === 125) {
                  if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar")
                    throw this.raise(u.RecordExpressionBarIncorrectEndSyntaxType, { at: this.state.curPosition() });
                  this.state.pos += 2, this.finishToken(9);
                  return;
                }
                if (this.hasPlugin("recordAndTuple") && r === 93) {
                  if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar")
                    throw this.raise(u.TupleExpressionBarIncorrectEndSyntaxType, { at: this.state.curPosition() });
                  this.state.pos += 2, this.finishToken(4);
                  return;
                }
              }
              if (r === 61) {
                this.finishOp(30, 2);
                return;
              }
              this.finishOp(t3 === 124 ? 43 : 45, 1);
            }
            readToken_caret() {
              let t3 = this.input.charCodeAt(this.state.pos + 1);
              if (t3 === 61 && !this.state.inType)
                this.finishOp(32, 2);
              else if (t3 === 94 && this.hasPlugin(["pipelineOperator", { proposal: "hack", topicToken: "^^" }])) {
                if (this.finishOp(37, 2), this.input.codePointAt(this.state.pos) === 94)
                  throw this.unexpected();
              } else
                this.finishOp(44, 1);
            }
            readToken_atSign() {
              this.input.charCodeAt(this.state.pos + 1) === 64 && this.hasPlugin(["pipelineOperator", { proposal: "hack", topicToken: "@@" }]) ? this.finishOp(38, 2) : this.finishOp(26, 1);
            }
            readToken_plus_min(t3) {
              let r = this.input.charCodeAt(this.state.pos + 1);
              if (r === t3) {
                this.finishOp(34, 2);
                return;
              }
              r === 61 ? this.finishOp(30, 2) : this.finishOp(53, 1);
            }
            readToken_lt() {
              let { pos: t3 } = this.state, r = this.input.charCodeAt(t3 + 1);
              if (r === 60) {
                if (this.input.charCodeAt(t3 + 2) === 61) {
                  this.finishOp(30, 3);
                  return;
                }
                this.finishOp(51, 2);
                return;
              }
              if (r === 61) {
                this.finishOp(49, 2);
                return;
              }
              this.finishOp(47, 1);
            }
            readToken_gt() {
              let { pos: t3 } = this.state, r = this.input.charCodeAt(t3 + 1);
              if (r === 62) {
                let e = this.input.charCodeAt(t3 + 2) === 62 ? 3 : 2;
                if (this.input.charCodeAt(t3 + e) === 61) {
                  this.finishOp(30, e + 1);
                  return;
                }
                this.finishOp(52, e);
                return;
              }
              if (r === 61) {
                this.finishOp(49, 2);
                return;
              }
              this.finishOp(48, 1);
            }
            readToken_eq_excl(t3) {
              let r = this.input.charCodeAt(this.state.pos + 1);
              if (r === 61) {
                this.finishOp(46, this.input.charCodeAt(this.state.pos + 2) === 61 ? 3 : 2);
                return;
              }
              if (t3 === 61 && r === 62) {
                this.state.pos += 2, this.finishToken(19);
                return;
              }
              this.finishOp(t3 === 61 ? 29 : 35, 1);
            }
            readToken_question() {
              let t3 = this.input.charCodeAt(this.state.pos + 1), r = this.input.charCodeAt(this.state.pos + 2);
              t3 === 63 ? r === 61 ? this.finishOp(30, 3) : this.finishOp(40, 2) : t3 === 46 && !(r >= 48 && r <= 57) ? (this.state.pos += 2, this.finishToken(18)) : (++this.state.pos, this.finishToken(17));
            }
            getTokenFromCode(t3) {
              switch (t3) {
                case 46:
                  this.readToken_dot();
                  return;
                case 40:
                  ++this.state.pos, this.finishToken(10);
                  return;
                case 41:
                  ++this.state.pos, this.finishToken(11);
                  return;
                case 59:
                  ++this.state.pos, this.finishToken(13);
                  return;
                case 44:
                  ++this.state.pos, this.finishToken(12);
                  return;
                case 91:
                  if (this.hasPlugin("recordAndTuple") && this.input.charCodeAt(this.state.pos + 1) === 124) {
                    if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar")
                      throw this.raise(u.TupleExpressionBarIncorrectStartSyntaxType, { at: this.state.curPosition() });
                    this.state.pos += 2, this.finishToken(2);
                  } else
                    ++this.state.pos, this.finishToken(0);
                  return;
                case 93:
                  ++this.state.pos, this.finishToken(3);
                  return;
                case 123:
                  if (this.hasPlugin("recordAndTuple") && this.input.charCodeAt(this.state.pos + 1) === 124) {
                    if (this.getPluginOption("recordAndTuple", "syntaxType") !== "bar")
                      throw this.raise(u.RecordExpressionBarIncorrectStartSyntaxType, { at: this.state.curPosition() });
                    this.state.pos += 2, this.finishToken(6);
                  } else
                    ++this.state.pos, this.finishToken(5);
                  return;
                case 125:
                  ++this.state.pos, this.finishToken(8);
                  return;
                case 58:
                  this.hasPlugin("functionBind") && this.input.charCodeAt(this.state.pos + 1) === 58 ? this.finishOp(15, 2) : (++this.state.pos, this.finishToken(14));
                  return;
                case 63:
                  this.readToken_question();
                  return;
                case 96:
                  this.readTemplateToken();
                  return;
                case 48: {
                  let r = this.input.charCodeAt(this.state.pos + 1);
                  if (r === 120 || r === 88) {
                    this.readRadixNumber(16);
                    return;
                  }
                  if (r === 111 || r === 79) {
                    this.readRadixNumber(8);
                    return;
                  }
                  if (r === 98 || r === 66) {
                    this.readRadixNumber(2);
                    return;
                  }
                }
                case 49:
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 55:
                case 56:
                case 57:
                  this.readNumber(false);
                  return;
                case 34:
                case 39:
                  this.readString(t3);
                  return;
                case 47:
                  this.readToken_slash();
                  return;
                case 37:
                case 42:
                  this.readToken_mult_modulo(t3);
                  return;
                case 124:
                case 38:
                  this.readToken_pipe_amp(t3);
                  return;
                case 94:
                  this.readToken_caret();
                  return;
                case 43:
                case 45:
                  this.readToken_plus_min(t3);
                  return;
                case 60:
                  this.readToken_lt();
                  return;
                case 62:
                  this.readToken_gt();
                  return;
                case 61:
                case 33:
                  this.readToken_eq_excl(t3);
                  return;
                case 126:
                  this.finishOp(36, 1);
                  return;
                case 64:
                  this.readToken_atSign();
                  return;
                case 35:
                  this.readToken_numberSign();
                  return;
                case 92:
                  this.readWord();
                  return;
                default:
                  if (ge(t3)) {
                    this.readWord(t3);
                    return;
                  }
              }
              throw this.raise(u.InvalidOrUnexpectedToken, { at: this.state.curPosition(), unexpected: String.fromCodePoint(t3) });
            }
            finishOp(t3, r) {
              let e = this.input.slice(this.state.pos, this.state.pos + r);
              this.state.pos += r, this.finishToken(t3, e);
            }
            readRegexp() {
              let t3 = this.state.startLoc, r = this.state.start + 1, e, s, { pos: i } = this.state;
              for (; ; ++i) {
                if (i >= this.length)
                  throw this.raise(u.UnterminatedRegExp, { at: y(t3, 1) });
                let c = this.input.charCodeAt(i);
                if (et(c))
                  throw this.raise(u.UnterminatedRegExp, { at: y(t3, 1) });
                if (e)
                  e = false;
                else {
                  if (c === 91)
                    s = true;
                  else if (c === 93 && s)
                    s = false;
                  else if (c === 47 && !s)
                    break;
                  e = c === 92;
                }
              }
              let a = this.input.slice(r, i);
              ++i;
              let n = "", o = () => y(t3, i + 2 - r);
              for (; i < this.length; ) {
                let c = this.codePointAtPos(i), p = String.fromCharCode(c);
                if (Ol.has(c))
                  c === 118 ? (this.expectPlugin("regexpUnicodeSets", o()), n.includes("u") && this.raise(u.IncompatibleRegExpUVFlags, { at: o() })) : c === 117 && n.includes("v") && this.raise(u.IncompatibleRegExpUVFlags, { at: o() }), n.includes(p) && this.raise(u.DuplicateRegExpFlags, { at: o() });
                else if (Re(c) || c === 92)
                  this.raise(u.MalformedRegExpFlags, { at: o() });
                else
                  break;
                ++i, n += p;
              }
              this.state.pos = i, this.finishToken(135, { pattern: a, flags: n });
            }
            readInt(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true, { n: i, pos: a } = qr(this.input, this.state.pos, this.state.lineStart, this.state.curLine, t3, r, e, s, this.errorHandlers_readInt, false);
              return this.state.pos = a, i;
            }
            readRadixNumber(t3) {
              let r = this.state.curPosition(), e = false;
              this.state.pos += 2;
              let s = this.readInt(t3);
              s == null && this.raise(u.InvalidDigit, { at: y(r, 2), radix: t3 });
              let i = this.input.charCodeAt(this.state.pos);
              if (i === 110)
                ++this.state.pos, e = true;
              else if (i === 109)
                throw this.raise(u.InvalidDecimal, { at: r });
              if (ge(this.codePointAtPos(this.state.pos)))
                throw this.raise(u.NumberIdentifier, { at: this.state.curPosition() });
              if (e) {
                let a = this.input.slice(r.index, this.state.pos).replace(/[_n]/g, "");
                this.finishToken(133, a);
                return;
              }
              this.finishToken(132, s);
            }
            readNumber(t3) {
              let r = this.state.pos, e = this.state.curPosition(), s = false, i = false, a = false, n = false, o = false;
              !t3 && this.readInt(10) === null && this.raise(u.InvalidNumber, { at: this.state.curPosition() });
              let c = this.state.pos - r >= 2 && this.input.charCodeAt(r) === 48;
              if (c) {
                let A = this.input.slice(r, this.state.pos);
                if (this.recordStrictModeErrors(u.StrictOctalLiteral, { at: e }), !this.state.strict) {
                  let b = A.indexOf("_");
                  b > 0 && this.raise(u.ZeroDigitNumericSeparator, { at: y(e, b) });
                }
                o = c && !/[89]/.test(A);
              }
              let p = this.input.charCodeAt(this.state.pos);
              if (p === 46 && !o && (++this.state.pos, this.readInt(10), s = true, p = this.input.charCodeAt(this.state.pos)), (p === 69 || p === 101) && !o && (p = this.input.charCodeAt(++this.state.pos), (p === 43 || p === 45) && ++this.state.pos, this.readInt(10) === null && this.raise(u.InvalidOrMissingExponent, { at: e }), s = true, n = true, p = this.input.charCodeAt(this.state.pos)), p === 110 && ((s || c) && this.raise(u.InvalidBigIntLiteral, { at: e }), ++this.state.pos, i = true), p === 109 && (this.expectPlugin("decimal", this.state.curPosition()), (n || c) && this.raise(u.InvalidDecimal, { at: e }), ++this.state.pos, a = true), ge(this.codePointAtPos(this.state.pos)))
                throw this.raise(u.NumberIdentifier, { at: this.state.curPosition() });
              let m = this.input.slice(r, this.state.pos).replace(/[_mn]/g, "");
              if (i) {
                this.finishToken(133, m);
                return;
              }
              if (a) {
                this.finishToken(134, m);
                return;
              }
              let x = o ? parseInt(m, 8) : parseFloat(m);
              this.finishToken(132, x);
            }
            readCodePoint(t3) {
              let { code: r, pos: e } = Ur(this.input, this.state.pos, this.state.lineStart, this.state.curLine, t3, this.errorHandlers_readCodePoint);
              return this.state.pos = e, r;
            }
            readString(t3) {
              let { str: r, pos: e, curLine: s, lineStart: i } = jr(t3 === 34 ? "double" : "single", this.input, this.state.pos + 1, this.state.lineStart, this.state.curLine, this.errorHandlers_readStringContents_string);
              this.state.pos = e + 1, this.state.lineStart = i, this.state.curLine = s, this.finishToken(131, r);
            }
            readTemplateContinuation() {
              this.match(8) || this.unexpected(null, 8), this.state.pos--, this.readTemplateToken();
            }
            readTemplateToken() {
              let t3 = this.input[this.state.pos], { str: r, firstInvalidLoc: e, pos: s, curLine: i, lineStart: a } = jr("template", this.input, this.state.pos + 1, this.state.lineStart, this.state.curLine, this.errorHandlers_readStringContents_template);
              this.state.pos = s + 1, this.state.lineStart = a, this.state.curLine = i, e && (this.state.firstInvalidTemplateEscapePos = new f(e.curLine, e.pos - e.lineStart, e.pos)), this.input.codePointAt(s) === 96 ? this.finishToken(24, e ? null : t3 + r + "`") : (this.state.pos++, this.finishToken(25, e ? null : t3 + r + "${"));
            }
            recordStrictModeErrors(t3, r) {
              let { at: e } = r, s = e.index;
              this.state.strict && !this.state.strictErrors.has(s) ? this.raise(t3, { at: e }) : this.state.strictErrors.set(s, [t3, e]);
            }
            readWord1(t3) {
              this.state.containsEsc = false;
              let r = "", e = this.state.pos, s = this.state.pos;
              for (t3 !== void 0 && (this.state.pos += t3 <= 65535 ? 1 : 2); this.state.pos < this.length; ) {
                let i = this.codePointAtPos(this.state.pos);
                if (Re(i))
                  this.state.pos += i <= 65535 ? 1 : 2;
                else if (i === 92) {
                  this.state.containsEsc = true, r += this.input.slice(s, this.state.pos);
                  let a = this.state.curPosition(), n = this.state.pos === e ? ge : Re;
                  if (this.input.charCodeAt(++this.state.pos) !== 117) {
                    this.raise(u.MissingUnicodeEscape, { at: this.state.curPosition() }), s = this.state.pos - 1;
                    continue;
                  }
                  ++this.state.pos;
                  let o = this.readCodePoint(true);
                  o !== null && (n(o) || this.raise(u.EscapedCharNotAnIdentifier, { at: a }), r += String.fromCodePoint(o)), s = this.state.pos;
                } else
                  break;
              }
              return r + this.input.slice(s, this.state.pos);
            }
            readWord(t3) {
              let r = this.readWord1(t3), e = zt.get(r);
              e !== void 0 ? this.finishToken(e, Ee(e)) : this.finishToken(130, r);
            }
            checkKeywordEscapes() {
              let { type: t3 } = this.state;
              Yt(t3) && this.state.containsEsc && this.raise(u.InvalidEscapedReservedWord, { at: this.state.startLoc, reservedWord: Ee(t3) });
            }
            raise(t3, r) {
              let { at: e } = r, s = h(r, Fl), i = e instanceof f ? e : e.loc.start, a = t3({ loc: i, details: s });
              if (!this.options.errorRecovery)
                throw a;
              return this.isLookahead || this.state.errors.push(a), a;
            }
            raiseOverwrite(t3, r) {
              let { at: e } = r, s = h(r, Ll), i = e instanceof f ? e : e.loc.start, a = i.index, n = this.state.errors;
              for (let o = n.length - 1; o >= 0; o--) {
                let c = n[o];
                if (c.loc.index === a)
                  return n[o] = t3({ loc: i, details: s });
                if (c.loc.index < a)
                  break;
              }
              return this.raise(t3, r);
            }
            updateContext(t3) {
            }
            unexpected(t3, r) {
              throw this.raise(u.UnexpectedToken, { expected: r ? Ee(r) : null, at: t3 != null ? t3 : this.state.startLoc });
            }
            expectPlugin(t3, r) {
              if (this.hasPlugin(t3))
                return true;
              throw this.raise(u.MissingPlugin, { at: r != null ? r : this.state.startLoc, missingPlugin: [t3] });
            }
            expectOnePlugin(t3) {
              if (!t3.some((r) => this.hasPlugin(r)))
                throw this.raise(u.MissingOneOfPlugins, { at: this.state.startLoc, missingPlugin: t3 });
            }
            errorBuilder(t3) {
              return (r, e, s) => {
                this.raise(t3, { at: tt(r, e, s) });
              };
            }
          }, Ml = class {
            constructor() {
              this.privateNames = /* @__PURE__ */ new Set(), this.loneAccessors = /* @__PURE__ */ new Map(), this.undefinedPrivateNames = /* @__PURE__ */ new Map();
            }
          }, _l = class {
            constructor(t3) {
              this.parser = void 0, this.stack = [], this.undefinedPrivateNames = /* @__PURE__ */ new Map(), this.parser = t3;
            }
            current() {
              return this.stack[this.stack.length - 1];
            }
            enter() {
              this.stack.push(new Ml());
            }
            exit() {
              let t3 = this.stack.pop(), r = this.current();
              for (let [e, s] of Array.from(t3.undefinedPrivateNames))
                r ? r.undefinedPrivateNames.has(e) || r.undefinedPrivateNames.set(e, s) : this.parser.raise(u.InvalidPrivateFieldResolution, { at: s, identifierName: e });
            }
            declarePrivateName(t3, r, e) {
              let { privateNames: s, loneAccessors: i, undefinedPrivateNames: a } = this.current(), n = s.has(t3);
              if (r & ls) {
                let o = n && i.get(t3);
                if (o) {
                  let c = o & gt, p = r & gt, m = o & ls, x = r & ls;
                  n = m === x || c !== p, n || i.delete(t3);
                } else
                  n || i.set(t3, r);
              }
              n && this.parser.raise(u.PrivateNameRedeclaration, { at: e, identifierName: t3 }), s.add(t3), a.delete(t3);
            }
            usePrivateName(t3, r) {
              let e;
              for (e of this.stack)
                if (e.privateNames.has(t3))
                  return;
              e ? e.undefinedPrivateNames.set(t3, r) : this.parser.raise(u.InvalidPrivateFieldResolution, { at: r, identifierName: t3 });
            }
          }, Rl = 0, $r = 1, ms = 2, Hr = 3, Tt = class {
            constructor() {
              let t3 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : Rl;
              this.type = void 0, this.type = t3;
            }
            canBeArrowParameterDeclaration() {
              return this.type === ms || this.type === $r;
            }
            isCertainlyParameterDeclaration() {
              return this.type === Hr;
            }
          }, zr = class extends Tt {
            constructor(t3) {
              super(t3), this.declarationErrors = /* @__PURE__ */ new Map();
            }
            recordDeclarationError(t3, r) {
              let { at: e } = r, s = e.index;
              this.declarationErrors.set(s, [t3, e]);
            }
            clearDeclarationError(t3) {
              this.declarationErrors.delete(t3);
            }
            iterateErrors(t3) {
              this.declarationErrors.forEach(t3);
            }
          }, jl = class {
            constructor(t3) {
              this.parser = void 0, this.stack = [new Tt()], this.parser = t3;
            }
            enter(t3) {
              this.stack.push(t3);
            }
            exit() {
              this.stack.pop();
            }
            recordParameterInitializerError(t3, r) {
              let { at: e } = r, s = { at: e.loc.start }, { stack: i } = this, a = i.length - 1, n = i[a];
              for (; !n.isCertainlyParameterDeclaration(); ) {
                if (n.canBeArrowParameterDeclaration())
                  n.recordDeclarationError(t3, s);
                else
                  return;
                n = i[--a];
              }
              this.parser.raise(t3, s);
            }
            recordArrowParameterBindingError(t3, r) {
              let { at: e } = r, { stack: s } = this, i = s[s.length - 1], a = { at: e.loc.start };
              if (i.isCertainlyParameterDeclaration())
                this.parser.raise(t3, a);
              else if (i.canBeArrowParameterDeclaration())
                i.recordDeclarationError(t3, a);
              else
                return;
            }
            recordAsyncArrowParametersError(t3) {
              let { at: r } = t3, { stack: e } = this, s = e.length - 1, i = e[s];
              for (; i.canBeArrowParameterDeclaration(); )
                i.type === ms && i.recordDeclarationError(u.AwaitBindingIdentifier, { at: r }), i = e[--s];
            }
            validateAsPattern() {
              let { stack: t3 } = this, r = t3[t3.length - 1];
              r.canBeArrowParameterDeclaration() && r.iterateErrors((e) => {
                let [s, i] = e;
                this.parser.raise(s, { at: i });
                let a = t3.length - 2, n = t3[a];
                for (; n.canBeArrowParameterDeclaration(); )
                  n.clearDeclarationError(i.index), n = t3[--a];
              });
            }
          };
          function ql() {
            return new Tt(Hr);
          }
          function Ul() {
            return new zr($r);
          }
          function $l() {
            return new zr(ms);
          }
          function Vr() {
            return new Tt();
          }
          var $e = 0, Kr = 1, vt = 2, Wr = 4, He = 8, Hl = class {
            constructor() {
              this.stacks = [];
            }
            enter(t3) {
              this.stacks.push(t3);
            }
            exit() {
              this.stacks.pop();
            }
            currentFlags() {
              return this.stacks[this.stacks.length - 1];
            }
            get hasAwait() {
              return (this.currentFlags() & vt) > 0;
            }
            get hasYield() {
              return (this.currentFlags() & Kr) > 0;
            }
            get hasReturn() {
              return (this.currentFlags() & Wr) > 0;
            }
            get hasIn() {
              return (this.currentFlags() & He) > 0;
            }
          };
          function Et(t3, r) {
            return (t3 ? vt : 0) | (r ? Kr : 0);
          }
          var zl = class extends Bl {
            addExtra(t3, r, e) {
              let s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true;
              if (!t3)
                return;
              let i = t3.extra = t3.extra || {};
              s ? i[r] = e : Object.defineProperty(i, r, { enumerable: s, value: e });
            }
            isContextual(t3) {
              return this.state.type === t3 && !this.state.containsEsc;
            }
            isUnparsedContextual(t3, r) {
              let e = t3 + r.length;
              if (this.input.slice(t3, e) === r) {
                let s = this.input.charCodeAt(e);
                return !(Re(s) || (s & 64512) === 55296);
              }
              return false;
            }
            isLookaheadContextual(t3) {
              let r = this.nextTokenStart();
              return this.isUnparsedContextual(r, t3);
            }
            eatContextual(t3) {
              return this.isContextual(t3) ? (this.next(), true) : false;
            }
            expectContextual(t3, r) {
              if (!this.eatContextual(t3))
                throw r != null ? this.raise(r, { at: this.state.startLoc }) : this.unexpected(null, t3);
            }
            canInsertSemicolon() {
              return this.match(137) || this.match(8) || this.hasPrecedingLineBreak();
            }
            hasPrecedingLineBreak() {
              return ps.test(this.input.slice(this.state.lastTokEndLoc.index, this.state.start));
            }
            hasFollowingLineBreak() {
              return Mr.lastIndex = this.state.end, Mr.test(this.input);
            }
            isLineTerminator() {
              return this.eat(13) || this.canInsertSemicolon();
            }
            semicolon() {
              ((arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : true) ? this.isLineTerminator() : this.eat(13)) || this.raise(u.MissingSemicolon, { at: this.state.lastTokEndLoc });
            }
            expect(t3, r) {
              this.eat(t3) || this.unexpected(r, t3);
            }
            tryParse(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this.state.clone(), e = { node: null };
              try {
                let s = t3(function() {
                  let i = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : null;
                  throw e.node = i, e;
                });
                if (this.state.errors.length > r.errors.length) {
                  let i = this.state;
                  return this.state = r, this.state.tokensLength = i.tokensLength, { node: s, error: i.errors[r.errors.length], thrown: false, aborted: false, failState: i };
                }
                return { node: s, error: null, thrown: false, aborted: false, failState: null };
              } catch (s) {
                let i = this.state;
                if (this.state = r, s instanceof SyntaxError)
                  return { node: null, error: s, thrown: true, aborted: false, failState: i };
                if (s === e)
                  return { node: e.node, error: null, thrown: false, aborted: true, failState: i };
                throw s;
              }
            }
            checkExpressionErrors(t3, r) {
              if (!t3)
                return false;
              let { shorthandAssignLoc: e, doubleProtoLoc: s, privateKeyLoc: i, optionalParametersLoc: a } = t3, n = !!e || !!s || !!a || !!i;
              if (!r)
                return n;
              e != null && this.raise(u.InvalidCoverInitializedName, { at: e }), s != null && this.raise(u.DuplicateProto, { at: s }), i != null && this.raise(u.UnexpectedPrivateField, { at: i }), a != null && this.unexpected(a);
            }
            isLiteralPropertyName() {
              return gr(this.state.type);
            }
            isPrivateName(t3) {
              return t3.type === "PrivateName";
            }
            getPrivateNameSV(t3) {
              return t3.id.name;
            }
            hasPropertyAsPrivateName(t3) {
              return (t3.type === "MemberExpression" || t3.type === "OptionalMemberExpression") && this.isPrivateName(t3.property);
            }
            isOptionalChain(t3) {
              return t3.type === "OptionalMemberExpression" || t3.type === "OptionalCallExpression";
            }
            isObjectProperty(t3) {
              return t3.type === "ObjectProperty";
            }
            isObjectMethod(t3) {
              return t3.type === "ObjectMethod";
            }
            initializeScopes() {
              let t3 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : this.options.sourceType === "module", r = this.state.labels;
              this.state.labels = [];
              let e = this.exportedIdentifiers;
              this.exportedIdentifiers = /* @__PURE__ */ new Set();
              let s = this.inModule;
              this.inModule = t3;
              let i = this.scope, a = this.getScopeHandler();
              this.scope = new a(this, t3);
              let n = this.prodParam;
              this.prodParam = new Hl();
              let o = this.classScope;
              this.classScope = new _l(this);
              let c = this.expressionScope;
              return this.expressionScope = new jl(this), () => {
                this.state.labels = r, this.exportedIdentifiers = e, this.inModule = s, this.scope = i, this.prodParam = n, this.classScope = o, this.expressionScope = c;
              };
            }
            enterInitialScopes() {
              let t3 = $e;
              this.inModule && (t3 |= vt), this.scope.enter(qe), this.prodParam.enter(t3);
            }
            checkDestructuringPrivate(t3) {
              let { privateKeyLoc: r } = t3;
              r !== null && this.expectPlugin("destructuringPrivate", r);
            }
          }, Ct = class {
            constructor() {
              this.shorthandAssignLoc = null, this.doubleProtoLoc = null, this.privateKeyLoc = null, this.optionalParametersLoc = null;
            }
          }, bt = class {
            constructor(t3, r, e) {
              this.type = "", this.start = r, this.end = 0, this.loc = new d(e), t3 != null && t3.options.ranges && (this.range = [r, 0]), t3 != null && t3.filename && (this.loc.filename = t3.filename);
            }
          }, ys = bt.prototype;
          ys.__clone = function() {
            let t3 = new bt(void 0, this.start, this.loc.start), r = Object.keys(this);
            for (let e = 0, s = r.length; e < s; e++) {
              let i = r[e];
              i !== "leadingComments" && i !== "trailingComments" && i !== "innerComments" && (t3[i] = this[i]);
            }
            return t3;
          };
          function Vl(t3) {
            return Te(t3);
          }
          function Te(t3) {
            let { type: r, start: e, end: s, loc: i, range: a, extra: n, name: o } = t3, c = Object.create(ys);
            return c.type = r, c.start = e, c.end = s, c.loc = i, c.range = a, c.extra = n, c.name = o, r === "Placeholder" && (c.expectedNode = t3.expectedNode), c;
          }
          function Kl(t3) {
            let { type: r, start: e, end: s, loc: i, range: a, extra: n } = t3;
            if (r === "Placeholder")
              return Vl(t3);
            let o = Object.create(ys);
            return o.type = r, o.start = e, o.end = s, o.loc = i, o.range = a, t3.raw !== void 0 ? o.raw = t3.raw : o.extra = n, o.value = t3.value, o;
          }
          var Wl = class extends zl {
            startNode() {
              return new bt(this, this.state.start, this.state.startLoc);
            }
            startNodeAt(t3) {
              return new bt(this, t3.index, t3);
            }
            startNodeAtNode(t3) {
              return this.startNodeAt(t3.loc.start);
            }
            finishNode(t3, r) {
              return this.finishNodeAt(t3, r, this.state.lastTokEndLoc);
            }
            finishNodeAt(t3, r, e) {
              return t3.type = r, t3.end = e.index, t3.loc.end = e, this.options.ranges && (t3.range[1] = e.index), this.options.attachComment && this.processComment(t3), t3;
            }
            resetStartLocation(t3, r) {
              t3.start = r.index, t3.loc.start = r, this.options.ranges && (t3.range[0] = r.index);
            }
            resetEndLocation(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this.state.lastTokEndLoc;
              t3.end = r.index, t3.loc.end = r, this.options.ranges && (t3.range[1] = r.index);
            }
            resetStartLocationFromNode(t3, r) {
              this.resetStartLocation(t3, r.loc.start);
            }
          }, Gl = /* @__PURE__ */ new Set(["_", "any", "bool", "boolean", "empty", "extends", "false", "interface", "mixed", "null", "number", "static", "string", "true", "typeof", "void"]), D = _`flow`({ AmbiguousConditionalArrow: "Ambiguous expression: wrap the arrow functions in parentheses to disambiguate.", AmbiguousDeclareModuleKind: "Found both `declare module.exports` and `declare export` in the same module. Modules can only have 1 since they are either an ES module or they are a CommonJS module.", AssignReservedType: (t3) => {
            let { reservedType: r } = t3;
            return `Cannot overwrite reserved type ${r}.`;
          }, DeclareClassElement: "The `declare` modifier can only appear on class fields.", DeclareClassFieldInitializer: "Initializers are not allowed in fields with the `declare` modifier.", DuplicateDeclareModuleExports: "Duplicate `declare module.exports` statement.", EnumBooleanMemberNotInitialized: (t3) => {
            let { memberName: r, enumName: e } = t3;
            return `Boolean enum members need to be initialized. Use either \`${r} = true,\` or \`${r} = false,\` in enum \`${e}\`.`;
          }, EnumDuplicateMemberName: (t3) => {
            let { memberName: r, enumName: e } = t3;
            return `Enum member names need to be unique, but the name \`${r}\` has already been used before in enum \`${e}\`.`;
          }, EnumInconsistentMemberValues: (t3) => {
            let { enumName: r } = t3;
            return `Enum \`${r}\` has inconsistent member initializers. Either use no initializers, or consistently use literals (either booleans, numbers, or strings) for all member initializers.`;
          }, EnumInvalidExplicitType: (t3) => {
            let { invalidEnumType: r, enumName: e } = t3;
            return `Enum type \`${r}\` is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${e}\`.`;
          }, EnumInvalidExplicitTypeUnknownSupplied: (t3) => {
            let { enumName: r } = t3;
            return `Supplied enum type is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${r}\`.`;
          }, EnumInvalidMemberInitializerPrimaryType: (t3) => {
            let { enumName: r, memberName: e, explicitType: s } = t3;
            return `Enum \`${r}\` has type \`${s}\`, so the initializer of \`${e}\` needs to be a ${s} literal.`;
          }, EnumInvalidMemberInitializerSymbolType: (t3) => {
            let { enumName: r, memberName: e } = t3;
            return `Symbol enum members cannot be initialized. Use \`${e},\` in enum \`${r}\`.`;
          }, EnumInvalidMemberInitializerUnknownType: (t3) => {
            let { enumName: r, memberName: e } = t3;
            return `The enum member initializer for \`${e}\` needs to be a literal (either a boolean, number, or string) in enum \`${r}\`.`;
          }, EnumInvalidMemberName: (t3) => {
            let { enumName: r, memberName: e, suggestion: s } = t3;
            return `Enum member names cannot start with lowercase 'a' through 'z'. Instead of using \`${e}\`, consider using \`${s}\`, in enum \`${r}\`.`;
          }, EnumNumberMemberNotInitialized: (t3) => {
            let { enumName: r, memberName: e } = t3;
            return `Number enum members need to be initialized, e.g. \`${e} = 1\` in enum \`${r}\`.`;
          }, EnumStringMemberInconsistentlyInitailized: (t3) => {
            let { enumName: r } = t3;
            return `String enum members need to consistently either all use initializers, or use no initializers, in enum \`${r}\`.`;
          }, GetterMayNotHaveThisParam: "A getter cannot have a `this` parameter.", ImportReflectionHasImportType: "An `import module` declaration can not use `type` or `typeof` keyword.", ImportTypeShorthandOnlyInPureImport: "The `type` and `typeof` keywords on named imports can only be used on regular `import` statements. It cannot be used with `import type` or `import typeof` statements.", InexactInsideExact: "Explicit inexact syntax cannot appear inside an explicit exact object type.", InexactInsideNonObject: "Explicit inexact syntax cannot appear in class or interface definitions.", InexactVariance: "Explicit inexact syntax cannot have variance.", InvalidNonTypeImportInDeclareModule: "Imports within a `declare module` body must always be `import type` or `import typeof`.", MissingTypeParamDefault: "Type parameter declaration needs a default, since a preceding type parameter declaration has a default.", NestedDeclareModule: "`declare module` cannot be used inside another `declare module`.", NestedFlowComment: "Cannot have a flow comment inside another flow comment.", PatternIsOptional: Object.assign({ message: "A binding pattern parameter cannot be optional in an implementation signature." }, { reasonCode: "OptionalBindingPattern" }), SetterMayNotHaveThisParam: "A setter cannot have a `this` parameter.", SpreadVariance: "Spread properties cannot have variance.", ThisParamAnnotationRequired: "A type annotation is required for the `this` parameter.", ThisParamBannedInConstructor: "Constructors cannot have a `this` parameter; constructors don't bind `this` like other functions.", ThisParamMayNotBeOptional: "The `this` parameter cannot be optional.", ThisParamMustBeFirst: "The `this` parameter must be the first function parameter.", ThisParamNoDefault: "The `this` parameter may not have a default value.", TypeBeforeInitializer: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.", TypeCastInPattern: "The type cast expression is expected to be wrapped with parenthesis.", UnexpectedExplicitInexactInObject: "Explicit inexact syntax must appear at the end of an inexact object.", UnexpectedReservedType: (t3) => {
            let { reservedType: r } = t3;
            return `Unexpected reserved type ${r}.`;
          }, UnexpectedReservedUnderscore: "`_` is only allowed as a type argument to call or new.", UnexpectedSpaceBetweenModuloChecks: "Spaces between `%` and `checks` are not allowed here.", UnexpectedSpreadType: "Spread operator cannot appear in class or interface definitions.", UnexpectedSubtractionOperand: 'Unexpected token, expected "number" or "bigint".', UnexpectedTokenAfterTypeParameter: "Expected an arrow function after this type parameter declaration.", UnexpectedTypeParameterBeforeAsyncArrowFunction: "Type parameters must come after the async keyword, e.g. instead of `<T> async () => {}`, use `async <T>() => {}`.", UnsupportedDeclareExportKind: (t3) => {
            let { unsupportedExportKind: r, suggestion: e } = t3;
            return `\`declare export ${r}\` is not supported. Use \`${e}\` instead.`;
          }, UnsupportedStatementInDeclareModule: "Only declares and type imports are allowed inside declare module.", UnterminatedFlowComment: "Unterminated flow-comment." });
          function Jl(t3) {
            return t3.type === "DeclareExportAllDeclaration" || t3.type === "DeclareExportDeclaration" && (!t3.declaration || t3.declaration.type !== "TypeAlias" && t3.declaration.type !== "InterfaceDeclaration");
          }
          function xs(t3) {
            return t3.importKind === "type" || t3.importKind === "typeof";
          }
          function Gr(t3) {
            return ye(t3) && t3 !== 97;
          }
          var Xl = { const: "declare export var", let: "declare export var", type: "export type", interface: "export interface" };
          function Yl(t3, r) {
            let e = [], s = [];
            for (let i = 0; i < t3.length; i++)
              (r(t3[i], i, t3) ? e : s).push(t3[i]);
            return [e, s];
          }
          var Ql = /\*?\s*@((?:no)?flow)\b/, Zl = (t3) => class extends t3 {
            constructor() {
              super(...arguments), this.flowPragma = void 0;
            }
            getScopeHandler() {
              return El;
            }
            shouldParseTypes() {
              return this.getPluginOption("flow", "all") || this.flowPragma === "flow";
            }
            shouldParseEnums() {
              return !!this.getPluginOption("flow", "enums");
            }
            finishToken(e, s) {
              return e !== 131 && e !== 13 && e !== 28 && this.flowPragma === void 0 && (this.flowPragma = null), super.finishToken(e, s);
            }
            addComment(e) {
              if (this.flowPragma === void 0) {
                let s = Ql.exec(e.value);
                if (s)
                  if (s[1] === "flow")
                    this.flowPragma = "flow";
                  else if (s[1] === "noflow")
                    this.flowPragma = "noflow";
                  else
                    throw new Error("Unexpected flow pragma");
              }
              return super.addComment(e);
            }
            flowParseTypeInitialiser(e) {
              let s = this.state.inType;
              this.state.inType = true, this.expect(e || 14);
              let i = this.flowParseType();
              return this.state.inType = s, i;
            }
            flowParsePredicate() {
              let e = this.startNode(), s = this.state.startLoc;
              return this.next(), this.expectContextual(108), this.state.lastTokStart > s.index + 1 && this.raise(D.UnexpectedSpaceBetweenModuloChecks, { at: s }), this.eat(10) ? (e.value = super.parseExpression(), this.expect(11), this.finishNode(e, "DeclaredPredicate")) : this.finishNode(e, "InferredPredicate");
            }
            flowParseTypeAndPredicateInitialiser() {
              let e = this.state.inType;
              this.state.inType = true, this.expect(14);
              let s = null, i = null;
              return this.match(54) ? (this.state.inType = e, i = this.flowParsePredicate()) : (s = this.flowParseType(), this.state.inType = e, this.match(54) && (i = this.flowParsePredicate())), [s, i];
            }
            flowParseDeclareClass(e) {
              return this.next(), this.flowParseInterfaceish(e, true), this.finishNode(e, "DeclareClass");
            }
            flowParseDeclareFunction(e) {
              this.next();
              let s = e.id = this.parseIdentifier(), i = this.startNode(), a = this.startNode();
              this.match(47) ? i.typeParameters = this.flowParseTypeParameterDeclaration() : i.typeParameters = null, this.expect(10);
              let n = this.flowParseFunctionTypeParams();
              return i.params = n.params, i.rest = n.rest, i.this = n._this, this.expect(11), [i.returnType, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), a.typeAnnotation = this.finishNode(i, "FunctionTypeAnnotation"), s.typeAnnotation = this.finishNode(a, "TypeAnnotation"), this.resetEndLocation(s), this.semicolon(), this.scope.declareName(e.id.name, xl, e.id.loc.start), this.finishNode(e, "DeclareFunction");
            }
            flowParseDeclare(e, s) {
              if (this.match(80))
                return this.flowParseDeclareClass(e);
              if (this.match(68))
                return this.flowParseDeclareFunction(e);
              if (this.match(74))
                return this.flowParseDeclareVariable(e);
              if (this.eatContextual(125))
                return this.match(16) ? this.flowParseDeclareModuleExports(e) : (s && this.raise(D.NestedDeclareModule, { at: this.state.lastTokStartLoc }), this.flowParseDeclareModule(e));
              if (this.isContextual(128))
                return this.flowParseDeclareTypeAlias(e);
              if (this.isContextual(129))
                return this.flowParseDeclareOpaqueType(e);
              if (this.isContextual(127))
                return this.flowParseDeclareInterface(e);
              if (this.match(82))
                return this.flowParseDeclareExportDeclaration(e, s);
              throw this.unexpected();
            }
            flowParseDeclareVariable(e) {
              return this.next(), e.id = this.flowParseTypeAnnotatableIdentifier(true), this.scope.declareName(e.id.name, xt, e.id.loc.start), this.semicolon(), this.finishNode(e, "DeclareVariable");
            }
            flowParseDeclareModule(e) {
              this.scope.enter(je), this.match(131) ? e.id = super.parseExprAtom() : e.id = this.parseIdentifier();
              let s = e.body = this.startNode(), i = s.body = [];
              for (this.expect(5); !this.match(8); ) {
                let o = this.startNode();
                this.match(83) ? (this.next(), !this.isContextual(128) && !this.match(87) && this.raise(D.InvalidNonTypeImportInDeclareModule, { at: this.state.lastTokStartLoc }), super.parseImport(o)) : (this.expectContextual(123, D.UnsupportedStatementInDeclareModule), o = this.flowParseDeclare(o, true)), i.push(o);
              }
              this.scope.exit(), this.expect(8), this.finishNode(s, "BlockStatement");
              let a = null, n = false;
              return i.forEach((o) => {
                Jl(o) ? (a === "CommonJS" && this.raise(D.AmbiguousDeclareModuleKind, { at: o }), a = "ES") : o.type === "DeclareModuleExports" && (n && this.raise(D.DuplicateDeclareModuleExports, { at: o }), a === "ES" && this.raise(D.AmbiguousDeclareModuleKind, { at: o }), a = "CommonJS", n = true);
              }), e.kind = a || "CommonJS", this.finishNode(e, "DeclareModule");
            }
            flowParseDeclareExportDeclaration(e, s) {
              if (this.expect(82), this.eat(65))
                return this.match(68) || this.match(80) ? e.declaration = this.flowParseDeclare(this.startNode()) : (e.declaration = this.flowParseType(), this.semicolon()), e.default = true, this.finishNode(e, "DeclareExportDeclaration");
              if (this.match(75) || this.isLet() || (this.isContextual(128) || this.isContextual(127)) && !s) {
                let i = this.state.value;
                throw this.raise(D.UnsupportedDeclareExportKind, { at: this.state.startLoc, unsupportedExportKind: i, suggestion: Xl[i] });
              }
              if (this.match(74) || this.match(68) || this.match(80) || this.isContextual(129))
                return e.declaration = this.flowParseDeclare(this.startNode()), e.default = false, this.finishNode(e, "DeclareExportDeclaration");
              if (this.match(55) || this.match(5) || this.isContextual(127) || this.isContextual(128) || this.isContextual(129))
                return e = this.parseExport(e, null), e.type === "ExportNamedDeclaration" && (e.type = "ExportDeclaration", e.default = false, delete e.exportKind), e.type = "Declare" + e.type, e;
              throw this.unexpected();
            }
            flowParseDeclareModuleExports(e) {
              return this.next(), this.expectContextual(109), e.typeAnnotation = this.flowParseTypeAnnotation(), this.semicolon(), this.finishNode(e, "DeclareModuleExports");
            }
            flowParseDeclareTypeAlias(e) {
              this.next();
              let s = this.flowParseTypeAlias(e);
              return s.type = "DeclareTypeAlias", s;
            }
            flowParseDeclareOpaqueType(e) {
              this.next();
              let s = this.flowParseOpaqueType(e, true);
              return s.type = "DeclareOpaqueType", s;
            }
            flowParseDeclareInterface(e) {
              return this.next(), this.flowParseInterfaceish(e), this.finishNode(e, "DeclareInterface");
            }
            flowParseInterfaceish(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              if (e.id = this.flowParseRestrictedIdentifier(!s, true), this.scope.declareName(e.id.name, s ? Dr : De, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.extends = [], e.implements = [], e.mixins = [], this.eat(81))
                do
                  e.extends.push(this.flowParseInterfaceExtends());
                while (!s && this.eat(12));
              if (this.isContextual(115)) {
                this.next();
                do
                  e.mixins.push(this.flowParseInterfaceExtends());
                while (this.eat(12));
              }
              if (this.isContextual(111)) {
                this.next();
                do
                  e.implements.push(this.flowParseInterfaceExtends());
                while (this.eat(12));
              }
              e.body = this.flowParseObjectType({ allowStatic: s, allowExact: false, allowSpread: false, allowProto: s, allowInexact: false });
            }
            flowParseInterfaceExtends() {
              let e = this.startNode();
              return e.id = this.flowParseQualifiedTypeIdentifier(), this.match(47) ? e.typeParameters = this.flowParseTypeParameterInstantiation() : e.typeParameters = null, this.finishNode(e, "InterfaceExtends");
            }
            flowParseInterface(e) {
              return this.flowParseInterfaceish(e), this.finishNode(e, "InterfaceDeclaration");
            }
            checkNotUnderscore(e) {
              e === "_" && this.raise(D.UnexpectedReservedUnderscore, { at: this.state.startLoc });
            }
            checkReservedType(e, s, i) {
              Gl.has(e) && this.raise(i ? D.AssignReservedType : D.UnexpectedReservedType, { at: s, reservedType: e });
            }
            flowParseRestrictedIdentifier(e, s) {
              return this.checkReservedType(this.state.value, this.state.startLoc, s), this.parseIdentifier(e);
            }
            flowParseTypeAlias(e) {
              return e.id = this.flowParseRestrictedIdentifier(false, true), this.scope.declareName(e.id.name, De, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.right = this.flowParseTypeInitialiser(29), this.semicolon(), this.finishNode(e, "TypeAlias");
            }
            flowParseOpaqueType(e, s) {
              return this.expectContextual(128), e.id = this.flowParseRestrictedIdentifier(true, true), this.scope.declareName(e.id.name, De, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.supertype = null, this.match(14) && (e.supertype = this.flowParseTypeInitialiser(14)), e.impltype = null, s || (e.impltype = this.flowParseTypeInitialiser(29)), this.semicolon(), this.finishNode(e, "OpaqueType");
            }
            flowParseTypeParameter() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : false, s = this.state.startLoc, i = this.startNode(), a = this.flowParseVariance(), n = this.flowParseTypeAnnotatableIdentifier();
              return i.name = n.name, i.variance = a, i.bound = n.typeAnnotation, this.match(29) ? (this.eat(29), i.default = this.flowParseType()) : e && this.raise(D.MissingTypeParamDefault, { at: s }), this.finishNode(i, "TypeParameter");
            }
            flowParseTypeParameterDeclaration() {
              let e = this.state.inType, s = this.startNode();
              s.params = [], this.state.inType = true, this.match(47) || this.match(140) ? this.next() : this.unexpected();
              let i = false;
              do {
                let a = this.flowParseTypeParameter(i);
                s.params.push(a), a.default && (i = true), this.match(48) || this.expect(12);
              } while (!this.match(48));
              return this.expect(48), this.state.inType = e, this.finishNode(s, "TypeParameterDeclaration");
            }
            flowParseTypeParameterInstantiation() {
              let e = this.startNode(), s = this.state.inType;
              e.params = [], this.state.inType = true, this.expect(47);
              let i = this.state.noAnonFunctionType;
              for (this.state.noAnonFunctionType = false; !this.match(48); )
                e.params.push(this.flowParseType()), this.match(48) || this.expect(12);
              return this.state.noAnonFunctionType = i, this.expect(48), this.state.inType = s, this.finishNode(e, "TypeParameterInstantiation");
            }
            flowParseTypeParameterInstantiationCallOrNew() {
              let e = this.startNode(), s = this.state.inType;
              for (e.params = [], this.state.inType = true, this.expect(47); !this.match(48); )
                e.params.push(this.flowParseTypeOrImplicitInstantiation()), this.match(48) || this.expect(12);
              return this.expect(48), this.state.inType = s, this.finishNode(e, "TypeParameterInstantiation");
            }
            flowParseInterfaceType() {
              let e = this.startNode();
              if (this.expectContextual(127), e.extends = [], this.eat(81))
                do
                  e.extends.push(this.flowParseInterfaceExtends());
                while (this.eat(12));
              return e.body = this.flowParseObjectType({ allowStatic: false, allowExact: false, allowSpread: false, allowProto: false, allowInexact: false }), this.finishNode(e, "InterfaceTypeAnnotation");
            }
            flowParseObjectPropertyKey() {
              return this.match(132) || this.match(131) ? super.parseExprAtom() : this.parseIdentifier(true);
            }
            flowParseObjectTypeIndexer(e, s, i) {
              return e.static = s, this.lookahead().type === 14 ? (e.id = this.flowParseObjectPropertyKey(), e.key = this.flowParseTypeInitialiser()) : (e.id = null, e.key = this.flowParseType()), this.expect(3), e.value = this.flowParseTypeInitialiser(), e.variance = i, this.finishNode(e, "ObjectTypeIndexer");
            }
            flowParseObjectTypeInternalSlot(e, s) {
              return e.static = s, e.id = this.flowParseObjectPropertyKey(), this.expect(3), this.expect(3), this.match(47) || this.match(10) ? (e.method = true, e.optional = false, e.value = this.flowParseObjectTypeMethodish(this.startNodeAt(e.loc.start))) : (e.method = false, this.eat(17) && (e.optional = true), e.value = this.flowParseTypeInitialiser()), this.finishNode(e, "ObjectTypeInternalSlot");
            }
            flowParseObjectTypeMethodish(e) {
              for (e.params = [], e.rest = null, e.typeParameters = null, e.this = null, this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration()), this.expect(10), this.match(78) && (e.this = this.flowParseFunctionTypeParam(true), e.this.name = null, this.match(11) || this.expect(12)); !this.match(11) && !this.match(21); )
                e.params.push(this.flowParseFunctionTypeParam(false)), this.match(11) || this.expect(12);
              return this.eat(21) && (e.rest = this.flowParseFunctionTypeParam(false)), this.expect(11), e.returnType = this.flowParseTypeInitialiser(), this.finishNode(e, "FunctionTypeAnnotation");
            }
            flowParseObjectTypeCallProperty(e, s) {
              let i = this.startNode();
              return e.static = s, e.value = this.flowParseObjectTypeMethodish(i), this.finishNode(e, "ObjectTypeCallProperty");
            }
            flowParseObjectType(e) {
              let { allowStatic: s, allowExact: i, allowSpread: a, allowProto: n, allowInexact: o } = e, c = this.state.inType;
              this.state.inType = true;
              let p = this.startNode();
              p.callProperties = [], p.properties = [], p.indexers = [], p.internalSlots = [];
              let m, x, A = false;
              for (i && this.match(6) ? (this.expect(6), m = 9, x = true) : (this.expect(5), m = 8, x = false), p.exact = x; !this.match(m); ) {
                let O = false, R = null, Y = null, Q = this.startNode();
                if (n && this.isContextual(116)) {
                  let se = this.lookahead();
                  se.type !== 14 && se.type !== 17 && (this.next(), R = this.state.startLoc, s = false);
                }
                if (s && this.isContextual(104)) {
                  let se = this.lookahead();
                  se.type !== 14 && se.type !== 17 && (this.next(), O = true);
                }
                let J = this.flowParseVariance();
                if (this.eat(0))
                  R != null && this.unexpected(R), this.eat(0) ? (J && this.unexpected(J.loc.start), p.internalSlots.push(this.flowParseObjectTypeInternalSlot(Q, O))) : p.indexers.push(this.flowParseObjectTypeIndexer(Q, O, J));
                else if (this.match(10) || this.match(47))
                  R != null && this.unexpected(R), J && this.unexpected(J.loc.start), p.callProperties.push(this.flowParseObjectTypeCallProperty(Q, O));
                else {
                  let se = "init";
                  if (this.isContextual(98) || this.isContextual(103)) {
                    let Ih = this.lookahead();
                    gr(Ih.type) && (se = this.state.value, this.next());
                  }
                  let Ve = this.flowParseObjectTypeProperty(Q, O, R, J, se, a, o != null ? o : !x);
                  Ve === null ? (A = true, Y = this.state.lastTokStartLoc) : p.properties.push(Ve);
                }
                this.flowObjectTypeSemicolon(), Y && !this.match(8) && !this.match(9) && this.raise(D.UnexpectedExplicitInexactInObject, { at: Y });
              }
              this.expect(m), a && (p.inexact = A);
              let b = this.finishNode(p, "ObjectTypeAnnotation");
              return this.state.inType = c, b;
            }
            flowParseObjectTypeProperty(e, s, i, a, n, o, c) {
              if (this.eat(21))
                return this.match(12) || this.match(13) || this.match(8) || this.match(9) ? (o ? c || this.raise(D.InexactInsideExact, { at: this.state.lastTokStartLoc }) : this.raise(D.InexactInsideNonObject, { at: this.state.lastTokStartLoc }), a && this.raise(D.InexactVariance, { at: a }), null) : (o || this.raise(D.UnexpectedSpreadType, { at: this.state.lastTokStartLoc }), i != null && this.unexpected(i), a && this.raise(D.SpreadVariance, { at: a }), e.argument = this.flowParseType(), this.finishNode(e, "ObjectTypeSpreadProperty"));
              {
                e.key = this.flowParseObjectPropertyKey(), e.static = s, e.proto = i != null, e.kind = n;
                let p = false;
                return this.match(47) || this.match(10) ? (e.method = true, i != null && this.unexpected(i), a && this.unexpected(a.loc.start), e.value = this.flowParseObjectTypeMethodish(this.startNodeAt(e.loc.start)), (n === "get" || n === "set") && this.flowCheckGetterSetterParams(e), !o && e.key.name === "constructor" && e.value.this && this.raise(D.ThisParamBannedInConstructor, { at: e.value.this })) : (n !== "init" && this.unexpected(), e.method = false, this.eat(17) && (p = true), e.value = this.flowParseTypeInitialiser(), e.variance = a), e.optional = p, this.finishNode(e, "ObjectTypeProperty");
              }
            }
            flowCheckGetterSetterParams(e) {
              let s = e.kind === "get" ? 0 : 1, i = e.value.params.length + (e.value.rest ? 1 : 0);
              e.value.this && this.raise(e.kind === "get" ? D.GetterMayNotHaveThisParam : D.SetterMayNotHaveThisParam, { at: e.value.this }), i !== s && this.raise(e.kind === "get" ? u.BadGetterArity : u.BadSetterArity, { at: e }), e.kind === "set" && e.value.rest && this.raise(u.BadSetterRestParameter, { at: e });
            }
            flowObjectTypeSemicolon() {
              !this.eat(13) && !this.eat(12) && !this.match(8) && !this.match(9) && this.unexpected();
            }
            flowParseQualifiedTypeIdentifier(e, s) {
              var i;
              (i = e) != null || (e = this.state.startLoc);
              let a = s || this.flowParseRestrictedIdentifier(true);
              for (; this.eat(16); ) {
                let n = this.startNodeAt(e);
                n.qualification = a, n.id = this.flowParseRestrictedIdentifier(true), a = this.finishNode(n, "QualifiedTypeIdentifier");
              }
              return a;
            }
            flowParseGenericType(e, s) {
              let i = this.startNodeAt(e);
              return i.typeParameters = null, i.id = this.flowParseQualifiedTypeIdentifier(e, s), this.match(47) && (i.typeParameters = this.flowParseTypeParameterInstantiation()), this.finishNode(i, "GenericTypeAnnotation");
            }
            flowParseTypeofType() {
              let e = this.startNode();
              return this.expect(87), e.argument = this.flowParsePrimaryType(), this.finishNode(e, "TypeofTypeAnnotation");
            }
            flowParseTupleType() {
              let e = this.startNode();
              for (e.types = [], this.expect(0); this.state.pos < this.length && !this.match(3) && (e.types.push(this.flowParseType()), !this.match(3)); )
                this.expect(12);
              return this.expect(3), this.finishNode(e, "TupleTypeAnnotation");
            }
            flowParseFunctionTypeParam(e) {
              let s = null, i = false, a = null, n = this.startNode(), o = this.lookahead(), c = this.state.type === 78;
              return o.type === 14 || o.type === 17 ? (c && !e && this.raise(D.ThisParamMustBeFirst, { at: n }), s = this.parseIdentifier(c), this.eat(17) && (i = true, c && this.raise(D.ThisParamMayNotBeOptional, { at: n })), a = this.flowParseTypeInitialiser()) : a = this.flowParseType(), n.name = s, n.optional = i, n.typeAnnotation = a, this.finishNode(n, "FunctionTypeParam");
            }
            reinterpretTypeAsFunctionTypeParam(e) {
              let s = this.startNodeAt(e.loc.start);
              return s.name = null, s.optional = false, s.typeAnnotation = e, this.finishNode(s, "FunctionTypeParam");
            }
            flowParseFunctionTypeParams() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [], s = null, i = null;
              for (this.match(78) && (i = this.flowParseFunctionTypeParam(true), i.name = null, this.match(11) || this.expect(12)); !this.match(11) && !this.match(21); )
                e.push(this.flowParseFunctionTypeParam(false)), this.match(11) || this.expect(12);
              return this.eat(21) && (s = this.flowParseFunctionTypeParam(false)), { params: e, rest: s, _this: i };
            }
            flowIdentToTypeAnnotation(e, s, i) {
              switch (i.name) {
                case "any":
                  return this.finishNode(s, "AnyTypeAnnotation");
                case "bool":
                case "boolean":
                  return this.finishNode(s, "BooleanTypeAnnotation");
                case "mixed":
                  return this.finishNode(s, "MixedTypeAnnotation");
                case "empty":
                  return this.finishNode(s, "EmptyTypeAnnotation");
                case "number":
                  return this.finishNode(s, "NumberTypeAnnotation");
                case "string":
                  return this.finishNode(s, "StringTypeAnnotation");
                case "symbol":
                  return this.finishNode(s, "SymbolTypeAnnotation");
                default:
                  return this.checkNotUnderscore(i.name), this.flowParseGenericType(e, i);
              }
            }
            flowParsePrimaryType() {
              let e = this.state.startLoc, s = this.startNode(), i, a, n = false, o = this.state.noAnonFunctionType;
              switch (this.state.type) {
                case 5:
                  return this.flowParseObjectType({ allowStatic: false, allowExact: false, allowSpread: true, allowProto: false, allowInexact: true });
                case 6:
                  return this.flowParseObjectType({ allowStatic: false, allowExact: true, allowSpread: true, allowProto: false, allowInexact: false });
                case 0:
                  return this.state.noAnonFunctionType = false, a = this.flowParseTupleType(), this.state.noAnonFunctionType = o, a;
                case 47:
                  return s.typeParameters = this.flowParseTypeParameterDeclaration(), this.expect(10), i = this.flowParseFunctionTypeParams(), s.params = i.params, s.rest = i.rest, s.this = i._this, this.expect(11), this.expect(19), s.returnType = this.flowParseType(), this.finishNode(s, "FunctionTypeAnnotation");
                case 10:
                  if (this.next(), !this.match(11) && !this.match(21))
                    if (z(this.state.type) || this.match(78)) {
                      let c = this.lookahead().type;
                      n = c !== 17 && c !== 14;
                    } else
                      n = true;
                  if (n) {
                    if (this.state.noAnonFunctionType = false, a = this.flowParseType(), this.state.noAnonFunctionType = o, this.state.noAnonFunctionType || !(this.match(12) || this.match(11) && this.lookahead().type === 19))
                      return this.expect(11), a;
                    this.eat(12);
                  }
                  return a ? i = this.flowParseFunctionTypeParams([this.reinterpretTypeAsFunctionTypeParam(a)]) : i = this.flowParseFunctionTypeParams(), s.params = i.params, s.rest = i.rest, s.this = i._this, this.expect(11), this.expect(19), s.returnType = this.flowParseType(), s.typeParameters = null, this.finishNode(s, "FunctionTypeAnnotation");
                case 131:
                  return this.parseLiteral(this.state.value, "StringLiteralTypeAnnotation");
                case 85:
                case 86:
                  return s.value = this.match(85), this.next(), this.finishNode(s, "BooleanLiteralTypeAnnotation");
                case 53:
                  if (this.state.value === "-") {
                    if (this.next(), this.match(132))
                      return this.parseLiteralAtNode(-this.state.value, "NumberLiteralTypeAnnotation", s);
                    if (this.match(133))
                      return this.parseLiteralAtNode(-this.state.value, "BigIntLiteralTypeAnnotation", s);
                    throw this.raise(D.UnexpectedSubtractionOperand, { at: this.state.startLoc });
                  }
                  throw this.unexpected();
                case 132:
                  return this.parseLiteral(this.state.value, "NumberLiteralTypeAnnotation");
                case 133:
                  return this.parseLiteral(this.state.value, "BigIntLiteralTypeAnnotation");
                case 88:
                  return this.next(), this.finishNode(s, "VoidTypeAnnotation");
                case 84:
                  return this.next(), this.finishNode(s, "NullLiteralTypeAnnotation");
                case 78:
                  return this.next(), this.finishNode(s, "ThisTypeAnnotation");
                case 55:
                  return this.next(), this.finishNode(s, "ExistsTypeAnnotation");
                case 87:
                  return this.flowParseTypeofType();
                default:
                  if (Yt(this.state.type)) {
                    let c = Ee(this.state.type);
                    return this.next(), super.createIdentifier(s, c);
                  } else if (z(this.state.type))
                    return this.isContextual(127) ? this.flowParseInterfaceType() : this.flowIdentToTypeAnnotation(e, s, this.parseIdentifier());
              }
              throw this.unexpected();
            }
            flowParsePostfixType() {
              let e = this.state.startLoc, s = this.flowParsePrimaryType(), i = false;
              for (; (this.match(0) || this.match(18)) && !this.canInsertSemicolon(); ) {
                let a = this.startNodeAt(e), n = this.eat(18);
                i = i || n, this.expect(0), !n && this.match(3) ? (a.elementType = s, this.next(), s = this.finishNode(a, "ArrayTypeAnnotation")) : (a.objectType = s, a.indexType = this.flowParseType(), this.expect(3), i ? (a.optional = n, s = this.finishNode(a, "OptionalIndexedAccessType")) : s = this.finishNode(a, "IndexedAccessType"));
              }
              return s;
            }
            flowParsePrefixType() {
              let e = this.startNode();
              return this.eat(17) ? (e.typeAnnotation = this.flowParsePrefixType(), this.finishNode(e, "NullableTypeAnnotation")) : this.flowParsePostfixType();
            }
            flowParseAnonFunctionWithoutParens() {
              let e = this.flowParsePrefixType();
              if (!this.state.noAnonFunctionType && this.eat(19)) {
                let s = this.startNodeAt(e.loc.start);
                return s.params = [this.reinterpretTypeAsFunctionTypeParam(e)], s.rest = null, s.this = null, s.returnType = this.flowParseType(), s.typeParameters = null, this.finishNode(s, "FunctionTypeAnnotation");
              }
              return e;
            }
            flowParseIntersectionType() {
              let e = this.startNode();
              this.eat(45);
              let s = this.flowParseAnonFunctionWithoutParens();
              for (e.types = [s]; this.eat(45); )
                e.types.push(this.flowParseAnonFunctionWithoutParens());
              return e.types.length === 1 ? s : this.finishNode(e, "IntersectionTypeAnnotation");
            }
            flowParseUnionType() {
              let e = this.startNode();
              this.eat(43);
              let s = this.flowParseIntersectionType();
              for (e.types = [s]; this.eat(43); )
                e.types.push(this.flowParseIntersectionType());
              return e.types.length === 1 ? s : this.finishNode(e, "UnionTypeAnnotation");
            }
            flowParseType() {
              let e = this.state.inType;
              this.state.inType = true;
              let s = this.flowParseUnionType();
              return this.state.inType = e, s;
            }
            flowParseTypeOrImplicitInstantiation() {
              if (this.state.type === 130 && this.state.value === "_") {
                let e = this.state.startLoc, s = this.parseIdentifier();
                return this.flowParseGenericType(e, s);
              } else
                return this.flowParseType();
            }
            flowParseTypeAnnotation() {
              let e = this.startNode();
              return e.typeAnnotation = this.flowParseTypeInitialiser(), this.finishNode(e, "TypeAnnotation");
            }
            flowParseTypeAnnotatableIdentifier(e) {
              let s = e ? this.parseIdentifier() : this.flowParseRestrictedIdentifier();
              return this.match(14) && (s.typeAnnotation = this.flowParseTypeAnnotation(), this.resetEndLocation(s)), s;
            }
            typeCastToParameter(e) {
              return e.expression.typeAnnotation = e.typeAnnotation, this.resetEndLocation(e.expression, e.typeAnnotation.loc.end), e.expression;
            }
            flowParseVariance() {
              let e = null;
              return this.match(53) ? (e = this.startNode(), this.state.value === "+" ? e.kind = "plus" : e.kind = "minus", this.next(), this.finishNode(e, "Variance")) : e;
            }
            parseFunctionBody(e, s) {
              let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              return s ? this.forwardNoArrowParamsConversionAt(e, () => super.parseFunctionBody(e, true, i)) : super.parseFunctionBody(e, false, i);
            }
            parseFunctionBodyAndFinish(e, s) {
              let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              if (this.match(14)) {
                let a = this.startNode();
                [a.typeAnnotation, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), e.returnType = a.typeAnnotation ? this.finishNode(a, "TypeAnnotation") : null;
              }
              return super.parseFunctionBodyAndFinish(e, s, i);
            }
            parseStatementLike(e) {
              if (this.state.strict && this.isContextual(127)) {
                let i = this.lookahead();
                if (ye(i.type)) {
                  let a = this.startNode();
                  return this.next(), this.flowParseInterface(a);
                }
              } else if (this.shouldParseEnums() && this.isContextual(124)) {
                let i = this.startNode();
                return this.next(), this.flowParseEnumDeclaration(i);
              }
              let s = super.parseStatementLike(e);
              return this.flowPragma === void 0 && !this.isValidDirective(s) && (this.flowPragma = null), s;
            }
            parseExpressionStatement(e, s, i) {
              if (s.type === "Identifier") {
                if (s.name === "declare") {
                  if (this.match(80) || z(this.state.type) || this.match(68) || this.match(74) || this.match(82))
                    return this.flowParseDeclare(e);
                } else if (z(this.state.type)) {
                  if (s.name === "interface")
                    return this.flowParseInterface(e);
                  if (s.name === "type")
                    return this.flowParseTypeAlias(e);
                  if (s.name === "opaque")
                    return this.flowParseOpaqueType(e, false);
                }
              }
              return super.parseExpressionStatement(e, s, i);
            }
            shouldParseExportDeclaration() {
              let { type: e } = this.state;
              return Pr(e) || this.shouldParseEnums() && e === 124 ? !this.state.containsEsc : super.shouldParseExportDeclaration();
            }
            isExportDefaultSpecifier() {
              let { type: e } = this.state;
              return Pr(e) || this.shouldParseEnums() && e === 124 ? this.state.containsEsc : super.isExportDefaultSpecifier();
            }
            parseExportDefaultExpression() {
              if (this.shouldParseEnums() && this.isContextual(124)) {
                let e = this.startNode();
                return this.next(), this.flowParseEnumDeclaration(e);
              }
              return super.parseExportDefaultExpression();
            }
            parseConditional(e, s, i) {
              if (!this.match(17))
                return e;
              if (this.state.maybeInArrowParameters) {
                let A = this.lookaheadCharCode();
                if (A === 44 || A === 61 || A === 58 || A === 41)
                  return this.setOptionalParametersError(i), e;
              }
              this.expect(17);
              let a = this.state.clone(), n = this.state.noArrowAt, o = this.startNodeAt(s), { consequent: c, failed: p } = this.tryParseConditionalConsequent(), [m, x] = this.getArrowLikeExpressions(c);
              if (p || x.length > 0) {
                let A = [...n];
                if (x.length > 0) {
                  this.state = a, this.state.noArrowAt = A;
                  for (let b = 0; b < x.length; b++)
                    A.push(x[b].start);
                  ({ consequent: c, failed: p } = this.tryParseConditionalConsequent()), [m, x] = this.getArrowLikeExpressions(c);
                }
                p && m.length > 1 && this.raise(D.AmbiguousConditionalArrow, { at: a.startLoc }), p && m.length === 1 && (this.state = a, A.push(m[0].start), this.state.noArrowAt = A, { consequent: c, failed: p } = this.tryParseConditionalConsequent());
              }
              return this.getArrowLikeExpressions(c, true), this.state.noArrowAt = n, this.expect(14), o.test = e, o.consequent = c, o.alternate = this.forwardNoArrowParamsConversionAt(o, () => this.parseMaybeAssign(void 0, void 0)), this.finishNode(o, "ConditionalExpression");
            }
            tryParseConditionalConsequent() {
              this.state.noArrowParamsConversionAt.push(this.state.start);
              let e = this.parseMaybeAssignAllowIn(), s = !this.match(14);
              return this.state.noArrowParamsConversionAt.pop(), { consequent: e, failed: s };
            }
            getArrowLikeExpressions(e, s) {
              let i = [e], a = [];
              for (; i.length !== 0; ) {
                let n = i.pop();
                n.type === "ArrowFunctionExpression" ? (n.typeParameters || !n.returnType ? this.finishArrowValidation(n) : a.push(n), i.push(n.body)) : n.type === "ConditionalExpression" && (i.push(n.consequent), i.push(n.alternate));
              }
              return s ? (a.forEach((n) => this.finishArrowValidation(n)), [a, []]) : Yl(a, (n) => n.params.every((o) => this.isAssignable(o, true)));
            }
            finishArrowValidation(e) {
              var s;
              this.toAssignableList(e.params, (s = e.extra) == null ? void 0 : s.trailingCommaLoc, false), this.scope.enter(Pe | ts), super.checkParams(e, false, true), this.scope.exit();
            }
            forwardNoArrowParamsConversionAt(e, s) {
              let i;
              return this.state.noArrowParamsConversionAt.indexOf(e.start) !== -1 ? (this.state.noArrowParamsConversionAt.push(this.state.start), i = s(), this.state.noArrowParamsConversionAt.pop()) : i = s(), i;
            }
            parseParenItem(e, s) {
              if (e = super.parseParenItem(e, s), this.eat(17) && (e.optional = true, this.resetEndLocation(e)), this.match(14)) {
                let i = this.startNodeAt(s);
                return i.expression = e, i.typeAnnotation = this.flowParseTypeAnnotation(), this.finishNode(i, "TypeCastExpression");
              }
              return e;
            }
            assertModuleNodeAllowed(e) {
              e.type === "ImportDeclaration" && (e.importKind === "type" || e.importKind === "typeof") || e.type === "ExportNamedDeclaration" && e.exportKind === "type" || e.type === "ExportAllDeclaration" && e.exportKind === "type" || super.assertModuleNodeAllowed(e);
            }
            parseExport(e, s) {
              let i = super.parseExport(e, s);
              return (i.type === "ExportNamedDeclaration" || i.type === "ExportAllDeclaration") && (i.exportKind = i.exportKind || "value"), i;
            }
            parseExportDeclaration(e) {
              if (this.isContextual(128)) {
                e.exportKind = "type";
                let s = this.startNode();
                return this.next(), this.match(5) ? (e.specifiers = this.parseExportSpecifiers(true), super.parseExportFrom(e), null) : this.flowParseTypeAlias(s);
              } else if (this.isContextual(129)) {
                e.exportKind = "type";
                let s = this.startNode();
                return this.next(), this.flowParseOpaqueType(s, false);
              } else if (this.isContextual(127)) {
                e.exportKind = "type";
                let s = this.startNode();
                return this.next(), this.flowParseInterface(s);
              } else if (this.shouldParseEnums() && this.isContextual(124)) {
                e.exportKind = "value";
                let s = this.startNode();
                return this.next(), this.flowParseEnumDeclaration(s);
              } else
                return super.parseExportDeclaration(e);
            }
            eatExportStar(e) {
              return super.eatExportStar(e) ? true : this.isContextual(128) && this.lookahead().type === 55 ? (e.exportKind = "type", this.next(), this.next(), true) : false;
            }
            maybeParseExportNamespaceSpecifier(e) {
              let { startLoc: s } = this.state, i = super.maybeParseExportNamespaceSpecifier(e);
              return i && e.exportKind === "type" && this.unexpected(s), i;
            }
            parseClassId(e, s, i) {
              super.parseClassId(e, s, i), this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration());
            }
            parseClassMember(e, s, i) {
              let { startLoc: a } = this.state;
              if (this.isContextual(123)) {
                if (super.parseClassMemberFromModifier(e, s))
                  return;
                s.declare = true;
              }
              super.parseClassMember(e, s, i), s.declare && (s.type !== "ClassProperty" && s.type !== "ClassPrivateProperty" && s.type !== "PropertyDefinition" ? this.raise(D.DeclareClassElement, { at: a }) : s.value && this.raise(D.DeclareClassFieldInitializer, { at: s.value }));
            }
            isIterator(e) {
              return e === "iterator" || e === "asyncIterator";
            }
            readIterator() {
              let e = super.readWord1(), s = "@@" + e;
              (!this.isIterator(e) || !this.state.inType) && this.raise(u.InvalidIdentifier, { at: this.state.curPosition(), identifierName: s }), this.finishToken(130, s);
            }
            getTokenFromCode(e) {
              let s = this.input.charCodeAt(this.state.pos + 1);
              return e === 123 && s === 124 ? this.finishOp(6, 2) : this.state.inType && (e === 62 || e === 60) ? this.finishOp(e === 62 ? 48 : 47, 1) : this.state.inType && e === 63 ? s === 46 ? this.finishOp(18, 2) : this.finishOp(17, 1) : hl(e, s, this.input.charCodeAt(this.state.pos + 2)) ? (this.state.pos += 2, this.readIterator()) : super.getTokenFromCode(e);
            }
            isAssignable(e, s) {
              return e.type === "TypeCastExpression" ? this.isAssignable(e.expression, s) : super.isAssignable(e, s);
            }
            toAssignable(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              !s && e.type === "AssignmentExpression" && e.left.type === "TypeCastExpression" && (e.left = this.typeCastToParameter(e.left)), super.toAssignable(e, s);
            }
            toAssignableList(e, s, i) {
              for (let a = 0; a < e.length; a++) {
                let n = e[a];
                (n == null ? void 0 : n.type) === "TypeCastExpression" && (e[a] = this.typeCastToParameter(n));
              }
              super.toAssignableList(e, s, i);
            }
            toReferencedList(e, s) {
              for (let a = 0; a < e.length; a++) {
                var i;
                let n = e[a];
                n && n.type === "TypeCastExpression" && !((i = n.extra) != null && i.parenthesized) && (e.length > 1 || !s) && this.raise(D.TypeCastInPattern, { at: n.typeAnnotation });
              }
              return e;
            }
            parseArrayLike(e, s, i, a) {
              let n = super.parseArrayLike(e, s, i, a);
              return s && !this.state.maybeInArrowParameters && this.toReferencedList(n.elements), n;
            }
            isValidLVal(e, s, i) {
              return e === "TypeCastExpression" || super.isValidLVal(e, s, i);
            }
            parseClassProperty(e) {
              return this.match(14) && (e.typeAnnotation = this.flowParseTypeAnnotation()), super.parseClassProperty(e);
            }
            parseClassPrivateProperty(e) {
              return this.match(14) && (e.typeAnnotation = this.flowParseTypeAnnotation()), super.parseClassPrivateProperty(e);
            }
            isClassMethod() {
              return this.match(47) || super.isClassMethod();
            }
            isClassProperty() {
              return this.match(14) || super.isClassProperty();
            }
            isNonstaticConstructor(e) {
              return !this.match(14) && super.isNonstaticConstructor(e);
            }
            pushClassMethod(e, s, i, a, n, o) {
              if (s.variance && this.unexpected(s.variance.loc.start), delete s.variance, this.match(47) && (s.typeParameters = this.flowParseTypeParameterDeclaration()), super.pushClassMethod(e, s, i, a, n, o), s.params && n) {
                let c = s.params;
                c.length > 0 && this.isThisParam(c[0]) && this.raise(D.ThisParamBannedInConstructor, { at: s });
              } else if (s.type === "MethodDefinition" && n && s.value.params) {
                let c = s.value.params;
                c.length > 0 && this.isThisParam(c[0]) && this.raise(D.ThisParamBannedInConstructor, { at: s });
              }
            }
            pushClassPrivateMethod(e, s, i, a) {
              s.variance && this.unexpected(s.variance.loc.start), delete s.variance, this.match(47) && (s.typeParameters = this.flowParseTypeParameterDeclaration()), super.pushClassPrivateMethod(e, s, i, a);
            }
            parseClassSuper(e) {
              if (super.parseClassSuper(e), e.superClass && this.match(47) && (e.superTypeParameters = this.flowParseTypeParameterInstantiation()), this.isContextual(111)) {
                this.next();
                let s = e.implements = [];
                do {
                  let i = this.startNode();
                  i.id = this.flowParseRestrictedIdentifier(true), this.match(47) ? i.typeParameters = this.flowParseTypeParameterInstantiation() : i.typeParameters = null, s.push(this.finishNode(i, "ClassImplements"));
                } while (this.eat(12));
              }
            }
            checkGetterSetterParams(e) {
              super.checkGetterSetterParams(e);
              let s = this.getObjectOrClassMethodParams(e);
              if (s.length > 0) {
                let i = s[0];
                this.isThisParam(i) && e.kind === "get" ? this.raise(D.GetterMayNotHaveThisParam, { at: i }) : this.isThisParam(i) && this.raise(D.SetterMayNotHaveThisParam, { at: i });
              }
            }
            parsePropertyNamePrefixOperator(e) {
              e.variance = this.flowParseVariance();
            }
            parseObjPropValue(e, s, i, a, n, o, c) {
              e.variance && this.unexpected(e.variance.loc.start), delete e.variance;
              let p;
              this.match(47) && !o && (p = this.flowParseTypeParameterDeclaration(), this.match(10) || this.unexpected());
              let m = super.parseObjPropValue(e, s, i, a, n, o, c);
              return p && ((m.value || m).typeParameters = p), m;
            }
            parseAssignableListItemTypes(e) {
              return this.eat(17) && (e.type !== "Identifier" && this.raise(D.PatternIsOptional, { at: e }), this.isThisParam(e) && this.raise(D.ThisParamMayNotBeOptional, { at: e }), e.optional = true), this.match(14) ? e.typeAnnotation = this.flowParseTypeAnnotation() : this.isThisParam(e) && this.raise(D.ThisParamAnnotationRequired, { at: e }), this.match(29) && this.isThisParam(e) && this.raise(D.ThisParamNoDefault, { at: e }), this.resetEndLocation(e), e;
            }
            parseMaybeDefault(e, s) {
              let i = super.parseMaybeDefault(e, s);
              return i.type === "AssignmentPattern" && i.typeAnnotation && i.right.start < i.typeAnnotation.start && this.raise(D.TypeBeforeInitializer, { at: i.typeAnnotation }), i;
            }
            shouldParseDefaultImport(e) {
              return xs(e) ? Gr(this.state.type) : super.shouldParseDefaultImport(e);
            }
            checkImportReflection(e) {
              super.checkImportReflection(e), e.module && e.importKind !== "value" && this.raise(D.ImportReflectionHasImportType, { at: e.specifiers[0].loc.start });
            }
            parseImportSpecifierLocal(e, s, i) {
              s.local = xs(e) ? this.flowParseRestrictedIdentifier(true, true) : this.parseIdentifier(), e.specifiers.push(this.finishImportSpecifier(s, i));
            }
            maybeParseDefaultImportSpecifier(e) {
              e.importKind = "value";
              let s = null;
              if (this.match(87) ? s = "typeof" : this.isContextual(128) && (s = "type"), s) {
                let i = this.lookahead(), { type: a } = i;
                s === "type" && a === 55 && this.unexpected(null, i.type), (Gr(a) || a === 5 || a === 55) && (this.next(), e.importKind = s);
              }
              return super.maybeParseDefaultImportSpecifier(e);
            }
            parseImportSpecifier(e, s, i, a, n) {
              let o = e.imported, c = null;
              o.type === "Identifier" && (o.name === "type" ? c = "type" : o.name === "typeof" && (c = "typeof"));
              let p = false;
              if (this.isContextual(93) && !this.isLookaheadContextual("as")) {
                let x = this.parseIdentifier(true);
                c !== null && !ye(this.state.type) ? (e.imported = x, e.importKind = c, e.local = Te(x)) : (e.imported = o, e.importKind = null, e.local = this.parseIdentifier());
              } else {
                if (c !== null && ye(this.state.type))
                  e.imported = this.parseIdentifier(true), e.importKind = c;
                else {
                  if (s)
                    throw this.raise(u.ImportBindingIsString, { at: e, importName: o.value });
                  e.imported = o, e.importKind = null;
                }
                this.eatContextual(93) ? e.local = this.parseIdentifier() : (p = true, e.local = Te(e.imported));
              }
              let m = xs(e);
              return i && m && this.raise(D.ImportTypeShorthandOnlyInPureImport, { at: e }), (i || m) && this.checkReservedType(e.local.name, e.local.loc.start, true), p && !i && !m && this.checkReservedWord(e.local.name, e.loc.start, true, true), this.finishImportSpecifier(e, "ImportSpecifier");
            }
            parseBindingAtom() {
              switch (this.state.type) {
                case 78:
                  return this.parseIdentifier(true);
                default:
                  return super.parseBindingAtom();
              }
            }
            parseFunctionParams(e, s) {
              let i = e.kind;
              i !== "get" && i !== "set" && this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration()), super.parseFunctionParams(e, s);
            }
            parseVarId(e, s) {
              super.parseVarId(e, s), this.match(14) && (e.id.typeAnnotation = this.flowParseTypeAnnotation(), this.resetEndLocation(e.id));
            }
            parseAsyncArrowFromCallExpression(e, s) {
              if (this.match(14)) {
                let i = this.state.noAnonFunctionType;
                this.state.noAnonFunctionType = true, e.returnType = this.flowParseTypeAnnotation(), this.state.noAnonFunctionType = i;
              }
              return super.parseAsyncArrowFromCallExpression(e, s);
            }
            shouldParseAsyncArrow() {
              return this.match(14) || super.shouldParseAsyncArrow();
            }
            parseMaybeAssign(e, s) {
              var i;
              let a = null, n;
              if (this.hasPlugin("jsx") && (this.match(140) || this.match(47))) {
                if (a = this.state.clone(), n = this.tryParse(() => super.parseMaybeAssign(e, s), a), !n.error)
                  return n.node;
                let { context: p } = this.state, m = p[p.length - 1];
                (m === $2.j_oTag || m === $2.j_expr) && p.pop();
              }
              if ((i = n) != null && i.error || this.match(47)) {
                var o, c;
                a = a || this.state.clone();
                let p, m = this.tryParse((A) => {
                  var b;
                  p = this.flowParseTypeParameterDeclaration();
                  let O = this.forwardNoArrowParamsConversionAt(p, () => {
                    let Y = super.parseMaybeAssign(e, s);
                    return this.resetStartLocationFromNode(Y, p), Y;
                  });
                  (b = O.extra) != null && b.parenthesized && A();
                  let R = this.maybeUnwrapTypeCastExpression(O);
                  return R.type !== "ArrowFunctionExpression" && A(), R.typeParameters = p, this.resetStartLocationFromNode(R, p), O;
                }, a), x = null;
                if (m.node && this.maybeUnwrapTypeCastExpression(m.node).type === "ArrowFunctionExpression") {
                  if (!m.error && !m.aborted)
                    return m.node.async && this.raise(D.UnexpectedTypeParameterBeforeAsyncArrowFunction, { at: p }), m.node;
                  x = m.node;
                }
                if ((o = n) != null && o.node)
                  return this.state = n.failState, n.node;
                if (x)
                  return this.state = m.failState, x;
                throw (c = n) != null && c.thrown ? n.error : m.thrown ? m.error : this.raise(D.UnexpectedTokenAfterTypeParameter, { at: p });
              }
              return super.parseMaybeAssign(e, s);
            }
            parseArrow(e) {
              if (this.match(14)) {
                let s = this.tryParse(() => {
                  let i = this.state.noAnonFunctionType;
                  this.state.noAnonFunctionType = true;
                  let a = this.startNode();
                  return [a.typeAnnotation, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), this.state.noAnonFunctionType = i, this.canInsertSemicolon() && this.unexpected(), this.match(19) || this.unexpected(), a;
                });
                if (s.thrown)
                  return null;
                s.error && (this.state = s.failState), e.returnType = s.node.typeAnnotation ? this.finishNode(s.node, "TypeAnnotation") : null;
              }
              return super.parseArrow(e);
            }
            shouldParseArrow(e) {
              return this.match(14) || super.shouldParseArrow(e);
            }
            setArrowFunctionParameters(e, s) {
              this.state.noArrowParamsConversionAt.indexOf(e.start) !== -1 ? e.params = s : super.setArrowFunctionParameters(e, s);
            }
            checkParams(e, s, i) {
              let a = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true;
              if (!(i && this.state.noArrowParamsConversionAt.indexOf(e.start) !== -1)) {
                for (let n = 0; n < e.params.length; n++)
                  this.isThisParam(e.params[n]) && n > 0 && this.raise(D.ThisParamMustBeFirst, { at: e.params[n] });
                return super.checkParams(e, s, i, a);
              }
            }
            parseParenAndDistinguishExpression(e) {
              return super.parseParenAndDistinguishExpression(e && this.state.noArrowAt.indexOf(this.state.start) === -1);
            }
            parseSubscripts(e, s, i) {
              if (e.type === "Identifier" && e.name === "async" && this.state.noArrowAt.indexOf(s.index) !== -1) {
                this.next();
                let a = this.startNodeAt(s);
                a.callee = e, a.arguments = super.parseCallExpressionArguments(11, false), e = this.finishNode(a, "CallExpression");
              } else if (e.type === "Identifier" && e.name === "async" && this.match(47)) {
                let a = this.state.clone(), n = this.tryParse((c) => this.parseAsyncArrowWithTypeParameters(s) || c(), a);
                if (!n.error && !n.aborted)
                  return n.node;
                let o = this.tryParse(() => super.parseSubscripts(e, s, i), a);
                if (o.node && !o.error)
                  return o.node;
                if (n.node)
                  return this.state = n.failState, n.node;
                if (o.node)
                  return this.state = o.failState, o.node;
                throw n.error || o.error;
              }
              return super.parseSubscripts(e, s, i);
            }
            parseSubscript(e, s, i, a) {
              if (this.match(18) && this.isLookaheadToken_lt()) {
                if (a.optionalChainMember = true, i)
                  return a.stop = true, e;
                this.next();
                let n = this.startNodeAt(s);
                return n.callee = e, n.typeArguments = this.flowParseTypeParameterInstantiation(), this.expect(10), n.arguments = this.parseCallExpressionArguments(11, false), n.optional = true, this.finishCallExpression(n, true);
              } else if (!i && this.shouldParseTypes() && this.match(47)) {
                let n = this.startNodeAt(s);
                n.callee = e;
                let o = this.tryParse(() => (n.typeArguments = this.flowParseTypeParameterInstantiationCallOrNew(), this.expect(10), n.arguments = super.parseCallExpressionArguments(11, false), a.optionalChainMember && (n.optional = false), this.finishCallExpression(n, a.optionalChainMember)));
                if (o.node)
                  return o.error && (this.state = o.failState), o.node;
              }
              return super.parseSubscript(e, s, i, a);
            }
            parseNewCallee(e) {
              super.parseNewCallee(e);
              let s = null;
              this.shouldParseTypes() && this.match(47) && (s = this.tryParse(() => this.flowParseTypeParameterInstantiationCallOrNew()).node), e.typeArguments = s;
            }
            parseAsyncArrowWithTypeParameters(e) {
              let s = this.startNodeAt(e);
              if (this.parseFunctionParams(s), !!this.parseArrow(s))
                return super.parseArrowExpression(s, void 0, true);
            }
            readToken_mult_modulo(e) {
              let s = this.input.charCodeAt(this.state.pos + 1);
              if (e === 42 && s === 47 && this.state.hasFlowComment) {
                this.state.hasFlowComment = false, this.state.pos += 2, this.nextToken();
                return;
              }
              super.readToken_mult_modulo(e);
            }
            readToken_pipe_amp(e) {
              let s = this.input.charCodeAt(this.state.pos + 1);
              if (e === 124 && s === 125) {
                this.finishOp(9, 2);
                return;
              }
              super.readToken_pipe_amp(e);
            }
            parseTopLevel(e, s) {
              let i = super.parseTopLevel(e, s);
              return this.state.hasFlowComment && this.raise(D.UnterminatedFlowComment, { at: this.state.curPosition() }), i;
            }
            skipBlockComment() {
              if (this.hasPlugin("flowComments") && this.skipFlowComment()) {
                if (this.state.hasFlowComment)
                  throw this.raise(D.NestedFlowComment, { at: this.state.startLoc });
                this.hasFlowCommentCompletion();
                let e = this.skipFlowComment();
                e && (this.state.pos += e, this.state.hasFlowComment = true);
                return;
              }
              return super.skipBlockComment(this.state.hasFlowComment ? "*-/" : "*/");
            }
            skipFlowComment() {
              let { pos: e } = this.state, s = 2;
              for (; [32, 9].includes(this.input.charCodeAt(e + s)); )
                s++;
              let i = this.input.charCodeAt(s + e), a = this.input.charCodeAt(s + e + 1);
              return i === 58 && a === 58 ? s + 2 : this.input.slice(s + e, s + e + 12) === "flow-include" ? s + 12 : i === 58 && a !== 58 ? s : false;
            }
            hasFlowCommentCompletion() {
              if (this.input.indexOf("*/", this.state.pos) === -1)
                throw this.raise(u.UnterminatedComment, { at: this.state.curPosition() });
            }
            flowEnumErrorBooleanMemberNotInitialized(e, s) {
              let { enumName: i, memberName: a } = s;
              this.raise(D.EnumBooleanMemberNotInitialized, { at: e, memberName: a, enumName: i });
            }
            flowEnumErrorInvalidMemberInitializer(e, s) {
              return this.raise(s.explicitType ? s.explicitType === "symbol" ? D.EnumInvalidMemberInitializerSymbolType : D.EnumInvalidMemberInitializerPrimaryType : D.EnumInvalidMemberInitializerUnknownType, Object.assign({ at: e }, s));
            }
            flowEnumErrorNumberMemberNotInitialized(e, s) {
              let { enumName: i, memberName: a } = s;
              this.raise(D.EnumNumberMemberNotInitialized, { at: e, enumName: i, memberName: a });
            }
            flowEnumErrorStringMemberInconsistentlyInitailized(e, s) {
              let { enumName: i } = s;
              this.raise(D.EnumStringMemberInconsistentlyInitailized, { at: e, enumName: i });
            }
            flowEnumMemberInit() {
              let e = this.state.startLoc, s = () => this.match(12) || this.match(8);
              switch (this.state.type) {
                case 132: {
                  let i = this.parseNumericLiteral(this.state.value);
                  return s() ? { type: "number", loc: i.loc.start, value: i } : { type: "invalid", loc: e };
                }
                case 131: {
                  let i = this.parseStringLiteral(this.state.value);
                  return s() ? { type: "string", loc: i.loc.start, value: i } : { type: "invalid", loc: e };
                }
                case 85:
                case 86: {
                  let i = this.parseBooleanLiteral(this.match(85));
                  return s() ? { type: "boolean", loc: i.loc.start, value: i } : { type: "invalid", loc: e };
                }
                default:
                  return { type: "invalid", loc: e };
              }
            }
            flowEnumMemberRaw() {
              let e = this.state.startLoc, s = this.parseIdentifier(true), i = this.eat(29) ? this.flowEnumMemberInit() : { type: "none", loc: e };
              return { id: s, init: i };
            }
            flowEnumCheckExplicitTypeMismatch(e, s, i) {
              let { explicitType: a } = s;
              a !== null && a !== i && this.flowEnumErrorInvalidMemberInitializer(e, s);
            }
            flowEnumMembers(e) {
              let { enumName: s, explicitType: i } = e, a = /* @__PURE__ */ new Set(), n = { booleanMembers: [], numberMembers: [], stringMembers: [], defaultedMembers: [] }, o = false;
              for (; !this.match(8); ) {
                if (this.eat(21)) {
                  o = true;
                  break;
                }
                let c = this.startNode(), { id: p, init: m } = this.flowEnumMemberRaw(), x = p.name;
                if (x === "")
                  continue;
                /^[a-z]/.test(x) && this.raise(D.EnumInvalidMemberName, { at: p, memberName: x, suggestion: x[0].toUpperCase() + x.slice(1), enumName: s }), a.has(x) && this.raise(D.EnumDuplicateMemberName, { at: p, memberName: x, enumName: s }), a.add(x);
                let A = { enumName: s, explicitType: i, memberName: x };
                switch (c.id = p, m.type) {
                  case "boolean": {
                    this.flowEnumCheckExplicitTypeMismatch(m.loc, A, "boolean"), c.init = m.value, n.booleanMembers.push(this.finishNode(c, "EnumBooleanMember"));
                    break;
                  }
                  case "number": {
                    this.flowEnumCheckExplicitTypeMismatch(m.loc, A, "number"), c.init = m.value, n.numberMembers.push(this.finishNode(c, "EnumNumberMember"));
                    break;
                  }
                  case "string": {
                    this.flowEnumCheckExplicitTypeMismatch(m.loc, A, "string"), c.init = m.value, n.stringMembers.push(this.finishNode(c, "EnumStringMember"));
                    break;
                  }
                  case "invalid":
                    throw this.flowEnumErrorInvalidMemberInitializer(m.loc, A);
                  case "none":
                    switch (i) {
                      case "boolean":
                        this.flowEnumErrorBooleanMemberNotInitialized(m.loc, A);
                        break;
                      case "number":
                        this.flowEnumErrorNumberMemberNotInitialized(m.loc, A);
                        break;
                      default:
                        n.defaultedMembers.push(this.finishNode(c, "EnumDefaultedMember"));
                    }
                }
                this.match(8) || this.expect(12);
              }
              return { members: n, hasUnknownMembers: o };
            }
            flowEnumStringMembers(e, s, i) {
              let { enumName: a } = i;
              if (e.length === 0)
                return s;
              if (s.length === 0)
                return e;
              if (s.length > e.length) {
                for (let n of e)
                  this.flowEnumErrorStringMemberInconsistentlyInitailized(n, { enumName: a });
                return s;
              } else {
                for (let n of s)
                  this.flowEnumErrorStringMemberInconsistentlyInitailized(n, { enumName: a });
                return e;
              }
            }
            flowEnumParseExplicitType(e) {
              let { enumName: s } = e;
              if (!this.eatContextual(101))
                return null;
              if (!z(this.state.type))
                throw this.raise(D.EnumInvalidExplicitTypeUnknownSupplied, { at: this.state.startLoc, enumName: s });
              let { value: i } = this.state;
              return this.next(), i !== "boolean" && i !== "number" && i !== "string" && i !== "symbol" && this.raise(D.EnumInvalidExplicitType, { at: this.state.startLoc, enumName: s, invalidEnumType: i }), i;
            }
            flowEnumBody(e, s) {
              let i = s.name, a = s.loc.start, n = this.flowEnumParseExplicitType({ enumName: i });
              this.expect(5);
              let { members: o, hasUnknownMembers: c } = this.flowEnumMembers({ enumName: i, explicitType: n });
              switch (e.hasUnknownMembers = c, n) {
                case "boolean":
                  return e.explicitType = true, e.members = o.booleanMembers, this.expect(8), this.finishNode(e, "EnumBooleanBody");
                case "number":
                  return e.explicitType = true, e.members = o.numberMembers, this.expect(8), this.finishNode(e, "EnumNumberBody");
                case "string":
                  return e.explicitType = true, e.members = this.flowEnumStringMembers(o.stringMembers, o.defaultedMembers, { enumName: i }), this.expect(8), this.finishNode(e, "EnumStringBody");
                case "symbol":
                  return e.members = o.defaultedMembers, this.expect(8), this.finishNode(e, "EnumSymbolBody");
                default: {
                  let p = () => (e.members = [], this.expect(8), this.finishNode(e, "EnumStringBody"));
                  e.explicitType = false;
                  let m = o.booleanMembers.length, x = o.numberMembers.length, A = o.stringMembers.length, b = o.defaultedMembers.length;
                  if (!m && !x && !A && !b)
                    return p();
                  if (!m && !x)
                    return e.members = this.flowEnumStringMembers(o.stringMembers, o.defaultedMembers, { enumName: i }), this.expect(8), this.finishNode(e, "EnumStringBody");
                  if (!x && !A && m >= b) {
                    for (let O of o.defaultedMembers)
                      this.flowEnumErrorBooleanMemberNotInitialized(O.loc.start, { enumName: i, memberName: O.id.name });
                    return e.members = o.booleanMembers, this.expect(8), this.finishNode(e, "EnumBooleanBody");
                  } else if (!m && !A && x >= b) {
                    for (let O of o.defaultedMembers)
                      this.flowEnumErrorNumberMemberNotInitialized(O.loc.start, { enumName: i, memberName: O.id.name });
                    return e.members = o.numberMembers, this.expect(8), this.finishNode(e, "EnumNumberBody");
                  } else
                    return this.raise(D.EnumInconsistentMemberValues, { at: a, enumName: i }), p();
                }
              }
            }
            flowParseEnumDeclaration(e) {
              let s = this.parseIdentifier();
              return e.id = s, e.body = this.flowEnumBody(this.startNode(), s), this.finishNode(e, "EnumDeclaration");
            }
            isLookaheadToken_lt() {
              let e = this.nextTokenStart();
              if (this.input.charCodeAt(e) === 60) {
                let s = this.input.charCodeAt(e + 1);
                return s !== 60 && s !== 61;
              }
              return false;
            }
            maybeUnwrapTypeCastExpression(e) {
              return e.type === "TypeCastExpression" ? e.expression : e;
            }
          }, eh = { __proto__: null, quot: '"', amp: "&", apos: "'", lt: "<", gt: ">", nbsp: "\xA0", iexcl: "\xA1", cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", brvbar: "\xA6", sect: "\xA7", uml: "\xA8", copy: "\xA9", ordf: "\xAA", laquo: "\xAB", not: "\xAC", shy: "\xAD", reg: "\xAE", macr: "\xAF", deg: "\xB0", plusmn: "\xB1", sup2: "\xB2", sup3: "\xB3", acute: "\xB4", micro: "\xB5", para: "\xB6", middot: "\xB7", cedil: "\xB8", sup1: "\xB9", ordm: "\xBA", raquo: "\xBB", frac14: "\xBC", frac12: "\xBD", frac34: "\xBE", iquest: "\xBF", Agrave: "\xC0", Aacute: "\xC1", Acirc: "\xC2", Atilde: "\xC3", Auml: "\xC4", Aring: "\xC5", AElig: "\xC6", Ccedil: "\xC7", Egrave: "\xC8", Eacute: "\xC9", Ecirc: "\xCA", Euml: "\xCB", Igrave: "\xCC", Iacute: "\xCD", Icirc: "\xCE", Iuml: "\xCF", ETH: "\xD0", Ntilde: "\xD1", Ograve: "\xD2", Oacute: "\xD3", Ocirc: "\xD4", Otilde: "\xD5", Ouml: "\xD6", times: "\xD7", Oslash: "\xD8", Ugrave: "\xD9", Uacute: "\xDA", Ucirc: "\xDB", Uuml: "\xDC", Yacute: "\xDD", THORN: "\xDE", szlig: "\xDF", agrave: "\xE0", aacute: "\xE1", acirc: "\xE2", atilde: "\xE3", auml: "\xE4", aring: "\xE5", aelig: "\xE6", ccedil: "\xE7", egrave: "\xE8", eacute: "\xE9", ecirc: "\xEA", euml: "\xEB", igrave: "\xEC", iacute: "\xED", icirc: "\xEE", iuml: "\xEF", eth: "\xF0", ntilde: "\xF1", ograve: "\xF2", oacute: "\xF3", ocirc: "\xF4", otilde: "\xF5", ouml: "\xF6", divide: "\xF7", oslash: "\xF8", ugrave: "\xF9", uacute: "\xFA", ucirc: "\xFB", uuml: "\xFC", yacute: "\xFD", thorn: "\xFE", yuml: "\xFF", OElig: "\u0152", oelig: "\u0153", Scaron: "\u0160", scaron: "\u0161", Yuml: "\u0178", fnof: "\u0192", circ: "\u02C6", tilde: "\u02DC", Alpha: "\u0391", Beta: "\u0392", Gamma: "\u0393", Delta: "\u0394", Epsilon: "\u0395", Zeta: "\u0396", Eta: "\u0397", Theta: "\u0398", Iota: "\u0399", Kappa: "\u039A", Lambda: "\u039B", Mu: "\u039C", Nu: "\u039D", Xi: "\u039E", Omicron: "\u039F", Pi: "\u03A0", Rho: "\u03A1", Sigma: "\u03A3", Tau: "\u03A4", Upsilon: "\u03A5", Phi: "\u03A6", Chi: "\u03A7", Psi: "\u03A8", Omega: "\u03A9", alpha: "\u03B1", beta: "\u03B2", gamma: "\u03B3", delta: "\u03B4", epsilon: "\u03B5", zeta: "\u03B6", eta: "\u03B7", theta: "\u03B8", iota: "\u03B9", kappa: "\u03BA", lambda: "\u03BB", mu: "\u03BC", nu: "\u03BD", xi: "\u03BE", omicron: "\u03BF", pi: "\u03C0", rho: "\u03C1", sigmaf: "\u03C2", sigma: "\u03C3", tau: "\u03C4", upsilon: "\u03C5", phi: "\u03C6", chi: "\u03C7", psi: "\u03C8", omega: "\u03C9", thetasym: "\u03D1", upsih: "\u03D2", piv: "\u03D6", ensp: "\u2002", emsp: "\u2003", thinsp: "\u2009", zwnj: "\u200C", zwj: "\u200D", lrm: "\u200E", rlm: "\u200F", ndash: "\u2013", mdash: "\u2014", lsquo: "\u2018", rsquo: "\u2019", sbquo: "\u201A", ldquo: "\u201C", rdquo: "\u201D", bdquo: "\u201E", dagger: "\u2020", Dagger: "\u2021", bull: "\u2022", hellip: "\u2026", permil: "\u2030", prime: "\u2032", Prime: "\u2033", lsaquo: "\u2039", rsaquo: "\u203A", oline: "\u203E", frasl: "\u2044", euro: "\u20AC", image: "\u2111", weierp: "\u2118", real: "\u211C", trade: "\u2122", alefsym: "\u2135", larr: "\u2190", uarr: "\u2191", rarr: "\u2192", darr: "\u2193", harr: "\u2194", crarr: "\u21B5", lArr: "\u21D0", uArr: "\u21D1", rArr: "\u21D2", dArr: "\u21D3", hArr: "\u21D4", forall: "\u2200", part: "\u2202", exist: "\u2203", empty: "\u2205", nabla: "\u2207", isin: "\u2208", notin: "\u2209", ni: "\u220B", prod: "\u220F", sum: "\u2211", minus: "\u2212", lowast: "\u2217", radic: "\u221A", prop: "\u221D", infin: "\u221E", ang: "\u2220", and: "\u2227", or: "\u2228", cap: "\u2229", cup: "\u222A", int: "\u222B", there4: "\u2234", sim: "\u223C", cong: "\u2245", asymp: "\u2248", ne: "\u2260", equiv: "\u2261", le: "\u2264", ge: "\u2265", sub: "\u2282", sup: "\u2283", nsub: "\u2284", sube: "\u2286", supe: "\u2287", oplus: "\u2295", otimes: "\u2297", perp: "\u22A5", sdot: "\u22C5", lceil: "\u2308", rceil: "\u2309", lfloor: "\u230A", rfloor: "\u230B", lang: "\u2329", rang: "\u232A", loz: "\u25CA", spades: "\u2660", clubs: "\u2663", hearts: "\u2665", diams: "\u2666" }, Fe = _`jsx`({ AttributeIsEmpty: "JSX attributes must only be assigned a non-empty expression.", MissingClosingTagElement: (t3) => {
            let { openingTagName: r } = t3;
            return `Expected corresponding JSX closing tag for <${r}>.`;
          }, MissingClosingTagFragment: "Expected corresponding JSX closing tag for <>.", UnexpectedSequenceExpression: "Sequence expressions cannot be directly nested inside JSX. Did you mean to wrap it in parentheses (...)?", UnexpectedToken: (t3) => {
            let { unexpected: r, HTMLEntity: e } = t3;
            return `Unexpected token \`${r}\`. Did you mean \`${e}\` or \`{'${r}'}\`?`;
          }, UnsupportedJsxValue: "JSX value should be either an expression or a quoted JSX text.", UnterminatedJsxContent: "Unterminated JSX contents.", UnwrappedAdjacentJSXElements: "Adjacent JSX elements must be wrapped in an enclosing tag. Did you want a JSX fragment <>...</>?" });
          function we(t3) {
            return t3 ? t3.type === "JSXOpeningFragment" || t3.type === "JSXClosingFragment" : false;
          }
          function ze(t3) {
            if (t3.type === "JSXIdentifier")
              return t3.name;
            if (t3.type === "JSXNamespacedName")
              return t3.namespace.name + ":" + t3.name.name;
            if (t3.type === "JSXMemberExpression")
              return ze(t3.object) + "." + ze(t3.property);
            throw new Error("Node had unexpected type: " + t3.type);
          }
          var th = (t3) => class extends t3 {
            jsxReadToken() {
              let e = "", s = this.state.pos;
              for (; ; ) {
                if (this.state.pos >= this.length)
                  throw this.raise(Fe.UnterminatedJsxContent, { at: this.state.startLoc });
                let i = this.input.charCodeAt(this.state.pos);
                switch (i) {
                  case 60:
                  case 123:
                    return this.state.pos === this.state.start ? i === 60 && this.state.canStartJSXElement ? (++this.state.pos, this.finishToken(140)) : super.getTokenFromCode(i) : (e += this.input.slice(s, this.state.pos), this.finishToken(139, e));
                  case 38:
                    e += this.input.slice(s, this.state.pos), e += this.jsxReadEntity(), s = this.state.pos;
                    break;
                  case 62:
                  case 125:
                  default:
                    et(i) ? (e += this.input.slice(s, this.state.pos), e += this.jsxReadNewLine(true), s = this.state.pos) : ++this.state.pos;
                }
              }
            }
            jsxReadNewLine(e) {
              let s = this.input.charCodeAt(this.state.pos), i;
              return ++this.state.pos, s === 13 && this.input.charCodeAt(this.state.pos) === 10 ? (++this.state.pos, i = e ? `
` : `\r
`) : i = String.fromCharCode(s), ++this.state.curLine, this.state.lineStart = this.state.pos, i;
            }
            jsxReadString(e) {
              let s = "", i = ++this.state.pos;
              for (; ; ) {
                if (this.state.pos >= this.length)
                  throw this.raise(u.UnterminatedString, { at: this.state.startLoc });
                let a = this.input.charCodeAt(this.state.pos);
                if (a === e)
                  break;
                a === 38 ? (s += this.input.slice(i, this.state.pos), s += this.jsxReadEntity(), i = this.state.pos) : et(a) ? (s += this.input.slice(i, this.state.pos), s += this.jsxReadNewLine(false), i = this.state.pos) : ++this.state.pos;
              }
              return s += this.input.slice(i, this.state.pos++), this.finishToken(131, s);
            }
            jsxReadEntity() {
              let e = ++this.state.pos;
              if (this.codePointAtPos(this.state.pos) === 35) {
                ++this.state.pos;
                let s = 10;
                this.codePointAtPos(this.state.pos) === 120 && (s = 16, ++this.state.pos);
                let i = this.readInt(s, void 0, false, "bail");
                if (i !== null && this.codePointAtPos(this.state.pos) === 59)
                  return ++this.state.pos, String.fromCodePoint(i);
              } else {
                let s = 0, i = false;
                for (; s++ < 10 && this.state.pos < this.length && !(i = this.codePointAtPos(this.state.pos) == 59); )
                  ++this.state.pos;
                if (i) {
                  let a = this.input.slice(e, this.state.pos), n = eh[a];
                  if (++this.state.pos, n)
                    return n;
                }
              }
              return this.state.pos = e, "&";
            }
            jsxReadWord() {
              let e, s = this.state.pos;
              do
                e = this.input.charCodeAt(++this.state.pos);
              while (Re(e) || e === 45);
              return this.finishToken(138, this.input.slice(s, this.state.pos));
            }
            jsxParseIdentifier() {
              let e = this.startNode();
              return this.match(138) ? e.name = this.state.value : Yt(this.state.type) ? e.name = Ee(this.state.type) : this.unexpected(), this.next(), this.finishNode(e, "JSXIdentifier");
            }
            jsxParseNamespacedName() {
              let e = this.state.startLoc, s = this.jsxParseIdentifier();
              if (!this.eat(14))
                return s;
              let i = this.startNodeAt(e);
              return i.namespace = s, i.name = this.jsxParseIdentifier(), this.finishNode(i, "JSXNamespacedName");
            }
            jsxParseElementName() {
              let e = this.state.startLoc, s = this.jsxParseNamespacedName();
              if (s.type === "JSXNamespacedName")
                return s;
              for (; this.eat(16); ) {
                let i = this.startNodeAt(e);
                i.object = s, i.property = this.jsxParseIdentifier(), s = this.finishNode(i, "JSXMemberExpression");
              }
              return s;
            }
            jsxParseAttributeValue() {
              let e;
              switch (this.state.type) {
                case 5:
                  return e = this.startNode(), this.setContext($2.brace), this.next(), e = this.jsxParseExpressionContainer(e, $2.j_oTag), e.expression.type === "JSXEmptyExpression" && this.raise(Fe.AttributeIsEmpty, { at: e }), e;
                case 140:
                case 131:
                  return this.parseExprAtom();
                default:
                  throw this.raise(Fe.UnsupportedJsxValue, { at: this.state.startLoc });
              }
            }
            jsxParseEmptyExpression() {
              let e = this.startNodeAt(this.state.lastTokEndLoc);
              return this.finishNodeAt(e, "JSXEmptyExpression", this.state.startLoc);
            }
            jsxParseSpreadChild(e) {
              return this.next(), e.expression = this.parseExpression(), this.setContext($2.j_expr), this.state.canStartJSXElement = true, this.expect(8), this.finishNode(e, "JSXSpreadChild");
            }
            jsxParseExpressionContainer(e, s) {
              if (this.match(8))
                e.expression = this.jsxParseEmptyExpression();
              else {
                let i = this.parseExpression();
                e.expression = i;
              }
              return this.setContext(s), this.state.canStartJSXElement = true, this.expect(8), this.finishNode(e, "JSXExpressionContainer");
            }
            jsxParseAttribute() {
              let e = this.startNode();
              return this.match(5) ? (this.setContext($2.brace), this.next(), this.expect(21), e.argument = this.parseMaybeAssignAllowIn(), this.setContext($2.j_oTag), this.state.canStartJSXElement = true, this.expect(8), this.finishNode(e, "JSXSpreadAttribute")) : (e.name = this.jsxParseNamespacedName(), e.value = this.eat(29) ? this.jsxParseAttributeValue() : null, this.finishNode(e, "JSXAttribute"));
            }
            jsxParseOpeningElementAt(e) {
              let s = this.startNodeAt(e);
              return this.eat(141) ? this.finishNode(s, "JSXOpeningFragment") : (s.name = this.jsxParseElementName(), this.jsxParseOpeningElementAfterName(s));
            }
            jsxParseOpeningElementAfterName(e) {
              let s = [];
              for (; !this.match(56) && !this.match(141); )
                s.push(this.jsxParseAttribute());
              return e.attributes = s, e.selfClosing = this.eat(56), this.expect(141), this.finishNode(e, "JSXOpeningElement");
            }
            jsxParseClosingElementAt(e) {
              let s = this.startNodeAt(e);
              return this.eat(141) ? this.finishNode(s, "JSXClosingFragment") : (s.name = this.jsxParseElementName(), this.expect(141), this.finishNode(s, "JSXClosingElement"));
            }
            jsxParseElementAt(e) {
              let s = this.startNodeAt(e), i = [], a = this.jsxParseOpeningElementAt(e), n = null;
              if (!a.selfClosing) {
                e:
                  for (; ; )
                    switch (this.state.type) {
                      case 140:
                        if (e = this.state.startLoc, this.next(), this.eat(56)) {
                          n = this.jsxParseClosingElementAt(e);
                          break e;
                        }
                        i.push(this.jsxParseElementAt(e));
                        break;
                      case 139:
                        i.push(this.parseExprAtom());
                        break;
                      case 5: {
                        let o = this.startNode();
                        this.setContext($2.brace), this.next(), this.match(21) ? i.push(this.jsxParseSpreadChild(o)) : i.push(this.jsxParseExpressionContainer(o, $2.j_expr));
                        break;
                      }
                      default:
                        throw this.unexpected();
                    }
                we(a) && !we(n) && n !== null ? this.raise(Fe.MissingClosingTagFragment, { at: n }) : !we(a) && we(n) ? this.raise(Fe.MissingClosingTagElement, { at: n, openingTagName: ze(a.name) }) : !we(a) && !we(n) && ze(n.name) !== ze(a.name) && this.raise(Fe.MissingClosingTagElement, { at: n, openingTagName: ze(a.name) });
              }
              if (we(a) ? (s.openingFragment = a, s.closingFragment = n) : (s.openingElement = a, s.closingElement = n), s.children = i, this.match(47))
                throw this.raise(Fe.UnwrappedAdjacentJSXElements, { at: this.state.startLoc });
              return we(a) ? this.finishNode(s, "JSXFragment") : this.finishNode(s, "JSXElement");
            }
            jsxParseElement() {
              let e = this.state.startLoc;
              return this.next(), this.jsxParseElementAt(e);
            }
            setContext(e) {
              let { context: s } = this.state;
              s[s.length - 1] = e;
            }
            parseExprAtom(e) {
              return this.match(139) ? this.parseLiteral(this.state.value, "JSXText") : this.match(140) ? this.jsxParseElement() : this.match(47) && this.input.charCodeAt(this.state.pos) !== 33 ? (this.replaceToken(140), this.jsxParseElement()) : super.parseExprAtom(e);
            }
            skipSpace() {
              this.curContext().preserveSpace || super.skipSpace();
            }
            getTokenFromCode(e) {
              let s = this.curContext();
              if (s === $2.j_expr)
                return this.jsxReadToken();
              if (s === $2.j_oTag || s === $2.j_cTag) {
                if (ge(e))
                  return this.jsxReadWord();
                if (e === 62)
                  return ++this.state.pos, this.finishToken(141);
                if ((e === 34 || e === 39) && s === $2.j_oTag)
                  return this.jsxReadString(e);
              }
              return e === 60 && this.state.canStartJSXElement && this.input.charCodeAt(this.state.pos + 1) !== 33 ? (++this.state.pos, this.finishToken(140)) : super.getTokenFromCode(e);
            }
            updateContext(e) {
              let { context: s, type: i } = this.state;
              if (i === 56 && e === 140)
                s.splice(-2, 2, $2.j_cTag), this.state.canStartJSXElement = false;
              else if (i === 140)
                s.push($2.j_oTag);
              else if (i === 141) {
                let a = s[s.length - 1];
                a === $2.j_oTag && e === 56 || a === $2.j_cTag ? (s.pop(), this.state.canStartJSXElement = s[s.length - 1] === $2.j_expr) : (this.setContext($2.j_expr), this.state.canStartJSXElement = true);
              } else
                this.state.canStartJSXElement = Wo(i);
            }
          }, sh = class extends us {
            constructor() {
              super(...arguments), this.types = /* @__PURE__ */ new Set(), this.enums = /* @__PURE__ */ new Set(), this.constEnums = /* @__PURE__ */ new Set(), this.classes = /* @__PURE__ */ new Set(), this.exportOnlyBindings = /* @__PURE__ */ new Set();
            }
          }, rh = class extends cs {
            constructor() {
              super(...arguments), this.importsStack = [];
            }
            createScope(t3) {
              return this.importsStack.push(/* @__PURE__ */ new Set()), new sh(t3);
            }
            enter(t3) {
              t3 == Ue && this.importsStack.push(/* @__PURE__ */ new Set()), super.enter(t3);
            }
            exit() {
              let t3 = super.exit();
              return t3 == Ue && this.importsStack.pop(), t3;
            }
            hasImport(t3, r) {
              let e = this.importsStack.length;
              if (this.importsStack[e - 1].has(t3))
                return true;
              if (!r && e > 1) {
                for (let s = 0; s < e - 1; s++)
                  if (this.importsStack[s].has(t3))
                    return true;
              }
              return false;
            }
            declareName(t3, r, e) {
              if (r & Ye) {
                this.hasImport(t3, true) && this.parser.raise(u.VarRedeclaration, { at: e, identifierName: t3 }), this.importsStack[this.importsStack.length - 1].add(t3);
                return;
              }
              let s = this.currentScope();
              if (r & is) {
                this.maybeExportDefined(s, t3), s.exportOnlyBindings.add(t3);
                return;
              }
              super.declareName(t3, r, e), r & ke && (r & Ae || (this.checkRedeclarationInScope(s, t3, r, e), this.maybeExportDefined(s, t3)), s.types.add(t3)), r & ss && s.enums.add(t3), r & rs && s.constEnums.add(t3), r & yt && s.classes.add(t3);
            }
            isRedeclaredInScope(t3, r, e) {
              if (t3.enums.has(r)) {
                if (e & ss) {
                  let s = !!(e & rs), i = t3.constEnums.has(r);
                  return s !== i;
                }
                return true;
              }
              return e & yt && t3.classes.has(r) ? t3.lexical.has(r) ? !!(e & Ae) : false : e & ke && t3.types.has(r) ? true : super.isRedeclaredInScope(t3, r, e);
            }
            checkLocalExport(t3) {
              let { name: r } = t3;
              if (this.hasImport(r))
                return;
              let e = this.scopeStack.length;
              for (let s = e - 1; s >= 0; s--) {
                let i = this.scopeStack[s];
                if (i.types.has(r) || i.exportOnlyBindings.has(r))
                  return;
              }
              super.checkLocalExport(t3);
            }
          }, ih = (t3, r) => Object.hasOwnProperty.call(t3, r) && t3[r];
          function ah(t3) {
            if (t3 == null)
              throw new Error(`Unexpected ${t3} value.`);
            return t3;
          }
          function Jr(t3) {
            if (!t3)
              throw new Error("Assert fail");
          }
          var w = _`typescript`({ AbstractMethodHasImplementation: (t3) => {
            let { methodName: r } = t3;
            return `Method '${r}' cannot have an implementation because it is marked abstract.`;
          }, AbstractPropertyHasInitializer: (t3) => {
            let { propertyName: r } = t3;
            return `Property '${r}' cannot have an initializer because it is marked abstract.`;
          }, AccesorCannotDeclareThisParameter: "'get' and 'set' accessors cannot declare 'this' parameters.", AccesorCannotHaveTypeParameters: "An accessor cannot have type parameters.", AccessorCannotBeOptional: "An 'accessor' property cannot be declared optional.", ClassMethodHasDeclare: "Class methods cannot have the 'declare' modifier.", ClassMethodHasReadonly: "Class methods cannot have the 'readonly' modifier.", ConstInitiailizerMustBeStringOrNumericLiteralOrLiteralEnumReference: "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference.", ConstructorHasTypeParameters: "Type parameters cannot appear on a constructor declaration.", DeclareAccessor: (t3) => {
            let { kind: r } = t3;
            return `'declare' is not allowed in ${r}ters.`;
          }, DeclareClassFieldHasInitializer: "Initializers are not allowed in ambient contexts.", DeclareFunctionHasImplementation: "An implementation cannot be declared in ambient contexts.", DuplicateAccessibilityModifier: (t3) => {
            let { modifier: r } = t3;
            return "Accessibility modifier already seen.";
          }, DuplicateModifier: (t3) => {
            let { modifier: r } = t3;
            return `Duplicate modifier: '${r}'.`;
          }, EmptyHeritageClauseType: (t3) => {
            let { token: r } = t3;
            return `'${r}' list cannot be empty.`;
          }, EmptyTypeArguments: "Type argument list cannot be empty.", EmptyTypeParameters: "Type parameter list cannot be empty.", ExpectedAmbientAfterExportDeclare: "'export declare' must be followed by an ambient declaration.", ImportAliasHasImportType: "An import alias can not use 'import type'.", ImportReflectionHasImportType: "An `import module` declaration can not use `type` modifier", IncompatibleModifiers: (t3) => {
            let { modifiers: r } = t3;
            return `'${r[0]}' modifier cannot be used with '${r[1]}' modifier.`;
          }, IndexSignatureHasAbstract: "Index signatures cannot have the 'abstract' modifier.", IndexSignatureHasAccessibility: (t3) => {
            let { modifier: r } = t3;
            return `Index signatures cannot have an accessibility modifier ('${r}').`;
          }, IndexSignatureHasDeclare: "Index signatures cannot have the 'declare' modifier.", IndexSignatureHasOverride: "'override' modifier cannot appear on an index signature.", IndexSignatureHasStatic: "Index signatures cannot have the 'static' modifier.", InitializerNotAllowedInAmbientContext: "Initializers are not allowed in ambient contexts.", InvalidModifierOnTypeMember: (t3) => {
            let { modifier: r } = t3;
            return `'${r}' modifier cannot appear on a type member.`;
          }, InvalidModifierOnTypeParameter: (t3) => {
            let { modifier: r } = t3;
            return `'${r}' modifier cannot appear on a type parameter.`;
          }, InvalidModifierOnTypeParameterPositions: (t3) => {
            let { modifier: r } = t3;
            return `'${r}' modifier can only appear on a type parameter of a class, interface or type alias.`;
          }, InvalidModifiersOrder: (t3) => {
            let { orderedModifiers: r } = t3;
            return `'${r[0]}' modifier must precede '${r[1]}' modifier.`;
          }, InvalidPropertyAccessAfterInstantiationExpression: "Invalid property access after an instantiation expression. You can either wrap the instantiation expression in parentheses, or delete the type arguments.", InvalidTupleMemberLabel: "Tuple members must be labeled with a simple identifier.", MissingInterfaceName: "'interface' declarations must be followed by an identifier.", MixedLabeledAndUnlabeledElements: "Tuple members must all have names or all not have names.", NonAbstractClassHasAbstractMethod: "Abstract methods can only appear within an abstract class.", NonClassMethodPropertyHasAbstractModifer: "'abstract' modifier can only appear on a class, method, or property declaration.", OptionalTypeBeforeRequired: "A required element cannot follow an optional element.", OverrideNotInSubClass: "This member cannot have an 'override' modifier because its containing class does not extend another class.", PatternIsOptional: "A binding pattern parameter cannot be optional in an implementation signature.", PrivateElementHasAbstract: "Private elements cannot have the 'abstract' modifier.", PrivateElementHasAccessibility: (t3) => {
            let { modifier: r } = t3;
            return `Private elements cannot have an accessibility modifier ('${r}').`;
          }, ReadonlyForMethodSignature: "'readonly' modifier can only appear on a property declaration or index signature.", ReservedArrowTypeParam: "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma, as in `<T,>() => ...`.", ReservedTypeAssertion: "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead.", SetAccesorCannotHaveOptionalParameter: "A 'set' accessor cannot have an optional parameter.", SetAccesorCannotHaveRestParameter: "A 'set' accessor cannot have rest parameter.", SetAccesorCannotHaveReturnType: "A 'set' accessor cannot have a return type annotation.", SingleTypeParameterWithoutTrailingComma: (t3) => {
            let { typeParameterName: r } = t3;
            return `Single type parameter ${r} should have a trailing comma. Example usage: <${r},>.`;
          }, StaticBlockCannotHaveModifier: "Static class blocks cannot have any modifier.", TypeAnnotationAfterAssign: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.", TypeImportCannotSpecifyDefaultAndNamed: "A type-only import can specify a default import or named bindings, but not both.", TypeModifierIsUsedInTypeExports: "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement.", TypeModifierIsUsedInTypeImports: "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement.", UnexpectedParameterModifier: "A parameter property is only allowed in a constructor implementation.", UnexpectedReadonly: "'readonly' type modifier is only permitted on array and tuple literal types.", UnexpectedTypeAnnotation: "Did not expect a type annotation here.", UnexpectedTypeCastInParameter: "Unexpected type cast in parameter position.", UnsupportedImportTypeArgument: "Argument in a type import must be a string literal.", UnsupportedParameterPropertyKind: "A parameter property may not be declared using a binding pattern.", UnsupportedSignatureParameterKind: (t3) => {
            let { type: r } = t3;
            return `Name in a signature must be an Identifier, ObjectPattern or ArrayPattern, instead got ${r}.`;
          } });
          function nh(t3) {
            switch (t3) {
              case "any":
                return "TSAnyKeyword";
              case "boolean":
                return "TSBooleanKeyword";
              case "bigint":
                return "TSBigIntKeyword";
              case "never":
                return "TSNeverKeyword";
              case "number":
                return "TSNumberKeyword";
              case "object":
                return "TSObjectKeyword";
              case "string":
                return "TSStringKeyword";
              case "symbol":
                return "TSSymbolKeyword";
              case "undefined":
                return "TSUndefinedKeyword";
              case "unknown":
                return "TSUnknownKeyword";
              default:
                return;
            }
          }
          function Xr(t3) {
            return t3 === "private" || t3 === "public" || t3 === "protected";
          }
          function oh(t3) {
            return t3 === "in" || t3 === "out";
          }
          var lh = (t3) => class extends t3 {
            getScopeHandler() {
              return rh;
            }
            tsIsIdentifier() {
              return z(this.state.type);
            }
            tsTokenCanFollowModifier() {
              return (this.match(0) || this.match(5) || this.match(55) || this.match(21) || this.match(136) || this.isLiteralPropertyName()) && !this.hasPrecedingLineBreak();
            }
            tsNextTokenCanFollowModifier() {
              return this.next(), this.tsTokenCanFollowModifier();
            }
            tsParseModifier(e, s) {
              if (!z(this.state.type) && this.state.type !== 58)
                return;
              let i = this.state.value;
              if (e.indexOf(i) !== -1) {
                if (s && this.tsIsStartOfStaticBlocks())
                  return;
                if (this.tsTryParse(this.tsNextTokenCanFollowModifier.bind(this)))
                  return i;
              }
            }
            tsParseModifiers(e) {
              let { modified: s, allowedModifiers: i, disallowedModifiers: a, stopOnStartOfClassStaticBlock: n, errorTemplate: o = w.InvalidModifierOnTypeMember } = e, c = (m, x, A, b) => {
                x === A && s[b] && this.raise(w.InvalidModifiersOrder, { at: m, orderedModifiers: [A, b] });
              }, p = (m, x, A, b) => {
                (s[A] && x === b || s[b] && x === A) && this.raise(w.IncompatibleModifiers, { at: m, modifiers: [A, b] });
              };
              for (; ; ) {
                let { startLoc: m } = this.state, x = this.tsParseModifier(i.concat(a != null ? a : []), n);
                if (!x)
                  break;
                Xr(x) ? s.accessibility ? this.raise(w.DuplicateAccessibilityModifier, { at: m, modifier: x }) : (c(m, x, x, "override"), c(m, x, x, "static"), c(m, x, x, "readonly"), s.accessibility = x) : oh(x) ? (s[x] && this.raise(w.DuplicateModifier, { at: m, modifier: x }), s[x] = true, c(m, x, "in", "out")) : (Object.hasOwnProperty.call(s, x) ? this.raise(w.DuplicateModifier, { at: m, modifier: x }) : (c(m, x, "static", "readonly"), c(m, x, "static", "override"), c(m, x, "override", "readonly"), c(m, x, "abstract", "override"), p(m, x, "declare", "override"), p(m, x, "static", "abstract")), s[x] = true), a != null && a.includes(x) && this.raise(o, { at: m, modifier: x });
              }
            }
            tsIsListTerminator(e) {
              switch (e) {
                case "EnumMembers":
                case "TypeMembers":
                  return this.match(8);
                case "HeritageClauseElement":
                  return this.match(5);
                case "TupleElementTypes":
                  return this.match(3);
                case "TypeParametersOrArguments":
                  return this.match(48);
              }
              throw new Error("Unreachable");
            }
            tsParseList(e, s) {
              let i = [];
              for (; !this.tsIsListTerminator(e); )
                i.push(s());
              return i;
            }
            tsParseDelimitedList(e, s, i) {
              return ah(this.tsParseDelimitedListWorker(e, s, true, i));
            }
            tsParseDelimitedListWorker(e, s, i, a) {
              let n = [], o = -1;
              for (; !this.tsIsListTerminator(e); ) {
                o = -1;
                let c = s();
                if (c == null)
                  return;
                if (n.push(c), this.eat(12)) {
                  o = this.state.lastTokStart;
                  continue;
                }
                if (this.tsIsListTerminator(e))
                  break;
                i && this.expect(12);
                return;
              }
              return a && (a.value = o), n;
            }
            tsParseBracketedList(e, s, i, a, n) {
              a || (i ? this.expect(0) : this.expect(47));
              let o = this.tsParseDelimitedList(e, s, n);
              return i ? this.expect(3) : this.expect(48), o;
            }
            tsParseImportType() {
              let e = this.startNode();
              return this.expect(83), this.expect(10), this.match(131) || this.raise(w.UnsupportedImportTypeArgument, { at: this.state.startLoc }), e.argument = super.parseExprAtom(), this.expect(11), this.eat(16) && (e.qualifier = this.tsParseEntityName()), this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSImportType");
            }
            tsParseEntityName() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : true, s = this.parseIdentifier(e);
              for (; this.eat(16); ) {
                let i = this.startNodeAtNode(s);
                i.left = s, i.right = this.parseIdentifier(e), s = this.finishNode(i, "TSQualifiedName");
              }
              return s;
            }
            tsParseTypeReference() {
              let e = this.startNode();
              return e.typeName = this.tsParseEntityName(), !this.hasPrecedingLineBreak() && this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSTypeReference");
            }
            tsParseThisTypePredicate(e) {
              this.next();
              let s = this.startNodeAtNode(e);
              return s.parameterName = e, s.typeAnnotation = this.tsParseTypeAnnotation(false), s.asserts = false, this.finishNode(s, "TSTypePredicate");
            }
            tsParseThisTypeNode() {
              let e = this.startNode();
              return this.next(), this.finishNode(e, "TSThisType");
            }
            tsParseTypeQuery() {
              let e = this.startNode();
              return this.expect(87), this.match(83) ? e.exprName = this.tsParseImportType() : e.exprName = this.tsParseEntityName(), !this.hasPrecedingLineBreak() && this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSTypeQuery");
            }
            tsParseInOutModifiers(e) {
              this.tsParseModifiers({ modified: e, allowedModifiers: ["in", "out"], disallowedModifiers: ["public", "private", "protected", "readonly", "declare", "abstract", "override"], errorTemplate: w.InvalidModifierOnTypeParameter });
            }
            tsParseNoneModifiers(e) {
              this.tsParseModifiers({ modified: e, allowedModifiers: [], disallowedModifiers: ["in", "out"], errorTemplate: w.InvalidModifierOnTypeParameterPositions });
            }
            tsParseTypeParameter() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : this.tsParseNoneModifiers.bind(this), s = this.startNode();
              return e(s), s.name = this.tsParseTypeParameterName(), s.constraint = this.tsEatThenParseType(81), s.default = this.tsEatThenParseType(29), this.finishNode(s, "TSTypeParameter");
            }
            tsTryParseTypeParameters(e) {
              if (this.match(47))
                return this.tsParseTypeParameters(e);
            }
            tsParseTypeParameters(e) {
              let s = this.startNode();
              this.match(47) || this.match(140) ? this.next() : this.unexpected();
              let i = { value: -1 };
              return s.params = this.tsParseBracketedList("TypeParametersOrArguments", this.tsParseTypeParameter.bind(this, e), false, true, i), s.params.length === 0 && this.raise(w.EmptyTypeParameters, { at: s }), i.value !== -1 && this.addExtra(s, "trailingComma", i.value), this.finishNode(s, "TSTypeParameterDeclaration");
            }
            tsFillSignature(e, s) {
              let i = e === 19, a = "parameters", n = "typeAnnotation";
              s.typeParameters = this.tsTryParseTypeParameters(), this.expect(10), s[a] = this.tsParseBindingListForSignature(), i ? s[n] = this.tsParseTypeOrTypePredicateAnnotation(e) : this.match(e) && (s[n] = this.tsParseTypeOrTypePredicateAnnotation(e));
            }
            tsParseBindingListForSignature() {
              return super.parseBindingList(11, 41).map((e) => (e.type !== "Identifier" && e.type !== "RestElement" && e.type !== "ObjectPattern" && e.type !== "ArrayPattern" && this.raise(w.UnsupportedSignatureParameterKind, { at: e, type: e.type }), e));
            }
            tsParseTypeMemberSemicolon() {
              !this.eat(12) && !this.isLineTerminator() && this.expect(13);
            }
            tsParseSignatureMember(e, s) {
              return this.tsFillSignature(14, s), this.tsParseTypeMemberSemicolon(), this.finishNode(s, e);
            }
            tsIsUnambiguouslyIndexSignature() {
              return this.next(), z(this.state.type) ? (this.next(), this.match(14)) : false;
            }
            tsTryParseIndexSignature(e) {
              if (!(this.match(0) && this.tsLookAhead(this.tsIsUnambiguouslyIndexSignature.bind(this))))
                return;
              this.expect(0);
              let s = this.parseIdentifier();
              s.typeAnnotation = this.tsParseTypeAnnotation(), this.resetEndLocation(s), this.expect(3), e.parameters = [s];
              let i = this.tsTryParseTypeAnnotation();
              return i && (e.typeAnnotation = i), this.tsParseTypeMemberSemicolon(), this.finishNode(e, "TSIndexSignature");
            }
            tsParsePropertyOrMethodSignature(e, s) {
              this.eat(17) && (e.optional = true);
              let i = e;
              if (this.match(10) || this.match(47)) {
                s && this.raise(w.ReadonlyForMethodSignature, { at: e });
                let a = i;
                a.kind && this.match(47) && this.raise(w.AccesorCannotHaveTypeParameters, { at: this.state.curPosition() }), this.tsFillSignature(14, a), this.tsParseTypeMemberSemicolon();
                let n = "parameters", o = "typeAnnotation";
                if (a.kind === "get")
                  a[n].length > 0 && (this.raise(u.BadGetterArity, { at: this.state.curPosition() }), this.isThisParam(a[n][0]) && this.raise(w.AccesorCannotDeclareThisParameter, { at: this.state.curPosition() }));
                else if (a.kind === "set") {
                  if (a[n].length !== 1)
                    this.raise(u.BadSetterArity, { at: this.state.curPosition() });
                  else {
                    let c = a[n][0];
                    this.isThisParam(c) && this.raise(w.AccesorCannotDeclareThisParameter, { at: this.state.curPosition() }), c.type === "Identifier" && c.optional && this.raise(w.SetAccesorCannotHaveOptionalParameter, { at: this.state.curPosition() }), c.type === "RestElement" && this.raise(w.SetAccesorCannotHaveRestParameter, { at: this.state.curPosition() });
                  }
                  a[o] && this.raise(w.SetAccesorCannotHaveReturnType, { at: a[o] });
                } else
                  a.kind = "method";
                return this.finishNode(a, "TSMethodSignature");
              } else {
                let a = i;
                s && (a.readonly = true);
                let n = this.tsTryParseTypeAnnotation();
                return n && (a.typeAnnotation = n), this.tsParseTypeMemberSemicolon(), this.finishNode(a, "TSPropertySignature");
              }
            }
            tsParseTypeMember() {
              let e = this.startNode();
              if (this.match(10) || this.match(47))
                return this.tsParseSignatureMember("TSCallSignatureDeclaration", e);
              if (this.match(77)) {
                let i = this.startNode();
                return this.next(), this.match(10) || this.match(47) ? this.tsParseSignatureMember("TSConstructSignatureDeclaration", e) : (e.key = this.createIdentifier(i, "new"), this.tsParsePropertyOrMethodSignature(e, false));
              }
              this.tsParseModifiers({ modified: e, allowedModifiers: ["readonly"], disallowedModifiers: ["declare", "abstract", "private", "protected", "public", "static", "override"] });
              let s = this.tsTryParseIndexSignature(e);
              return s || (super.parsePropertyName(e), !e.computed && e.key.type === "Identifier" && (e.key.name === "get" || e.key.name === "set") && this.tsTokenCanFollowModifier() && (e.kind = e.key.name, super.parsePropertyName(e)), this.tsParsePropertyOrMethodSignature(e, !!e.readonly));
            }
            tsParseTypeLiteral() {
              let e = this.startNode();
              return e.members = this.tsParseObjectTypeMembers(), this.finishNode(e, "TSTypeLiteral");
            }
            tsParseObjectTypeMembers() {
              this.expect(5);
              let e = this.tsParseList("TypeMembers", this.tsParseTypeMember.bind(this));
              return this.expect(8), e;
            }
            tsIsStartOfMappedType() {
              return this.next(), this.eat(53) ? this.isContextual(120) : (this.isContextual(120) && this.next(), !this.match(0) || (this.next(), !this.tsIsIdentifier()) ? false : (this.next(), this.match(58)));
            }
            tsParseMappedTypeParameter() {
              let e = this.startNode();
              return e.name = this.tsParseTypeParameterName(), e.constraint = this.tsExpectThenParseType(58), this.finishNode(e, "TSTypeParameter");
            }
            tsParseMappedType() {
              let e = this.startNode();
              return this.expect(5), this.match(53) ? (e.readonly = this.state.value, this.next(), this.expectContextual(120)) : this.eatContextual(120) && (e.readonly = true), this.expect(0), e.typeParameter = this.tsParseMappedTypeParameter(), e.nameType = this.eatContextual(93) ? this.tsParseType() : null, this.expect(3), this.match(53) ? (e.optional = this.state.value, this.next(), this.expect(17)) : this.eat(17) && (e.optional = true), e.typeAnnotation = this.tsTryParseType(), this.semicolon(), this.expect(8), this.finishNode(e, "TSMappedType");
            }
            tsParseTupleType() {
              let e = this.startNode();
              e.elementTypes = this.tsParseBracketedList("TupleElementTypes", this.tsParseTupleElementType.bind(this), true, false);
              let s = false, i = null;
              return e.elementTypes.forEach((a) => {
                var n;
                let { type: o } = a;
                s && o !== "TSRestType" && o !== "TSOptionalType" && !(o === "TSNamedTupleMember" && a.optional) && this.raise(w.OptionalTypeBeforeRequired, { at: a }), s || (s = o === "TSNamedTupleMember" && a.optional || o === "TSOptionalType");
                let c = o;
                o === "TSRestType" && (a = a.typeAnnotation, c = a.type);
                let p = c === "TSNamedTupleMember";
                (n = i) != null || (i = p), i !== p && this.raise(w.MixedLabeledAndUnlabeledElements, { at: a });
              }), this.finishNode(e, "TSTupleType");
            }
            tsParseTupleElementType() {
              let { startLoc: e } = this.state, s = this.eat(21), i = this.tsParseType(), a = this.eat(17);
              if (this.eat(14)) {
                let o = this.startNodeAtNode(i);
                o.optional = a, i.type === "TSTypeReference" && !i.typeParameters && i.typeName.type === "Identifier" ? o.label = i.typeName : (this.raise(w.InvalidTupleMemberLabel, { at: i }), o.label = i), o.elementType = this.tsParseType(), i = this.finishNode(o, "TSNamedTupleMember");
              } else if (a) {
                let o = this.startNodeAtNode(i);
                o.typeAnnotation = i, i = this.finishNode(o, "TSOptionalType");
              }
              if (s) {
                let o = this.startNodeAt(e);
                o.typeAnnotation = i, i = this.finishNode(o, "TSRestType");
              }
              return i;
            }
            tsParseParenthesizedType() {
              let e = this.startNode();
              return this.expect(10), e.typeAnnotation = this.tsParseType(), this.expect(11), this.finishNode(e, "TSParenthesizedType");
            }
            tsParseFunctionOrConstructorType(e, s) {
              let i = this.startNode();
              return e === "TSConstructorType" && (i.abstract = !!s, s && this.next(), this.next()), this.tsInAllowConditionalTypesContext(() => this.tsFillSignature(19, i)), this.finishNode(i, e);
            }
            tsParseLiteralTypeNode() {
              let e = this.startNode();
              return e.literal = (() => {
                switch (this.state.type) {
                  case 132:
                  case 133:
                  case 131:
                  case 85:
                  case 86:
                    return super.parseExprAtom();
                  default:
                    throw this.unexpected();
                }
              })(), this.finishNode(e, "TSLiteralType");
            }
            tsParseTemplateLiteralType() {
              let e = this.startNode();
              return e.literal = super.parseTemplate(false), this.finishNode(e, "TSLiteralType");
            }
            parseTemplateSubstitution() {
              return this.state.inType ? this.tsParseType() : super.parseTemplateSubstitution();
            }
            tsParseThisTypeOrThisTypePredicate() {
              let e = this.tsParseThisTypeNode();
              return this.isContextual(114) && !this.hasPrecedingLineBreak() ? this.tsParseThisTypePredicate(e) : e;
            }
            tsParseNonArrayType() {
              switch (this.state.type) {
                case 131:
                case 132:
                case 133:
                case 85:
                case 86:
                  return this.tsParseLiteralTypeNode();
                case 53:
                  if (this.state.value === "-") {
                    let e = this.startNode(), s = this.lookahead();
                    if (s.type !== 132 && s.type !== 133)
                      throw this.unexpected();
                    return e.literal = this.parseMaybeUnary(), this.finishNode(e, "TSLiteralType");
                  }
                  break;
                case 78:
                  return this.tsParseThisTypeOrThisTypePredicate();
                case 87:
                  return this.tsParseTypeQuery();
                case 83:
                  return this.tsParseImportType();
                case 5:
                  return this.tsLookAhead(this.tsIsStartOfMappedType.bind(this)) ? this.tsParseMappedType() : this.tsParseTypeLiteral();
                case 0:
                  return this.tsParseTupleType();
                case 10:
                  return this.tsParseParenthesizedType();
                case 25:
                case 24:
                  return this.tsParseTemplateLiteralType();
                default: {
                  let { type: e } = this.state;
                  if (z(e) || e === 88 || e === 84) {
                    let s = e === 88 ? "TSVoidKeyword" : e === 84 ? "TSNullKeyword" : nh(this.state.value);
                    if (s !== void 0 && this.lookaheadCharCode() !== 46) {
                      let i = this.startNode();
                      return this.next(), this.finishNode(i, s);
                    }
                    return this.tsParseTypeReference();
                  }
                }
              }
              throw this.unexpected();
            }
            tsParseArrayTypeOrHigher() {
              let e = this.tsParseNonArrayType();
              for (; !this.hasPrecedingLineBreak() && this.eat(0); )
                if (this.match(3)) {
                  let s = this.startNodeAtNode(e);
                  s.elementType = e, this.expect(3), e = this.finishNode(s, "TSArrayType");
                } else {
                  let s = this.startNodeAtNode(e);
                  s.objectType = e, s.indexType = this.tsParseType(), this.expect(3), e = this.finishNode(s, "TSIndexedAccessType");
                }
              return e;
            }
            tsParseTypeOperator() {
              let e = this.startNode(), s = this.state.value;
              return this.next(), e.operator = s, e.typeAnnotation = this.tsParseTypeOperatorOrHigher(), s === "readonly" && this.tsCheckTypeAnnotationForReadOnly(e), this.finishNode(e, "TSTypeOperator");
            }
            tsCheckTypeAnnotationForReadOnly(e) {
              switch (e.typeAnnotation.type) {
                case "TSTupleType":
                case "TSArrayType":
                  return;
                default:
                  this.raise(w.UnexpectedReadonly, { at: e });
              }
            }
            tsParseInferType() {
              let e = this.startNode();
              this.expectContextual(113);
              let s = this.startNode();
              return s.name = this.tsParseTypeParameterName(), s.constraint = this.tsTryParse(() => this.tsParseConstraintForInferType()), e.typeParameter = this.finishNode(s, "TSTypeParameter"), this.finishNode(e, "TSInferType");
            }
            tsParseConstraintForInferType() {
              if (this.eat(81)) {
                let e = this.tsInDisallowConditionalTypesContext(() => this.tsParseType());
                if (this.state.inDisallowConditionalTypesContext || !this.match(17))
                  return e;
              }
            }
            tsParseTypeOperatorOrHigher() {
              return Zo(this.state.type) && !this.state.containsEsc ? this.tsParseTypeOperator() : this.isContextual(113) ? this.tsParseInferType() : this.tsInAllowConditionalTypesContext(() => this.tsParseArrayTypeOrHigher());
            }
            tsParseUnionOrIntersectionType(e, s, i) {
              let a = this.startNode(), n = this.eat(i), o = [];
              do
                o.push(s());
              while (this.eat(i));
              return o.length === 1 && !n ? o[0] : (a.types = o, this.finishNode(a, e));
            }
            tsParseIntersectionTypeOrHigher() {
              return this.tsParseUnionOrIntersectionType("TSIntersectionType", this.tsParseTypeOperatorOrHigher.bind(this), 45);
            }
            tsParseUnionTypeOrHigher() {
              return this.tsParseUnionOrIntersectionType("TSUnionType", this.tsParseIntersectionTypeOrHigher.bind(this), 43);
            }
            tsIsStartOfFunctionType() {
              return this.match(47) ? true : this.match(10) && this.tsLookAhead(this.tsIsUnambiguouslyStartOfFunctionType.bind(this));
            }
            tsSkipParameterStart() {
              if (z(this.state.type) || this.match(78))
                return this.next(), true;
              if (this.match(5)) {
                let { errors: e } = this.state, s = e.length;
                try {
                  return this.parseObjectLike(8, true), e.length === s;
                } catch {
                  return false;
                }
              }
              if (this.match(0)) {
                this.next();
                let { errors: e } = this.state, s = e.length;
                try {
                  return super.parseBindingList(3, 93, true), e.length === s;
                } catch {
                  return false;
                }
              }
              return false;
            }
            tsIsUnambiguouslyStartOfFunctionType() {
              return this.next(), !!(this.match(11) || this.match(21) || this.tsSkipParameterStart() && (this.match(14) || this.match(12) || this.match(17) || this.match(29) || this.match(11) && (this.next(), this.match(19))));
            }
            tsParseTypeOrTypePredicateAnnotation(e) {
              return this.tsInType(() => {
                let s = this.startNode();
                this.expect(e);
                let i = this.startNode(), a = !!this.tsTryParse(this.tsParseTypePredicateAsserts.bind(this));
                if (a && this.match(78)) {
                  let c = this.tsParseThisTypeOrThisTypePredicate();
                  return c.type === "TSThisType" ? (i.parameterName = c, i.asserts = true, i.typeAnnotation = null, c = this.finishNode(i, "TSTypePredicate")) : (this.resetStartLocationFromNode(c, i), c.asserts = true), s.typeAnnotation = c, this.finishNode(s, "TSTypeAnnotation");
                }
                let n = this.tsIsIdentifier() && this.tsTryParse(this.tsParseTypePredicatePrefix.bind(this));
                if (!n)
                  return a ? (i.parameterName = this.parseIdentifier(), i.asserts = a, i.typeAnnotation = null, s.typeAnnotation = this.finishNode(i, "TSTypePredicate"), this.finishNode(s, "TSTypeAnnotation")) : this.tsParseTypeAnnotation(false, s);
                let o = this.tsParseTypeAnnotation(false);
                return i.parameterName = n, i.typeAnnotation = o, i.asserts = a, s.typeAnnotation = this.finishNode(i, "TSTypePredicate"), this.finishNode(s, "TSTypeAnnotation");
              });
            }
            tsTryParseTypeOrTypePredicateAnnotation() {
              return this.match(14) ? this.tsParseTypeOrTypePredicateAnnotation(14) : void 0;
            }
            tsTryParseTypeAnnotation() {
              return this.match(14) ? this.tsParseTypeAnnotation() : void 0;
            }
            tsTryParseType() {
              return this.tsEatThenParseType(14);
            }
            tsParseTypePredicatePrefix() {
              let e = this.parseIdentifier();
              if (this.isContextual(114) && !this.hasPrecedingLineBreak())
                return this.next(), e;
            }
            tsParseTypePredicateAsserts() {
              if (this.state.type !== 107)
                return false;
              let e = this.state.containsEsc;
              return this.next(), !z(this.state.type) && !this.match(78) ? false : (e && this.raise(u.InvalidEscapedReservedWord, { at: this.state.lastTokStartLoc, reservedWord: "asserts" }), true);
            }
            tsParseTypeAnnotation() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : true, s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this.startNode();
              return this.tsInType(() => {
                e && this.expect(14), s.typeAnnotation = this.tsParseType();
              }), this.finishNode(s, "TSTypeAnnotation");
            }
            tsParseType() {
              Jr(this.state.inType);
              let e = this.tsParseNonConditionalType();
              if (this.state.inDisallowConditionalTypesContext || this.hasPrecedingLineBreak() || !this.eat(81))
                return e;
              let s = this.startNodeAtNode(e);
              return s.checkType = e, s.extendsType = this.tsInDisallowConditionalTypesContext(() => this.tsParseNonConditionalType()), this.expect(17), s.trueType = this.tsInAllowConditionalTypesContext(() => this.tsParseType()), this.expect(14), s.falseType = this.tsInAllowConditionalTypesContext(() => this.tsParseType()), this.finishNode(s, "TSConditionalType");
            }
            isAbstractConstructorSignature() {
              return this.isContextual(122) && this.lookahead().type === 77;
            }
            tsParseNonConditionalType() {
              return this.tsIsStartOfFunctionType() ? this.tsParseFunctionOrConstructorType("TSFunctionType") : this.match(77) ? this.tsParseFunctionOrConstructorType("TSConstructorType") : this.isAbstractConstructorSignature() ? this.tsParseFunctionOrConstructorType("TSConstructorType", true) : this.tsParseUnionTypeOrHigher();
            }
            tsParseTypeAssertion() {
              this.getPluginOption("typescript", "disallowAmbiguousJSXLike") && this.raise(w.ReservedTypeAssertion, { at: this.state.startLoc });
              let e = this.startNode();
              return e.typeAnnotation = this.tsInType(() => (this.next(), this.match(75) ? this.tsParseTypeReference() : this.tsParseType())), this.expect(48), e.expression = this.parseMaybeUnary(), this.finishNode(e, "TSTypeAssertion");
            }
            tsParseHeritageClause(e) {
              let s = this.state.startLoc, i = this.tsParseDelimitedList("HeritageClauseElement", () => {
                let a = this.startNode();
                return a.expression = this.tsParseEntityName(), this.match(47) && (a.typeParameters = this.tsParseTypeArguments()), this.finishNode(a, "TSExpressionWithTypeArguments");
              });
              return i.length || this.raise(w.EmptyHeritageClauseType, { at: s, token: e }), i;
            }
            tsParseInterfaceDeclaration(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
              if (this.hasFollowingLineBreak())
                return null;
              this.expectContextual(127), s.declare && (e.declare = true), z(this.state.type) ? (e.id = this.parseIdentifier(), this.checkIdentifier(e.id, pl)) : (e.id = null, this.raise(w.MissingInterfaceName, { at: this.state.startLoc })), e.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this)), this.eat(81) && (e.extends = this.tsParseHeritageClause("extends"));
              let i = this.startNode();
              return i.body = this.tsInType(this.tsParseObjectTypeMembers.bind(this)), e.body = this.finishNode(i, "TSInterfaceBody"), this.finishNode(e, "TSInterfaceDeclaration");
            }
            tsParseTypeAliasDeclaration(e) {
              return e.id = this.parseIdentifier(), this.checkIdentifier(e.id, fl), e.typeAnnotation = this.tsInType(() => {
                if (e.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this)), this.expect(29), this.isContextual(112) && this.lookahead().type !== 16) {
                  let s = this.startNode();
                  return this.next(), this.finishNode(s, "TSIntrinsicKeyword");
                }
                return this.tsParseType();
              }), this.semicolon(), this.finishNode(e, "TSTypeAliasDeclaration");
            }
            tsInNoContext(e) {
              let s = this.state.context;
              this.state.context = [s[0]];
              try {
                return e();
              } finally {
                this.state.context = s;
              }
            }
            tsInType(e) {
              let s = this.state.inType;
              this.state.inType = true;
              try {
                return e();
              } finally {
                this.state.inType = s;
              }
            }
            tsInDisallowConditionalTypesContext(e) {
              let s = this.state.inDisallowConditionalTypesContext;
              this.state.inDisallowConditionalTypesContext = true;
              try {
                return e();
              } finally {
                this.state.inDisallowConditionalTypesContext = s;
              }
            }
            tsInAllowConditionalTypesContext(e) {
              let s = this.state.inDisallowConditionalTypesContext;
              this.state.inDisallowConditionalTypesContext = false;
              try {
                return e();
              } finally {
                this.state.inDisallowConditionalTypesContext = s;
              }
            }
            tsEatThenParseType(e) {
              return this.match(e) ? this.tsNextThenParseType() : void 0;
            }
            tsExpectThenParseType(e) {
              return this.tsDoThenParseType(() => this.expect(e));
            }
            tsNextThenParseType() {
              return this.tsDoThenParseType(() => this.next());
            }
            tsDoThenParseType(e) {
              return this.tsInType(() => (e(), this.tsParseType()));
            }
            tsParseEnumMember() {
              let e = this.startNode();
              return e.id = this.match(131) ? super.parseStringLiteral(this.state.value) : this.parseIdentifier(true), this.eat(29) && (e.initializer = super.parseMaybeAssignAllowIn()), this.finishNode(e, "TSEnumMember");
            }
            tsParseEnumDeclaration(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
              return s.const && (e.const = true), s.declare && (e.declare = true), this.expectContextual(124), e.id = this.parseIdentifier(), this.checkIdentifier(e.id, e.const ? ml : Fr), this.expect(5), e.members = this.tsParseDelimitedList("EnumMembers", this.tsParseEnumMember.bind(this)), this.expect(8), this.finishNode(e, "TSEnumDeclaration");
            }
            tsParseModuleBlock() {
              let e = this.startNode();
              return this.scope.enter(je), this.expect(5), super.parseBlockOrModuleBlockBody(e.body = [], void 0, true, 8), this.scope.exit(), this.finishNode(e, "TSModuleBlock");
            }
            tsParseModuleOrNamespaceDeclaration(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              if (e.id = this.parseIdentifier(), s || this.checkIdentifier(e.id, yl), this.eat(16)) {
                let i = this.startNode();
                this.tsParseModuleOrNamespaceDeclaration(i, true), e.body = i;
              } else
                this.scope.enter(Ue), this.prodParam.enter($e), e.body = this.tsParseModuleBlock(), this.prodParam.exit(), this.scope.exit();
              return this.finishNode(e, "TSModuleDeclaration");
            }
            tsParseAmbientExternalModuleDeclaration(e) {
              return this.isContextual(110) ? (e.global = true, e.id = this.parseIdentifier()) : this.match(131) ? e.id = super.parseStringLiteral(this.state.value) : this.unexpected(), this.match(5) ? (this.scope.enter(Ue), this.prodParam.enter($e), e.body = this.tsParseModuleBlock(), this.prodParam.exit(), this.scope.exit()) : this.semicolon(), this.finishNode(e, "TSModuleDeclaration");
            }
            tsParseImportEqualsDeclaration(e, s) {
              e.isExport = s || false, e.id = this.parseIdentifier(), this.checkIdentifier(e.id, Ye), this.expect(29);
              let i = this.tsParseModuleReference();
              return e.importKind === "type" && i.type !== "TSExternalModuleReference" && this.raise(w.ImportAliasHasImportType, { at: i }), e.moduleReference = i, this.semicolon(), this.finishNode(e, "TSImportEqualsDeclaration");
            }
            tsIsExternalModuleReference() {
              return this.isContextual(117) && this.lookaheadCharCode() === 40;
            }
            tsParseModuleReference() {
              return this.tsIsExternalModuleReference() ? this.tsParseExternalModuleReference() : this.tsParseEntityName(false);
            }
            tsParseExternalModuleReference() {
              let e = this.startNode();
              if (this.expectContextual(117), this.expect(10), !this.match(131))
                throw this.unexpected();
              return e.expression = super.parseExprAtom(), this.expect(11), this.finishNode(e, "TSExternalModuleReference");
            }
            tsLookAhead(e) {
              let s = this.state.clone(), i = e();
              return this.state = s, i;
            }
            tsTryParseAndCatch(e) {
              let s = this.tryParse((i) => e() || i());
              if (!(s.aborted || !s.node))
                return s.error && (this.state = s.failState), s.node;
            }
            tsTryParse(e) {
              let s = this.state.clone(), i = e();
              if (i !== void 0 && i !== false)
                return i;
              this.state = s;
            }
            tsTryParseDeclare(e) {
              if (this.isLineTerminator())
                return;
              let s = this.state.type, i;
              return this.isContextual(99) && (s = 74, i = "let"), this.tsInAmbientContext(() => {
                if (s === 68)
                  return e.declare = true, super.parseFunctionStatement(e, false, false);
                if (s === 80)
                  return e.declare = true, this.parseClass(e, true, false);
                if (s === 124)
                  return this.tsParseEnumDeclaration(e, { declare: true });
                if (s === 110)
                  return this.tsParseAmbientExternalModuleDeclaration(e);
                if (s === 75 || s === 74)
                  return !this.match(75) || !this.isLookaheadContextual("enum") ? (e.declare = true, this.parseVarStatement(e, i || this.state.value, true)) : (this.expect(75), this.tsParseEnumDeclaration(e, { const: true, declare: true }));
                if (s === 127) {
                  let a = this.tsParseInterfaceDeclaration(e, { declare: true });
                  if (a)
                    return a;
                }
                if (z(s))
                  return this.tsParseDeclaration(e, this.state.value, true, null);
              });
            }
            tsTryParseExportDeclaration() {
              return this.tsParseDeclaration(this.startNode(), this.state.value, true, null);
            }
            tsParseExpressionStatement(e, s, i) {
              switch (s.name) {
                case "declare": {
                  let a = this.tsTryParseDeclare(e);
                  if (a)
                    return a.declare = true, a;
                  break;
                }
                case "global":
                  if (this.match(5)) {
                    this.scope.enter(Ue), this.prodParam.enter($e);
                    let a = e;
                    return a.global = true, a.id = s, a.body = this.tsParseModuleBlock(), this.scope.exit(), this.prodParam.exit(), this.finishNode(a, "TSModuleDeclaration");
                  }
                  break;
                default:
                  return this.tsParseDeclaration(e, s.name, false, i);
              }
            }
            tsParseDeclaration(e, s, i, a) {
              switch (s) {
                case "abstract":
                  if (this.tsCheckLineTerminator(i) && (this.match(80) || z(this.state.type)))
                    return this.tsParseAbstractDeclaration(e, a);
                  break;
                case "module":
                  if (this.tsCheckLineTerminator(i)) {
                    if (this.match(131))
                      return this.tsParseAmbientExternalModuleDeclaration(e);
                    if (z(this.state.type))
                      return this.tsParseModuleOrNamespaceDeclaration(e);
                  }
                  break;
                case "namespace":
                  if (this.tsCheckLineTerminator(i) && z(this.state.type))
                    return this.tsParseModuleOrNamespaceDeclaration(e);
                  break;
                case "type":
                  if (this.tsCheckLineTerminator(i) && z(this.state.type))
                    return this.tsParseTypeAliasDeclaration(e);
                  break;
              }
            }
            tsCheckLineTerminator(e) {
              return e ? this.hasFollowingLineBreak() ? false : (this.next(), true) : !this.isLineTerminator();
            }
            tsTryParseGenericAsyncArrowFunction(e) {
              if (!this.match(47))
                return;
              let s = this.state.maybeInArrowParameters;
              this.state.maybeInArrowParameters = true;
              let i = this.tsTryParseAndCatch(() => {
                let a = this.startNodeAt(e);
                return a.typeParameters = this.tsParseTypeParameters(), super.parseFunctionParams(a), a.returnType = this.tsTryParseTypeOrTypePredicateAnnotation(), this.expect(19), a;
              });
              if (this.state.maybeInArrowParameters = s, !!i)
                return super.parseArrowExpression(i, null, true);
            }
            tsParseTypeArgumentsInExpression() {
              if (this.reScan_lt() === 47)
                return this.tsParseTypeArguments();
            }
            tsParseTypeArguments() {
              let e = this.startNode();
              return e.params = this.tsInType(() => this.tsInNoContext(() => (this.expect(47), this.tsParseDelimitedList("TypeParametersOrArguments", this.tsParseType.bind(this))))), e.params.length === 0 && this.raise(w.EmptyTypeArguments, { at: e }), this.expect(48), this.finishNode(e, "TSTypeParameterInstantiation");
            }
            tsIsDeclarationStart() {
              return el(this.state.type);
            }
            isExportDefaultSpecifier() {
              return this.tsIsDeclarationStart() ? false : super.isExportDefaultSpecifier();
            }
            parseAssignableListItem(e, s) {
              let i = this.state.startLoc, a, n = false, o = false;
              if (e !== void 0) {
                let m = {};
                this.tsParseModifiers({ modified: m, allowedModifiers: ["public", "private", "protected", "override", "readonly"] }), a = m.accessibility, o = m.override, n = m.readonly, e === false && (a || n || o) && this.raise(w.UnexpectedParameterModifier, { at: i });
              }
              let c = this.parseMaybeDefault();
              this.parseAssignableListItemTypes(c);
              let p = this.parseMaybeDefault(c.loc.start, c);
              if (a || n || o) {
                let m = this.startNodeAt(i);
                return s.length && (m.decorators = s), a && (m.accessibility = a), n && (m.readonly = n), o && (m.override = o), p.type !== "Identifier" && p.type !== "AssignmentPattern" && this.raise(w.UnsupportedParameterPropertyKind, { at: m }), m.parameter = p, this.finishNode(m, "TSParameterProperty");
              }
              return s.length && (c.decorators = s), p;
            }
            isSimpleParameter(e) {
              return e.type === "TSParameterProperty" && super.isSimpleParameter(e.parameter) || super.isSimpleParameter(e);
            }
            parseFunctionBodyAndFinish(e, s) {
              let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              this.match(14) && (e.returnType = this.tsParseTypeOrTypePredicateAnnotation(14));
              let a = s === "FunctionDeclaration" ? "TSDeclareFunction" : s === "ClassMethod" || s === "ClassPrivateMethod" ? "TSDeclareMethod" : void 0;
              return a && !this.match(5) && this.isLineTerminator() ? this.finishNode(e, a) : a === "TSDeclareFunction" && this.state.isAmbientContext && (this.raise(w.DeclareFunctionHasImplementation, { at: e }), e.declare) ? super.parseFunctionBodyAndFinish(e, a, i) : super.parseFunctionBodyAndFinish(e, s, i);
            }
            registerFunctionStatementId(e) {
              !e.body && e.id ? this.checkIdentifier(e.id, Lr) : super.registerFunctionStatementId(e);
            }
            tsCheckForInvalidTypeCasts(e) {
              e.forEach((s) => {
                (s == null ? void 0 : s.type) === "TSTypeCastExpression" && this.raise(w.UnexpectedTypeAnnotation, { at: s.typeAnnotation });
              });
            }
            toReferencedList(e, s) {
              return this.tsCheckForInvalidTypeCasts(e), e;
            }
            parseArrayLike(e, s, i, a) {
              let n = super.parseArrayLike(e, s, i, a);
              return n.type === "ArrayExpression" && this.tsCheckForInvalidTypeCasts(n.elements), n;
            }
            parseSubscript(e, s, i, a) {
              if (!this.hasPrecedingLineBreak() && this.match(35)) {
                this.state.canStartJSXElement = false, this.next();
                let o = this.startNodeAt(s);
                return o.expression = e, this.finishNode(o, "TSNonNullExpression");
              }
              let n = false;
              if (this.match(18) && this.lookaheadCharCode() === 60) {
                if (i)
                  return a.stop = true, e;
                a.optionalChainMember = n = true, this.next();
              }
              if (this.match(47) || this.match(51)) {
                let o, c = this.tsTryParseAndCatch(() => {
                  if (!i && this.atPossibleAsyncArrow(e)) {
                    let A = this.tsTryParseGenericAsyncArrowFunction(s);
                    if (A)
                      return A;
                  }
                  let p = this.tsParseTypeArgumentsInExpression();
                  if (!p)
                    return;
                  if (n && !this.match(10)) {
                    o = this.state.curPosition();
                    return;
                  }
                  if (ct(this.state.type)) {
                    let A = super.parseTaggedTemplateExpression(e, s, a);
                    return A.typeParameters = p, A;
                  }
                  if (!i && this.eat(10)) {
                    let A = this.startNodeAt(s);
                    return A.callee = e, A.arguments = this.parseCallExpressionArguments(11, false), this.tsCheckForInvalidTypeCasts(A.arguments), A.typeParameters = p, a.optionalChainMember && (A.optional = n), this.finishCallExpression(A, a.optionalChainMember);
                  }
                  let m = this.state.type;
                  if (m === 48 || m === 52 || m !== 10 && Xt(m) && !this.hasPrecedingLineBreak())
                    return;
                  let x = this.startNodeAt(s);
                  return x.expression = e, x.typeParameters = p, this.finishNode(x, "TSInstantiationExpression");
                });
                if (o && this.unexpected(o, 10), c)
                  return c.type === "TSInstantiationExpression" && (this.match(16) || this.match(18) && this.lookaheadCharCode() !== 40) && this.raise(w.InvalidPropertyAccessAfterInstantiationExpression, { at: this.state.startLoc }), c;
              }
              return super.parseSubscript(e, s, i, a);
            }
            parseNewCallee(e) {
              var s;
              super.parseNewCallee(e);
              let { callee: i } = e;
              i.type === "TSInstantiationExpression" && !((s = i.extra) != null && s.parenthesized) && (e.typeParameters = i.typeParameters, e.callee = i.expression);
            }
            parseExprOp(e, s, i) {
              let a;
              if (ut(58) > i && !this.hasPrecedingLineBreak() && (this.isContextual(93) || (a = this.isContextual(118)))) {
                let n = this.startNodeAt(s);
                return n.expression = e, n.typeAnnotation = this.tsInType(() => (this.next(), this.match(75) ? (a && this.raise(u.UnexpectedKeyword, { at: this.state.startLoc, keyword: "const" }), this.tsParseTypeReference()) : this.tsParseType())), this.finishNode(n, a ? "TSSatisfiesExpression" : "TSAsExpression"), this.reScan_lt_gt(), this.parseExprOp(n, s, i);
              }
              return super.parseExprOp(e, s, i);
            }
            checkReservedWord(e, s, i, a) {
              this.state.isAmbientContext || super.checkReservedWord(e, s, i, a);
            }
            checkImportReflection(e) {
              super.checkImportReflection(e), e.module && e.importKind !== "value" && this.raise(w.ImportReflectionHasImportType, { at: e.specifiers[0].loc.start });
            }
            checkDuplicateExports() {
            }
            parseImport(e) {
              if (e.importKind = "value", z(this.state.type) || this.match(55) || this.match(5)) {
                let i = this.lookahead();
                if (this.isContextual(128) && i.type !== 12 && i.type !== 97 && i.type !== 29 && (e.importKind = "type", this.next(), i = this.lookahead()), z(this.state.type) && i.type === 29)
                  return this.tsParseImportEqualsDeclaration(e);
              }
              let s = super.parseImport(e);
              return s.importKind === "type" && s.specifiers.length > 1 && s.specifiers[0].type === "ImportDefaultSpecifier" && this.raise(w.TypeImportCannotSpecifyDefaultAndNamed, { at: s }), s;
            }
            parseExport(e, s) {
              if (this.match(83))
                return this.next(), this.isContextual(128) && this.lookaheadCharCode() !== 61 ? (e.importKind = "type", this.next()) : e.importKind = "value", this.tsParseImportEqualsDeclaration(e, true);
              if (this.eat(29)) {
                let i = e;
                return i.expression = super.parseExpression(), this.semicolon(), this.finishNode(i, "TSExportAssignment");
              } else if (this.eatContextual(93)) {
                let i = e;
                return this.expectContextual(126), i.id = this.parseIdentifier(), this.semicolon(), this.finishNode(i, "TSNamespaceExportDeclaration");
              } else
                return this.isContextual(128) && this.lookahead().type === 5 ? (this.next(), e.exportKind = "type") : e.exportKind = "value", super.parseExport(e, s);
            }
            isAbstractClass() {
              return this.isContextual(122) && this.lookahead().type === 80;
            }
            parseExportDefaultExpression() {
              if (this.isAbstractClass()) {
                let e = this.startNode();
                return this.next(), e.abstract = true, this.parseClass(e, true, true);
              }
              if (this.match(127)) {
                let e = this.tsParseInterfaceDeclaration(this.startNode());
                if (e)
                  return e;
              }
              return super.parseExportDefaultExpression();
            }
            parseVarStatement(e, s) {
              let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, { isAmbientContext: a } = this.state, n = super.parseVarStatement(e, s, i || a);
              if (!a)
                return n;
              for (let { id: o, init: c } of n.declarations)
                c && (s !== "const" || o.typeAnnotation ? this.raise(w.InitializerNotAllowedInAmbientContext, { at: c }) : c.type !== "StringLiteral" && c.type !== "BooleanLiteral" && c.type !== "NumericLiteral" && c.type !== "BigIntLiteral" && (c.type !== "TemplateLiteral" || c.expressions.length > 0) && !hh(c) && this.raise(w.ConstInitiailizerMustBeStringOrNumericLiteralOrLiteralEnumReference, { at: c }));
              return n;
            }
            parseStatementContent(e, s) {
              if (this.match(75) && this.isLookaheadContextual("enum")) {
                let i = this.startNode();
                return this.expect(75), this.tsParseEnumDeclaration(i, { const: true });
              }
              if (this.isContextual(124))
                return this.tsParseEnumDeclaration(this.startNode());
              if (this.isContextual(127)) {
                let i = this.tsParseInterfaceDeclaration(this.startNode());
                if (i)
                  return i;
              }
              return super.parseStatementContent(e, s);
            }
            parseAccessModifier() {
              return this.tsParseModifier(["public", "protected", "private"]);
            }
            tsHasSomeModifiers(e, s) {
              return s.some((i) => Xr(i) ? e.accessibility === i : !!e[i]);
            }
            tsIsStartOfStaticBlocks() {
              return this.isContextual(104) && this.lookaheadCharCode() === 123;
            }
            parseClassMember(e, s, i) {
              let a = ["declare", "private", "public", "protected", "override", "abstract", "readonly", "static"];
              this.tsParseModifiers({ modified: s, allowedModifiers: a, disallowedModifiers: ["in", "out"], stopOnStartOfClassStaticBlock: true, errorTemplate: w.InvalidModifierOnTypeParameterPositions });
              let n = () => {
                this.tsIsStartOfStaticBlocks() ? (this.next(), this.next(), this.tsHasSomeModifiers(s, a) && this.raise(w.StaticBlockCannotHaveModifier, { at: this.state.curPosition() }), super.parseClassStaticBlock(e, s)) : this.parseClassMemberWithIsStatic(e, s, i, !!s.static);
              };
              s.declare ? this.tsInAmbientContext(n) : n();
            }
            parseClassMemberWithIsStatic(e, s, i, a) {
              let n = this.tsTryParseIndexSignature(s);
              if (n) {
                e.body.push(n), s.abstract && this.raise(w.IndexSignatureHasAbstract, { at: s }), s.accessibility && this.raise(w.IndexSignatureHasAccessibility, { at: s, modifier: s.accessibility }), s.declare && this.raise(w.IndexSignatureHasDeclare, { at: s }), s.override && this.raise(w.IndexSignatureHasOverride, { at: s });
                return;
              }
              !this.state.inAbstractClass && s.abstract && this.raise(w.NonAbstractClassHasAbstractMethod, { at: s }), s.override && (i.hadSuperClass || this.raise(w.OverrideNotInSubClass, { at: s })), super.parseClassMemberWithIsStatic(e, s, i, a);
            }
            parsePostMemberNameModifiers(e) {
              this.eat(17) && (e.optional = true), e.readonly && this.match(10) && this.raise(w.ClassMethodHasReadonly, { at: e }), e.declare && this.match(10) && this.raise(w.ClassMethodHasDeclare, { at: e });
            }
            parseExpressionStatement(e, s, i) {
              return (s.type === "Identifier" ? this.tsParseExpressionStatement(e, s, i) : void 0) || super.parseExpressionStatement(e, s, i);
            }
            shouldParseExportDeclaration() {
              return this.tsIsDeclarationStart() ? true : super.shouldParseExportDeclaration();
            }
            parseConditional(e, s, i) {
              if (!this.state.maybeInArrowParameters || !this.match(17))
                return super.parseConditional(e, s, i);
              let a = this.tryParse(() => super.parseConditional(e, s));
              return a.node ? (a.error && (this.state = a.failState), a.node) : (a.error && super.setOptionalParametersError(i, a.error), e);
            }
            parseParenItem(e, s) {
              if (e = super.parseParenItem(e, s), this.eat(17) && (e.optional = true, this.resetEndLocation(e)), this.match(14)) {
                let i = this.startNodeAt(s);
                return i.expression = e, i.typeAnnotation = this.tsParseTypeAnnotation(), this.finishNode(i, "TSTypeCastExpression");
              }
              return e;
            }
            parseExportDeclaration(e) {
              if (!this.state.isAmbientContext && this.isContextual(123))
                return this.tsInAmbientContext(() => this.parseExportDeclaration(e));
              let s = this.state.startLoc, i = this.eatContextual(123);
              if (i && (this.isContextual(123) || !this.shouldParseExportDeclaration()))
                throw this.raise(w.ExpectedAmbientAfterExportDeclare, { at: this.state.startLoc });
              let n = z(this.state.type) && this.tsTryParseExportDeclaration() || super.parseExportDeclaration(e);
              return n ? ((n.type === "TSInterfaceDeclaration" || n.type === "TSTypeAliasDeclaration" || i) && (e.exportKind = "type"), i && (this.resetStartLocation(n, s), n.declare = true), n) : null;
            }
            parseClassId(e, s, i, a) {
              if ((!s || i) && this.isContextual(111))
                return;
              super.parseClassId(e, s, i, e.declare ? Lr : kr);
              let n = this.tsTryParseTypeParameters(this.tsParseInOutModifiers.bind(this));
              n && (e.typeParameters = n);
            }
            parseClassPropertyAnnotation(e) {
              e.optional || (this.eat(35) ? e.definite = true : this.eat(17) && (e.optional = true));
              let s = this.tsTryParseTypeAnnotation();
              s && (e.typeAnnotation = s);
            }
            parseClassProperty(e) {
              if (this.parseClassPropertyAnnotation(e), this.state.isAmbientContext && !(e.readonly && !e.typeAnnotation) && this.match(29) && this.raise(w.DeclareClassFieldHasInitializer, { at: this.state.startLoc }), e.abstract && this.match(29)) {
                let { key: s } = e;
                this.raise(w.AbstractPropertyHasInitializer, { at: this.state.startLoc, propertyName: s.type === "Identifier" && !e.computed ? s.name : `[${this.input.slice(s.start, s.end)}]` });
              }
              return super.parseClassProperty(e);
            }
            parseClassPrivateProperty(e) {
              return e.abstract && this.raise(w.PrivateElementHasAbstract, { at: e }), e.accessibility && this.raise(w.PrivateElementHasAccessibility, { at: e, modifier: e.accessibility }), this.parseClassPropertyAnnotation(e), super.parseClassPrivateProperty(e);
            }
            parseClassAccessorProperty(e) {
              return this.parseClassPropertyAnnotation(e), e.optional && this.raise(w.AccessorCannotBeOptional, { at: e }), super.parseClassAccessorProperty(e);
            }
            pushClassMethod(e, s, i, a, n, o) {
              let c = this.tsTryParseTypeParameters();
              c && n && this.raise(w.ConstructorHasTypeParameters, { at: c });
              let { declare: p = false, kind: m } = s;
              p && (m === "get" || m === "set") && this.raise(w.DeclareAccessor, { at: s, kind: m }), c && (s.typeParameters = c), super.pushClassMethod(e, s, i, a, n, o);
            }
            pushClassPrivateMethod(e, s, i, a) {
              let n = this.tsTryParseTypeParameters();
              n && (s.typeParameters = n), super.pushClassPrivateMethod(e, s, i, a);
            }
            declareClassPrivateMethodInScope(e, s) {
              e.type !== "TSDeclareMethod" && (e.type === "MethodDefinition" && !e.value.body || super.declareClassPrivateMethodInScope(e, s));
            }
            parseClassSuper(e) {
              super.parseClassSuper(e), e.superClass && (this.match(47) || this.match(51)) && (e.superTypeParameters = this.tsParseTypeArgumentsInExpression()), this.eatContextual(111) && (e.implements = this.tsParseHeritageClause("implements"));
            }
            parseObjPropValue(e, s, i, a, n, o, c) {
              let p = this.tsTryParseTypeParameters();
              return p && (e.typeParameters = p), super.parseObjPropValue(e, s, i, a, n, o, c);
            }
            parseFunctionParams(e, s) {
              let i = this.tsTryParseTypeParameters();
              i && (e.typeParameters = i), super.parseFunctionParams(e, s);
            }
            parseVarId(e, s) {
              super.parseVarId(e, s), e.id.type === "Identifier" && !this.hasPrecedingLineBreak() && this.eat(35) && (e.definite = true);
              let i = this.tsTryParseTypeAnnotation();
              i && (e.id.typeAnnotation = i, this.resetEndLocation(e.id));
            }
            parseAsyncArrowFromCallExpression(e, s) {
              return this.match(14) && (e.returnType = this.tsParseTypeAnnotation()), super.parseAsyncArrowFromCallExpression(e, s);
            }
            parseMaybeAssign(e, s) {
              var i, a, n, o, c, p, m;
              let x, A, b;
              if (this.hasPlugin("jsx") && (this.match(140) || this.match(47))) {
                if (x = this.state.clone(), A = this.tryParse(() => super.parseMaybeAssign(e, s), x), !A.error)
                  return A.node;
                let { context: Y } = this.state, Q = Y[Y.length - 1];
                (Q === $2.j_oTag || Q === $2.j_expr) && Y.pop();
              }
              if (!((i = A) != null && i.error) && !this.match(47))
                return super.parseMaybeAssign(e, s);
              (!x || x === this.state) && (x = this.state.clone());
              let O, R = this.tryParse((Y) => {
                var Q, J;
                O = this.tsParseTypeParameters();
                let se = super.parseMaybeAssign(e, s);
                return (se.type !== "ArrowFunctionExpression" || (Q = se.extra) != null && Q.parenthesized) && Y(), ((J = O) == null ? void 0 : J.params.length) !== 0 && this.resetStartLocationFromNode(se, O), se.typeParameters = O, se;
              }, x);
              if (!R.error && !R.aborted)
                return O && this.reportReservedArrowTypeParam(O), R.node;
              if (!A && (Jr(!this.hasPlugin("jsx")), b = this.tryParse(() => super.parseMaybeAssign(e, s), x), !b.error))
                return b.node;
              if ((a = A) != null && a.node)
                return this.state = A.failState, A.node;
              if (R.node)
                return this.state = R.failState, O && this.reportReservedArrowTypeParam(O), R.node;
              if ((n = b) != null && n.node)
                return this.state = b.failState, b.node;
              throw (o = A) != null && o.thrown ? A.error : R.thrown ? R.error : (c = b) != null && c.thrown ? b.error : ((p = A) == null ? void 0 : p.error) || R.error || ((m = b) == null ? void 0 : m.error);
            }
            reportReservedArrowTypeParam(e) {
              var s;
              e.params.length === 1 && !((s = e.extra) != null && s.trailingComma) && this.getPluginOption("typescript", "disallowAmbiguousJSXLike") && this.raise(w.ReservedArrowTypeParam, { at: e });
            }
            parseMaybeUnary(e, s) {
              return !this.hasPlugin("jsx") && this.match(47) ? this.tsParseTypeAssertion() : super.parseMaybeUnary(e, s);
            }
            parseArrow(e) {
              if (this.match(14)) {
                let s = this.tryParse((i) => {
                  let a = this.tsParseTypeOrTypePredicateAnnotation(14);
                  return (this.canInsertSemicolon() || !this.match(19)) && i(), a;
                });
                if (s.aborted)
                  return;
                s.thrown || (s.error && (this.state = s.failState), e.returnType = s.node);
              }
              return super.parseArrow(e);
            }
            parseAssignableListItemTypes(e) {
              this.eat(17) && (e.type !== "Identifier" && !this.state.isAmbientContext && !this.state.inType && this.raise(w.PatternIsOptional, { at: e }), e.optional = true);
              let s = this.tsTryParseTypeAnnotation();
              return s && (e.typeAnnotation = s), this.resetEndLocation(e), e;
            }
            isAssignable(e, s) {
              switch (e.type) {
                case "TSTypeCastExpression":
                  return this.isAssignable(e.expression, s);
                case "TSParameterProperty":
                  return true;
                default:
                  return super.isAssignable(e, s);
              }
            }
            toAssignable(e) {
              let s = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              switch (e.type) {
                case "ParenthesizedExpression":
                  this.toAssignableParenthesizedExpression(e, s);
                  break;
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSNonNullExpression":
                case "TSTypeAssertion":
                  s ? this.expressionScope.recordArrowParameterBindingError(w.UnexpectedTypeCastInParameter, { at: e }) : this.raise(w.UnexpectedTypeCastInParameter, { at: e }), this.toAssignable(e.expression, s);
                  break;
                case "AssignmentExpression":
                  !s && e.left.type === "TSTypeCastExpression" && (e.left = this.typeCastToParameter(e.left));
                default:
                  super.toAssignable(e, s);
              }
            }
            toAssignableParenthesizedExpression(e, s) {
              switch (e.expression.type) {
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSNonNullExpression":
                case "TSTypeAssertion":
                case "ParenthesizedExpression":
                  this.toAssignable(e.expression, s);
                  break;
                default:
                  super.toAssignable(e, s);
              }
            }
            checkToRestConversion(e, s) {
              switch (e.type) {
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSTypeAssertion":
                case "TSNonNullExpression":
                  this.checkToRestConversion(e.expression, false);
                  break;
                default:
                  super.checkToRestConversion(e, s);
              }
            }
            isValidLVal(e, s, i) {
              return ih({ TSTypeCastExpression: true, TSParameterProperty: "parameter", TSNonNullExpression: "expression", TSAsExpression: (i !== be || !s) && ["expression", true], TSSatisfiesExpression: (i !== be || !s) && ["expression", true], TSTypeAssertion: (i !== be || !s) && ["expression", true] }, e) || super.isValidLVal(e, s, i);
            }
            parseBindingAtom() {
              switch (this.state.type) {
                case 78:
                  return this.parseIdentifier(true);
                default:
                  return super.parseBindingAtom();
              }
            }
            parseMaybeDecoratorArguments(e) {
              if (this.match(47) || this.match(51)) {
                let s = this.tsParseTypeArgumentsInExpression();
                if (this.match(10)) {
                  let i = super.parseMaybeDecoratorArguments(e);
                  return i.typeParameters = s, i;
                }
                this.unexpected(null, 10);
              }
              return super.parseMaybeDecoratorArguments(e);
            }
            checkCommaAfterRest(e) {
              return this.state.isAmbientContext && this.match(12) && this.lookaheadCharCode() === e ? (this.next(), false) : super.checkCommaAfterRest(e);
            }
            isClassMethod() {
              return this.match(47) || super.isClassMethod();
            }
            isClassProperty() {
              return this.match(35) || this.match(14) || super.isClassProperty();
            }
            parseMaybeDefault(e, s) {
              let i = super.parseMaybeDefault(e, s);
              return i.type === "AssignmentPattern" && i.typeAnnotation && i.right.start < i.typeAnnotation.start && this.raise(w.TypeAnnotationAfterAssign, { at: i.typeAnnotation }), i;
            }
            getTokenFromCode(e) {
              if (this.state.inType) {
                if (e === 62)
                  return this.finishOp(48, 1);
                if (e === 60)
                  return this.finishOp(47, 1);
              }
              return super.getTokenFromCode(e);
            }
            reScan_lt_gt() {
              let { type: e } = this.state;
              e === 47 ? (this.state.pos -= 1, this.readToken_lt()) : e === 48 && (this.state.pos -= 1, this.readToken_gt());
            }
            reScan_lt() {
              let { type: e } = this.state;
              return e === 51 ? (this.state.pos -= 2, this.finishOp(47, 1), 47) : e;
            }
            toAssignableList(e, s, i) {
              for (let a = 0; a < e.length; a++) {
                let n = e[a];
                (n == null ? void 0 : n.type) === "TSTypeCastExpression" && (e[a] = this.typeCastToParameter(n));
              }
              super.toAssignableList(e, s, i);
            }
            typeCastToParameter(e) {
              return e.expression.typeAnnotation = e.typeAnnotation, this.resetEndLocation(e.expression, e.typeAnnotation.loc.end), e.expression;
            }
            shouldParseArrow(e) {
              return this.match(14) ? e.every((s) => this.isAssignable(s, true)) : super.shouldParseArrow(e);
            }
            shouldParseAsyncArrow() {
              return this.match(14) || super.shouldParseAsyncArrow();
            }
            canHaveLeadingDecorator() {
              return super.canHaveLeadingDecorator() || this.isAbstractClass();
            }
            jsxParseOpeningElementAfterName(e) {
              if (this.match(47) || this.match(51)) {
                let s = this.tsTryParseAndCatch(() => this.tsParseTypeArgumentsInExpression());
                s && (e.typeParameters = s);
              }
              return super.jsxParseOpeningElementAfterName(e);
            }
            getGetterSetterExpectedParamCount(e) {
              let s = super.getGetterSetterExpectedParamCount(e), a = this.getObjectOrClassMethodParams(e)[0];
              return a && this.isThisParam(a) ? s + 1 : s;
            }
            parseCatchClauseParam() {
              let e = super.parseCatchClauseParam(), s = this.tsTryParseTypeAnnotation();
              return s && (e.typeAnnotation = s, this.resetEndLocation(e)), e;
            }
            tsInAmbientContext(e) {
              let s = this.state.isAmbientContext;
              this.state.isAmbientContext = true;
              try {
                return e();
              } finally {
                this.state.isAmbientContext = s;
              }
            }
            parseClass(e, s, i) {
              let a = this.state.inAbstractClass;
              this.state.inAbstractClass = !!e.abstract;
              try {
                return super.parseClass(e, s, i);
              } finally {
                this.state.inAbstractClass = a;
              }
            }
            tsParseAbstractDeclaration(e, s) {
              if (this.match(80))
                return e.abstract = true, this.maybeTakeDecorators(s, this.parseClass(e, true, false));
              if (this.isContextual(127)) {
                if (!this.hasFollowingLineBreak())
                  return e.abstract = true, this.raise(w.NonClassMethodPropertyHasAbstractModifer, { at: e }), this.tsParseInterfaceDeclaration(e);
              } else
                this.unexpected(null, 80);
            }
            parseMethod(e, s, i, a, n, o, c) {
              let p = super.parseMethod(e, s, i, a, n, o, c);
              if (p.abstract && (this.hasPlugin("estree") ? !!p.value.body : !!p.body)) {
                let { key: x } = p;
                this.raise(w.AbstractMethodHasImplementation, { at: p, methodName: x.type === "Identifier" && !p.computed ? x.name : `[${this.input.slice(x.start, x.end)}]` });
              }
              return p;
            }
            tsParseTypeParameterName() {
              return this.parseIdentifier().name;
            }
            shouldParseAsAmbientContext() {
              return !!this.getPluginOption("typescript", "dts");
            }
            parse() {
              return this.shouldParseAsAmbientContext() && (this.state.isAmbientContext = true), super.parse();
            }
            getExpression() {
              return this.shouldParseAsAmbientContext() && (this.state.isAmbientContext = true), super.getExpression();
            }
            parseExportSpecifier(e, s, i, a) {
              return !s && a ? (this.parseTypeOnlyImportExportSpecifier(e, false, i), this.finishNode(e, "ExportSpecifier")) : (e.exportKind = "value", super.parseExportSpecifier(e, s, i, a));
            }
            parseImportSpecifier(e, s, i, a, n) {
              return !s && a ? (this.parseTypeOnlyImportExportSpecifier(e, true, i), this.finishNode(e, "ImportSpecifier")) : (e.importKind = "value", super.parseImportSpecifier(e, s, i, a, i ? Or : Ye));
            }
            parseTypeOnlyImportExportSpecifier(e, s, i) {
              let a = s ? "imported" : "local", n = s ? "local" : "exported", o = e[a], c, p = false, m = true, x = o.loc.start;
              if (this.isContextual(93)) {
                let b = this.parseIdentifier();
                if (this.isContextual(93)) {
                  let O = this.parseIdentifier();
                  ye(this.state.type) ? (p = true, o = b, c = s ? this.parseIdentifier() : this.parseModuleExportName(), m = false) : (c = O, m = false);
                } else
                  ye(this.state.type) ? (m = false, c = s ? this.parseIdentifier() : this.parseModuleExportName()) : (p = true, o = b);
              } else
                ye(this.state.type) && (p = true, s ? (o = this.parseIdentifier(true), this.isContextual(93) || this.checkReservedWord(o.name, o.loc.start, true, true)) : o = this.parseModuleExportName());
              p && i && this.raise(s ? w.TypeModifierIsUsedInTypeImports : w.TypeModifierIsUsedInTypeExports, { at: x }), e[a] = o, e[n] = c;
              let A = s ? "importKind" : "exportKind";
              e[A] = p ? "type" : "value", m && this.eatContextual(93) && (e[n] = s ? this.parseIdentifier() : this.parseModuleExportName()), e[n] || (e[n] = Te(e[a])), s && this.checkIdentifier(e[n], p ? Or : Ye);
            }
          };
          function hh(t3) {
            if (t3.type !== "MemberExpression")
              return false;
            let { computed: r, property: e } = t3;
            return r && e.type !== "StringLiteral" && (e.type !== "TemplateLiteral" || e.expressions.length > 0) ? false : Yr(t3.object);
          }
          function Yr(t3) {
            return t3.type === "Identifier" ? true : t3.type !== "MemberExpression" || t3.computed ? false : Yr(t3.object);
          }
          var Qr = _`placeholders`({ ClassNameIsRequired: "A class name is required.", UnexpectedSpace: "Unexpected space in placeholder." }), uh = (t3) => class extends t3 {
            parsePlaceholder(e) {
              if (this.match(142)) {
                let s = this.startNode();
                return this.next(), this.assertNoSpace(), s.name = super.parseIdentifier(true), this.assertNoSpace(), this.expect(142), this.finishPlaceholder(s, e);
              }
            }
            finishPlaceholder(e, s) {
              let i = !!(e.expectedNode && e.type === "Placeholder");
              return e.expectedNode = s, i ? e : this.finishNode(e, "Placeholder");
            }
            getTokenFromCode(e) {
              return e === 37 && this.input.charCodeAt(this.state.pos + 1) === 37 ? this.finishOp(142, 2) : super.getTokenFromCode(e);
            }
            parseExprAtom(e) {
              return this.parsePlaceholder("Expression") || super.parseExprAtom(e);
            }
            parseIdentifier(e) {
              return this.parsePlaceholder("Identifier") || super.parseIdentifier(e);
            }
            checkReservedWord(e, s, i, a) {
              e !== void 0 && super.checkReservedWord(e, s, i, a);
            }
            parseBindingAtom() {
              return this.parsePlaceholder("Pattern") || super.parseBindingAtom();
            }
            isValidLVal(e, s, i) {
              return e === "Placeholder" || super.isValidLVal(e, s, i);
            }
            toAssignable(e, s) {
              e && e.type === "Placeholder" && e.expectedNode === "Expression" ? e.expectedNode = "Pattern" : super.toAssignable(e, s);
            }
            chStartsBindingIdentifier(e, s) {
              return !!(super.chStartsBindingIdentifier(e, s) || this.lookahead().type === 142);
            }
            verifyBreakContinue(e, s) {
              e.label && e.label.type === "Placeholder" || super.verifyBreakContinue(e, s);
            }
            parseExpressionStatement(e, s) {
              if (s.type !== "Placeholder" || s.extra && s.extra.parenthesized)
                return super.parseExpressionStatement(e, s);
              if (this.match(14)) {
                let i = e;
                return i.label = this.finishPlaceholder(s, "Identifier"), this.next(), i.body = super.parseStatementOrFunctionDeclaration(false), this.finishNode(i, "LabeledStatement");
              }
              return this.semicolon(), e.name = s.name, this.finishPlaceholder(e, "Statement");
            }
            parseBlock(e, s, i) {
              return this.parsePlaceholder("BlockStatement") || super.parseBlock(e, s, i);
            }
            parseFunctionId(e) {
              return this.parsePlaceholder("Identifier") || super.parseFunctionId(e);
            }
            parseClass(e, s, i) {
              let a = s ? "ClassDeclaration" : "ClassExpression";
              this.next();
              let n = this.state.strict, o = this.parsePlaceholder("Identifier");
              if (o)
                if (this.match(81) || this.match(142) || this.match(5))
                  e.id = o;
                else {
                  if (i || !s)
                    return e.id = null, e.body = this.finishPlaceholder(o, "ClassBody"), this.finishNode(e, a);
                  throw this.raise(Qr.ClassNameIsRequired, { at: this.state.startLoc });
                }
              else
                this.parseClassId(e, s, i);
              return super.parseClassSuper(e), e.body = this.parsePlaceholder("ClassBody") || super.parseClassBody(!!e.superClass, n), this.finishNode(e, a);
            }
            parseExport(e, s) {
              let i = this.parsePlaceholder("Identifier");
              if (!i)
                return super.parseExport(e, s);
              if (!this.isContextual(97) && !this.match(12))
                return e.specifiers = [], e.source = null, e.declaration = this.finishPlaceholder(i, "Declaration"), this.finishNode(e, "ExportNamedDeclaration");
              this.expectPlugin("exportDefaultFrom");
              let a = this.startNode();
              return a.exported = i, e.specifiers = [this.finishNode(a, "ExportDefaultSpecifier")], super.parseExport(e, s);
            }
            isExportDefaultSpecifier() {
              if (this.match(65)) {
                let e = this.nextTokenStart();
                if (this.isUnparsedContextual(e, "from") && this.input.startsWith(Ee(142), this.nextTokenStartSince(e + 4)))
                  return true;
              }
              return super.isExportDefaultSpecifier();
            }
            maybeParseExportDefaultSpecifier(e) {
              return e.specifiers && e.specifiers.length > 0 ? true : super.maybeParseExportDefaultSpecifier(e);
            }
            checkExport(e) {
              let { specifiers: s } = e;
              s != null && s.length && (e.specifiers = s.filter((i) => i.exported.type === "Placeholder")), super.checkExport(e), e.specifiers = s;
            }
            parseImport(e) {
              let s = this.parsePlaceholder("Identifier");
              if (!s)
                return super.parseImport(e);
              if (e.specifiers = [], !this.isContextual(97) && !this.match(12))
                return e.source = this.finishPlaceholder(s, "StringLiteral"), this.semicolon(), this.finishNode(e, "ImportDeclaration");
              let i = this.startNodeAtNode(s);
              return i.local = s, e.specifiers.push(this.finishNode(i, "ImportDefaultSpecifier")), this.eat(12) && (this.maybeParseStarImportSpecifier(e) || this.parseNamedImportSpecifiers(e)), this.expectContextual(97), e.source = this.parseImportSource(), this.semicolon(), this.finishNode(e, "ImportDeclaration");
            }
            parseImportSource() {
              return this.parsePlaceholder("StringLiteral") || super.parseImportSource();
            }
            assertNoSpace() {
              this.state.start > this.state.lastTokEndLoc.index && this.raise(Qr.UnexpectedSpace, { at: this.state.lastTokEndLoc });
            }
          }, ch = (t3) => class extends t3 {
            parseV8Intrinsic() {
              if (this.match(54)) {
                let e = this.state.startLoc, s = this.startNode();
                if (this.next(), z(this.state.type)) {
                  let i = this.parseIdentifierName(), a = this.createIdentifier(s, i);
                  if (a.type = "V8IntrinsicIdentifier", this.match(10))
                    return a;
                }
                this.unexpected(e);
              }
            }
            parseExprAtom(e) {
              return this.parseV8Intrinsic() || super.parseExprAtom(e);
            }
          };
          function te(t3, r) {
            let [e, s] = typeof r == "string" ? [r, {}] : r, i = Object.keys(s), a = i.length === 0;
            return t3.some((n) => {
              if (typeof n == "string")
                return a && n === e;
              {
                let [o, c] = n;
                if (o !== e)
                  return false;
                for (let p of i)
                  if (c[p] !== s[p])
                    return false;
                return true;
              }
            });
          }
          function Le(t3, r, e) {
            let s = t3.find((i) => Array.isArray(i) ? i[0] === r : i === r);
            return s && Array.isArray(s) && s.length > 1 ? s[1][e] : null;
          }
          var Zr = ["minimal", "fsharp", "hack", "smart"], ei = ["^^", "@@", "^", "%", "#"], ti = ["hash", "bar"];
          function ph(t3) {
            if (te(t3, "decorators")) {
              if (te(t3, "decorators-legacy"))
                throw new Error("Cannot use the decorators and decorators-legacy plugin together");
              let r = Le(t3, "decorators", "decoratorsBeforeExport");
              if (r != null && typeof r != "boolean")
                throw new Error("'decoratorsBeforeExport' must be a boolean.");
              let e = Le(t3, "decorators", "allowCallParenthesized");
              if (e != null && typeof e != "boolean")
                throw new Error("'allowCallParenthesized' must be a boolean.");
            }
            if (te(t3, "flow") && te(t3, "typescript"))
              throw new Error("Cannot combine flow and typescript plugins.");
            if (te(t3, "placeholders") && te(t3, "v8intrinsic"))
              throw new Error("Cannot combine placeholders and v8intrinsic plugins.");
            if (te(t3, "pipelineOperator")) {
              let r = Le(t3, "pipelineOperator", "proposal");
              if (!Zr.includes(r)) {
                let s = Zr.map((i) => `"${i}"`).join(", ");
                throw new Error(`"pipelineOperator" requires "proposal" option whose value must be one of: ${s}.`);
              }
              let e = te(t3, ["recordAndTuple", { syntaxType: "hash" }]);
              if (r === "hack") {
                if (te(t3, "placeholders"))
                  throw new Error("Cannot combine placeholders plugin and Hack-style pipes.");
                if (te(t3, "v8intrinsic"))
                  throw new Error("Cannot combine v8intrinsic plugin and Hack-style pipes.");
                let s = Le(t3, "pipelineOperator", "topicToken");
                if (!ei.includes(s)) {
                  let i = ei.map((a) => `"${a}"`).join(", ");
                  throw new Error(`"pipelineOperator" in "proposal": "hack" mode also requires a "topicToken" option whose value must be one of: ${i}.`);
                }
                if (s === "#" && e)
                  throw new Error('Plugin conflict between `["pipelineOperator", { proposal: "hack", topicToken: "#" }]` and `["recordAndtuple", { syntaxType: "hash"}]`.');
              } else if (r === "smart" && e)
                throw new Error('Plugin conflict between `["pipelineOperator", { proposal: "smart" }]` and `["recordAndtuple", { syntaxType: "hash"}]`.');
            }
            if (te(t3, "moduleAttributes")) {
              if (te(t3, "importAssertions"))
                throw new Error("Cannot combine importAssertions and moduleAttributes plugins.");
              if (Le(t3, "moduleAttributes", "version") !== "may-2020")
                throw new Error("The 'moduleAttributes' plugin requires a 'version' option, representing the last proposal update. Currently, the only supported value is 'may-2020'.");
            }
            if (te(t3, "recordAndTuple") && Le(t3, "recordAndTuple", "syntaxType") != null && !ti.includes(Le(t3, "recordAndTuple", "syntaxType")))
              throw new Error("The 'syntaxType' option of the 'recordAndTuple' plugin must be one of: " + ti.map((r) => `'${r}'`).join(", "));
            if (te(t3, "asyncDoExpressions") && !te(t3, "doExpressions")) {
              let r = new Error("'asyncDoExpressions' requires 'doExpressions', please add 'doExpressions' to parser plugins.");
              throw r.missingPlugins = "doExpressions", r;
            }
          }
          var si = { estree: _e, jsx: th, flow: Zl, typescript: lh, v8intrinsic: ch, placeholders: uh }, fh = Object.keys(si), ri = { sourceType: "script", sourceFilename: void 0, startColumn: 0, startLine: 1, allowAwaitOutsideFunction: false, allowReturnOutsideFunction: false, allowImportExportEverywhere: false, allowSuperOutsideMethod: false, allowUndeclaredExports: false, plugins: [], strictMode: null, ranges: false, tokens: false, createParenthesizedExpressions: false, errorRecovery: false, attachComment: true };
          function dh(t3) {
            let r = {};
            for (let e of Object.keys(ri))
              r[e] = t3 && t3[e] != null ? t3[e] : ri[e];
            return r;
          }
          var mh = (t3, r) => Object.hasOwnProperty.call(t3, r) && t3[r], ii = (t3) => t3.type === "ParenthesizedExpression" ? ii(t3.expression) : t3, yh = class extends Wl {
            toAssignable(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              var e, s;
              let i;
              switch ((t3.type === "ParenthesizedExpression" || (e = t3.extra) != null && e.parenthesized) && (i = ii(t3), r ? i.type === "Identifier" ? this.expressionScope.recordArrowParameterBindingError(u.InvalidParenthesizedAssignment, { at: t3 }) : i.type !== "MemberExpression" && this.raise(u.InvalidParenthesizedAssignment, { at: t3 }) : this.raise(u.InvalidParenthesizedAssignment, { at: t3 })), t3.type) {
                case "Identifier":
                case "ObjectPattern":
                case "ArrayPattern":
                case "AssignmentPattern":
                case "RestElement":
                  break;
                case "ObjectExpression":
                  t3.type = "ObjectPattern";
                  for (let n = 0, o = t3.properties.length, c = o - 1; n < o; n++) {
                    var a;
                    let p = t3.properties[n], m = n === c;
                    this.toAssignableObjectExpressionProp(p, m, r), m && p.type === "RestElement" && (a = t3.extra) != null && a.trailingCommaLoc && this.raise(u.RestTrailingComma, { at: t3.extra.trailingCommaLoc });
                  }
                  break;
                case "ObjectProperty": {
                  let { key: n, value: o } = t3;
                  this.isPrivateName(n) && this.classScope.usePrivateName(this.getPrivateNameSV(n), n.loc.start), this.toAssignable(o, r);
                  break;
                }
                case "SpreadElement":
                  throw new Error("Internal @babel/parser error (this is a bug, please report it). SpreadElement should be converted by .toAssignable's caller.");
                case "ArrayExpression":
                  t3.type = "ArrayPattern", this.toAssignableList(t3.elements, (s = t3.extra) == null ? void 0 : s.trailingCommaLoc, r);
                  break;
                case "AssignmentExpression":
                  t3.operator !== "=" && this.raise(u.MissingEqInAssignment, { at: t3.left.loc.end }), t3.type = "AssignmentPattern", delete t3.operator, this.toAssignable(t3.left, r);
                  break;
                case "ParenthesizedExpression":
                  this.toAssignable(i, r);
                  break;
              }
            }
            toAssignableObjectExpressionProp(t3, r, e) {
              if (t3.type === "ObjectMethod")
                this.raise(t3.kind === "get" || t3.kind === "set" ? u.PatternHasAccessor : u.PatternHasMethod, { at: t3.key });
              else if (t3.type === "SpreadElement") {
                t3.type = "RestElement";
                let s = t3.argument;
                this.checkToRestConversion(s, false), this.toAssignable(s, e), r || this.raise(u.RestTrailingComma, { at: t3 });
              } else
                this.toAssignable(t3, e);
            }
            toAssignableList(t3, r, e) {
              let s = t3.length - 1;
              for (let i = 0; i <= s; i++) {
                let a = t3[i];
                if (a) {
                  if (a.type === "SpreadElement") {
                    a.type = "RestElement";
                    let n = a.argument;
                    this.checkToRestConversion(n, true), this.toAssignable(n, e);
                  } else
                    this.toAssignable(a, e);
                  a.type === "RestElement" && (i < s ? this.raise(u.RestTrailingComma, { at: a }) : r && this.raise(u.RestTrailingComma, { at: r }));
                }
              }
            }
            isAssignable(t3, r) {
              switch (t3.type) {
                case "Identifier":
                case "ObjectPattern":
                case "ArrayPattern":
                case "AssignmentPattern":
                case "RestElement":
                  return true;
                case "ObjectExpression": {
                  let e = t3.properties.length - 1;
                  return t3.properties.every((s, i) => s.type !== "ObjectMethod" && (i === e || s.type !== "SpreadElement") && this.isAssignable(s));
                }
                case "ObjectProperty":
                  return this.isAssignable(t3.value);
                case "SpreadElement":
                  return this.isAssignable(t3.argument);
                case "ArrayExpression":
                  return t3.elements.every((e) => e === null || this.isAssignable(e));
                case "AssignmentExpression":
                  return t3.operator === "=";
                case "ParenthesizedExpression":
                  return this.isAssignable(t3.expression);
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return !r;
                default:
                  return false;
              }
            }
            toReferencedList(t3, r) {
              return t3;
            }
            toReferencedListDeep(t3, r) {
              this.toReferencedList(t3, r);
              for (let e of t3)
                (e == null ? void 0 : e.type) === "ArrayExpression" && this.toReferencedListDeep(e.elements);
            }
            parseSpread(t3) {
              let r = this.startNode();
              return this.next(), r.argument = this.parseMaybeAssignAllowIn(t3, void 0), this.finishNode(r, "SpreadElement");
            }
            parseRestBinding() {
              let t3 = this.startNode();
              return this.next(), t3.argument = this.parseBindingAtom(), this.finishNode(t3, "RestElement");
            }
            parseBindingAtom() {
              switch (this.state.type) {
                case 0: {
                  let t3 = this.startNode();
                  return this.next(), t3.elements = this.parseBindingList(3, 93, true), this.finishNode(t3, "ArrayPattern");
                }
                case 5:
                  return this.parseObjectLike(8, true);
              }
              return this.parseIdentifier();
            }
            parseBindingList(t3, r, e, s) {
              let i = [], a = true;
              for (; !this.eat(t3); )
                if (a ? a = false : this.expect(12), e && this.match(12))
                  i.push(null);
                else {
                  if (this.eat(t3))
                    break;
                  if (this.match(21)) {
                    if (i.push(this.parseAssignableListItemTypes(this.parseRestBinding())), !this.checkCommaAfterRest(r)) {
                      this.expect(t3);
                      break;
                    }
                  } else {
                    let n = [];
                    for (this.match(26) && this.hasPlugin("decorators") && this.raise(u.UnsupportedParameterDecorator, { at: this.state.startLoc }); this.match(26); )
                      n.push(this.parseDecorator());
                    i.push(this.parseAssignableListItem(s, n));
                  }
                }
              return i;
            }
            parseBindingRestProperty(t3) {
              return this.next(), t3.argument = this.parseIdentifier(), this.checkCommaAfterRest(125), this.finishNode(t3, "RestElement");
            }
            parseBindingProperty() {
              let t3 = this.startNode(), { type: r, startLoc: e } = this.state;
              return r === 21 ? this.parseBindingRestProperty(t3) : (r === 136 ? (this.expectPlugin("destructuringPrivate", e), this.classScope.usePrivateName(this.state.value, e), t3.key = this.parsePrivateName()) : this.parsePropertyName(t3), t3.method = false, this.parseObjPropValue(t3, e, false, false, true, false));
            }
            parseAssignableListItem(t3, r) {
              let e = this.parseMaybeDefault();
              this.parseAssignableListItemTypes(e);
              let s = this.parseMaybeDefault(e.loc.start, e);
              return r.length && (e.decorators = r), s;
            }
            parseAssignableListItemTypes(t3) {
              return t3;
            }
            parseMaybeDefault(t3, r) {
              var e, s;
              if ((e = t3) != null || (t3 = this.state.startLoc), r = (s = r) != null ? s : this.parseBindingAtom(), !this.eat(29))
                return r;
              let i = this.startNodeAt(t3);
              return i.left = r, i.right = this.parseMaybeAssignAllowIn(), this.finishNode(i, "AssignmentPattern");
            }
            isValidLVal(t3, r, e) {
              return mh({ AssignmentPattern: "left", RestElement: "argument", ObjectProperty: "value", ParenthesizedExpression: "expression", ArrayPattern: "elements", ObjectPattern: "properties" }, t3);
            }
            checkLVal(t3, r) {
              let { in: e, binding: s = be, checkClashes: i = false, strictModeChanged: a = false, allowingSloppyLetBinding: n = !(s & Ce), hasParenthesizedAncestor: o = false } = r;
              var c;
              let p = t3.type;
              if (this.isObjectMethod(t3))
                return;
              if (p === "MemberExpression") {
                s !== be && this.raise(u.InvalidPropertyBindingPattern, { at: t3 });
                return;
              }
              if (t3.type === "Identifier") {
                this.checkIdentifier(t3, s, a, n);
                let { name: O } = t3;
                i && (i.has(O) ? this.raise(u.ParamDupe, { at: t3 }) : i.add(O));
                return;
              }
              let m = this.isValidLVal(t3.type, !(o || (c = t3.extra) != null && c.parenthesized) && e.type === "AssignmentExpression", s);
              if (m === true)
                return;
              if (m === false) {
                let O = s === be ? u.InvalidLhs : u.InvalidLhsBinding;
                this.raise(O, { at: t3, ancestor: e.type === "UpdateExpression" ? { type: "UpdateExpression", prefix: e.prefix } : { type: e.type } });
                return;
              }
              let [x, A] = Array.isArray(m) ? m : [m, p === "ParenthesizedExpression"], b = t3.type === "ArrayPattern" || t3.type === "ObjectPattern" || t3.type === "ParenthesizedExpression" ? t3 : e;
              for (let O of [].concat(t3[x]))
                O && this.checkLVal(O, { in: b, binding: s, checkClashes: i, allowingSloppyLetBinding: n, strictModeChanged: a, hasParenthesizedAncestor: A });
            }
            checkIdentifier(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : !(r & Ce);
              this.state.strict && (e ? br(t3.name, this.inModule) : Cr(t3.name)) && (r === be ? this.raise(u.StrictEvalArguments, { at: t3, referenceName: t3.name }) : this.raise(u.StrictEvalArgumentsBinding, { at: t3, bindingName: t3.name })), !s && t3.name === "let" && this.raise(u.LetInLexicalBinding, { at: t3 }), r & be || this.declareNameFromIdentifier(t3, r);
            }
            declareNameFromIdentifier(t3, r) {
              this.scope.declareName(t3.name, r, t3.loc.start);
            }
            checkToRestConversion(t3, r) {
              switch (t3.type) {
                case "ParenthesizedExpression":
                  this.checkToRestConversion(t3.expression, r);
                  break;
                case "Identifier":
                case "MemberExpression":
                  break;
                case "ArrayExpression":
                case "ObjectExpression":
                  if (r)
                    break;
                default:
                  this.raise(u.InvalidRestAssignmentPattern, { at: t3 });
              }
            }
            checkCommaAfterRest(t3) {
              return this.match(12) ? (this.raise(this.lookaheadCharCode() === t3 ? u.RestTrailingComma : u.ElementAfterRest, { at: this.state.startLoc }), true) : false;
            }
          }, xh = class extends yh {
            checkProto(t3, r, e, s) {
              if (t3.type === "SpreadElement" || this.isObjectMethod(t3) || t3.computed || t3.shorthand)
                return;
              let i = t3.key;
              if ((i.type === "Identifier" ? i.name : i.value) === "__proto__") {
                if (r) {
                  this.raise(u.RecordNoProto, { at: i });
                  return;
                }
                e.used && (s ? s.doubleProtoLoc === null && (s.doubleProtoLoc = i.loc.start) : this.raise(u.DuplicateProto, { at: i })), e.used = true;
              }
            }
            shouldExitDescending(t3, r) {
              return t3.type === "ArrowFunctionExpression" && t3.start === r;
            }
            getExpression() {
              this.enterInitialScopes(), this.nextToken();
              let t3 = this.parseExpression();
              return this.match(137) || this.unexpected(), this.finalizeRemainingComments(), t3.comments = this.state.comments, t3.errors = this.state.errors, this.options.tokens && (t3.tokens = this.tokens), t3;
            }
            parseExpression(t3, r) {
              return t3 ? this.disallowInAnd(() => this.parseExpressionBase(r)) : this.allowInAnd(() => this.parseExpressionBase(r));
            }
            parseExpressionBase(t3) {
              let r = this.state.startLoc, e = this.parseMaybeAssign(t3);
              if (this.match(12)) {
                let s = this.startNodeAt(r);
                for (s.expressions = [e]; this.eat(12); )
                  s.expressions.push(this.parseMaybeAssign(t3));
                return this.toReferencedList(s.expressions), this.finishNode(s, "SequenceExpression");
              }
              return e;
            }
            parseMaybeAssignDisallowIn(t3, r) {
              return this.disallowInAnd(() => this.parseMaybeAssign(t3, r));
            }
            parseMaybeAssignAllowIn(t3, r) {
              return this.allowInAnd(() => this.parseMaybeAssign(t3, r));
            }
            setOptionalParametersError(t3, r) {
              var e;
              t3.optionalParametersLoc = (e = r == null ? void 0 : r.loc) != null ? e : this.state.startLoc;
            }
            parseMaybeAssign(t3, r) {
              let e = this.state.startLoc;
              if (this.isContextual(106) && this.prodParam.hasYield) {
                let n = this.parseYield();
                return r && (n = r.call(this, n, e)), n;
              }
              let s;
              t3 ? s = false : (t3 = new Ct(), s = true);
              let { type: i } = this.state;
              (i === 10 || z(i)) && (this.state.potentialArrowAt = this.state.start);
              let a = this.parseMaybeConditional(t3);
              if (r && (a = r.call(this, a, e)), Go(this.state.type)) {
                let n = this.startNodeAt(e), o = this.state.value;
                if (n.operator = o, this.match(29)) {
                  this.toAssignable(a, true), n.left = a;
                  let c = e.index;
                  t3.doubleProtoLoc != null && t3.doubleProtoLoc.index >= c && (t3.doubleProtoLoc = null), t3.shorthandAssignLoc != null && t3.shorthandAssignLoc.index >= c && (t3.shorthandAssignLoc = null), t3.privateKeyLoc != null && t3.privateKeyLoc.index >= c && (this.checkDestructuringPrivate(t3), t3.privateKeyLoc = null);
                } else
                  n.left = a;
                return this.next(), n.right = this.parseMaybeAssign(), this.checkLVal(a, { in: this.finishNode(n, "AssignmentExpression") }), n;
              } else
                s && this.checkExpressionErrors(t3, true);
              return a;
            }
            parseMaybeConditional(t3) {
              let r = this.state.startLoc, e = this.state.potentialArrowAt, s = this.parseExprOps(t3);
              return this.shouldExitDescending(s, e) ? s : this.parseConditional(s, r, t3);
            }
            parseConditional(t3, r, e) {
              if (this.eat(17)) {
                let s = this.startNodeAt(r);
                return s.test = t3, s.consequent = this.parseMaybeAssignAllowIn(), this.expect(14), s.alternate = this.parseMaybeAssign(), this.finishNode(s, "ConditionalExpression");
              }
              return t3;
            }
            parseMaybeUnaryOrPrivate(t3) {
              return this.match(136) ? this.parsePrivateName() : this.parseMaybeUnary(t3);
            }
            parseExprOps(t3) {
              let r = this.state.startLoc, e = this.state.potentialArrowAt, s = this.parseMaybeUnaryOrPrivate(t3);
              return this.shouldExitDescending(s, e) ? s : this.parseExprOp(s, r, -1);
            }
            parseExprOp(t3, r, e) {
              if (this.isPrivateName(t3)) {
                let i = this.getPrivateNameSV(t3);
                (e >= ut(58) || !this.prodParam.hasIn || !this.match(58)) && this.raise(u.PrivateInExpectedIn, { at: t3, identifierName: i }), this.classScope.usePrivateName(i, t3.loc.start);
              }
              let s = this.state.type;
              if (Xo(s) && (this.prodParam.hasIn || !this.match(58))) {
                let i = ut(s);
                if (i > e) {
                  if (s === 39) {
                    if (this.expectPlugin("pipelineOperator"), this.state.inFSharpPipelineDirectBody)
                      return t3;
                    this.checkPipelineAtInfixOperator(t3, r);
                  }
                  let a = this.startNodeAt(r);
                  a.left = t3, a.operator = this.state.value;
                  let n = s === 41 || s === 42, o = s === 40;
                  if (o && (i = ut(42)), this.next(), s === 39 && this.hasPlugin(["pipelineOperator", { proposal: "minimal" }]) && this.state.type === 96 && this.prodParam.hasAwait)
                    throw this.raise(u.UnexpectedAwaitAfterPipelineBody, { at: this.state.startLoc });
                  a.right = this.parseExprOpRightExpr(s, i);
                  let c = this.finishNode(a, n || o ? "LogicalExpression" : "BinaryExpression"), p = this.state.type;
                  if (o && (p === 41 || p === 42) || n && p === 40)
                    throw this.raise(u.MixingCoalesceWithLogical, { at: this.state.startLoc });
                  return this.parseExprOp(c, r, e);
                }
              }
              return t3;
            }
            parseExprOpRightExpr(t3, r) {
              let e = this.state.startLoc;
              switch (t3) {
                case 39:
                  switch (this.getPluginOption("pipelineOperator", "proposal")) {
                    case "hack":
                      return this.withTopicBindingContext(() => this.parseHackPipeBody());
                    case "smart":
                      return this.withTopicBindingContext(() => {
                        if (this.prodParam.hasYield && this.isContextual(106))
                          throw this.raise(u.PipeBodyIsTighter, { at: this.state.startLoc });
                        return this.parseSmartPipelineBodyInStyle(this.parseExprOpBaseRightExpr(t3, r), e);
                      });
                    case "fsharp":
                      return this.withSoloAwaitPermittingContext(() => this.parseFSharpPipelineBody(r));
                  }
                default:
                  return this.parseExprOpBaseRightExpr(t3, r);
              }
            }
            parseExprOpBaseRightExpr(t3, r) {
              let e = this.state.startLoc;
              return this.parseExprOp(this.parseMaybeUnaryOrPrivate(), e, tl(t3) ? r - 1 : r);
            }
            parseHackPipeBody() {
              var t3;
              let { startLoc: r } = this.state, e = this.parseMaybeAssign();
              return j.has(e.type) && !((t3 = e.extra) != null && t3.parenthesized) && this.raise(u.PipeUnparenthesizedBody, { at: r, type: e.type }), this.topicReferenceWasUsedInCurrentContext() || this.raise(u.PipeTopicUnused, { at: r }), e;
            }
            checkExponentialAfterUnary(t3) {
              this.match(57) && this.raise(u.UnexpectedTokenUnaryExponentiation, { at: t3.argument });
            }
            parseMaybeUnary(t3, r) {
              let e = this.state.startLoc, s = this.isContextual(96);
              if (s && this.isAwaitAllowed()) {
                this.next();
                let o = this.parseAwait(e);
                return r || this.checkExponentialAfterUnary(o), o;
              }
              let i = this.match(34), a = this.startNode();
              if (Qo(this.state.type)) {
                a.operator = this.state.value, a.prefix = true, this.match(72) && this.expectPlugin("throwExpressions");
                let o = this.match(89);
                if (this.next(), a.argument = this.parseMaybeUnary(null, true), this.checkExpressionErrors(t3, true), this.state.strict && o) {
                  let c = a.argument;
                  c.type === "Identifier" ? this.raise(u.StrictDelete, { at: a }) : this.hasPropertyAsPrivateName(c) && this.raise(u.DeletePrivateField, { at: a });
                }
                if (!i)
                  return r || this.checkExponentialAfterUnary(a), this.finishNode(a, "UnaryExpression");
              }
              let n = this.parseUpdate(a, i, t3);
              if (s) {
                let { type: o } = this.state;
                if ((this.hasPlugin("v8intrinsic") ? Xt(o) : Xt(o) && !this.match(54)) && !this.isAmbiguousAwait())
                  return this.raiseOverwrite(u.AwaitNotInAsyncContext, { at: e }), this.parseAwait(e);
              }
              return n;
            }
            parseUpdate(t3, r, e) {
              if (r) {
                let a = t3;
                return this.checkLVal(a.argument, { in: this.finishNode(a, "UpdateExpression") }), t3;
              }
              let s = this.state.startLoc, i = this.parseExprSubscripts(e);
              if (this.checkExpressionErrors(e, false))
                return i;
              for (; Yo(this.state.type) && !this.canInsertSemicolon(); ) {
                let a = this.startNodeAt(s);
                a.operator = this.state.value, a.prefix = false, a.argument = i, this.next(), this.checkLVal(i, { in: i = this.finishNode(a, "UpdateExpression") });
              }
              return i;
            }
            parseExprSubscripts(t3) {
              let r = this.state.startLoc, e = this.state.potentialArrowAt, s = this.parseExprAtom(t3);
              return this.shouldExitDescending(s, e) ? s : this.parseSubscripts(s, r);
            }
            parseSubscripts(t3, r, e) {
              let s = { optionalChainMember: false, maybeAsyncArrow: this.atPossibleAsyncArrow(t3), stop: false };
              do
                t3 = this.parseSubscript(t3, r, e, s), s.maybeAsyncArrow = false;
              while (!s.stop);
              return t3;
            }
            parseSubscript(t3, r, e, s) {
              let { type: i } = this.state;
              if (!e && i === 15)
                return this.parseBind(t3, r, e, s);
              if (ct(i))
                return this.parseTaggedTemplateExpression(t3, r, s);
              let a = false;
              if (i === 18) {
                if (e && this.lookaheadCharCode() === 40)
                  return s.stop = true, t3;
                s.optionalChainMember = a = true, this.next();
              }
              if (!e && this.match(10))
                return this.parseCoverCallAndAsyncArrowHead(t3, r, s, a);
              {
                let n = this.eat(0);
                return n || a || this.eat(16) ? this.parseMember(t3, r, s, n, a) : (s.stop = true, t3);
              }
            }
            parseMember(t3, r, e, s, i) {
              let a = this.startNodeAt(r);
              return a.object = t3, a.computed = s, s ? (a.property = this.parseExpression(), this.expect(3)) : this.match(136) ? (t3.type === "Super" && this.raise(u.SuperPrivateField, { at: r }), this.classScope.usePrivateName(this.state.value, this.state.startLoc), a.property = this.parsePrivateName()) : a.property = this.parseIdentifier(true), e.optionalChainMember ? (a.optional = i, this.finishNode(a, "OptionalMemberExpression")) : this.finishNode(a, "MemberExpression");
            }
            parseBind(t3, r, e, s) {
              let i = this.startNodeAt(r);
              return i.object = t3, this.next(), i.callee = this.parseNoCallExpr(), s.stop = true, this.parseSubscripts(this.finishNode(i, "BindExpression"), r, e);
            }
            parseCoverCallAndAsyncArrowHead(t3, r, e, s) {
              let i = this.state.maybeInArrowParameters, a = null;
              this.state.maybeInArrowParameters = true, this.next();
              let n = this.startNodeAt(r);
              n.callee = t3;
              let { maybeAsyncArrow: o, optionalChainMember: c } = e;
              o && (this.expressionScope.enter($l()), a = new Ct()), c && (n.optional = s), s ? n.arguments = this.parseCallExpressionArguments(11) : n.arguments = this.parseCallExpressionArguments(11, t3.type === "Import", t3.type !== "Super", n, a);
              let p = this.finishCallExpression(n, c);
              return o && this.shouldParseAsyncArrow() && !s ? (e.stop = true, this.checkDestructuringPrivate(a), this.expressionScope.validateAsPattern(), this.expressionScope.exit(), p = this.parseAsyncArrowFromCallExpression(this.startNodeAt(r), p)) : (o && (this.checkExpressionErrors(a, true), this.expressionScope.exit()), this.toReferencedArguments(p)), this.state.maybeInArrowParameters = i, p;
            }
            toReferencedArguments(t3, r) {
              this.toReferencedListDeep(t3.arguments, r);
            }
            parseTaggedTemplateExpression(t3, r, e) {
              let s = this.startNodeAt(r);
              return s.tag = t3, s.quasi = this.parseTemplate(true), e.optionalChainMember && this.raise(u.OptionalChainingNoTemplate, { at: r }), this.finishNode(s, "TaggedTemplateExpression");
            }
            atPossibleAsyncArrow(t3) {
              return t3.type === "Identifier" && t3.name === "async" && this.state.lastTokEndLoc.index === t3.end && !this.canInsertSemicolon() && t3.end - t3.start === 5 && t3.start === this.state.potentialArrowAt;
            }
            finishCallExpression(t3, r) {
              if (t3.callee.type === "Import")
                if (t3.arguments.length === 2 && (this.hasPlugin("moduleAttributes") || this.expectPlugin("importAssertions")), t3.arguments.length === 0 || t3.arguments.length > 2)
                  this.raise(u.ImportCallArity, { at: t3, maxArgumentCount: this.hasPlugin("importAssertions") || this.hasPlugin("moduleAttributes") ? 2 : 1 });
                else
                  for (let e of t3.arguments)
                    e.type === "SpreadElement" && this.raise(u.ImportCallSpreadArgument, { at: e });
              return this.finishNode(t3, r ? "OptionalCallExpression" : "CallExpression");
            }
            parseCallExpressionArguments(t3, r, e, s, i) {
              let a = [], n = true, o = this.state.inFSharpPipelineDirectBody;
              for (this.state.inFSharpPipelineDirectBody = false; !this.eat(t3); ) {
                if (n)
                  n = false;
                else if (this.expect(12), this.match(t3)) {
                  r && !this.hasPlugin("importAssertions") && !this.hasPlugin("moduleAttributes") && this.raise(u.ImportCallArgumentTrailingComma, { at: this.state.lastTokStartLoc }), s && this.addTrailingCommaExtraToNode(s), this.next();
                  break;
                }
                a.push(this.parseExprListItem(false, i, e));
              }
              return this.state.inFSharpPipelineDirectBody = o, a;
            }
            shouldParseAsyncArrow() {
              return this.match(19) && !this.canInsertSemicolon();
            }
            parseAsyncArrowFromCallExpression(t3, r) {
              var e;
              return this.resetPreviousNodeTrailingComments(r), this.expect(19), this.parseArrowExpression(t3, r.arguments, true, (e = r.extra) == null ? void 0 : e.trailingCommaLoc), r.innerComments && Qe(t3, r.innerComments), r.callee.trailingComments && Qe(t3, r.callee.trailingComments), t3;
            }
            parseNoCallExpr() {
              let t3 = this.state.startLoc;
              return this.parseSubscripts(this.parseExprAtom(), t3, true);
            }
            parseExprAtom(t3) {
              let r, e = null, { type: s } = this.state;
              switch (s) {
                case 79:
                  return this.parseSuper();
                case 83:
                  return r = this.startNode(), this.next(), this.match(16) ? this.parseImportMetaProperty(r) : (this.match(10) || this.raise(u.UnsupportedImport, { at: this.state.lastTokStartLoc }), this.finishNode(r, "Import"));
                case 78:
                  return r = this.startNode(), this.next(), this.finishNode(r, "ThisExpression");
                case 90:
                  return this.parseDo(this.startNode(), false);
                case 56:
                case 31:
                  return this.readRegexp(), this.parseRegExpLiteral(this.state.value);
                case 132:
                  return this.parseNumericLiteral(this.state.value);
                case 133:
                  return this.parseBigIntLiteral(this.state.value);
                case 134:
                  return this.parseDecimalLiteral(this.state.value);
                case 131:
                  return this.parseStringLiteral(this.state.value);
                case 84:
                  return this.parseNullLiteral();
                case 85:
                  return this.parseBooleanLiteral(true);
                case 86:
                  return this.parseBooleanLiteral(false);
                case 10: {
                  let i = this.state.potentialArrowAt === this.state.start;
                  return this.parseParenAndDistinguishExpression(i);
                }
                case 2:
                case 1:
                  return this.parseArrayLike(this.state.type === 2 ? 4 : 3, false, true);
                case 0:
                  return this.parseArrayLike(3, true, false, t3);
                case 6:
                case 7:
                  return this.parseObjectLike(this.state.type === 6 ? 9 : 8, false, true);
                case 5:
                  return this.parseObjectLike(8, false, false, t3);
                case 68:
                  return this.parseFunctionOrFunctionSent();
                case 26:
                  e = this.parseDecorators();
                case 80:
                  return this.parseClass(this.maybeTakeDecorators(e, this.startNode()), false);
                case 77:
                  return this.parseNewOrNewTarget();
                case 25:
                case 24:
                  return this.parseTemplate(false);
                case 15: {
                  r = this.startNode(), this.next(), r.object = null;
                  let i = r.callee = this.parseNoCallExpr();
                  if (i.type === "MemberExpression")
                    return this.finishNode(r, "BindExpression");
                  throw this.raise(u.UnsupportedBind, { at: i });
                }
                case 136:
                  return this.raise(u.PrivateInExpectedIn, { at: this.state.startLoc, identifierName: this.state.value }), this.parsePrivateName();
                case 33:
                  return this.parseTopicReferenceThenEqualsSign(54, "%");
                case 32:
                  return this.parseTopicReferenceThenEqualsSign(44, "^");
                case 37:
                case 38:
                  return this.parseTopicReference("hack");
                case 44:
                case 54:
                case 27: {
                  let i = this.getPluginOption("pipelineOperator", "proposal");
                  if (i)
                    return this.parseTopicReference(i);
                  throw this.unexpected();
                }
                case 47: {
                  let i = this.input.codePointAt(this.nextTokenStart());
                  if (ge(i) || i === 62) {
                    this.expectOnePlugin(["jsx", "flow", "typescript"]);
                    break;
                  } else
                    throw this.unexpected();
                }
                default:
                  if (z(s)) {
                    if (this.isContextual(125) && this.lookaheadCharCode() === 123 && !this.hasFollowingLineBreak())
                      return this.parseModuleExpression();
                    let i = this.state.potentialArrowAt === this.state.start, a = this.state.containsEsc, n = this.parseIdentifier();
                    if (!a && n.name === "async" && !this.canInsertSemicolon()) {
                      let { type: o } = this.state;
                      if (o === 68)
                        return this.resetPreviousNodeTrailingComments(n), this.next(), this.parseAsyncFunctionExpression(this.startNodeAtNode(n));
                      if (z(o))
                        return this.lookaheadCharCode() === 61 ? this.parseAsyncArrowUnaryFunction(this.startNodeAtNode(n)) : n;
                      if (o === 90)
                        return this.resetPreviousNodeTrailingComments(n), this.parseDo(this.startNodeAtNode(n), true);
                    }
                    return i && this.match(19) && !this.canInsertSemicolon() ? (this.next(), this.parseArrowExpression(this.startNodeAtNode(n), [n], false)) : n;
                  } else
                    throw this.unexpected();
              }
            }
            parseTopicReferenceThenEqualsSign(t3, r) {
              let e = this.getPluginOption("pipelineOperator", "proposal");
              if (e)
                return this.state.type = t3, this.state.value = r, this.state.pos--, this.state.end--, this.state.endLoc = y(this.state.endLoc, -1), this.parseTopicReference(e);
              throw this.unexpected();
            }
            parseTopicReference(t3) {
              let r = this.startNode(), e = this.state.startLoc, s = this.state.type;
              return this.next(), this.finishTopicReference(r, e, t3, s);
            }
            finishTopicReference(t3, r, e, s) {
              if (this.testTopicReferenceConfiguration(e, r, s)) {
                let i = e === "smart" ? "PipelinePrimaryTopicReference" : "TopicReference";
                return this.topicReferenceIsAllowedInCurrentContext() || this.raise(e === "smart" ? u.PrimaryTopicNotAllowed : u.PipeTopicUnbound, { at: r }), this.registerTopicReference(), this.finishNode(t3, i);
              } else
                throw this.raise(u.PipeTopicUnconfiguredToken, { at: r, token: Ee(s) });
            }
            testTopicReferenceConfiguration(t3, r, e) {
              switch (t3) {
                case "hack":
                  return this.hasPlugin(["pipelineOperator", { topicToken: Ee(e) }]);
                case "smart":
                  return e === 27;
                default:
                  throw this.raise(u.PipeTopicRequiresHackPipes, { at: r });
              }
            }
            parseAsyncArrowUnaryFunction(t3) {
              this.prodParam.enter(Et(true, this.prodParam.hasYield));
              let r = [this.parseIdentifier()];
              return this.prodParam.exit(), this.hasPrecedingLineBreak() && this.raise(u.LineTerminatorBeforeArrow, { at: this.state.curPosition() }), this.expect(19), this.parseArrowExpression(t3, r, true);
            }
            parseDo(t3, r) {
              this.expectPlugin("doExpressions"), r && this.expectPlugin("asyncDoExpressions"), t3.async = r, this.next();
              let e = this.state.labels;
              return this.state.labels = [], r ? (this.prodParam.enter(vt), t3.body = this.parseBlock(), this.prodParam.exit()) : t3.body = this.parseBlock(), this.state.labels = e, this.finishNode(t3, "DoExpression");
            }
            parseSuper() {
              let t3 = this.startNode();
              return this.next(), this.match(10) && !this.scope.allowDirectSuper && !this.options.allowSuperOutsideMethod ? this.raise(u.SuperNotAllowed, { at: t3 }) : !this.scope.allowSuper && !this.options.allowSuperOutsideMethod && this.raise(u.UnexpectedSuper, { at: t3 }), !this.match(10) && !this.match(0) && !this.match(16) && this.raise(u.UnsupportedSuper, { at: t3 }), this.finishNode(t3, "Super");
            }
            parsePrivateName() {
              let t3 = this.startNode(), r = this.startNodeAt(y(this.state.startLoc, 1)), e = this.state.value;
              return this.next(), t3.id = this.createIdentifier(r, e), this.finishNode(t3, "PrivateName");
            }
            parseFunctionOrFunctionSent() {
              let t3 = this.startNode();
              if (this.next(), this.prodParam.hasYield && this.match(16)) {
                let r = this.createIdentifier(this.startNodeAtNode(t3), "function");
                return this.next(), this.match(102) ? this.expectPlugin("functionSent") : this.hasPlugin("functionSent") || this.unexpected(), this.parseMetaProperty(t3, r, "sent");
              }
              return this.parseFunction(t3);
            }
            parseMetaProperty(t3, r, e) {
              t3.meta = r;
              let s = this.state.containsEsc;
              return t3.property = this.parseIdentifier(true), (t3.property.name !== e || s) && this.raise(u.UnsupportedMetaProperty, { at: t3.property, target: r.name, onlyValidPropertyName: e }), this.finishNode(t3, "MetaProperty");
            }
            parseImportMetaProperty(t3) {
              let r = this.createIdentifier(this.startNodeAtNode(t3), "import");
              return this.next(), this.isContextual(100) && (this.inModule || this.raise(u.ImportMetaOutsideModule, { at: r }), this.sawUnambiguousESM = true), this.parseMetaProperty(t3, r, "meta");
            }
            parseLiteralAtNode(t3, r, e) {
              return this.addExtra(e, "rawValue", t3), this.addExtra(e, "raw", this.input.slice(e.start, this.state.end)), e.value = t3, this.next(), this.finishNode(e, r);
            }
            parseLiteral(t3, r) {
              let e = this.startNode();
              return this.parseLiteralAtNode(t3, r, e);
            }
            parseStringLiteral(t3) {
              return this.parseLiteral(t3, "StringLiteral");
            }
            parseNumericLiteral(t3) {
              return this.parseLiteral(t3, "NumericLiteral");
            }
            parseBigIntLiteral(t3) {
              return this.parseLiteral(t3, "BigIntLiteral");
            }
            parseDecimalLiteral(t3) {
              return this.parseLiteral(t3, "DecimalLiteral");
            }
            parseRegExpLiteral(t3) {
              let r = this.parseLiteral(t3.value, "RegExpLiteral");
              return r.pattern = t3.pattern, r.flags = t3.flags, r;
            }
            parseBooleanLiteral(t3) {
              let r = this.startNode();
              return r.value = t3, this.next(), this.finishNode(r, "BooleanLiteral");
            }
            parseNullLiteral() {
              let t3 = this.startNode();
              return this.next(), this.finishNode(t3, "NullLiteral");
            }
            parseParenAndDistinguishExpression(t3) {
              let r = this.state.startLoc, e;
              this.next(), this.expressionScope.enter(Ul());
              let s = this.state.maybeInArrowParameters, i = this.state.inFSharpPipelineDirectBody;
              this.state.maybeInArrowParameters = true, this.state.inFSharpPipelineDirectBody = false;
              let a = this.state.startLoc, n = [], o = new Ct(), c = true, p, m;
              for (; !this.match(11); ) {
                if (c)
                  c = false;
                else if (this.expect(12, o.optionalParametersLoc === null ? null : o.optionalParametersLoc), this.match(11)) {
                  m = this.state.startLoc;
                  break;
                }
                if (this.match(21)) {
                  let b = this.state.startLoc;
                  if (p = this.state.startLoc, n.push(this.parseParenItem(this.parseRestBinding(), b)), !this.checkCommaAfterRest(41))
                    break;
                } else
                  n.push(this.parseMaybeAssignAllowIn(o, this.parseParenItem));
              }
              let x = this.state.lastTokEndLoc;
              this.expect(11), this.state.maybeInArrowParameters = s, this.state.inFSharpPipelineDirectBody = i;
              let A = this.startNodeAt(r);
              return t3 && this.shouldParseArrow(n) && (A = this.parseArrow(A)) ? (this.checkDestructuringPrivate(o), this.expressionScope.validateAsPattern(), this.expressionScope.exit(), this.parseArrowExpression(A, n, false), A) : (this.expressionScope.exit(), n.length || this.unexpected(this.state.lastTokStartLoc), m && this.unexpected(m), p && this.unexpected(p), this.checkExpressionErrors(o, true), this.toReferencedListDeep(n, true), n.length > 1 ? (e = this.startNodeAt(a), e.expressions = n, this.finishNode(e, "SequenceExpression"), this.resetEndLocation(e, x)) : e = n[0], this.wrapParenthesis(r, e));
            }
            wrapParenthesis(t3, r) {
              if (!this.options.createParenthesizedExpressions)
                return this.addExtra(r, "parenthesized", true), this.addExtra(r, "parenStart", t3.index), this.takeSurroundingComments(r, t3.index, this.state.lastTokEndLoc.index), r;
              let e = this.startNodeAt(t3);
              return e.expression = r, this.finishNode(e, "ParenthesizedExpression");
            }
            shouldParseArrow(t3) {
              return !this.canInsertSemicolon();
            }
            parseArrow(t3) {
              if (this.eat(19))
                return t3;
            }
            parseParenItem(t3, r) {
              return t3;
            }
            parseNewOrNewTarget() {
              let t3 = this.startNode();
              if (this.next(), this.match(16)) {
                let r = this.createIdentifier(this.startNodeAtNode(t3), "new");
                this.next();
                let e = this.parseMetaProperty(t3, r, "target");
                return !this.scope.inNonArrowFunction && !this.scope.inClass && this.raise(u.UnexpectedNewTarget, { at: e }), e;
              }
              return this.parseNew(t3);
            }
            parseNew(t3) {
              if (this.parseNewCallee(t3), this.eat(10)) {
                let r = this.parseExprList(11);
                this.toReferencedList(r), t3.arguments = r;
              } else
                t3.arguments = [];
              return this.finishNode(t3, "NewExpression");
            }
            parseNewCallee(t3) {
              t3.callee = this.parseNoCallExpr(), t3.callee.type === "Import" ? this.raise(u.ImportCallNotNewExpression, { at: t3.callee }) : this.isOptionalChain(t3.callee) ? this.raise(u.OptionalChainingNoNew, { at: this.state.lastTokEndLoc }) : this.eat(18) && this.raise(u.OptionalChainingNoNew, { at: this.state.startLoc });
            }
            parseTemplateElement(t3) {
              let { start: r, startLoc: e, end: s, value: i } = this.state, a = r + 1, n = this.startNodeAt(y(e, 1));
              i === null && (t3 || this.raise(u.InvalidEscapeSequenceTemplate, { at: y(this.state.firstInvalidTemplateEscapePos, 1) }));
              let o = this.match(24), c = o ? -1 : -2, p = s + c;
              n.value = { raw: this.input.slice(a, p).replace(/\r\n?/g, `
`), cooked: i === null ? null : i.slice(1, c) }, n.tail = o, this.next();
              let m = this.finishNode(n, "TemplateElement");
              return this.resetEndLocation(m, y(this.state.lastTokEndLoc, c)), m;
            }
            parseTemplate(t3) {
              let r = this.startNode();
              r.expressions = [];
              let e = this.parseTemplateElement(t3);
              for (r.quasis = [e]; !e.tail; )
                r.expressions.push(this.parseTemplateSubstitution()), this.readTemplateContinuation(), r.quasis.push(e = this.parseTemplateElement(t3));
              return this.finishNode(r, "TemplateLiteral");
            }
            parseTemplateSubstitution() {
              return this.parseExpression();
            }
            parseObjectLike(t3, r, e, s) {
              e && this.expectPlugin("recordAndTuple");
              let i = this.state.inFSharpPipelineDirectBody;
              this.state.inFSharpPipelineDirectBody = false;
              let a = /* @__PURE__ */ Object.create(null), n = true, o = this.startNode();
              for (o.properties = [], this.next(); !this.match(t3); ) {
                if (n)
                  n = false;
                else if (this.expect(12), this.match(t3)) {
                  this.addTrailingCommaExtraToNode(o);
                  break;
                }
                let p;
                r ? p = this.parseBindingProperty() : (p = this.parsePropertyDefinition(s), this.checkProto(p, e, a, s)), e && !this.isObjectProperty(p) && p.type !== "SpreadElement" && this.raise(u.InvalidRecordProperty, { at: p }), p.shorthand && this.addExtra(p, "shorthand", true), o.properties.push(p);
              }
              this.next(), this.state.inFSharpPipelineDirectBody = i;
              let c = "ObjectExpression";
              return r ? c = "ObjectPattern" : e && (c = "RecordExpression"), this.finishNode(o, c);
            }
            addTrailingCommaExtraToNode(t3) {
              this.addExtra(t3, "trailingComma", this.state.lastTokStart), this.addExtra(t3, "trailingCommaLoc", this.state.lastTokStartLoc, false);
            }
            maybeAsyncOrAccessorProp(t3) {
              return !t3.computed && t3.key.type === "Identifier" && (this.isLiteralPropertyName() || this.match(0) || this.match(55));
            }
            parsePropertyDefinition(t3) {
              let r = [];
              if (this.match(26))
                for (this.hasPlugin("decorators") && this.raise(u.UnsupportedPropertyDecorator, { at: this.state.startLoc }); this.match(26); )
                  r.push(this.parseDecorator());
              let e = this.startNode(), s = false, i = false, a;
              if (this.match(21))
                return r.length && this.unexpected(), this.parseSpread();
              r.length && (e.decorators = r, r = []), e.method = false, t3 && (a = this.state.startLoc);
              let n = this.eat(55);
              this.parsePropertyNamePrefixOperator(e);
              let o = this.state.containsEsc, c = this.parsePropertyName(e, t3);
              if (!n && !o && this.maybeAsyncOrAccessorProp(e)) {
                let p = c.name;
                p === "async" && !this.hasPrecedingLineBreak() && (s = true, this.resetPreviousNodeTrailingComments(c), n = this.eat(55), this.parsePropertyName(e)), (p === "get" || p === "set") && (i = true, this.resetPreviousNodeTrailingComments(c), e.kind = p, this.match(55) && (n = true, this.raise(u.AccessorIsGenerator, { at: this.state.curPosition(), kind: p }), this.next()), this.parsePropertyName(e));
              }
              return this.parseObjPropValue(e, a, n, s, false, i, t3);
            }
            getGetterSetterExpectedParamCount(t3) {
              return t3.kind === "get" ? 0 : 1;
            }
            getObjectOrClassMethodParams(t3) {
              return t3.params;
            }
            checkGetterSetterParams(t3) {
              var r;
              let e = this.getGetterSetterExpectedParamCount(t3), s = this.getObjectOrClassMethodParams(t3);
              s.length !== e && this.raise(t3.kind === "get" ? u.BadGetterArity : u.BadSetterArity, { at: t3 }), t3.kind === "set" && ((r = s[s.length - 1]) == null ? void 0 : r.type) === "RestElement" && this.raise(u.BadSetterRestParameter, { at: t3 });
            }
            parseObjectMethod(t3, r, e, s, i) {
              if (i) {
                let a = this.parseMethod(t3, r, false, false, false, "ObjectMethod");
                return this.checkGetterSetterParams(a), a;
              }
              if (e || r || this.match(10))
                return s && this.unexpected(), t3.kind = "method", t3.method = true, this.parseMethod(t3, r, e, false, false, "ObjectMethod");
            }
            parseObjectProperty(t3, r, e, s) {
              if (t3.shorthand = false, this.eat(14))
                return t3.value = e ? this.parseMaybeDefault(this.state.startLoc) : this.parseMaybeAssignAllowIn(s), this.finishNode(t3, "ObjectProperty");
              if (!t3.computed && t3.key.type === "Identifier") {
                if (this.checkReservedWord(t3.key.name, t3.key.loc.start, true, false), e)
                  t3.value = this.parseMaybeDefault(r, Te(t3.key));
                else if (this.match(29)) {
                  let i = this.state.startLoc;
                  s != null ? s.shorthandAssignLoc === null && (s.shorthandAssignLoc = i) : this.raise(u.InvalidCoverInitializedName, { at: i }), t3.value = this.parseMaybeDefault(r, Te(t3.key));
                } else
                  t3.value = Te(t3.key);
                return t3.shorthand = true, this.finishNode(t3, "ObjectProperty");
              }
            }
            parseObjPropValue(t3, r, e, s, i, a, n) {
              let o = this.parseObjectMethod(t3, e, s, i, a) || this.parseObjectProperty(t3, r, i, n);
              return o || this.unexpected(), o;
            }
            parsePropertyName(t3, r) {
              if (this.eat(0))
                t3.computed = true, t3.key = this.parseMaybeAssignAllowIn(), this.expect(3);
              else {
                let { type: e, value: s } = this.state, i;
                if (ye(e))
                  i = this.parseIdentifier(true);
                else
                  switch (e) {
                    case 132:
                      i = this.parseNumericLiteral(s);
                      break;
                    case 131:
                      i = this.parseStringLiteral(s);
                      break;
                    case 133:
                      i = this.parseBigIntLiteral(s);
                      break;
                    case 134:
                      i = this.parseDecimalLiteral(s);
                      break;
                    case 136: {
                      let a = this.state.startLoc;
                      r != null ? r.privateKeyLoc === null && (r.privateKeyLoc = a) : this.raise(u.UnexpectedPrivateField, { at: a }), i = this.parsePrivateName();
                      break;
                    }
                    default:
                      throw this.unexpected();
                  }
                t3.key = i, e !== 136 && (t3.computed = false);
              }
              return t3.key;
            }
            initFunction(t3, r) {
              t3.id = null, t3.generator = false, t3.async = r;
            }
            parseMethod(t3, r, e, s, i, a) {
              let n = arguments.length > 6 && arguments[6] !== void 0 ? arguments[6] : false;
              this.initFunction(t3, e), t3.generator = r;
              let o = s;
              this.scope.enter(Pe | pt | (n ? Ne : 0) | (i ? wr : 0)), this.prodParam.enter(Et(e, t3.generator)), this.parseFunctionParams(t3, o);
              let c = this.parseFunctionBodyAndFinish(t3, a, true);
              return this.prodParam.exit(), this.scope.exit(), c;
            }
            parseArrayLike(t3, r, e, s) {
              e && this.expectPlugin("recordAndTuple");
              let i = this.state.inFSharpPipelineDirectBody;
              this.state.inFSharpPipelineDirectBody = false;
              let a = this.startNode();
              return this.next(), a.elements = this.parseExprList(t3, !e, s, a), this.state.inFSharpPipelineDirectBody = i, this.finishNode(a, e ? "TupleExpression" : "ArrayExpression");
            }
            parseArrowExpression(t3, r, e, s) {
              this.scope.enter(Pe | ts);
              let i = Et(e, false);
              !this.match(5) && this.prodParam.hasIn && (i |= He), this.prodParam.enter(i), this.initFunction(t3, e);
              let a = this.state.maybeInArrowParameters;
              return r && (this.state.maybeInArrowParameters = true, this.setArrowFunctionParameters(t3, r, s)), this.state.maybeInArrowParameters = false, this.parseFunctionBody(t3, true), this.prodParam.exit(), this.scope.exit(), this.state.maybeInArrowParameters = a, this.finishNode(t3, "ArrowFunctionExpression");
            }
            setArrowFunctionParameters(t3, r, e) {
              this.toAssignableList(r, e, false), t3.params = r;
            }
            parseFunctionBodyAndFinish(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              return this.parseFunctionBody(t3, false, e), this.finishNode(t3, r);
            }
            parseFunctionBody(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, s = r && !this.match(5);
              if (this.expressionScope.enter(Vr()), s)
                t3.body = this.parseMaybeAssign(), this.checkParams(t3, false, r, false);
              else {
                let i = this.state.strict, a = this.state.labels;
                this.state.labels = [], this.prodParam.enter(this.prodParam.currentFlags() | Wr), t3.body = this.parseBlock(true, false, (n) => {
                  let o = !this.isSimpleParamList(t3.params);
                  n && o && this.raise(u.IllegalLanguageModeDirective, { at: (t3.kind === "method" || t3.kind === "constructor") && t3.key ? t3.key.loc.end : t3 });
                  let c = !i && this.state.strict;
                  this.checkParams(t3, !this.state.strict && !r && !e && !o, r, c), this.state.strict && t3.id && this.checkIdentifier(t3.id, dl, c);
                }), this.prodParam.exit(), this.state.labels = a;
              }
              this.expressionScope.exit();
            }
            isSimpleParameter(t3) {
              return t3.type === "Identifier";
            }
            isSimpleParamList(t3) {
              for (let r = 0, e = t3.length; r < e; r++)
                if (!this.isSimpleParameter(t3[r]))
                  return false;
              return true;
            }
            checkParams(t3, r, e) {
              let s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true, i = !r && /* @__PURE__ */ new Set(), a = { type: "FormalParameters" };
              for (let n of t3.params)
                this.checkLVal(n, { in: a, binding: xt, checkClashes: i, strictModeChanged: s });
            }
            parseExprList(t3, r, e, s) {
              let i = [], a = true;
              for (; !this.eat(t3); ) {
                if (a)
                  a = false;
                else if (this.expect(12), this.match(t3)) {
                  s && this.addTrailingCommaExtraToNode(s), this.next();
                  break;
                }
                i.push(this.parseExprListItem(r, e));
              }
              return i;
            }
            parseExprListItem(t3, r, e) {
              let s;
              if (this.match(12))
                t3 || this.raise(u.UnexpectedToken, { at: this.state.curPosition(), unexpected: "," }), s = null;
              else if (this.match(21)) {
                let i = this.state.startLoc;
                s = this.parseParenItem(this.parseSpread(r), i);
              } else if (this.match(17)) {
                this.expectPlugin("partialApplication"), e || this.raise(u.UnexpectedArgumentPlaceholder, { at: this.state.startLoc });
                let i = this.startNode();
                this.next(), s = this.finishNode(i, "ArgumentPlaceholder");
              } else
                s = this.parseMaybeAssignAllowIn(r, this.parseParenItem);
              return s;
            }
            parseIdentifier(t3) {
              let r = this.startNode(), e = this.parseIdentifierName(t3);
              return this.createIdentifier(r, e);
            }
            createIdentifier(t3, r) {
              return t3.name = r, t3.loc.identifierName = r, this.finishNode(t3, "Identifier");
            }
            parseIdentifierName(t3) {
              let r, { startLoc: e, type: s } = this.state;
              if (ye(s))
                r = this.state.value;
              else
                throw this.unexpected();
              let i = Ko(s);
              return t3 ? i && this.replaceToken(130) : this.checkReservedWord(r, e, i, false), this.next(), r;
            }
            checkReservedWord(t3, r, e, s) {
              if (t3.length > 10 || !cl(t3))
                return;
              if (t3 === "yield") {
                if (this.prodParam.hasYield) {
                  this.raise(u.YieldBindingIdentifier, { at: r });
                  return;
                }
              } else if (t3 === "await") {
                if (this.prodParam.hasAwait) {
                  this.raise(u.AwaitBindingIdentifier, { at: r });
                  return;
                }
                if (this.scope.inStaticBlock) {
                  this.raise(u.AwaitBindingIdentifierInStaticBlock, { at: r });
                  return;
                }
                this.expressionScope.recordAsyncArrowParametersError({ at: r });
              } else if (t3 === "arguments" && this.scope.inClassAndNotInNonArrowFunction) {
                this.raise(u.ArgumentsInClass, { at: r });
                return;
              }
              if (e && ll(t3)) {
                this.raise(u.UnexpectedKeyword, { at: r, keyword: t3 });
                return;
              }
              (this.state.strict ? s ? br : Er : vr)(t3, this.inModule) && this.raise(u.UnexpectedReservedWord, { at: r, reservedWord: t3 });
            }
            isAwaitAllowed() {
              return !!(this.prodParam.hasAwait || this.options.allowAwaitOutsideFunction && !this.scope.inFunction);
            }
            parseAwait(t3) {
              let r = this.startNodeAt(t3);
              return this.expressionScope.recordParameterInitializerError(u.AwaitExpressionFormalParameter, { at: r }), this.eat(55) && this.raise(u.ObsoleteAwaitStar, { at: r }), !this.scope.inFunction && !this.options.allowAwaitOutsideFunction && (this.isAmbiguousAwait() ? this.ambiguousScriptDifferentAst = true : this.sawUnambiguousESM = true), this.state.soloAwait || (r.argument = this.parseMaybeUnary(null, true)), this.finishNode(r, "AwaitExpression");
            }
            isAmbiguousAwait() {
              if (this.hasPrecedingLineBreak())
                return true;
              let { type: t3 } = this.state;
              return t3 === 53 || t3 === 10 || t3 === 0 || ct(t3) || t3 === 101 && !this.state.containsEsc || t3 === 135 || t3 === 56 || this.hasPlugin("v8intrinsic") && t3 === 54;
            }
            parseYield() {
              let t3 = this.startNode();
              this.expressionScope.recordParameterInitializerError(u.YieldInParameter, { at: t3 }), this.next();
              let r = false, e = null;
              if (!this.hasPrecedingLineBreak())
                switch (r = this.eat(55), this.state.type) {
                  case 13:
                  case 137:
                  case 8:
                  case 11:
                  case 3:
                  case 9:
                  case 14:
                  case 12:
                    if (!r)
                      break;
                  default:
                    e = this.parseMaybeAssign();
                }
              return t3.delegate = r, t3.argument = e, this.finishNode(t3, "YieldExpression");
            }
            checkPipelineAtInfixOperator(t3, r) {
              this.hasPlugin(["pipelineOperator", { proposal: "smart" }]) && t3.type === "SequenceExpression" && this.raise(u.PipelineHeadSequenceExpression, { at: r });
            }
            parseSmartPipelineBodyInStyle(t3, r) {
              if (this.isSimpleReference(t3)) {
                let e = this.startNodeAt(r);
                return e.callee = t3, this.finishNode(e, "PipelineBareFunction");
              } else {
                let e = this.startNodeAt(r);
                return this.checkSmartPipeTopicBodyEarlyErrors(r), e.expression = t3, this.finishNode(e, "PipelineTopicExpression");
              }
            }
            isSimpleReference(t3) {
              switch (t3.type) {
                case "MemberExpression":
                  return !t3.computed && this.isSimpleReference(t3.object);
                case "Identifier":
                  return true;
                default:
                  return false;
              }
            }
            checkSmartPipeTopicBodyEarlyErrors(t3) {
              if (this.match(19))
                throw this.raise(u.PipelineBodyNoArrow, { at: this.state.startLoc });
              this.topicReferenceWasUsedInCurrentContext() || this.raise(u.PipelineTopicUnused, { at: t3 });
            }
            withTopicBindingContext(t3) {
              let r = this.state.topicContext;
              this.state.topicContext = { maxNumOfResolvableTopics: 1, maxTopicIndex: null };
              try {
                return t3();
              } finally {
                this.state.topicContext = r;
              }
            }
            withSmartMixTopicForbiddingContext(t3) {
              if (this.hasPlugin(["pipelineOperator", { proposal: "smart" }])) {
                let r = this.state.topicContext;
                this.state.topicContext = { maxNumOfResolvableTopics: 0, maxTopicIndex: null };
                try {
                  return t3();
                } finally {
                  this.state.topicContext = r;
                }
              } else
                return t3();
            }
            withSoloAwaitPermittingContext(t3) {
              let r = this.state.soloAwait;
              this.state.soloAwait = true;
              try {
                return t3();
              } finally {
                this.state.soloAwait = r;
              }
            }
            allowInAnd(t3) {
              let r = this.prodParam.currentFlags();
              if (He & ~r) {
                this.prodParam.enter(r | He);
                try {
                  return t3();
                } finally {
                  this.prodParam.exit();
                }
              }
              return t3();
            }
            disallowInAnd(t3) {
              let r = this.prodParam.currentFlags();
              if (He & r) {
                this.prodParam.enter(r & ~He);
                try {
                  return t3();
                } finally {
                  this.prodParam.exit();
                }
              }
              return t3();
            }
            registerTopicReference() {
              this.state.topicContext.maxTopicIndex = 0;
            }
            topicReferenceIsAllowedInCurrentContext() {
              return this.state.topicContext.maxNumOfResolvableTopics >= 1;
            }
            topicReferenceWasUsedInCurrentContext() {
              return this.state.topicContext.maxTopicIndex != null && this.state.topicContext.maxTopicIndex >= 0;
            }
            parseFSharpPipelineBody(t3) {
              let r = this.state.startLoc;
              this.state.potentialArrowAt = this.state.start;
              let e = this.state.inFSharpPipelineDirectBody;
              this.state.inFSharpPipelineDirectBody = true;
              let s = this.parseExprOp(this.parseMaybeUnaryOrPrivate(), r, t3);
              return this.state.inFSharpPipelineDirectBody = e, s;
            }
            parseModuleExpression() {
              this.expectPlugin("moduleBlocks");
              let t3 = this.startNode();
              this.next(), this.match(5) || this.unexpected(null, 5);
              let r = this.startNodeAt(this.state.endLoc);
              this.next();
              let e = this.initializeScopes(true);
              this.enterInitialScopes();
              try {
                t3.body = this.parseProgram(r, 8, "module");
              } finally {
                e();
              }
              return this.finishNode(t3, "ModuleExpression");
            }
            parsePropertyNamePrefixOperator(t3) {
            }
          }, gs = { kind: "loop" }, gh = { kind: "switch" }, ie = { Expression: 0, Declaration: 1, HangingDeclaration: 2, NullableId: 4, Async: 8 }, ae = { StatementOnly: 0, AllowImportExport: 1, AllowDeclaration: 2, AllowFunctionDeclaration: 4, AllowLabeledFunction: 8 }, Ph = /[\uD800-\uDFFF]/u, Ps = /in(?:stanceof)?/y;
          function Ah(t3, r) {
            for (let e = 0; e < t3.length; e++) {
              let s = t3[e], { type: i } = s;
              if (typeof i == "number") {
                {
                  if (i === 136) {
                    let { loc: a, start: n, value: o, end: c } = s, p = n + 1, m = y(a.start, 1);
                    t3.splice(e, 1, new Se({ type: xe(27), value: "#", start: n, end: p, startLoc: a.start, endLoc: m }), new Se({ type: xe(130), value: o, start: p, end: c, startLoc: m, endLoc: a.end })), e++;
                    continue;
                  }
                  if (ct(i)) {
                    let { loc: a, start: n, value: o, end: c } = s, p = n + 1, m = y(a.start, 1), x;
                    r.charCodeAt(n) === 96 ? x = new Se({ type: xe(22), value: "`", start: n, end: p, startLoc: a.start, endLoc: m }) : x = new Se({ type: xe(8), value: "}", start: n, end: p, startLoc: a.start, endLoc: m });
                    let A, b, O, R;
                    i === 24 ? (b = c - 1, O = y(a.end, -1), A = o === null ? null : o.slice(1, -1), R = new Se({ type: xe(22), value: "`", start: b, end: c, startLoc: O, endLoc: a.end })) : (b = c - 2, O = y(a.end, -2), A = o === null ? null : o.slice(1, -2), R = new Se({ type: xe(23), value: "${", start: b, end: c, startLoc: O, endLoc: a.end })), t3.splice(e, 1, x, new Se({ type: xe(20), value: A, start: p, end: b, startLoc: m, endLoc: O }), R), e += 2;
                    continue;
                  }
                }
                s.type = xe(i);
              }
            }
            return t3;
          }
          var Th = class extends xh {
            parseTopLevel(t3, r) {
              return t3.program = this.parseProgram(r), t3.comments = this.state.comments, this.options.tokens && (t3.tokens = Ah(this.tokens, this.input)), this.finishNode(t3, "File");
            }
            parseProgram(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 137, e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : this.options.sourceType;
              if (t3.sourceType = e, t3.interpreter = this.parseInterpreterDirective(), this.parseBlockBody(t3, true, true, r), this.inModule && !this.options.allowUndeclaredExports && this.scope.undefinedExports.size > 0)
                for (let [i, a] of Array.from(this.scope.undefinedExports))
                  this.raise(u.ModuleExportUndefined, { at: a, localName: i });
              let s;
              return r === 137 ? s = this.finishNode(t3, "Program") : s = this.finishNodeAt(t3, "Program", y(this.state.startLoc, -1)), s;
            }
            stmtToDirective(t3) {
              let r = t3;
              r.type = "Directive", r.value = r.expression, delete r.expression;
              let e = r.value, s = e.value, i = this.input.slice(e.start, e.end), a = e.value = i.slice(1, -1);
              return this.addExtra(e, "raw", i), this.addExtra(e, "rawValue", a), this.addExtra(e, "expressionValue", s), e.type = "DirectiveLiteral", r;
            }
            parseInterpreterDirective() {
              if (!this.match(28))
                return null;
              let t3 = this.startNode();
              return t3.value = this.state.value, this.next(), this.finishNode(t3, "InterpreterDirective");
            }
            isLet() {
              return this.isContextual(99) ? this.hasFollowingBindingAtom() : false;
            }
            chStartsBindingIdentifier(t3, r) {
              if (ge(t3)) {
                if (Ps.lastIndex = r, Ps.test(this.input)) {
                  let e = this.codePointAtPos(Ps.lastIndex);
                  if (!Re(e) && e !== 92)
                    return false;
                }
                return true;
              } else
                return t3 === 92;
            }
            chStartsBindingPattern(t3) {
              return t3 === 91 || t3 === 123;
            }
            hasFollowingBindingAtom() {
              let t3 = this.nextTokenStart(), r = this.codePointAtPos(t3);
              return this.chStartsBindingPattern(r) || this.chStartsBindingIdentifier(r, t3);
            }
            hasFollowingBindingIdentifier() {
              let t3 = this.nextTokenStart(), r = this.codePointAtPos(t3);
              return this.chStartsBindingIdentifier(r, t3);
            }
            startsUsingForOf() {
              let t3 = this.lookahead();
              return t3.type === 101 && !t3.containsEsc ? false : (this.expectPlugin("explicitResourceManagement"), true);
            }
            parseModuleItem() {
              return this.parseStatementLike(ae.AllowImportExport | ae.AllowDeclaration | ae.AllowFunctionDeclaration | ae.AllowLabeledFunction);
            }
            parseStatementListItem() {
              return this.parseStatementLike(ae.AllowDeclaration | ae.AllowFunctionDeclaration | ae.AllowLabeledFunction);
            }
            parseStatementOrFunctionDeclaration(t3) {
              return this.parseStatementLike(ae.AllowFunctionDeclaration | (t3 ? 0 : ae.AllowLabeledFunction));
            }
            parseStatement() {
              return this.parseStatementLike(ae.StatementOnly);
            }
            parseStatementLike(t3) {
              let r = null;
              return this.match(26) && (r = this.parseDecorators(true)), this.parseStatementContent(t3, r);
            }
            parseStatementContent(t3, r) {
              let e = this.state.type, s = this.startNode(), i = !!(t3 & ae.AllowDeclaration), a = !!(t3 & ae.AllowFunctionDeclaration), n = t3 & ae.AllowImportExport;
              switch (e) {
                case 60:
                  return this.parseBreakContinueStatement(s, true);
                case 63:
                  return this.parseBreakContinueStatement(s, false);
                case 64:
                  return this.parseDebuggerStatement(s);
                case 90:
                  return this.parseDoWhileStatement(s);
                case 91:
                  return this.parseForStatement(s);
                case 68:
                  if (this.lookaheadCharCode() === 46)
                    break;
                  return i || (this.state.strict ? this.raise(u.StrictFunction, { at: this.state.startLoc }) : a || this.raise(u.SloppyFunction, { at: this.state.startLoc })), this.parseFunctionStatement(s, false, !i && a);
                case 80:
                  return i || this.unexpected(), this.parseClass(this.maybeTakeDecorators(r, s), true);
                case 69:
                  return this.parseIfStatement(s);
                case 70:
                  return this.parseReturnStatement(s);
                case 71:
                  return this.parseSwitchStatement(s);
                case 72:
                  return this.parseThrowStatement(s);
                case 73:
                  return this.parseTryStatement(s);
                case 105:
                  if (this.hasFollowingLineBreak() || this.state.containsEsc || !this.hasFollowingBindingIdentifier())
                    break;
                  return this.expectPlugin("explicitResourceManagement"), !this.scope.inModule && this.scope.inTopLevel ? this.raise(u.UnexpectedUsingDeclaration, { at: this.state.startLoc }) : i || this.raise(u.UnexpectedLexicalDeclaration, { at: this.state.startLoc }), this.parseVarStatement(s, "using");
                case 99: {
                  if (this.state.containsEsc)
                    break;
                  let p = this.nextTokenStart(), m = this.codePointAtPos(p);
                  if (m !== 91 && (!i && this.hasFollowingLineBreak() || !this.chStartsBindingIdentifier(m, p) && m !== 123))
                    break;
                }
                case 75:
                  i || this.raise(u.UnexpectedLexicalDeclaration, { at: this.state.startLoc });
                case 74: {
                  let p = this.state.value;
                  return this.parseVarStatement(s, p);
                }
                case 92:
                  return this.parseWhileStatement(s);
                case 76:
                  return this.parseWithStatement(s);
                case 5:
                  return this.parseBlock();
                case 13:
                  return this.parseEmptyStatement(s);
                case 83: {
                  let p = this.lookaheadCharCode();
                  if (p === 40 || p === 46)
                    break;
                }
                case 82: {
                  !this.options.allowImportExportEverywhere && !n && this.raise(u.UnexpectedImportExport, { at: this.state.startLoc }), this.next();
                  let p;
                  return e === 83 ? (p = this.parseImport(s), p.type === "ImportDeclaration" && (!p.importKind || p.importKind === "value") && (this.sawUnambiguousESM = true)) : (p = this.parseExport(s, r), (p.type === "ExportNamedDeclaration" && (!p.exportKind || p.exportKind === "value") || p.type === "ExportAllDeclaration" && (!p.exportKind || p.exportKind === "value") || p.type === "ExportDefaultDeclaration") && (this.sawUnambiguousESM = true)), this.assertModuleNodeAllowed(p), p;
                }
                default:
                  if (this.isAsyncFunction())
                    return i || this.raise(u.AsyncFunctionInSingleStatementContext, { at: this.state.startLoc }), this.next(), this.parseFunctionStatement(s, true, !i && a);
              }
              let o = this.state.value, c = this.parseExpression();
              return z(e) && c.type === "Identifier" && this.eat(14) ? this.parseLabeledStatement(s, o, c, t3) : this.parseExpressionStatement(s, c, r);
            }
            assertModuleNodeAllowed(t3) {
              !this.options.allowImportExportEverywhere && !this.inModule && this.raise(u.ImportOutsideModule, { at: t3 });
            }
            decoratorsEnabledBeforeExport() {
              return this.hasPlugin("decorators-legacy") ? true : this.hasPlugin("decorators") && !!this.getPluginOption("decorators", "decoratorsBeforeExport");
            }
            maybeTakeDecorators(t3, r, e) {
              return t3 && (r.decorators = t3, this.resetStartLocationFromNode(r, t3[0]), e && this.resetStartLocationFromNode(e, r)), r;
            }
            canHaveLeadingDecorator() {
              return this.match(80);
            }
            parseDecorators(t3) {
              let r = [];
              do
                r.push(this.parseDecorator());
              while (this.match(26));
              if (this.match(82))
                t3 || this.unexpected(), this.decoratorsEnabledBeforeExport() || this.raise(u.DecoratorExportClass, { at: this.state.startLoc });
              else if (!this.canHaveLeadingDecorator())
                throw this.raise(u.UnexpectedLeadingDecorator, { at: this.state.startLoc });
              return r;
            }
            parseDecorator() {
              this.expectOnePlugin(["decorators", "decorators-legacy"]);
              let t3 = this.startNode();
              if (this.next(), this.hasPlugin("decorators")) {
                let r = this.state.startLoc, e;
                if (this.match(10)) {
                  let s = this.state.startLoc;
                  this.next(), e = this.parseExpression(), this.expect(11), e = this.wrapParenthesis(s, e);
                  let i = this.state.startLoc;
                  t3.expression = this.parseMaybeDecoratorArguments(e), this.getPluginOption("decorators", "allowCallParenthesized") === false && t3.expression !== e && this.raise(u.DecoratorArgumentsOutsideParentheses, { at: i });
                } else {
                  for (e = this.parseIdentifier(false); this.eat(16); ) {
                    let s = this.startNodeAt(r);
                    s.object = e, this.match(136) ? (this.classScope.usePrivateName(this.state.value, this.state.startLoc), s.property = this.parsePrivateName()) : s.property = this.parseIdentifier(true), s.computed = false, e = this.finishNode(s, "MemberExpression");
                  }
                  t3.expression = this.parseMaybeDecoratorArguments(e);
                }
              } else
                t3.expression = this.parseExprSubscripts();
              return this.finishNode(t3, "Decorator");
            }
            parseMaybeDecoratorArguments(t3) {
              if (this.eat(10)) {
                let r = this.startNodeAtNode(t3);
                return r.callee = t3, r.arguments = this.parseCallExpressionArguments(11, false), this.toReferencedList(r.arguments), this.finishNode(r, "CallExpression");
              }
              return t3;
            }
            parseBreakContinueStatement(t3, r) {
              return this.next(), this.isLineTerminator() ? t3.label = null : (t3.label = this.parseIdentifier(), this.semicolon()), this.verifyBreakContinue(t3, r), this.finishNode(t3, r ? "BreakStatement" : "ContinueStatement");
            }
            verifyBreakContinue(t3, r) {
              let e;
              for (e = 0; e < this.state.labels.length; ++e) {
                let s = this.state.labels[e];
                if ((t3.label == null || s.name === t3.label.name) && (s.kind != null && (r || s.kind === "loop") || t3.label && r))
                  break;
              }
              if (e === this.state.labels.length) {
                let s = r ? "BreakStatement" : "ContinueStatement";
                this.raise(u.IllegalBreakContinue, { at: t3, type: s });
              }
            }
            parseDebuggerStatement(t3) {
              return this.next(), this.semicolon(), this.finishNode(t3, "DebuggerStatement");
            }
            parseHeaderExpression() {
              this.expect(10);
              let t3 = this.parseExpression();
              return this.expect(11), t3;
            }
            parseDoWhileStatement(t3) {
              return this.next(), this.state.labels.push(gs), t3.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.state.labels.pop(), this.expect(92), t3.test = this.parseHeaderExpression(), this.eat(13), this.finishNode(t3, "DoWhileStatement");
            }
            parseForStatement(t3) {
              this.next(), this.state.labels.push(gs);
              let r = null;
              if (this.isAwaitAllowed() && this.eatContextual(96) && (r = this.state.lastTokStartLoc), this.scope.enter(je), this.expect(10), this.match(13))
                return r !== null && this.unexpected(r), this.parseFor(t3, null);
              let e = this.isContextual(99), s = this.isContextual(105) && !this.hasFollowingLineBreak(), i = e && this.hasFollowingBindingAtom() || s && this.hasFollowingBindingIdentifier() && this.startsUsingForOf();
              if (this.match(74) || this.match(75) || i) {
                let p = this.startNode(), m = this.state.value;
                this.next(), this.parseVar(p, true, m);
                let x = this.finishNode(p, "VariableDeclaration"), A = this.match(58);
                return A && s && this.raise(u.ForInUsing, { at: x }), (A || this.isContextual(101)) && x.declarations.length === 1 ? this.parseForIn(t3, x, r) : (r !== null && this.unexpected(r), this.parseFor(t3, x));
              }
              let a = this.isContextual(95), n = new Ct(), o = this.parseExpression(true, n), c = this.isContextual(101);
              if (c && (e && this.raise(u.ForOfLet, { at: o }), r === null && a && o.type === "Identifier" && this.raise(u.ForOfAsync, { at: o })), c || this.match(58)) {
                this.checkDestructuringPrivate(n), this.toAssignable(o, true);
                let p = c ? "ForOfStatement" : "ForInStatement";
                return this.checkLVal(o, { in: { type: p } }), this.parseForIn(t3, o, r);
              } else
                this.checkExpressionErrors(n, true);
              return r !== null && this.unexpected(r), this.parseFor(t3, o);
            }
            parseFunctionStatement(t3, r, e) {
              return this.next(), this.parseFunction(t3, ie.Declaration | (e ? ie.HangingDeclaration : 0) | (r ? ie.Async : 0));
            }
            parseIfStatement(t3) {
              return this.next(), t3.test = this.parseHeaderExpression(), t3.consequent = this.parseStatementOrFunctionDeclaration(true), t3.alternate = this.eat(66) ? this.parseStatementOrFunctionDeclaration(true) : null, this.finishNode(t3, "IfStatement");
            }
            parseReturnStatement(t3) {
              return !this.prodParam.hasReturn && !this.options.allowReturnOutsideFunction && this.raise(u.IllegalReturn, { at: this.state.startLoc }), this.next(), this.isLineTerminator() ? t3.argument = null : (t3.argument = this.parseExpression(), this.semicolon()), this.finishNode(t3, "ReturnStatement");
            }
            parseSwitchStatement(t3) {
              this.next(), t3.discriminant = this.parseHeaderExpression();
              let r = t3.cases = [];
              this.expect(5), this.state.labels.push(gh), this.scope.enter(je);
              let e;
              for (let s; !this.match(8); )
                if (this.match(61) || this.match(65)) {
                  let i = this.match(61);
                  e && this.finishNode(e, "SwitchCase"), r.push(e = this.startNode()), e.consequent = [], this.next(), i ? e.test = this.parseExpression() : (s && this.raise(u.MultipleDefaultsInSwitch, { at: this.state.lastTokStartLoc }), s = true, e.test = null), this.expect(14);
                } else
                  e ? e.consequent.push(this.parseStatementListItem()) : this.unexpected();
              return this.scope.exit(), e && this.finishNode(e, "SwitchCase"), this.next(), this.state.labels.pop(), this.finishNode(t3, "SwitchStatement");
            }
            parseThrowStatement(t3) {
              return this.next(), this.hasPrecedingLineBreak() && this.raise(u.NewlineAfterThrow, { at: this.state.lastTokEndLoc }), t3.argument = this.parseExpression(), this.semicolon(), this.finishNode(t3, "ThrowStatement");
            }
            parseCatchClauseParam() {
              let t3 = this.parseBindingAtom(), r = t3.type === "Identifier";
              return this.scope.enter(r ? Sr : 0), this.checkLVal(t3, { in: { type: "CatchClause" }, binding: De, allowingSloppyLetBinding: true }), t3;
            }
            parseTryStatement(t3) {
              if (this.next(), t3.block = this.parseBlock(), t3.handler = null, this.match(62)) {
                let r = this.startNode();
                this.next(), this.match(10) ? (this.expect(10), r.param = this.parseCatchClauseParam(), this.expect(11)) : (r.param = null, this.scope.enter(je)), r.body = this.withSmartMixTopicForbiddingContext(() => this.parseBlock(false, false)), this.scope.exit(), t3.handler = this.finishNode(r, "CatchClause");
              }
              return t3.finalizer = this.eat(67) ? this.parseBlock() : null, !t3.handler && !t3.finalizer && this.raise(u.NoCatchOrFinally, { at: t3 }), this.finishNode(t3, "TryStatement");
            }
            parseVarStatement(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
              return this.next(), this.parseVar(t3, false, r, e), this.semicolon(), this.finishNode(t3, "VariableDeclaration");
            }
            parseWhileStatement(t3) {
              return this.next(), t3.test = this.parseHeaderExpression(), this.state.labels.push(gs), t3.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.state.labels.pop(), this.finishNode(t3, "WhileStatement");
            }
            parseWithStatement(t3) {
              return this.state.strict && this.raise(u.StrictWith, { at: this.state.startLoc }), this.next(), t3.object = this.parseHeaderExpression(), t3.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.finishNode(t3, "WithStatement");
            }
            parseEmptyStatement(t3) {
              return this.next(), this.finishNode(t3, "EmptyStatement");
            }
            parseLabeledStatement(t3, r, e, s) {
              for (let a of this.state.labels)
                a.name === r && this.raise(u.LabelRedeclaration, { at: e, labelName: r });
              let i = Jo(this.state.type) ? "loop" : this.match(71) ? "switch" : null;
              for (let a = this.state.labels.length - 1; a >= 0; a--) {
                let n = this.state.labels[a];
                if (n.statementStart === t3.start)
                  n.statementStart = this.state.start, n.kind = i;
                else
                  break;
              }
              return this.state.labels.push({ name: r, kind: i, statementStart: this.state.start }), t3.body = s & ae.AllowLabeledFunction ? this.parseStatementOrFunctionDeclaration(false) : this.parseStatement(), this.state.labels.pop(), t3.label = e, this.finishNode(t3, "LabeledStatement");
            }
            parseExpressionStatement(t3, r, e) {
              return t3.expression = r, this.semicolon(), this.finishNode(t3, "ExpressionStatement");
            }
            parseBlock() {
              let t3 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : false, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true, e = arguments.length > 2 ? arguments[2] : void 0, s = this.startNode();
              return t3 && this.state.strictErrors.clear(), this.expect(5), r && this.scope.enter(je), this.parseBlockBody(s, t3, false, 8, e), r && this.scope.exit(), this.finishNode(s, "BlockStatement");
            }
            isValidDirective(t3) {
              return t3.type === "ExpressionStatement" && t3.expression.type === "StringLiteral" && !t3.expression.extra.parenthesized;
            }
            parseBlockBody(t3, r, e, s, i) {
              let a = t3.body = [], n = t3.directives = [];
              this.parseBlockOrModuleBlockBody(a, r ? n : void 0, e, s, i);
            }
            parseBlockOrModuleBlockBody(t3, r, e, s, i) {
              let a = this.state.strict, n = false, o = false;
              for (; !this.match(s); ) {
                let c = e ? this.parseModuleItem() : this.parseStatementListItem();
                if (r && !o) {
                  if (this.isValidDirective(c)) {
                    let p = this.stmtToDirective(c);
                    r.push(p), !n && p.value.value === "use strict" && (n = true, this.setStrict(true));
                    continue;
                  }
                  o = true, this.state.strictErrors.clear();
                }
                t3.push(c);
              }
              i && i.call(this, n), a || this.setStrict(false), this.next();
            }
            parseFor(t3, r) {
              return t3.init = r, this.semicolon(false), t3.test = this.match(13) ? null : this.parseExpression(), this.semicolon(false), t3.update = this.match(11) ? null : this.parseExpression(), this.expect(11), t3.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.scope.exit(), this.state.labels.pop(), this.finishNode(t3, "ForStatement");
            }
            parseForIn(t3, r, e) {
              let s = this.match(58);
              return this.next(), s ? e !== null && this.unexpected(e) : t3.await = e !== null, r.type === "VariableDeclaration" && r.declarations[0].init != null && (!s || this.state.strict || r.kind !== "var" || r.declarations[0].id.type !== "Identifier") && this.raise(u.ForInOfLoopInitializer, { at: r, type: s ? "ForInStatement" : "ForOfStatement" }), r.type === "AssignmentPattern" && this.raise(u.InvalidLhs, { at: r, ancestor: { type: "ForStatement" } }), t3.left = r, t3.right = s ? this.parseExpression() : this.parseMaybeAssignAllowIn(), this.expect(11), t3.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.scope.exit(), this.state.labels.pop(), this.finishNode(t3, s ? "ForInStatement" : "ForOfStatement");
            }
            parseVar(t3, r, e) {
              let s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false, i = t3.declarations = [];
              for (t3.kind = e; ; ) {
                let a = this.startNode();
                if (this.parseVarId(a, e), a.init = this.eat(29) ? r ? this.parseMaybeAssignDisallowIn() : this.parseMaybeAssignAllowIn() : null, a.init === null && !s && (a.id.type !== "Identifier" && !(r && (this.match(58) || this.isContextual(101))) ? this.raise(u.DeclarationMissingInitializer, { at: this.state.lastTokEndLoc, kind: "destructuring" }) : e === "const" && !(this.match(58) || this.isContextual(101)) && this.raise(u.DeclarationMissingInitializer, { at: this.state.lastTokEndLoc, kind: "const" })), i.push(this.finishNode(a, "VariableDeclarator")), !this.eat(12))
                  break;
              }
              return t3;
            }
            parseVarId(t3, r) {
              let e = this.parseBindingAtom();
              this.checkLVal(e, { in: { type: "VariableDeclarator" }, binding: r === "var" ? xt : De }), t3.id = e;
            }
            parseAsyncFunctionExpression(t3) {
              return this.parseFunction(t3, ie.Async);
            }
            parseFunction(t3) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : ie.Expression, e = r & ie.HangingDeclaration, s = !!(r & ie.Declaration), i = s && !(r & ie.NullableId), a = !!(r & ie.Async);
              this.initFunction(t3, a), this.match(55) && (e && this.raise(u.GeneratorInSingleStatementContext, { at: this.state.startLoc }), this.next(), t3.generator = true), s && (t3.id = this.parseFunctionId(i));
              let n = this.state.maybeInArrowParameters;
              return this.state.maybeInArrowParameters = false, this.scope.enter(Pe), this.prodParam.enter(Et(a, t3.generator)), s || (t3.id = this.parseFunctionId()), this.parseFunctionParams(t3, false), this.withSmartMixTopicForbiddingContext(() => {
                this.parseFunctionBodyAndFinish(t3, s ? "FunctionDeclaration" : "FunctionExpression");
              }), this.prodParam.exit(), this.scope.exit(), s && !e && this.registerFunctionStatementId(t3), this.state.maybeInArrowParameters = n, t3;
            }
            parseFunctionId(t3) {
              return t3 || z(this.state.type) ? this.parseIdentifier() : null;
            }
            parseFunctionParams(t3, r) {
              this.expect(10), this.expressionScope.enter(ql()), t3.params = this.parseBindingList(11, 41, false, r), this.expressionScope.exit();
            }
            registerFunctionStatementId(t3) {
              t3.id && this.scope.declareName(t3.id.name, this.state.strict || t3.generator || t3.async ? this.scope.treatFunctionsAsVar ? xt : De : Dr, t3.id.loc.start);
            }
            parseClass(t3, r, e) {
              this.next();
              let s = this.state.strict;
              return this.state.strict = true, this.parseClassId(t3, r, e), this.parseClassSuper(t3), t3.body = this.parseClassBody(!!t3.superClass, s), this.finishNode(t3, r ? "ClassDeclaration" : "ClassExpression");
            }
            isClassProperty() {
              return this.match(29) || this.match(13) || this.match(8);
            }
            isClassMethod() {
              return this.match(10);
            }
            isNonstaticConstructor(t3) {
              return !t3.computed && !t3.static && (t3.key.name === "constructor" || t3.key.value === "constructor");
            }
            parseClassBody(t3, r) {
              this.classScope.enter();
              let e = { hadConstructor: false, hadSuperClass: t3 }, s = [], i = this.startNode();
              if (i.body = [], this.expect(5), this.withSmartMixTopicForbiddingContext(() => {
                for (; !this.match(8); ) {
                  if (this.eat(13)) {
                    if (s.length > 0)
                      throw this.raise(u.DecoratorSemicolon, { at: this.state.lastTokEndLoc });
                    continue;
                  }
                  if (this.match(26)) {
                    s.push(this.parseDecorator());
                    continue;
                  }
                  let a = this.startNode();
                  s.length && (a.decorators = s, this.resetStartLocationFromNode(a, s[0]), s = []), this.parseClassMember(i, a, e), a.kind === "constructor" && a.decorators && a.decorators.length > 0 && this.raise(u.DecoratorConstructor, { at: a });
                }
              }), this.state.strict = r, this.next(), s.length)
                throw this.raise(u.TrailingDecorator, { at: this.state.startLoc });
              return this.classScope.exit(), this.finishNode(i, "ClassBody");
            }
            parseClassMemberFromModifier(t3, r) {
              let e = this.parseIdentifier(true);
              if (this.isClassMethod()) {
                let s = r;
                return s.kind = "method", s.computed = false, s.key = e, s.static = false, this.pushClassMethod(t3, s, false, false, false, false), true;
              } else if (this.isClassProperty()) {
                let s = r;
                return s.computed = false, s.key = e, s.static = false, t3.body.push(this.parseClassProperty(s)), true;
              }
              return this.resetPreviousNodeTrailingComments(e), false;
            }
            parseClassMember(t3, r, e) {
              let s = this.isContextual(104);
              if (s) {
                if (this.parseClassMemberFromModifier(t3, r))
                  return;
                if (this.eat(5)) {
                  this.parseClassStaticBlock(t3, r);
                  return;
                }
              }
              this.parseClassMemberWithIsStatic(t3, r, e, s);
            }
            parseClassMemberWithIsStatic(t3, r, e, s) {
              let i = r, a = r, n = r, o = r, c = r, p = i, m = i;
              if (r.static = s, this.parsePropertyNamePrefixOperator(r), this.eat(55)) {
                p.kind = "method";
                let R = this.match(136);
                if (this.parseClassElementName(p), R) {
                  this.pushClassPrivateMethod(t3, a, true, false);
                  return;
                }
                this.isNonstaticConstructor(i) && this.raise(u.ConstructorIsGenerator, { at: i.key }), this.pushClassMethod(t3, i, true, false, false, false);
                return;
              }
              let x = z(this.state.type) && !this.state.containsEsc, A = this.match(136), b = this.parseClassElementName(r), O = this.state.startLoc;
              if (this.parsePostMemberNameModifiers(m), this.isClassMethod()) {
                if (p.kind = "method", A) {
                  this.pushClassPrivateMethod(t3, a, false, false);
                  return;
                }
                let R = this.isNonstaticConstructor(i), Y = false;
                R && (i.kind = "constructor", e.hadConstructor && !this.hasPlugin("typescript") && this.raise(u.DuplicateConstructor, { at: b }), R && this.hasPlugin("typescript") && r.override && this.raise(u.OverrideOnConstructor, { at: b }), e.hadConstructor = true, Y = e.hadSuperClass), this.pushClassMethod(t3, i, false, false, R, Y);
              } else if (this.isClassProperty())
                A ? this.pushClassPrivateProperty(t3, o) : this.pushClassProperty(t3, n);
              else if (x && b.name === "async" && !this.isLineTerminator()) {
                this.resetPreviousNodeTrailingComments(b);
                let R = this.eat(55);
                m.optional && this.unexpected(O), p.kind = "method";
                let Y = this.match(136);
                this.parseClassElementName(p), this.parsePostMemberNameModifiers(m), Y ? this.pushClassPrivateMethod(t3, a, R, true) : (this.isNonstaticConstructor(i) && this.raise(u.ConstructorIsAsync, { at: i.key }), this.pushClassMethod(t3, i, R, true, false, false));
              } else if (x && (b.name === "get" || b.name === "set") && !(this.match(55) && this.isLineTerminator())) {
                this.resetPreviousNodeTrailingComments(b), p.kind = b.name;
                let R = this.match(136);
                this.parseClassElementName(i), R ? this.pushClassPrivateMethod(t3, a, false, false) : (this.isNonstaticConstructor(i) && this.raise(u.ConstructorIsAccessor, { at: i.key }), this.pushClassMethod(t3, i, false, false, false, false)), this.checkGetterSetterParams(i);
              } else if (x && b.name === "accessor" && !this.isLineTerminator()) {
                this.expectPlugin("decoratorAutoAccessors"), this.resetPreviousNodeTrailingComments(b);
                let R = this.match(136);
                this.parseClassElementName(n), this.pushClassAccessorProperty(t3, c, R);
              } else
                this.isLineTerminator() ? A ? this.pushClassPrivateProperty(t3, o) : this.pushClassProperty(t3, n) : this.unexpected();
            }
            parseClassElementName(t3) {
              let { type: r, value: e } = this.state;
              if ((r === 130 || r === 131) && t3.static && e === "prototype" && this.raise(u.StaticPrototype, { at: this.state.startLoc }), r === 136) {
                e === "constructor" && this.raise(u.ConstructorClassPrivateField, { at: this.state.startLoc });
                let s = this.parsePrivateName();
                return t3.key = s, s;
              }
              return this.parsePropertyName(t3);
            }
            parseClassStaticBlock(t3, r) {
              var e;
              this.scope.enter(Ne | ft | pt);
              let s = this.state.labels;
              this.state.labels = [], this.prodParam.enter($e);
              let i = r.body = [];
              this.parseBlockOrModuleBlockBody(i, void 0, false, 8), this.prodParam.exit(), this.scope.exit(), this.state.labels = s, t3.body.push(this.finishNode(r, "StaticBlock")), (e = r.decorators) != null && e.length && this.raise(u.DecoratorStaticBlock, { at: r });
            }
            pushClassProperty(t3, r) {
              !r.computed && (r.key.name === "constructor" || r.key.value === "constructor") && this.raise(u.ConstructorClassField, { at: r.key }), t3.body.push(this.parseClassProperty(r));
            }
            pushClassPrivateProperty(t3, r) {
              let e = this.parseClassPrivateProperty(r);
              t3.body.push(e), this.classScope.declarePrivateName(this.getPrivateNameSV(e.key), hs, e.key.loc.start);
            }
            pushClassAccessorProperty(t3, r, e) {
              if (!e && !r.computed) {
                let i = r.key;
                (i.name === "constructor" || i.value === "constructor") && this.raise(u.ConstructorClassField, { at: i });
              }
              let s = this.parseClassAccessorProperty(r);
              t3.body.push(s), e && this.classScope.declarePrivateName(this.getPrivateNameSV(s.key), hs, s.key.loc.start);
            }
            pushClassMethod(t3, r, e, s, i, a) {
              t3.body.push(this.parseMethod(r, e, s, i, a, "ClassMethod", true));
            }
            pushClassPrivateMethod(t3, r, e, s) {
              let i = this.parseMethod(r, e, s, false, false, "ClassPrivateMethod", true);
              t3.body.push(i);
              let a = i.kind === "get" ? i.static ? gl : Al : i.kind === "set" ? i.static ? Pl : Tl : hs;
              this.declareClassPrivateMethodInScope(i, a);
            }
            declareClassPrivateMethodInScope(t3, r) {
              this.classScope.declarePrivateName(this.getPrivateNameSV(t3.key), r, t3.key.loc.start);
            }
            parsePostMemberNameModifiers(t3) {
            }
            parseClassPrivateProperty(t3) {
              return this.parseInitializer(t3), this.semicolon(), this.finishNode(t3, "ClassPrivateProperty");
            }
            parseClassProperty(t3) {
              return this.parseInitializer(t3), this.semicolon(), this.finishNode(t3, "ClassProperty");
            }
            parseClassAccessorProperty(t3) {
              return this.parseInitializer(t3), this.semicolon(), this.finishNode(t3, "ClassAccessorProperty");
            }
            parseInitializer(t3) {
              this.scope.enter(Ne | pt), this.expressionScope.enter(Vr()), this.prodParam.enter($e), t3.value = this.eat(29) ? this.parseMaybeAssignAllowIn() : null, this.expressionScope.exit(), this.prodParam.exit(), this.scope.exit();
            }
            parseClassId(t3, r, e) {
              let s = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : kr;
              if (z(this.state.type))
                t3.id = this.parseIdentifier(), r && this.declareNameFromIdentifier(t3.id, s);
              else if (e || !r)
                t3.id = null;
              else
                throw this.raise(u.MissingClassName, { at: this.state.startLoc });
            }
            parseClassSuper(t3) {
              t3.superClass = this.eat(81) ? this.parseExprSubscripts() : null;
            }
            parseExport(t3, r) {
              let e = this.maybeParseExportDefaultSpecifier(t3), s = !e || this.eat(12), i = s && this.eatExportStar(t3), a = i && this.maybeParseExportNamespaceSpecifier(t3), n = s && (!a || this.eat(12)), o = e || i;
              if (i && !a) {
                if (e && this.unexpected(), r)
                  throw this.raise(u.UnsupportedDecoratorExport, { at: t3 });
                return this.parseExportFrom(t3, true), this.finishNode(t3, "ExportAllDeclaration");
              }
              let c = this.maybeParseExportNamedSpecifiers(t3);
              if (e && s && !i && !c || a && n && !c)
                throw this.unexpected(null, 5);
              let p;
              if (o || c) {
                if (p = false, r)
                  throw this.raise(u.UnsupportedDecoratorExport, { at: t3 });
                this.parseExportFrom(t3, o);
              } else
                p = this.maybeParseExportDeclaration(t3);
              if (o || c || p) {
                var m;
                let x = t3;
                if (this.checkExport(x, true, false, !!x.source), ((m = x.declaration) == null ? void 0 : m.type) === "ClassDeclaration")
                  this.maybeTakeDecorators(r, x.declaration, x);
                else if (r)
                  throw this.raise(u.UnsupportedDecoratorExport, { at: t3 });
                return this.finishNode(x, "ExportNamedDeclaration");
              }
              if (this.eat(65)) {
                let x = t3, A = this.parseExportDefaultExpression();
                if (x.declaration = A, A.type === "ClassDeclaration")
                  this.maybeTakeDecorators(r, A, x);
                else if (r)
                  throw this.raise(u.UnsupportedDecoratorExport, { at: t3 });
                return this.checkExport(x, true, true), this.finishNode(x, "ExportDefaultDeclaration");
              }
              throw this.unexpected(null, 5);
            }
            eatExportStar(t3) {
              return this.eat(55);
            }
            maybeParseExportDefaultSpecifier(t3) {
              if (this.isExportDefaultSpecifier()) {
                this.expectPlugin("exportDefaultFrom");
                let r = this.startNode();
                return r.exported = this.parseIdentifier(true), t3.specifiers = [this.finishNode(r, "ExportDefaultSpecifier")], true;
              }
              return false;
            }
            maybeParseExportNamespaceSpecifier(t3) {
              if (this.isContextual(93)) {
                t3.specifiers || (t3.specifiers = []);
                let r = this.startNodeAt(this.state.lastTokStartLoc);
                return this.next(), r.exported = this.parseModuleExportName(), t3.specifiers.push(this.finishNode(r, "ExportNamespaceSpecifier")), true;
              }
              return false;
            }
            maybeParseExportNamedSpecifiers(t3) {
              if (this.match(5)) {
                t3.specifiers || (t3.specifiers = []);
                let r = t3.exportKind === "type";
                return t3.specifiers.push(...this.parseExportSpecifiers(r)), t3.source = null, t3.declaration = null, this.hasPlugin("importAssertions") && (t3.assertions = []), true;
              }
              return false;
            }
            maybeParseExportDeclaration(t3) {
              return this.shouldParseExportDeclaration() ? (t3.specifiers = [], t3.source = null, this.hasPlugin("importAssertions") && (t3.assertions = []), t3.declaration = this.parseExportDeclaration(t3), true) : false;
            }
            isAsyncFunction() {
              if (!this.isContextual(95))
                return false;
              let t3 = this.nextTokenStart();
              return !ps.test(this.input.slice(this.state.pos, t3)) && this.isUnparsedContextual(t3, "function");
            }
            parseExportDefaultExpression() {
              let t3 = this.startNode();
              if (this.match(68))
                return this.next(), this.parseFunction(t3, ie.Declaration | ie.NullableId);
              if (this.isAsyncFunction())
                return this.next(), this.next(), this.parseFunction(t3, ie.Declaration | ie.NullableId | ie.Async);
              if (this.match(80))
                return this.parseClass(t3, true, true);
              if (this.match(26))
                return this.hasPlugin("decorators") && this.getPluginOption("decorators", "decoratorsBeforeExport") && this.raise(u.DecoratorBeforeExport, { at: this.state.startLoc }), this.parseClass(this.maybeTakeDecorators(this.parseDecorators(false), this.startNode()), true, true);
              if (this.match(75) || this.match(74) || this.isLet())
                throw this.raise(u.UnsupportedDefaultExport, { at: this.state.startLoc });
              let r = this.parseMaybeAssignAllowIn();
              return this.semicolon(), r;
            }
            parseExportDeclaration(t3) {
              return this.match(80) ? this.parseClass(this.startNode(), true, false) : this.parseStatementListItem();
            }
            isExportDefaultSpecifier() {
              let { type: t3 } = this.state;
              if (z(t3)) {
                if (t3 === 95 && !this.state.containsEsc || t3 === 99)
                  return false;
                if ((t3 === 128 || t3 === 127) && !this.state.containsEsc) {
                  let { type: s } = this.lookahead();
                  if (z(s) && s !== 97 || s === 5)
                    return this.expectOnePlugin(["flow", "typescript"]), false;
                }
              } else if (!this.match(65))
                return false;
              let r = this.nextTokenStart(), e = this.isUnparsedContextual(r, "from");
              if (this.input.charCodeAt(r) === 44 || z(this.state.type) && e)
                return true;
              if (this.match(65) && e) {
                let s = this.input.charCodeAt(this.nextTokenStartSince(r + 4));
                return s === 34 || s === 39;
              }
              return false;
            }
            parseExportFrom(t3, r) {
              if (this.eatContextual(97)) {
                t3.source = this.parseImportSource(), this.checkExport(t3);
                let e = this.maybeParseImportAssertions();
                e && (t3.assertions = e, this.checkJSONModuleImport(t3));
              } else
                r && this.unexpected();
              this.semicolon();
            }
            shouldParseExportDeclaration() {
              let { type: t3 } = this.state;
              if (t3 === 26 && (this.expectOnePlugin(["decorators", "decorators-legacy"]), this.hasPlugin("decorators"))) {
                if (this.getPluginOption("decorators", "decoratorsBeforeExport"))
                  throw this.raise(u.DecoratorBeforeExport, { at: this.state.startLoc });
                return true;
              }
              return t3 === 74 || t3 === 75 || t3 === 68 || t3 === 80 || this.isLet() || this.isAsyncFunction();
            }
            checkExport(t3, r, e, s) {
              if (r) {
                if (e) {
                  if (this.checkDuplicateExports(t3, "default"), this.hasPlugin("exportDefaultFrom")) {
                    var i;
                    let a = t3.declaration;
                    a.type === "Identifier" && a.name === "from" && a.end - a.start === 4 && !((i = a.extra) != null && i.parenthesized) && this.raise(u.ExportDefaultFromAsIdentifier, { at: a });
                  }
                } else if (t3.specifiers && t3.specifiers.length)
                  for (let a of t3.specifiers) {
                    let { exported: n } = a, o = n.type === "Identifier" ? n.name : n.value;
                    if (this.checkDuplicateExports(a, o), !s && a.local) {
                      let { local: c } = a;
                      c.type !== "Identifier" ? this.raise(u.ExportBindingIsString, { at: a, localName: c.value, exportName: o }) : (this.checkReservedWord(c.name, c.loc.start, true, false), this.scope.checkLocalExport(c));
                    }
                  }
                else if (t3.declaration) {
                  if (t3.declaration.type === "FunctionDeclaration" || t3.declaration.type === "ClassDeclaration") {
                    let a = t3.declaration.id;
                    if (!a)
                      throw new Error("Assertion failure");
                    this.checkDuplicateExports(t3, a.name);
                  } else if (t3.declaration.type === "VariableDeclaration")
                    for (let a of t3.declaration.declarations)
                      this.checkDeclaration(a.id);
                }
              }
            }
            checkDeclaration(t3) {
              if (t3.type === "Identifier")
                this.checkDuplicateExports(t3, t3.name);
              else if (t3.type === "ObjectPattern")
                for (let r of t3.properties)
                  this.checkDeclaration(r);
              else if (t3.type === "ArrayPattern")
                for (let r of t3.elements)
                  r && this.checkDeclaration(r);
              else
                t3.type === "ObjectProperty" ? this.checkDeclaration(t3.value) : t3.type === "RestElement" ? this.checkDeclaration(t3.argument) : t3.type === "AssignmentPattern" && this.checkDeclaration(t3.left);
            }
            checkDuplicateExports(t3, r) {
              this.exportedIdentifiers.has(r) && (r === "default" ? this.raise(u.DuplicateDefaultExport, { at: t3 }) : this.raise(u.DuplicateExport, { at: t3, exportName: r })), this.exportedIdentifiers.add(r);
            }
            parseExportSpecifiers(t3) {
              let r = [], e = true;
              for (this.expect(5); !this.eat(8); ) {
                if (e)
                  e = false;
                else if (this.expect(12), this.eat(8))
                  break;
                let s = this.isContextual(128), i = this.match(131), a = this.startNode();
                a.local = this.parseModuleExportName(), r.push(this.parseExportSpecifier(a, i, t3, s));
              }
              return r;
            }
            parseExportSpecifier(t3, r, e, s) {
              return this.eatContextual(93) ? t3.exported = this.parseModuleExportName() : r ? t3.exported = Kl(t3.local) : t3.exported || (t3.exported = Te(t3.local)), this.finishNode(t3, "ExportSpecifier");
            }
            parseModuleExportName() {
              if (this.match(131)) {
                let t3 = this.parseStringLiteral(this.state.value), r = t3.value.match(Ph);
                return r && this.raise(u.ModuleExportNameHasLoneSurrogate, { at: t3, surrogateCharCode: r[0].charCodeAt(0) }), t3;
              }
              return this.parseIdentifier(true);
            }
            isJSONModuleImport(t3) {
              return t3.assertions != null ? t3.assertions.some((r) => {
                let { key: e, value: s } = r;
                return s.value === "json" && (e.type === "Identifier" ? e.name === "type" : e.value === "type");
              }) : false;
            }
            checkImportReflection(t3) {
              if (t3.module) {
                var r;
                (t3.specifiers.length !== 1 || t3.specifiers[0].type !== "ImportDefaultSpecifier") && this.raise(u.ImportReflectionNotBinding, { at: t3.specifiers[0].loc.start }), ((r = t3.assertions) == null ? void 0 : r.length) > 0 && this.raise(u.ImportReflectionHasAssertion, { at: t3.specifiers[0].loc.start });
              }
            }
            checkJSONModuleImport(t3) {
              if (this.isJSONModuleImport(t3) && t3.type !== "ExportAllDeclaration") {
                let { specifiers: r } = t3;
                if (r != null) {
                  let e = r.find((s) => {
                    let i;
                    if (s.type === "ExportSpecifier" ? i = s.local : s.type === "ImportSpecifier" && (i = s.imported), i !== void 0)
                      return i.type === "Identifier" ? i.name !== "default" : i.value !== "default";
                  });
                  e !== void 0 && this.raise(u.ImportJSONBindingNotDefault, { at: e.loc.start });
                }
              }
            }
            parseMaybeImportReflection(t3) {
              let r = false;
              if (this.isContextual(125)) {
                let e = this.lookahead(), s = e.type;
                z(s) ? (s !== 97 || this.input.charCodeAt(this.nextTokenStartSince(e.end)) === 102) && (r = true) : s !== 12 && (r = true);
              }
              r ? (this.expectPlugin("importReflection"), this.next(), t3.module = true) : this.hasPlugin("importReflection") && (t3.module = false);
            }
            parseImport(t3) {
              if (t3.specifiers = [], !this.match(131)) {
                this.parseMaybeImportReflection(t3);
                let s = !this.maybeParseDefaultImportSpecifier(t3) || this.eat(12), i = s && this.maybeParseStarImportSpecifier(t3);
                s && !i && this.parseNamedImportSpecifiers(t3), this.expectContextual(97);
              }
              t3.source = this.parseImportSource();
              let r = this.maybeParseImportAssertions();
              if (r)
                t3.assertions = r;
              else {
                let e = this.maybeParseModuleAttributes();
                e && (t3.attributes = e);
              }
              return this.checkImportReflection(t3), this.checkJSONModuleImport(t3), this.semicolon(), this.finishNode(t3, "ImportDeclaration");
            }
            parseImportSource() {
              return this.match(131) || this.unexpected(), this.parseExprAtom();
            }
            shouldParseDefaultImport(t3) {
              return z(this.state.type);
            }
            parseImportSpecifierLocal(t3, r, e) {
              r.local = this.parseIdentifier(), t3.specifiers.push(this.finishImportSpecifier(r, e));
            }
            finishImportSpecifier(t3, r) {
              let e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : De;
              return this.checkLVal(t3.local, { in: t3, binding: e }), this.finishNode(t3, r);
            }
            parseAssertEntries() {
              let t3 = [], r = /* @__PURE__ */ new Set();
              do {
                if (this.match(8))
                  break;
                let e = this.startNode(), s = this.state.value;
                if (r.has(s) && this.raise(u.ModuleAttributesWithDuplicateKeys, { at: this.state.startLoc, key: s }), r.add(s), this.match(131) ? e.key = this.parseStringLiteral(s) : e.key = this.parseIdentifier(true), this.expect(14), !this.match(131))
                  throw this.raise(u.ModuleAttributeInvalidValue, { at: this.state.startLoc });
                e.value = this.parseStringLiteral(this.state.value), t3.push(this.finishNode(e, "ImportAttribute"));
              } while (this.eat(12));
              return t3;
            }
            maybeParseModuleAttributes() {
              if (this.match(76) && !this.hasPrecedingLineBreak())
                this.expectPlugin("moduleAttributes"), this.next();
              else
                return this.hasPlugin("moduleAttributes") ? [] : null;
              let t3 = [], r = /* @__PURE__ */ new Set();
              do {
                let e = this.startNode();
                if (e.key = this.parseIdentifier(true), e.key.name !== "type" && this.raise(u.ModuleAttributeDifferentFromType, { at: e.key }), r.has(e.key.name) && this.raise(u.ModuleAttributesWithDuplicateKeys, { at: e.key, key: e.key.name }), r.add(e.key.name), this.expect(14), !this.match(131))
                  throw this.raise(u.ModuleAttributeInvalidValue, { at: this.state.startLoc });
                e.value = this.parseStringLiteral(this.state.value), this.finishNode(e, "ImportAttribute"), t3.push(e);
              } while (this.eat(12));
              return t3;
            }
            maybeParseImportAssertions() {
              if (this.isContextual(94) && !this.hasPrecedingLineBreak())
                this.expectPlugin("importAssertions"), this.next();
              else
                return this.hasPlugin("importAssertions") ? [] : null;
              this.eat(5);
              let t3 = this.parseAssertEntries();
              return this.eat(8), t3;
            }
            maybeParseDefaultImportSpecifier(t3) {
              return this.shouldParseDefaultImport(t3) ? (this.parseImportSpecifierLocal(t3, this.startNode(), "ImportDefaultSpecifier"), true) : false;
            }
            maybeParseStarImportSpecifier(t3) {
              if (this.match(55)) {
                let r = this.startNode();
                return this.next(), this.expectContextual(93), this.parseImportSpecifierLocal(t3, r, "ImportNamespaceSpecifier"), true;
              }
              return false;
            }
            parseNamedImportSpecifiers(t3) {
              let r = true;
              for (this.expect(5); !this.eat(8); ) {
                if (r)
                  r = false;
                else {
                  if (this.eat(14))
                    throw this.raise(u.DestructureNamedImport, { at: this.state.startLoc });
                  if (this.expect(12), this.eat(8))
                    break;
                }
                let e = this.startNode(), s = this.match(131), i = this.isContextual(128);
                e.imported = this.parseModuleExportName();
                let a = this.parseImportSpecifier(e, s, t3.importKind === "type" || t3.importKind === "typeof", i, void 0);
                t3.specifiers.push(a);
              }
            }
            parseImportSpecifier(t3, r, e, s, i) {
              if (this.eatContextual(93))
                t3.local = this.parseIdentifier();
              else {
                let { imported: a } = t3;
                if (r)
                  throw this.raise(u.ImportBindingIsString, { at: t3, importName: a.value });
                this.checkReservedWord(a.name, t3.loc.start, true, true), t3.local || (t3.local = Te(a));
              }
              return this.finishImportSpecifier(t3, "ImportSpecifier", i);
            }
            isThisParam(t3) {
              return t3.type === "Identifier" && t3.name === "this";
            }
          }, ai = class extends Th {
            constructor(t3, r) {
              t3 = dh(t3), super(t3, r), this.options = t3, this.initializeScopes(), this.plugins = vh(this.options.plugins), this.filename = t3.sourceFilename;
            }
            getScopeHandler() {
              return cs;
            }
            parse() {
              this.enterInitialScopes();
              let t3 = this.startNode(), r = this.startNode();
              return this.nextToken(), t3.errors = null, this.parseTopLevel(t3, r), t3.errors = this.state.errors, t3;
            }
          };
          function vh(t3) {
            let r = /* @__PURE__ */ new Map();
            for (let e of t3) {
              let [s, i] = Array.isArray(e) ? e : [e, {}];
              r.has(s) || r.set(s, i || {});
            }
            return r;
          }
          function Eh(t3, r) {
            var e;
            if (((e = r) == null ? void 0 : e.sourceType) === "unambiguous") {
              r = Object.assign({}, r);
              try {
                r.sourceType = "module";
                let s = st(r, t3), i = s.parse();
                if (s.sawUnambiguousESM)
                  return i;
                if (s.ambiguousScriptDifferentAst)
                  try {
                    return r.sourceType = "script", st(r, t3).parse();
                  } catch {
                  }
                else
                  i.program.sourceType = "script";
                return i;
              } catch (s) {
                try {
                  return r.sourceType = "script", st(r, t3).parse();
                } catch {
                }
                throw s;
              }
            } else
              return st(r, t3).parse();
          }
          function Ch(t3, r) {
            let e = st(r, t3);
            return e.options.strictMode && (e.state.strict = true), e.getExpression();
          }
          function bh(t3) {
            let r = {};
            for (let e of Object.keys(t3))
              r[e] = xe(t3[e]);
            return r;
          }
          var Sh = bh(Vo);
          function st(t3, r) {
            let e = ai;
            return t3 != null && t3.plugins && (ph(t3.plugins), e = wh(t3.plugins)), new e(t3, r);
          }
          var ni = {};
          function wh(t3) {
            let r = fh.filter((i) => te(t3, i)), e = r.join("/"), s = ni[e];
            if (!s) {
              s = ai;
              for (let i of r)
                s = si[i](s);
              ni[e] = s;
            }
            return s;
          }
          l.parse = Eh, l.parseExpression = Ch, l.tokTypes = Sh;
        } }), Gf = K({ "src/language-js/parse/json.js"(l, h) {
          "use strict";
          V();
          var f = mr(), d = yr(), y = _o(), P = Ro();
          function g() {
            let C = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, { allowComments: L = true } = C;
            return function(k) {
              let { parseExpression: H } = Uo(), W;
              try {
                W = H(k, { tokens: true, ranges: true });
              } catch (B) {
                throw P(B);
              }
              if (!L && f(W.comments))
                throw T(W.comments[0], "Comment");
              return S(W), W;
            };
          }
          function T(C, L) {
            let [j, k] = [C.loc.start, C.loc.end].map((H) => {
              let { line: W, column: B } = H;
              return { line: W, column: B + 1 };
            });
            return d(`${L} is not allowed in JSON.`, { start: j, end: k });
          }
          function S(C) {
            switch (C.type) {
              case "ArrayExpression":
                for (let L of C.elements)
                  L !== null && S(L);
                return;
              case "ObjectExpression":
                for (let L of C.properties)
                  S(L);
                return;
              case "ObjectProperty":
                if (C.computed)
                  throw T(C.key, "Computed key");
                if (C.shorthand)
                  throw T(C.key, "Shorthand property");
                C.key.type !== "Identifier" && S(C.key), S(C.value);
                return;
              case "UnaryExpression": {
                let { operator: L, argument: j } = C;
                if (L !== "+" && L !== "-")
                  throw T(C, `Operator '${C.operator}'`);
                if (j.type === "NumericLiteral" || j.type === "Identifier" && (j.name === "Infinity" || j.name === "NaN"))
                  return;
                throw T(j, `Operator '${L}' before '${j.type}'`);
              }
              case "Identifier":
                if (C.name !== "Infinity" && C.name !== "NaN" && C.name !== "undefined")
                  throw T(C, `Identifier '${C.name}'`);
                return;
              case "TemplateLiteral":
                if (f(C.expressions))
                  throw T(C.expressions[0], "'TemplateLiteral' with expression");
                for (let L of C.quasis)
                  S(L);
                return;
              case "NullLiteral":
              case "BooleanLiteral":
              case "NumericLiteral":
              case "StringLiteral":
              case "TemplateElement":
                return;
              default:
                throw T(C, `'${C.type}'`);
            }
          }
          var F = g(), I = { json: y({ parse: F, hasPragma() {
            return true;
          } }), json5: y(F), "json-stringify": y({ parse: g({ allowComments: false }), astFormat: "estree-json" }) };
          h.exports = I;
        } });
        V();
        var Jf = Nf(), Xf = To(), Yf = Lf(), We = _o(), Qf = Ro(), Zf = Wf(), ed = Gf(), td = { sourceType: "module", allowImportExportEverywhere: true, allowReturnOutsideFunction: true, allowSuperOutsideMethod: true, allowUndeclaredExports: true, errorRecovery: true, createParenthesizedExpressions: true, plugins: ["doExpressions", "exportDefaultFrom", "functionBind", "functionSent", "throwExpressions", "partialApplication", ["decorators", { decoratorsBeforeExport: false }], "importAssertions", "decimal", "moduleBlocks", "asyncDoExpressions", "regexpUnicodeSets", "destructuringPrivate", "decoratorAutoAccessors"], tokens: true, ranges: true }, sd = ["recordAndTuple", { syntaxType: "hash" }], mo = "v8intrinsic", yo = [["pipelineOperator", { proposal: "hack", topicToken: "%" }], ["pipelineOperator", { proposal: "minimal" }], ["pipelineOperator", { proposal: "fsharp" }]], de = function(l) {
          let h = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : td;
          return Object.assign(Object.assign({}, h), {}, { plugins: [...h.plugins, ...l] });
        }, rd = /@(?:no)?flow\b/;
        function id(l, h) {
          if (h.filepath && h.filepath.endsWith(".js.flow"))
            return true;
          let f = Xf(l);
          f && (l = l.slice(f.length));
          let d = Yf(l, 0);
          return d !== false && (l = l.slice(0, d)), rd.test(l);
        }
        function ad(l, h, f) {
          let d = Uo()[l], y = d(h, f), P = y.errors.find((g) => !cd.has(g.reasonCode));
          if (P)
            throw P;
          return y;
        }
        function Ge(l) {
          for (var h = arguments.length, f = new Array(h > 1 ? h - 1 : 0), d = 1; d < h; d++)
            f[d - 1] = arguments[d];
          return function(y, P) {
            let g = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
            if ((g.parser === "babel" || g.parser === "__babel_estree") && id(y, g))
              return g.parser = "babel-flow", $o(y, P, g);
            let T = f;
            g.__babelSourceType === "script" && (T = T.map((C) => Object.assign(Object.assign({}, C), {}, { sourceType: "script" }))), /#[[{]/.test(y) && (T = T.map((C) => de([sd], C)));
            let S = /%[A-Z]/.test(y);
            y.includes("|>") ? T = (S ? [...yo, mo] : yo).flatMap((L) => T.map((j) => de([L], j))) : S && (T = T.map((C) => de([mo], C)));
            let { result: F, error: I } = Jf(...T.map((C) => () => ad(l, y, C)));
            if (!F)
              throw Qf(I);
            return g.originalText = y, Zf(F, g);
          };
        }
        var nd = Ge("parse", de(["jsx", "flow"])), $o = Ge("parse", de(["jsx", ["flow", { all: true, enums: true }]])), od = Ge("parse", de(["jsx", "typescript"]), de(["typescript"])), ld = Ge("parse", de(["jsx", "flow", "estree"])), hd = Ge("parseExpression", de(["jsx"])), ud = Ge("parseExpression", de(["typescript"])), cd = /* @__PURE__ */ new Set(["StrictNumericEscape", "StrictWith", "StrictOctalLiteral", "StrictDelete", "StrictEvalArguments", "StrictEvalArgumentsBinding", "StrictFunction", "EmptyTypeArguments", "EmptyTypeParameters", "ConstructorHasTypeParameters", "UnsupportedParameterPropertyKind", "UnexpectedParameterModifier", "MixedLabeledAndUnlabeledElements", "InvalidTupleMemberLabel", "NonClassMethodPropertyHasAbstractModifer", "ReadonlyForMethodSignature", "ClassMethodHasDeclare", "ClassMethodHasReadonly", "InvalidModifierOnTypeMember", "DuplicateAccessibilityModifier", "IndexSignatureHasDeclare", "DecoratorExportClass", "ParamDupe", "InvalidDecimal", "RestTrailingComma", "UnsupportedParameterDecorator", "UnterminatedJsxContent", "UnexpectedReservedWord", "ModuleAttributesWithDuplicateKeys", "LineTerminatorBeforeArrow", "InvalidEscapeSequenceTemplate", "NonAbstractClassHasAbstractMethod", "UnsupportedPropertyDecorator", "OptionalTypeBeforeRequired", "PatternIsOptional", "OptionalBindingPattern", "DeclareClassFieldHasInitializer", "TypeImportCannotSpecifyDefaultAndNamed", "DeclareFunctionHasImplementation", "ConstructorClassField", "VarRedeclaration", "InvalidPrivateFieldResolution", "DuplicateExport"]), xo = We(nd), go = We(od), Po = We(hd), pd = We(ud);
        Ho.exports = { parsers: Object.assign(Object.assign({ babel: xo, "babel-flow": We($o), "babel-ts": go }, ed), {}, { __js_expression: Po, __vue_expression: Po, __vue_ts_expression: pd, __vue_event_binding: xo, __vue_ts_event_binding: go, __babel_estree: We(ld) }) };
      });
      return fd();
    });
  }
});

// node_modules/prettier/parser-flow.js
var require_parser_flow = __commonJS({
  "node_modules/prettier/parser-flow.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.flow = e();
      }
    })(function() {
      "use strict";
      var Ne = (I0, L0) => () => (L0 || I0((L0 = { exports: {} }).exports, L0), L0.exports);
      var Ai = Ne((Bae, in0) => {
        var h_ = function(I0) {
          return I0 && I0.Math == Math && I0;
        };
        in0.exports = h_(typeof globalThis == "object" && globalThis) || h_(typeof window == "object" && window) || h_(typeof self == "object" && self) || h_(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var Wc = Ne((qae, fn0) => {
        fn0.exports = function(I0) {
          try {
            return !!I0();
          } catch {
            return true;
          }
        };
      });
      var ws = Ne((Uae, xn0) => {
        var W7e = Wc();
        xn0.exports = !W7e(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var BR = Ne((Hae, an0) => {
        var J7e = Wc();
        an0.exports = !J7e(function() {
          var I0 = function() {
          }.bind();
          return typeof I0 != "function" || I0.hasOwnProperty("prototype");
        });
      });
      var w_ = Ne((Xae, on0) => {
        var $7e = BR(), k_ = Function.prototype.call;
        on0.exports = $7e ? k_.bind(k_) : function() {
          return k_.apply(k_, arguments);
        };
      });
      var ln0 = Ne((vn0) => {
        "use strict";
        var cn0 = {}.propertyIsEnumerable, sn0 = Object.getOwnPropertyDescriptor, Z7e = sn0 && !cn0.call({ 1: 2 }, 1);
        vn0.f = Z7e ? function(L0) {
          var rr = sn0(this, L0);
          return !!rr && rr.enumerable;
        } : cn0;
      });
      var qR = Ne((Vae, bn0) => {
        bn0.exports = function(I0, L0) {
          return { enumerable: !(I0 & 1), configurable: !(I0 & 2), writable: !(I0 & 4), value: L0 };
        };
      });
      var Es = Ne((zae, _n0) => {
        var pn0 = BR(), mn0 = Function.prototype, UR = mn0.call, Q7e = pn0 && mn0.bind.bind(UR, UR);
        _n0.exports = pn0 ? Q7e : function(I0) {
          return function() {
            return UR.apply(I0, arguments);
          };
        };
      });
      var hn0 = Ne((Kae, dn0) => {
        var yn0 = Es(), rie = yn0({}.toString), eie = yn0("".slice);
        dn0.exports = function(I0) {
          return eie(rie(I0), 8, -1);
        };
      });
      var wn0 = Ne((Wae, kn0) => {
        var nie = Es(), tie = Wc(), uie = hn0(), HR = Object, iie = nie("".split);
        kn0.exports = tie(function() {
          return !HR("z").propertyIsEnumerable(0);
        }) ? function(I0) {
          return uie(I0) == "String" ? iie(I0, "") : HR(I0);
        } : HR;
      });
      var XR = Ne((Jae, En0) => {
        En0.exports = function(I0) {
          return I0 == null;
        };
      });
      var YR = Ne(($ae, Sn0) => {
        var fie = XR(), xie = TypeError;
        Sn0.exports = function(I0) {
          if (fie(I0))
            throw xie("Can't call method on " + I0);
          return I0;
        };
      });
      var E_ = Ne((Zae, gn0) => {
        var aie = wn0(), oie = YR();
        gn0.exports = function(I0) {
          return aie(oie(I0));
        };
      });
      var zR = Ne((Qae, Fn0) => {
        var VR = typeof document == "object" && document.all, cie = typeof VR > "u" && VR !== void 0;
        Fn0.exports = { all: VR, IS_HTMLDDA: cie };
      });
      var Zi = Ne((roe, On0) => {
        var Tn0 = zR(), sie = Tn0.all;
        On0.exports = Tn0.IS_HTMLDDA ? function(I0) {
          return typeof I0 == "function" || I0 === sie;
        } : function(I0) {
          return typeof I0 == "function";
        };
      });
      var S2 = Ne((eoe, Nn0) => {
        var In0 = Zi(), An0 = zR(), vie = An0.all;
        Nn0.exports = An0.IS_HTMLDDA ? function(I0) {
          return typeof I0 == "object" ? I0 !== null : In0(I0) || I0 === vie;
        } : function(I0) {
          return typeof I0 == "object" ? I0 !== null : In0(I0);
        };
      });
      var S_ = Ne((noe, Cn0) => {
        var KR = Ai(), lie = Zi(), bie = function(I0) {
          return lie(I0) ? I0 : void 0;
        };
        Cn0.exports = function(I0, L0) {
          return arguments.length < 2 ? bie(KR[I0]) : KR[I0] && KR[I0][L0];
        };
      });
      var Dn0 = Ne((toe, Pn0) => {
        var pie = Es();
        Pn0.exports = pie({}.isPrototypeOf);
      });
      var Rn0 = Ne((uoe, Ln0) => {
        var mie = S_();
        Ln0.exports = mie("navigator", "userAgent") || "";
      });
      var Hn0 = Ne((ioe, Un0) => {
        var qn0 = Ai(), WR = Rn0(), jn0 = qn0.process, Gn0 = qn0.Deno, Mn0 = jn0 && jn0.versions || Gn0 && Gn0.version, Bn0 = Mn0 && Mn0.v8, Qi, g_;
        Bn0 && (Qi = Bn0.split("."), g_ = Qi[0] > 0 && Qi[0] < 4 ? 1 : +(Qi[0] + Qi[1]));
        !g_ && WR && (Qi = WR.match(/Edge\/(\d+)/), (!Qi || Qi[1] >= 74) && (Qi = WR.match(/Chrome\/(\d+)/), Qi && (g_ = +Qi[1])));
        Un0.exports = g_;
      });
      var JR = Ne((foe, Yn0) => {
        var Xn0 = Hn0(), _ie = Wc();
        Yn0.exports = !!Object.getOwnPropertySymbols && !_ie(function() {
          var I0 = Symbol();
          return !String(I0) || !(Object(I0) instanceof Symbol) || !Symbol.sham && Xn0 && Xn0 < 41;
        });
      });
      var $R = Ne((xoe, Vn0) => {
        var yie = JR();
        Vn0.exports = yie && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var ZR = Ne((aoe, zn0) => {
        var die = S_(), hie = Zi(), kie = Dn0(), wie = $R(), Eie = Object;
        zn0.exports = wie ? function(I0) {
          return typeof I0 == "symbol";
        } : function(I0) {
          var L0 = die("Symbol");
          return hie(L0) && kie(L0.prototype, Eie(I0));
        };
      });
      var Wn0 = Ne((ooe, Kn0) => {
        var Sie = String;
        Kn0.exports = function(I0) {
          try {
            return Sie(I0);
          } catch {
            return "Object";
          }
        };
      });
      var $n0 = Ne((coe, Jn0) => {
        var gie = Zi(), Fie = Wn0(), Tie = TypeError;
        Jn0.exports = function(I0) {
          if (gie(I0))
            return I0;
          throw Tie(Fie(I0) + " is not a function");
        };
      });
      var Qn0 = Ne((soe, Zn0) => {
        var Oie = $n0(), Iie = XR();
        Zn0.exports = function(I0, L0) {
          var rr = I0[L0];
          return Iie(rr) ? void 0 : Oie(rr);
        };
      });
      var et0 = Ne((voe, rt0) => {
        var QR = w_(), rj = Zi(), ej = S2(), Aie = TypeError;
        rt0.exports = function(I0, L0) {
          var rr, hr;
          if (L0 === "string" && rj(rr = I0.toString) && !ej(hr = QR(rr, I0)) || rj(rr = I0.valueOf) && !ej(hr = QR(rr, I0)) || L0 !== "string" && rj(rr = I0.toString) && !ej(hr = QR(rr, I0)))
            return hr;
          throw Aie("Can't convert object to primitive value");
        };
      });
      var tt0 = Ne((loe, nt0) => {
        nt0.exports = false;
      });
      var F_ = Ne((boe, it0) => {
        var ut0 = Ai(), Nie = Object.defineProperty;
        it0.exports = function(I0, L0) {
          try {
            Nie(ut0, I0, { value: L0, configurable: true, writable: true });
          } catch {
            ut0[I0] = L0;
          }
          return L0;
        };
      });
      var T_ = Ne((poe, xt0) => {
        var Cie = Ai(), Pie = F_(), ft0 = "__core-js_shared__", Die = Cie[ft0] || Pie(ft0, {});
        xt0.exports = Die;
      });
      var nj = Ne((moe, ot0) => {
        var Lie = tt0(), at0 = T_();
        (ot0.exports = function(I0, L0) {
          return at0[I0] || (at0[I0] = L0 !== void 0 ? L0 : {});
        })("versions", []).push({ version: "3.26.1", mode: Lie ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var st0 = Ne((_oe, ct0) => {
        var Rie = YR(), jie = Object;
        ct0.exports = function(I0) {
          return jie(Rie(I0));
        };
      });
      var n1 = Ne((yoe, vt0) => {
        var Gie = Es(), Mie = st0(), Bie = Gie({}.hasOwnProperty);
        vt0.exports = Object.hasOwn || function(L0, rr) {
          return Bie(Mie(L0), rr);
        };
      });
      var tj = Ne((doe, lt0) => {
        var qie = Es(), Uie = 0, Hie = Math.random(), Xie = qie(1 .toString);
        lt0.exports = function(I0) {
          return "Symbol(" + (I0 === void 0 ? "" : I0) + ")_" + Xie(++Uie + Hie, 36);
        };
      });
      var dt0 = Ne((hoe, yt0) => {
        var Yie = Ai(), Vie = nj(), bt0 = n1(), zie = tj(), pt0 = JR(), _t0 = $R(), g2 = Vie("wks"), xv = Yie.Symbol, mt0 = xv && xv.for, Kie = _t0 ? xv : xv && xv.withoutSetter || zie;
        yt0.exports = function(I0) {
          if (!bt0(g2, I0) || !(pt0 || typeof g2[I0] == "string")) {
            var L0 = "Symbol." + I0;
            pt0 && bt0(xv, I0) ? g2[I0] = xv[I0] : _t0 && mt0 ? g2[I0] = mt0(L0) : g2[I0] = Kie(L0);
          }
          return g2[I0];
        };
      });
      var Et0 = Ne((koe, wt0) => {
        var Wie = w_(), ht0 = S2(), kt0 = ZR(), Jie = Qn0(), $ie = et0(), Zie = dt0(), Qie = TypeError, rfe = Zie("toPrimitive");
        wt0.exports = function(I0, L0) {
          if (!ht0(I0) || kt0(I0))
            return I0;
          var rr = Jie(I0, rfe), hr;
          if (rr) {
            if (L0 === void 0 && (L0 = "default"), hr = Wie(rr, I0, L0), !ht0(hr) || kt0(hr))
              return hr;
            throw Qie("Can't convert object to primitive value");
          }
          return L0 === void 0 && (L0 = "number"), $ie(I0, L0);
        };
      });
      var uj = Ne((woe, St0) => {
        var efe = Et0(), nfe = ZR();
        St0.exports = function(I0) {
          var L0 = efe(I0, "string");
          return nfe(L0) ? L0 : L0 + "";
        };
      });
      var Tt0 = Ne((Eoe, Ft0) => {
        var tfe = Ai(), gt0 = S2(), ij = tfe.document, ufe = gt0(ij) && gt0(ij.createElement);
        Ft0.exports = function(I0) {
          return ufe ? ij.createElement(I0) : {};
        };
      });
      var fj = Ne((Soe, Ot0) => {
        var ife = ws(), ffe = Wc(), xfe = Tt0();
        Ot0.exports = !ife && !ffe(function() {
          return Object.defineProperty(xfe("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var xj = Ne((At0) => {
        var afe = ws(), ofe = w_(), cfe = ln0(), sfe = qR(), vfe = E_(), lfe = uj(), bfe = n1(), pfe = fj(), It0 = Object.getOwnPropertyDescriptor;
        At0.f = afe ? It0 : function(L0, rr) {
          if (L0 = vfe(L0), rr = lfe(rr), pfe)
            try {
              return It0(L0, rr);
            } catch {
            }
          if (bfe(L0, rr))
            return sfe(!ofe(cfe.f, L0, rr), L0[rr]);
        };
      });
      var Ct0 = Ne((Foe, Nt0) => {
        var mfe = ws(), _fe = Wc();
        Nt0.exports = mfe && _fe(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var O_ = Ne((Toe, Pt0) => {
        var yfe = S2(), dfe = String, hfe = TypeError;
        Pt0.exports = function(I0) {
          if (yfe(I0))
            return I0;
          throw hfe(dfe(I0) + " is not an object");
        };
      });
      var o4 = Ne((Lt0) => {
        var kfe = ws(), wfe = fj(), Efe = Ct0(), I_ = O_(), Dt0 = uj(), Sfe = TypeError, aj = Object.defineProperty, gfe = Object.getOwnPropertyDescriptor, oj = "enumerable", cj = "configurable", sj = "writable";
        Lt0.f = kfe ? Efe ? function(L0, rr, hr) {
          if (I_(L0), rr = Dt0(rr), I_(hr), typeof L0 == "function" && rr === "prototype" && "value" in hr && sj in hr && !hr[sj]) {
            var se = gfe(L0, rr);
            se && se[sj] && (L0[rr] = hr.value, hr = { configurable: cj in hr ? hr[cj] : se[cj], enumerable: oj in hr ? hr[oj] : se[oj], writable: false });
          }
          return aj(L0, rr, hr);
        } : aj : function(L0, rr, hr) {
          if (I_(L0), rr = Dt0(rr), I_(hr), wfe)
            try {
              return aj(L0, rr, hr);
            } catch {
            }
          if ("get" in hr || "set" in hr)
            throw Sfe("Accessors not supported");
          return "value" in hr && (L0[rr] = hr.value), L0;
        };
      });
      var vj = Ne((Ioe, Rt0) => {
        var Ffe = ws(), Tfe = o4(), Ofe = qR();
        Rt0.exports = Ffe ? function(I0, L0, rr) {
          return Tfe.f(I0, L0, Ofe(1, rr));
        } : function(I0, L0, rr) {
          return I0[L0] = rr, I0;
        };
      });
      var Mt0 = Ne((Aoe, Gt0) => {
        var lj = ws(), Ife = n1(), jt0 = Function.prototype, Afe = lj && Object.getOwnPropertyDescriptor, bj = Ife(jt0, "name"), Nfe = bj && function() {
        }.name === "something", Cfe = bj && (!lj || lj && Afe(jt0, "name").configurable);
        Gt0.exports = { EXISTS: bj, PROPER: Nfe, CONFIGURABLE: Cfe };
      });
      var qt0 = Ne((Noe, Bt0) => {
        var Pfe = Es(), Dfe = Zi(), pj = T_(), Lfe = Pfe(Function.toString);
        Dfe(pj.inspectSource) || (pj.inspectSource = function(I0) {
          return Lfe(I0);
        });
        Bt0.exports = pj.inspectSource;
      });
      var Xt0 = Ne((Coe, Ht0) => {
        var Rfe = Ai(), jfe = Zi(), Ut0 = Rfe.WeakMap;
        Ht0.exports = jfe(Ut0) && /native code/.test(String(Ut0));
      });
      var zt0 = Ne((Poe, Vt0) => {
        var Gfe = nj(), Mfe = tj(), Yt0 = Gfe("keys");
        Vt0.exports = function(I0) {
          return Yt0[I0] || (Yt0[I0] = Mfe(I0));
        };
      });
      var mj = Ne((Doe, Kt0) => {
        Kt0.exports = {};
      });
      var Zt0 = Ne((Loe, $t0) => {
        var Bfe = Xt0(), Jt0 = Ai(), qfe = S2(), Ufe = vj(), _j = n1(), yj = T_(), Hfe = zt0(), Xfe = mj(), Wt0 = "Object already initialized", dj = Jt0.TypeError, Yfe = Jt0.WeakMap, A_, c4, N_, Vfe = function(I0) {
          return N_(I0) ? c4(I0) : A_(I0, {});
        }, zfe = function(I0) {
          return function(L0) {
            var rr;
            if (!qfe(L0) || (rr = c4(L0)).type !== I0)
              throw dj("Incompatible receiver, " + I0 + " required");
            return rr;
          };
        };
        Bfe || yj.state ? (rf = yj.state || (yj.state = new Yfe()), rf.get = rf.get, rf.has = rf.has, rf.set = rf.set, A_ = function(I0, L0) {
          if (rf.has(I0))
            throw dj(Wt0);
          return L0.facade = I0, rf.set(I0, L0), L0;
        }, c4 = function(I0) {
          return rf.get(I0) || {};
        }, N_ = function(I0) {
          return rf.has(I0);
        }) : (av = Hfe("state"), Xfe[av] = true, A_ = function(I0, L0) {
          if (_j(I0, av))
            throw dj(Wt0);
          return L0.facade = I0, Ufe(I0, av, L0), L0;
        }, c4 = function(I0) {
          return _j(I0, av) ? I0[av] : {};
        }, N_ = function(I0) {
          return _j(I0, av);
        });
        var rf, av;
        $t0.exports = { set: A_, get: c4, has: N_, enforce: Vfe, getterFor: zfe };
      });
      var kj = Ne((Roe, ru0) => {
        var Kfe = Wc(), Wfe = Zi(), C_ = n1(), hj = ws(), Jfe = Mt0().CONFIGURABLE, $fe = qt0(), Qt0 = Zt0(), Zfe = Qt0.enforce, Qfe = Qt0.get, P_ = Object.defineProperty, rxe = hj && !Kfe(function() {
          return P_(function() {
          }, "length", { value: 8 }).length !== 8;
        }), exe = String(String).split("String"), nxe = ru0.exports = function(I0, L0, rr) {
          String(L0).slice(0, 7) === "Symbol(" && (L0 = "[" + String(L0).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), rr && rr.getter && (L0 = "get " + L0), rr && rr.setter && (L0 = "set " + L0), (!C_(I0, "name") || Jfe && I0.name !== L0) && (hj ? P_(I0, "name", { value: L0, configurable: true }) : I0.name = L0), rxe && rr && C_(rr, "arity") && I0.length !== rr.arity && P_(I0, "length", { value: rr.arity });
          try {
            rr && C_(rr, "constructor") && rr.constructor ? hj && P_(I0, "prototype", { writable: false }) : I0.prototype && (I0.prototype = void 0);
          } catch {
          }
          var hr = Zfe(I0);
          return C_(hr, "source") || (hr.source = exe.join(typeof L0 == "string" ? L0 : "")), I0;
        };
        Function.prototype.toString = nxe(function() {
          return Wfe(this) && Qfe(this).source || $fe(this);
        }, "toString");
      });
      var nu0 = Ne((joe, eu0) => {
        var txe = Zi(), uxe = o4(), ixe = kj(), fxe = F_();
        eu0.exports = function(I0, L0, rr, hr) {
          hr || (hr = {});
          var se = hr.enumerable, qe = hr.name !== void 0 ? hr.name : L0;
          if (txe(rr) && ixe(rr, qe, hr), hr.global)
            se ? I0[L0] = rr : fxe(L0, rr);
          else {
            try {
              hr.unsafe ? I0[L0] && (se = true) : delete I0[L0];
            } catch {
            }
            se ? I0[L0] = rr : uxe.f(I0, L0, { value: rr, enumerable: false, configurable: !hr.nonConfigurable, writable: !hr.nonWritable });
          }
          return I0;
        };
      });
      var uu0 = Ne((Goe, tu0) => {
        var xxe = Math.ceil, axe = Math.floor;
        tu0.exports = Math.trunc || function(L0) {
          var rr = +L0;
          return (rr > 0 ? axe : xxe)(rr);
        };
      });
      var wj = Ne((Moe, iu0) => {
        var oxe = uu0();
        iu0.exports = function(I0) {
          var L0 = +I0;
          return L0 !== L0 || L0 === 0 ? 0 : oxe(L0);
        };
      });
      var xu0 = Ne((Boe, fu0) => {
        var cxe = wj(), sxe = Math.max, vxe = Math.min;
        fu0.exports = function(I0, L0) {
          var rr = cxe(I0);
          return rr < 0 ? sxe(rr + L0, 0) : vxe(rr, L0);
        };
      });
      var ou0 = Ne((qoe, au0) => {
        var lxe = wj(), bxe = Math.min;
        au0.exports = function(I0) {
          return I0 > 0 ? bxe(lxe(I0), 9007199254740991) : 0;
        };
      });
      var su0 = Ne((Uoe, cu0) => {
        var pxe = ou0();
        cu0.exports = function(I0) {
          return pxe(I0.length);
        };
      });
      var bu0 = Ne((Hoe, lu0) => {
        var mxe = E_(), _xe = xu0(), yxe = su0(), vu0 = function(I0) {
          return function(L0, rr, hr) {
            var se = mxe(L0), qe = yxe(se), Ce = _xe(hr, qe), gn;
            if (I0 && rr != rr) {
              for (; qe > Ce; )
                if (gn = se[Ce++], gn != gn)
                  return true;
            } else
              for (; qe > Ce; Ce++)
                if ((I0 || Ce in se) && se[Ce] === rr)
                  return I0 || Ce || 0;
            return !I0 && -1;
          };
        };
        lu0.exports = { includes: vu0(true), indexOf: vu0(false) };
      });
      var _u0 = Ne((Xoe, mu0) => {
        var dxe = Es(), Ej = n1(), hxe = E_(), kxe = bu0().indexOf, wxe = mj(), pu0 = dxe([].push);
        mu0.exports = function(I0, L0) {
          var rr = hxe(I0), hr = 0, se = [], qe;
          for (qe in rr)
            !Ej(wxe, qe) && Ej(rr, qe) && pu0(se, qe);
          for (; L0.length > hr; )
            Ej(rr, qe = L0[hr++]) && (~kxe(se, qe) || pu0(se, qe));
          return se;
        };
      });
      var du0 = Ne((Yoe, yu0) => {
        yu0.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var ku0 = Ne((hu0) => {
        var Exe = _u0(), Sxe = du0(), gxe = Sxe.concat("length", "prototype");
        hu0.f = Object.getOwnPropertyNames || function(L0) {
          return Exe(L0, gxe);
        };
      });
      var Eu0 = Ne((wu0) => {
        wu0.f = Object.getOwnPropertySymbols;
      });
      var gu0 = Ne((Koe, Su0) => {
        var Fxe = S_(), Txe = Es(), Oxe = ku0(), Ixe = Eu0(), Axe = O_(), Nxe = Txe([].concat);
        Su0.exports = Fxe("Reflect", "ownKeys") || function(L0) {
          var rr = Oxe.f(Axe(L0)), hr = Ixe.f;
          return hr ? Nxe(rr, hr(L0)) : rr;
        };
      });
      var Ou0 = Ne((Woe, Tu0) => {
        var Fu0 = n1(), Cxe = gu0(), Pxe = xj(), Dxe = o4();
        Tu0.exports = function(I0, L0, rr) {
          for (var hr = Cxe(L0), se = Dxe.f, qe = Pxe.f, Ce = 0; Ce < hr.length; Ce++) {
            var gn = hr[Ce];
            !Fu0(I0, gn) && !(rr && Fu0(rr, gn)) && se(I0, gn, qe(L0, gn));
          }
        };
      });
      var Au0 = Ne((Joe, Iu0) => {
        var Lxe = Wc(), Rxe = Zi(), jxe = /#|\.prototype\./, s4 = function(I0, L0) {
          var rr = Mxe[Gxe(I0)];
          return rr == qxe ? true : rr == Bxe ? false : Rxe(L0) ? Lxe(L0) : !!L0;
        }, Gxe = s4.normalize = function(I0) {
          return String(I0).replace(jxe, ".").toLowerCase();
        }, Mxe = s4.data = {}, Bxe = s4.NATIVE = "N", qxe = s4.POLYFILL = "P";
        Iu0.exports = s4;
      });
      var Cu0 = Ne(($oe, Nu0) => {
        var Sj = Ai(), Uxe = xj().f, Hxe = vj(), Xxe = nu0(), Yxe = F_(), Vxe = Ou0(), zxe = Au0();
        Nu0.exports = function(I0, L0) {
          var rr = I0.target, hr = I0.global, se = I0.stat, qe, Ce, gn, En, Jn, In;
          if (hr ? Ce = Sj : se ? Ce = Sj[rr] || Yxe(rr, {}) : Ce = (Sj[rr] || {}).prototype, Ce)
            for (gn in L0) {
              if (Jn = L0[gn], I0.dontCallGetSet ? (In = Uxe(Ce, gn), En = In && In.value) : En = Ce[gn], qe = zxe(hr ? gn : rr + (se ? "." : "#") + gn, I0.forced), !qe && En !== void 0) {
                if (typeof Jn == typeof En)
                  continue;
                Vxe(Jn, En);
              }
              (I0.sham || En && En.sham) && Hxe(Jn, "sham", true), Xxe(Ce, gn, Jn, I0);
            }
        };
      });
      var Pu0 = Ne(() => {
        var Kxe = Cu0(), gj = Ai();
        Kxe({ global: true, forced: gj.globalThis !== gj }, { globalThis: gj });
      });
      var Du0 = Ne(() => {
        Pu0();
      });
      var ju0 = Ne((nce, Ru0) => {
        var Lu0 = kj(), Wxe = o4();
        Ru0.exports = function(I0, L0, rr) {
          return rr.get && Lu0(rr.get, L0, { getter: true }), rr.set && Lu0(rr.set, L0, { setter: true }), Wxe.f(I0, L0, rr);
        };
      });
      var Mu0 = Ne((tce, Gu0) => {
        "use strict";
        var Jxe = O_();
        Gu0.exports = function() {
          var I0 = Jxe(this), L0 = "";
          return I0.hasIndices && (L0 += "d"), I0.global && (L0 += "g"), I0.ignoreCase && (L0 += "i"), I0.multiline && (L0 += "m"), I0.dotAll && (L0 += "s"), I0.unicode && (L0 += "u"), I0.unicodeSets && (L0 += "v"), I0.sticky && (L0 += "y"), L0;
        };
      });
      var Uu0 = Ne(() => {
        var $xe = Ai(), Zxe = ws(), Qxe = ju0(), rae = Mu0(), eae = Wc(), Bu0 = $xe.RegExp, qu0 = Bu0.prototype, nae = Zxe && eae(function() {
          var I0 = true;
          try {
            Bu0(".", "d");
          } catch {
            I0 = false;
          }
          var L0 = {}, rr = "", hr = I0 ? "dgimsy" : "gimsy", se = function(En, Jn) {
            Object.defineProperty(L0, En, { get: function() {
              return rr += Jn, true;
            } });
          }, qe = { dotAll: "s", global: "g", ignoreCase: "i", multiline: "m", sticky: "y" };
          I0 && (qe.hasIndices = "d");
          for (var Ce in qe)
            se(Ce, qe[Ce]);
          var gn = Object.getOwnPropertyDescriptor(qu0, "flags").get.call(L0);
          return gn !== hr || rr !== hr;
        });
        nae && Qxe(qu0, "flags", { configurable: true, get: rae });
      });
      var Dae = Ne((fce, s70) => {
        Du0();
        Uu0();
        var tU = Object.defineProperty, tae = Object.getOwnPropertyDescriptor, uU = Object.getOwnPropertyNames, uae = Object.prototype.hasOwnProperty, L_ = (I0, L0) => function() {
          return I0 && (L0 = (0, I0[uU(I0)[0]])(I0 = 0)), L0;
        }, ru = (I0, L0) => function() {
          return L0 || (0, I0[uU(I0)[0]])((L0 = { exports: {} }).exports, L0), L0.exports;
        }, iU = (I0, L0) => {
          for (var rr in L0)
            tU(I0, rr, { get: L0[rr], enumerable: true });
        }, iae = (I0, L0, rr, hr) => {
          if (L0 && typeof L0 == "object" || typeof L0 == "function")
            for (let se of uU(L0))
              !uae.call(I0, se) && se !== rr && tU(I0, se, { get: () => L0[se], enumerable: !(hr = tae(L0, se)) || hr.enumerable });
          return I0;
        }, fU = (I0) => iae(tU({}, "__esModule", { value: true }), I0), Dt = L_({ "<define:process>"() {
        } }), Hu0 = ru({ "src/common/parser-create-error.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr, se) {
            let qe = new SyntaxError(hr + " (" + se.start.line + ":" + se.start.column + ")");
            return qe.loc = se, qe;
          }
          L0.exports = rr;
        } }), Xu0 = {};
        iU(Xu0, { EOL: () => Ij, arch: () => fae, cpus: () => $u0, default: () => n70, endianness: () => Yu0, freemem: () => Wu0, getNetworkInterfaces: () => e70, hostname: () => Vu0, loadavg: () => zu0, networkInterfaces: () => r70, platform: () => xae, release: () => Qu0, tmpDir: () => Tj, tmpdir: () => Oj, totalmem: () => Ju0, type: () => Zu0, uptime: () => Ku0 });
        function Yu0() {
          if (typeof D_ > "u") {
            var I0 = new ArrayBuffer(2), L0 = new Uint8Array(I0), rr = new Uint16Array(I0);
            if (L0[0] = 1, L0[1] = 2, rr[0] === 258)
              D_ = "BE";
            else if (rr[0] === 513)
              D_ = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return D_;
        }
        function Vu0() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function zu0() {
          return [];
        }
        function Ku0() {
          return 0;
        }
        function Wu0() {
          return Number.MAX_VALUE;
        }
        function Ju0() {
          return Number.MAX_VALUE;
        }
        function $u0() {
          return [];
        }
        function Zu0() {
          return "Browser";
        }
        function Qu0() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function r70() {
        }
        function e70() {
        }
        function fae() {
          return "javascript";
        }
        function xae() {
          return "browser";
        }
        function Tj() {
          return "/tmp";
        }
        var D_, Oj, Ij, n70, aae = L_({ "node-modules-polyfills:os"() {
          Dt(), Oj = Tj, Ij = `
`, n70 = { EOL: Ij, tmpdir: Oj, tmpDir: Tj, networkInterfaces: r70, getNetworkInterfaces: e70, release: Qu0, type: Zu0, cpus: $u0, totalmem: Ju0, freemem: Wu0, uptime: Ku0, loadavg: zu0, hostname: Vu0, endianness: Yu0 };
        } }), oae = ru({ "node-modules-polyfills-commonjs:os"(I0, L0) {
          Dt();
          var rr = (aae(), fU(Xu0));
          if (rr && rr.default) {
            L0.exports = rr.default;
            for (let hr in rr)
              L0.exports[hr] = rr[hr];
          } else
            rr && (L0.exports = rr);
        } }), cae = ru({ "node_modules/detect-newline/index.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = (hr) => {
            if (typeof hr != "string")
              throw new TypeError("Expected a string");
            let se = hr.match(/(?:\r?\n)/g) || [];
            if (se.length === 0)
              return;
            let qe = se.filter((gn) => gn === `\r
`).length, Ce = se.length - qe;
            return qe > Ce ? `\r
` : `
`;
          };
          L0.exports = rr, L0.exports.graceful = (hr) => typeof hr == "string" && rr(hr) || `
`;
        } }), sae = ru({ "node_modules/jest-docblock/build/index.js"(I0) {
          "use strict";
          Dt(), Object.defineProperty(I0, "__esModule", { value: true }), I0.extract = Mu, I0.parse = ct, I0.parseWithComments = o7, I0.print = Sn, I0.strip = fn;
          function L0() {
            let Ze = oae();
            return L0 = function() {
              return Ze;
            }, Ze;
          }
          function rr() {
            let Ze = hr(cae());
            return rr = function() {
              return Ze;
            }, Ze;
          }
          function hr(Ze) {
            return Ze && Ze.__esModule ? Ze : { default: Ze };
          }
          var se = /\*\/$/, qe = /^\/\*\*?/, Ce = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, gn = /(^|\s+)\/\/([^\r\n]*)/g, En = /^(\r?\n)+/, Jn = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, In = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, it2 = /(\r?\n|^) *\* ?/g, ot = [];
          function Mu(Ze) {
            let Xt = Ze.match(Ce);
            return Xt ? Xt[0].trimLeft() : "";
          }
          function fn(Ze) {
            let Xt = Ze.match(Ce);
            return Xt && Xt[0] ? Ze.substring(Xt[0].length) : Ze;
          }
          function ct(Ze) {
            return o7(Ze).pragmas;
          }
          function o7(Ze) {
            let Xt = (0, rr().default)(Ze) || L0().EOL;
            Ze = Ze.replace(qe, "").replace(se, "").replace(it2, "$1");
            let S7 = "";
            for (; S7 !== Ze; )
              S7 = Ze, Ze = Ze.replace(Jn, `${Xt}$1 $2${Xt}`);
            Ze = Ze.replace(En, "").trimRight();
            let Lt = /* @__PURE__ */ Object.create(null), Ss = Ze.replace(In, "").replace(En, "").trimRight(), Nn;
            for (; Nn = In.exec(Ze); ) {
              let Jc = Nn[2].replace(gn, "");
              typeof Lt[Nn[1]] == "string" || Array.isArray(Lt[Nn[1]]) ? Lt[Nn[1]] = ot.concat(Lt[Nn[1]], Jc) : Lt[Nn[1]] = Jc;
            }
            return { comments: Ss, pragmas: Lt };
          }
          function Sn(Ze) {
            let { comments: Xt = "", pragmas: S7 = {} } = Ze, Lt = (0, rr().default)(Xt) || L0().EOL, Ss = "/**", Nn = " *", Jc = " */", Ni = Object.keys(S7), li = Ni.map((g7) => ln(g7, S7[g7])).reduce((g7, ov) => g7.concat(ov), []).map((g7) => `${Nn} ${g7}${Lt}`).join("");
            if (!Xt) {
              if (Ni.length === 0)
                return "";
              if (Ni.length === 1 && !Array.isArray(S7[Ni[0]])) {
                let g7 = S7[Ni[0]];
                return `${Ss} ${ln(Ni[0], g7)[0]}${Jc}`;
              }
            }
            let Gt = Xt.split(Lt).map((g7) => `${Nn} ${g7}`).join(Lt) + Lt;
            return Ss + Lt + (Xt ? Gt : "") + (Xt && Ni.length ? Nn + Lt : "") + li + Jc;
          }
          function ln(Ze, Xt) {
            return ot.concat(Xt).map((S7) => `@${Ze} ${S7}`.trim());
          }
        } }), vae = ru({ "src/common/end-of-line.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(Ce) {
            let gn = Ce.indexOf("\r");
            return gn >= 0 ? Ce.charAt(gn + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function hr(Ce) {
            switch (Ce) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function se(Ce, gn) {
            let En;
            switch (gn) {
              case `
`:
                En = /\n/g;
                break;
              case "\r":
                En = /\r/g;
                break;
              case `\r
`:
                En = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(gn)}.`);
            }
            let Jn = Ce.match(En);
            return Jn ? Jn.length : 0;
          }
          function qe(Ce) {
            return Ce.replace(/\r\n?/g, `
`);
          }
          L0.exports = { guessEndOfLine: rr, convertEndOfLineToChars: hr, countEndOfLineChars: se, normalizeEndOfLine: qe };
        } }), lae = ru({ "src/language-js/utils/get-shebang.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr) {
            if (!hr.startsWith("#!"))
              return "";
            let se = hr.indexOf(`
`);
            return se === -1 ? hr : hr.slice(0, se);
          }
          L0.exports = rr;
        } }), bae = ru({ "src/language-js/pragma.js"(I0, L0) {
          "use strict";
          Dt();
          var { parseWithComments: rr, strip: hr, extract: se, print: qe } = sae(), { normalizeEndOfLine: Ce } = vae(), gn = lae();
          function En(it2) {
            let ot = gn(it2);
            ot && (it2 = it2.slice(ot.length + 1));
            let Mu = se(it2), { pragmas: fn, comments: ct } = rr(Mu);
            return { shebang: ot, text: it2, pragmas: fn, comments: ct };
          }
          function Jn(it2) {
            let ot = Object.keys(En(it2).pragmas);
            return ot.includes("prettier") || ot.includes("format");
          }
          function In(it2) {
            let { shebang: ot, text: Mu, pragmas: fn, comments: ct } = En(it2), o7 = hr(Mu), Sn = qe({ pragmas: Object.assign({ format: "" }, fn), comments: ct.trimStart() });
            return (ot ? `${ot}
` : "") + Ce(Sn) + (o7.startsWith(`
`) ? `
` : `

`) + o7;
          }
          L0.exports = { hasPragma: Jn, insertPragma: In };
        } }), t70 = ru({ "src/utils/is-non-empty-array.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr) {
            return Array.isArray(hr) && hr.length > 0;
          }
          L0.exports = rr;
        } }), u70 = ru({ "src/language-js/loc.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = t70();
          function hr(En) {
            var Jn, In;
            let it2 = En.range ? En.range[0] : En.start, ot = (Jn = (In = En.declaration) === null || In === void 0 ? void 0 : In.decorators) !== null && Jn !== void 0 ? Jn : En.decorators;
            return rr(ot) ? Math.min(hr(ot[0]), it2) : it2;
          }
          function se(En) {
            return En.range ? En.range[1] : En.end;
          }
          function qe(En, Jn) {
            let In = hr(En);
            return Number.isInteger(In) && In === hr(Jn);
          }
          function Ce(En, Jn) {
            let In = se(En);
            return Number.isInteger(In) && In === se(Jn);
          }
          function gn(En, Jn) {
            return qe(En, Jn) && Ce(En, Jn);
          }
          L0.exports = { locStart: hr, locEnd: se, hasSameLocStart: qe, hasSameLoc: gn };
        } }), pae = ru({ "src/language-js/parse/utils/create-parser.js"(I0, L0) {
          "use strict";
          Dt();
          var { hasPragma: rr } = bae(), { locStart: hr, locEnd: se } = u70();
          function qe(Ce) {
            return Ce = typeof Ce == "function" ? { parse: Ce } : Ce, Object.assign({ astFormat: "estree", hasPragma: rr, locStart: hr, locEnd: se }, Ce);
          }
          L0.exports = qe;
        } }), mae = ru({ "src/language-js/parse/utils/replace-hashbang.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr) {
            return hr.charAt(0) === "#" && hr.charAt(1) === "!" ? "//" + hr.slice(2) : hr;
          }
          L0.exports = rr;
        } }), _ae = ru({ "src/language-js/utils/is-ts-keyword-type.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr) {
            let { type: se } = hr;
            return se.startsWith("TS") && se.endsWith("Keyword");
          }
          L0.exports = rr;
        } }), yae = ru({ "src/language-js/utils/is-block-comment.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]), hr = (se) => rr.has(se == null ? void 0 : se.type);
          L0.exports = hr;
        } }), dae = ru({ "src/language-js/utils/is-type-cast-comment.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = yae();
          function hr(se) {
            return rr(se) && se.value[0] === "*" && /@type\b/.test(se.value);
          }
          L0.exports = hr;
        } }), hae = ru({ "src/utils/get-last.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = (hr) => hr[hr.length - 1];
          L0.exports = rr;
        } }), i70 = ru({ "src/language-js/parse/postprocess/visit-node.js"(I0, L0) {
          "use strict";
          Dt();
          function rr(hr, se) {
            if (Array.isArray(hr)) {
              for (let qe = 0; qe < hr.length; qe++)
                hr[qe] = rr(hr[qe], se);
              return hr;
            }
            if (hr && typeof hr == "object" && typeof hr.type == "string") {
              let qe = Object.keys(hr);
              for (let Ce = 0; Ce < qe.length; Ce++)
                hr[qe[Ce]] = rr(hr[qe[Ce]], se);
              return se(hr) || hr;
            }
            return hr;
          }
          L0.exports = rr;
        } }), f70 = ru({ "src/language-js/parse/postprocess/throw-syntax-error.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = Hu0();
          function hr(se, qe) {
            let { start: Ce, end: gn } = se.loc;
            throw rr(qe, { start: { line: Ce.line, column: Ce.column + 1 }, end: { line: gn.line, column: gn.column + 1 } });
          }
          L0.exports = hr;
        } }), kae = ru({ "src/language-js/parse/postprocess/typescript.js"(I0, L0) {
          "use strict";
          Dt();
          var rr = t70(), hr = i70(), se = f70(), qe = { AbstractKeyword: 126, SourceFile: 308, PropertyDeclaration: 169 };
          function Ce(In) {
            for (; In && In.kind !== qe.SourceFile; )
              In = In.parent;
            return In;
          }
          function gn(In) {
            let { illegalDecorators: it2 } = In;
            if (!rr(it2))
              return;
            let [{ expression: ot }] = it2, Mu = Ce(ot), [fn, ct] = [ot.pos, ot.end].map((o7) => {
              let { line: Sn, character: ln } = Mu.getLineAndCharacterOfPosition(o7);
              return { line: Sn + 1, column: ln };
            });
            se({ loc: { start: fn, end: ct } }, "Decorators are not valid here.");
          }
          function En(In, it2) {
            In.kind !== qe.PropertyDeclaration || In.modifiers && !In.modifiers.some((ot) => ot.kind === qe.AbstractKeyword) || In.initializer && it2.value === null && se(it2, "Abstract property cannot have an initializer");
          }
          function Jn(In, it2) {
            let { esTreeNodeToTSNodeMap: ot, tsNodeToESTreeNodeMap: Mu } = it2.tsParseResult;
            hr(In, (fn) => {
              let ct = ot.get(fn);
              if (!ct)
                return;
              let o7 = Mu.get(ct);
              o7 === fn && (gn(ct), En(ct, o7));
            });
          }
          L0.exports = { throwErrorForInvalidNodes: Jn };
        } }), wae = ru({ "src/language-js/parse/postprocess/index.js"(I0, L0) {
          "use strict";
          Dt();
          var { locStart: rr, locEnd: hr } = u70(), se = _ae(), qe = dae(), Ce = hae(), gn = i70(), { throwErrorForInvalidNodes: En } = kae(), Jn = f70();
          function In(fn, ct) {
            if (ct.parser === "typescript" && /@|abstract/.test(ct.originalText) && En(fn, ct), ct.parser !== "typescript" && ct.parser !== "flow" && ct.parser !== "acorn" && ct.parser !== "espree" && ct.parser !== "meriyah") {
              let Sn = /* @__PURE__ */ new Set();
              fn = gn(fn, (ln) => {
                ln.leadingComments && ln.leadingComments.some(qe) && Sn.add(rr(ln));
              }), fn = gn(fn, (ln) => {
                if (ln.type === "ParenthesizedExpression") {
                  let { expression: Ze } = ln;
                  if (Ze.type === "TypeCastExpression")
                    return Ze.range = ln.range, Ze;
                  let Xt = rr(ln);
                  if (!Sn.has(Xt))
                    return Ze.extra = Object.assign(Object.assign({}, Ze.extra), {}, { parenthesized: true }), Ze;
                }
              });
            }
            return fn = gn(fn, (Sn) => {
              switch (Sn.type) {
                case "ChainExpression":
                  return it2(Sn.expression);
                case "LogicalExpression": {
                  if (ot(Sn))
                    return Mu(Sn);
                  break;
                }
                case "VariableDeclaration": {
                  let ln = Ce(Sn.declarations);
                  ln && ln.init && o7(Sn, ln);
                  break;
                }
                case "TSParenthesizedType":
                  return se(Sn.typeAnnotation) || Sn.typeAnnotation.type === "TSThisType" || (Sn.typeAnnotation.range = [rr(Sn), hr(Sn)]), Sn.typeAnnotation;
                case "TSTypeParameter":
                  if (typeof Sn.name == "string") {
                    let ln = rr(Sn);
                    Sn.name = { type: "Identifier", name: Sn.name, range: [ln, ln + Sn.name.length] };
                  }
                  break;
                case "ObjectExpression":
                  if (ct.parser === "typescript") {
                    let ln = Sn.properties.find((Ze) => Ze.type === "Property" && Ze.value.type === "TSEmptyBodyFunctionExpression");
                    ln && Jn(ln.value, "Unexpected token.");
                  }
                  break;
                case "SequenceExpression": {
                  let ln = Ce(Sn.expressions);
                  Sn.range = [rr(Sn), Math.min(hr(ln), hr(Sn))];
                  break;
                }
                case "TopicReference":
                  ct.__isUsingHackPipeline = true;
                  break;
                case "ExportAllDeclaration": {
                  let { exported: ln } = Sn;
                  if (ct.parser === "meriyah" && ln && ln.type === "Identifier") {
                    let Ze = ct.originalText.slice(rr(ln), hr(ln));
                    (Ze.startsWith('"') || Ze.startsWith("'")) && (Sn.exported = Object.assign(Object.assign({}, Sn.exported), {}, { type: "Literal", value: Sn.exported.name, raw: Ze }));
                  }
                  break;
                }
                case "PropertyDefinition":
                  if (ct.parser === "meriyah" && Sn.static && !Sn.computed && !Sn.key) {
                    let ln = "static", Ze = rr(Sn);
                    Object.assign(Sn, { static: false, key: { type: "Identifier", name: ln, range: [Ze, Ze + ln.length] } });
                  }
                  break;
              }
            }), fn;
            function o7(Sn, ln) {
              ct.originalText[hr(ln)] !== ";" && (Sn.range = [rr(Sn), hr(ln)]);
            }
          }
          function it2(fn) {
            switch (fn.type) {
              case "CallExpression":
                fn.type = "OptionalCallExpression", fn.callee = it2(fn.callee);
                break;
              case "MemberExpression":
                fn.type = "OptionalMemberExpression", fn.object = it2(fn.object);
                break;
              case "TSNonNullExpression":
                fn.expression = it2(fn.expression);
                break;
            }
            return fn;
          }
          function ot(fn) {
            return fn.type === "LogicalExpression" && fn.right.type === "LogicalExpression" && fn.operator === fn.right.operator;
          }
          function Mu(fn) {
            return ot(fn) ? Mu({ type: "LogicalExpression", operator: fn.operator, left: Mu({ type: "LogicalExpression", operator: fn.operator, left: fn.left, right: fn.right.left, range: [rr(fn.left), hr(fn.right.left)] }), right: fn.right.right, range: [rr(fn), hr(fn)] }) : fn;
          }
          L0.exports = In;
        } }), x70 = {};
        iU(x70, { default: () => a70 });
        var a70, Eae = L_({ "node-modules-polyfills:fs"() {
          Dt(), a70 = {};
        } }), Fj = ru({ "node-modules-polyfills-commonjs:fs"(I0, L0) {
          Dt();
          var rr = (Eae(), fU(x70));
          if (rr && rr.default) {
            L0.exports = rr.default;
            for (let hr in rr)
              L0.exports[hr] = rr[hr];
          } else
            rr && (L0.exports = rr);
        } }), o70 = {};
        iU(o70, { ALPN_ENABLED: () => Gq, COPYFILE_EXCL: () => jB, COPYFILE_FICLONE: () => MB, COPYFILE_FICLONE_FORCE: () => qB, DH_CHECK_P_NOT_PRIME: () => Lq, DH_CHECK_P_NOT_SAFE_PRIME: () => Dq, DH_NOT_SUITABLE_GENERATOR: () => jq, DH_UNABLE_TO_CHECK_GENERATOR: () => Rq, E2BIG: () => Dj, EACCES: () => Lj, EADDRINUSE: () => Rj, EADDRNOTAVAIL: () => jj, EAFNOSUPPORT: () => Gj, EAGAIN: () => Mj, EALREADY: () => Bj, EBADF: () => qj, EBADMSG: () => Uj, EBUSY: () => Hj, ECANCELED: () => Xj, ECHILD: () => Yj, ECONNABORTED: () => Vj, ECONNREFUSED: () => zj, ECONNRESET: () => Kj, EDEADLK: () => Wj, EDESTADDRREQ: () => Jj, EDOM: () => $j, EDQUOT: () => Zj, EEXIST: () => Qj, EFAULT: () => rG, EFBIG: () => eG, EHOSTUNREACH: () => nG, EIDRM: () => tG, EILSEQ: () => uG, EINPROGRESS: () => iG, EINTR: () => fG, EINVAL: () => xG, EIO: () => aG, EISCONN: () => oG, EISDIR: () => cG, ELOOP: () => sG, EMFILE: () => vG, EMLINK: () => lG, EMSGSIZE: () => bG, EMULTIHOP: () => pG, ENAMETOOLONG: () => mG, ENETDOWN: () => _G, ENETRESET: () => yG, ENETUNREACH: () => dG, ENFILE: () => hG, ENGINE_METHOD_ALL: () => Cq, ENGINE_METHOD_CIPHERS: () => Oq, ENGINE_METHOD_DH: () => gq, ENGINE_METHOD_DIGESTS: () => Iq, ENGINE_METHOD_DSA: () => Sq, ENGINE_METHOD_EC: () => Tq, ENGINE_METHOD_NONE: () => Pq, ENGINE_METHOD_PKEY_ASN1_METHS: () => Nq, ENGINE_METHOD_PKEY_METHS: () => Aq, ENGINE_METHOD_RAND: () => Fq, ENGINE_METHOD_RSA: () => Eq, ENOBUFS: () => kG, ENODATA: () => wG, ENODEV: () => EG, ENOENT: () => SG, ENOEXEC: () => gG, ENOLCK: () => FG, ENOLINK: () => TG, ENOMEM: () => OG, ENOMSG: () => IG, ENOPROTOOPT: () => AG, ENOSPC: () => NG, ENOSR: () => CG, ENOSTR: () => PG, ENOSYS: () => DG, ENOTCONN: () => LG, ENOTDIR: () => RG, ENOTEMPTY: () => jG, ENOTSOCK: () => GG, ENOTSUP: () => MG, ENOTTY: () => BG, ENXIO: () => qG, EOPNOTSUPP: () => UG, EOVERFLOW: () => HG, EPERM: () => XG, EPIPE: () => YG, EPROTO: () => VG, EPROTONOSUPPORT: () => zG, EPROTOTYPE: () => KG, ERANGE: () => WG, EROFS: () => JG, ESPIPE: () => $G, ESRCH: () => ZG, ESTALE: () => QG, ETIME: () => rM, ETIMEDOUT: () => eM, ETXTBSY: () => nM, EWOULDBLOCK: () => tM, EXDEV: () => uM, F_OK: () => CB, OPENSSL_VERSION_NUMBER: () => UB, O_APPEND: () => lB, O_CREAT: () => oB, O_DIRECTORY: () => bB, O_DSYNC: () => _B, O_EXCL: () => cB, O_NOCTTY: () => sB, O_NOFOLLOW: () => pB, O_NONBLOCK: () => dB, O_RDONLY: () => XM, O_RDWR: () => VM, O_SYMLINK: () => yB, O_SYNC: () => mB, O_TRUNC: () => vB, O_WRONLY: () => YM, POINT_CONVERSION_COMPRESSED: () => Qq, POINT_CONVERSION_HYBRID: () => eU, POINT_CONVERSION_UNCOMPRESSED: () => rU, PRIORITY_ABOVE_NORMAL: () => aM, PRIORITY_BELOW_NORMAL: () => fM, PRIORITY_HIGH: () => oM, PRIORITY_HIGHEST: () => cM, PRIORITY_LOW: () => iM, PRIORITY_NORMAL: () => xM, RSA_NO_PADDING: () => qq, RSA_PKCS1_OAEP_PADDING: () => Uq, RSA_PKCS1_PADDING: () => Mq, RSA_PKCS1_PSS_PADDING: () => Xq, RSA_PSS_SALTLEN_AUTO: () => zq, RSA_PSS_SALTLEN_DIGEST: () => Yq, RSA_PSS_SALTLEN_MAX_SIGN: () => Vq, RSA_SSLV23_PADDING: () => Bq, RSA_X931_PADDING: () => Hq, RTLD_GLOBAL: () => Cj, RTLD_LAZY: () => Aj, RTLD_LOCAL: () => Pj, RTLD_NOW: () => Nj, R_OK: () => PB, SIGABRT: () => mM, SIGALRM: () => gM, SIGBUS: () => yM, SIGCHLD: () => TM, SIGCONT: () => OM, SIGFPE: () => dM, SIGHUP: () => sM, SIGILL: () => bM, SIGINFO: () => BM, SIGINT: () => vM, SIGIO: () => MM, SIGIOT: () => _M, SIGKILL: () => hM, SIGPIPE: () => SM, SIGPROF: () => jM, SIGQUIT: () => lM, SIGSEGV: () => wM, SIGSTOP: () => IM, SIGSYS: () => qM, SIGTERM: () => FM, SIGTRAP: () => pM, SIGTSTP: () => AM, SIGTTIN: () => NM, SIGTTOU: () => CM, SIGURG: () => PM, SIGUSR1: () => kM, SIGUSR2: () => EM, SIGVTALRM: () => RM, SIGWINCH: () => GM, SIGXCPU: () => DM, SIGXFSZ: () => LM, SSL_OP_ALL: () => HB, SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION: () => XB, SSL_OP_CIPHER_SERVER_PREFERENCE: () => YB, SSL_OP_CISCO_ANYCONNECT: () => VB, SSL_OP_COOKIE_EXCHANGE: () => zB, SSL_OP_CRYPTOPRO_TLSEXT_BUG: () => KB, SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS: () => WB, SSL_OP_EPHEMERAL_RSA: () => JB, SSL_OP_LEGACY_SERVER_CONNECT: () => $B, SSL_OP_MICROSOFT_BIG_SSLV3_BUFFER: () => ZB, SSL_OP_MICROSOFT_SESS_ID_BUG: () => QB, SSL_OP_MSIE_SSLV2_RSA_PADDING: () => rq, SSL_OP_NETSCAPE_CA_DN_BUG: () => eq, SSL_OP_NETSCAPE_CHALLENGE_BUG: () => nq, SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG: () => tq, SSL_OP_NETSCAPE_REUSE_CIPHER_CHANGE_BUG: () => uq, SSL_OP_NO_COMPRESSION: () => iq, SSL_OP_NO_QUERY_MTU: () => fq, SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION: () => xq, SSL_OP_NO_SSLv2: () => aq, SSL_OP_NO_SSLv3: () => oq, SSL_OP_NO_TICKET: () => cq, SSL_OP_NO_TLSv1: () => sq, SSL_OP_NO_TLSv1_1: () => vq, SSL_OP_NO_TLSv1_2: () => lq, SSL_OP_PKCS1_CHECK_1: () => bq, SSL_OP_PKCS1_CHECK_2: () => pq, SSL_OP_SINGLE_DH_USE: () => mq, SSL_OP_SINGLE_ECDH_USE: () => _q, SSL_OP_SSLEAY_080_CLIENT_DH_BUG: () => yq, SSL_OP_SSLREF2_REUSE_CERT_TYPE_BUG: () => dq, SSL_OP_TLS_BLOCK_PADDING_BUG: () => hq, SSL_OP_TLS_D5_BUG: () => kq, SSL_OP_TLS_ROLLBACK_BUG: () => wq, S_IFBLK: () => iB, S_IFCHR: () => uB, S_IFDIR: () => tB, S_IFIFO: () => fB, S_IFLNK: () => xB, S_IFMT: () => eB, S_IFREG: () => nB, S_IFSOCK: () => aB, S_IRGRP: () => gB, S_IROTH: () => IB, S_IRUSR: () => kB, S_IRWXG: () => SB, S_IRWXO: () => OB, S_IRWXU: () => hB, S_IWGRP: () => FB, S_IWOTH: () => AB, S_IWUSR: () => wB, S_IXGRP: () => TB, S_IXOTH: () => NB, S_IXUSR: () => EB, TLS1_1_VERSION: () => Jq, TLS1_2_VERSION: () => $q, TLS1_3_VERSION: () => Zq, TLS1_VERSION: () => Wq, UV_DIRENT_BLOCK: () => rB, UV_DIRENT_CHAR: () => QM, UV_DIRENT_DIR: () => WM, UV_DIRENT_FIFO: () => $M, UV_DIRENT_FILE: () => KM, UV_DIRENT_LINK: () => JM, UV_DIRENT_SOCKET: () => ZM, UV_DIRENT_UNKNOWN: () => zM, UV_FS_COPYFILE_EXCL: () => RB, UV_FS_COPYFILE_FICLONE: () => GB, UV_FS_COPYFILE_FICLONE_FORCE: () => BB, UV_FS_SYMLINK_DIR: () => UM, UV_FS_SYMLINK_JUNCTION: () => HM, W_OK: () => DB, X_OK: () => LB, default: () => c70, defaultCipherList: () => nU, defaultCoreCipherList: () => Kq });
        var Aj, Nj, Cj, Pj, Dj, Lj, Rj, jj, Gj, Mj, Bj, qj, Uj, Hj, Xj, Yj, Vj, zj, Kj, Wj, Jj, $j, Zj, Qj, rG, eG, nG, tG, uG, iG, fG, xG, aG, oG, cG, sG, vG, lG, bG, pG, mG, _G, yG, dG, hG, kG, wG, EG, SG, gG, FG, TG, OG, IG, AG, NG, CG, PG, DG, LG, RG, jG, GG, MG, BG, qG, UG, HG, XG, YG, VG, zG, KG, WG, JG, $G, ZG, QG, rM, eM, nM, tM, uM, iM, fM, xM, aM, oM, cM, sM, vM, lM, bM, pM, mM, _M, yM, dM, hM, kM, wM, EM, SM, gM, FM, TM, OM, IM, AM, NM, CM, PM, DM, LM, RM, jM, GM, MM, BM, qM, UM, HM, XM, YM, VM, zM, KM, WM, JM, $M, ZM, QM, rB, eB, nB, tB, uB, iB, fB, xB, aB, oB, cB, sB, vB, lB, bB, pB, mB, _B, yB, dB, hB, kB, wB, EB, SB, gB, FB, TB, OB, IB, AB, NB, CB, PB, DB, LB, RB, jB, GB, MB, BB, qB, UB, HB, XB, YB, VB, zB, KB, WB, JB, $B, ZB, QB, rq, eq, nq, tq, uq, iq, fq, xq, aq, oq, cq, sq, vq, lq, bq, pq, mq, _q, yq, dq, hq, kq, wq, Eq, Sq, gq, Fq, Tq, Oq, Iq, Aq, Nq, Cq, Pq, Dq, Lq, Rq, jq, Gq, Mq, Bq, qq, Uq, Hq, Xq, Yq, Vq, zq, Kq, Wq, Jq, $q, Zq, Qq, rU, eU, nU, c70, Sae = L_({ "node-modules-polyfills:constants"() {
          Dt(), Aj = 1, Nj = 2, Cj = 8, Pj = 4, Dj = 7, Lj = 13, Rj = 48, jj = 49, Gj = 47, Mj = 35, Bj = 37, qj = 9, Uj = 94, Hj = 16, Xj = 89, Yj = 10, Vj = 53, zj = 61, Kj = 54, Wj = 11, Jj = 39, $j = 33, Zj = 69, Qj = 17, rG = 14, eG = 27, nG = 65, tG = 90, uG = 92, iG = 36, fG = 4, xG = 22, aG = 5, oG = 56, cG = 21, sG = 62, vG = 24, lG = 31, bG = 40, pG = 95, mG = 63, _G = 50, yG = 52, dG = 51, hG = 23, kG = 55, wG = 96, EG = 19, SG = 2, gG = 8, FG = 77, TG = 97, OG = 12, IG = 91, AG = 42, NG = 28, CG = 98, PG = 99, DG = 78, LG = 57, RG = 20, jG = 66, GG = 38, MG = 45, BG = 25, qG = 6, UG = 102, HG = 84, XG = 1, YG = 32, VG = 100, zG = 43, KG = 41, WG = 34, JG = 30, $G = 29, ZG = 3, QG = 70, rM = 101, eM = 60, nM = 26, tM = 35, uM = 18, iM = 19, fM = 10, xM = 0, aM = -7, oM = -14, cM = -20, sM = 1, vM = 2, lM = 3, bM = 4, pM = 5, mM = 6, _M = 6, yM = 10, dM = 8, hM = 9, kM = 30, wM = 11, EM = 31, SM = 13, gM = 14, FM = 15, TM = 20, OM = 19, IM = 17, AM = 18, NM = 21, CM = 22, PM = 16, DM = 24, LM = 25, RM = 26, jM = 27, GM = 28, MM = 23, BM = 29, qM = 12, UM = 1, HM = 2, XM = 0, YM = 1, VM = 2, zM = 0, KM = 1, WM = 2, JM = 3, $M = 4, ZM = 5, QM = 6, rB = 7, eB = 61440, nB = 32768, tB = 16384, uB = 8192, iB = 24576, fB = 4096, xB = 40960, aB = 49152, oB = 512, cB = 2048, sB = 131072, vB = 1024, lB = 8, bB = 1048576, pB = 256, mB = 128, _B = 4194304, yB = 2097152, dB = 4, hB = 448, kB = 256, wB = 128, EB = 64, SB = 56, gB = 32, FB = 16, TB = 8, OB = 7, IB = 4, AB = 2, NB = 1, CB = 0, PB = 4, DB = 2, LB = 1, RB = 1, jB = 1, GB = 2, MB = 2, BB = 4, qB = 4, UB = 269488175, HB = 2147485780, XB = 262144, YB = 4194304, VB = 32768, zB = 8192, KB = 2147483648, WB = 2048, JB = 0, $B = 4, ZB = 0, QB = 0, rq = 0, eq = 0, nq = 0, tq = 0, uq = 0, iq = 131072, fq = 4096, xq = 65536, aq = 0, oq = 33554432, cq = 16384, sq = 67108864, vq = 268435456, lq = 134217728, bq = 0, pq = 0, mq = 0, _q = 0, yq = 0, dq = 0, hq = 0, kq = 0, wq = 8388608, Eq = 1, Sq = 2, gq = 4, Fq = 8, Tq = 2048, Oq = 64, Iq = 128, Aq = 512, Nq = 1024, Cq = 65535, Pq = 0, Dq = 2, Lq = 1, Rq = 4, jq = 8, Gq = 1, Mq = 1, Bq = 2, qq = 3, Uq = 4, Hq = 5, Xq = 6, Yq = -1, Vq = -2, zq = -2, Kq = "TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:TLS_AES_128_GCM_SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA256:ECDHE-RSA-AES256-SHA384:DHE-RSA-AES256-SHA384:ECDHE-RSA-AES256-SHA256:DHE-RSA-AES256-SHA256:HIGH:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!SRP:!CAMELLIA", Wq = 769, Jq = 770, $q = 771, Zq = 772, Qq = 2, rU = 4, eU = 6, nU = "TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:TLS_AES_128_GCM_SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA256:ECDHE-RSA-AES256-SHA384:DHE-RSA-AES256-SHA384:ECDHE-RSA-AES256-SHA256:DHE-RSA-AES256-SHA256:HIGH:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!SRP:!CAMELLIA", c70 = { RTLD_LAZY: Aj, RTLD_NOW: Nj, RTLD_GLOBAL: Cj, RTLD_LOCAL: Pj, E2BIG: Dj, EACCES: Lj, EADDRINUSE: Rj, EADDRNOTAVAIL: jj, EAFNOSUPPORT: Gj, EAGAIN: Mj, EALREADY: Bj, EBADF: qj, EBADMSG: Uj, EBUSY: Hj, ECANCELED: Xj, ECHILD: Yj, ECONNABORTED: Vj, ECONNREFUSED: zj, ECONNRESET: Kj, EDEADLK: Wj, EDESTADDRREQ: Jj, EDOM: $j, EDQUOT: Zj, EEXIST: Qj, EFAULT: rG, EFBIG: eG, EHOSTUNREACH: nG, EIDRM: tG, EILSEQ: uG, EINPROGRESS: iG, EINTR: fG, EINVAL: xG, EIO: aG, EISCONN: oG, EISDIR: cG, ELOOP: sG, EMFILE: vG, EMLINK: lG, EMSGSIZE: bG, EMULTIHOP: pG, ENAMETOOLONG: mG, ENETDOWN: _G, ENETRESET: yG, ENETUNREACH: dG, ENFILE: hG, ENOBUFS: kG, ENODATA: wG, ENODEV: EG, ENOENT: SG, ENOEXEC: gG, ENOLCK: FG, ENOLINK: TG, ENOMEM: OG, ENOMSG: IG, ENOPROTOOPT: AG, ENOSPC: NG, ENOSR: CG, ENOSTR: PG, ENOSYS: DG, ENOTCONN: LG, ENOTDIR: RG, ENOTEMPTY: jG, ENOTSOCK: GG, ENOTSUP: MG, ENOTTY: BG, ENXIO: qG, EOPNOTSUPP: UG, EOVERFLOW: HG, EPERM: XG, EPIPE: YG, EPROTO: VG, EPROTONOSUPPORT: zG, EPROTOTYPE: KG, ERANGE: WG, EROFS: JG, ESPIPE: $G, ESRCH: ZG, ESTALE: QG, ETIME: rM, ETIMEDOUT: eM, ETXTBSY: nM, EWOULDBLOCK: tM, EXDEV: uM, PRIORITY_LOW: iM, PRIORITY_BELOW_NORMAL: fM, PRIORITY_NORMAL: xM, PRIORITY_ABOVE_NORMAL: aM, PRIORITY_HIGH: oM, PRIORITY_HIGHEST: cM, SIGHUP: sM, SIGINT: vM, SIGQUIT: lM, SIGILL: bM, SIGTRAP: pM, SIGABRT: mM, SIGIOT: _M, SIGBUS: yM, SIGFPE: dM, SIGKILL: hM, SIGUSR1: kM, SIGSEGV: wM, SIGUSR2: EM, SIGPIPE: SM, SIGALRM: gM, SIGTERM: FM, SIGCHLD: TM, SIGCONT: OM, SIGSTOP: IM, SIGTSTP: AM, SIGTTIN: NM, SIGTTOU: CM, SIGURG: PM, SIGXCPU: DM, SIGXFSZ: LM, SIGVTALRM: RM, SIGPROF: jM, SIGWINCH: GM, SIGIO: MM, SIGINFO: BM, SIGSYS: qM, UV_FS_SYMLINK_DIR: UM, UV_FS_SYMLINK_JUNCTION: HM, O_RDONLY: XM, O_WRONLY: YM, O_RDWR: VM, UV_DIRENT_UNKNOWN: zM, UV_DIRENT_FILE: KM, UV_DIRENT_DIR: WM, UV_DIRENT_LINK: JM, UV_DIRENT_FIFO: $M, UV_DIRENT_SOCKET: ZM, UV_DIRENT_CHAR: QM, UV_DIRENT_BLOCK: rB, S_IFMT: eB, S_IFREG: nB, S_IFDIR: tB, S_IFCHR: uB, S_IFBLK: iB, S_IFIFO: fB, S_IFLNK: xB, S_IFSOCK: aB, O_CREAT: oB, O_EXCL: cB, O_NOCTTY: sB, O_TRUNC: vB, O_APPEND: lB, O_DIRECTORY: bB, O_NOFOLLOW: pB, O_SYNC: mB, O_DSYNC: _B, O_SYMLINK: yB, O_NONBLOCK: dB, S_IRWXU: hB, S_IRUSR: kB, S_IWUSR: wB, S_IXUSR: EB, S_IRWXG: SB, S_IRGRP: gB, S_IWGRP: FB, S_IXGRP: TB, S_IRWXO: OB, S_IROTH: IB, S_IWOTH: AB, S_IXOTH: NB, F_OK: CB, R_OK: PB, W_OK: DB, X_OK: LB, UV_FS_COPYFILE_EXCL: RB, COPYFILE_EXCL: jB, UV_FS_COPYFILE_FICLONE: GB, COPYFILE_FICLONE: MB, UV_FS_COPYFILE_FICLONE_FORCE: BB, COPYFILE_FICLONE_FORCE: qB, OPENSSL_VERSION_NUMBER: UB, SSL_OP_ALL: HB, SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION: XB, SSL_OP_CIPHER_SERVER_PREFERENCE: YB, SSL_OP_CISCO_ANYCONNECT: VB, SSL_OP_COOKIE_EXCHANGE: zB, SSL_OP_CRYPTOPRO_TLSEXT_BUG: KB, SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS: WB, SSL_OP_EPHEMERAL_RSA: JB, SSL_OP_LEGACY_SERVER_CONNECT: $B, SSL_OP_MICROSOFT_BIG_SSLV3_BUFFER: ZB, SSL_OP_MICROSOFT_SESS_ID_BUG: QB, SSL_OP_MSIE_SSLV2_RSA_PADDING: rq, SSL_OP_NETSCAPE_CA_DN_BUG: eq, SSL_OP_NETSCAPE_CHALLENGE_BUG: nq, SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG: tq, SSL_OP_NETSCAPE_REUSE_CIPHER_CHANGE_BUG: uq, SSL_OP_NO_COMPRESSION: iq, SSL_OP_NO_QUERY_MTU: fq, SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION: xq, SSL_OP_NO_SSLv2: aq, SSL_OP_NO_SSLv3: oq, SSL_OP_NO_TICKET: cq, SSL_OP_NO_TLSv1: sq, SSL_OP_NO_TLSv1_1: vq, SSL_OP_NO_TLSv1_2: lq, SSL_OP_PKCS1_CHECK_1: bq, SSL_OP_PKCS1_CHECK_2: pq, SSL_OP_SINGLE_DH_USE: mq, SSL_OP_SINGLE_ECDH_USE: _q, SSL_OP_SSLEAY_080_CLIENT_DH_BUG: yq, SSL_OP_SSLREF2_REUSE_CERT_TYPE_BUG: dq, SSL_OP_TLS_BLOCK_PADDING_BUG: hq, SSL_OP_TLS_D5_BUG: kq, SSL_OP_TLS_ROLLBACK_BUG: wq, ENGINE_METHOD_RSA: Eq, ENGINE_METHOD_DSA: Sq, ENGINE_METHOD_DH: gq, ENGINE_METHOD_RAND: Fq, ENGINE_METHOD_EC: Tq, ENGINE_METHOD_CIPHERS: Oq, ENGINE_METHOD_DIGESTS: Iq, ENGINE_METHOD_PKEY_METHS: Aq, ENGINE_METHOD_PKEY_ASN1_METHS: Nq, ENGINE_METHOD_ALL: Cq, ENGINE_METHOD_NONE: Pq, DH_CHECK_P_NOT_SAFE_PRIME: Dq, DH_CHECK_P_NOT_PRIME: Lq, DH_UNABLE_TO_CHECK_GENERATOR: Rq, DH_NOT_SUITABLE_GENERATOR: jq, ALPN_ENABLED: Gq, RSA_PKCS1_PADDING: Mq, RSA_SSLV23_PADDING: Bq, RSA_NO_PADDING: qq, RSA_PKCS1_OAEP_PADDING: Uq, RSA_X931_PADDING: Hq, RSA_PKCS1_PSS_PADDING: Xq, RSA_PSS_SALTLEN_DIGEST: Yq, RSA_PSS_SALTLEN_MAX_SIGN: Vq, RSA_PSS_SALTLEN_AUTO: zq, defaultCoreCipherList: Kq, TLS1_VERSION: Wq, TLS1_1_VERSION: Jq, TLS1_2_VERSION: $q, TLS1_3_VERSION: Zq, POINT_CONVERSION_COMPRESSED: Qq, POINT_CONVERSION_UNCOMPRESSED: rU, POINT_CONVERSION_HYBRID: eU, defaultCipherList: nU };
        } }), gae = ru({ "node-modules-polyfills-commonjs:constants"(I0, L0) {
          Dt();
          var rr = (Sae(), fU(o70));
          if (rr && rr.default) {
            L0.exports = rr.default;
            for (let hr in rr)
              L0.exports[hr] = rr[hr];
          } else
            rr && (L0.exports = rr);
        } }), Fae = ru({ "node_modules/flow-parser/flow_parser.js"(I0) {
          Dt(), function(L0) {
            "use strict";
            var rr = "member_property_expression", hr = 8483, se = 12538, qe = "children", Ce = "predicate_expression", gn = "??", En = "Identifier", Jn = 64311, In = 192, it2 = 11710, ot = 122654, Mu = 110947, fn = 67591, ct = "!", o7 = "directive", Sn = 163, ln = "block", Ze = 126553, Xt = 12735, S7 = 68096, Lt = "params", Ss = 93071, Nn = 122, Jc = 72767, Ni = 181, li = "for_statement", Gt = 128, g7 = "start", ov = 43867, xU = "_method", R_ = 70414, cv = ">", ef = "catch_body", j_ = 120121, aU = "the end of an expression statement (`;`)", G_ = 124907, oU = 1027, v4 = 126558, nf = "jsx_fragment", M_ = 42527, B_ = "decorators", q_ = 82943, U_ = 71039, H_ = 110882, X_ = 67514, cU = 8472, sU = "update", Y_ = 12783, V_ = 12438, z_ = 12352, K_ = 8511, W_ = 42961, F2 = "method", l4 = 120713, tf = 8191, uf = "function_param", J_ = 67871, F7 = "throw", $_ = 11507, ff = "class_extends", Z_ = 43470, xf = "object_key_literal", Q_ = 71903, ry = 65437, af = "jsx_child", ey = 43311, b4 = 119995, ny = 67637, p4 = 68116, ty = 66204, uy = 65470, vU = "<<=", iy = "e", fy = 67391, m4 = 11631, _4 = 69956, sv = "tparams", xy = 66735, ay = 64217, oy = 43697, lU = "Invalid binary/octal ", cy = -43, sy = 43255, y4 = "do", vy = 43301, of = "binding_pattern", ly = 120487, cf = "jsx_attribute_value_literal", d4 = "package", sf = "interface_declaration", by = 72750, py = 119892, bU = "tail", pU = -53, vf = 111, mU = 180, my = 119807, _y = 71959, _U = 8206, yy = 65613, $c = "type", dy = 55215, hy = -42, lf = "export_default_declaration_decl", h4 = 72970, yU = "filtered_out", ky = 70416, dU = 229, bf = "function_this_param", hU = "module", k4 = "try", wy = 70143, Ey = 125183, Sy = 70412, h0 = "@])", pf = "binary", kU = "infinity", w4 = "private", gy = 65500, E4 = "has_unknown_members", mf = "pattern_array_rest_element", wU = "Property", gs = "implements", Fy = 12548, EU = 211, _f = "if_alternate_statement", Ty = 124903, Oy = 43395, vv = "src/parser/type_parser.ml", Iy = 66915, S4 = 126552, Ay = 120712, g4 = 126555, Ny = 120596, c7 = "raw", T7 = 112, yf = "class_declaration", df = "statement", Cy = 126624, Py = 71235, hf = "meta_property", Dy = 44002, Ly = 8467, kf = "class_property_value", Ry = 8318, wf = "optional_call", jy = 43761, Zc = "kind", Ef = "class_identifier", Gy = 69955, My = 66378, By = 120512, qy = 68220, Yt = 110, Uy = 123583, T2 = "declare", Sf = "typeof_member_identifier", gf = "catch_clause", Hy = 11742, Xy = 70831, F4 = 8468, Ff = "for_in_assignment_pattern", SU = -32, Tf = "object_", Yy = 43262, Vy = "mixins", Of = "type_param", gU = "visit_trailing_comment", zy = 71839, O2 = "boolean", If = "call", FU = "expected *", Ky = 43010, Wy = 241, Iu = "expression", I2 = "column", Jy = 43595, $y = 43258, Zy = 191456, Af = "member_type_identifier", A2 = 117, Qy = 43754, T4 = 126544, TU = "Assert_failure", rd = 66517, ed = 42964, Nf = "enum_number_member", OU = "a string", nd = 65855, td = 119993, ud = "opaque", IU = 870530776, id = 67711, fd = 66994, Cf = "enum_symbol_body", AU = 185, NU = 219, O4 = "filter", xd = 43615, I4 = 126560, ad = 19903, t1 = "get", od = 64316, CU = `Fatal error: exception %s
`, A4 = "exported", PU = ">=", Wu = "return", N4 = "members", C4 = 256, cd = 66962, sd = 64279, vd = 67829, DU = "Enum `", LU = "&&=", Pf = "object_property", ld = 67589, Df = "pattern_object_property", Lf = "template_literal_element", bd = 69551, Ci = 127343600, P4 = 70452, Rf = "class_element", pd = "ENOENT", md = 71131, RU = 200, _d = 120137, yd = 94098, D4 = 72349, jU = 1328, jf = "function_identifier", dd = 126543, Gf = "jsx_attribute_name", hd = 43487, kr = "@[<2>{ ", GU = "ENOTEMPTY", kd = 65908, wd = 72191, L4 = 120513, Ed = 92909, MU = "bound", Sd = 162, BU = 172, R4 = 120070, Mf = "enum_number_body", Bf = "update_expression", qf = "spread_element", Uf = "for_in_left_declaration", j4 = 64319, N2 = "%d", gd = 12703, G4 = 11687, qU = "@,))@]", Fd = 42239, Hf = "type_cast", Td = 42508, Xf = "class_implements_interface", Od = 67640, Id = 605857695, UU = "Cygwin", HU = "buffer.ml", Ad = 124908, XU = "handler", Nd = 66207, Cd = 66963, M4 = 11558, YU = "-=", Ln = 113, Pd = 113775, VU = "collect_comments", B4 = 126540, lv = "set", Yf = "assignment_pattern", Au = "right", Vf = "object_key_identifier", q4 = 120133, Dd = "Invalid number ", Ld = 42963, U4 = 12539, Rd = 68023, jd = 43798, ti = 100, zf = "pattern_literal", Kf = "generic_type", zU = "*", Gd = 42783, Md = 42890, Bd = 230, H4 = "else", qd = 70851, Ud = 69289, KU = "the start of a statement", X4 = "properties", Hd = 43696, Xd = 110959, Wf = "declare_function", Y4 = 120597, Jf = "object_indexer_property_type", Yd = 70492, Vd = 2048, C2 = "arguments", Xr = "comments", zd = 43042, Qc = 107, Kd = 110575, WU = 161, Wd = 67431, V4 = "line", P2 = "declaration", eu = "static", $f = "pattern_identifier", Jd = 69958, JU = "the", $d = "Unix.Unix_error", Zd = 43814, rs = "annot", Qd = 65786, rh = 66303, eh = 64967, nh = 64255, th = 8584, z4 = 120655, $U = "Stack_overflow", uh = 43700, Zf = "syntax_opt", ZU = "/static/", Qf = "comprehension", ih = 253, QU = "Not_found", rH = "+=", eH = 235, fh = 68680, xh = 66954, ah = 64324, oh = 72966, nH = 174, tH = -1053382366, ch = "rest", rx = "pattern_array_element", ex = "jsx_attribute_value_expression", K4 = 65595, nx = "pattern_array_e", uH = 243, sh = 43711, vh = "rmdir", W4 = "symbol", lh = 69926, J4 = "*dummy method*", bh = 43741, O7 = "typeParameters", D2 = "const", iH = 1026, fH = 149, ph = 12341, mh = 72847, _h = 66993, xH = 202, Pi = "false", Vt = 106, yh = 120076, dh = 186, Di = 128, hh = 125124, kh = "Fatal error: exception ", $4 = 67593, wh = 69297, Eh = 44031, aH = 234, Sh = 92927, gh = 68095, Ju = 8231, tx = "object_key_computed", ux = "labeled_statement", ix = "function_param_pattern", Z4 = 126590, Fh = 65481, Th = 43442, oH = "collect_comments_opt", fx = "variable_declarator", bv = "_", Oh = "compare: functional value", Ih = 67967, pv = "computed", xx = "object_property_type", yt = "id", Ah = 126562, u1 = 114, cH = "comment_bounds", Nh = 70853, Ch = 69247, ax = "class_private_field", Ph = 42237, Dh = 72329, sH = "Invalid_argument", Lh = 113770, Q4 = 94031, Rh = 120092, ox = "declare_class", jh = 67839, Gh = 72250, vH = "%ni", Mh = 92879, lH = "prototype", Fs = "`.", cx = 8287, r8 = 65344, Bh = "&", I7 = "debugger", sx = "type_identifier_reference", bH = "Internal Error: Found private field in object props", vx = "sequence", lx = "call_type_args", pH = 238, qh = 12348, mH = "++", Uh = 68863, Hh = 72001, Xh = 70084, Yh = "label", mv = -45, bx = "jsx_opening_attribute", Vh = 43583, e8 = "%F", zh = 43784, Kh = 113791, px = "call_arguments", n8 = 126503, Wh = 43743, $u = "0", Jh = 119967, t8 = 126538, mx = "new_", _v = 449540197, $h = 64109, Zh = 68466, Qh = 177983, St = 248, _x = "program", Ye = "@,]@]", rk = 68031, yx = "function_type", dx = "type_", u8 = 8484, ek = 67382, nk = 42537, tk = 226, uk = 66559, ik = 42993, fk = 64274, i8 = 71236, xk = 120069, ak = 72105, ok = 126570, ck = "object", sk = 42959, A7 = "break", hx = "for_of_statement", vk = 43695, f8 = 126551, lk = 66955, x8 = 126520, bk = 66499, L2 = 1024, pk = 67455, mk = 43018, _H = 198, a8 = 126522, kx = "function_declaration", _k = 73064, wx = "await", yk = 92728, dk = 70418, hk = 68119, Ex = "function_rest_param", kk = 42653, o8 = 11703, bi = "left", c8 = 70449, wk = 184, Sx = "declare_type_alias", gx = 16777215, s8 = 70302, yH = "/=", dH = "|=", Ek = 55242, Sk = 126583, gk = 124927, Fk = 124895, Tk = 72959, Ok = 65497, hH = "Invalid legacy octal ", es = "typeof", Ik = "explicit_type", Fx = "statement_list", Ak = 65495, Tx = "class_method", v8 = 8526, l8 = 244, Nk = 67861, b8 = 119994, p8 = "enum", kH = 2147483647, Ck = 69762, wH = 208, R2 = "in", Pk = 11702, m8 = 67638, EH = ", characters ", Dk = 70753, yv = "super", Lk = 92783, Rk = 8304, _8 = 126504, Ox = "import_specifier", jk = 68324, Gk = 101589, Mk = 67646, Ix = "expression_or_spread", Bk = 74879, qk = 43792, y8 = 43260, Uk = 93052, SH = "{", Hk = 65574, Xk = 125258, dv = 224, Ax = "jsx_element_name_member_expression", j2 = "instanceof", Yk = 69599, Vk = 43560, Nx = "function_expression", d8 = 223, zk = 72242, Kk = 11498, Wk = 126467, Jk = 73112, gH = 140, h8 = 70107, $k = 13311, Cx = "jsx_children", k8 = 126548, Zk = 63743, w8 = 43471, Px = "jsx_expression", Qk = 69864, rw = 71998, ew = 72e3, E8 = 126591, S8 = 12592, Dx = "type_params", nw = 126578, g8 = 126537, wr = "{ ", tw = 123627, Lx = "jsx_spread_attribute", De = "@,", uw = 70161, iw = 187, F8 = 126500, Rx = "label_identifier", fw = 42606, jx = "number_literal_type", T8 = 42999, xw = 64310, FH = -594953737, aw = 122623, O8 = "hasUnknownMembers", Gx = "array", TH = "^=", Mx = "enum_string_member", ow = 65536, cw = 65615, ns = "void", sw = 65135, Z0 = ")", OH = 138, vw = 70002, G2 = "let", lw = 70271, bw = "nan", W = "@[%s =@ ", pw = 194559, mw = 110579, Bx = "binding_type_identifier", _w = 42735, IH = 57343, Zu = "/", qx = "for_in_statement_lhs", yw = 43503, dw = 8516, hw = 66938, kw = "ENOTDIR", AH = "TypeParameterInstantiation", ww = 69749, Ew = 65381, Sw = 83526, hv = "number", gw = 12447, NH = 154, I8 = 70286, Fw = 72160, Tw = 43493, CH = 206, Ux = "enum_member_identifier", A8 = 70280, M2 = "function", N8 = 70162, Ow = 255, Iw = 67702, Aw = 66771, Nw = 70312, PH = "|", Cw = 93759, DH = "End_of_file", Pw = 43709, i1 = "new", LH = "Failure", B2 = "local", Dw = 101631, C8 = 8489, P8 = "with", Hx = "enum_declaration", Lw = 218, Rw = 70457, D8 = 8488, Xx = "member", L8 = 64325, jw = 247, Gw = 70448, Mw = 69967, R8 = 126535, Bw = 71934, Yx = "import_named_specifier", qw = 65312, Uw = 126619, Vx = "type_annotation", RH = 56320, Hw = 131071, Xw = 120770, Yw = 67002, zx = "with_", Kx = "statement_fork_point", jH = "finalizer", Vw = 12320, GH = "elements", Wx = "literal", zw = 68607, Kw = 8507, j8 = "each", MH = "Sys_error", Ww = 123535, Jw = 130, Jx = "bigint_literal_type", $w = 64829, G8 = 11727, Zw = 120538, $x = "member_private_name", Zx = "type_alias", BH = "Printexc.handle_uncaught_exception", M8 = 126556, Qx = "tagged_template", ra = "pattern_object_property_literal_key", Qw = 43881, B8 = 72192, rE = 67826, eE = 124910, nE = 66511, ts = "int_of_string", tE = 43249, tr = "None", qH = "FunctionTypeParam", ui = "name", uE = 70285, s7 = 103, iE = 120744, ea = 12288, na = "intersection_type", fE = 11679, q8 = 11559, UH = "callee", xE = 71295, aE = 70018, oE = 11567, cE = 42954, HH = "*-/", Qu = "predicate", ta = "expression_statement", XH = "regexp", sE = 65479, YH = 132, vE = 11389, Bu = "optional", VH = -602162310, z = "@]", lE = 120003, bE = 72249, zH = "Unexpected ", pE = 73008, U8 = "finally", ua = "toplevel_statement_list", KH = "end", mE = 178207, WH = "&=", _E = 70301, JH = "%Li", yE = 72161, dE = 69746, hE = 70460, kE = 12799, H8 = 65535, wE = "loc", EE = 69375, SE = 43518, $H = 205, gE = 65487, ia = "while_", FE = 183983, fa = "typeof_expression", TE = -673950933, OE = 42559, ZH = "||", IE = 124926, AE = 55291, xa = "jsx_element_name_identifier", aa = 8239, X8 = "mixed", QH = 136, NE = -253313196, CE = 11734, Y8 = 67827, PE = 68287, DE = 119976, rX = "**", J = " =", V8 = 888960333, LE = 124902, oa = "tuple_type", eX = 227, RE = 70726, jE = 73111, z8 = 126602, GE = 126529, ca = "object_property_value_type", C0 = "%a", nX = ", ", tX = "<=", ME = 69423, uX = 199, K8 = 11695, BE = 12294, W8 = 11711, qE = 67583, iX = 710, J8 = 126584, UE = 68295, HE = 72703, XE = "prefix", fX = -80, $8 = 69415, YE = 11492, q2 = "class", Z8 = 65575, N7 = "continue", VE = 65663, xX = 2047, Q8 = 68120, zE = 71086, KE = 19967, Li = 782176664, WE = 120779, r3 = 8486, pi = " ", aX = "||=", oX = "Undefined_recursive_module", JE = 66863, cX = "RestElement", e3 = 126634, $E = 66377, ZE = 74751, sa = "jsx_element_name_namespaced", QE = 43334, rS = 66815, C7 = "typeAnnotation", eS = 120126, va = "array_element", n3 = 64285, sX = 189, vX = "**=", Yr = "()", nS = 8543, la = "declare_module", ba = "export_batch_specifier", lX = "%i", bX = ">>>=", tS = 68029, pX = "importKind", P7 = "extends", uS = 64296, t3 = 43259, iS = 71679, fS = 64913, xS = 119969, aS = 94175, oS = 72440, u3 = 65141, pa = "function_", cS = 43071, sS = 42888, vS = 69807, au = "variance", us = 123, ma = "import_default_specifier", mX = ">>>", lS = 43764, mi = "pattern", bS = 71947, pS = 70655, kv = "consequent", _X = 4096, mS = 183, _S = 68447, yS = 65473, is = 255, dS = 73648, _a = "call_type_arg", ya = 8238, hS = 68899, kS = 93026, Ve = "@[<2>[", wS = 110588, da = "comment", yX = 191, ha = "switch_case", dX = 175, ES = 71942, ka = "do_while", wv = "constructor", SS = 43587, gS = 43586, ku = "yield", FS = 67462, hX = "fd ", TS = -61, OS = "target", i3 = 72272, U2 = "var", kX = "impltype", f3 = 70108, H2 = "0o", IS = 119972, AS = 92991, x3 = 70441, a3 = 8450, NS = 120074, CS = 66717, wa = "interface_type", o3 = 43880, Cn = "%B", PS = 111355, Ev = 5760, DS = 11630, c3 = 126499, LS = "of", wX = ">>", EX = "Popping lex mode from empty stack", s3 = 120629, fs2 = 108, RS = 43002, SX = "%=", v3 = 126539, jS = 126502, Ea = "template_literal", GS = "src/parser/statement_parser.ml", MS = ": Not a directory", gX = "b", BS = 67461, qS = 11519, FX = "src/parser/flow_lexer.ml", TX = "Out_of_memory", US = 120570, Sa = 12287, HS = 126534, XS = "index out of bounds", YS = 73029, l3 = "_bigarr02", b3 = 126571, OX = "))", ga = "for_statement_init", IX = "supertype", Fa = "class_property", p3 = "}", f1 = "this", Ta = "declare_module_exports", AX = "@", Oa = "union_type", Ri = 65535, Ia = "variance_opt", VS = 94032, NX = 222, zS = 42124, Aa = "this_expression", Na = "jsx_element", CX = "typeArguments", KS = 65019, WS = 125251, JS = 64111, $S = 8471, Ca = "typeof_qualified_identifier", ZS = 70497, PX = "EnumDefaultedMember", Pa = 8202, QS = 66927, D7 = "switch", rg = 69634, Da = "unary_expression", eg = 71215, DX = 126, ng = 67679, tg = 65597, LX = 207, ug = 120686, m3 = 72163, ig = 67001, fg = 42962, xg = 64262, X2 = 124, La = 65279, ag = 126495, RX = 169, og = 71944, jX = -10, _3 = "alternate", cg = 92975, sg = 65489, Y2 = 252, vg = 67807, lg = 43187, bg = 68850, y3 = "export", pg = 66383, GX = "===", Ra = ".", ja = "type_args", MX = 147, mg = 92159, BX = 240, Ga = "jsx_element_name", _g = 72283, yg = 171, x1 = 116, dg = 110587, d3 = 70279, hg = 75075, kg = 65338, Ma = "function_params", wg = 126627, qX = 213, h3 = 73065, Eg = 71352, k3 = 119970, Sg = 70005, gg = 12295, w3 = 120771, Fg = 71494, Tg = 11557, Og = 42191, UX = "flags", Ig = 68437, Ag = 70730, Ba = "optional_indexed_access", qa = "pattern_object_p", Ng = 42785, Ua = "nullable_type", qn = "value", Cg = 12343, Pg = 68415, Dg = 11694, HX = 221, Lg = 11726, Ha = "syntax", Rg = 119964, XX = "&&", jg = 68497, Gg = 73097, xs = "null", E3 = 126523, Mg = 120084, Bg = 126601, qg = 8454, Ug = "expressions", Hg = 72144, V2 = '"', Zr = "(@[", YX = 1022, VX = 231, Xg = 170, S3 = 12448, Yg = 68786, g3 = "<", zX = 931, KX = "(", WX = 196, JX = 2048, F3 = "an identifier", T3 = 69959, Vg = 68799, $X = "leadingComments", zg = 72969, Kg = 182, Wg = 100351, Xa = "enum_defaulted_member", Jg = 69839, $g = 94026, Zg = 209, ZX = ">>=", Qg = 131, O3 = 12336, v7 = "empty", QX = 331416730, rY = 204, rF = 70479, eF = 69487, nF = 101640, tF = 43123, eY = "([^/]+)", I3 = 8319, nY = 165, Ya = "object_type_property_setter", tY = 909, uF = 15, iF = 12591, br = 125, fF = 92735, uY = "cases", xF = 183969, a1 = "bigint", iY = "Division_by_zero", aF = 67071, oF = 12329, A3 = 120004, cF = 69414, N3 = "if", sF = 126519, vF = "immediately within another function.", lF = 55238, bF = 126498, fY = "qualification", pF = 66256, Er = "@ }@]", z2 = 118, C3 = 11565, P3 = 120122, Va = "pattern_object_rest_property", mF = 74862, D3 = "'", _F = -26065557, yF = 124911, Sv = 119, L7 = 104, za = "assignment", dF = 8457, K2 = "from", hF = 64321, kF = 113817, wF = 65629, EF = 42655, ji = 102, SF = 43137, gF = 11502, o0 = ";@ ", R7 = 101, Ka = "pattern_array_element_pattern", $n = "body", Wa = "jsx_member_expression", FF = 65547, Ja = "jsx_attribute_value", $a = "jsx_namespaced_name", L3 = 72967, TF = 126550, gv = 254, OF = 43807, IF = 43738, R3 = 126589, j3 = 8455, G3 = 126628, AF = 11670, xY = "*=", M3 = 120134, Za = "conditional", aY = " : flags Open_text and Open_binary are not compatible", B3 = 119965, NF = 69890, CF = 72817, PF = 164, DF = 43822, q3 = 69744, oY = "\\\\", LF = 43638, RF = 93047, jF = "AssignmentPattern", U3 = 64322, GF = 123190, cY = 188, Qa = "object_spread_property_type", MF = 70783, BF = 113663, sY = 160, H3 = 42622, X3 = 43823, Gi = "init", Fv = 109, qF = 66503, Y3 = "proto", UF = 74649, ro = "optional_member", HF = 40981, XF = 120654, v = "@ ", eo = "enum_boolean_body", no = "export_named_specifier", to = "declare_interface", YF = 70451, uo = "pattern_object_property_computed_key", V3 = -97, z3 = 120539, K3 = 64317, VF = 12543, io = "export_named_declaration_specifier", zF = 43359, W3 = 126530, J3 = 72713, KF = 113800, vY = 195, WF = 72367, JF = 72103, $F = 70278, fo = "if_consequent_statement", W2 = -85, $3 = 126496, xo = "try_catch", ao = "computed_key", oo = "class_", ZF = 173823, co = "pattern_object_property_identifier_key", lY = "f", so = "arrow_function", Z3 = 8485, QF = 126546, vo = "enum_boolean_member", rT = 94177, J2 = "delete", eT = 232, bY = "blocks", lo = "pattern_array_rest_element_pattern", nT = 78894, Q3 = 66512, tT = 94111, Tv = "string", Ts = "test", uT = 69572, iT = 66463, fT = 66335, xT = 72348, aT = 73061, o1 = ":", bo = "enum_body", oT = 110590, po = "function_this_param_type", cT = 215, sT = 77823, pY = "minus", mY = 201, vT = 119980, mo = "private_name", _o = "object_key", yo = "function_param_type", _Y = "<<", lT = 11718, c1 = "as", yY = "delegate", Mi = "true", bT = 67413, r6 = 70854, pT = 73439, mT = 43776, _T = 71723, yT = 11505, dT = 214, hT = 120628, kT = 43513, ho = "jsx_attribute_name_namespaced", e6 = 120127, n6 = "Map.bal", t6 = "any", dY = "@[", hY = "camlinternalMod.ml", u6 = 126559, qu = "import", i6 = 70404, ko = "jsx_spread_child", wT = 233, ET = 67897, ST = 119974, Uu = 8233, gT = 68405, f6 = 239, kY = "attributes", wY = 173, wo = "object_internal_slot_property_type", FT = 71351, TT = 242, OT = 67643, x6 = "shorthand", Eo = "for_in_statement", IT = 126463, AT = 71338, NT = 69445, CT = 65370, PT = 73055, DT = 167, LT = 64911, So = "pattern_object_property_pattern", EY = 212, SY = 197, a6 = 126579, RT = 64286, jT = "explicitType", GT = 67669, MT = 43866, gY = "Sys_blocked_io", o6 = "catch", BT = 123197, qT = 64466, UT = 65140, HT = 73030, XT = 69404, c6 = "protected", FY = 8204, YT = 67504, VT = 193, $2 = 246, zT = 43713, s6 = 120571, go = "array_type", TY = "%u", Fo = "export_default_declaration", To = "class_expression", OY = "quasi", zt = "%S", KT = 8525, v6 = 126515, WT = 120485, l6 = 43519, b6 = 120745, p6 = 94178, JT = 126588, Kn = 127, $T = 66855, IY = "@{", AY = "visit_leading_comment", ZT = 67742, NY = " : flags Open_rdonly and Open_wronly are not compatible", QT = 120144, m6 = "returnType", s1 = -744106340, v1 = 240, Oo = "-", _6 = 8469, Os = "async", y6 = 126521, rO = 72095, d6 = 216, CY = " : file already exists", eO = 178205, nO = 8449, h6 = 94179, tO = 42774, k6 = "case", uO = 66965, iO = 66431, PY = 190, Io = "declare_export_declaration", Z2 = "targs", Ao = "type_identifier", fO = 64284, xO = 43013, w6 = 43815, No = "function_body_any", aO = 66966, E6 = 120687, oO = 66939, cO = 66978, DY = 168, S6 = "public", sO = 68115, vO = 43712, g6 = 65598, F6 = 126547, lO = 110591, Co = "indexed_access", LY = 12520, r7 = "interface", RY = `(Program not linked with -g, cannot print stack backtrace)
`, l1 = -46, Po = "string_literal_type", Do = "import_namespace_specifier", bO = 120132, T6 = 11735, pO = 67505, O6 = 119893, I6 = "bool", Q2 = 1e3, _i = "default", mO = 236, C = "", _O = "exportKind", jY = "trailingComments", A6 = "^", yO = 71983, dO = 8348, hO = 66977, kO = 65594, Lo = "logical", Ro = "jsx_member_expression_identifier", N6 = 210, GY = "cooked", jo = "for_of_left_declaration", Ov = 63, wO = 72202, l7 = "argument", EO = 12442, SO = 43645, C6 = 120085, gO = 42539, P6 = 126468, MY = 166, BY = "Match_failure", FO = 68191, wu = "src/parser/flow_ast.ml", D6 = 11647, Go = "declare_variable", as = "+", TO = 71127, L6 = 120145, Mo = "declare_export_declaration_decl", R6 = 64318, qY = 179, Bo = "class_implements", UY = "!=", HY = "inexact", XY = "%li", YY = 237, rl = "a", j6 = 73062, OO = 178, qo = 65278, Uo = "function_rest_param_type", IO = 77711, AO = 70066, NO = 43714, VY = -696510241, G6 = 70480, CO = 69748, PO = 113788, DO = 94207, zY = `\r
`, Ho = "class_body", LO = 126651, RO = 68735, jO = 43273, M6 = 119996, B6 = 67644, KY = 224, Xo = "catch_clause_pattern", Yo = "boolean_literal_type", q6 = 126554, U6 = 126557, GO = 113807, H6 = 126536, WY = "%", Iv = "property", MO = 71956, JY = "#", BO = 123213, el = "meta", Vo = "for_of_assignment_pattern", zo = "if_statement", qO = 66421, UO = 8505, HO = 225, nl = 250, XO = 100343, X6 = "Literal", YO = 42887, Av = 115, $Y = ";", VO = 1255, zO = "=", KO = 126566, WO = 93823, Ko = "opaque_type", ZY = "!==", Wo = "jsx_attribute", Jo = "type_annotation_hint", Bi = 32768, JO = 73727, QY = "range", rV = 245, $O = "jsError", Y6 = 70006, ZO = 43492, V6 = "@]}", ur = "(Some ", QO = 8477, eV = 129, rI = 71487, z6 = 126564, nV = `
`, eI = 126514, nI = 70080, $o = "generic_identifier_type", tI = 66811, Zo = "typeof_identifier", tV = "~", uI = 65007, Qo = "pattern_object_rest_property_pattern", iI = 194, uV = 1039100673, fI = 66461, xI = 70319, K6 = 11719, aI = 72271, Wt = -48, rc = "enum_string_body", oI = 70461, ec = "export_named_declaration", cI = 110930, sI = 92862, iV = "??=", vI = 70440, W6 = "while", ou = "camlinternalFormat.ml", lI = 43782, fV = 203, bI = 173791, pI = 11263, mI = 1114111, _I = 42969, J6 = 70750, nc = "jsx_identifier", yI = 70105, dI = 43014, hI = 11564, tc = "typeof_type", xV = "EEXIST", kI = 64847, wI = 71167, EI = 42511, SI = 72712, gI = 92995, FI = 43704, tl = 121, uc = "object_call_property_type", TI = 64433, ul = "operator", $6 = 68296, ic = "class_decorator", fc = 120, xc = "for_of_statement_lhs", OI = 11623, II = 67004, AI = 71999, NI = 70708, CI = 512, PI = 110927, DI = 71423, aV = 32752, LI = 93951, RI = 12292, ac = "object_type", Z6 = "types", jI = 110580, oV = 177, GI = 126633, MI = 12686, oc = 8286, cV = 144, BI = 73647, sV = 228, Q6 = 70855, b1 = "0x", qI = 70366, UI = `
`, cc = "variable_declaration", HI = 65276, rp = 119981, XI = 71945, YI = 43887, j7 = 105, VI = 8335, zI = 123565, KI = 69505, WI = 70187, sc = "jsx_attribute_name_identifier", vc = "source", lc = "pattern_object_property_key", ep = 65548, JI = 66175, $I = 92766, bc = "pattern_assignment_pattern", pc = "object_type_property_getter", np = 8305, G7 = "generator", tp = "for", vV = "PropertyDefinition", lV = "--", cu = -36, ZI = "mkdir", QI = 68223, mc = "generic_qualified_identifier_type", rA = 11686, _c = "jsx_closing_element", eA = 43790, up = ": No such file or directory", nA = 69687, tA = 66348, ip = 72162, uA = 43388, iA = 72768, fA = 68351, d = "<2>", fp = 64297, xA = 125259, aA = 220, zr = ",@ ", bV = "win32", xp = 70281, yc = "member_property_identifier", oA = 68149, cA = 68111, sA = 71450, vA = 43009, dc = "member_property", lA = 73458, yi = "identifier", bA = 67423, pA = 66775, mA = 110951, pV = "Internal Error: Found object private prop", hc = "super_expression", kc = "jsx_opening_element", _A = 177976, wc = "variable_declarator_pattern", Ec = "pattern_expression", Sc = "jsx_member_expression_object", yA = 68252, dA = 77808, Nv = -835925911, gc = "import_declaration", hA = 55203, mV = "Pervasives.do_at_exit", _V = "utf8", ii = "key", kA = 43702, Fc = "spread_property", ap = 126563, wA = 863850040, EA = 70106, op = 67592, Tc = "function_expression_or_method", SA = 71958, Oc = "for_init_declaration", gA = 71955, cp = 123214, FA = 68479, yV = "==", TA = 43019, OA = 123180, sp = 217, Cv = "specifiers", Ic = "function_body", IA = 69622, vp = 8487, AA = 43641, dV = "Unexpected token `", hV = "v", NA = 123135, CA = 69295, lp = 120093, PA = 8521, bp = 43642, kV = 176;
            function v70(t4, n, e, i, x) {
              if (i <= n)
                for (var c = 1; c <= x; c++)
                  e[i + c] = t4[n + c];
              else
                for (var c = x; c >= 1; c--)
                  e[i + c] = t4[n + c];
              return 0;
            }
            function l70(t4) {
              for (var n = [0]; t4 !== 0; ) {
                for (var e = t4[1], i = 1; i < e.length; i++)
                  n.push(e[i]);
                t4 = t4[2];
              }
              return n;
            }
            function b70(t4, n, e) {
              var i = new Array(e + 1);
              i[0] = 0;
              for (var x = 1, c = n + 1; x <= e; x++, c++)
                i[x] = t4[c];
              return i;
            }
            function DA(t4, n, e) {
              var i = String.fromCharCode;
              if (n == 0 && e <= _X && e == t4.length)
                return i.apply(null, t4);
              for (var x = C; 0 < e; n += L2, e -= L2)
                x += i.apply(null, t4.slice(n, n + Math.min(e, L2)));
              return x;
            }
            function pp(t4) {
              if (L0.Uint8Array)
                var n = new L0.Uint8Array(t4.l);
              else
                var n = new Array(t4.l);
              for (var e = t4.c, i = e.length, x = 0; x < i; x++)
                n[x] = e.charCodeAt(x);
              for (i = t4.l; x < i; x++)
                n[x] = 0;
              return t4.c = n, t4.t = 4, n;
            }
            function Is(t4, n, e, i, x) {
              if (x == 0)
                return 0;
              if (i == 0 && (x >= e.l || e.t == 2 && x >= e.c.length))
                e.c = t4.t == 4 ? DA(t4.c, n, x) : n == 0 && t4.c.length == x ? t4.c : t4.c.substr(n, x), e.t = e.c.length == e.l ? 0 : 2;
              else if (e.t == 2 && i == e.c.length)
                e.c += t4.t == 4 ? DA(t4.c, n, x) : n == 0 && t4.c.length == x ? t4.c : t4.c.substr(n, x), e.t = e.c.length == e.l ? 0 : 2;
              else {
                e.t != 4 && pp(e);
                var c = t4.c, s = e.c;
                if (t4.t == 4)
                  if (i <= n)
                    for (var p = 0; p < x; p++)
                      s[i + p] = c[n + p];
                  else
                    for (var p = x - 1; p >= 0; p--)
                      s[i + p] = c[n + p];
                else {
                  for (var y = Math.min(x, c.length - n), p = 0; p < y; p++)
                    s[i + p] = c.charCodeAt(n + p);
                  for (; p < x; p++)
                    s[i + p] = 0;
                }
              }
              return 0;
            }
            function Lae(t4) {
              return t4;
            }
            function As(t4, n, e, i, x) {
              return Is(t4, n, e, i, x), 0;
            }
            function p70(t4, n) {
              throw [0, t4, n];
            }
            function Pv(t4, n) {
              if (t4 == 0)
                return C;
              if (n.repeat)
                return n.repeat(t4);
              for (var e = C, i = 0; ; ) {
                if (t4 & 1 && (e += n), t4 >>= 1, t4 == 0)
                  return e;
                n += n, i++, i == 9 && n.slice(0, 1);
              }
            }
            function Dv(t4) {
              t4.t == 2 ? t4.c += Pv(t4.l - t4.c.length, "\0") : t4.c = DA(t4.c, 0, t4.c.length), t4.t = 0;
            }
            function wV(t4) {
              if (t4.length < 24) {
                for (var n = 0; n < t4.length; n++)
                  if (t4.charCodeAt(n) > Kn)
                    return false;
                return true;
              } else
                return !/[^\x00-\x7f]/.test(t4);
            }
            function LA(t4) {
              for (var n = C, e = C, i, x, c, s, p = 0, y = t4.length; p < y; p++) {
                if (x = t4.charCodeAt(p), x < Di) {
                  for (var T = p + 1; T < y && (x = t4.charCodeAt(T)) < Di; T++)
                    ;
                  if (T - p > CI ? (e.substr(0, 1), n += e, e = C, n += t4.slice(p, T)) : e += t4.slice(p, T), T == y)
                    break;
                  p = T;
                }
                s = 1, ++p < y && ((c = t4.charCodeAt(p)) & -64) == Gt && (i = c + (x << 6), x < KY ? (s = i - 12416, s < Di && (s = 1)) : (s = 2, ++p < y && ((c = t4.charCodeAt(p)) & -64) == Gt && (i = c + (i << 6), x < BX ? (s = i - 925824, (s < JX || s >= 55295 && s < 57344) && (s = 2)) : (s = 3, ++p < y && ((c = t4.charCodeAt(p)) & -64) == Gt && x < 245 && (s = c - 63447168 + (i << 6), (s < 65536 || s > 1114111) && (s = 3)))))), s < 4 ? (p -= s, e += "\uFFFD") : s > Ri ? e += String.fromCharCode(55232 + (s >> 10), RH + (s & 1023)) : e += String.fromCharCode(s), e.length > L2 && (e.substr(0, 1), n += e, e = C);
              }
              return n + e;
            }
            function Ac(t4, n, e) {
              this.t = t4, this.c = n, this.l = e;
            }
            Ac.prototype.toString = function() {
              switch (this.t) {
                case 9:
                  return this.c;
                default:
                  Dv(this);
                case 0:
                  if (wV(this.c))
                    return this.t = 9, this.c;
                  this.t = 8;
                case 8:
                  return this.c;
              }
            }, Ac.prototype.toUtf16 = function() {
              var t4 = this.toString();
              return this.t == 9 ? t4 : LA(t4);
            }, Ac.prototype.slice = function() {
              var t4 = this.t == 4 ? this.c.slice() : this.c;
              return new Ac(this.t, t4, this.l);
            };
            function EV(t4) {
              return new Ac(0, t4, t4.length);
            }
            function r(t4) {
              return EV(t4);
            }
            function RA(t4, n) {
              p70(t4, r(n));
            }
            var Kt = [0];
            function su(t4) {
              RA(Kt.Invalid_argument, t4);
            }
            function SV() {
              su(XS);
            }
            function Zn(t4, n, e) {
              if (e &= is, t4.t != 4) {
                if (n == t4.c.length)
                  return t4.c += String.fromCharCode(e), n + 1 == t4.l && (t4.t = 0), 0;
                pp(t4);
              }
              return t4.c[n] = e, 0;
            }
            function p1(t4, n, e) {
              return n >>> 0 >= t4.l && SV(), Zn(t4, n, e);
            }
            function Hu(t4, n) {
              switch (t4.t & 6) {
                default:
                  if (n >= t4.c.length)
                    return 0;
                case 0:
                  return t4.c.charCodeAt(n);
                case 4:
                  return t4.c[n];
              }
            }
            function os(t4, n) {
              if (t4.fun)
                return os(t4.fun, n);
              if (typeof t4 != "function")
                return t4;
              var e = t4.length | 0;
              if (e === 0)
                return t4.apply(null, n);
              var i = n.length | 0, x = e - i | 0;
              return x == 0 ? t4.apply(null, n) : x < 0 ? os(t4.apply(null, n.slice(0, e)), n.slice(e)) : function() {
                for (var c = arguments.length == 0 ? 1 : arguments.length, s = new Array(n.length + c), p = 0; p < n.length; p++)
                  s[p] = n[p];
                for (var p = 0; p < arguments.length; p++)
                  s[n.length + p] = arguments[p];
                return os(t4, s);
              };
            }
            function il() {
              su(XS);
            }
            function nu(t4, n) {
              return n >>> 0 >= t4.length - 1 && il(), t4;
            }
            function m70(t4) {
              return isFinite(t4) ? Math.abs(t4) >= 22250738585072014e-324 ? 0 : t4 != 0 ? 1 : 2 : isNaN(t4) ? 4 : 3;
            }
            function Nc(t4) {
              return t4.t & 6 && Dv(t4), t4.c;
            }
            var _70 = Math.log2 && Math.log2(11235582092889474e291) == 1020;
            function y70(t4) {
              if (_70)
                return Math.floor(Math.log2(t4));
              var n = 0;
              if (t4 == 0)
                return -1 / 0;
              if (t4 >= 1)
                for (; t4 >= 2; )
                  t4 /= 2, n++;
              else
                for (; t4 < 1; )
                  t4 *= 2, n--;
              return n;
            }
            function jA(t4) {
              var n = new L0.Float32Array(1);
              n[0] = t4;
              var e = new L0.Int32Array(n.buffer);
              return e[0] | 0;
            }
            var gV = Math.pow(2, -24);
            function FV(t4) {
              throw t4;
            }
            function TV() {
              FV(Kt.Division_by_zero);
            }
            function cn(t4, n, e) {
              this.lo = t4 & gx, this.mi = n & gx, this.hi = e & Ri;
            }
            cn.prototype.caml_custom = "_j", cn.prototype.copy = function() {
              return new cn(this.lo, this.mi, this.hi);
            }, cn.prototype.ucompare = function(t4) {
              return this.hi > t4.hi ? 1 : this.hi < t4.hi ? -1 : this.mi > t4.mi ? 1 : this.mi < t4.mi ? -1 : this.lo > t4.lo ? 1 : this.lo < t4.lo ? -1 : 0;
            }, cn.prototype.compare = function(t4) {
              var n = this.hi << 16, e = t4.hi << 16;
              return n > e ? 1 : n < e ? -1 : this.mi > t4.mi ? 1 : this.mi < t4.mi ? -1 : this.lo > t4.lo ? 1 : this.lo < t4.lo ? -1 : 0;
            }, cn.prototype.neg = function() {
              var t4 = -this.lo, n = -this.mi + (t4 >> 24), e = -this.hi + (n >> 24);
              return new cn(t4, n, e);
            }, cn.prototype.add = function(t4) {
              var n = this.lo + t4.lo, e = this.mi + t4.mi + (n >> 24), i = this.hi + t4.hi + (e >> 24);
              return new cn(n, e, i);
            }, cn.prototype.sub = function(t4) {
              var n = this.lo - t4.lo, e = this.mi - t4.mi + (n >> 24), i = this.hi - t4.hi + (e >> 24);
              return new cn(n, e, i);
            }, cn.prototype.mul = function(t4) {
              var n = this.lo * t4.lo, e = (n * gV | 0) + this.mi * t4.lo + this.lo * t4.mi, i = (e * gV | 0) + this.hi * t4.lo + this.mi * t4.mi + this.lo * t4.hi;
              return new cn(n, e, i);
            }, cn.prototype.isZero = function() {
              return (this.lo | this.mi | this.hi) == 0;
            }, cn.prototype.isNeg = function() {
              return this.hi << 16 < 0;
            }, cn.prototype.and = function(t4) {
              return new cn(this.lo & t4.lo, this.mi & t4.mi, this.hi & t4.hi);
            }, cn.prototype.or = function(t4) {
              return new cn(this.lo | t4.lo, this.mi | t4.mi, this.hi | t4.hi);
            }, cn.prototype.xor = function(t4) {
              return new cn(this.lo ^ t4.lo, this.mi ^ t4.mi, this.hi ^ t4.hi);
            }, cn.prototype.shift_left = function(t4) {
              return t4 = t4 & 63, t4 == 0 ? this : t4 < 24 ? new cn(this.lo << t4, this.mi << t4 | this.lo >> 24 - t4, this.hi << t4 | this.mi >> 24 - t4) : t4 < 48 ? new cn(0, this.lo << t4 - 24, this.mi << t4 - 24 | this.lo >> 48 - t4) : new cn(0, 0, this.lo << t4 - 48);
            }, cn.prototype.shift_right_unsigned = function(t4) {
              return t4 = t4 & 63, t4 == 0 ? this : t4 < 24 ? new cn(this.lo >> t4 | this.mi << 24 - t4, this.mi >> t4 | this.hi << 24 - t4, this.hi >> t4) : t4 < 48 ? new cn(this.mi >> t4 - 24 | this.hi << 48 - t4, this.hi >> t4 - 24, 0) : new cn(this.hi >> t4 - 48, 0, 0);
            }, cn.prototype.shift_right = function(t4) {
              if (t4 = t4 & 63, t4 == 0)
                return this;
              var n = this.hi << 16 >> 16;
              if (t4 < 24)
                return new cn(this.lo >> t4 | this.mi << 24 - t4, this.mi >> t4 | n << 24 - t4, this.hi << 16 >> t4 >>> 16);
              var e = this.hi << 16 >> 31;
              return t4 < 48 ? new cn(this.mi >> t4 - 24 | this.hi << 48 - t4, this.hi << 16 >> t4 - 24 >> 16, e & Ri) : new cn(this.hi << 16 >> t4 - 32, e, e);
            }, cn.prototype.lsl1 = function() {
              this.hi = this.hi << 1 | this.mi >> 23, this.mi = (this.mi << 1 | this.lo >> 23) & gx, this.lo = this.lo << 1 & gx;
            }, cn.prototype.lsr1 = function() {
              this.lo = (this.lo >>> 1 | this.mi << 23) & gx, this.mi = (this.mi >>> 1 | this.hi << 23) & gx, this.hi = this.hi >>> 1;
            }, cn.prototype.udivmod = function(t4) {
              for (var n = 0, e = this.copy(), i = t4.copy(), x = new cn(0, 0, 0); e.ucompare(i) > 0; )
                n++, i.lsl1();
              for (; n >= 0; )
                n--, x.lsl1(), e.ucompare(i) >= 0 && (x.lo++, e = e.sub(i)), i.lsr1();
              return { quotient: x, modulus: e };
            }, cn.prototype.div = function(t4) {
              var n = this;
              t4.isZero() && TV();
              var e = n.hi ^ t4.hi;
              n.hi & Bi && (n = n.neg()), t4.hi & Bi && (t4 = t4.neg());
              var i = n.udivmod(t4).quotient;
              return e & Bi && (i = i.neg()), i;
            }, cn.prototype.mod = function(t4) {
              var n = this;
              t4.isZero() && TV();
              var e = n.hi;
              n.hi & Bi && (n = n.neg()), t4.hi & Bi && (t4 = t4.neg());
              var i = n.udivmod(t4).modulus;
              return e & Bi && (i = i.neg()), i;
            }, cn.prototype.toInt = function() {
              return this.lo | this.mi << 24;
            }, cn.prototype.toFloat = function() {
              return (this.hi << 16) * Math.pow(2, 32) + this.mi * Math.pow(2, 24) + this.lo;
            }, cn.prototype.toArray = function() {
              return [this.hi >> 8, this.hi & is, this.mi >> 16, this.mi >> 8 & is, this.mi & is, this.lo >> 16, this.lo >> 8 & is, this.lo & is];
            }, cn.prototype.lo32 = function() {
              return this.lo | (this.mi & is) << 24;
            }, cn.prototype.hi32 = function() {
              return this.mi >>> 8 & Ri | this.hi << 16;
            };
            function mp(t4, n, e) {
              return new cn(t4, n, e);
            }
            function _p(t4) {
              if (!isFinite(t4))
                return isNaN(t4) ? mp(1, 0, aV) : t4 > 0 ? mp(0, 0, aV) : mp(0, 0, 65520);
              var n = t4 == 0 && 1 / t4 == -1 / 0 ? Bi : t4 >= 0 ? 0 : Bi;
              n && (t4 = -t4);
              var e = y70(t4) + 1023;
              e <= 0 ? (e = 0, t4 /= Math.pow(2, -iH)) : (t4 /= Math.pow(2, e - oU), t4 < 16 && (t4 *= 2, e -= 1), e == 0 && (t4 /= 2));
              var i = Math.pow(2, 24), x = t4 | 0;
              t4 = (t4 - x) * i;
              var c = t4 | 0;
              t4 = (t4 - c) * i;
              var s = t4 | 0;
              return x = x & uF | n | e << 4, mp(s, c, x);
            }
            function fl(t4) {
              return t4.toArray();
            }
            function OV(t4, n, e) {
              if (t4.write(32, n.dims.length), t4.write(32, n.kind | n.layout << 8), n.caml_custom == l3)
                for (var i = 0; i < n.dims.length; i++)
                  n.dims[i] < Ri ? t4.write(16, n.dims[i]) : (t4.write(16, Ri), t4.write(32, 0), t4.write(32, n.dims[i]));
              else
                for (var i = 0; i < n.dims.length; i++)
                  t4.write(32, n.dims[i]);
              switch (n.kind) {
                case 2:
                case 3:
                case 12:
                  for (var i = 0; i < n.data.length; i++)
                    t4.write(8, n.data[i]);
                  break;
                case 4:
                case 5:
                  for (var i = 0; i < n.data.length; i++)
                    t4.write(16, n.data[i]);
                  break;
                case 6:
                  for (var i = 0; i < n.data.length; i++)
                    t4.write(32, n.data[i]);
                  break;
                case 8:
                case 9:
                  t4.write(8, 0);
                  for (var i = 0; i < n.data.length; i++)
                    t4.write(32, n.data[i]);
                  break;
                case 7:
                  for (var i = 0; i < n.data.length / 2; i++)
                    for (var x = fl(n.get(i)), c = 0; c < 8; c++)
                      t4.write(8, x[c]);
                  break;
                case 1:
                  for (var i = 0; i < n.data.length; i++)
                    for (var x = fl(_p(n.get(i))), c = 0; c < 8; c++)
                      t4.write(8, x[c]);
                  break;
                case 0:
                  for (var i = 0; i < n.data.length; i++) {
                    var x = jA(n.get(i));
                    t4.write(32, x);
                  }
                  break;
                case 10:
                  for (var i = 0; i < n.data.length / 2; i++) {
                    var c = n.get(i);
                    t4.write(32, jA(c[1])), t4.write(32, jA(c[2]));
                  }
                  break;
                case 11:
                  for (var i = 0; i < n.data.length / 2; i++) {
                    for (var s = n.get(i), x = fl(_p(s[1])), c = 0; c < 8; c++)
                      t4.write(8, x[c]);
                    for (var x = fl(_p(s[2])), c = 0; c < 8; c++)
                      t4.write(8, x[c]);
                  }
                  break;
              }
              e[0] = (4 + n.dims.length) * 4, e[1] = (4 + n.dims.length) * 8;
            }
            function IV(t4) {
              switch (t4) {
                case 7:
                case 10:
                case 11:
                  return 2;
                default:
                  return 1;
              }
            }
            function d70(t4, n) {
              var e = L0, i;
              switch (t4) {
                case 0:
                  i = e.Float32Array;
                  break;
                case 1:
                  i = e.Float64Array;
                  break;
                case 2:
                  i = e.Int8Array;
                  break;
                case 3:
                  i = e.Uint8Array;
                  break;
                case 4:
                  i = e.Int16Array;
                  break;
                case 5:
                  i = e.Uint16Array;
                  break;
                case 6:
                  i = e.Int32Array;
                  break;
                case 7:
                  i = e.Int32Array;
                  break;
                case 8:
                  i = e.Int32Array;
                  break;
                case 9:
                  i = e.Int32Array;
                  break;
                case 10:
                  i = e.Float32Array;
                  break;
                case 11:
                  i = e.Float64Array;
                  break;
                case 12:
                  i = e.Uint8Array;
                  break;
              }
              i || su("Bigarray.create: unsupported kind");
              var x = new i(n * IV(t4));
              return x;
            }
            function GA(t4) {
              var n = new L0.Int32Array(1);
              n[0] = t4;
              var e = new L0.Float32Array(n.buffer);
              return e[0];
            }
            function xl(t4) {
              return new cn(t4[7] << 0 | t4[6] << 8 | t4[5] << 16, t4[4] << 0 | t4[3] << 8 | t4[2] << 16, t4[1] << 0 | t4[0] << 8);
            }
            function MA(t4) {
              var n = t4.lo, e = t4.mi, i = t4.hi, x = (i & 32767) >> 4;
              if (x == xX)
                return n | e | i & uF ? NaN : i & Bi ? -1 / 0 : 1 / 0;
              var c = Math.pow(2, -24), s = (n * c + e) * c + (i & uF);
              return x > 0 ? (s += 16, s *= Math.pow(2, x - oU)) : s *= Math.pow(2, -iH), i & Bi && (s = -s), s;
            }
            function BA(t4) {
              for (var n = t4.length, e = 1, i = 0; i < n; i++)
                t4[i] < 0 && su("Bigarray.create: negative dimension"), e = e * t4[i];
              return e;
            }
            function h70(t4, n) {
              return new cn(t4 & gx, t4 >>> 24 & is | (n & Ri) << 8, n >>> 16 & Ri);
            }
            function qA(t4) {
              return t4.hi32();
            }
            function UA(t4) {
              return t4.lo32();
            }
            var k70 = l3;
            function Ns(t4, n, e, i) {
              this.kind = t4, this.layout = n, this.dims = e, this.data = i;
            }
            Ns.prototype.caml_custom = k70, Ns.prototype.offset = function(t4) {
              var n = 0;
              if (typeof t4 == "number" && (t4 = [t4]), t4 instanceof Array || su("bigarray.js: invalid offset"), this.dims.length != t4.length && su("Bigarray.get/set: bad number of dimensions"), this.layout == 0)
                for (var e = 0; e < this.dims.length; e++)
                  (t4[e] < 0 || t4[e] >= this.dims[e]) && il(), n = n * this.dims[e] + t4[e];
              else
                for (var e = this.dims.length - 1; e >= 0; e--)
                  (t4[e] < 1 || t4[e] > this.dims[e]) && il(), n = n * this.dims[e] + (t4[e] - 1);
              return n;
            }, Ns.prototype.get = function(t4) {
              switch (this.kind) {
                case 7:
                  var n = this.data[t4 * 2 + 0], e = this.data[t4 * 2 + 1];
                  return h70(n, e);
                case 10:
                case 11:
                  var i = this.data[t4 * 2 + 0], x = this.data[t4 * 2 + 1];
                  return [gv, i, x];
                default:
                  return this.data[t4];
              }
            }, Ns.prototype.set = function(t4, n) {
              switch (this.kind) {
                case 7:
                  this.data[t4 * 2 + 0] = UA(n), this.data[t4 * 2 + 1] = qA(n);
                  break;
                case 10:
                case 11:
                  this.data[t4 * 2 + 0] = n[1], this.data[t4 * 2 + 1] = n[2];
                  break;
                default:
                  this.data[t4] = n;
                  break;
              }
              return 0;
            }, Ns.prototype.fill = function(t4) {
              switch (this.kind) {
                case 7:
                  var n = UA(t4), e = qA(t4);
                  if (n == e)
                    this.data.fill(n);
                  else
                    for (var i = 0; i < this.data.length; i++)
                      this.data[i] = i % 2 == 0 ? n : e;
                  break;
                case 10:
                case 11:
                  var x = t4[1], c = t4[2];
                  if (x == c)
                    this.data.fill(x);
                  else
                    for (var i = 0; i < this.data.length; i++)
                      this.data[i] = i % 2 == 0 ? x : c;
                  break;
                default:
                  this.data.fill(t4);
                  break;
              }
            }, Ns.prototype.compare = function(t4, n) {
              if (this.layout != t4.layout || this.kind != t4.kind) {
                var e = this.kind | this.layout << 8, i = t4.kind | t4.layout << 8;
                return i - e;
              }
              if (this.dims.length != t4.dims.length)
                return t4.dims.length - this.dims.length;
              for (var x = 0; x < this.dims.length; x++)
                if (this.dims[x] != t4.dims[x])
                  return this.dims[x] < t4.dims[x] ? -1 : 1;
              switch (this.kind) {
                case 0:
                case 1:
                case 10:
                case 11:
                  for (var c, s, x = 0; x < this.data.length; x++) {
                    if (c = this.data[x], s = t4.data[x], c < s)
                      return -1;
                    if (c > s)
                      return 1;
                    if (c != s) {
                      if (!n)
                        return NaN;
                      if (c == c)
                        return 1;
                      if (s == s)
                        return -1;
                    }
                  }
                  break;
                case 7:
                  for (var x = 0; x < this.data.length; x += 2) {
                    if (this.data[x + 1] < t4.data[x + 1])
                      return -1;
                    if (this.data[x + 1] > t4.data[x + 1])
                      return 1;
                    if (this.data[x] >>> 0 < t4.data[x] >>> 0)
                      return -1;
                    if (this.data[x] >>> 0 > t4.data[x] >>> 0)
                      return 1;
                  }
                  break;
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                case 8:
                case 9:
                case 12:
                  for (var x = 0; x < this.data.length; x++) {
                    if (this.data[x] < t4.data[x])
                      return -1;
                    if (this.data[x] > t4.data[x])
                      return 1;
                  }
                  break;
              }
              return 0;
            };
            function Lv(t4, n, e, i) {
              this.kind = t4, this.layout = n, this.dims = e, this.data = i;
            }
            Lv.prototype = new Ns(), Lv.prototype.offset = function(t4) {
              return typeof t4 != "number" && (t4 instanceof Array && t4.length == 1 ? t4 = t4[0] : su("Ml_Bigarray_c_1_1.offset")), (t4 < 0 || t4 >= this.dims[0]) && il(), t4;
            }, Lv.prototype.get = function(t4) {
              return this.data[t4];
            }, Lv.prototype.set = function(t4, n) {
              return this.data[t4] = n, 0;
            }, Lv.prototype.fill = function(t4) {
              return this.data.fill(t4), 0;
            };
            function AV(t4, n, e, i) {
              var x = IV(t4);
              return BA(e) * x != i.length && su("length doesn't match dims"), n == 0 && e.length == 1 && x == 1 ? new Lv(t4, n, e, i) : new Ns(t4, n, e, i);
            }
            function e7(t4) {
              RA(Kt.Failure, t4);
            }
            function NV(t4, n, e) {
              var i = t4.read32s();
              (i < 0 || i > 16) && e7("input_value: wrong number of bigarray dimensions");
              var x = t4.read32s(), c = x & is, s = x >> 8 & 1, p = [];
              if (e == l3)
                for (var y = 0; y < i; y++) {
                  var T = t4.read16u();
                  if (T == Ri) {
                    var E = t4.read32u(), h = t4.read32u();
                    E != 0 && e7("input_value: bigarray dimension overflow in 32bit"), T = h;
                  }
                  p.push(T);
                }
              else
                for (var y = 0; y < i; y++)
                  p.push(t4.read32u());
              var w = BA(p), G = d70(c, w), A = AV(c, s, p, G);
              switch (c) {
                case 2:
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read8s();
                  break;
                case 3:
                case 12:
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read8u();
                  break;
                case 4:
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read16s();
                  break;
                case 5:
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read16u();
                  break;
                case 6:
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read32s();
                  break;
                case 8:
                case 9:
                  var S = t4.read8u();
                  S && e7("input_value: cannot read bigarray with 64-bit OCaml ints");
                  for (var y = 0; y < w; y++)
                    G[y] = t4.read32s();
                  break;
                case 7:
                  for (var k0 = new Array(8), y = 0; y < w; y++) {
                    for (var M = 0; M < 8; M++)
                      k0[M] = t4.read8u();
                    var K = xl(k0);
                    A.set(y, K);
                  }
                  break;
                case 1:
                  for (var k0 = new Array(8), y = 0; y < w; y++) {
                    for (var M = 0; M < 8; M++)
                      k0[M] = t4.read8u();
                    var V = MA(xl(k0));
                    A.set(y, V);
                  }
                  break;
                case 0:
                  for (var y = 0; y < w; y++) {
                    var V = GA(t4.read32s());
                    A.set(y, V);
                  }
                  break;
                case 10:
                  for (var y = 0; y < w; y++) {
                    var f0 = GA(t4.read32s()), m0 = GA(t4.read32s());
                    A.set(y, [gv, f0, m0]);
                  }
                  break;
                case 11:
                  for (var k0 = new Array(8), y = 0; y < w; y++) {
                    for (var M = 0; M < 8; M++)
                      k0[M] = t4.read8u();
                    for (var f0 = MA(xl(k0)), M = 0; M < 8; M++)
                      k0[M] = t4.read8u();
                    var m0 = MA(xl(k0));
                    A.set(y, [gv, f0, m0]);
                  }
                  break;
              }
              return n[0] = (4 + i) * 4, AV(c, s, p, G);
            }
            function CV(t4, n, e) {
              return t4.compare(n, e);
            }
            function PV(t4, n) {
              return Math.imul(t4, n);
            }
            function cs(t4, n) {
              return n = PV(n, -862048943), n = n << 15 | n >>> 32 - 15, n = PV(n, 461845907), t4 ^= n, t4 = t4 << 13 | t4 >>> 32 - 13, (t4 + (t4 << 2) | 0) + -430675100 | 0;
            }
            function w70(t4, n) {
              return t4 = cs(t4, UA(n)), t4 = cs(t4, qA(n)), t4;
            }
            function DV(t4, n) {
              return w70(t4, _p(n));
            }
            function LV(t4) {
              var n = BA(t4.dims), e = 0;
              switch (t4.kind) {
                case 2:
                case 3:
                case 12:
                  n > C4 && (n = C4);
                  var i = 0, x = 0;
                  for (x = 0; x + 4 <= t4.data.length; x += 4)
                    i = t4.data[x + 0] | t4.data[x + 1] << 8 | t4.data[x + 2] << 16 | t4.data[x + 3] << 24, e = cs(e, i);
                  switch (i = 0, n & 3) {
                    case 3:
                      i = t4.data[x + 2] << 16;
                    case 2:
                      i |= t4.data[x + 1] << 8;
                    case 1:
                      i |= t4.data[x + 0], e = cs(e, i);
                  }
                  break;
                case 4:
                case 5:
                  n > Gt && (n = Gt);
                  var i = 0, x = 0;
                  for (x = 0; x + 2 <= t4.data.length; x += 2)
                    i = t4.data[x + 0] | t4.data[x + 1] << 16, e = cs(e, i);
                  n & 1 && (e = cs(e, t4.data[x]));
                  break;
                case 6:
                  n > 64 && (n = 64);
                  for (var x = 0; x < n; x++)
                    e = cs(e, t4.data[x]);
                  break;
                case 8:
                case 9:
                  n > 64 && (n = 64);
                  for (var x = 0; x < n; x++)
                    e = cs(e, t4.data[x]);
                  break;
                case 7:
                  n > 32 && (n = 32), n *= 2;
                  for (var x = 0; x < n; x++)
                    e = cs(e, t4.data[x]);
                  break;
                case 10:
                  n *= 2;
                case 0:
                  n > 64 && (n = 64);
                  for (var x = 0; x < n; x++)
                    e = DV(e, t4.data[x]);
                  break;
                case 11:
                  n *= 2;
                case 1:
                  n > 32 && (n = 32);
                  for (var x = 0; x < n; x++)
                    e = DV(e, t4.data[x]);
                  break;
              }
              return e;
            }
            function E70(t4, n) {
              return n[0] = 4, t4.read32s();
            }
            function S70(t4, n) {
              switch (t4.read8u()) {
                case 1:
                  return n[0] = 4, t4.read32s();
                case 2:
                  e7("input_value: native integer value too large");
                default:
                  e7("input_value: ill-formed native integer");
              }
            }
            function g70(t4, n) {
              for (var e = new Array(8), i = 0; i < 8; i++)
                e[i] = t4.read8u();
              return n[0] = 8, xl(e);
            }
            function F70(t4, n, e) {
              for (var i = fl(n), x = 0; x < 8; x++)
                t4.write(8, i[x]);
              e[0] = 8, e[1] = 8;
            }
            function T70(t4, n, e) {
              return t4.compare(n);
            }
            function O70(t4) {
              return t4.lo32() ^ t4.hi32();
            }
            var RV = { _j: { deserialize: g70, serialize: F70, fixed_length: 8, compare: T70, hash: O70 }, _i: { deserialize: E70, fixed_length: 4 }, _n: { deserialize: S70, fixed_length: 4 }, _bigarray: { deserialize: function(t4, n) {
              return NV(t4, n, "_bigarray");
            }, serialize: OV, compare: CV, hash: LV }, _bigarr02: { deserialize: function(t4, n) {
              return NV(t4, n, l3);
            }, serialize: OV, compare: CV, hash: LV } };
            function HA(t4) {
              return RV[t4.caml_custom] && RV[t4.caml_custom].compare;
            }
            function jV(t4, n, e, i) {
              var x = HA(n);
              if (x) {
                var c = e > 0 ? x(n, t4, i) : x(t4, n, i);
                if (i && c != c)
                  return e;
                if (+c != +c)
                  return +c;
                if (c | 0)
                  return c | 0;
              }
              return e;
            }
            function yp(t4) {
              return t4 instanceof Ac;
            }
            function XA(t4) {
              return yp(t4);
            }
            function GV(t4) {
              if (typeof t4 == "number")
                return Q2;
              if (yp(t4))
                return Y2;
              if (XA(t4))
                return 1252;
              if (t4 instanceof Array && t4[0] === t4[0] >>> 0 && t4[0] <= Ow) {
                var n = t4[0] | 0;
                return n == gv ? 0 : n;
              } else {
                if (t4 instanceof String)
                  return LY;
                if (typeof t4 == "string")
                  return LY;
                if (t4 instanceof Number)
                  return Q2;
                if (t4 && t4.caml_custom)
                  return VO;
                if (t4 && t4.compare)
                  return 1256;
                if (typeof t4 == "function")
                  return 1247;
                if (typeof t4 == "symbol")
                  return 1251;
              }
              return 1001;
            }
            function Cc(t4, n) {
              return t4 < n ? -1 : t4 == n ? 0 : 1;
            }
            function MV(t4, n) {
              return t4.t & 6 && Dv(t4), n.t & 6 && Dv(n), t4.c < n.c ? -1 : t4.c > n.c ? 1 : 0;
            }
            function Ee(t4, n) {
              return MV(t4, n);
            }
            function dp(t4, n, e) {
              for (var i = []; ; ) {
                if (!(e && t4 === n)) {
                  var x = GV(t4);
                  if (x == nl) {
                    t4 = t4[1];
                    continue;
                  }
                  var c = GV(n);
                  if (c == nl) {
                    n = n[1];
                    continue;
                  }
                  if (x !== c)
                    return x == Q2 ? c == VO ? jV(t4, n, -1, e) : -1 : c == Q2 ? x == VO ? jV(n, t4, 1, e) : 1 : x < c ? -1 : 1;
                  switch (x) {
                    case 247:
                      su(Oh);
                      break;
                    case 248:
                      var p = Cc(t4[2], n[2]);
                      if (p != 0)
                        return p | 0;
                      break;
                    case 249:
                      su(Oh);
                      break;
                    case 250:
                      su("equal: got Forward_tag, should not happen");
                      break;
                    case 251:
                      su("equal: abstract value");
                      break;
                    case 252:
                      if (t4 !== n) {
                        var p = MV(t4, n);
                        if (p != 0)
                          return p | 0;
                      }
                      break;
                    case 253:
                      su("equal: got Double_tag, should not happen");
                      break;
                    case 254:
                      su("equal: got Double_array_tag, should not happen");
                      break;
                    case 255:
                      su("equal: got Custom_tag, should not happen");
                      break;
                    case 1247:
                      su(Oh);
                      break;
                    case 1255:
                      var s = HA(t4);
                      if (s != HA(n))
                        return t4.caml_custom < n.caml_custom ? -1 : 1;
                      s || su("compare: abstract value");
                      var p = s(t4, n, e);
                      if (p != p)
                        return e ? -1 : p;
                      if (p !== (p | 0))
                        return -1;
                      if (p != 0)
                        return p | 0;
                      break;
                    case 1256:
                      var p = t4.compare(n, e);
                      if (p != p)
                        return e ? -1 : p;
                      if (p !== (p | 0))
                        return -1;
                      if (p != 0)
                        return p | 0;
                      break;
                    case 1e3:
                      if (t4 = +t4, n = +n, t4 < n)
                        return -1;
                      if (t4 > n)
                        return 1;
                      if (t4 != n) {
                        if (!e)
                          return NaN;
                        if (t4 == t4)
                          return 1;
                        if (n == n)
                          return -1;
                      }
                      break;
                    case 1001:
                      if (t4 < n)
                        return -1;
                      if (t4 > n)
                        return 1;
                      if (t4 != n) {
                        if (!e)
                          return NaN;
                        if (t4 == t4)
                          return 1;
                        if (n == n)
                          return -1;
                      }
                      break;
                    case 1251:
                      if (t4 !== n)
                        return e ? 1 : NaN;
                      break;
                    case 1252:
                      var t4 = Nc(t4), n = Nc(n);
                      if (t4 !== n) {
                        if (t4 < n)
                          return -1;
                        if (t4 > n)
                          return 1;
                      }
                      break;
                    case 12520:
                      var t4 = t4.toString(), n = n.toString();
                      if (t4 !== n) {
                        if (t4 < n)
                          return -1;
                        if (t4 > n)
                          return 1;
                      }
                      break;
                    case 246:
                    case 254:
                    default:
                      if (t4.length != n.length)
                        return t4.length < n.length ? -1 : 1;
                      t4.length > 1 && i.push(t4, n, 1);
                      break;
                  }
                }
                if (i.length == 0)
                  return 0;
                var y = i.pop();
                n = i.pop(), t4 = i.pop(), y + 1 < t4.length && i.push(t4, n, y + 1), t4 = t4[y], n = n[y];
              }
            }
            function BV(t4, n) {
              return dp(t4, n, true);
            }
            function I70() {
              return [0];
            }
            function Rt(t4) {
              return t4 < 0 && su("Bytes.create"), new Ac(t4 ? 2 : 9, C, t4);
            }
            function qV(t4, n) {
              return +(dp(t4, n, false) == 0);
            }
            function A70(t4, n, e, i) {
              if (e > 0)
                if (n == 0 && (e >= t4.l || t4.t == 2 && e >= t4.c.length))
                  i == 0 ? (t4.c = C, t4.t = 2) : (t4.c = Pv(e, String.fromCharCode(i)), t4.t = e == t4.l ? 0 : 2);
                else
                  for (t4.t != 4 && pp(t4), e += n; n < e; n++)
                    t4.c[n] = i;
              return 0;
            }
            function al(t4) {
              var n;
              if (t4 = Nc(t4), n = +t4, t4.length > 0 && n === n || (t4 = t4.replace(/_/g, C), n = +t4, t4.length > 0 && n === n || /^[+-]?nan$/i.test(t4)))
                return n;
              var e = /^ *([+-]?)0x([0-9a-f]+)\.?([0-9a-f]*)p([+-]?[0-9]+)/i.exec(t4);
              if (e) {
                var i = e[3].replace(/0+$/, C), x = parseInt(e[1] + e[2] + i, 16), c = (e[4] | 0) - 4 * i.length;
                return n = x * Math.pow(2, c), n;
              }
              if (/^\+?inf(inity)?$/i.test(t4))
                return 1 / 0;
              if (/^-inf(inity)?$/i.test(t4))
                return -1 / 0;
              e7("float_of_string");
            }
            function YA(t4) {
              t4 = Nc(t4);
              var n = t4.length;
              n > 31 && su("format_int: format too long");
              for (var e = { justify: as, signstyle: Oo, filler: pi, alternate: false, base: 0, signedconv: false, width: 0, uppercase: false, sign: 1, prec: -1, conv: lY }, i = 0; i < n; i++) {
                var x = t4.charAt(i);
                switch (x) {
                  case "-":
                    e.justify = Oo;
                    break;
                  case "+":
                  case " ":
                    e.signstyle = x;
                    break;
                  case "0":
                    e.filler = $u;
                    break;
                  case "#":
                    e.alternate = true;
                    break;
                  case "1":
                  case "2":
                  case "3":
                  case "4":
                  case "5":
                  case "6":
                  case "7":
                  case "8":
                  case "9":
                    for (e.width = 0; x = t4.charCodeAt(i) - 48, x >= 0 && x <= 9; )
                      e.width = e.width * 10 + x, i++;
                    i--;
                    break;
                  case ".":
                    for (e.prec = 0, i++; x = t4.charCodeAt(i) - 48, x >= 0 && x <= 9; )
                      e.prec = e.prec * 10 + x, i++;
                    i--;
                  case "d":
                  case "i":
                    e.signedconv = true;
                  case "u":
                    e.base = 10;
                    break;
                  case "x":
                    e.base = 16;
                    break;
                  case "X":
                    e.base = 16, e.uppercase = true;
                    break;
                  case "o":
                    e.base = 8;
                    break;
                  case "e":
                  case "f":
                  case "g":
                    e.signedconv = true, e.conv = x;
                    break;
                  case "E":
                  case "F":
                  case "G":
                    e.signedconv = true, e.uppercase = true, e.conv = x.toLowerCase();
                    break;
                }
              }
              return e;
            }
            function VA(t4, n) {
              t4.uppercase && (n = n.toUpperCase());
              var e = n.length;
              t4.signedconv && (t4.sign < 0 || t4.signstyle != Oo) && e++, t4.alternate && (t4.base == 8 && (e += 1), t4.base == 16 && (e += 2));
              var i = C;
              if (t4.justify == as && t4.filler == pi)
                for (var x = e; x < t4.width; x++)
                  i += pi;
              if (t4.signedconv && (t4.sign < 0 ? i += Oo : t4.signstyle != Oo && (i += t4.signstyle)), t4.alternate && t4.base == 8 && (i += $u), t4.alternate && t4.base == 16 && (i += b1), t4.justify == as && t4.filler == $u)
                for (var x = e; x < t4.width; x++)
                  i += $u;
              if (i += n, t4.justify == Oo)
                for (var x = e; x < t4.width; x++)
                  i += pi;
              return r(i);
            }
            function zA(t4, n) {
              function e(E, h) {
                if (Math.abs(E) < 1)
                  return E.toFixed(h);
                var w = parseInt(E.toString().split(as)[1]);
                return w > 20 ? (w -= 20, E /= Math.pow(10, w), E += new Array(w + 1).join($u), h > 0 && (E = E + Ra + new Array(h + 1).join($u)), E) : E.toFixed(h);
              }
              var i, x = YA(t4), c = x.prec < 0 ? 6 : x.prec;
              if ((n < 0 || n == 0 && 1 / n == -1 / 0) && (x.sign = -1, n = -n), isNaN(n))
                i = bw, x.filler = pi;
              else if (!isFinite(n))
                i = "inf", x.filler = pi;
              else
                switch (x.conv) {
                  case "e":
                    var i = n.toExponential(c), s = i.length;
                    i.charAt(s - 3) == iy && (i = i.slice(0, s - 1) + $u + i.slice(s - 1));
                    break;
                  case "f":
                    i = e(n, c);
                    break;
                  case "g":
                    c = c || 1, i = n.toExponential(c - 1);
                    var p = i.indexOf(iy), y = +i.slice(p + 1);
                    if (y < -4 || n >= 1e21 || n.toFixed(0).length > c) {
                      for (var s = p - 1; i.charAt(s) == $u; )
                        s--;
                      i.charAt(s) == Ra && s--, i = i.slice(0, s + 1) + i.slice(p), s = i.length, i.charAt(s - 3) == iy && (i = i.slice(0, s - 1) + $u + i.slice(s - 1));
                      break;
                    } else {
                      var T = c;
                      if (y < 0)
                        T -= y + 1, i = n.toFixed(T);
                      else
                        for (; i = n.toFixed(T), i.length > c + 1; )
                          T--;
                      if (T) {
                        for (var s = i.length - 1; i.charAt(s) == $u; )
                          s--;
                        i.charAt(s) == Ra && s--, i = i.slice(0, s + 1);
                      }
                    }
                    break;
                }
              return VA(x, i);
            }
            function hp(t4, n) {
              if (Nc(t4) == N2)
                return r(C + n);
              var e = YA(t4);
              n < 0 && (e.signedconv ? (e.sign = -1, n = -n) : n >>>= 0);
              var i = n.toString(e.base);
              if (e.prec >= 0) {
                e.filler = pi;
                var x = e.prec - i.length;
                x > 0 && (i = Pv(x, $u) + i);
              }
              return VA(e, i);
            }
            var UV = 0;
            function M7() {
              return UV++;
            }
            function N70() {
              return 0;
            }
            function HV() {
              return [0];
            }
            var kp = [];
            function Qe(t4, n, e) {
              var i = t4[1], x = kp[e];
              if (x === void 0)
                for (var c = kp.length; c < e; c++)
                  kp[c] = 0;
              else if (i[x] === n)
                return i[x - 1];
              for (var s = 3, p = i[1] * 2 + 1, y; s < p; )
                y = s + p >> 1 | 1, n < i[y + 1] ? p = y - 2 : s = y;
              return kp[e] = s + 1, n == i[s + 1] ? i[s] : 0;
            }
            function C70(t4) {
              for (var n = C, e = n, i, x, c = 0, s = t4.length; c < s; c++) {
                if (i = t4.charCodeAt(c), i < Di) {
                  for (var p = c + 1; p < s && (i = t4.charCodeAt(p)) < Di; p++)
                    ;
                  if (p - c > CI ? (e.substr(0, 1), n += e, e = C, n += t4.slice(c, p)) : e += t4.slice(c, p), p == s)
                    break;
                  c = p;
                }
                i < JX ? (e += String.fromCharCode(192 | i >> 6), e += String.fromCharCode(Di | i & Ov)) : i < 55296 || i >= IH ? e += String.fromCharCode(KY | i >> 12, Di | i >> 6 & Ov, Di | i & Ov) : i >= 56319 || c + 1 == s || (x = t4.charCodeAt(c + 1)) < RH || x > IH ? e += "\xEF\xBF\xBD" : (c++, i = (i << 10) + x - 56613888, e += String.fromCharCode(BX | i >> 18, Di | i >> 12 & Ov, Di | i >> 6 & Ov, Di | i & Ov)), e.length > L2 && (e.substr(0, 1), n += e, e = C);
              }
              return n + e;
            }
            function P70(t4) {
              var n = 9;
              return wV(t4) || (n = 8, t4 = C70(t4)), new Ac(n, t4, t4.length);
            }
            function B7(t4) {
              return P70(t4);
            }
            function D70(t4, n, e) {
              if (!isFinite(t4))
                return isNaN(t4) ? B7(bw) : B7(t4 > 0 ? kU : "-infinity");
              var i = t4 == 0 && 1 / t4 == -1 / 0 ? 1 : t4 >= 0 ? 0 : 1;
              i && (t4 = -t4);
              var x = 0;
              if (t4 != 0)
                if (t4 < 1)
                  for (; t4 < 1 && x > -YX; )
                    t4 *= 2, x--;
                else
                  for (; t4 >= 2; )
                    t4 /= 2, x++;
              var c = x < 0 ? C : as, s = C;
              if (i)
                s = Oo;
              else
                switch (e) {
                  case 43:
                    s = as;
                    break;
                  case 32:
                    s = pi;
                    break;
                  default:
                    break;
                }
              if (n >= 0 && n < 13) {
                var p = Math.pow(2, n * 4);
                t4 = Math.round(t4 * p) / p;
              }
              var y = t4.toString(16);
              if (n >= 0) {
                var T = y.indexOf(Ra);
                if (T < 0)
                  y += Ra + Pv(n, $u);
                else {
                  var E = T + 1 + n;
                  y.length < E ? y += Pv(E - y.length, $u) : y = y.substr(0, E);
                }
              }
              return B7(s + b1 + y + "p" + c + x.toString(10));
            }
            function L70(t4) {
              return +t4.isZero();
            }
            function wp(t4) {
              return new cn(t4 & gx, t4 >> 24 & gx, t4 >> 31 & Ri);
            }
            function R70(t4) {
              return t4.toInt();
            }
            function j70(t4) {
              return +t4.isNeg();
            }
            function XV(t4) {
              return t4.neg();
            }
            function G70(t4, n) {
              var e = YA(t4);
              e.signedconv && j70(n) && (e.sign = -1, n = XV(n));
              var i = C, x = wp(e.base), c = "0123456789abcdef";
              do {
                var s = n.udivmod(x);
                n = s.quotient, i = c.charAt(R70(s.modulus)) + i;
              } while (!L70(n));
              if (e.prec >= 0) {
                e.filler = pi;
                var p = e.prec - i.length;
                p > 0 && (i = Pv(p, $u) + i);
              }
              return VA(e, i);
            }
            function b7(t4) {
              return t4.l;
            }
            function tn(t4) {
              return b7(t4);
            }
            function Vr(t4, n) {
              return Hu(t4, n);
            }
            function M70(t4, n) {
              return t4.add(n);
            }
            function B70(t4, n) {
              return t4.mul(n);
            }
            function KA(t4, n) {
              return t4.ucompare(n) < 0;
            }
            function YV(t4) {
              var n = 0, e = tn(t4), i = 10, x = 1;
              if (e > 0)
                switch (Vr(t4, n)) {
                  case 45:
                    n++, x = -1;
                    break;
                  case 43:
                    n++, x = 1;
                    break;
                }
              if (n + 1 < e && Vr(t4, n) == 48)
                switch (Vr(t4, n + 1)) {
                  case 120:
                  case 88:
                    i = 16, n += 2;
                    break;
                  case 111:
                  case 79:
                    i = 8, n += 2;
                    break;
                  case 98:
                  case 66:
                    i = 2, n += 2;
                    break;
                  case 117:
                  case 85:
                    n += 2;
                    break;
                }
              return [n, x, i];
            }
            function Ep(t4) {
              return t4 >= 48 && t4 <= 57 ? t4 - 48 : t4 >= 65 && t4 <= 90 ? t4 - 55 : t4 >= 97 && t4 <= Nn ? t4 - 87 : -1;
            }
            function Rv(t4) {
              var n = YV(t4), e = n[0], i = n[1], x = n[2], c = wp(x), s = new cn(gx, 268435455, Ri).udivmod(c).quotient, p = Vr(t4, e), y = Ep(p);
              (y < 0 || y >= x) && e7(ts);
              for (var T = wp(y); ; )
                if (e++, p = Vr(t4, e), p != 95) {
                  if (y = Ep(p), y < 0 || y >= x)
                    break;
                  KA(s, T) && e7(ts), y = wp(y), T = M70(B70(c, T), y), KA(T, y) && e7(ts);
                }
              return e != tn(t4) && e7(ts), x == 10 && KA(new cn(0, 0, Bi), T) && e7(ts), i < 0 && (T = XV(T)), T;
            }
            function jv(t4) {
              return t4.toFloat();
            }
            function qi(t4) {
              var n = YV(t4), e = n[0], i = n[1], x = n[2], c = tn(t4), s = -1 >>> 0, p = e < c ? Vr(t4, e) : 0, y = Ep(p);
              (y < 0 || y >= x) && e7(ts);
              var T = y;
              for (e++; e < c; e++)
                if (p = Vr(t4, e), p != 95) {
                  if (y = Ep(p), y < 0 || y >= x)
                    break;
                  T = x * T + y, T > s && e7(ts);
                }
              return e != c && e7(ts), T = i * T, x == 10 && (T | 0) != T && e7(ts), T | 0;
            }
            function q70(t4) {
              return t4.slice(1);
            }
            function U70(t4) {
              return !!t4;
            }
            function bn(t4) {
              return t4.toUtf16();
            }
            function H70(t4) {
              for (var n = {}, e = 1; e < t4.length; e++) {
                var i = t4[e];
                n[bn(i[1])] = i[2];
              }
              return n;
            }
            function X70(t4, n) {
              return +(dp(t4, n, false) < 0);
            }
            function Gv(e, n) {
              e < 0 && il();
              var e = e + 1 | 0, i = new Array(e);
              i[0] = 0;
              for (var x = 1; x < e; x++)
                i[x] = n;
              return i;
            }
            function Y70() {
              return 0;
            }
            function st(t4) {
              RA(Kt.Sys_error, t4);
            }
            var Pc = new Array();
            function m1(t4) {
              var n = Pc[t4];
              if (n.opened || st("Cannot flush a closed channel"), !n.buffer || n.buffer == C)
                return 0;
              if (n.fd && Kt.fds[n.fd] && Kt.fds[n.fd].output) {
                var e = Kt.fds[n.fd].output;
                switch (e.length) {
                  case 2:
                    e(t4, n.buffer);
                    break;
                  default:
                    e(n.buffer);
                }
              }
              return n.buffer = C, 0;
            }
            function VV() {
              return typeof L0.process < "u" && typeof L0.process.versions < "u" && typeof L0.process.versions.node < "u" && L0.process.platform !== "browser";
            }
            function V70() {
              function t4(e) {
                if (e.charAt(0) === Zu)
                  return [C, e.substring(1)];
              }
              function n(e) {
                var i = /^([a-zA-Z]:|[\\/]{2}[^\\/]+[\\/]+[^\\/]+)?([\\/])?([\s\S]*?)$/, x = i.exec(e), c = x[1] || C, s = Boolean(c && c.charAt(1) !== o1);
                if (Boolean(x[2] || s)) {
                  var p = x[1] || C, y = x[2] || C;
                  return [p, e.substring(p.length + y.length)];
                }
              }
              return L0.process && L0.process.platform && L0.process.platform === bV ? n : t4;
            }
            var WA = V70();
            function zV(t4) {
              return t4.slice(-1) !== Zu ? t4 + Zu : t4;
            }
            if (L0.process && L0.process.cwd)
              var ol = L0.process.cwd().replace(/\\/g, Zu);
            else
              var ol = "/static";
            ol = zV(ol);
            function z70(t4) {
              t4 = bn(t4), WA(t4) || (t4 = ol + t4);
              for (var n = WA(t4), e = n[1].split(Zu), i = [], x = 0; x < e.length; x++)
                switch (e[x]) {
                  case "..":
                    i.length > 1 && i.pop();
                    break;
                  case ".":
                    break;
                  default:
                    i.push(e[x]);
                    break;
                }
              return i.unshift(n[0]), i.orig = t4, i;
            }
            var K70 = ["E2BIG", "EACCES", "EAGAIN", "EBADF", "EBUSY", "ECHILD", "EDEADLK", "EDOM", xV, "EFAULT", "EFBIG", "EINTR", "EINVAL", "EIO", "EISDIR", "EMFILE", "EMLINK", "ENAMETOOLONG", "ENFILE", "ENODEV", pd, "ENOEXEC", "ENOLCK", "ENOMEM", "ENOSPC", "ENOSYS", kw, GU, "ENOTTY", "ENXIO", "EPERM", "EPIPE", "ERANGE", "EROFS", "ESPIPE", "ESRCH", "EXDEV", "EWOULDBLOCK", "EINPROGRESS", "EALREADY", "ENOTSOCK", "EDESTADDRREQ", "EMSGSIZE", "EPROTOTYPE", "ENOPROTOOPT", "EPROTONOSUPPORT", "ESOCKTNOSUPPORT", "EOPNOTSUPP", "EPFNOSUPPORT", "EAFNOSUPPORT", "EADDRINUSE", "EADDRNOTAVAIL", "ENETDOWN", "ENETUNREACH", "ENETRESET", "ECONNABORTED", "ECONNRESET", "ENOBUFS", "EISCONN", "ENOTCONN", "ESHUTDOWN", "ETOOMANYREFS", "ETIMEDOUT", "ECONNREFUSED", "EHOSTDOWN", "EHOSTUNREACH", "ELOOP", "EOVERFLOW"];
            function _1(t4, n, e, i) {
              var x = K70.indexOf(t4);
              x < 0 && (i == null && (i = -9999), x = [0, i]);
              var c = [x, B7(n || C), B7(e || C)];
              return c;
            }
            var KV = {};
            function y1(t4) {
              return KV[t4];
            }
            function d1(t4, n) {
              throw [0, t4].concat(n);
            }
            function W70(t4) {
              return new Ac(4, t4, t4.length);
            }
            function J70(t4) {
              t4 = Nc(t4), st(t4 + up);
            }
            function $70(t4, n) {
              return n >>> 0 >= t4.l && SV(), Hu(t4, n);
            }
            function WV() {
            }
            function Eu(t4) {
              this.data = t4;
            }
            Eu.prototype = new WV(), Eu.prototype.truncate = function(t4) {
              var n = this.data;
              this.data = Rt(t4 | 0), Is(n, 0, this.data, 0, t4);
            }, Eu.prototype.length = function() {
              return b7(this.data);
            }, Eu.prototype.write = function(t4, n, e, i) {
              var x = this.length();
              if (t4 + i >= x) {
                var c = Rt(t4 + i), s = this.data;
                this.data = c, Is(s, 0, this.data, 0, x);
              }
              return As(n, e, this.data, t4, i), 0;
            }, Eu.prototype.read = function(t4, n, e, i) {
              var x = this.length();
              return Is(this.data, t4, n, e, i), 0;
            }, Eu.prototype.read_one = function(t4) {
              return $70(this.data, t4);
            }, Eu.prototype.close = function() {
            }, Eu.prototype.constructor = Eu;
            function n7(t4, n) {
              this.content = {}, this.root = t4, this.lookupFun = n;
            }
            n7.prototype.nm = function(t4) {
              return this.root + t4;
            }, n7.prototype.create_dir_if_needed = function(t4) {
              for (var n = t4.split(Zu), e = C, i = 0; i < n.length - 1; i++)
                e += n[i] + Zu, !this.content[e] && (this.content[e] = Symbol("directory"));
            }, n7.prototype.slash = function(t4) {
              return /\/$/.test(t4) ? t4 : t4 + Zu;
            }, n7.prototype.lookup = function(t4) {
              if (!this.content[t4] && this.lookupFun) {
                var n = this.lookupFun(r(this.root), r(t4));
                n !== 0 && (this.create_dir_if_needed(t4), this.content[t4] = new Eu(n[1]));
              }
            }, n7.prototype.exists = function(t4) {
              if (t4 == C)
                return 1;
              var n = this.slash(t4);
              return this.content[n] ? 1 : (this.lookup(t4), this.content[t4] ? 1 : 0);
            }, n7.prototype.mkdir = function(t4, n, e) {
              var i = e && y1($d);
              this.exists(t4) && (i ? d1(i, _1(xV, ZI, this.nm(t4))) : st(t4 + ": File exists"));
              var x = /^(.*)\/[^/]+/.exec(t4);
              x = x && x[1] || C, this.exists(x) || (i ? d1(i, _1(pd, ZI, this.nm(x))) : st(x + up)), this.is_dir(x) || (i ? d1(i, _1(kw, ZI, this.nm(x))) : st(x + MS)), this.create_dir_if_needed(this.slash(t4));
            }, n7.prototype.rmdir = function(t4, n) {
              var e = n && y1($d), i = t4 == C ? C : this.slash(t4), x = new RegExp(A6 + i + eY);
              this.exists(t4) || (e ? d1(e, _1(pd, vh, this.nm(t4))) : st(t4 + up)), this.is_dir(t4) || (e ? d1(e, _1(kw, vh, this.nm(t4))) : st(t4 + MS));
              for (var c in this.content)
                c.match(x) && (e ? d1(e, _1(GU, vh, this.nm(t4))) : st(this.nm(t4) + ": Directory not empty"));
              delete this.content[i];
            }, n7.prototype.readdir = function(t4) {
              var n = t4 == C ? C : this.slash(t4);
              this.exists(t4) || st(t4 + up), this.is_dir(t4) || st(t4 + MS);
              var e = new RegExp(A6 + n + eY), i = {}, x = [];
              for (var c in this.content) {
                var s = c.match(e);
                s && !i[s[1]] && (i[s[1]] = true, x.push(s[1]));
              }
              return x;
            }, n7.prototype.is_dir = function(t4) {
              if (t4 == C)
                return true;
              var n = this.slash(t4);
              return this.content[n] ? 1 : 0;
            }, n7.prototype.unlink = function(t4) {
              var n = !!this.content[t4];
              return delete this.content[t4], n;
            }, n7.prototype.open = function(t4, n) {
              if (n.rdonly && n.wronly && st(this.nm(t4) + NY), n.text && n.binary && st(this.nm(t4) + aY), this.lookup(t4), this.content[t4]) {
                this.is_dir(t4) && st(this.nm(t4) + " : is a directory"), n.create && n.excl && st(this.nm(t4) + CY);
                var e = this.content[t4];
                return n.truncate && e.truncate(), e;
              } else {
                if (n.create)
                  return this.create_dir_if_needed(t4), this.content[t4] = new Eu(Rt(0)), this.content[t4];
                J70(this.nm(t4));
              }
            }, n7.prototype.register = function(t4, n) {
              var e;
              if (this.content[t4] && st(this.nm(t4) + CY), yp(n) && (e = new Eu(n)), XA(n))
                e = new Eu(n);
              else if (n instanceof Array)
                e = new Eu(W70(n));
              else if (typeof n == "string")
                e = new Eu(EV(n));
              else if (n.toString) {
                var i = B7(n.toString());
                e = new Eu(i);
              }
              e ? (this.create_dir_if_needed(t4), this.content[t4] = e) : st(this.nm(t4) + " : registering file with invalid content type");
            }, n7.prototype.constructor = n7;
            function Z70(t4) {
              for (var n = tn(t4), e = new Array(n), i = 0; i < n; i++)
                e[i] = Vr(t4, i);
              return e;
            }
            function Q70(t4) {
              return t4.t != 4 && pp(t4), t4.c;
            }
            function Dc(t4) {
              this.fs = Fj(), this.fd = t4;
            }
            Dc.prototype = new WV(), Dc.prototype.truncate = function(t4) {
              try {
                this.fs.ftruncateSync(this.fd, t4 | 0);
              } catch (n) {
                st(n.toString());
              }
            }, Dc.prototype.length = function() {
              try {
                return this.fs.fstatSync(this.fd).size;
              } catch (t4) {
                st(t4.toString());
              }
            }, Dc.prototype.write = function(t4, n, e, i) {
              var x = Z70(n);
              x instanceof L0.Uint8Array || (x = new L0.Uint8Array(x));
              var c = L0.Buffer.from(x);
              try {
                this.fs.writeSync(this.fd, c, e, i, t4);
              } catch (s) {
                st(s.toString());
              }
              return 0;
            }, Dc.prototype.read = function(t4, n, e, i) {
              var x = Q70(n);
              x instanceof L0.Uint8Array || (x = new L0.Uint8Array(x));
              var c = L0.Buffer.from(x);
              try {
                this.fs.readSync(this.fd, c, e, i, t4);
              } catch (p) {
                st(p.toString());
              }
              for (var s = 0; s < i; s++)
                p1(n, e + s, c[e + s]);
              return 0;
            }, Dc.prototype.read_one = function(t4) {
              var n = new L0.Uint8Array(1), e = L0.Buffer.from(n);
              try {
                this.fs.readSync(this.fd, e, 0, 1, t4);
              } catch (i) {
                st(i.toString());
              }
              return e[0];
            }, Dc.prototype.close = function() {
              try {
                this.fs.closeSync(this.fd);
              } catch (t4) {
                st(t4.toString());
              }
            }, Dc.prototype.constructor = Dc;
            function Su(t4) {
              this.fs = Fj(), this.root = t4;
            }
            Su.prototype.nm = function(t4) {
              return this.root + t4;
            }, Su.prototype.exists = function(t4) {
              try {
                return this.fs.existsSync(this.nm(t4)) ? 1 : 0;
              } catch {
                return 0;
              }
            }, Su.prototype.mkdir = function(t4, n, e) {
              try {
                return this.fs.mkdirSync(this.nm(t4), { mode: n }), 0;
              } catch (i) {
                this.raise_nodejs_error(i, e);
              }
            }, Su.prototype.rmdir = function(t4, n) {
              try {
                return this.fs.rmdirSync(this.nm(t4)), 0;
              } catch (e) {
                this.raise_nodejs_error(e, n);
              }
            }, Su.prototype.readdir = function(t4, n) {
              try {
                return this.fs.readdirSync(this.nm(t4));
              } catch (e) {
                this.raise_nodejs_error(e, n);
              }
            }, Su.prototype.is_dir = function(t4) {
              try {
                return this.fs.statSync(this.nm(t4)).isDirectory() ? 1 : 0;
              } catch (n) {
                st(n.toString());
              }
            }, Su.prototype.unlink = function(t4, n) {
              try {
                var e = this.fs.existsSync(this.nm(t4)) ? 1 : 0;
                return this.fs.unlinkSync(this.nm(t4)), e;
              } catch (i) {
                this.raise_nodejs_error(i, n);
              }
            }, Su.prototype.open = function(t4, n, e) {
              var i = gae(), x = 0;
              for (var c in n)
                switch (c) {
                  case "rdonly":
                    x |= i.O_RDONLY;
                    break;
                  case "wronly":
                    x |= i.O_WRONLY;
                    break;
                  case "append":
                    x |= i.O_WRONLY | i.O_APPEND;
                    break;
                  case "create":
                    x |= i.O_CREAT;
                    break;
                  case "truncate":
                    x |= i.O_TRUNC;
                    break;
                  case "excl":
                    x |= i.O_EXCL;
                    break;
                  case "binary":
                    x |= i.O_BINARY;
                    break;
                  case "text":
                    x |= i.O_TEXT;
                    break;
                  case "nonblock":
                    x |= i.O_NONBLOCK;
                    break;
                }
              try {
                var s = this.fs.openSync(this.nm(t4), x);
                return new Dc(s);
              } catch (p) {
                this.raise_nodejs_error(p, e);
              }
            }, Su.prototype.rename = function(t4, n, e) {
              try {
                this.fs.renameSync(this.nm(t4), this.nm(n));
              } catch (i) {
                this.raise_nodejs_error(i, e);
              }
            }, Su.prototype.stat = function(t4, n) {
              try {
                var e = this.fs.statSync(this.nm(t4));
                return this.stats_from_js(e);
              } catch (i) {
                this.raise_nodejs_error(i, n);
              }
            }, Su.prototype.lstat = function(t4, n) {
              try {
                var e = this.fs.lstatSync(this.nm(t4));
                return this.stats_from_js(e);
              } catch (i) {
                this.raise_nodejs_error(i, n);
              }
            }, Su.prototype.symlink = function(t4, n, e, i) {
              try {
                return this.fs.symlinkSync(this.nm(n), this.nm(e), t4 ? "dir" : "file"), 0;
              } catch (x) {
                this.raise_nodejs_error(x, i);
              }
            }, Su.prototype.readlink = function(t4, n) {
              try {
                var e = this.fs.readlinkSync(this.nm(t4), _V);
                return B7(e);
              } catch (i) {
                this.raise_nodejs_error(i, n);
              }
            }, Su.prototype.raise_nodejs_error = function(t4, n) {
              var e = y1($d);
              if (n && e) {
                var i = _1(t4.code, t4.syscall, t4.path, t4.errno);
                d1(e, i);
              } else
                st(t4.toString());
            }, Su.prototype.stats_from_js = function(t4) {
              var n;
              return t4.isFile() ? n = 0 : t4.isDirectory() ? n = 1 : t4.isCharacterDevice() ? n = 2 : t4.isBlockDevice() ? n = 3 : t4.isSymbolicLink() ? n = 4 : t4.isFIFO() ? n = 5 : t4.isSocket() && (n = 6), [0, t4.dev, t4.ino, n, t4.mode, t4.nlink, t4.uid, t4.gid, t4.rdev, t4.size, t4.atimeMs, t4.mtimeMs, t4.ctimeMs];
            }, Su.prototype.constructor = Su;
            function JV(t4) {
              var n = WA(t4);
              if (n)
                return n[0] + Zu;
            }
            var Sp = JV(ol) || e7("unable to compute caml_root"), Mv = [];
            VV() ? Mv.push({ path: Sp, device: new Su(Sp) }) : Mv.push({ path: Sp, device: new n7(Sp) }), Mv.push({ path: ZU, device: new n7(ZU) });
            function ri0(e) {
              for (var n = z70(e), e = n.join(Zu), i = zV(e), x, c = 0; c < Mv.length; c++) {
                var s = Mv[c];
                i.search(s.path) == 0 && (!x || x.path.length < s.path.length) && (x = { path: s.path, device: s.device, rest: e.substring(s.path.length, e.length) });
              }
              if (!x) {
                var p = JV(e);
                if (p && p.match(/^[a-zA-Z]:\/$/)) {
                  var s = { path: p, device: new Su(p) };
                  Mv.push(s), x = { path: s.path, device: s.device, rest: e.substring(s.path.length, e.length) };
                }
              }
              if (x)
                return x;
              st("no device found for " + i);
            }
            function $V(t4, n) {
              var e = Pc[t4], i = r(n), x = tn(i);
              return e.file.write(e.offset, i, 0, x), e.offset += x, 0;
            }
            function ei0(n) {
              var n = LA(n), e = L0;
              if (e.process && e.process.stdout && e.process.stdout.write)
                e.process.stderr.write(n);
              else {
                n.charCodeAt(n.length - 1) == 10 && (n = n.substr(0, n.length - 1));
                var i = e.console;
                i && i.error && i.error(n);
              }
            }
            function ni0(n) {
              var n = LA(n), e = L0;
              if (e.process && e.process.stdout && e.process.stdout.write)
                e.process.stdout.write(n);
              else {
                n.charCodeAt(n.length - 1) == 10 && (n = n.substr(0, n.length - 1));
                var i = e.console;
                i && i.log && i.log(n);
              }
            }
            function gp(t4, n, e, i) {
              Kt.fds === void 0 && (Kt.fds = new Array()), i = i || {};
              var x = {};
              return x.file = e, x.offset = i.append ? e.length() : 0, x.flags = i, x.output = n, Kt.fds[t4] = x, (!Kt.fd_last_idx || t4 > Kt.fd_last_idx) && (Kt.fd_last_idx = t4), t4;
            }
            function Rae(t4, n, e) {
              for (var i = {}; n; ) {
                switch (n[1]) {
                  case 0:
                    i.rdonly = 1;
                    break;
                  case 1:
                    i.wronly = 1;
                    break;
                  case 2:
                    i.append = 1;
                    break;
                  case 3:
                    i.create = 1;
                    break;
                  case 4:
                    i.truncate = 1;
                    break;
                  case 5:
                    i.excl = 1;
                    break;
                  case 6:
                    i.binary = 1;
                    break;
                  case 7:
                    i.text = 1;
                    break;
                  case 8:
                    i.nonblock = 1;
                    break;
                }
                n = n[2];
              }
              i.rdonly && i.wronly && st(Nc(t4) + NY), i.text && i.binary && st(Nc(t4) + aY);
              var x = ri0(t4), c = x.device.open(x.rest, i), s = Kt.fd_last_idx ? Kt.fd_last_idx : 0;
              return gp(s + 1, $V, c, i);
            }
            gp(0, $V, new Eu(Rt(0))), gp(1, ni0, new Eu(Rt(0))), gp(2, ei0, new Eu(Rt(0)));
            function ti0(t4) {
              var n = Kt.fds[t4];
              n.flags.wronly && st(hX + t4 + " is writeonly");
              var e = null;
              if (t4 == 0 && VV()) {
                var i = Fj();
                e = function() {
                  return B7(i.readFileSync(0, _V));
                };
              }
              var x = { file: n.file, offset: n.offset, fd: t4, opened: true, out: false, refill: e };
              return Pc[x.fd] = x, x.fd;
            }
            function ZV(t4) {
              var n = Kt.fds[t4];
              n.flags.rdonly && st(hX + t4 + " is readonly");
              var e = { file: n.file, offset: n.offset, fd: t4, opened: true, out: true, buffer: C };
              return Pc[e.fd] = e, e.fd;
            }
            function ui0() {
              for (var t4 = 0, n = 0; n < Pc.length; n++)
                Pc[n] && Pc[n].opened && Pc[n].out && (t4 = [0, Pc[n].fd, t4]);
              return t4;
            }
            function jae(t4) {
              return t4;
            }
            function ii0(t4, n, e, i) {
              var x = Pc[t4];
              x.opened || st("Cannot output to a closed channel");
              var c;
              e == 0 && b7(n) == i ? c = n : (c = Rt(i), Is(n, e, c, 0, i));
              var s = c, p = Nc(s), y = p.lastIndexOf(nV);
              return y < 0 ? x.buffer += p : (x.buffer += p.substr(0, y + 1), m1(t4), x.buffer += p.substr(y + 1)), 0;
            }
            function JA(t4, n, e, i) {
              return ii0(t4, n, e, i);
            }
            function QV(t4, n) {
              var e = r(String.fromCharCode(n));
              return JA(t4, e, 0, 1), 0;
            }
            function cl(t4, n) {
              return +(dp(t4, n, false) != 0);
            }
            function $A(t4, n) {
              var e = new Array(n + 1);
              e[0] = t4;
              for (var i = 1; i <= n; i++)
                e[i] = 0;
              return e;
            }
            function fi0(t4, n) {
              return t4[0] = nl, t4[1] = n, 0;
            }
            function h1(t4) {
              return t4 instanceof Array && t4[0] == t4[0] >>> 0 ? t4[0] : yp(t4) || XA(t4) ? Y2 : t4 instanceof Function || typeof t4 == "function" ? jw : t4 && t4.caml_custom ? Ow : Q2;
            }
            function di(t4, n, e) {
              e && L0.toplevelReloc && (t4 = L0.toplevelReloc(e)), Kt[t4 + 1] = n, e && (Kt[e] = n);
            }
            function ZA(t4, n) {
              return KV[Nc(t4)] = n, 0;
            }
            function xi0(t4) {
              return t4[2] = UV++, t4;
            }
            function ai0(t4, n) {
              return t4 === n ? 1 : (t4.t & 6 && Dv(t4), n.t & 6 && Dv(n), t4.c == n.c ? 1 : 0);
            }
            function Un(t4, n) {
              return ai0(t4, n);
            }
            function oi0() {
              su(XS);
            }
            function At(t4, n) {
              return n >>> 0 >= tn(t4) && oi0(), Vr(t4, n);
            }
            function n0(t4, n) {
              return 1 - Un(t4, n);
            }
            function ci0() {
              return [0, r("js_of_ocaml")];
            }
            function si0() {
              return 2147483647 / 4 | 0;
            }
            function vi0(t4) {
              return 0;
            }
            var li0 = L0.process && L0.process.platform && L0.process.platform == bV ? UU : "Unix";
            function bi0() {
              return [0, r(li0), 32, 0];
            }
            function pi0() {
              FV(Kt.Not_found);
            }
            function rz(t4) {
              var n = L0, e = bn(t4);
              if (n.process && n.process.env && n.process.env[e] != null)
                return B7(n.process.env[e]);
              if (L0.jsoo_static_env && L0.jsoo_static_env[e])
                return B7(L0.jsoo_static_env[e]);
              pi0();
            }
            function QA(t4) {
              for (var n = 1; t4 && t4.joo_tramp; )
                t4 = t4.joo_tramp.apply(null, t4.joo_args), n++;
              return t4;
            }
            function gu(t4, n) {
              return { joo_tramp: t4, joo_args: n };
            }
            function N(t4, n) {
              if (typeof n == "function")
                return t4.fun = n, 0;
              if (n.fun)
                return t4.fun = n.fun, 0;
              for (var e = n.length; e--; )
                t4[e] = n[e];
              return 0;
            }
            function Gae(t4) {
              return t4;
            }
            function gt(t4) {
              return t4 instanceof Array ? t4 : L0.RangeError && t4 instanceof L0.RangeError && t4.message && t4.message.match(/maximum call stack/i) || L0.InternalError && t4 instanceof L0.InternalError && t4.message && t4.message.match(/too much recursion/i) ? Kt.Stack_overflow : t4 instanceof L0.Error && y1($O) ? [0, y1($O), t4] : [0, Kt.Failure, B7(String(t4))];
            }
            function mi0(t4) {
              switch (t4[2]) {
                case -8:
                case -11:
                case -12:
                  return 1;
                default:
                  return 0;
              }
            }
            function _i0(t4) {
              var n = C;
              if (t4[0] == 0) {
                if (n += t4[1][1], t4.length == 3 && t4[2][0] == 0 && mi0(t4[1]))
                  var i = t4[2], e = 1;
                else
                  var e = 2, i = t4;
                n += KX;
                for (var x = e; x < i.length; x++) {
                  x > e && (n += nX);
                  var c = i[x];
                  typeof c == "number" ? n += c.toString() : c instanceof Ac || typeof c == "string" ? n += V2 + c.toString() + V2 : n += bv;
                }
                n += Z0;
              } else
                t4[0] == St && (n += t4[1]);
              return n;
            }
            function ez(t4) {
              if (t4 instanceof Array && (t4[0] == 0 || t4[0] == St)) {
                var n = y1(BH);
                if (n)
                  n(t4, false);
                else {
                  var e = _i0(t4), i = y1(mV);
                  i && i(0), L0.console.error(kh + e + nV);
                }
              } else
                throw t4;
            }
            function yi0() {
              var t4 = L0;
              t4.process && t4.process.on ? t4.process.on("uncaughtException", function(n, e) {
                ez(n), t4.process.exit(2);
              }) : t4.addEventListener && t4.addEventListener("error", function(n) {
                n.error && ez(n.error);
              });
            }
            yi0();
            function u(t4, n) {
              return t4.length == 1 ? t4(n) : os(t4, [n]);
            }
            function a(t4, n, e) {
              return t4.length == 2 ? t4(n, e) : os(t4, [n, e]);
            }
            function ir(t4, n, e, i) {
              return t4.length == 3 ? t4(n, e, i) : os(t4, [n, e, i]);
            }
            function R(t4, n, e, i, x) {
              return t4.length == 4 ? t4(n, e, i, x) : os(t4, [n, e, i, x]);
            }
            function p7(t4, n, e, i, x, c) {
              return t4.length == 5 ? t4(n, e, i, x, c) : os(t4, [n, e, i, x, c]);
            }
            function di0(t4, n, e, i, x, c, s, p) {
              return t4.length == 7 ? t4(n, e, i, x, c, s, p) : os(t4, [n, e, i, x, c, s, p]);
            }
            var rN = [St, r(TX), -1], nz = [St, r(MH), -2], q7 = [St, r(LH), -3], eN = [St, r(sH), -4], Jt = [St, r(QU), -7], tz = [St, r(BY), -8], uz = [St, r($U), -9], Fn = [St, r(TU), -11], sl = [St, r(oX), -12], iz = [0, s7], hi0 = [4, 0, 0, 0, [12, 45, [4, 0, 0, 0, 0]]], nN = [0, [11, r('File "'), [2, 0, [11, r('", line '), [4, 0, 0, 0, [11, r(EH), [4, 0, 0, 0, [12, 45, [4, 0, 0, 0, [11, r(": "), [2, 0, 0]]]]]]]]]], r('File "%s", line %d, characters %d-%d: %s')], fz = [0, 0, [0, 0, 0], [0, 0, 0]], tN = r(""), uN = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), Bv = [0, 0, 0, 0, 1, 0], xz = [0, r(Gx), r(va), r(go), r(so), r(za), r(Yf), r(Jx), r(pf), r(of), r(Bx), r(ln), r(Yo), r(A7), r(If), r(px), r(_a), r(lx), r(ef), r(gf), r(Xo), r(oo), r(Ho), r(yf), r(ic), r(Rf), r(To), r(ff), r(Ef), r(Bo), r(Xf), r(Tx), r(ax), r(Fa), r(kf), r(da), r(Qf), r(ao), r(Za), r(N7), r(I7), r(ox), r(Io), r(Mo), r(Wf), r(to), r(la), r(Ta), r(Sx), r(Go), r(ka), r(v7), r(bo), r(eo), r(vo), r(Hx), r(Xa), r(Ux), r(Mf), r(Nf), r(rc), r(Mx), r(Cf), r(ba), r(Fo), r(lf), r(ec), r(io), r(no), r(Iu), r(Ix), r(ta), r(Ff), r(Uf), r(Eo), r(qx), r(Oc), r(Vo), r(jo), r(hx), r(xc), r(li), r(ga), r(pa), r(Ic), r(No), r(kx), r(Nx), r(Tc), r(jf), r(uf), r(ix), r(yo), r(Ma), r(Ex), r(Uo), r(bf), r(po), r(yx), r(G7), r($o), r(mc), r(Kf), r(yi), r(_f), r(fo), r(zo), r(qu), r(gc), r(ma), r(Yx), r(Do), r(Ox), r(Co), r(r7), r(sf), r(wa), r(na), r(Wo), r(Gf), r(sc), r(ho), r(Ja), r(ex), r(cf), r(af), r(Cx), r(_c), r(Na), r(Ga), r(xa), r(Ax), r(sa), r(Px), r(nf), r(nc), r(Wa), r(Ro), r(Sc), r($a), r(bx), r(kc), r(Lx), r(ko), r(Rx), r(ux), r(Wx), r(Lo), r(Xx), r($x), r(dc), r(rr), r(yc), r(Af), r(hf), r(mx), r(Ua), r(jx), r(Tf), r(uc), r(Jf), r(wo), r(_o), r(tx), r(Vf), r(xf), r(Pf), r(xx), r(ca), r(Qa), r(ac), r(pc), r(Ya), r(Ko), r(wf), r(Ba), r(ro), r(mi), r(nx), r(rx), r(Ka), r(mf), r(lo), r(bc), r(Ec), r($f), r(zf), r(qa), r(Df), r(uo), r(co), r(lc), r(ra), r(So), r(Va), r(Qo), r(Qu), r(Ce), r(mo), r(_x), r(Wu), r(vx), r(qf), r(Fc), r(df), r(Kx), r(Fx), r(Po), r(hc), r(D7), r(ha), r(Ha), r(Zf), r(Qx), r(Ea), r(Lf), r(Aa), r(F7), r(ua), r(xo), r(oa), r(dx), r(Zx), r(Vx), r(Jo), r(ja), r(Hf), r(Ao), r(sx), r(Of), r(Dx), r(fa), r(Zo), r(Sf), r(Ca), r(tc), r(Da), r(Oa), r(Bf), r(cc), r(fx), r(wc), r(au), r(Ia), r(ia), r(zx), r(ku)], az = [0, r("first_leading"), r("last_trailing")], oz = [0, 0];
            di(11, sl, oX), di(10, Fn, TU), di(9, [St, r(gY), jX], gY), di(8, uz, $U), di(7, tz, BY), di(6, Jt, QU), di(5, [St, r(iY), -6], iY), di(4, [St, r(DH), -5], DH), di(3, eN, sH), di(2, q7, LH), di(1, nz, MH), di(0, rN, TX);
            var ki0 = r("output_substring"), wi0 = r("%.12g"), Ei0 = r(Ra), Si0 = r(Mi), gi0 = r(Pi), Fi0 = r(oY), Ti0 = r("\\'"), Oi0 = r("\\b"), Ii0 = r("\\t"), Ai0 = r("\\n"), Ni0 = r("\\r"), Ci0 = r("List.iter2"), Pi0 = r("tl"), Di0 = r("hd"), Li0 = r("String.blit / Bytes.blit_string"), Ri0 = r("Bytes.blit"), ji0 = r("String.sub / Bytes.sub"), Gi0 = r("Array.blit"), Mi0 = r("Array.sub"), Bi0 = r("Map.remove_min_elt"), qi0 = [0, 0, 0, 0], Ui0 = [0, r("map.ml"), 400, 10], Hi0 = [0, 0, 0], Xi0 = r(n6), Yi0 = r(n6), Vi0 = r(n6), zi0 = r(n6), Ki0 = r("Stdlib.Queue.Empty"), Wi0 = r("CamlinternalLazy.Undefined"), Ji0 = r("Buffer.add_substring/add_subbytes"), $i0 = r("Buffer.add: cannot grow buffer"), Zi0 = [0, r(HU), 93, 2], Qi0 = [0, r(HU), 94, 2], rf0 = r("Buffer.sub"), ef0 = r("%c"), nf0 = r("%s"), tf0 = r(lX), uf0 = r(XY), if0 = r(vH), ff0 = r(JH), xf0 = r("%f"), af0 = r(Cn), of0 = r("%{"), cf0 = r("%}"), sf0 = r("%("), vf0 = r("%)"), lf0 = r(C0), bf0 = r("%t"), pf0 = r("%?"), mf0 = r("%r"), _f0 = r("%_r"), yf0 = [0, r(ou), 850, 23], df0 = [0, r(ou), 814, 21], hf0 = [0, r(ou), 815, 21], kf0 = [0, r(ou), 818, 21], wf0 = [0, r(ou), 819, 21], Ef0 = [0, r(ou), 822, 19], Sf0 = [0, r(ou), 823, 19], gf0 = [0, r(ou), 826, 22], Ff0 = [0, r(ou), 827, 22], Tf0 = [0, r(ou), 831, 30], Of0 = [0, r(ou), 832, 30], If0 = [0, r(ou), 836, 26], Af0 = [0, r(ou), 837, 26], Nf0 = [0, r(ou), 846, 28], Cf0 = [0, r(ou), 847, 28], Pf0 = [0, r(ou), 851, 23], Df0 = r(TY), Lf0 = [0, r(ou), 1558, 4], Rf0 = r("Printf: bad conversion %["), jf0 = [0, r(ou), 1626, 39], Gf0 = [0, r(ou), 1649, 31], Mf0 = [0, r(ou), 1650, 31], Bf0 = r("Printf: bad conversion %_"), qf0 = r(IY), Uf0 = r(dY), Hf0 = r(IY), Xf0 = r(dY), Yf0 = [0, [11, r("invalid box description "), [3, 0, 0]], r("invalid box description %S")], Vf0 = r(C), zf0 = [0, 0, 4], Kf0 = r(C), Wf0 = r(gX), Jf0 = r("h"), $f0 = r("hov"), Zf0 = r("hv"), Qf0 = r(hV), rx0 = r(bw), ex0 = r("neg_infinity"), nx0 = r(kU), tx0 = r(Ra), ux0 = r("%+nd"), ix0 = r("% nd"), fx0 = r("%+ni"), xx0 = r("% ni"), ax0 = r("%nx"), ox0 = r("%#nx"), cx0 = r("%nX"), sx0 = r("%#nX"), vx0 = r("%no"), lx0 = r("%#no"), bx0 = r("%nd"), px0 = r(vH), mx0 = r("%nu"), _x0 = r("%+ld"), yx0 = r("% ld"), dx0 = r("%+li"), hx0 = r("% li"), kx0 = r("%lx"), wx0 = r("%#lx"), Ex0 = r("%lX"), Sx0 = r("%#lX"), gx0 = r("%lo"), Fx0 = r("%#lo"), Tx0 = r("%ld"), Ox0 = r(XY), Ix0 = r("%lu"), Ax0 = r("%+Ld"), Nx0 = r("% Ld"), Cx0 = r("%+Li"), Px0 = r("% Li"), Dx0 = r("%Lx"), Lx0 = r("%#Lx"), Rx0 = r("%LX"), jx0 = r("%#LX"), Gx0 = r("%Lo"), Mx0 = r("%#Lo"), Bx0 = r("%Ld"), qx0 = r(JH), Ux0 = r("%Lu"), Hx0 = r("%+d"), Xx0 = r("% d"), Yx0 = r("%+i"), Vx0 = r("% i"), zx0 = r("%x"), Kx0 = r("%#x"), Wx0 = r("%X"), Jx0 = r("%#X"), $x0 = r("%o"), Zx0 = r("%#o"), Qx0 = r(N2), ra0 = r(lX), ea0 = r(TY), na0 = r(z), ta0 = r("@}"), ua0 = r("@?"), ia0 = r(`@
`), fa0 = r("@."), xa0 = r("@@"), aa0 = r("@%"), oa0 = r(AX), ca0 = r("CamlinternalFormat.Type_mismatch"), sa0 = r(C), va0 = [0, [11, r(nX), [2, 0, [2, 0, 0]]], r(", %s%s")], la0 = [0, [11, r(kh), [2, 0, [12, 10, 0]]], r(CU)], ba0 = [0, [11, r("Fatal error in uncaught exception handler: exception "), [2, 0, [12, 10, 0]]], r(`Fatal error in uncaught exception handler: exception %s
`)], pa0 = r("Fatal error: out of memory in uncaught exception handler"), ma0 = [0, [11, r(kh), [2, 0, [12, 10, 0]]], r(CU)], _a0 = [0, [2, 0, [12, 10, 0]], r(`%s
`)], ya0 = [0, [11, r(RY), 0], r(RY)], da0 = r("Raised at"), ha0 = r("Re-raised at"), ka0 = r("Raised by primitive operation at"), wa0 = r("Called from"), Ea0 = r(" (inlined)"), Sa0 = r(C), ga0 = [0, [2, 0, [12, 32, [2, 0, [11, r(' in file "'), [2, 0, [12, 34, [2, 0, [11, r(", line "), [4, 0, 0, 0, [11, r(EH), hi0]]]]]]]]]], r('%s %s in file "%s"%s, line %d, characters %d-%d')], Fa0 = [0, [2, 0, [11, r(" unknown location"), 0]], r("%s unknown location")], Ta0 = r("Out of memory"), Oa0 = r("Stack overflow"), Ia0 = r("Pattern matching failed"), Aa0 = r("Assertion failed"), Na0 = r("Undefined recursive module"), Ca0 = [0, [12, 40, [2, 0, [2, 0, [12, 41, 0]]]], r("(%s%s)")], Pa0 = r(C), Da0 = r(C), La0 = [0, [12, 40, [2, 0, [12, 41, 0]]], r("(%s)")], Ra0 = [0, [4, 0, 0, 0, 0], r(N2)], ja0 = [0, [3, 0, 0], r(zt)], Ga0 = r(bv), Ma0 = [0, r(C), r(`(Cannot print locations:
 bytecode executable program file not found)`), r(`(Cannot print locations:
 bytecode executable program file appears to be corrupt)`), r(`(Cannot print locations:
 bytecode executable program file has wrong magic number)`), r(`(Cannot print locations:
 bytecode executable program file cannot be opened;
 -- too many open files. Try running with OCAMLRUNPARAM=b=2)`)], Ba0 = [3, 0, 3], qa0 = r(Ra), Ua0 = r(cv), Ha0 = r("</"), Xa0 = r(C), Ya0 = r(cv), Va0 = r(g3), za0 = r(C), Ka0 = r(UI), Wa0 = r(C), Ja0 = r(C), $a0 = r(C), Za0 = r(C), Qa0 = [0, r(C)], ro0 = r(C), eo0 = r(C), no0 = r(C), to0 = r(C), uo0 = [0, r(C), 0, r(C)], io0 = r(C), fo0 = r("Stdlib.Format.String_tag"), xo0 = [0, r("camlinternalOO.ml"), 281, 50], ao0 = r(C), oo0 = [0, r(hY), 72, 5], co0 = [0, r(hY), 81, 2], so0 = r("CamlinternalMod.update_mod: not a module"), vo0 = r("CamlinternalMod.init_mod: not a module"), lo0 = r("TMPDIR"), bo0 = r("TEMP"), po0 = r(UU), mo0 = r("Win32"), _o0 = [0, r("src/wtf8.ml"), 65, 9], yo0 = r("Js_of_ocaml__Js.Error"), do0 = r($O), ho0 = [0, [15, 0], r(C0)], ko0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wo0 = r(Yr), Eo0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], So0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], go0 = r("Flow_ast.Program.statements"), Fo0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], To0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Oo0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Io0 = [0, [17, 0, 0], r(z)], Ao0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], No0 = r(Xr), Co0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Po0 = r(ur), Do0 = r(Z0), Lo0 = r(tr), Ro0 = [0, [17, 0, 0], r(z)], jo0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Go0 = r("all_comments"), Mo0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Bo0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], qo0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Uo0 = [0, [17, 0, 0], r(z)], Ho0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Xo0 = [0, [15, 0], r(C0)], Yo0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Vo0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], zo0 = [0, [17, 0, [12, 41, 0]], r(h0)], Ko0 = [0, [15, 0], r(C0)], Wo0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Function.BodyBlock"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Function.BodyBlock@ ")], Jo0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], $o0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Zo0 = [0, [17, 0, [12, 41, 0]], r(h0)], Qo0 = [0, [17, 0, [12, 41, 0]], r(h0)], rc0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Function.BodyExpression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Function.BodyExpression@ ")], ec0 = [0, [17, 0, [12, 41, 0]], r(h0)], nc0 = [0, [15, 0], r(C0)], tc0 = r(Yr), uc0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ic0 = r("Flow_ast.Function.id"), fc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xc0 = r(ur), ac0 = r(Z0), oc0 = r(tr), cc0 = [0, [17, 0, 0], r(z)], sc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], vc0 = r(Lt), lc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bc0 = [0, [17, 0, 0], r(z)], pc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mc0 = r($n), _c0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yc0 = [0, [17, 0, 0], r(z)], dc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hc0 = r(Os), kc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wc0 = [0, [9, 0, 0], r(Cn)], Ec0 = [0, [17, 0, 0], r(z)], Sc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], gc0 = r(G7), Fc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Tc0 = [0, [9, 0, 0], r(Cn)], Oc0 = [0, [17, 0, 0], r(z)], Ic0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ac0 = r(Qu), Nc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Cc0 = r(ur), Pc0 = r(Z0), Dc0 = r(tr), Lc0 = [0, [17, 0, 0], r(z)], Rc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jc0 = r(Wu), Gc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Mc0 = [0, [17, 0, 0], r(z)], Bc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qc0 = r(sv), Uc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Hc0 = r(ur), Xc0 = r(Z0), Yc0 = r(tr), Vc0 = [0, [17, 0, 0], r(z)], zc0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Kc0 = r(Xr), Wc0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jc0 = r(ur), $c0 = r(Z0), Zc0 = r(tr), Qc0 = [0, [17, 0, 0], r(z)], rs0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], es0 = r("sig_loc"), ns0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ts0 = [0, [17, 0, 0], r(z)], us0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], is0 = [0, [15, 0], r(C0)], fs0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xs0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], as0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], os0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cs0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ss0 = r("Flow_ast.Function.Params.this_"), vs0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ls0 = r(ur), bs0 = r(Z0), ps0 = r(tr), ms0 = [0, [17, 0, 0], r(z)], _s0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ys0 = r(Lt), ds0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hs0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], ks0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], ws0 = [0, [17, 0, 0], r(z)], Es0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ss0 = r(ch), gs0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Fs0 = r(ur), Ts0 = r(Z0), Os0 = r(tr), Is0 = [0, [17, 0, 0], r(z)], As0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ns0 = r(Xr), Cs0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ps0 = r(ur), Ds0 = r(Z0), Ls0 = r(tr), Rs0 = [0, [17, 0, 0], r(z)], js0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Gs0 = [0, [15, 0], r(C0)], Ms0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Bs0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], qs0 = [0, [17, 0, [12, 41, 0]], r(h0)], Us0 = [0, [15, 0], r(C0)], Hs0 = r(Yr), Xs0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Ys0 = r("Flow_ast.Function.ThisParam.annot"), Vs0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zs0 = [0, [17, 0, 0], r(z)], Ks0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ws0 = r(Xr), Js0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $s0 = r(ur), Zs0 = r(Z0), Qs0 = r(tr), r10 = [0, [17, 0, 0], r(z)], e10 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], n10 = [0, [15, 0], r(C0)], t10 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], u10 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], i10 = [0, [17, 0, [12, 41, 0]], r(h0)], f10 = [0, [15, 0], r(C0)], x10 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], a10 = r("Flow_ast.Function.Param.argument"), o10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c10 = [0, [17, 0, 0], r(z)], s10 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], v10 = r(_i), l10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], b10 = r(ur), p10 = r(Z0), m10 = r(tr), _10 = [0, [17, 0, 0], r(z)], y10 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], d10 = [0, [15, 0], r(C0)], h10 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], k10 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], w10 = [0, [17, 0, [12, 41, 0]], r(h0)], E10 = [0, [15, 0], r(C0)], S10 = r(Yr), g10 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], F10 = r("Flow_ast.Function.RestParam.argument"), T10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], O10 = [0, [17, 0, 0], r(z)], I10 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], A10 = r(Xr), N10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], C10 = r(ur), P10 = r(Z0), D10 = r(tr), L10 = [0, [17, 0, 0], r(z)], R10 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], j10 = [0, [15, 0], r(C0)], G10 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], M10 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], B10 = [0, [17, 0, [12, 41, 0]], r(h0)], q10 = [0, [15, 0], r(C0)], U10 = r(Yr), H10 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], X10 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Y10 = r("Flow_ast.Class.id"), V10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], z10 = r(ur), K10 = r(Z0), W10 = r(tr), J10 = [0, [17, 0, 0], r(z)], $10 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Z10 = r($n), Q10 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rv0 = [0, [17, 0, 0], r(z)], ev0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nv0 = r(sv), tv0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uv0 = r(ur), iv0 = r(Z0), fv0 = r(tr), xv0 = [0, [17, 0, 0], r(z)], av0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ov0 = r(P7), cv0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sv0 = r(ur), vv0 = r(Z0), lv0 = r(tr), bv0 = [0, [17, 0, 0], r(z)], pv0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mv0 = r(gs), _v0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yv0 = r(ur), dv0 = r(Z0), hv0 = r(tr), kv0 = [0, [17, 0, 0], r(z)], wv0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ev0 = r("class_decorators"), Sv0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gv0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Fv0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Tv0 = [0, [17, 0, 0], r(z)], Ov0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Iv0 = r(Xr), Av0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Nv0 = r(ur), Cv0 = r(Z0), Pv0 = r(tr), Dv0 = [0, [17, 0, 0], r(z)], Lv0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Rv0 = [0, [15, 0], r(C0)], jv0 = r(Yr), Gv0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Mv0 = r("Flow_ast.Class.Decorator.expression"), Bv0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], qv0 = [0, [17, 0, 0], r(z)], Uv0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Hv0 = r(Xr), Xv0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Yv0 = r(ur), Vv0 = r(Z0), zv0 = r(tr), Kv0 = [0, [17, 0, 0], r(z)], Wv0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Jv0 = [0, [15, 0], r(C0)], $v0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Zv0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Qv0 = [0, [17, 0, [12, 41, 0]], r(h0)], r20 = [0, [15, 0], r(C0)], e20 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Class.Body.Method"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Class.Body.Method@ ")], n20 = [0, [17, 0, [12, 41, 0]], r(h0)], t20 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Class.Body.Property"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Class.Body.Property@ ")], u20 = [0, [17, 0, [12, 41, 0]], r(h0)], i20 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Class.Body.PrivateField"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Class.Body.PrivateField@ ")], f20 = [0, [17, 0, [12, 41, 0]], r(h0)], x20 = [0, [15, 0], r(C0)], a20 = r(Yr), o20 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], c20 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], s20 = r("Flow_ast.Class.Body.body"), v20 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], l20 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], b20 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], p20 = [0, [17, 0, 0], r(z)], m20 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _20 = r(Xr), y20 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], d20 = r(ur), h20 = r(Z0), k20 = r(tr), w20 = [0, [17, 0, 0], r(z)], E20 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], S20 = [0, [15, 0], r(C0)], g20 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], F20 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], T20 = [0, [17, 0, [12, 41, 0]], r(h0)], O20 = [0, [15, 0], r(C0)], I20 = r(Yr), A20 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], N20 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], C20 = r("Flow_ast.Class.Implements.interfaces"), P20 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], D20 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], L20 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], R20 = [0, [17, 0, 0], r(z)], j20 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], G20 = r(Xr), M20 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], B20 = r(ur), q20 = r(Z0), U20 = r(tr), H20 = [0, [17, 0, 0], r(z)], X20 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Y20 = [0, [15, 0], r(C0)], V20 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], z20 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], K20 = [0, [17, 0, [12, 41, 0]], r(h0)], W20 = [0, [15, 0], r(C0)], J20 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], $20 = r("Flow_ast.Class.Implements.Interface.id"), Z20 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Q20 = [0, [17, 0, 0], r(z)], rl0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], el0 = r(Z2), nl0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], tl0 = r(ur), ul0 = r(Z0), il0 = r(tr), fl0 = [0, [17, 0, 0], r(z)], xl0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], al0 = [0, [15, 0], r(C0)], ol0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], cl0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], sl0 = [0, [17, 0, [12, 41, 0]], r(h0)], vl0 = [0, [15, 0], r(C0)], ll0 = r(Yr), bl0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], pl0 = r("Flow_ast.Class.Extends.expr"), ml0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _l0 = [0, [17, 0, 0], r(z)], yl0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dl0 = r(Z2), hl0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kl0 = r(ur), wl0 = r(Z0), El0 = r(tr), Sl0 = [0, [17, 0, 0], r(z)], gl0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Fl0 = r(Xr), Tl0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ol0 = r(ur), Il0 = r(Z0), Al0 = r(tr), Nl0 = [0, [17, 0, 0], r(z)], Cl0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Pl0 = [0, [15, 0], r(C0)], Dl0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Ll0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Rl0 = [0, [17, 0, [12, 41, 0]], r(h0)], jl0 = [0, [15, 0], r(C0)], Gl0 = r(Yr), Ml0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Bl0 = r("Flow_ast.Class.PrivateField.key"), ql0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ul0 = [0, [17, 0, 0], r(z)], Hl0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Xl0 = r(qn), Yl0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Vl0 = [0, [17, 0, 0], r(z)], zl0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Kl0 = r(rs), Wl0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jl0 = [0, [17, 0, 0], r(z)], $l0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Zl0 = r(eu), Ql0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rb0 = [0, [9, 0, 0], r(Cn)], eb0 = [0, [17, 0, 0], r(z)], nb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tb0 = r(au), ub0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ib0 = r(ur), fb0 = r(Z0), xb0 = r(tr), ab0 = [0, [17, 0, 0], r(z)], ob0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cb0 = r(Xr), sb0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vb0 = r(ur), lb0 = r(Z0), bb0 = r(tr), pb0 = [0, [17, 0, 0], r(z)], mb0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], _b0 = [0, [15, 0], r(C0)], yb0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], db0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], hb0 = [0, [17, 0, [12, 41, 0]], r(h0)], kb0 = [0, [15, 0], r(C0)], wb0 = r("Flow_ast.Class.Property.Uninitialized"), Eb0 = r("Flow_ast.Class.Property.Declared"), Sb0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Class.Property.Initialized"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Class.Property.Initialized@ ")], gb0 = [0, [17, 0, [12, 41, 0]], r(h0)], Fb0 = [0, [15, 0], r(C0)], Tb0 = r(Yr), Ob0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Ib0 = r("Flow_ast.Class.Property.key"), Ab0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Nb0 = [0, [17, 0, 0], r(z)], Cb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Pb0 = r(qn), Db0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Lb0 = [0, [17, 0, 0], r(z)], Rb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jb0 = r(rs), Gb0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Mb0 = [0, [17, 0, 0], r(z)], Bb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qb0 = r(eu), Ub0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Hb0 = [0, [9, 0, 0], r(Cn)], Xb0 = [0, [17, 0, 0], r(z)], Yb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Vb0 = r(au), zb0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Kb0 = r(ur), Wb0 = r(Z0), Jb0 = r(tr), $b0 = [0, [17, 0, 0], r(z)], Zb0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Qb0 = r(Xr), r40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], e40 = r(ur), n40 = r(Z0), t40 = r(tr), u40 = [0, [17, 0, 0], r(z)], i40 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], f40 = [0, [15, 0], r(C0)], x40 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], a40 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], o40 = [0, [17, 0, [12, 41, 0]], r(h0)], c40 = [0, [15, 0], r(C0)], s40 = r(Yr), v40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], l40 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], b40 = r("Flow_ast.Class.Method.kind"), p40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], m40 = [0, [17, 0, 0], r(z)], _40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], y40 = r(ii), d40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], h40 = [0, [17, 0, 0], r(z)], k40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], w40 = r(qn), E40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], S40 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], g40 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], F40 = [0, [17, 0, [12, 41, 0]], r(h0)], T40 = [0, [17, 0, 0], r(z)], O40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], I40 = r(eu), A40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], N40 = [0, [9, 0, 0], r(Cn)], C40 = [0, [17, 0, 0], r(z)], P40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], D40 = r(B_), L40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], R40 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], j40 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], G40 = [0, [17, 0, 0], r(z)], M40 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], B40 = r(Xr), q40 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], U40 = r(ur), H40 = r(Z0), X40 = r(tr), Y40 = [0, [17, 0, 0], r(z)], V40 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], z40 = [0, [15, 0], r(C0)], K40 = r("Flow_ast.Class.Method.Constructor"), W40 = r("Flow_ast.Class.Method.Method"), J40 = r("Flow_ast.Class.Method.Get"), $40 = r("Flow_ast.Class.Method.Set"), Z40 = [0, [15, 0], r(C0)], Q40 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], r80 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], e80 = [0, [17, 0, [12, 41, 0]], r(h0)], n80 = [0, [15, 0], r(C0)], t80 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], u80 = r("Flow_ast.Comment.kind"), i80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], f80 = [0, [17, 0, 0], r(z)], x80 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a80 = r("text"), o80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c80 = [0, [3, 0, 0], r(zt)], s80 = [0, [17, 0, 0], r(z)], v80 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], l80 = r("on_newline"), b80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], p80 = [0, [9, 0, 0], r(Cn)], m80 = [0, [17, 0, 0], r(z)], _80 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], y80 = [0, [15, 0], r(C0)], d80 = r("Flow_ast.Comment.Line"), h80 = r("Flow_ast.Comment.Block"), k80 = [0, [15, 0], r(C0)], w80 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], E80 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], S80 = [0, [17, 0, [12, 41, 0]], r(h0)], g80 = [0, [15, 0], r(C0)], F80 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object@ ")], T80 = [0, [17, 0, [12, 41, 0]], r(h0)], O80 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Array"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Array@ ")], I80 = [0, [17, 0, [12, 41, 0]], r(h0)], A80 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Identifier@ ")], N80 = [0, [17, 0, [12, 41, 0]], r(h0)], C80 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Expression@ ")], P80 = [0, [17, 0, [12, 41, 0]], r(h0)], D80 = [0, [15, 0], r(C0)], L80 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], R80 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], j80 = [0, [17, 0, [12, 41, 0]], r(h0)], G80 = [0, [15, 0], r(C0)], M80 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], B80 = r("Flow_ast.Pattern.Identifier.name"), q80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], U80 = [0, [17, 0, 0], r(z)], H80 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], X80 = r(rs), Y80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], V80 = [0, [17, 0, 0], r(z)], z80 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], K80 = r(Bu), W80 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], J80 = [0, [9, 0, 0], r(Cn)], $80 = [0, [17, 0, 0], r(z)], Z80 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Q80 = [0, [15, 0], r(C0)], r30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], e30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], n30 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], t30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], u30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], i30 = r("Flow_ast.Pattern.Array.elements"), f30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], x30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], a30 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], o30 = [0, [17, 0, 0], r(z)], c30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], s30 = r(rs), v30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], l30 = [0, [17, 0, 0], r(z)], b30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], p30 = r(Xr), m30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _30 = r(ur), y30 = r(Z0), d30 = r(tr), h30 = [0, [17, 0, 0], r(z)], k30 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], w30 = [0, [15, 0], r(C0)], E30 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Array.Element"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Array.Element@ ")], S30 = [0, [17, 0, [12, 41, 0]], r(h0)], g30 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Array.RestElement"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Array.RestElement@ ")], F30 = [0, [17, 0, [12, 41, 0]], r(h0)], T30 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Array.Hole"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Array.Hole@ ")], O30 = [0, [17, 0, [12, 41, 0]], r(h0)], I30 = [0, [15, 0], r(C0)], A30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], N30 = r("Flow_ast.Pattern.Array.Element.argument"), C30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], P30 = [0, [17, 0, 0], r(z)], D30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], L30 = r(_i), R30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], j30 = r(ur), G30 = r(Z0), M30 = r(tr), B30 = [0, [17, 0, 0], r(z)], q30 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], U30 = [0, [15, 0], r(C0)], H30 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], X30 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Y30 = [0, [17, 0, [12, 41, 0]], r(h0)], V30 = [0, [15, 0], r(C0)], z30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], K30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], W30 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], J30 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $30 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Z30 = r("Flow_ast.Pattern.Object.properties"), Q30 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], r60 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], e60 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], n60 = [0, [17, 0, 0], r(z)], t60 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], u60 = r(rs), i60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], f60 = [0, [17, 0, 0], r(z)], x60 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a60 = r(Xr), o60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c60 = r(ur), s60 = r(Z0), v60 = r(tr), l60 = [0, [17, 0, 0], r(z)], b60 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], p60 = [0, [15, 0], r(C0)], m60 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object.Property"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object.Property@ ")], _60 = [0, [17, 0, [12, 41, 0]], r(h0)], y60 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object.RestElement"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object.RestElement@ ")], d60 = [0, [17, 0, [12, 41, 0]], r(h0)], h60 = [0, [15, 0], r(C0)], k60 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], w60 = r("Flow_ast.Pattern.Object.Property.key"), E60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], S60 = [0, [17, 0, 0], r(z)], g60 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], F60 = r(mi), T60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], O60 = [0, [17, 0, 0], r(z)], I60 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], A60 = r(_i), N60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], C60 = r(ur), P60 = r(Z0), D60 = r(tr), L60 = [0, [17, 0, 0], r(z)], R60 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], j60 = r(x6), G60 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], M60 = [0, [9, 0, 0], r(Cn)], B60 = [0, [17, 0, 0], r(z)], q60 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], U60 = [0, [15, 0], r(C0)], H60 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], X60 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Y60 = [0, [17, 0, [12, 41, 0]], r(h0)], V60 = [0, [15, 0], r(C0)], z60 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object.Property.Literal"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object.Property.Literal@ ")], K60 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], W60 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], J60 = [0, [17, 0, [12, 41, 0]], r(h0)], $60 = [0, [17, 0, [12, 41, 0]], r(h0)], Z60 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object.Property.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object.Property.Identifier@ ")], Q60 = [0, [17, 0, [12, 41, 0]], r(h0)], rp0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Pattern.Object.Property.Computed"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Pattern.Object.Property.Computed@ ")], ep0 = [0, [17, 0, [12, 41, 0]], r(h0)], np0 = [0, [15, 0], r(C0)], tp0 = r(Yr), up0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ip0 = r("Flow_ast.Pattern.RestElement.argument"), fp0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xp0 = [0, [17, 0, 0], r(z)], ap0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], op0 = r(Xr), cp0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sp0 = r(ur), vp0 = r(Z0), lp0 = r(tr), bp0 = [0, [17, 0, 0], r(z)], pp0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], mp0 = [0, [15, 0], r(C0)], _p0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], yp0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], dp0 = [0, [17, 0, [12, 41, 0]], r(h0)], hp0 = [0, [15, 0], r(C0)], kp0 = r(Yr), wp0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ep0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Sp0 = r("Flow_ast.JSX.frag_opening_element"), gp0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Fp0 = [0, [17, 0, 0], r(z)], Tp0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Op0 = r("frag_closing_element"), Ip0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ap0 = [0, [17, 0, 0], r(z)], Np0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Cp0 = r("frag_children"), Pp0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Dp0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Lp0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Rp0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], jp0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Gp0 = [0, [17, 0, [12, 41, 0]], r(h0)], Mp0 = [0, [17, 0, 0], r(z)], Bp0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qp0 = r("frag_comments"), Up0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Hp0 = r(ur), Xp0 = r(Z0), Yp0 = r(tr), Vp0 = [0, [17, 0, 0], r(z)], zp0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Kp0 = [0, [15, 0], r(C0)], Wp0 = r(Yr), Jp0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $p0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Zp0 = r("Flow_ast.JSX.opening_element"), Qp0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], r50 = [0, [17, 0, 0], r(z)], e50 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], n50 = r("closing_element"), t50 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], u50 = r(ur), i50 = r(Z0), f50 = r(tr), x50 = [0, [17, 0, 0], r(z)], a50 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], o50 = r(qe), c50 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], s50 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], v50 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], l50 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], b50 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], p50 = [0, [17, 0, [12, 41, 0]], r(h0)], m50 = [0, [17, 0, 0], r(z)], _50 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], y50 = r(Xr), d50 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], h50 = r(ur), k50 = r(Z0), w50 = r(tr), E50 = [0, [17, 0, 0], r(z)], S50 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], g50 = [0, [15, 0], r(C0)], F50 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Element"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Element@ ")], T50 = [0, [17, 0, [12, 41, 0]], r(h0)], O50 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Fragment"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Fragment@ ")], I50 = [0, [17, 0, [12, 41, 0]], r(h0)], A50 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.ExpressionContainer"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.ExpressionContainer@ ")], N50 = [0, [17, 0, [12, 41, 0]], r(h0)], C50 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.SpreadChild"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.SpreadChild@ ")], P50 = [0, [17, 0, [12, 41, 0]], r(h0)], D50 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Text"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Text@ ")], L50 = [0, [17, 0, [12, 41, 0]], r(h0)], R50 = [0, [15, 0], r(C0)], j50 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], G50 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], M50 = [0, [17, 0, [12, 41, 0]], r(h0)], B50 = [0, [15, 0], r(C0)], q50 = r(Yr), U50 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], H50 = r("Flow_ast.JSX.SpreadChild.expression"), X50 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Y50 = [0, [17, 0, 0], r(z)], V50 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], z50 = r(Xr), K50 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], W50 = r(ur), J50 = r(Z0), $50 = r(tr), Z50 = [0, [17, 0, 0], r(z)], Q50 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], rm0 = [0, [15, 0], r(C0)], em0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], nm0 = r("Flow_ast.JSX.Closing.name"), tm0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], um0 = [0, [17, 0, 0], r(z)], im0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], fm0 = [0, [15, 0], r(C0)], xm0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], am0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], om0 = [0, [17, 0, [12, 41, 0]], r(h0)], cm0 = [0, [15, 0], r(C0)], sm0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], vm0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], lm0 = r("Flow_ast.JSX.Opening.name"), bm0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pm0 = [0, [17, 0, 0], r(z)], mm0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _m0 = r("self_closing"), ym0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dm0 = [0, [9, 0, 0], r(Cn)], hm0 = [0, [17, 0, 0], r(z)], km0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wm0 = r(kY), Em0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Sm0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], gm0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Fm0 = [0, [17, 0, 0], r(z)], Tm0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Om0 = [0, [15, 0], r(C0)], Im0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Opening.Attribute"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Opening.Attribute@ ")], Am0 = [0, [17, 0, [12, 41, 0]], r(h0)], Nm0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Opening.SpreadAttribute"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Opening.SpreadAttribute@ ")], Cm0 = [0, [17, 0, [12, 41, 0]], r(h0)], Pm0 = [0, [15, 0], r(C0)], Dm0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Lm0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Rm0 = [0, [17, 0, [12, 41, 0]], r(h0)], jm0 = [0, [15, 0], r(C0)], Gm0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Identifier@ ")], Mm0 = [0, [17, 0, [12, 41, 0]], r(h0)], Bm0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.NamespacedName"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.NamespacedName@ ")], qm0 = [0, [17, 0, [12, 41, 0]], r(h0)], Um0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.MemberExpression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.MemberExpression@ ")], Hm0 = [0, [17, 0, [12, 41, 0]], r(h0)], Xm0 = [0, [15, 0], r(C0)], Ym0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Vm0 = r("Flow_ast.JSX.MemberExpression._object"), zm0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Km0 = [0, [17, 0, 0], r(z)], Wm0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Jm0 = r(Iv), $m0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Zm0 = [0, [17, 0, 0], r(z)], Qm0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], r90 = [0, [15, 0], r(C0)], e90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.MemberExpression.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.MemberExpression.Identifier@ ")], n90 = [0, [17, 0, [12, 41, 0]], r(h0)], t90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.MemberExpression.MemberExpression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.MemberExpression.MemberExpression@ ")], u90 = [0, [17, 0, [12, 41, 0]], r(h0)], i90 = [0, [15, 0], r(C0)], f90 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], x90 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], a90 = [0, [17, 0, [12, 41, 0]], r(h0)], o90 = [0, [15, 0], r(C0)], c90 = r(Yr), s90 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], v90 = r("Flow_ast.JSX.SpreadAttribute.argument"), l90 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], b90 = [0, [17, 0, 0], r(z)], p90 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], m90 = r(Xr), _90 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], y90 = r(ur), d90 = r(Z0), h90 = r(tr), k90 = [0, [17, 0, 0], r(z)], w90 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], E90 = [0, [15, 0], r(C0)], S90 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], g90 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], F90 = [0, [17, 0, [12, 41, 0]], r(h0)], T90 = [0, [15, 0], r(C0)], O90 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], I90 = r("Flow_ast.JSX.Attribute.name"), A90 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], N90 = [0, [17, 0, 0], r(z)], C90 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], P90 = r(qn), D90 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], L90 = r(ur), R90 = r(Z0), j90 = r(tr), G90 = [0, [17, 0, 0], r(z)], M90 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], B90 = [0, [15, 0], r(C0)], q90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Attribute.Literal ("), [17, [0, r(De), 0, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Attribute.Literal (@,")], U90 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], H90 = [0, [17, [0, r(De), 0, 0], [11, r(OX), [17, 0, 0]]], r(qU)], X90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Attribute.ExpressionContainer ("), [17, [0, r(De), 0, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Attribute.ExpressionContainer (@,")], Y90 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], V90 = [0, [17, [0, r(De), 0, 0], [11, r(OX), [17, 0, 0]]], r(qU)], z90 = [0, [15, 0], r(C0)], K90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Attribute.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Attribute.Identifier@ ")], W90 = [0, [17, 0, [12, 41, 0]], r(h0)], J90 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.Attribute.NamespacedName"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.Attribute.NamespacedName@ ")], $90 = [0, [17, 0, [12, 41, 0]], r(h0)], Z90 = [0, [15, 0], r(C0)], Q90 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], r_0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], e_0 = [0, [17, 0, [12, 41, 0]], r(h0)], n_0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], t_0 = r("Flow_ast.JSX.Text.value"), u_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], i_0 = [0, [3, 0, 0], r(zt)], f_0 = [0, [17, 0, 0], r(z)], x_0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a_0 = r(c7), o_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c_0 = [0, [3, 0, 0], r(zt)], s_0 = [0, [17, 0, 0], r(z)], v_0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], l_0 = [0, [15, 0], r(C0)], b_0 = [0, [15, 0], r(C0)], p_0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.JSX.ExpressionContainer.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.JSX.ExpressionContainer.Expression@ ")], m_0 = [0, [17, 0, [12, 41, 0]], r(h0)], __0 = r("Flow_ast.JSX.ExpressionContainer.EmptyExpression"), y_0 = [0, [15, 0], r(C0)], d_0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], h_0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], k_0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], w_0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], E_0 = r("Flow_ast.JSX.ExpressionContainer.expression"), S_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], g_0 = [0, [17, 0, 0], r(z)], F_0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], T_0 = r(Xr), O_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], I_0 = r(ur), A_0 = r(Z0), N_0 = r(tr), C_0 = [0, [17, 0, 0], r(z)], P_0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], D_0 = [0, [15, 0], r(C0)], L_0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], R_0 = r("Flow_ast.JSX.NamespacedName.namespace"), j_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], G_0 = [0, [17, 0, 0], r(z)], M_0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], B_0 = r(ui), q_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], U_0 = [0, [17, 0, 0], r(z)], H_0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], X_0 = [0, [15, 0], r(C0)], Y_0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], V_0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], z_0 = [0, [17, 0, [12, 41, 0]], r(h0)], K_0 = [0, [15, 0], r(C0)], W_0 = r(Yr), J_0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], $_0 = r("Flow_ast.JSX.Identifier.name"), Z_0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Q_0 = [0, [3, 0, 0], r(zt)], ry0 = [0, [17, 0, 0], r(z)], ey0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ny0 = r(Xr), ty0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uy0 = r(ur), iy0 = r(Z0), fy0 = r(tr), xy0 = [0, [17, 0, 0], r(z)], ay0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], oy0 = [0, [15, 0], r(C0)], cy0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], sy0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], vy0 = [0, [17, 0, [12, 41, 0]], r(h0)], ly0 = [0, [15, 0], r(C0)], by0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Array"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Array@ ")], py0 = [0, [17, 0, [12, 41, 0]], r(h0)], my0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.ArrowFunction"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.ArrowFunction@ ")], _y0 = [0, [17, 0, [12, 41, 0]], r(h0)], yy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Assignment"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Assignment@ ")], dy0 = [0, [17, 0, [12, 41, 0]], r(h0)], hy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Binary"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Binary@ ")], ky0 = [0, [17, 0, [12, 41, 0]], r(h0)], wy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Call"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Call@ ")], Ey0 = [0, [17, 0, [12, 41, 0]], r(h0)], Sy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Class"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Class@ ")], gy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Fy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Comprehension"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Comprehension@ ")], Ty0 = [0, [17, 0, [12, 41, 0]], r(h0)], Oy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Conditional"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Conditional@ ")], Iy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Ay0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Function"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Function@ ")], Ny0 = [0, [17, 0, [12, 41, 0]], r(h0)], Cy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Generator"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Generator@ ")], Py0 = [0, [17, 0, [12, 41, 0]], r(h0)], Dy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Identifier@ ")], Ly0 = [0, [17, 0, [12, 41, 0]], r(h0)], Ry0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Import"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Import@ ")], jy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Gy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.JSXElement"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.JSXElement@ ")], My0 = [0, [17, 0, [12, 41, 0]], r(h0)], By0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.JSXFragment"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.JSXFragment@ ")], qy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Uy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Literal"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Literal@ ")], Hy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Xy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Logical"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Logical@ ")], Yy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Vy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Member"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Member@ ")], zy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Ky0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.MetaProperty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.MetaProperty@ ")], Wy0 = [0, [17, 0, [12, 41, 0]], r(h0)], Jy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.New"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.New@ ")], $y0 = [0, [17, 0, [12, 41, 0]], r(h0)], Zy0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object@ ")], Qy0 = [0, [17, 0, [12, 41, 0]], r(h0)], rd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.OptionalCall"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.OptionalCall@ ")], ed0 = [0, [17, 0, [12, 41, 0]], r(h0)], nd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.OptionalMember"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.OptionalMember@ ")], td0 = [0, [17, 0, [12, 41, 0]], r(h0)], ud0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Sequence"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Sequence@ ")], id0 = [0, [17, 0, [12, 41, 0]], r(h0)], fd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Super"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Super@ ")], xd0 = [0, [17, 0, [12, 41, 0]], r(h0)], ad0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.TaggedTemplate"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.TaggedTemplate@ ")], od0 = [0, [17, 0, [12, 41, 0]], r(h0)], cd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.TemplateLiteral"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.TemplateLiteral@ ")], sd0 = [0, [17, 0, [12, 41, 0]], r(h0)], vd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.This"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.This@ ")], ld0 = [0, [17, 0, [12, 41, 0]], r(h0)], bd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.TypeCast"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.TypeCast@ ")], pd0 = [0, [17, 0, [12, 41, 0]], r(h0)], md0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Unary"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Unary@ ")], _d0 = [0, [17, 0, [12, 41, 0]], r(h0)], yd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Update"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Update@ ")], dd0 = [0, [17, 0, [12, 41, 0]], r(h0)], hd0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Yield"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Yield@ ")], kd0 = [0, [17, 0, [12, 41, 0]], r(h0)], wd0 = [0, [15, 0], r(C0)], Ed0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Sd0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], gd0 = [0, [17, 0, [12, 41, 0]], r(h0)], Fd0 = [0, [15, 0], r(C0)], Td0 = r(Yr), Od0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Id0 = r("Flow_ast.Expression.Import.argument"), Ad0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Nd0 = [0, [17, 0, 0], r(z)], Cd0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Pd0 = r(Xr), Dd0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ld0 = r(ur), Rd0 = r(Z0), jd0 = r(tr), Gd0 = [0, [17, 0, 0], r(z)], Md0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Bd0 = [0, [15, 0], r(C0)], qd0 = r(Yr), Ud0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Hd0 = r("Flow_ast.Expression.Super.comments"), Xd0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Yd0 = r(ur), Vd0 = r(Z0), zd0 = r(tr), Kd0 = [0, [17, 0, 0], r(z)], Wd0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Jd0 = [0, [15, 0], r(C0)], $d0 = r(Yr), Zd0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Qd0 = r("Flow_ast.Expression.This.comments"), rh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eh0 = r(ur), nh0 = r(Z0), th0 = r(tr), uh0 = [0, [17, 0, 0], r(z)], ih0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], fh0 = [0, [15, 0], r(C0)], xh0 = r(Yr), ah0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], oh0 = r("Flow_ast.Expression.MetaProperty.meta"), ch0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sh0 = [0, [17, 0, 0], r(z)], vh0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lh0 = r(Iv), bh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ph0 = [0, [17, 0, 0], r(z)], mh0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _h0 = r(Xr), yh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dh0 = r(ur), hh0 = r(Z0), kh0 = r(tr), wh0 = [0, [17, 0, 0], r(z)], Eh0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Sh0 = [0, [15, 0], r(C0)], gh0 = r(Yr), Fh0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Th0 = r("Flow_ast.Expression.TypeCast.expression"), Oh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ih0 = [0, [17, 0, 0], r(z)], Ah0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Nh0 = r(rs), Ch0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ph0 = [0, [17, 0, 0], r(z)], Dh0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Lh0 = r(Xr), Rh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], jh0 = r(ur), Gh0 = r(Z0), Mh0 = r(tr), Bh0 = [0, [17, 0, 0], r(z)], qh0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Uh0 = [0, [15, 0], r(C0)], Hh0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Xh0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Yh0 = r("Flow_ast.Expression.Generator.blocks"), Vh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zh0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Kh0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Wh0 = [0, [17, 0, 0], r(z)], Jh0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $h0 = r(O4), Zh0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Qh0 = r(ur), rk0 = r(Z0), ek0 = r(tr), nk0 = [0, [17, 0, 0], r(z)], tk0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], uk0 = [0, [15, 0], r(C0)], ik0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], fk0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], xk0 = r("Flow_ast.Expression.Comprehension.blocks"), ak0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ok0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], ck0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], sk0 = [0, [17, 0, 0], r(z)], vk0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lk0 = r(O4), bk0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pk0 = r(ur), mk0 = r(Z0), _k0 = r(tr), yk0 = [0, [17, 0, 0], r(z)], dk0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], hk0 = [0, [15, 0], r(C0)], kk0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], wk0 = r("Flow_ast.Expression.Comprehension.Block.left"), Ek0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Sk0 = [0, [17, 0, 0], r(z)], gk0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Fk0 = r(Au), Tk0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ok0 = [0, [17, 0, 0], r(z)], Ik0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ak0 = r(j8), Nk0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ck0 = [0, [9, 0, 0], r(Cn)], Pk0 = [0, [17, 0, 0], r(z)], Dk0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Lk0 = [0, [15, 0], r(C0)], Rk0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], jk0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Gk0 = [0, [17, 0, [12, 41, 0]], r(h0)], Mk0 = [0, [15, 0], r(C0)], Bk0 = r(Yr), qk0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Uk0 = r("Flow_ast.Expression.Yield.argument"), Hk0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Xk0 = r(ur), Yk0 = r(Z0), Vk0 = r(tr), zk0 = [0, [17, 0, 0], r(z)], Kk0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Wk0 = r(Xr), Jk0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $k0 = r(ur), Zk0 = r(Z0), Qk0 = r(tr), rw0 = [0, [17, 0, 0], r(z)], ew0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nw0 = r(yY), tw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uw0 = [0, [9, 0, 0], r(Cn)], iw0 = [0, [17, 0, 0], r(z)], fw0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xw0 = r("result_out"), aw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ow0 = [0, [17, 0, 0], r(z)], cw0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], sw0 = [0, [15, 0], r(C0)], vw0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], lw0 = r("Flow_ast.Expression.OptionalMember.member"), bw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pw0 = [0, [17, 0, 0], r(z)], mw0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _w0 = r(yU), yw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dw0 = [0, [17, 0, 0], r(z)], hw0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], kw0 = r(Bu), ww0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ew0 = [0, [9, 0, 0], r(Cn)], Sw0 = [0, [17, 0, 0], r(z)], gw0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Fw0 = [0, [15, 0], r(C0)], Tw0 = r(Yr), Ow0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Iw0 = r("Flow_ast.Expression.Member._object"), Aw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Nw0 = [0, [17, 0, 0], r(z)], Cw0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Pw0 = r(Iv), Dw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Lw0 = [0, [17, 0, 0], r(z)], Rw0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jw0 = r(Xr), Gw0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Mw0 = r(ur), Bw0 = r(Z0), qw0 = r(tr), Uw0 = [0, [17, 0, 0], r(z)], Hw0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Xw0 = [0, [15, 0], r(C0)], Yw0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Member.PropertyIdentifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Member.PropertyIdentifier@ ")], Vw0 = [0, [17, 0, [12, 41, 0]], r(h0)], zw0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Member.PropertyPrivateName"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Member.PropertyPrivateName@ ")], Kw0 = [0, [17, 0, [12, 41, 0]], r(h0)], Ww0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Member.PropertyExpression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Member.PropertyExpression@ ")], Jw0 = [0, [17, 0, [12, 41, 0]], r(h0)], $w0 = [0, [15, 0], r(C0)], Zw0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Qw0 = r("Flow_ast.Expression.OptionalCall.call"), rE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eE0 = [0, [17, 0, 0], r(z)], nE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tE0 = r(yU), uE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], iE0 = [0, [17, 0, 0], r(z)], fE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xE0 = r(Bu), aE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], oE0 = [0, [9, 0, 0], r(Cn)], cE0 = [0, [17, 0, 0], r(z)], sE0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], vE0 = [0, [15, 0], r(C0)], lE0 = r(Yr), bE0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], pE0 = r("Flow_ast.Expression.Call.callee"), mE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _E0 = [0, [17, 0, 0], r(z)], yE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dE0 = r(Z2), hE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kE0 = r(ur), wE0 = r(Z0), EE0 = r(tr), SE0 = [0, [17, 0, 0], r(z)], gE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], FE0 = r(C2), TE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], OE0 = [0, [17, 0, 0], r(z)], IE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], AE0 = r(Xr), NE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], CE0 = r(ur), PE0 = r(Z0), DE0 = r(tr), LE0 = [0, [17, 0, 0], r(z)], RE0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], jE0 = [0, [15, 0], r(C0)], GE0 = r(Yr), ME0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], BE0 = r("Flow_ast.Expression.New.callee"), qE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], UE0 = [0, [17, 0, 0], r(z)], HE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], XE0 = r(Z2), YE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], VE0 = r(ur), zE0 = r(Z0), KE0 = r(tr), WE0 = [0, [17, 0, 0], r(z)], JE0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $E0 = r(C2), ZE0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], QE0 = r(ur), rS0 = r(Z0), eS0 = r(tr), nS0 = [0, [17, 0, 0], r(z)], tS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uS0 = r(Xr), iS0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fS0 = r(ur), xS0 = r(Z0), aS0 = r(tr), oS0 = [0, [17, 0, 0], r(z)], cS0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], sS0 = [0, [15, 0], r(C0)], vS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lS0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], bS0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], pS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mS0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], _S0 = r("Flow_ast.Expression.ArgList.arguments"), yS0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dS0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], hS0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], kS0 = [0, [17, 0, 0], r(z)], wS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ES0 = r(Xr), SS0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gS0 = r(ur), FS0 = r(Z0), TS0 = r(tr), OS0 = [0, [17, 0, 0], r(z)], IS0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], AS0 = [0, [15, 0], r(C0)], NS0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], CS0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], PS0 = [0, [17, 0, [12, 41, 0]], r(h0)], DS0 = [0, [15, 0], r(C0)], LS0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Expression@ ")], RS0 = [0, [17, 0, [12, 41, 0]], r(h0)], jS0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Spread"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Spread@ ")], GS0 = [0, [17, 0, [12, 41, 0]], r(h0)], MS0 = [0, [15, 0], r(C0)], BS0 = r(Yr), qS0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], US0 = r("Flow_ast.Expression.Conditional.test"), HS0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], XS0 = [0, [17, 0, 0], r(z)], YS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], VS0 = r(kv), zS0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], KS0 = [0, [17, 0, 0], r(z)], WS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], JS0 = r(_3), $S0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ZS0 = [0, [17, 0, 0], r(z)], QS0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], rg0 = r(Xr), eg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ng0 = r(ur), tg0 = r(Z0), ug0 = r(tr), ig0 = [0, [17, 0, 0], r(z)], fg0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], xg0 = [0, [15, 0], r(C0)], ag0 = r(Yr), og0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], cg0 = r("Flow_ast.Expression.Logical.operator"), sg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vg0 = [0, [17, 0, 0], r(z)], lg0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bg0 = r(bi), pg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mg0 = [0, [17, 0, 0], r(z)], _g0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], yg0 = r(Au), dg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hg0 = [0, [17, 0, 0], r(z)], kg0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wg0 = r(Xr), Eg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Sg0 = r(ur), gg0 = r(Z0), Fg0 = r(tr), Tg0 = [0, [17, 0, 0], r(z)], Og0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Ig0 = [0, [15, 0], r(C0)], Ag0 = r("Flow_ast.Expression.Logical.Or"), Ng0 = r("Flow_ast.Expression.Logical.And"), Cg0 = r("Flow_ast.Expression.Logical.NullishCoalesce"), Pg0 = [0, [15, 0], r(C0)], Dg0 = r(Yr), Lg0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Rg0 = r("Flow_ast.Expression.Update.operator"), jg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Gg0 = [0, [17, 0, 0], r(z)], Mg0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Bg0 = r(l7), qg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ug0 = [0, [17, 0, 0], r(z)], Hg0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Xg0 = r(XE), Yg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Vg0 = [0, [9, 0, 0], r(Cn)], zg0 = [0, [17, 0, 0], r(z)], Kg0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Wg0 = r(Xr), Jg0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $g0 = r(ur), Zg0 = r(Z0), Qg0 = r(tr), rF0 = [0, [17, 0, 0], r(z)], eF0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], nF0 = [0, [15, 0], r(C0)], tF0 = r("Flow_ast.Expression.Update.Decrement"), uF0 = r("Flow_ast.Expression.Update.Increment"), iF0 = [0, [15, 0], r(C0)], fF0 = r(Yr), xF0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], aF0 = r("Flow_ast.Expression.Assignment.operator"), oF0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], cF0 = r(ur), sF0 = r(Z0), vF0 = r(tr), lF0 = [0, [17, 0, 0], r(z)], bF0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], pF0 = r(bi), mF0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _F0 = [0, [17, 0, 0], r(z)], yF0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dF0 = r(Au), hF0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kF0 = [0, [17, 0, 0], r(z)], wF0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], EF0 = r(Xr), SF0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gF0 = r(ur), FF0 = r(Z0), TF0 = r(tr), OF0 = [0, [17, 0, 0], r(z)], IF0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], AF0 = [0, [15, 0], r(C0)], NF0 = r("Flow_ast.Expression.Assignment.PlusAssign"), CF0 = r("Flow_ast.Expression.Assignment.MinusAssign"), PF0 = r("Flow_ast.Expression.Assignment.MultAssign"), DF0 = r("Flow_ast.Expression.Assignment.ExpAssign"), LF0 = r("Flow_ast.Expression.Assignment.DivAssign"), RF0 = r("Flow_ast.Expression.Assignment.ModAssign"), jF0 = r("Flow_ast.Expression.Assignment.LShiftAssign"), GF0 = r("Flow_ast.Expression.Assignment.RShiftAssign"), MF0 = r("Flow_ast.Expression.Assignment.RShift3Assign"), BF0 = r("Flow_ast.Expression.Assignment.BitOrAssign"), qF0 = r("Flow_ast.Expression.Assignment.BitXorAssign"), UF0 = r("Flow_ast.Expression.Assignment.BitAndAssign"), HF0 = r("Flow_ast.Expression.Assignment.NullishAssign"), XF0 = r("Flow_ast.Expression.Assignment.AndAssign"), YF0 = r("Flow_ast.Expression.Assignment.OrAssign"), VF0 = [0, [15, 0], r(C0)], zF0 = r(Yr), KF0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], WF0 = r("Flow_ast.Expression.Binary.operator"), JF0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $F0 = [0, [17, 0, 0], r(z)], ZF0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], QF0 = r(bi), rT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eT0 = [0, [17, 0, 0], r(z)], nT0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tT0 = r(Au), uT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], iT0 = [0, [17, 0, 0], r(z)], fT0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xT0 = r(Xr), aT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], oT0 = r(ur), cT0 = r(Z0), sT0 = r(tr), vT0 = [0, [17, 0, 0], r(z)], lT0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], bT0 = [0, [15, 0], r(C0)], pT0 = r("Flow_ast.Expression.Binary.Equal"), mT0 = r("Flow_ast.Expression.Binary.NotEqual"), _T0 = r("Flow_ast.Expression.Binary.StrictEqual"), yT0 = r("Flow_ast.Expression.Binary.StrictNotEqual"), dT0 = r("Flow_ast.Expression.Binary.LessThan"), hT0 = r("Flow_ast.Expression.Binary.LessThanEqual"), kT0 = r("Flow_ast.Expression.Binary.GreaterThan"), wT0 = r("Flow_ast.Expression.Binary.GreaterThanEqual"), ET0 = r("Flow_ast.Expression.Binary.LShift"), ST0 = r("Flow_ast.Expression.Binary.RShift"), gT0 = r("Flow_ast.Expression.Binary.RShift3"), FT0 = r("Flow_ast.Expression.Binary.Plus"), TT0 = r("Flow_ast.Expression.Binary.Minus"), OT0 = r("Flow_ast.Expression.Binary.Mult"), IT0 = r("Flow_ast.Expression.Binary.Exp"), AT0 = r("Flow_ast.Expression.Binary.Div"), NT0 = r("Flow_ast.Expression.Binary.Mod"), CT0 = r("Flow_ast.Expression.Binary.BitOr"), PT0 = r("Flow_ast.Expression.Binary.Xor"), DT0 = r("Flow_ast.Expression.Binary.BitAnd"), LT0 = r("Flow_ast.Expression.Binary.In"), RT0 = r("Flow_ast.Expression.Binary.Instanceof"), jT0 = [0, [15, 0], r(C0)], GT0 = r(Yr), MT0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], BT0 = r("Flow_ast.Expression.Unary.operator"), qT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], UT0 = [0, [17, 0, 0], r(z)], HT0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], XT0 = r(l7), YT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], VT0 = [0, [17, 0, 0], r(z)], zT0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], KT0 = r(Xr), WT0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], JT0 = r(ur), $T0 = r(Z0), ZT0 = r(tr), QT0 = [0, [17, 0, 0], r(z)], rO0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], eO0 = [0, [15, 0], r(C0)], nO0 = r("Flow_ast.Expression.Unary.Minus"), tO0 = r("Flow_ast.Expression.Unary.Plus"), uO0 = r("Flow_ast.Expression.Unary.Not"), iO0 = r("Flow_ast.Expression.Unary.BitNot"), fO0 = r("Flow_ast.Expression.Unary.Typeof"), xO0 = r("Flow_ast.Expression.Unary.Void"), aO0 = r("Flow_ast.Expression.Unary.Delete"), oO0 = r("Flow_ast.Expression.Unary.Await"), cO0 = [0, [15, 0], r(C0)], sO0 = r(Yr), vO0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], bO0 = r("Flow_ast.Expression.Sequence.expressions"), pO0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], _O0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], yO0 = [0, [17, 0, 0], r(z)], dO0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hO0 = r(Xr), kO0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wO0 = r(ur), EO0 = r(Z0), SO0 = r(tr), gO0 = [0, [17, 0, 0], r(z)], FO0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], TO0 = [0, [15, 0], r(C0)], OO0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], IO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], AO0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], NO0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], CO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], PO0 = r("Flow_ast.Expression.Object.properties"), DO0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], LO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], RO0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], jO0 = [0, [17, 0, 0], r(z)], GO0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], MO0 = r(Xr), BO0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], qO0 = r(ur), UO0 = r(Z0), HO0 = r(tr), XO0 = [0, [17, 0, 0], r(z)], YO0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], VO0 = [0, [15, 0], r(C0)], zO0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.Property@ ")], KO0 = [0, [17, 0, [12, 41, 0]], r(h0)], WO0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.SpreadProperty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.SpreadProperty@ ")], JO0 = [0, [17, 0, [12, 41, 0]], r(h0)], $O0 = [0, [15, 0], r(C0)], ZO0 = r(Yr), QO0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], rI0 = r("Flow_ast.Expression.Object.SpreadProperty.argument"), eI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], nI0 = [0, [17, 0, 0], r(z)], tI0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uI0 = r(Xr), iI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fI0 = r(ur), xI0 = r(Z0), aI0 = r(tr), oI0 = [0, [17, 0, 0], r(z)], cI0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], sI0 = [0, [15, 0], r(C0)], vI0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], lI0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], bI0 = [0, [17, 0, [12, 41, 0]], r(h0)], pI0 = [0, [15, 0], r(C0)], mI0 = r(Yr), _I0 = r(Yr), yI0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Init {"), [17, [0, r(De), 0, 0], 0]]], r("@[<2>Flow_ast.Expression.Object.Property.Init {@,")], dI0 = r(ii), hI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kI0 = [0, [17, 0, 0], r(z)], wI0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], EI0 = r(qn), SI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gI0 = [0, [17, 0, 0], r(z)], FI0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], TI0 = r(x6), OI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], II0 = [0, [9, 0, 0], r(Cn)], AI0 = [0, [17, 0, 0], r(z)], NI0 = [0, [17, 0, [12, br, 0]], r(V6)], CI0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Method {"), [17, [0, r(De), 0, 0], 0]]], r("@[<2>Flow_ast.Expression.Object.Property.Method {@,")], PI0 = r(ii), DI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], LI0 = [0, [17, 0, 0], r(z)], RI0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jI0 = r(qn), GI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], MI0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], BI0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], qI0 = [0, [17, 0, [12, 41, 0]], r(h0)], UI0 = [0, [17, 0, 0], r(z)], HI0 = [0, [17, 0, [12, br, 0]], r(V6)], XI0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Get {"), [17, [0, r(De), 0, 0], 0]]], r("@[<2>Flow_ast.Expression.Object.Property.Get {@,")], YI0 = r(ii), VI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zI0 = [0, [17, 0, 0], r(z)], KI0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], WI0 = r(qn), JI0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $I0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], ZI0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], QI0 = [0, [17, 0, [12, 41, 0]], r(h0)], rA0 = [0, [17, 0, 0], r(z)], eA0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nA0 = r(Xr), tA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uA0 = r(ur), iA0 = r(Z0), fA0 = r(tr), xA0 = [0, [17, 0, 0], r(z)], aA0 = [0, [17, 0, [12, br, 0]], r(V6)], oA0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Set {"), [17, [0, r(De), 0, 0], 0]]], r("@[<2>Flow_ast.Expression.Object.Property.Set {@,")], cA0 = r(ii), sA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vA0 = [0, [17, 0, 0], r(z)], lA0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bA0 = r(qn), pA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mA0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], _A0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], yA0 = [0, [17, 0, [12, 41, 0]], r(h0)], dA0 = [0, [17, 0, 0], r(z)], hA0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], kA0 = r(Xr), wA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], EA0 = r(ur), SA0 = r(Z0), gA0 = r(tr), FA0 = [0, [17, 0, 0], r(z)], TA0 = [0, [17, 0, [12, br, 0]], r(V6)], OA0 = [0, [15, 0], r(C0)], IA0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], AA0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], NA0 = [0, [17, 0, [12, 41, 0]], r(h0)], CA0 = [0, [15, 0], r(C0)], PA0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Literal"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.Property.Literal@ ")], DA0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], LA0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], RA0 = [0, [17, 0, [12, 41, 0]], r(h0)], jA0 = [0, [17, 0, [12, 41, 0]], r(h0)], GA0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.Property.Identifier@ ")], MA0 = [0, [17, 0, [12, 41, 0]], r(h0)], BA0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.PrivateName"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.Property.PrivateName@ ")], qA0 = [0, [17, 0, [12, 41, 0]], r(h0)], UA0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Object.Property.Computed"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Object.Property.Computed@ ")], HA0 = [0, [17, 0, [12, 41, 0]], r(h0)], XA0 = [0, [15, 0], r(C0)], YA0 = r(Yr), VA0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], zA0 = r("Flow_ast.Expression.TaggedTemplate.tag"), KA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], WA0 = [0, [17, 0, 0], r(z)], JA0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $A0 = r(OY), ZA0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], QA0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], rN0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], eN0 = [0, [17, 0, [12, 41, 0]], r(h0)], nN0 = [0, [17, 0, 0], r(z)], tN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uN0 = r(Xr), iN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fN0 = r(ur), xN0 = r(Z0), aN0 = r(tr), oN0 = [0, [17, 0, 0], r(z)], cN0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], sN0 = [0, [15, 0], r(C0)], vN0 = r(Yr), lN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], pN0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], mN0 = r("Flow_ast.Expression.TemplateLiteral.quasis"), _N0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yN0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], dN0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], hN0 = [0, [17, 0, 0], r(z)], kN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wN0 = r(Ug), EN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], SN0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], gN0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], FN0 = [0, [17, 0, 0], r(z)], TN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ON0 = r(Xr), IN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], AN0 = r(ur), NN0 = r(Z0), CN0 = r(tr), PN0 = [0, [17, 0, 0], r(z)], DN0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], LN0 = [0, [15, 0], r(C0)], RN0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], jN0 = r("Flow_ast.Expression.TemplateLiteral.Element.value"), GN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], MN0 = [0, [17, 0, 0], r(z)], BN0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qN0 = r(bU), UN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], HN0 = [0, [9, 0, 0], r(Cn)], XN0 = [0, [17, 0, 0], r(z)], YN0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], VN0 = [0, [15, 0], r(C0)], zN0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], KN0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], WN0 = [0, [17, 0, [12, 41, 0]], r(h0)], JN0 = [0, [15, 0], r(C0)], $N0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ZN0 = r("Flow_ast.Expression.TemplateLiteral.Element.raw"), QN0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rC0 = [0, [3, 0, 0], r(zt)], eC0 = [0, [17, 0, 0], r(z)], nC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tC0 = r(GY), uC0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], iC0 = [0, [3, 0, 0], r(zt)], fC0 = [0, [17, 0, 0], r(z)], xC0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], aC0 = [0, [15, 0], r(C0)], oC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cC0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], sC0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], vC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lC0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], bC0 = r("Flow_ast.Expression.Array.elements"), pC0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mC0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], _C0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], yC0 = [0, [17, 0, 0], r(z)], dC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hC0 = r(Xr), kC0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wC0 = r(ur), EC0 = r(Z0), SC0 = r(tr), gC0 = [0, [17, 0, 0], r(z)], FC0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], TC0 = [0, [15, 0], r(C0)], OC0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Array.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Array.Expression@ ")], IC0 = [0, [17, 0, [12, 41, 0]], r(h0)], AC0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Array.Spread"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Array.Spread@ ")], NC0 = [0, [17, 0, [12, 41, 0]], r(h0)], CC0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.Array.Hole"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.Array.Hole@ ")], PC0 = [0, [17, 0, [12, 41, 0]], r(h0)], DC0 = [0, [15, 0], r(C0)], LC0 = r(Yr), RC0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], jC0 = r("Flow_ast.Expression.SpreadElement.argument"), GC0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], MC0 = [0, [17, 0, 0], r(z)], BC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qC0 = r(Xr), UC0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], HC0 = r(ur), XC0 = r(Z0), YC0 = r(tr), VC0 = [0, [17, 0, 0], r(z)], zC0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], KC0 = [0, [15, 0], r(C0)], WC0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], JC0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], $C0 = [0, [17, 0, [12, 41, 0]], r(h0)], ZC0 = [0, [15, 0], r(C0)], QC0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], rP0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], eP0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], nP0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tP0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], uP0 = r("Flow_ast.Expression.CallTypeArgs.arguments"), iP0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fP0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], xP0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], aP0 = [0, [17, 0, 0], r(z)], oP0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cP0 = r(Xr), sP0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vP0 = r(ur), lP0 = r(Z0), bP0 = r(tr), pP0 = [0, [17, 0, 0], r(z)], mP0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], _P0 = [0, [15, 0], r(C0)], yP0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], dP0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], hP0 = [0, [17, 0, [12, 41, 0]], r(h0)], kP0 = [0, [15, 0], r(C0)], wP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.CallTypeArg.Explicit"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.CallTypeArg.Explicit@ ")], EP0 = [0, [17, 0, [12, 41, 0]], r(h0)], SP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Expression.CallTypeArg.Implicit"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Expression.CallTypeArg.Implicit@ ")], gP0 = [0, [17, 0, [12, 41, 0]], r(h0)], FP0 = [0, [15, 0], r(C0)], TP0 = r(Yr), OP0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], IP0 = r("Flow_ast.Expression.CallTypeArg.Implicit.comments"), AP0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], NP0 = r(ur), CP0 = r(Z0), PP0 = r(tr), DP0 = [0, [17, 0, 0], r(z)], LP0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], RP0 = [0, [15, 0], r(C0)], jP0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], GP0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], MP0 = [0, [17, 0, [12, 41, 0]], r(h0)], BP0 = [0, [15, 0], r(C0)], qP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Block"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Block@ ")], UP0 = [0, [17, 0, [12, 41, 0]], r(h0)], HP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Break"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Break@ ")], XP0 = [0, [17, 0, [12, 41, 0]], r(h0)], YP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ClassDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ClassDeclaration@ ")], VP0 = [0, [17, 0, [12, 41, 0]], r(h0)], zP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Continue"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Continue@ ")], KP0 = [0, [17, 0, [12, 41, 0]], r(h0)], WP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Debugger"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Debugger@ ")], JP0 = [0, [17, 0, [12, 41, 0]], r(h0)], $P0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareClass"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareClass@ ")], ZP0 = [0, [17, 0, [12, 41, 0]], r(h0)], QP0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration@ ")], rD0 = [0, [17, 0, [12, 41, 0]], r(h0)], eD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareFunction"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareFunction@ ")], nD0 = [0, [17, 0, [12, 41, 0]], r(h0)], tD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareInterface"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareInterface@ ")], uD0 = [0, [17, 0, [12, 41, 0]], r(h0)], iD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareModule"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareModule@ ")], fD0 = [0, [17, 0, [12, 41, 0]], r(h0)], xD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareModuleExports"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareModuleExports@ ")], aD0 = [0, [17, 0, [12, 41, 0]], r(h0)], oD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareTypeAlias"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareTypeAlias@ ")], cD0 = [0, [17, 0, [12, 41, 0]], r(h0)], sD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareOpaqueType"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareOpaqueType@ ")], vD0 = [0, [17, 0, [12, 41, 0]], r(h0)], lD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareVariable"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareVariable@ ")], bD0 = [0, [17, 0, [12, 41, 0]], r(h0)], pD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DoWhile"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DoWhile@ ")], mD0 = [0, [17, 0, [12, 41, 0]], r(h0)], _D0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Empty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Empty@ ")], yD0 = [0, [17, 0, [12, 41, 0]], r(h0)], dD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration@ ")], hD0 = [0, [17, 0, [12, 41, 0]], r(h0)], kD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportDefaultDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportDefaultDeclaration@ ")], wD0 = [0, [17, 0, [12, 41, 0]], r(h0)], ED0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportNamedDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportNamedDeclaration@ ")], SD0 = [0, [17, 0, [12, 41, 0]], r(h0)], gD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Expression@ ")], FD0 = [0, [17, 0, [12, 41, 0]], r(h0)], TD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.For"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.For@ ")], OD0 = [0, [17, 0, [12, 41, 0]], r(h0)], ID0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForIn"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForIn@ ")], AD0 = [0, [17, 0, [12, 41, 0]], r(h0)], ND0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForOf"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForOf@ ")], CD0 = [0, [17, 0, [12, 41, 0]], r(h0)], PD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.FunctionDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.FunctionDeclaration@ ")], DD0 = [0, [17, 0, [12, 41, 0]], r(h0)], LD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.If"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.If@ ")], RD0 = [0, [17, 0, [12, 41, 0]], r(h0)], jD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ImportDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ImportDeclaration@ ")], GD0 = [0, [17, 0, [12, 41, 0]], r(h0)], MD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.InterfaceDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.InterfaceDeclaration@ ")], BD0 = [0, [17, 0, [12, 41, 0]], r(h0)], qD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Labeled"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Labeled@ ")], UD0 = [0, [17, 0, [12, 41, 0]], r(h0)], HD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Return"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Return@ ")], XD0 = [0, [17, 0, [12, 41, 0]], r(h0)], YD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Switch"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Switch@ ")], VD0 = [0, [17, 0, [12, 41, 0]], r(h0)], zD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Throw"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Throw@ ")], KD0 = [0, [17, 0, [12, 41, 0]], r(h0)], WD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.Try"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.Try@ ")], JD0 = [0, [17, 0, [12, 41, 0]], r(h0)], $D0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.TypeAlias"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.TypeAlias@ ")], ZD0 = [0, [17, 0, [12, 41, 0]], r(h0)], QD0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.OpaqueType"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.OpaqueType@ ")], rL0 = [0, [17, 0, [12, 41, 0]], r(h0)], eL0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.VariableDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.VariableDeclaration@ ")], nL0 = [0, [17, 0, [12, 41, 0]], r(h0)], tL0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.While"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.While@ ")], uL0 = [0, [17, 0, [12, 41, 0]], r(h0)], iL0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.With"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.With@ ")], fL0 = [0, [17, 0, [12, 41, 0]], r(h0)], xL0 = [0, [15, 0], r(C0)], aL0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], oL0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], cL0 = [0, [17, 0, [12, 41, 0]], r(h0)], sL0 = [0, [15, 0], r(C0)], vL0 = r("Flow_ast.Statement.ExportValue"), lL0 = r("Flow_ast.Statement.ExportType"), bL0 = [0, [15, 0], r(C0)], pL0 = r(Yr), mL0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], _L0 = r("Flow_ast.Statement.Empty.comments"), yL0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dL0 = r(ur), hL0 = r(Z0), kL0 = r(tr), wL0 = [0, [17, 0, 0], r(z)], EL0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], SL0 = [0, [15, 0], r(C0)], gL0 = r(Yr), FL0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], TL0 = r("Flow_ast.Statement.Expression.expression"), OL0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], IL0 = [0, [17, 0, 0], r(z)], AL0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], NL0 = r(o7), CL0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], PL0 = r(ur), DL0 = [0, [3, 0, 0], r(zt)], LL0 = r(Z0), RL0 = r(tr), jL0 = [0, [17, 0, 0], r(z)], GL0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ML0 = r(Xr), BL0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], qL0 = r(ur), UL0 = r(Z0), HL0 = r(tr), XL0 = [0, [17, 0, 0], r(z)], YL0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], VL0 = [0, [15, 0], r(C0)], zL0 = r(Yr), KL0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], WL0 = r("Flow_ast.Statement.ImportDeclaration.import_kind"), JL0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $L0 = [0, [17, 0, 0], r(z)], ZL0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], QL0 = r(vc), rR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eR0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], nR0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], tR0 = [0, [17, 0, [12, 41, 0]], r(h0)], uR0 = [0, [17, 0, 0], r(z)], iR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], fR0 = r(_i), xR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], aR0 = r(ur), oR0 = r(Z0), cR0 = r(tr), sR0 = [0, [17, 0, 0], r(z)], vR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lR0 = r(Cv), bR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pR0 = r(ur), mR0 = r(Z0), _R0 = r(tr), yR0 = [0, [17, 0, 0], r(z)], dR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hR0 = r(Xr), kR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wR0 = r(ur), ER0 = r(Z0), SR0 = r(tr), gR0 = [0, [17, 0, 0], r(z)], FR0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], TR0 = [0, [15, 0], r(C0)], OR0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], IR0 = r("Flow_ast.Statement.ImportDeclaration.kind"), AR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], NR0 = r(ur), CR0 = r(Z0), PR0 = r(tr), DR0 = [0, [17, 0, 0], r(z)], LR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], RR0 = r(B2), jR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], GR0 = r(ur), MR0 = r(Z0), BR0 = r(tr), qR0 = [0, [17, 0, 0], r(z)], UR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], HR0 = r("remote"), XR0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], YR0 = [0, [17, 0, 0], r(z)], VR0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], zR0 = [0, [15, 0], r(C0)], KR0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], WR0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ImportDeclaration.ImportNamedSpecifiers"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ImportDeclaration.ImportNamedSpecifiers@ ")], JR0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], $R0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], ZR0 = [0, [17, 0, [12, 41, 0]], r(h0)], QR0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ImportDeclaration.ImportNamespaceSpecifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ImportDeclaration.ImportNamespaceSpecifier@ ")], rj0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], ej0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], nj0 = [0, [17, 0, [12, 41, 0]], r(h0)], tj0 = [0, [17, 0, [12, 41, 0]], r(h0)], uj0 = [0, [15, 0], r(C0)], ij0 = r("Flow_ast.Statement.ImportDeclaration.ImportType"), fj0 = r("Flow_ast.Statement.ImportDeclaration.ImportTypeof"), xj0 = r("Flow_ast.Statement.ImportDeclaration.ImportValue"), aj0 = [0, [15, 0], r(C0)], oj0 = r(Yr), cj0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], sj0 = r("Flow_ast.Statement.DeclareExportDeclaration.default"), vj0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], lj0 = r(ur), bj0 = r(Z0), pj0 = r(tr), mj0 = [0, [17, 0, 0], r(z)], _j0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], yj0 = r(P2), dj0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hj0 = r(ur), kj0 = r(Z0), wj0 = r(tr), Ej0 = [0, [17, 0, 0], r(z)], Sj0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], gj0 = r(Cv), Fj0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Tj0 = r(ur), Oj0 = r(Z0), Ij0 = r(tr), Aj0 = [0, [17, 0, 0], r(z)], Nj0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Cj0 = r(vc), Pj0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Dj0 = r(ur), Lj0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Rj0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], jj0 = [0, [17, 0, [12, 41, 0]], r(h0)], Gj0 = r(Z0), Mj0 = r(tr), Bj0 = [0, [17, 0, 0], r(z)], qj0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Uj0 = r(Xr), Hj0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Xj0 = r(ur), Yj0 = r(Z0), Vj0 = r(tr), zj0 = [0, [17, 0, 0], r(z)], Kj0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Wj0 = [0, [15, 0], r(C0)], Jj0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.Variable"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.Variable@ ")], $j0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Zj0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Qj0 = [0, [17, 0, [12, 41, 0]], r(h0)], rG0 = [0, [17, 0, [12, 41, 0]], r(h0)], eG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.Function"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.Function@ ")], nG0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], tG0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], uG0 = [0, [17, 0, [12, 41, 0]], r(h0)], iG0 = [0, [17, 0, [12, 41, 0]], r(h0)], fG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.Class"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.Class@ ")], xG0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], aG0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], oG0 = [0, [17, 0, [12, 41, 0]], r(h0)], cG0 = [0, [17, 0, [12, 41, 0]], r(h0)], sG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.DefaultType"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.DefaultType@ ")], vG0 = [0, [17, 0, [12, 41, 0]], r(h0)], lG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.NamedType"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.NamedType@ ")], bG0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], pG0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], mG0 = [0, [17, 0, [12, 41, 0]], r(h0)], _G0 = [0, [17, 0, [12, 41, 0]], r(h0)], yG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.NamedOpaqueType"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.NamedOpaqueType@ ")], dG0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], hG0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], kG0 = [0, [17, 0, [12, 41, 0]], r(h0)], wG0 = [0, [17, 0, [12, 41, 0]], r(h0)], EG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareExportDeclaration.Interface"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareExportDeclaration.Interface@ ")], SG0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], gG0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], FG0 = [0, [17, 0, [12, 41, 0]], r(h0)], TG0 = [0, [17, 0, [12, 41, 0]], r(h0)], OG0 = [0, [15, 0], r(C0)], IG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportDefaultDeclaration.Declaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportDefaultDeclaration.Declaration@ ")], AG0 = [0, [17, 0, [12, 41, 0]], r(h0)], NG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportDefaultDeclaration.Expression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportDefaultDeclaration.Expression@ ")], CG0 = [0, [17, 0, [12, 41, 0]], r(h0)], PG0 = [0, [15, 0], r(C0)], DG0 = r(Yr), LG0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], RG0 = r("Flow_ast.Statement.ExportDefaultDeclaration.default"), jG0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], GG0 = [0, [17, 0, 0], r(z)], MG0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], BG0 = r(P2), qG0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], UG0 = [0, [17, 0, 0], r(z)], HG0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], XG0 = r(Xr), YG0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], VG0 = r(ur), zG0 = r(Z0), KG0 = r(tr), WG0 = [0, [17, 0, 0], r(z)], JG0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], $G0 = [0, [15, 0], r(C0)], ZG0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], QG0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportNamedDeclaration.ExportSpecifiers"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportNamedDeclaration.ExportSpecifiers@ ")], rM0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], eM0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], nM0 = [0, [17, 0, [12, 41, 0]], r(h0)], tM0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ExportNamedDeclaration.ExportBatchSpecifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ExportNamedDeclaration.ExportBatchSpecifier@ ")], uM0 = [0, [17, 0, [12, 41, 0]], r(h0)], iM0 = [0, [15, 0], r(C0)], fM0 = r(Yr), xM0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], aM0 = r("Flow_ast.Statement.ExportNamedDeclaration.declaration"), oM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], cM0 = r(ur), sM0 = r(Z0), vM0 = r(tr), lM0 = [0, [17, 0, 0], r(z)], bM0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], pM0 = r(Cv), mM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _M0 = r(ur), yM0 = r(Z0), dM0 = r(tr), hM0 = [0, [17, 0, 0], r(z)], kM0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wM0 = r(vc), EM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], SM0 = r(ur), gM0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], FM0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], TM0 = [0, [17, 0, [12, 41, 0]], r(h0)], OM0 = r(Z0), IM0 = r(tr), AM0 = [0, [17, 0, 0], r(z)], NM0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], CM0 = r("export_kind"), PM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], DM0 = [0, [17, 0, 0], r(z)], LM0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], RM0 = r(Xr), jM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], GM0 = r(ur), MM0 = r(Z0), BM0 = r(tr), qM0 = [0, [17, 0, 0], r(z)], UM0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], HM0 = [0, [15, 0], r(C0)], XM0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], YM0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], VM0 = r(ur), zM0 = r(Z0), KM0 = r(tr), WM0 = [0, [17, 0, [12, 41, 0]], r(h0)], JM0 = [0, [15, 0], r(C0)], $M0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ZM0 = r("Flow_ast.Statement.ExportNamedDeclaration.ExportSpecifier.local"), QM0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rB0 = [0, [17, 0, 0], r(z)], eB0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nB0 = r(A4), tB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uB0 = r(ur), iB0 = r(Z0), fB0 = r(tr), xB0 = [0, [17, 0, 0], r(z)], aB0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], oB0 = [0, [15, 0], r(C0)], cB0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], sB0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], vB0 = [0, [17, 0, [12, 41, 0]], r(h0)], lB0 = [0, [15, 0], r(C0)], bB0 = r(Yr), pB0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], mB0 = r("Flow_ast.Statement.DeclareModuleExports.annot"), _B0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yB0 = [0, [17, 0, 0], r(z)], dB0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hB0 = r(Xr), kB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wB0 = r(ur), EB0 = r(Z0), SB0 = r(tr), gB0 = [0, [17, 0, 0], r(z)], FB0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], TB0 = [0, [15, 0], r(C0)], OB0 = r(Yr), IB0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], AB0 = r("Flow_ast.Statement.DeclareModule.id"), NB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], CB0 = [0, [17, 0, 0], r(z)], PB0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], DB0 = r($n), LB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], RB0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], jB0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], GB0 = [0, [17, 0, [12, 41, 0]], r(h0)], MB0 = [0, [17, 0, 0], r(z)], BB0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qB0 = r(Zc), UB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], HB0 = [0, [17, 0, 0], r(z)], XB0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], YB0 = r(Xr), VB0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zB0 = r(ur), KB0 = r(Z0), WB0 = r(tr), JB0 = [0, [17, 0, 0], r(z)], $B0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], ZB0 = [0, [15, 0], r(C0)], QB0 = r("Flow_ast.Statement.DeclareModule.ES"), rq0 = r("Flow_ast.Statement.DeclareModule.CommonJS"), eq0 = [0, [15, 0], r(C0)], nq0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareModule.Identifier"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareModule.Identifier@ ")], tq0 = [0, [17, 0, [12, 41, 0]], r(h0)], uq0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.DeclareModule.Literal"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.DeclareModule.Literal@ ")], iq0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], fq0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], xq0 = [0, [17, 0, [12, 41, 0]], r(h0)], aq0 = [0, [17, 0, [12, 41, 0]], r(h0)], oq0 = [0, [15, 0], r(C0)], cq0 = r(Yr), sq0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], vq0 = r("Flow_ast.Statement.DeclareFunction.id"), lq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bq0 = [0, [17, 0, 0], r(z)], pq0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mq0 = r(rs), _q0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yq0 = [0, [17, 0, 0], r(z)], dq0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], hq0 = r(Qu), kq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wq0 = r(ur), Eq0 = r(Z0), Sq0 = r(tr), gq0 = [0, [17, 0, 0], r(z)], Fq0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Tq0 = r(Xr), Oq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Iq0 = r(ur), Aq0 = r(Z0), Nq0 = r(tr), Cq0 = [0, [17, 0, 0], r(z)], Pq0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Dq0 = [0, [15, 0], r(C0)], Lq0 = r(Yr), Rq0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], jq0 = r("Flow_ast.Statement.DeclareVariable.id"), Gq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Mq0 = [0, [17, 0, 0], r(z)], Bq0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qq0 = r(rs), Uq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Hq0 = [0, [17, 0, 0], r(z)], Xq0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Yq0 = r(Xr), Vq0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zq0 = r(ur), Kq0 = r(Z0), Wq0 = r(tr), Jq0 = [0, [17, 0, 0], r(z)], $q0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Zq0 = [0, [15, 0], r(C0)], Qq0 = r(Yr), rU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], eU0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], nU0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], tU0 = [0, [17, 0, [12, 41, 0]], r(h0)], uU0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], iU0 = r("Flow_ast.Statement.DeclareClass.id"), fU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xU0 = [0, [17, 0, 0], r(z)], aU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], oU0 = r(sv), cU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sU0 = r(ur), vU0 = r(Z0), lU0 = r(tr), bU0 = [0, [17, 0, 0], r(z)], pU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mU0 = r($n), _U0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yU0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], dU0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], hU0 = [0, [17, 0, [12, 41, 0]], r(h0)], kU0 = [0, [17, 0, 0], r(z)], wU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], EU0 = r(P7), SU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gU0 = r(ur), FU0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], TU0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], OU0 = [0, [17, 0, [12, 41, 0]], r(h0)], IU0 = r(Z0), AU0 = r(tr), NU0 = [0, [17, 0, 0], r(z)], CU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], PU0 = r(Vy), DU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], LU0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], RU0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], jU0 = [0, [17, 0, 0], r(z)], GU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], MU0 = r(gs), BU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], qU0 = r(ur), UU0 = r(Z0), HU0 = r(tr), XU0 = [0, [17, 0, 0], r(z)], YU0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], VU0 = r(Xr), zU0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], KU0 = r(ur), WU0 = r(Z0), JU0 = r(tr), $U0 = [0, [17, 0, 0], r(z)], ZU0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], QU0 = [0, [15, 0], r(C0)], rH0 = r(Yr), eH0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nH0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], tH0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], uH0 = [0, [17, 0, [12, 41, 0]], r(h0)], iH0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], fH0 = r("Flow_ast.Statement.Interface.id"), xH0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], aH0 = [0, [17, 0, 0], r(z)], oH0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cH0 = r(sv), sH0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vH0 = r(ur), lH0 = r(Z0), bH0 = r(tr), pH0 = [0, [17, 0, 0], r(z)], mH0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _H0 = r(P7), yH0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dH0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], hH0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], kH0 = [0, [17, 0, 0], r(z)], wH0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], EH0 = r($n), SH0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gH0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], FH0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], TH0 = [0, [17, 0, [12, 41, 0]], r(h0)], OH0 = [0, [17, 0, 0], r(z)], IH0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], AH0 = r(Xr), NH0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], CH0 = r(ur), PH0 = r(Z0), DH0 = r(tr), LH0 = [0, [17, 0, 0], r(z)], RH0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], jH0 = [0, [15, 0], r(C0)], GH0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.BooleanBody"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.BooleanBody@ ")], MH0 = [0, [17, 0, [12, 41, 0]], r(h0)], BH0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.NumberBody"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.NumberBody@ ")], qH0 = [0, [17, 0, [12, 41, 0]], r(h0)], UH0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.StringBody"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.StringBody@ ")], HH0 = [0, [17, 0, [12, 41, 0]], r(h0)], XH0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.SymbolBody"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.SymbolBody@ ")], YH0 = [0, [17, 0, [12, 41, 0]], r(h0)], VH0 = [0, [15, 0], r(C0)], zH0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], KH0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], WH0 = [0, [17, 0, [12, 41, 0]], r(h0)], JH0 = [0, [15, 0], r(C0)], $H0 = r(Yr), ZH0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], QH0 = r("Flow_ast.Statement.EnumDeclaration.id"), rX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eX0 = [0, [17, 0, 0], r(z)], nX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tX0 = r($n), uX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], iX0 = [0, [17, 0, 0], r(z)], fX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xX0 = r(Xr), aX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], oX0 = r(ur), cX0 = r(Z0), sX0 = r(tr), vX0 = [0, [17, 0, 0], r(z)], lX0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], bX0 = [0, [15, 0], r(C0)], pX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], _X0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], yX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], hX0 = r("Flow_ast.Statement.EnumDeclaration.SymbolBody.members"), kX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], EX0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], SX0 = [0, [17, 0, 0], r(z)], gX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], FX0 = r(E4), TX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], OX0 = [0, [9, 0, 0], r(Cn)], IX0 = [0, [17, 0, 0], r(z)], AX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], NX0 = r(Xr), CX0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], PX0 = r(ur), DX0 = r(Z0), LX0 = r(tr), RX0 = [0, [17, 0, 0], r(z)], jX0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], GX0 = [0, [15, 0], r(C0)], MX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], BX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qX0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.StringBody.Defaulted"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.StringBody.Defaulted@ ")], UX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], HX0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], XX0 = [0, [17, 0, [12, 41, 0]], r(h0)], YX0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.EnumDeclaration.StringBody.Initialized"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.EnumDeclaration.StringBody.Initialized@ ")], VX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], zX0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], KX0 = [0, [17, 0, [12, 41, 0]], r(h0)], WX0 = [0, [15, 0], r(C0)], JX0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $X0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], ZX0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], QX0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], rY0 = r("Flow_ast.Statement.EnumDeclaration.StringBody.members"), eY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], nY0 = [0, [17, 0, 0], r(z)], tY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uY0 = r(Ik), iY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fY0 = [0, [9, 0, 0], r(Cn)], xY0 = [0, [17, 0, 0], r(z)], aY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], oY0 = r(E4), cY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sY0 = [0, [9, 0, 0], r(Cn)], vY0 = [0, [17, 0, 0], r(z)], lY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bY0 = r(Xr), pY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mY0 = r(ur), _Y0 = r(Z0), yY0 = r(tr), dY0 = [0, [17, 0, 0], r(z)], hY0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], kY0 = [0, [15, 0], r(C0)], wY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], EY0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], SY0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], gY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], FY0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], TY0 = r("Flow_ast.Statement.EnumDeclaration.NumberBody.members"), OY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], IY0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], AY0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], NY0 = [0, [17, 0, 0], r(z)], CY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], PY0 = r(Ik), DY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], LY0 = [0, [9, 0, 0], r(Cn)], RY0 = [0, [17, 0, 0], r(z)], jY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], GY0 = r(E4), MY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], BY0 = [0, [9, 0, 0], r(Cn)], qY0 = [0, [17, 0, 0], r(z)], UY0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], HY0 = r(Xr), XY0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], YY0 = r(ur), VY0 = r(Z0), zY0 = r(tr), KY0 = [0, [17, 0, 0], r(z)], WY0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], JY0 = [0, [15, 0], r(C0)], $Y0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ZY0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], QY0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], rV0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], eV0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], nV0 = r("Flow_ast.Statement.EnumDeclaration.BooleanBody.members"), tV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uV0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], iV0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], fV0 = [0, [17, 0, 0], r(z)], xV0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], aV0 = r(Ik), oV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], cV0 = [0, [9, 0, 0], r(Cn)], sV0 = [0, [17, 0, 0], r(z)], vV0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lV0 = r(E4), bV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pV0 = [0, [9, 0, 0], r(Cn)], mV0 = [0, [17, 0, 0], r(z)], _V0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], yV0 = r(Xr), dV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hV0 = r(ur), kV0 = r(Z0), wV0 = r(tr), EV0 = [0, [17, 0, 0], r(z)], SV0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], gV0 = [0, [15, 0], r(C0)], FV0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], TV0 = r("Flow_ast.Statement.EnumDeclaration.InitializedMember.id"), OV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], IV0 = [0, [17, 0, 0], r(z)], AV0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], NV0 = r(Gi), CV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], PV0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], DV0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], LV0 = [0, [17, 0, [12, 41, 0]], r(h0)], RV0 = [0, [17, 0, 0], r(z)], jV0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], GV0 = [0, [15, 0], r(C0)], MV0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], BV0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], qV0 = [0, [17, 0, [12, 41, 0]], r(h0)], UV0 = [0, [15, 0], r(C0)], HV0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], XV0 = r("Flow_ast.Statement.EnumDeclaration.DefaultedMember.id"), YV0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], VV0 = [0, [17, 0, 0], r(z)], zV0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], KV0 = [0, [15, 0], r(C0)], WV0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], JV0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], $V0 = [0, [17, 0, [12, 41, 0]], r(h0)], ZV0 = [0, [15, 0], r(C0)], QV0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForOf.LeftDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForOf.LeftDeclaration@ ")], rz0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], ez0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], nz0 = [0, [17, 0, [12, 41, 0]], r(h0)], tz0 = [0, [17, 0, [12, 41, 0]], r(h0)], uz0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForOf.LeftPattern"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForOf.LeftPattern@ ")], iz0 = [0, [17, 0, [12, 41, 0]], r(h0)], fz0 = [0, [15, 0], r(C0)], xz0 = r(Yr), az0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], oz0 = r("Flow_ast.Statement.ForOf.left"), cz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], sz0 = [0, [17, 0, 0], r(z)], vz0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lz0 = r(Au), bz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pz0 = [0, [17, 0, 0], r(z)], mz0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _z0 = r($n), yz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dz0 = [0, [17, 0, 0], r(z)], hz0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], kz0 = r(wx), wz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ez0 = [0, [9, 0, 0], r(Cn)], Sz0 = [0, [17, 0, 0], r(z)], gz0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Fz0 = r(Xr), Tz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Oz0 = r(ur), Iz0 = r(Z0), Az0 = r(tr), Nz0 = [0, [17, 0, 0], r(z)], Cz0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Pz0 = [0, [15, 0], r(C0)], Dz0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForIn.LeftDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForIn.LeftDeclaration@ ")], Lz0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Rz0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], jz0 = [0, [17, 0, [12, 41, 0]], r(h0)], Gz0 = [0, [17, 0, [12, 41, 0]], r(h0)], Mz0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.ForIn.LeftPattern"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.ForIn.LeftPattern@ ")], Bz0 = [0, [17, 0, [12, 41, 0]], r(h0)], qz0 = [0, [15, 0], r(C0)], Uz0 = r(Yr), Hz0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Xz0 = r("Flow_ast.Statement.ForIn.left"), Yz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Vz0 = [0, [17, 0, 0], r(z)], zz0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Kz0 = r(Au), Wz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jz0 = [0, [17, 0, 0], r(z)], $z0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Zz0 = r($n), Qz0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rK0 = [0, [17, 0, 0], r(z)], eK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nK0 = r(j8), tK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], uK0 = [0, [9, 0, 0], r(Cn)], iK0 = [0, [17, 0, 0], r(z)], fK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xK0 = r(Xr), aK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], oK0 = r(ur), cK0 = r(Z0), sK0 = r(tr), vK0 = [0, [17, 0, 0], r(z)], lK0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], bK0 = [0, [15, 0], r(C0)], pK0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.For.InitDeclaration"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.For.InitDeclaration@ ")], mK0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], _K0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], yK0 = [0, [17, 0, [12, 41, 0]], r(h0)], dK0 = [0, [17, 0, [12, 41, 0]], r(h0)], hK0 = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Statement.For.InitExpression"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Statement.For.InitExpression@ ")], kK0 = [0, [17, 0, [12, 41, 0]], r(h0)], wK0 = [0, [15, 0], r(C0)], EK0 = r(Yr), SK0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], gK0 = r("Flow_ast.Statement.For.init"), FK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], TK0 = r(ur), OK0 = r(Z0), IK0 = r(tr), AK0 = [0, [17, 0, 0], r(z)], NK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], CK0 = r(Ts), PK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], DK0 = r(ur), LK0 = r(Z0), RK0 = r(tr), jK0 = [0, [17, 0, 0], r(z)], GK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], MK0 = r(sU), BK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], qK0 = r(ur), UK0 = r(Z0), HK0 = r(tr), XK0 = [0, [17, 0, 0], r(z)], YK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], VK0 = r($n), zK0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], KK0 = [0, [17, 0, 0], r(z)], WK0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], JK0 = r(Xr), $K0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ZK0 = r(ur), QK0 = r(Z0), rW0 = r(tr), eW0 = [0, [17, 0, 0], r(z)], nW0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], tW0 = [0, [15, 0], r(C0)], uW0 = r(Yr), iW0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], fW0 = r("Flow_ast.Statement.DoWhile.body"), xW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], aW0 = [0, [17, 0, 0], r(z)], oW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], cW0 = r(Ts), sW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], vW0 = [0, [17, 0, 0], r(z)], lW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bW0 = r(Xr), pW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], mW0 = r(ur), _W0 = r(Z0), yW0 = r(tr), dW0 = [0, [17, 0, 0], r(z)], hW0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], kW0 = [0, [15, 0], r(C0)], wW0 = r(Yr), EW0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], SW0 = r("Flow_ast.Statement.While.test"), gW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], FW0 = [0, [17, 0, 0], r(z)], TW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], OW0 = r($n), IW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], AW0 = [0, [17, 0, 0], r(z)], NW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], CW0 = r(Xr), PW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], DW0 = r(ur), LW0 = r(Z0), RW0 = r(tr), jW0 = [0, [17, 0, 0], r(z)], GW0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], MW0 = [0, [15, 0], r(C0)], BW0 = r("Flow_ast.Statement.VariableDeclaration.Var"), qW0 = r("Flow_ast.Statement.VariableDeclaration.Let"), UW0 = r("Flow_ast.Statement.VariableDeclaration.Const"), HW0 = [0, [15, 0], r(C0)], XW0 = r(Yr), YW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], VW0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], zW0 = r("Flow_ast.Statement.VariableDeclaration.declarations"), KW0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], WW0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], JW0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], $W0 = [0, [17, 0, 0], r(z)], ZW0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], QW0 = r(Zc), rJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], eJ0 = [0, [17, 0, 0], r(z)], nJ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], tJ0 = r(Xr), uJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], iJ0 = r(ur), fJ0 = r(Z0), xJ0 = r(tr), aJ0 = [0, [17, 0, 0], r(z)], oJ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], cJ0 = [0, [15, 0], r(C0)], sJ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], vJ0 = r("Flow_ast.Statement.VariableDeclaration.Declarator.id"), lJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bJ0 = [0, [17, 0, 0], r(z)], pJ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mJ0 = r(Gi), _J0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], yJ0 = r(ur), dJ0 = r(Z0), hJ0 = r(tr), kJ0 = [0, [17, 0, 0], r(z)], wJ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], EJ0 = [0, [15, 0], r(C0)], SJ0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], gJ0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], FJ0 = [0, [17, 0, [12, 41, 0]], r(h0)], TJ0 = [0, [15, 0], r(C0)], OJ0 = r(Yr), IJ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], AJ0 = r("Flow_ast.Statement.Try.block"), NJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], CJ0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], PJ0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], DJ0 = [0, [17, 0, [12, 41, 0]], r(h0)], LJ0 = [0, [17, 0, 0], r(z)], RJ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jJ0 = r(XU), GJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], MJ0 = r(ur), BJ0 = r(Z0), qJ0 = r(tr), UJ0 = [0, [17, 0, 0], r(z)], HJ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], XJ0 = r(jH), YJ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], VJ0 = r(ur), zJ0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], KJ0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], WJ0 = [0, [17, 0, [12, 41, 0]], r(h0)], JJ0 = r(Z0), $J0 = r(tr), ZJ0 = [0, [17, 0, 0], r(z)], QJ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], r$0 = r(Xr), e$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], n$0 = r(ur), t$0 = r(Z0), u$0 = r(tr), i$0 = [0, [17, 0, 0], r(z)], f$0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], x$0 = [0, [15, 0], r(C0)], a$0 = r(Yr), o$0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], c$0 = r("Flow_ast.Statement.Try.CatchClause.param"), s$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], v$0 = r(ur), l$0 = r(Z0), b$0 = r(tr), p$0 = [0, [17, 0, 0], r(z)], m$0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _$0 = r($n), y$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], d$0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], h$0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], k$0 = [0, [17, 0, [12, 41, 0]], r(h0)], w$0 = [0, [17, 0, 0], r(z)], E$0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], S$0 = r(Xr), g$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], F$0 = r(ur), T$0 = r(Z0), O$0 = r(tr), I$0 = [0, [17, 0, 0], r(z)], A$0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], N$0 = [0, [15, 0], r(C0)], C$0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], P$0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], D$0 = [0, [17, 0, [12, 41, 0]], r(h0)], L$0 = [0, [15, 0], r(C0)], R$0 = r(Yr), j$0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], G$0 = r("Flow_ast.Statement.Throw.argument"), M$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], B$0 = [0, [17, 0, 0], r(z)], q$0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], U$0 = r(Xr), H$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], X$0 = r(ur), Y$0 = r(Z0), V$0 = r(tr), z$0 = [0, [17, 0, 0], r(z)], K$0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], W$0 = [0, [15, 0], r(C0)], J$0 = r(Yr), $$0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Z$0 = r("Flow_ast.Statement.Return.argument"), Q$0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rZ0 = r(ur), eZ0 = r(Z0), nZ0 = r(tr), tZ0 = [0, [17, 0, 0], r(z)], uZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], iZ0 = r(Xr), fZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xZ0 = r(ur), aZ0 = r(Z0), oZ0 = r(tr), cZ0 = [0, [17, 0, 0], r(z)], sZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], vZ0 = r("return_out"), lZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bZ0 = [0, [17, 0, 0], r(z)], pZ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], mZ0 = [0, [15, 0], r(C0)], _Z0 = r(Yr), yZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dZ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], hZ0 = r("Flow_ast.Statement.Switch.discriminant"), kZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], wZ0 = [0, [17, 0, 0], r(z)], EZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], SZ0 = r(uY), gZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], FZ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], TZ0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], OZ0 = [0, [17, 0, 0], r(z)], IZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], AZ0 = r(Xr), NZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], CZ0 = r(ur), PZ0 = r(Z0), DZ0 = r(tr), LZ0 = [0, [17, 0, 0], r(z)], RZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], jZ0 = r("exhaustive_out"), GZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], MZ0 = [0, [17, 0, 0], r(z)], BZ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], qZ0 = [0, [15, 0], r(C0)], UZ0 = r(Yr), HZ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], XZ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], YZ0 = r("Flow_ast.Statement.Switch.Case.test"), VZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zZ0 = r(ur), KZ0 = r(Z0), WZ0 = r(tr), JZ0 = [0, [17, 0, 0], r(z)], $Z0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ZZ0 = r(kv), QZ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rQ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], eQ0 = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], nQ0 = [0, [17, 0, 0], r(z)], tQ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uQ0 = r(Xr), iQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fQ0 = r(ur), xQ0 = r(Z0), aQ0 = r(tr), oQ0 = [0, [17, 0, 0], r(z)], cQ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], sQ0 = [0, [15, 0], r(C0)], vQ0 = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], lQ0 = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], bQ0 = [0, [17, 0, [12, 41, 0]], r(h0)], pQ0 = [0, [15, 0], r(C0)], mQ0 = r(Yr), _Q0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], yQ0 = r("Flow_ast.Statement.OpaqueType.id"), dQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hQ0 = [0, [17, 0, 0], r(z)], kQ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wQ0 = r(sv), EQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], SQ0 = r(ur), gQ0 = r(Z0), FQ0 = r(tr), TQ0 = [0, [17, 0, 0], r(z)], OQ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], IQ0 = r(kX), AQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], NQ0 = r(ur), CQ0 = r(Z0), PQ0 = r(tr), DQ0 = [0, [17, 0, 0], r(z)], LQ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], RQ0 = r(IX), jQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], GQ0 = r(ur), MQ0 = r(Z0), BQ0 = r(tr), qQ0 = [0, [17, 0, 0], r(z)], UQ0 = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], HQ0 = r(Xr), XQ0 = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], YQ0 = r(ur), VQ0 = r(Z0), zQ0 = r(tr), KQ0 = [0, [17, 0, 0], r(z)], WQ0 = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], JQ0 = [0, [15, 0], r(C0)], $Q0 = r(Yr), ZQ0 = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], QQ0 = r("Flow_ast.Statement.TypeAlias.id"), r0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], e0r = [0, [17, 0, 0], r(z)], n0r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], t0r = r(sv), u0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], i0r = r(ur), f0r = r(Z0), x0r = r(tr), a0r = [0, [17, 0, 0], r(z)], o0r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], c0r = r(Au), s0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], v0r = [0, [17, 0, 0], r(z)], l0r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], b0r = r(Xr), p0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], m0r = r(ur), _0r = r(Z0), y0r = r(tr), d0r = [0, [17, 0, 0], r(z)], h0r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], k0r = [0, [15, 0], r(C0)], w0r = r(Yr), E0r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], S0r = r("Flow_ast.Statement.With._object"), g0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], F0r = [0, [17, 0, 0], r(z)], T0r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], O0r = r($n), I0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], A0r = [0, [17, 0, 0], r(z)], N0r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], C0r = r(Xr), P0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], D0r = r(ur), L0r = r(Z0), R0r = r(tr), j0r = [0, [17, 0, 0], r(z)], G0r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], M0r = [0, [15, 0], r(C0)], B0r = r(Yr), q0r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], U0r = r("Flow_ast.Statement.Debugger.comments"), H0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], X0r = r(ur), Y0r = r(Z0), V0r = r(tr), z0r = [0, [17, 0, 0], r(z)], K0r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], W0r = [0, [15, 0], r(C0)], J0r = r(Yr), $0r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Z0r = r("Flow_ast.Statement.Continue.label"), Q0r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rrr = r(ur), err = r(Z0), nrr = r(tr), trr = [0, [17, 0, 0], r(z)], urr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], irr = r(Xr), frr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xrr = r(ur), arr = r(Z0), orr = r(tr), crr = [0, [17, 0, 0], r(z)], srr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], vrr = [0, [15, 0], r(C0)], lrr = r(Yr), brr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], prr = r("Flow_ast.Statement.Break.label"), mrr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _rr = r(ur), yrr = r(Z0), drr = r(tr), hrr = [0, [17, 0, 0], r(z)], krr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wrr = r(Xr), Err = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Srr = r(ur), grr = r(Z0), Frr = r(tr), Trr = [0, [17, 0, 0], r(z)], Orr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Irr = [0, [15, 0], r(C0)], Arr = r(Yr), Nrr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Crr = r("Flow_ast.Statement.Labeled.label"), Prr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Drr = [0, [17, 0, 0], r(z)], Lrr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Rrr = r($n), jrr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Grr = [0, [17, 0, 0], r(z)], Mrr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Brr = r(Xr), qrr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Urr = r(ur), Hrr = r(Z0), Xrr = r(tr), Yrr = [0, [17, 0, 0], r(z)], Vrr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], zrr = [0, [15, 0], r(C0)], Krr = r(Yr), Wrr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Jrr = r("Flow_ast.Statement.If.test"), $rr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Zrr = [0, [17, 0, 0], r(z)], Qrr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], rer = r(kv), eer = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ner = [0, [17, 0, 0], r(z)], ter = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], uer = r(_3), ier = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fer = r(ur), xer = r(Z0), aer = r(tr), oer = [0, [17, 0, 0], r(z)], cer = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ser = r(Xr), ver = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ler = r(ur), ber = r(Z0), per = r(tr), mer = [0, [17, 0, 0], r(z)], _er = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], yer = [0, [15, 0], r(C0)], der = r(Yr), her = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ker = r("Flow_ast.Statement.If.Alternate.body"), wer = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Eer = [0, [17, 0, 0], r(z)], Ser = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ger = r(Xr), Fer = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ter = r(ur), Oer = r(Z0), Ier = r(tr), Aer = [0, [17, 0, 0], r(z)], Ner = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Cer = [0, [15, 0], r(C0)], Per = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Der = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Ler = [0, [17, 0, [12, 41, 0]], r(h0)], Rer = [0, [15, 0], r(C0)], jer = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ger = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Mer = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Ber = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qer = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Uer = r("Flow_ast.Statement.Block.body"), Her = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Xer = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Yer = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Ver = [0, [17, 0, 0], r(z)], zer = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ker = r(Xr), Wer = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jer = r(ur), $er = r(Z0), Zer = r(tr), Qer = [0, [17, 0, 0], r(z)], rnr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], enr = [0, [15, 0], r(C0)], nnr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Predicate.Declared"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Predicate.Declared@ ")], tnr = [0, [17, 0, [12, 41, 0]], r(h0)], unr = r("Flow_ast.Type.Predicate.Inferred"), inr = [0, [15, 0], r(C0)], fnr = r(Yr), xnr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], anr = r("Flow_ast.Type.Predicate.kind"), onr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], cnr = [0, [17, 0, 0], r(z)], snr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], vnr = r(Xr), lnr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bnr = r(ur), pnr = r(Z0), mnr = r(tr), _nr = [0, [17, 0, 0], r(z)], ynr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], dnr = [0, [15, 0], r(C0)], hnr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], knr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], wnr = [0, [17, 0, [12, 41, 0]], r(h0)], Enr = [0, [15, 0], r(C0)], Snr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], gnr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Fnr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Tnr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Onr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Inr = r("Flow_ast.Type.TypeArgs.arguments"), Anr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Nnr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Cnr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Pnr = [0, [17, 0, 0], r(z)], Dnr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Lnr = r(Xr), Rnr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], jnr = r(ur), Gnr = r(Z0), Mnr = r(tr), Bnr = [0, [17, 0, 0], r(z)], qnr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Unr = [0, [15, 0], r(C0)], Hnr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Xnr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Ynr = [0, [17, 0, [12, 41, 0]], r(h0)], Vnr = [0, [15, 0], r(C0)], znr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Knr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Wnr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Jnr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $nr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Znr = r("Flow_ast.Type.TypeParams.params"), Qnr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rtr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], etr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], ntr = [0, [17, 0, 0], r(z)], ttr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], utr = r(Xr), itr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ftr = r(ur), xtr = r(Z0), atr = r(tr), otr = [0, [17, 0, 0], r(z)], ctr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], str = [0, [15, 0], r(C0)], vtr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], ltr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], btr = [0, [17, 0, [12, 41, 0]], r(h0)], ptr = [0, [15, 0], r(C0)], mtr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], _tr = r("Flow_ast.Type.TypeParam.name"), ytr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dtr = [0, [17, 0, 0], r(z)], htr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ktr = r(MU), wtr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Etr = [0, [17, 0, 0], r(z)], Str = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], gtr = r(au), Ftr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ttr = r(ur), Otr = r(Z0), Itr = r(tr), Atr = [0, [17, 0, 0], r(z)], Ntr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ctr = r(_i), Ptr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Dtr = r(ur), Ltr = r(Z0), Rtr = r(tr), jtr = [0, [17, 0, 0], r(z)], Gtr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Mtr = [0, [15, 0], r(C0)], Btr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], qtr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Utr = [0, [17, 0, [12, 41, 0]], r(h0)], Htr = [0, [15, 0], r(C0)], Xtr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Missing"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Missing@ ")], Ytr = [0, [17, 0, [12, 41, 0]], r(h0)], Vtr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Available"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Available@ ")], ztr = [0, [17, 0, [12, 41, 0]], r(h0)], Ktr = [0, [15, 0], r(C0)], Wtr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Jtr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], $tr = [0, [17, 0, [12, 41, 0]], r(h0)], Ztr = [0, [15, 0], r(C0)], Qtr = r(Yr), rur = r(Yr), eur = r(Yr), nur = r(Yr), tur = r(Yr), uur = r(Yr), iur = r(Yr), fur = r(Yr), xur = r(Yr), aur = r(Yr), our = r(Yr), cur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Any"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Any@ ")], sur = r(ur), vur = r(Z0), lur = r(tr), bur = [0, [17, 0, [12, 41, 0]], r(h0)], pur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Mixed"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Mixed@ ")], mur = r(ur), _ur = r(Z0), yur = r(tr), dur = [0, [17, 0, [12, 41, 0]], r(h0)], hur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Empty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Empty@ ")], kur = r(ur), wur = r(Z0), Eur = r(tr), Sur = [0, [17, 0, [12, 41, 0]], r(h0)], gur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Void"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Void@ ")], Fur = r(ur), Tur = r(Z0), Our = r(tr), Iur = [0, [17, 0, [12, 41, 0]], r(h0)], Aur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Null"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Null@ ")], Nur = r(ur), Cur = r(Z0), Pur = r(tr), Dur = [0, [17, 0, [12, 41, 0]], r(h0)], Lur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Number"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Number@ ")], Rur = r(ur), jur = r(Z0), Gur = r(tr), Mur = [0, [17, 0, [12, 41, 0]], r(h0)], Bur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.BigInt"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.BigInt@ ")], qur = r(ur), Uur = r(Z0), Hur = r(tr), Xur = [0, [17, 0, [12, 41, 0]], r(h0)], Yur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.String"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.String@ ")], Vur = r(ur), zur = r(Z0), Kur = r(tr), Wur = [0, [17, 0, [12, 41, 0]], r(h0)], Jur = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Boolean"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Boolean@ ")], $ur = r(ur), Zur = r(Z0), Qur = r(tr), r7r = [0, [17, 0, [12, 41, 0]], r(h0)], e7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Symbol"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Symbol@ ")], n7r = r(ur), t7r = r(Z0), u7r = r(tr), i7r = [0, [17, 0, [12, 41, 0]], r(h0)], f7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Exists"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Exists@ ")], x7r = r(ur), a7r = r(Z0), o7r = r(tr), c7r = [0, [17, 0, [12, 41, 0]], r(h0)], s7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Nullable"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Nullable@ ")], v7r = [0, [17, 0, [12, 41, 0]], r(h0)], l7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Function"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Function@ ")], b7r = [0, [17, 0, [12, 41, 0]], r(h0)], p7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object@ ")], m7r = [0, [17, 0, [12, 41, 0]], r(h0)], _7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Interface"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Interface@ ")], y7r = [0, [17, 0, [12, 41, 0]], r(h0)], d7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Array"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Array@ ")], h7r = [0, [17, 0, [12, 41, 0]], r(h0)], k7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Generic"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Generic@ ")], w7r = [0, [17, 0, [12, 41, 0]], r(h0)], E7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.IndexedAccess"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.IndexedAccess@ ")], S7r = [0, [17, 0, [12, 41, 0]], r(h0)], g7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.OptionalIndexedAccess"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.OptionalIndexedAccess@ ")], F7r = [0, [17, 0, [12, 41, 0]], r(h0)], T7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Union"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Union@ ")], O7r = [0, [17, 0, [12, 41, 0]], r(h0)], I7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Intersection"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Intersection@ ")], A7r = [0, [17, 0, [12, 41, 0]], r(h0)], N7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Typeof"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Typeof@ ")], C7r = [0, [17, 0, [12, 41, 0]], r(h0)], P7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Tuple"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Tuple@ ")], D7r = [0, [17, 0, [12, 41, 0]], r(h0)], L7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.StringLiteral"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.StringLiteral@ ")], R7r = [0, [17, 0, [12, 41, 0]], r(h0)], j7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.NumberLiteral"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.NumberLiteral@ ")], G7r = [0, [17, 0, [12, 41, 0]], r(h0)], M7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.BigIntLiteral"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.BigIntLiteral@ ")], B7r = [0, [17, 0, [12, 41, 0]], r(h0)], q7r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.BooleanLiteral"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.BooleanLiteral@ ")], U7r = [0, [17, 0, [12, 41, 0]], r(h0)], H7r = [0, [15, 0], r(C0)], X7r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Y7r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], V7r = [0, [17, 0, [12, 41, 0]], r(h0)], z7r = [0, [15, 0], r(C0)], K7r = r(Yr), W7r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], J7r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], $7r = r("Flow_ast.Type.Intersection.types"), Z7r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Q7r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], rir = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], eir = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], nir = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], tir = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], uir = [0, [17, 0, [12, 41, 0]], r(h0)], iir = [0, [17, 0, 0], r(z)], fir = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], xir = r(Xr), air = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], oir = r(ur), cir = r(Z0), sir = r(tr), vir = [0, [17, 0, 0], r(z)], lir = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], bir = [0, [15, 0], r(C0)], pir = r(Yr), mir = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _ir = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], yir = r("Flow_ast.Type.Union.types"), dir = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hir = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], kir = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], wir = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Eir = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Sir = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], gir = [0, [17, 0, [12, 41, 0]], r(h0)], Fir = [0, [17, 0, 0], r(z)], Tir = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Oir = r(Xr), Iir = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Air = r(ur), Nir = r(Z0), Cir = r(tr), Pir = [0, [17, 0, 0], r(z)], Dir = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Lir = [0, [15, 0], r(C0)], Rir = r(Yr), jir = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Gir = r("Flow_ast.Type.Array.argument"), Mir = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Bir = [0, [17, 0, 0], r(z)], qir = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Uir = r(Xr), Hir = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Xir = r(ur), Yir = r(Z0), Vir = r(tr), zir = [0, [17, 0, 0], r(z)], Kir = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Wir = [0, [15, 0], r(C0)], Jir = r(Yr), $ir = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Zir = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Qir = r("Flow_ast.Type.Tuple.types"), rfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], efr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], nfr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], tfr = [0, [17, 0, 0], r(z)], ufr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ifr = r(Xr), ffr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xfr = r(ur), afr = r(Z0), ofr = r(tr), cfr = [0, [17, 0, 0], r(z)], sfr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], vfr = [0, [15, 0], r(C0)], lfr = r(Yr), bfr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], pfr = r("Flow_ast.Type.Typeof.argument"), mfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], _fr = [0, [17, 0, 0], r(z)], yfr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dfr = r(Xr), hfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kfr = r(ur), wfr = r(Z0), Efr = r(tr), Sfr = [0, [17, 0, 0], r(z)], gfr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Ffr = [0, [15, 0], r(C0)], Tfr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Ofr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Ifr = [0, [17, 0, [12, 41, 0]], r(h0)], Afr = [0, [15, 0], r(C0)], Nfr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Cfr = r("Flow_ast.Type.Typeof.Target.qualification"), Pfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Dfr = [0, [17, 0, 0], r(z)], Lfr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Rfr = r(yt), jfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Gfr = [0, [17, 0, 0], r(z)], Mfr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Bfr = [0, [15, 0], r(C0)], qfr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Typeof.Target.Unqualified"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Typeof.Target.Unqualified@ ")], Ufr = [0, [17, 0, [12, 41, 0]], r(h0)], Hfr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Typeof.Target.Qualified"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Typeof.Target.Qualified@ ")], Xfr = [0, [17, 0, [12, 41, 0]], r(h0)], Yfr = [0, [15, 0], r(C0)], Vfr = r(Yr), zfr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Kfr = r("Flow_ast.Type.Nullable.argument"), Wfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jfr = [0, [17, 0, 0], r(z)], $fr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Zfr = r(Xr), Qfr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rxr = r(ur), exr = r(Z0), nxr = r(tr), txr = [0, [17, 0, 0], r(z)], uxr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], ixr = [0, [15, 0], r(C0)], fxr = r(Yr), xxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], axr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], oxr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], cxr = [0, [17, 0, [12, 41, 0]], r(h0)], sxr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], vxr = r("Flow_ast.Type.Interface.body"), lxr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bxr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], pxr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], mxr = [0, [17, 0, [12, 41, 0]], r(h0)], _xr = [0, [17, 0, 0], r(z)], yxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dxr = r(P7), hxr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kxr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], wxr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Exr = [0, [17, 0, 0], r(z)], Sxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], gxr = r(Xr), Fxr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Txr = r(ur), Oxr = r(Z0), Ixr = r(tr), Axr = [0, [17, 0, 0], r(z)], Nxr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Cxr = [0, [15, 0], r(C0)], Pxr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.Property"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.Property@ ")], Dxr = [0, [17, 0, [12, 41, 0]], r(h0)], Lxr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.SpreadProperty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.SpreadProperty@ ")], Rxr = [0, [17, 0, [12, 41, 0]], r(h0)], jxr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.Indexer"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.Indexer@ ")], Gxr = [0, [17, 0, [12, 41, 0]], r(h0)], Mxr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.CallProperty"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.CallProperty@ ")], Bxr = [0, [17, 0, [12, 41, 0]], r(h0)], qxr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.InternalSlot"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.InternalSlot@ ")], Uxr = [0, [17, 0, [12, 41, 0]], r(h0)], Hxr = [0, [15, 0], r(C0)], Xxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Yxr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Vxr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], zxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Kxr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Wxr = r("Flow_ast.Type.Object.exact"), Jxr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $xr = [0, [9, 0, 0], r(Cn)], Zxr = [0, [17, 0, 0], r(z)], Qxr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], rar = r(HY), ear = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], nar = [0, [9, 0, 0], r(Cn)], tar = [0, [17, 0, 0], r(z)], uar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], iar = r(X4), far = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xar = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], aar = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], oar = [0, [17, 0, 0], r(z)], car = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], sar = r(Xr), lar = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bar = r(ur), par = r(Z0), mar = r(tr), _ar = [0, [17, 0, 0], r(z)], yar = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], dar = [0, [15, 0], r(C0)], har = r(Yr), kar = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], war = r("Flow_ast.Type.Object.InternalSlot.id"), Ear = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Sar = [0, [17, 0, 0], r(z)], gar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Far = r(qn), Tar = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Oar = [0, [17, 0, 0], r(z)], Iar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Aar = r(Bu), Nar = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Car = [0, [9, 0, 0], r(Cn)], Par = [0, [17, 0, 0], r(z)], Dar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Lar = r(eu), Rar = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], jar = [0, [9, 0, 0], r(Cn)], Gar = [0, [17, 0, 0], r(z)], Mar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Bar = r(xU), qar = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Uar = [0, [9, 0, 0], r(Cn)], Har = [0, [17, 0, 0], r(z)], Xar = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Yar = r(Xr), Var = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], zar = r(ur), Kar = r(Z0), War = r(tr), Jar = [0, [17, 0, 0], r(z)], $ar = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Zar = [0, [15, 0], r(C0)], Qar = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], ror = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], eor = [0, [17, 0, [12, 41, 0]], r(h0)], nor = [0, [15, 0], r(C0)], tor = r(Yr), uor = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ior = r("Flow_ast.Type.Object.CallProperty.value"), xor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], aor = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], oor = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], cor = [0, [17, 0, [12, 41, 0]], r(h0)], sor = [0, [17, 0, 0], r(z)], vor = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lor = r(eu), bor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], por = [0, [9, 0, 0], r(Cn)], mor = [0, [17, 0, 0], r(z)], _or = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], yor = r(Xr), dor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hor = r(ur), kor = r(Z0), wor = r(tr), Eor = [0, [17, 0, 0], r(z)], Sor = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], gor = [0, [15, 0], r(C0)], For = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Tor = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Oor = [0, [17, 0, [12, 41, 0]], r(h0)], Ior = [0, [15, 0], r(C0)], Aor = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Nor = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Cor = [0, [17, 0, [12, 41, 0]], r(h0)], Por = [0, [15, 0], r(C0)], Dor = r(Yr), Lor = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Ror = r("Flow_ast.Type.Object.Indexer.id"), jor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Gor = r(ur), Mor = r(Z0), Bor = r(tr), qor = [0, [17, 0, 0], r(z)], Uor = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Hor = r(ii), Xor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Yor = [0, [17, 0, 0], r(z)], Vor = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], zor = r(qn), Kor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Wor = [0, [17, 0, 0], r(z)], Jor = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], $or = r(eu), Zor = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Qor = [0, [9, 0, 0], r(Cn)], rcr = [0, [17, 0, 0], r(z)], ecr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ncr = r(au), tcr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ucr = r(ur), icr = r(Z0), fcr = r(tr), xcr = [0, [17, 0, 0], r(z)], acr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], ocr = r(Xr), ccr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], scr = r(ur), vcr = r(Z0), lcr = r(tr), bcr = [0, [17, 0, 0], r(z)], pcr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], mcr = [0, [15, 0], r(C0)], _cr = r(Yr), ycr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], dcr = r("Flow_ast.Type.Object.SpreadProperty.argument"), hcr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], kcr = [0, [17, 0, 0], r(z)], wcr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ecr = r(Xr), Scr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gcr = r(ur), Fcr = r(Z0), Tcr = r(tr), Ocr = [0, [17, 0, 0], r(z)], Icr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Acr = [0, [15, 0], r(C0)], Ncr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Ccr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Pcr = [0, [17, 0, [12, 41, 0]], r(h0)], Dcr = [0, [15, 0], r(C0)], Lcr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.Property.Init"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.Property.Init@ ")], Rcr = [0, [17, 0, [12, 41, 0]], r(h0)], jcr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.Property.Get"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.Property.Get@ ")], Gcr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Mcr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Bcr = [0, [17, 0, [12, 41, 0]], r(h0)], qcr = [0, [17, 0, [12, 41, 0]], r(h0)], Ucr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Object.Property.Set"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Object.Property.Set@ ")], Hcr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Xcr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Ycr = [0, [17, 0, [12, 41, 0]], r(h0)], Vcr = [0, [17, 0, [12, 41, 0]], r(h0)], zcr = [0, [15, 0], r(C0)], Kcr = r(Yr), Wcr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Jcr = r("Flow_ast.Type.Object.Property.key"), $cr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Zcr = [0, [17, 0, 0], r(z)], Qcr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], rsr = r(qn), esr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], nsr = [0, [17, 0, 0], r(z)], tsr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], usr = r(Bu), isr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], fsr = [0, [9, 0, 0], r(Cn)], xsr = [0, [17, 0, 0], r(z)], asr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], osr = r(eu), csr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ssr = [0, [9, 0, 0], r(Cn)], vsr = [0, [17, 0, 0], r(z)], lsr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], bsr = r(Y3), psr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], msr = [0, [9, 0, 0], r(Cn)], _sr = [0, [17, 0, 0], r(z)], ysr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], dsr = r(xU), hsr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ksr = [0, [9, 0, 0], r(Cn)], wsr = [0, [17, 0, 0], r(z)], Esr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ssr = r(au), gsr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Fsr = r(ur), Tsr = r(Z0), Osr = r(tr), Isr = [0, [17, 0, 0], r(z)], Asr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Nsr = r(Xr), Csr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Psr = r(ur), Dsr = r(Z0), Lsr = r(tr), Rsr = [0, [17, 0, 0], r(z)], jsr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Gsr = [0, [15, 0], r(C0)], Msr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Bsr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], qsr = [0, [17, 0, [12, 41, 0]], r(h0)], Usr = [0, [15, 0], r(C0)], Hsr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Xsr = r("Flow_ast.Type.OptionalIndexedAccess.indexed_access"), Ysr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Vsr = [0, [17, 0, 0], r(z)], zsr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ksr = r(Bu), Wsr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jsr = [0, [9, 0, 0], r(Cn)], $sr = [0, [17, 0, 0], r(z)], Zsr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Qsr = [0, [15, 0], r(C0)], r1r = r(Yr), e1r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], n1r = r("Flow_ast.Type.IndexedAccess._object"), t1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], u1r = [0, [17, 0, 0], r(z)], i1r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], f1r = r("index"), x1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], a1r = [0, [17, 0, 0], r(z)], o1r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], c1r = r(Xr), s1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], v1r = r(ur), l1r = r(Z0), b1r = r(tr), p1r = [0, [17, 0, 0], r(z)], m1r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], _1r = [0, [15, 0], r(C0)], y1r = r(Yr), d1r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], h1r = r("Flow_ast.Type.Generic.id"), k1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], w1r = [0, [17, 0, 0], r(z)], E1r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], S1r = r(Z2), g1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], F1r = r(ur), T1r = r(Z0), O1r = r(tr), I1r = [0, [17, 0, 0], r(z)], A1r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], N1r = r(Xr), C1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], P1r = r(ur), D1r = r(Z0), L1r = r(tr), R1r = [0, [17, 0, 0], r(z)], j1r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], G1r = [0, [15, 0], r(C0)], M1r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], B1r = r("Flow_ast.Type.Generic.Identifier.qualification"), q1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], U1r = [0, [17, 0, 0], r(z)], H1r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], X1r = r(yt), Y1r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], V1r = [0, [17, 0, 0], r(z)], z1r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], K1r = [0, [15, 0], r(C0)], W1r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], J1r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], $1r = [0, [17, 0, [12, 41, 0]], r(h0)], Z1r = [0, [15, 0], r(C0)], Q1r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Generic.Identifier.Unqualified"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Generic.Identifier.Unqualified@ ")], rvr = [0, [17, 0, [12, 41, 0]], r(h0)], evr = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Type.Generic.Identifier.Qualified"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Type.Generic.Identifier.Qualified@ ")], nvr = [0, [17, 0, [12, 41, 0]], r(h0)], tvr = [0, [15, 0], r(C0)], uvr = r(Yr), ivr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], fvr = r("Flow_ast.Type.Function.tparams"), xvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], avr = r(ur), ovr = r(Z0), cvr = r(tr), svr = [0, [17, 0, 0], r(z)], vvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], lvr = r(Lt), bvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], pvr = [0, [17, 0, 0], r(z)], mvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], _vr = r(Wu), yvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], dvr = [0, [17, 0, 0], r(z)], hvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], kvr = r(Xr), wvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Evr = r(ur), Svr = r(Z0), gvr = r(tr), Fvr = [0, [17, 0, 0], r(z)], Tvr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Ovr = [0, [15, 0], r(C0)], Ivr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Avr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Nvr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Cvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Pvr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Dvr = r("Flow_ast.Type.Function.Params.this_"), Lvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Rvr = r(ur), jvr = r(Z0), Gvr = r(tr), Mvr = [0, [17, 0, 0], r(z)], Bvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], qvr = r(Lt), Uvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Hvr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], Xvr = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], Yvr = [0, [17, 0, 0], r(z)], Vvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], zvr = r(ch), Kvr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Wvr = r(ur), Jvr = r(Z0), $vr = r(tr), Zvr = [0, [17, 0, 0], r(z)], Qvr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], r2r = r(Xr), e2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], n2r = r(ur), t2r = r(Z0), u2r = r(tr), i2r = [0, [17, 0, 0], r(z)], f2r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], x2r = [0, [15, 0], r(C0)], a2r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], o2r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], c2r = [0, [17, 0, [12, 41, 0]], r(h0)], s2r = [0, [15, 0], r(C0)], v2r = r(Yr), l2r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], b2r = r("Flow_ast.Type.Function.ThisParam.annot"), p2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], m2r = [0, [17, 0, 0], r(z)], _2r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], y2r = r(Xr), d2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], h2r = r(ur), k2r = r(Z0), w2r = r(tr), E2r = [0, [17, 0, 0], r(z)], S2r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], g2r = [0, [15, 0], r(C0)], F2r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], T2r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], O2r = [0, [17, 0, [12, 41, 0]], r(h0)], I2r = [0, [15, 0], r(C0)], A2r = r(Yr), N2r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], C2r = r("Flow_ast.Type.Function.RestParam.argument"), P2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], D2r = [0, [17, 0, 0], r(z)], L2r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], R2r = r(Xr), j2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], G2r = r(ur), M2r = r(Z0), B2r = r(tr), q2r = [0, [17, 0, 0], r(z)], U2r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], H2r = [0, [15, 0], r(C0)], X2r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Y2r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], V2r = [0, [17, 0, [12, 41, 0]], r(h0)], z2r = [0, [15, 0], r(C0)], K2r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], W2r = r("Flow_ast.Type.Function.Param.name"), J2r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $2r = r(ur), Z2r = r(Z0), Q2r = r(tr), rlr = [0, [17, 0, 0], r(z)], elr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], nlr = r(rs), tlr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ulr = [0, [17, 0, 0], r(z)], ilr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], flr = r(Bu), xlr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], alr = [0, [9, 0, 0], r(Cn)], olr = [0, [17, 0, 0], r(z)], clr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], slr = [0, [15, 0], r(C0)], vlr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], llr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], blr = [0, [17, 0, [12, 41, 0]], r(h0)], plr = [0, [15, 0], r(C0)], mlr = r(Yr), _lr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ylr = r("Flow_ast.ComputedKey.expression"), dlr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hlr = [0, [17, 0, 0], r(z)], klr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], wlr = r(Xr), Elr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Slr = r(ur), glr = r(Z0), Flr = r(tr), Tlr = [0, [17, 0, 0], r(z)], Olr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Ilr = [0, [15, 0], r(C0)], Alr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Nlr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Clr = [0, [17, 0, [12, 41, 0]], r(h0)], Plr = [0, [15, 0], r(C0)], Dlr = r(Yr), Llr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Rlr = r("Flow_ast.Variance.kind"), jlr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Glr = [0, [17, 0, 0], r(z)], Mlr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Blr = r(Xr), qlr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ulr = r(ur), Hlr = r(Z0), Xlr = r(tr), Ylr = [0, [17, 0, 0], r(z)], Vlr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], zlr = [0, [15, 0], r(C0)], Klr = r("Flow_ast.Variance.Minus"), Wlr = r("Flow_ast.Variance.Plus"), Jlr = [0, [15, 0], r(C0)], $lr = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], Zlr = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], Qlr = [0, [17, 0, [12, 41, 0]], r(h0)], rbr = [0, [15, 0], r(C0)], ebr = r(Yr), nbr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], tbr = r("Flow_ast.BooleanLiteral.value"), ubr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ibr = [0, [9, 0, 0], r(Cn)], fbr = [0, [17, 0, 0], r(z)], xbr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], abr = r(Xr), obr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], cbr = r(ur), sbr = r(Z0), vbr = r(tr), lbr = [0, [17, 0, 0], r(z)], bbr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], pbr = [0, [15, 0], r(C0)], mbr = r(Yr), _br = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ybr = r("Flow_ast.BigIntLiteral.approx_value"), dbr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], hbr = [0, [8, [0, 0, 5], 0, 0, 0], r(e8)], kbr = [0, [17, 0, 0], r(z)], wbr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Ebr = r(a1), Sbr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], gbr = [0, [3, 0, 0], r(zt)], Fbr = [0, [17, 0, 0], r(z)], Tbr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Obr = r(Xr), Ibr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Abr = r(ur), Nbr = r(Z0), Cbr = r(tr), Pbr = [0, [17, 0, 0], r(z)], Dbr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], Lbr = [0, [15, 0], r(C0)], Rbr = r(Yr), jbr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], Gbr = r("Flow_ast.NumberLiteral.value"), Mbr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Bbr = [0, [8, [0, 0, 5], 0, 0, 0], r(e8)], qbr = [0, [17, 0, 0], r(z)], Ubr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Hbr = r(c7), Xbr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Ybr = [0, [3, 0, 0], r(zt)], Vbr = [0, [17, 0, 0], r(z)], zbr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Kbr = r(Xr), Wbr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], Jbr = r(ur), $br = r(Z0), Zbr = r(tr), Qbr = [0, [17, 0, 0], r(z)], r4r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], e4r = [0, [15, 0], r(C0)], n4r = r(Yr), t4r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], u4r = r("Flow_ast.StringLiteral.value"), i4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], f4r = [0, [3, 0, 0], r(zt)], x4r = [0, [17, 0, 0], r(z)], a4r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], o4r = r(c7), c4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], s4r = [0, [3, 0, 0], r(zt)], v4r = [0, [17, 0, 0], r(z)], l4r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], b4r = r(Xr), p4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], m4r = r(ur), _4r = r(Z0), y4r = r(tr), d4r = [0, [17, 0, 0], r(z)], h4r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], k4r = [0, [15, 0], r(C0)], w4r = r("Flow_ast.Literal.Null"), E4r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Literal.String"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Literal.String@ ")], S4r = [0, [3, 0, 0], r(zt)], g4r = [0, [17, 0, [12, 41, 0]], r(h0)], F4r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Literal.Boolean"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Literal.Boolean@ ")], T4r = [0, [9, 0, 0], r(Cn)], O4r = [0, [17, 0, [12, 41, 0]], r(h0)], I4r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Literal.Number"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Literal.Number@ ")], A4r = [0, [8, [0, 0, 5], 0, 0, 0], r(e8)], N4r = [0, [17, 0, [12, 41, 0]], r(h0)], C4r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Literal.BigInt"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Literal.BigInt@ ")], P4r = [0, [8, [0, 0, 5], 0, 0, 0], r(e8)], D4r = [0, [17, 0, [12, 41, 0]], r(h0)], L4r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("Flow_ast.Literal.RegExp"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>Flow_ast.Literal.RegExp@ ")], R4r = [0, [17, 0, [12, 41, 0]], r(h0)], j4r = [0, [15, 0], r(C0)], G4r = r(Yr), M4r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], B4r = r("Flow_ast.Literal.value"), q4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], U4r = [0, [17, 0, 0], r(z)], H4r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], X4r = r(c7), Y4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], V4r = [0, [3, 0, 0], r(zt)], z4r = [0, [17, 0, 0], r(z)], K4r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], W4r = r(Xr), J4r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], $4r = r(ur), Z4r = r(Z0), Q4r = r(tr), r8r = [0, [17, 0, 0], r(z)], e8r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], n8r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], t8r = r("Flow_ast.Literal.RegExp.pattern"), u8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], i8r = [0, [3, 0, 0], r(zt)], f8r = [0, [17, 0, 0], r(z)], x8r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a8r = r(UX), o8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c8r = [0, [3, 0, 0], r(zt)], s8r = [0, [17, 0, 0], r(z)], v8r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], l8r = [0, [15, 0], r(C0)], b8r = [0, [15, 0], r(C0)], p8r = r(Yr), m8r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], _8r = r("Flow_ast.PrivateName.name"), y8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], d8r = [0, [3, 0, 0], r(zt)], h8r = [0, [17, 0, 0], r(z)], k8r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], w8r = r(Xr), E8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], S8r = r(ur), g8r = r(Z0), F8r = r(tr), T8r = [0, [17, 0, 0], r(z)], O8r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], I8r = [0, [15, 0], r(C0)], A8r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], N8r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], C8r = [0, [17, 0, [12, 41, 0]], r(h0)], P8r = [0, [15, 0], r(C0)], D8r = r(Yr), L8r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], R8r = r("Flow_ast.Identifier.name"), j8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], G8r = [0, [3, 0, 0], r(zt)], M8r = [0, [17, 0, 0], r(z)], B8r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], q8r = r(Xr), U8r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], H8r = r(ur), X8r = r(Z0), Y8r = r(tr), V8r = [0, [17, 0, 0], r(z)], z8r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], K8r = [0, [15, 0], r(C0)], W8r = [0, [12, 40, [18, [1, [0, 0, r(C)]], 0]], r(Zr)], J8r = [0, [12, 44, [17, [0, r(v), 1, 0], 0]], r(zr)], $8r = [0, [17, 0, [12, 41, 0]], r(h0)], Z8r = [0, [15, 0], r(C0)], Q8r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], r3r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], e3r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], n3r = r("Flow_ast.Syntax.leading"), t3r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], u3r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], i3r = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], f3r = [0, [17, 0, 0], r(z)], x3r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a3r = r("trailing"), o3r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], c3r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, 91, 0]], r(Ve)], s3r = [0, [17, [0, r(De), 0, 0], [12, 93, [17, 0, 0]]], r(Ye)], v3r = [0, [17, 0, 0], r(z)], l3r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], b3r = r("internal"), p3r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], m3r = [0, [17, 0, 0], r(z)], _3r = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], y3r = [0, [0, 0, 0]], d3r = [0, r(wu), 21, 2], h3r = [0, [0, 0, 0, 0, 0]], k3r = [0, r(wu), 32, 2], w3r = [0, [0, 0, 0, 0, 0]], E3r = [0, r(wu), 43, 2], S3r = [0, [0, [0, [0, 0, 0]], 0, 0, 0, 0]], g3r = [0, r(wu), 70, 2], F3r = [0, [0, 0, 0]], T3r = [0, r(wu), 80, 2], O3r = [0, [0, 0, 0]], I3r = [0, r(wu), 90, 2], A3r = [0, [0, 0, 0]], N3r = [0, r(wu), R7, 2], C3r = [0, [0, 0, 0]], P3r = [0, r(wu), Yt, 2], D3r = [0, [0, 0, 0, 0, 0, 0, 0]], L3r = [0, r(wu), br, 2], R3r = [0, [0, 0, 0, 0, 0]], j3r = [0, r(wu), QH, 2], G3r = [0, [0, [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0, 0, 0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]]]], M3r = [0, r(wu), 485, 2], B3r = [0, [0, [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0]], q3r = [0, r(wu), YX, 2], U3r = [0, [0, [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], H3r = [0, r(wu), 1460, 2], X3r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0, 0, 0]], Y3r = [0, r(wu), 1604, 2], V3r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], z3r = [0, r(wu), 1689, 2], K3r = [0, [0, 0, 0, 0, 0, 0, 0]], W3r = [0, r(wu), 1705, 2], J3r = [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0]], $3r = [0, r(wu), 1828, 2], Z3r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], Q3r = [0, r(wu), 1895, 2], r6r = [0, [0, 0, 0, 0, 0]], e6r = [0, r(wu), 1907, 2], n6r = [0, [0, 0, 0]], t6r = [0, [0, 0, 0, 0, 0]], u6r = [0, [0, 0, 0, 0, 0]], i6r = [0, [0, [0, [0, 0, 0]], 0, 0, 0, 0]], f6r = [0, [0, 0, 0]], x6r = [0, [0, 0, 0]], a6r = [0, [0, 0, 0]], o6r = [0, [0, 0, 0]], c6r = [0, [0, 0, 0, 0, 0, 0, 0]], s6r = [0, [0, 0, 0, 0, 0]], v6r = [0, [0, [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0, 0, 0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]]]], l6r = [0, [0, [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0]], b6r = [0, [0, [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], p6r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0, 0, 0, 0, 0]], m6r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0]], 0, 0, 0, 0]], _6r = [0, [0, 0, 0, 0, 0, 0, 0]], y6r = [0, [0, [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0]], d6r = [0, [0, [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], [0, [0, 0, 0, 0, 0]], 0, 0, 0, 0]], h6r = [0, [0, 0, 0, 0, 0]], k6r = [0, 1], w6r = [0, 0], E6r = [0, 2], S6r = [0, 0], g6r = [0, 1], F6r = [0, 1], T6r = [0, 1], O6r = [0, 1], I6r = [0, 1], A6r = [0, 0, 0], N6r = [0, 0, 0], C6r = [0, r(ku), r(zx), r(ia), r(Ia), r(au), r(wc), r(fx), r(cc), r(Bf), r(Oa), r(Da), r(tc), r(Ca), r(Sf), r(Zo), r(fa), r(Dx), r(Of), r(sx), r(Ao), r(Hf), r(ja), r(Jo), r(Vx), r(Zx), r(dx), r(oa), r(xo), r(ua), r(F7), r(Aa), r(Lf), r(Ea), r(Qx), r(Zf), r(Ha), r(ha), r(D7), r(hc), r(Po), r(Fx), r(Kx), r(df), r(Fc), r(qf), r(vx), r(Wu), r(_x), r(mo), r(Ce), r(Qu), r(Qo), r(Va), r(So), r(ra), r(lc), r(co), r(uo), r(Df), r(qa), r(zf), r($f), r(Ec), r(bc), r(lo), r(mf), r(Ka), r(rx), r(nx), r(mi), r(ro), r(Ba), r(wf), r(Ko), r(Ya), r(pc), r(ac), r(Qa), r(ca), r(xx), r(Pf), r(xf), r(Vf), r(tx), r(_o), r(wo), r(Jf), r(uc), r(Tf), r(jx), r(Ua), r(mx), r(hf), r(Af), r(yc), r(rr), r(dc), r($x), r(Xx), r(Lo), r(Wx), r(ux), r(Rx), r(ko), r(Lx), r(kc), r(bx), r($a), r(Sc), r(Ro), r(Wa), r(nc), r(nf), r(Px), r(sa), r(Ax), r(xa), r(Ga), r(Na), r(_c), r(Cx), r(af), r(cf), r(ex), r(Ja), r(ho), r(sc), r(Gf), r(Wo), r(na), r(wa), r(sf), r(r7), r(Co), r(Ox), r(Do), r(Yx), r(ma), r(gc), r(qu), r(zo), r(fo), r(_f), r(yi), r(Kf), r(mc), r($o), r(G7), r(yx), r(po), r(bf), r(Uo), r(Ex), r(Ma), r(yo), r(ix), r(uf), r(jf), r(Tc), r(Nx), r(kx), r(No), r(Ic), r(pa), r(ga), r(li), r(xc), r(hx), r(jo), r(Vo), r(Oc), r(qx), r(Eo), r(Uf), r(Ff), r(ta), r(Ix), r(Iu), r(no), r(io), r(ec), r(lf), r(Fo), r(ba), r(Cf), r(Mx), r(rc), r(Nf), r(Mf), r(Ux), r(Xa), r(Hx), r(vo), r(eo), r(bo), r(v7), r(ka), r(Go), r(Sx), r(Ta), r(la), r(to), r(Wf), r(Mo), r(Io), r(ox), r(I7), r(N7), r(Za), r(ao), r(Qf), r(da), r(kf), r(Fa), r(ax), r(Tx), r(Xf), r(Bo), r(Ef), r(ff), r(To), r(Rf), r(ic), r(yf), r(Ho), r(oo), r(Xo), r(gf), r(ef), r(lx), r(_a), r(px), r(If), r(A7), r(Yo), r(ln), r(Bx), r(of), r(pf), r(Jx), r(Yf), r(za), r(so), r(go), r(va), r(Gx), r(J4)], P6r = [0, r(df), r(ex), r(yo), r(Kf), r(If), r(zf), r(Ua), r(tx), r(Px), r(wa), r(Jo), r(D7), r(Ya), r(no), r(ic), r(_c), r(mx), r(af), r(eo), r(Ux), r(zx), r(li), r(kc), r(jx), r($o), r(vo), r(Af), r(yi), r(Ia), r(qx), r(uo), r(Wf), r(lx), r(ix), r(ef), r(Ga), r(Cf), r(po), r(bc), r(xc), r(ha), r(Jx), r(_o), r(fo), r(Fx), r(bo), r(Lx), r(hf), r(ff), r(Fa), r(ro), r(So), r(Vf), r(Va), r(Wa), r(Xf), r(ac), r(Qu), r(Pf), r(Uo), r(yc), r(sa), r(Na), r(mc), r(ux), r(Za), r(Zx), r(Nf), r(xf), r(nc), r(Qf), r(Rx), r(Ma), r(co), r(go), r(la), r(Fo), r($x), r(nx), r(va), r(_a), r(vx), r(au), r(Qo), r(fa), r(zo), r(pf), r(ga), r(ua), r(sc), r(Rf), r(uc), r(Ha), r(v7), r(Vo), r(Vx), r(ku), r(xo), r(Io), r(tc), r(Ka), r(_x), r(Da), r(kf), r(Mo), r(cc), r(Cx), r(ra), r(na), r(Xa), r(Ff), r(pc), r(io), r(ko), r(mf), r(Eo), r(Of), r(oa), r(wc), r(Fc), r(Dx), r(Oa), r(Bo), r(hx), r(ax), r(Lo), r(Ex), r(Bf), r(da), r(Tf), r($a), r(Yf), r(Xx), r(oo), r(To), r(Co), r(lo), r(Ba), r(Sc), r(dc), r(qu), r(Wu), r(Yo), r(Zo), r(sx), r(hc), r(Ec), r(F7), r(I7), r(_f), r(Ko), r(Ix), r(cf), r(mi), r(Nx), r(Hx), r(Ox), r(Tx), r(uf), r(Wx), r(Ja), r(G7), r(bf), r(Sf), r(Mf), r(Ce), r(Ic), r(ma), r(rc), r(lf), r(Jf), r(qf), r(Do), r(ca), r(Df), r(dx), r(xx), r(Ao), r(px), r(Ta), r(Xo), r(to), r(Bx), r(Gf), r(Zf), r(yx), r(mo), r(gc), r(Ho), r(wo), r(xa), r(Ef), r(sf), r(ka), r(ja), r(Gx), r(fx), r(gf), r(Hf), r(Go), r(Ax), r(ho), r(ao), r(bx), r(qa), r(Wo), r(Uf), r(Ro), r(Ea), r(za), r($f), r(of), r(Iu), r(rx), r(ta), r(kx), r(No), r(Kx), r(N7), r(jf), r(lc), r(ba), r(Sx), r(Lf), r(Qx), r(Po), r(pa), r(ec), r(Ca), r(jo), r(wf), r(ln), r(Yx), r(yf), r(nf), r(Qa), r(Tc), r(ox), r(Mx), r(A7), r(so), r(r7), r(ia), r(Oc), r(Aa), r(rr)], D6r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("File_key.LibFile"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>File_key.LibFile@ ")], L6r = [0, [3, 0, 0], r(zt)], R6r = [0, [17, 0, [12, 41, 0]], r(h0)], j6r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("File_key.SourceFile"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>File_key.SourceFile@ ")], G6r = [0, [3, 0, 0], r(zt)], M6r = [0, [17, 0, [12, 41, 0]], r(h0)], B6r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("File_key.JsonFile"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>File_key.JsonFile@ ")], q6r = [0, [3, 0, 0], r(zt)], U6r = [0, [17, 0, [12, 41, 0]], r(h0)], H6r = [0, [12, 40, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r("File_key.ResourceFile"), [17, [0, r(v), 1, 0], 0]]]], r("(@[<2>File_key.ResourceFile@ ")], X6r = [0, [3, 0, 0], r(zt)], Y6r = [0, [17, 0, [12, 41, 0]], r(h0)], V6r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], z6r = r("Loc.line"), K6r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], W6r = [0, [4, 0, 0, 0, 0], r(N2)], J6r = [0, [17, 0, 0], r(z)], $6r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], Z6r = r(I2), Q6r = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], rpr = [0, [4, 0, 0, 0, 0], r(N2)], epr = [0, [17, 0, 0], r(z)], npr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], tpr = [0, [15, 0], r(C0)], upr = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [11, r(wr), 0]], r(kr)], ipr = r("Loc.source"), fpr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], xpr = r(ur), apr = r(Z0), opr = r(tr), cpr = [0, [17, 0, 0], r(z)], spr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], vpr = r(g7), lpr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], bpr = [0, [17, 0, 0], r(z)], ppr = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], mpr = r("_end"), _pr = [0, [18, [1, [0, 0, r(C)]], [2, 0, [11, r(J), [17, [0, r(v), 1, 0], 0]]]], r(W)], ypr = [0, [17, 0, 0], r(z)], dpr = [0, [17, [0, r(v), 1, 0], [12, br, [17, 0, 0]]], r(Er)], hpr = [0, r(Gx), r(va), r(go), r(so), r(za), r(Yf), r(Jx), r(pf), r(of), r(Bx), r(ln), r(Yo), r(A7), r(If), r(px), r(_a), r(lx), r(ef), r(gf), r(Xo), r(oo), r(Ho), r(yf), r(ic), r(Rf), r(To), r(ff), r(Ef), r(Bo), r(Xf), r(Tx), r(ax), r(Fa), r(kf), r(da), r(Qf), r(ao), r(Za), r(N7), r(I7), r(ox), r(Io), r(Mo), r(Wf), r(to), r(la), r(Ta), r(Sx), r(Go), r(ka), r(v7), r(bo), r(eo), r(vo), r(Hx), r(Xa), r(Ux), r(Mf), r(Nf), r(rc), r(Mx), r(Cf), r(ba), r(Fo), r(lf), r(ec), r(io), r(no), r(Iu), r(Ix), r(ta), r(Ff), r(Uf), r(Eo), r(qx), r(Oc), r(Vo), r(jo), r(hx), r(xc), r(li), r(ga), r(pa), r(Ic), r(No), r(kx), r(Nx), r(Tc), r(jf), r(uf), r(ix), r(yo), r(Ma), r(Ex), r(Uo), r(bf), r(po), r(yx), r(G7), r($o), r(mc), r(Kf), r(yi), r(_f), r(fo), r(zo), r(qu), r(gc), r(ma), r(Yx), r(Do), r(Ox), r(Co), r(r7), r(sf), r(wa), r(na), r(Wo), r(Gf), r(sc), r(ho), r(Ja), r(ex), r(cf), r(af), r(Cx), r(_c), r(Na), r(Ga), r(xa), r(Ax), r(sa), r(Px), r(nf), r(nc), r(Wa), r(Ro), r(Sc), r($a), r(bx), r(kc), r(Lx), r(ko), r(Rx), r(ux), r(Wx), r(Lo), r(Xx), r($x), r(dc), r(rr), r(yc), r(Af), r(hf), r(mx), r(Ua), r(jx), r(Tf), r(uc), r(Jf), r(wo), r(_o), r(tx), r(Vf), r(xf), r(Pf), r(xx), r(ca), r(Qa), r(ac), r(pc), r(Ya), r(Ko), r(wf), r(Ba), r(ro), r(mi), r(nx), r(rx), r(Ka), r(mf), r(lo), r(bc), r(Ec), r($f), r(zf), r(qa), r(Df), r(uo), r(co), r(lc), r(ra), r(So), r(Va), r(Qo), r(Qu), r(Ce), r(mo), r(_x), r(Wu), r(vx), r(qf), r(Fc), r(df), r(Kx), r(Fx), r(Po), r(hc), r(D7), r(ha), r(Ha), r(Zf), r(Qx), r(Ea), r(Lf), r(Aa), r(F7), r(ua), r(xo), r(oa), r(dx), r(Zx), r(Vx), r(Jo), r(ja), r(Hf), r(Ao), r(sx), r(Of), r(Dx), r(fa), r(Zo), r(Sf), r(Ca), r(tc), r(Da), r(Oa), r(Bf), r(cc), r(fx), r(wc), r(au), r(Ia), r(ia), r(zx), r(ku)], kpr = [0, r(ku), r(zx), r(ia), r(Ia), r(au), r(wc), r(fx), r(cc), r(Bf), r(Oa), r(Da), r(tc), r(Ca), r(Sf), r(Zo), r(fa), r(Dx), r(Of), r(sx), r(Ao), r(Hf), r(ja), r(Jo), r(Vx), r(Zx), r(dx), r(oa), r(xo), r(ua), r(F7), r(Aa), r(Lf), r(Ea), r(Qx), r(Zf), r(Ha), r(ha), r(D7), r(hc), r(Po), r(Fx), r(Kx), r(df), r(Fc), r(qf), r(vx), r(Wu), r(_x), r(mo), r(Ce), r(Qu), r(Qo), r(Va), r(So), r(ra), r(lc), r(co), r(uo), r(Df), r(qa), r(zf), r($f), r(Ec), r(bc), r(lo), r(mf), r(Ka), r(rx), r(nx), r(mi), r(ro), r(Ba), r(wf), r(Ko), r(Ya), r(pc), r(ac), r(Qa), r(ca), r(xx), r(Pf), r(xf), r(Vf), r(tx), r(_o), r(wo), r(Jf), r(uc), r(Tf), r(jx), r(Ua), r(mx), r(hf), r(Af), r(yc), r(rr), r(dc), r($x), r(Xx), r(Lo), r(Wx), r(ux), r(Rx), r(ko), r(Lx), r(kc), r(bx), r($a), r(Sc), r(Ro), r(Wa), r(nc), r(nf), r(Px), r(sa), r(Ax), r(xa), r(Ga), r(Na), r(_c), r(Cx), r(af), r(cf), r(ex), r(Ja), r(ho), r(sc), r(Gf), r(Wo), r(na), r(wa), r(sf), r(r7), r(Co), r(Ox), r(Do), r(Yx), r(ma), r(gc), r(qu), r(zo), r(fo), r(_f), r(yi), r(Kf), r(mc), r($o), r(G7), r(yx), r(po), r(bf), r(Uo), r(Ex), r(Ma), r(yo), r(ix), r(uf), r(jf), r(Tc), r(Nx), r(kx), r(No), r(Ic), r(pa), r(ga), r(li), r(xc), r(hx), r(jo), r(Vo), r(Oc), r(qx), r(Eo), r(Uf), r(Ff), r(ta), r(Ix), r(Iu), r(no), r(io), r(ec), r(lf), r(Fo), r(ba), r(Cf), r(Mx), r(rc), r(Nf), r(Mf), r(Ux), r(Xa), r(Hx), r(vo), r(eo), r(bo), r(v7), r(ka), r(Go), r(Sx), r(Ta), r(la), r(to), r(Wf), r(Mo), r(Io), r(ox), r(I7), r(N7), r(Za), r(ao), r(Qf), r(da), r(kf), r(Fa), r(ax), r(Tx), r(Xf), r(Bo), r(Ef), r(ff), r(To), r(Rf), r(ic), r(yf), r(Ho), r(oo), r(Xo), r(gf), r(ef), r(lx), r(_a), r(px), r(If), r(A7), r(Yo), r(ln), r(Bx), r(of), r(pf), r(Jx), r(Yf), r(za), r(so), r(go), r(va), r(Gx), r(J4)], wpr = [0, r(df), r(ex), r(yo), r(Kf), r(If), r(zf), r(Ua), r(tx), r(Px), r(wa), r(Jo), r(D7), r(Ya), r(no), r(ic), r(_c), r(mx), r(af), r(eo), r(Ux), r(zx), r(li), r(kc), r(jx), r($o), r(vo), r(Af), r(yi), r(Ia), r(qx), r(uo), r(Wf), r(lx), r(ix), r(ef), r(Ga), r(Cf), r(po), r(bc), r(xc), r(ha), r(Jx), r(_o), r(fo), r(Fx), r(bo), r(Lx), r(hf), r(ff), r(Fa), r(ro), r(So), r(Vf), r(Va), r(Wa), r(Xf), r(ac), r(Qu), r(Pf), r(Uo), r(yc), r(sa), r(Na), r(mc), r(ux), r(Za), r(Zx), r(Nf), r(xf), r(nc), r(Qf), r(Rx), r(Ma), r(co), r(go), r(la), r(Fo), r($x), r(nx), r(va), r(_a), r(vx), r(au), r(Qo), r(fa), r(zo), r(pf), r(ga), r(ua), r(sc), r(Rf), r(uc), r(Ha), r(v7), r(Vo), r(Vx), r(ku), r(xo), r(Io), r(tc), r(Ka), r(_x), r(Da), r(kf), r(Mo), r(cc), r(Cx), r(ra), r(na), r(Xa), r(Ff), r(pc), r(io), r(ko), r(mf), r(Eo), r(Of), r(oa), r(wc), r(Fc), r(Dx), r(Oa), r(Bo), r(hx), r(ax), r(Lo), r(Ex), r(Bf), r(da), r(Tf), r($a), r(Yf), r(Xx), r(oo), r(To), r(Co), r(lo), r(Ba), r(Sc), r(dc), r(qu), r(Wu), r(Yo), r(Zo), r(sx), r(hc), r(Ec), r(F7), r(I7), r(_f), r(Ko), r(Ix), r(cf), r(mi), r(Nx), r(Hx), r(Ox), r(Tx), r(uf), r(Wx), r(Ja), r(G7), r(bf), r(Sf), r(Mf), r(Ce), r(Ic), r(ma), r(rc), r(lf), r(Jf), r(qf), r(Do), r(ca), r(Df), r(dx), r(xx), r(Ao), r(px), r(Ta), r(Xo), r(to), r(Bx), r(Gf), r(Zf), r(yx), r(mo), r(gc), r(Ho), r(wo), r(xa), r(Ef), r(sf), r(ka), r(ja), r(Gx), r(fx), r(gf), r(Hf), r(Go), r(Ax), r(ho), r(ao), r(bx), r(qa), r(Wo), r(Uf), r(Ro), r(Ea), r(za), r($f), r(of), r(Iu), r(rx), r(ta), r(kx), r(No), r(Kx), r(N7), r(jf), r(lc), r(ba), r(Sx), r(Lf), r(Qx), r(Po), r(pa), r(ec), r(Ca), r(jo), r(wf), r(ln), r(Yx), r(yf), r(nf), r(Qa), r(Tc), r(ox), r(Mx), r(A7), r(so), r(r7), r(ia), r(Oc), r(Aa), r(rr)], Epr = r(yV), Spr = r(UY), gpr = r(GX), Fpr = r(ZY), Tpr = r(g3), Opr = r(tX), Ipr = r(cv), Apr = r(PU), Npr = r(_Y), Cpr = r(wX), Ppr = r(mX), Dpr = r(as), Lpr = r(Oo), Rpr = r(zU), jpr = r(rX), Gpr = r(Zu), Mpr = r(WY), Bpr = r(PH), qpr = r(A6), Upr = r(Bh), Hpr = r(R2), Xpr = r(j2), Ypr = r(rH), Vpr = r(YU), zpr = r(xY), Kpr = r(vX), Wpr = r(yH), Jpr = r(SX), $pr = r(vU), Zpr = r(ZX), Qpr = r(bX), r5r = r(dH), e5r = r(TH), n5r = r(WH), t5r = r(iV), u5r = r(LU), i5r = r(aX), f5r = r("Set.remove_min_elt"), x5r = [0, [12, 59, [17, [0, r(v), 1, 0], 0]], r(o0)], a5r = [0, [18, [1, [0, [11, r(d), 0], r(d)]], [12, us, 0]], r("@[<2>{")], o5r = [0, [12, 32, 0], r(pi)], c5r = [0, [12, 32, 0], r(pi)], s5r = [0, [17, [0, r(De), 0, 0], [12, br, [17, 0, 0]]], r("@,}@]")], v5r = [0, r("src/hack_forked/utils/collections/flow_set.ml"), 363, 14], l5r = [0, [0, 36, 37], [0, 48, 58], [0, 65, 91], [0, 95, 96], [0, 97, us], [0, Xg, yg], [0, Ni, Kg], [0, mS, wk], [0, dh, iw], [0, In, cT], [0, d6, jw], [0, St, 706], [0, iX, 722], [0, 736, 741], [0, 748, 749], [0, 750, 751], [0, 768, 885], [0, 886, 888], [0, 890, 894], [0, 895, 896], [0, 902, 907], [0, 908, tY], [0, 910, 930], [0, zX, 1014], [0, 1015, 1154], [0, 1155, 1160], [0, 1162, jU], [0, 1329, 1367], [0, 1369, 1370], [0, 1376, 1417], [0, 1425, 1470], [0, 1471, 1472], [0, 1473, 1475], [0, 1476, 1478], [0, 1479, 1480], [0, 1488, 1515], [0, 1519, 1523], [0, 1552, 1563], [0, 1568, 1642], [0, 1646, 1748], [0, 1749, 1757], [0, 1759, 1769], [0, 1770, 1789], [0, 1791, 1792], [0, 1808, 1867], [0, 1869, 1970], [0, 1984, 2038], [0, 2042, 2043], [0, 2045, 2046], [0, Vd, 2094], [0, 2112, 2140], [0, 2144, 2155], [0, 2208, 2229], [0, 2230, 2238], [0, 2259, 2274], [0, 2275, 2404], [0, 2406, 2416], [0, 2417, 2436], [0, 2437, 2445], [0, 2447, 2449], [0, 2451, 2473], [0, 2474, 2481], [0, 2482, 2483], [0, 2486, 2490], [0, 2492, 2501], [0, 2503, 2505], [0, 2507, 2511], [0, 2519, 2520], [0, 2524, 2526], [0, 2527, 2532], [0, 2534, 2546], [0, 2556, 2557], [0, 2558, 2559], [0, 2561, 2564], [0, 2565, 2571], [0, 2575, 2577], [0, 2579, 2601], [0, 2602, 2609], [0, 2610, 2612], [0, 2613, 2615], [0, 2616, 2618], [0, 2620, 2621], [0, 2622, 2627], [0, 2631, 2633], [0, 2635, 2638], [0, 2641, 2642], [0, 2649, 2653], [0, 2654, 2655], [0, 2662, 2678], [0, 2689, 2692], [0, 2693, 2702], [0, 2703, 2706], [0, 2707, 2729], [0, 2730, 2737], [0, 2738, 2740], [0, 2741, 2746], [0, 2748, 2758], [0, 2759, 2762], [0, 2763, 2766], [0, 2768, 2769], [0, 2784, 2788], [0, 2790, 2800], [0, 2809, 2816], [0, 2817, 2820], [0, 2821, 2829], [0, 2831, 2833], [0, 2835, 2857], [0, 2858, 2865], [0, 2866, 2868], [0, 2869, 2874], [0, 2876, 2885], [0, 2887, 2889], [0, 2891, 2894], [0, 2902, 2904], [0, 2908, 2910], [0, 2911, 2916], [0, 2918, 2928], [0, 2929, 2930], [0, 2946, 2948], [0, 2949, 2955], [0, 2958, 2961], [0, 2962, 2966], [0, 2969, 2971], [0, 2972, 2973], [0, 2974, 2976], [0, 2979, 2981], [0, 2984, 2987], [0, 2990, 3002], [0, 3006, 3011], [0, 3014, 3017], [0, 3018, 3022], [0, 3024, 3025], [0, 3031, 3032], [0, 3046, 3056], [0, 3072, 3085], [0, 3086, 3089], [0, 3090, 3113], [0, 3114, 3130], [0, 3133, 3141], [0, 3142, 3145], [0, 3146, 3150], [0, 3157, 3159], [0, 3160, 3163], [0, 3168, 3172], [0, 3174, 3184], [0, 3200, 3204], [0, 3205, 3213], [0, 3214, 3217], [0, 3218, 3241], [0, 3242, 3252], [0, 3253, 3258], [0, 3260, 3269], [0, 3270, 3273], [0, 3274, 3278], [0, 3285, 3287], [0, 3294, 3295], [0, 3296, 3300], [0, 3302, 3312], [0, 3313, 3315], [0, 3328, 3332], [0, 3333, 3341], [0, 3342, 3345], [0, 3346, 3397], [0, 3398, 3401], [0, 3402, 3407], [0, 3412, 3416], [0, 3423, 3428], [0, 3430, 3440], [0, 3450, 3456], [0, 3458, 3460], [0, 3461, 3479], [0, 3482, 3506], [0, 3507, 3516], [0, 3517, 3518], [0, 3520, 3527], [0, 3530, 3531], [0, 3535, 3541], [0, 3542, 3543], [0, 3544, 3552], [0, 3558, 3568], [0, 3570, 3572], [0, 3585, 3643], [0, 3648, 3663], [0, 3664, 3674], [0, 3713, 3715], [0, 3716, 3717], [0, 3718, 3723], [0, 3724, 3748], [0, 3749, 3750], [0, 3751, 3774], [0, 3776, 3781], [0, 3782, 3783], [0, 3784, 3790], [0, 3792, 3802], [0, 3804, 3808], [0, 3840, 3841], [0, 3864, 3866], [0, 3872, 3882], [0, 3893, 3894], [0, 3895, 3896], [0, 3897, 3898], [0, 3902, 3912], [0, 3913, 3949], [0, 3953, 3973], [0, 3974, 3992], [0, 3993, 4029], [0, 4038, 4039], [0, _X, 4170], [0, 4176, 4254], [0, 4256, 4294], [0, 4295, 4296], [0, 4301, 4302], [0, 4304, 4347], [0, 4348, 4681], [0, 4682, 4686], [0, 4688, 4695], [0, 4696, 4697], [0, 4698, 4702], [0, 4704, 4745], [0, 4746, 4750], [0, 4752, 4785], [0, 4786, 4790], [0, 4792, 4799], [0, 4800, 4801], [0, 4802, 4806], [0, 4808, 4823], [0, 4824, 4881], [0, 4882, 4886], [0, 4888, 4955], [0, 4957, 4960], [0, 4969, 4978], [0, 4992, 5008], [0, 5024, 5110], [0, 5112, 5118], [0, 5121, 5741], [0, 5743, Ev], [0, 5761, 5787], [0, 5792, 5867], [0, 5870, 5881], [0, 5888, 5901], [0, 5902, 5909], [0, 5920, 5941], [0, 5952, 5972], [0, 5984, 5997], [0, 5998, 6001], [0, 6002, 6004], [0, 6016, 6100], [0, 6103, 6104], [0, 6108, 6110], [0, 6112, 6122], [0, 6155, 6158], [0, 6160, 6170], [0, 6176, 6265], [0, 6272, 6315], [0, 6320, 6390], [0, 6400, 6431], [0, 6432, 6444], [0, 6448, 6460], [0, 6470, 6510], [0, 6512, 6517], [0, 6528, 6572], [0, 6576, 6602], [0, 6608, 6619], [0, 6656, 6684], [0, 6688, 6751], [0, 6752, 6781], [0, 6783, 6794], [0, 6800, 6810], [0, 6823, 6824], [0, 6832, 6846], [0, 6912, 6988], [0, 6992, 7002], [0, 7019, 7028], [0, 7040, 7156], [0, 7168, 7224], [0, 7232, 7242], [0, 7245, 7294], [0, 7296, 7305], [0, 7312, 7355], [0, 7357, 7360], [0, 7376, 7379], [0, 7380, 7419], [0, 7424, 7674], [0, 7675, 7958], [0, 7960, 7966], [0, 7968, 8006], [0, 8008, 8014], [0, 8016, 8024], [0, 8025, 8026], [0, 8027, 8028], [0, 8029, 8030], [0, 8031, 8062], [0, 8064, 8117], [0, 8118, 8125], [0, 8126, 8127], [0, 8130, 8133], [0, 8134, 8141], [0, 8144, 8148], [0, 8150, 8156], [0, 8160, 8173], [0, 8178, 8181], [0, 8182, 8189], [0, FY, _U], [0, 8255, 8257], [0, 8276, 8277], [0, np, 8306], [0, I3, 8320], [0, 8336, 8349], [0, 8400, 8413], [0, 8417, 8418], [0, 8421, 8433], [0, a3, 8451], [0, j3, 8456], [0, 8458, F4], [0, _6, 8470], [0, cU, 8478], [0, u8, Z3], [0, r3, vp], [0, D8, C8], [0, 8490, 8506], [0, 8508, 8512], [0, 8517, 8522], [0, v8, 8527], [0, 8544, 8585], [0, 11264, 11311], [0, 11312, 11359], [0, 11360, 11493], [0, 11499, 11508], [0, 11520, M4], [0, q8, 11560], [0, C3, 11566], [0, 11568, 11624], [0, m4, 11632], [0, D6, 11671], [0, 11680, G4], [0, 11688, K8], [0, 11696, o8], [0, 11704, W8], [0, 11712, K6], [0, 11720, G8], [0, 11728, T6], [0, 11736, 11743], [0, 11744, 11776], [0, 12293, 12296], [0, 12321, O3], [0, 12337, 12342], [0, 12344, 12349], [0, 12353, 12439], [0, 12441, S3], [0, 12449, U4], [0, 12540, 12544], [0, 12549, S8], [0, 12593, 12687], [0, 12704, 12731], [0, 12784, 12800], [0, 13312, 19894], [0, 19968, 40944], [0, 40960, 42125], [0, 42192, 42238], [0, 42240, 42509], [0, 42512, 42540], [0, 42560, 42608], [0, 42612, H3], [0, 42623, 42738], [0, 42775, 42784], [0, 42786, 42889], [0, 42891, 42944], [0, 42946, 42951], [0, T8, 43048], [0, 43072, 43124], [0, 43136, 43206], [0, 43216, 43226], [0, 43232, 43256], [0, t3, y8], [0, 43261, 43310], [0, 43312, 43348], [0, 43360, 43389], [0, 43392, 43457], [0, w8, 43482], [0, 43488, l6], [0, 43520, 43575], [0, 43584, 43598], [0, 43600, 43610], [0, 43616, 43639], [0, bp, 43715], [0, 43739, 43742], [0, 43744, 43760], [0, 43762, 43767], [0, 43777, 43783], [0, 43785, 43791], [0, 43793, 43799], [0, 43808, w6], [0, 43816, X3], [0, 43824, ov], [0, 43868, o3], [0, 43888, 44011], [0, 44012, 44014], [0, 44016, 44026], [0, 44032, 55204], [0, 55216, 55239], [0, 55243, 55292], [0, 63744, 64110], [0, 64112, 64218], [0, 64256, 64263], [0, 64275, 64280], [0, n3, fp], [0, 64298, Jn], [0, 64312, K3], [0, R6, j4], [0, 64320, U3], [0, 64323, L8], [0, 64326, 64434], [0, 64467, 64830], [0, 64848, 64912], [0, 64914, 64968], [0, 65008, 65020], [0, 65024, 65040], [0, 65056, 65072], [0, 65075, 65077], [0, 65101, 65104], [0, 65136, u3], [0, 65142, 65277], [0, 65296, 65306], [0, 65313, 65339], [0, 65343, r8], [0, 65345, 65371], [0, 65382, 65471], [0, 65474, 65480], [0, 65482, 65488], [0, 65490, 65496], [0, 65498, 65501], [0, ow, ep], [0, 65549, Z8], [0, 65576, K4], [0, 65596, g6], [0, 65599, 65614], [0, 65616, 65630], [0, 65664, 65787], [0, 65856, 65909], [0, 66045, 66046], [0, 66176, 66205], [0, 66208, 66257], [0, 66272, 66273], [0, 66304, 66336], [0, 66349, 66379], [0, 66384, 66427], [0, 66432, 66462], [0, 66464, 66500], [0, 66504, Q3], [0, 66513, 66518], [0, 66560, 66718], [0, 66720, 66730], [0, 66736, 66772], [0, 66776, 66812], [0, 66816, 66856], [0, 66864, 66916], [0, 67072, 67383], [0, 67392, 67414], [0, 67424, 67432], [0, 67584, 67590], [0, op, $4], [0, 67594, m8], [0, 67639, 67641], [0, B6, 67645], [0, 67647, 67670], [0, 67680, 67703], [0, 67712, 67743], [0, 67808, Y8], [0, 67828, 67830], [0, 67840, 67862], [0, 67872, 67898], [0, 67968, 68024], [0, 68030, 68032], [0, S7, 68100], [0, 68101, 68103], [0, 68108, p4], [0, 68117, Q8], [0, 68121, 68150], [0, 68152, 68155], [0, 68159, 68160], [0, 68192, 68221], [0, 68224, 68253], [0, 68288, $6], [0, 68297, 68327], [0, 68352, 68406], [0, 68416, 68438], [0, 68448, 68467], [0, 68480, 68498], [0, 68608, 68681], [0, 68736, 68787], [0, 68800, 68851], [0, 68864, 68904], [0, 68912, 68922], [0, 69376, 69405], [0, $8, 69416], [0, 69424, 69457], [0, 69600, 69623], [0, 69632, 69703], [0, 69734, q3], [0, 69759, 69819], [0, 69840, 69865], [0, 69872, 69882], [0, 69888, 69941], [0, 69942, 69952], [0, _4, T3], [0, 69968, 70004], [0, Y6, 70007], [0, 70016, 70085], [0, 70089, 70093], [0, 70096, h8], [0, f3, 70109], [0, 70144, N8], [0, 70163, 70200], [0, 70206, 70207], [0, 70272, d3], [0, A8, xp], [0, 70282, I8], [0, 70287, s8], [0, 70303, 70313], [0, 70320, 70379], [0, 70384, 70394], [0, 70400, i6], [0, 70405, 70413], [0, 70415, 70417], [0, 70419, x3], [0, 70442, c8], [0, 70450, P4], [0, 70453, 70458], [0, 70459, 70469], [0, 70471, 70473], [0, 70475, 70478], [0, G6, 70481], [0, 70487, 70488], [0, 70493, 70500], [0, 70502, 70509], [0, 70512, 70517], [0, 70656, 70731], [0, 70736, 70746], [0, J6, 70752], [0, 70784, r6], [0, Q6, 70856], [0, 70864, 70874], [0, 71040, 71094], [0, 71096, 71105], [0, 71128, 71134], [0, 71168, 71233], [0, i8, 71237], [0, 71248, 71258], [0, 71296, 71353], [0, 71360, 71370], [0, 71424, 71451], [0, 71453, 71468], [0, 71472, 71482], [0, 71680, 71739], [0, 71840, 71914], [0, 71935, 71936], [0, 72096, 72104], [0, 72106, 72152], [0, 72154, ip], [0, m3, 72165], [0, B8, 72255], [0, 72263, 72264], [0, i3, 72346], [0, D4, 72350], [0, 72384, 72441], [0, 72704, J3], [0, 72714, 72759], [0, 72760, 72769], [0, 72784, 72794], [0, 72818, 72848], [0, 72850, 72872], [0, 72873, 72887], [0, 72960, L3], [0, 72968, h4], [0, 72971, 73015], [0, 73018, 73019], [0, 73020, 73022], [0, 73023, 73032], [0, 73040, 73050], [0, 73056, j6], [0, 73063, h3], [0, 73066, 73103], [0, 73104, 73106], [0, 73107, 73113], [0, 73120, 73130], [0, 73440, 73463], [0, 73728, 74650], [0, 74752, 74863], [0, 74880, 75076], [0, 77824, 78895], [0, 82944, 83527], [0, 92160, 92729], [0, 92736, 92767], [0, 92768, 92778], [0, 92880, 92910], [0, 92912, 92917], [0, 92928, 92983], [0, 92992, 92996], [0, 93008, 93018], [0, 93027, 93048], [0, 93053, 93072], [0, 93760, 93824], [0, 93952, 94027], [0, Q4, 94088], [0, 94095, 94112], [0, 94176, p6], [0, h6, 94180], [0, 94208, 100344], [0, 100352, 101107], [0, 110592, 110879], [0, 110928, 110931], [0, 110948, 110952], [0, 110960, 111356], [0, 113664, 113771], [0, 113776, 113789], [0, 113792, 113801], [0, 113808, 113818], [0, 113821, 113823], [0, 119141, 119146], [0, 119149, 119155], [0, 119163, 119171], [0, 119173, 119180], [0, 119210, 119214], [0, 119362, 119365], [0, 119808, O6], [0, 119894, B3], [0, 119966, 119968], [0, k3, 119971], [0, 119973, 119975], [0, 119977, rp], [0, 119982, b8], [0, b4, M6], [0, 119997, A3], [0, 120005, R4], [0, 120071, 120075], [0, 120077, C6], [0, 120086, lp], [0, 120094, P3], [0, 120123, e6], [0, 120128, q4], [0, M3, 120135], [0, 120138, L6], [0, 120146, 120486], [0, 120488, L4], [0, 120514, z3], [0, 120540, s6], [0, 120572, Y4], [0, 120598, s3], [0, 120630, z4], [0, 120656, E6], [0, 120688, l4], [0, 120714, b6], [0, 120746, w3], [0, 120772, 120780], [0, 120782, 120832], [0, 121344, 121399], [0, 121403, 121453], [0, 121461, 121462], [0, 121476, 121477], [0, 121499, 121504], [0, 121505, 121520], [0, 122880, 122887], [0, 122888, 122905], [0, 122907, 122914], [0, 122915, 122917], [0, 122918, 122923], [0, 123136, 123181], [0, 123184, 123198], [0, 123200, 123210], [0, cp, 123215], [0, 123584, 123642], [0, 124928, 125125], [0, 125136, 125143], [0, 125184, 125260], [0, 125264, 125274], [0, 126464, P6], [0, 126469, $3], [0, 126497, c3], [0, F8, 126501], [0, n8, _8], [0, 126505, v6], [0, 126516, x8], [0, y6, a8], [0, E3, 126524], [0, W3, 126531], [0, R8, H6], [0, g8, t8], [0, v3, B4], [0, 126541, T4], [0, 126545, F6], [0, k8, 126549], [0, f8, S4], [0, Ze, q6], [0, g4, M8], [0, U6, v4], [0, u6, I4], [0, 126561, ap], [0, z6, 126565], [0, 126567, b3], [0, 126572, a6], [0, 126580, J8], [0, 126585, R3], [0, Z4, E8], [0, 126592, z8], [0, 126603, 126620], [0, 126625, G3], [0, 126629, e3], [0, 126635, 126652], [0, 131072, 173783], [0, 173824, 177973], [0, 177984, 178206], [0, 178208, 183970], [0, 183984, 191457], [0, 194560, 195102], [0, 917760, 918e3]], b5r = r(O2), p5r = r(hv), m5r = r(Tv), _5r = r(W4), y5r = r("Cannot export an enum with `export type`, try `export enum E {}` or `module.exports = E;` instead."), d5r = r("Enum members are separated with `,`. Replace `;` with `,`."), h5r = r("Unexpected reserved word"), k5r = r("Unexpected reserved type"), w5r = r("Unexpected `super` outside of a class method"), E5r = r("`super()` is only valid in a class constructor"), S5r = r("Unexpected end of input"), g5r = r("Unexpected variance sigil"), F5r = r("Unexpected static modifier"), T5r = r("Unexpected proto modifier"), O5r = r("Type aliases are not allowed in untyped mode"), I5r = r("Opaque type aliases are not allowed in untyped mode"), A5r = r("Type annotations are not allowed in untyped mode"), N5r = r("Type declarations are not allowed in untyped mode"), C5r = r("Type imports are not allowed in untyped mode"), P5r = r("Type exports are not allowed in untyped mode"), D5r = r("Interfaces are not allowed in untyped mode"), L5r = r("Spreading a type is only allowed inside an object type"), R5r = r("Explicit inexact syntax must come at the end of an object type"), j5r = r("Explicit inexact syntax cannot appear inside an explicit exact object type"), G5r = r("Explicit inexact syntax can only appear inside an object type"), M5r = r("Illegal newline after throw"), B5r = r("A bigint literal must be an integer"), q5r = r("A bigint literal cannot use exponential notation"), U5r = r("Invalid regular expression"), H5r = r("Invalid regular expression: missing /"), X5r = r("Invalid left-hand side in assignment"), Y5r = r("Invalid left-hand side in exponentiation expression"), V5r = r("Invalid left-hand side in for-in"), z5r = r("Invalid left-hand side in for-of"), K5r = r("Invalid optional indexed access. Indexed access uses bracket notation. Use the format `T?.[K]`."), W5r = r("found an expression instead"), J5r = r("Expected an object pattern, array pattern, or an identifier but "), $5r = r("More than one default clause in switch statement"), Z5r = r("Missing catch or finally after try"), Q5r = r("Illegal continue statement"), rmr = r("Illegal break statement"), emr = r("Illegal return statement"), nmr = r("Illegal Unicode escape"), tmr = r("Strict mode code may not include a with statement"), umr = r("Catch variable may not be eval or arguments in strict mode"), imr = r("Variable name may not be eval or arguments in strict mode"), fmr = r("Parameter name eval or arguments is not allowed in strict mode"), xmr = r("Strict mode function may not have duplicate parameter names"), amr = r('Illegal "use strict" directive in function with non-simple parameter list'), omr = r("Function name may not be eval or arguments in strict mode"), cmr = r("Octal literals are not allowed in strict mode."), smr = r("Number literals with leading zeros are not allowed in strict mode."), vmr = r("Delete of an unqualified identifier in strict mode."), lmr = r("Duplicate data property in object literal not allowed in strict mode"), bmr = r("Object literal may not have data and accessor property with the same name"), pmr = r("Object literal may not have multiple get/set accessors with the same name"), mmr = r("`typeof` can only be used to get the type of variables."), _mr = r("Assignment to eval or arguments is not allowed in strict mode"), ymr = r("Postfix increment/decrement may not have eval or arguments operand in strict mode"), dmr = r("Prefix increment/decrement may not have eval or arguments operand in strict mode"), hmr = r("Use of future reserved word in strict mode"), kmr = r("JSX attributes must only be assigned a non-empty expression"), wmr = r("JSX value should be either an expression or a quoted JSX text"), Emr = r("Const must be initialized"), Smr = r("Destructuring assignment must be initialized"), gmr = r("Illegal newline before arrow"), Fmr = r(vF), Tmr = r("Async functions can only be declared at top level or "), Omr = r(vF), Imr = r("Generators can only be declared at top level or "), Amr = r("elements must be wrapped in an enclosing parent tag"), Nmr = r("Unexpected token <. Remember, adjacent JSX "), Cmr = r("Rest parameter must be final parameter of an argument list"), Pmr = r("Rest element must be final element of an array pattern"), Dmr = r("Rest property must be final property of an object pattern"), Lmr = r("async is an implementation detail and isn't necessary for your declare function statement. It is sufficient for your declare function to just have a Promise return type."), Rmr = r("`declare` modifier can only appear on class fields."), jmr = r("Unexpected token `=`. Initializers are not allowed in a `declare`."), Gmr = r("Unexpected token `=`. Initializers are not allowed in a `declare opaque type`."), Mmr = r("`declare export let` is not supported. Use `declare export var` instead."), Bmr = r("`declare export const` is not supported. Use `declare export var` instead."), qmr = r("`declare export type` is not supported. Use `export type` instead."), Umr = r("`declare export interface` is not supported. Use `export interface` instead."), Hmr = r("`export * as` is an early-stage proposal and is not enabled by default. To enable support in the parser, use the `esproposal_export_star_as` option"), Xmr = r("Found a decorator in an unsupported position."), Ymr = r("Type parameter declaration needs a default, since a preceding type parameter declaration has a default."), Vmr = r("Duplicate `declare module.exports` statement!"), zmr = r("Found both `declare module.exports` and `declare export` in the same module. Modules can only have 1 since they are either an ES module xor they are a CommonJS module."), Kmr = r("Getter should have zero parameters"), Wmr = r("Setter should have exactly one parameter"), Jmr = r("`import type` or `import typeof`!"), $mr = r("Imports within a `declare module` body must always be "), Zmr = r("The `type` and `typeof` keywords on named imports can only be used on regular `import` statements. It cannot be used with `import type` or `import typeof` statements"), Qmr = r("Missing comma between import specifiers"), r9r = r("Missing comma between export specifiers"), e9r = r("Malformed unicode"), n9r = r("Classes may only have one constructor"), t9r = r("Private fields may not be deleted."), u9r = r("Private fields can only be referenced from within a class."), i9r = r("You may not access a private field through the `super` keyword."), f9r = r("Yield expression not allowed in formal parameter"), x9r = r("`await` is an invalid identifier in async functions"), a9r = r("`yield` is an invalid identifier in generators"), o9r = r("either a `let` binding pattern, or a member expression."), c9r = r("`let [` is ambiguous in this position because it is "), s9r = r("Literals cannot be used as shorthand properties."), v9r = r("Computed properties must have a value."), l9r = r("Object pattern can't contain methods"), b9r = r("A trailing comma is not permitted after the rest element"), p9r = r("An optional chain may not be used in a `new` expression."), m9r = r("Template literals may not be used in an optional chain."), _9r = r("Unexpected whitespace between `#` and identifier"), y9r = r("A type annotation is required for the `this` parameter."), d9r = r("The `this` parameter must be the first function parameter."), h9r = r("The `this` parameter cannot be optional."), k9r = r("A getter cannot have a `this` parameter."), w9r = r("A setter cannot have a `this` parameter."), E9r = r("Arrow functions cannot have a `this` parameter; arrow functions automatically bind `this` when declared."), S9r = r("Constructors cannot have a `this` parameter; constructors don't bind `this` like other functions."), g9r = [0, [11, r("Boolean enum members need to be initialized. Use either `"), [2, 0, [11, r(" = true,` or `"), [2, 0, [11, r(" = false,` in enum `"), [2, 0, [11, r(Fs), 0]]]]]]], r("Boolean enum members need to be initialized. Use either `%s = true,` or `%s = false,` in enum `%s`.")], F9r = [0, [11, r("Enum member names need to be unique, but the name `"), [2, 0, [11, r("` has already been used before in enum `"), [2, 0, [11, r(Fs), 0]]]]], r("Enum member names need to be unique, but the name `%s` has already been used before in enum `%s`.")], T9r = [0, [11, r(DU), [2, 0, [11, r("` has inconsistent member initializers. Either use no initializers, or consistently use literals (either booleans, numbers, or strings) for all member initializers."), 0]]], r("Enum `%s` has inconsistent member initializers. Either use no initializers, or consistently use literals (either booleans, numbers, or strings) for all member initializers.")], O9r = [0, [11, r("Use one of `boolean`, `number`, `string`, or `symbol` in enum `"), [2, 0, [11, r(Fs), 0]]], r("Use one of `boolean`, `number`, `string`, or `symbol` in enum `%s`.")], I9r = [0, [11, r("Enum type `"), [2, 0, [11, r("` is not valid. "), [2, 0, 0]]]], r("Enum type `%s` is not valid. %s")], A9r = [0, [11, r("Supplied enum type is not valid. "), [2, 0, 0]], r("Supplied enum type is not valid. %s")], N9r = [0, [11, r("Enum member names and initializers are separated with `=`. Replace `"), [2, 0, [11, r(":` with `"), [2, 0, [11, r(" =`."), 0]]]]], r("Enum member names and initializers are separated with `=`. Replace `%s:` with `%s =`.")], C9r = [0, [11, r("Symbol enum members cannot be initialized. Use `"), [2, 0, [11, r(",` in enum `"), [2, 0, [11, r(Fs), 0]]]]], r("Symbol enum members cannot be initialized. Use `%s,` in enum `%s`.")], P9r = [0, [11, r(DU), [2, 0, [11, r("` has type `"), [2, 0, [11, r("`, so the initializer of `"), [2, 0, [11, r("` needs to be a "), [2, 0, [11, r(" literal."), 0]]]]]]]]], r("Enum `%s` has type `%s`, so the initializer of `%s` needs to be a %s literal.")], D9r = [0, [11, r("The enum member initializer for `"), [2, 0, [11, r("` needs to be a literal (either a boolean, number, or string) in enum `"), [2, 0, [11, r(Fs), 0]]]]], r("The enum member initializer for `%s` needs to be a literal (either a boolean, number, or string) in enum `%s`.")], L9r = [0, [11, r("Enum member names cannot start with lowercase 'a' through 'z'. Instead of using `"), [2, 0, [11, r("`, consider using `"), [2, 0, [11, r("`, in enum `"), [2, 0, [11, r(Fs), 0]]]]]]], r("Enum member names cannot start with lowercase 'a' through 'z'. Instead of using `%s`, consider using `%s`, in enum `%s`.")], R9r = r("The `...` must come at the end of the enum body. Remove the trailing comma."), j9r = r("The `...` must come after all enum members. Move it to the end of the enum body."), G9r = [0, [11, r("Number enum members need to be initialized, e.g. `"), [2, 0, [11, r(" = 1,` in enum `"), [2, 0, [11, r(Fs), 0]]]]], r("Number enum members need to be initialized, e.g. `%s = 1,` in enum `%s`.")], M9r = [0, [11, r("String enum members need to consistently either all use initializers, or use no initializers, in enum "), [2, 0, [12, 46, 0]]], r("String enum members need to consistently either all use initializers, or use no initializers, in enum %s.")], B9r = [0, [11, r(zH), [2, 0, 0]], r("Unexpected %s")], q9r = [0, [11, r(zH), [2, 0, [11, r(", expected "), [2, 0, 0]]]], r("Unexpected %s, expected %s")], U9r = [0, [11, r(dV), [2, 0, [11, r("`. Did you mean `"), [2, 0, [11, r("`?"), 0]]]]], r("Unexpected token `%s`. Did you mean `%s`?")], H9r = r(D3), X9r = r("Invalid flags supplied to RegExp constructor '"), Y9r = r("Remove the period."), V9r = r("Indexed access uses bracket notation."), z9r = [0, [11, r("Invalid indexed access. "), [2, 0, [11, r(" Use the format `T[K]`."), 0]]], r("Invalid indexed access. %s Use the format `T[K]`.")], K9r = r(D3), W9r = r("Undefined label '"), J9r = r("' has already been declared"), $9r = r(" '"), Z9r = r("Expected corresponding JSX closing tag for "), Q9r = r(vF), r_r = r("In strict mode code, functions can only be declared at top level or "), e_r = r("inside a block, or as the body of an if statement."), n_r = r("In non-strict mode code, functions can only be declared at top level, "), t_r = [0, [11, r("Duplicate export for `"), [2, 0, [12, 96, 0]]], r("Duplicate export for `%s`")], u_r = r("` is declared more than once."), i_r = r("Private fields may only be declared once. `#"), f_r = r("static "), x_r = r(C), a_r = r(JY), o_r = r("methods"), c_r = r("fields"), s_r = r(Fs), v_r = r(" named `"), l_r = r("Classes may not have "), b_r = r("` has not been declared."), p_r = r("Private fields must be declared before they can be referenced. `#"), m_r = [0, [11, r(dV), [2, 0, [11, r("`. Parentheses are required to combine `??` with `&&` or `||` expressions."), 0]]], r("Unexpected token `%s`. Parentheses are required to combine `??` with `&&` or `||` expressions.")], __r = r("Parse_error.Error"), y_r = [0, r("src/third-party/sedlex/flow_sedlexing.ml"), v1, 4], d_r = r("Flow_sedlexing.MalFormed"), h_r = [0, 1, 0], k_r = [0, 0, [0, 1, 0], [0, 1, 0]], w_r = r(JU), E_r = r("end of input"), S_r = r(rl), g_r = r("template literal part"), F_r = r(rl), T_r = r(XH), O_r = r(JU), I_r = r(rl), A_r = r(hv), N_r = r(rl), C_r = r(a1), P_r = r(rl), D_r = r(Tv), L_r = r("an"), R_r = r(yi), j_r = r(pi), G_r = [0, [11, r("token `"), [2, 0, [12, 96, 0]]], r("token `%s`")], M_r = r(SH), B_r = r(p3), q_r = r("{|"), U_r = r("|}"), H_r = r(KX), X_r = r(Z0), Y_r = r("["), V_r = r("]"), z_r = r($Y), K_r = r(","), W_r = r(Ra), J_r = r("=>"), $_r = r("..."), Z_r = r(AX), Q_r = r(JY), ryr = r(M2), eyr = r(N3), nyr = r(R2), tyr = r(j2), uyr = r(Wu), iyr = r(D7), fyr = r(f1), xyr = r(F7), ayr = r(k4), oyr = r(U2), cyr = r(W6), syr = r(P8), vyr = r(D2), lyr = r(G2), byr = r(xs), pyr = r(Pi), myr = r(Mi), _yr = r(A7), yyr = r(k6), dyr = r(o6), hyr = r(N7), kyr = r(_i), wyr = r(y4), Eyr = r(U8), Syr = r(tp), gyr = r(q2), Fyr = r(P7), Tyr = r(eu), Oyr = r(H4), Iyr = r(i1), Ayr = r(J2), Nyr = r(es), Cyr = r(ns), Pyr = r(p8), Dyr = r(y3), Lyr = r(qu), Ryr = r(yv), jyr = r(gs), Gyr = r(r7), Myr = r(d4), Byr = r(w4), qyr = r(c6), Uyr = r(S6), Hyr = r(ku), Xyr = r(I7), Yyr = r(T2), Vyr = r($c), zyr = r(ud), Kyr = r(LS), Wyr = r(Os), Jyr = r(wx), $yr = r("%checks"), Zyr = r(bX), Qyr = r(ZX), rdr = r(vU), edr = r(TH), ndr = r(dH), tdr = r(WH), udr = r(SX), idr = r(yH), fdr = r(xY), xdr = r(vX), adr = r(YU), odr = r(rH), cdr = r(iV), sdr = r(LU), vdr = r(aX), ldr = r(zO), bdr = r("?."), pdr = r(gn), mdr = r("?"), _dr = r(o1), ydr = r(ZH), ddr = r(XX), hdr = r(PH), kdr = r(A6), wdr = r(Bh), Edr = r(yV), Sdr = r(UY), gdr = r(GX), Fdr = r(ZY), Tdr = r(tX), Odr = r(PU), Idr = r(g3), Adr = r(cv), Ndr = r(_Y), Cdr = r(wX), Pdr = r(mX), Ddr = r(as), Ldr = r(Oo), Rdr = r(Zu), jdr = r(zU), Gdr = r(rX), Mdr = r(WY), Bdr = r(ct), qdr = r(tV), Udr = r(mH), Hdr = r(lV), Xdr = r(C), Ydr = r(t6), Vdr = r(X8), zdr = r(v7), Kdr = r(hv), Wdr = r(a1), Jdr = r(Tv), $dr = r(ns), Zdr = r(W4), Qdr = r(Zu), rhr = r(Zu), ehr = r(O2), nhr = r(I6), thr = r("T_LCURLY"), uhr = r("T_RCURLY"), ihr = r("T_LCURLYBAR"), fhr = r("T_RCURLYBAR"), xhr = r("T_LPAREN"), ahr = r("T_RPAREN"), ohr = r("T_LBRACKET"), chr = r("T_RBRACKET"), shr = r("T_SEMICOLON"), vhr = r("T_COMMA"), lhr = r("T_PERIOD"), bhr = r("T_ARROW"), phr = r("T_ELLIPSIS"), mhr = r("T_AT"), _hr = r("T_POUND"), yhr = r("T_FUNCTION"), dhr = r("T_IF"), hhr = r("T_IN"), khr = r("T_INSTANCEOF"), whr = r("T_RETURN"), Ehr = r("T_SWITCH"), Shr = r("T_THIS"), ghr = r("T_THROW"), Fhr = r("T_TRY"), Thr = r("T_VAR"), Ohr = r("T_WHILE"), Ihr = r("T_WITH"), Ahr = r("T_CONST"), Nhr = r("T_LET"), Chr = r("T_NULL"), Phr = r("T_FALSE"), Dhr = r("T_TRUE"), Lhr = r("T_BREAK"), Rhr = r("T_CASE"), jhr = r("T_CATCH"), Ghr = r("T_CONTINUE"), Mhr = r("T_DEFAULT"), Bhr = r("T_DO"), qhr = r("T_FINALLY"), Uhr = r("T_FOR"), Hhr = r("T_CLASS"), Xhr = r("T_EXTENDS"), Yhr = r("T_STATIC"), Vhr = r("T_ELSE"), zhr = r("T_NEW"), Khr = r("T_DELETE"), Whr = r("T_TYPEOF"), Jhr = r("T_VOID"), $hr = r("T_ENUM"), Zhr = r("T_EXPORT"), Qhr = r("T_IMPORT"), rkr = r("T_SUPER"), ekr = r("T_IMPLEMENTS"), nkr = r("T_INTERFACE"), tkr = r("T_PACKAGE"), ukr = r("T_PRIVATE"), ikr = r("T_PROTECTED"), fkr = r("T_PUBLIC"), xkr = r("T_YIELD"), akr = r("T_DEBUGGER"), okr = r("T_DECLARE"), ckr = r("T_TYPE"), skr = r("T_OPAQUE"), vkr = r("T_OF"), lkr = r("T_ASYNC"), bkr = r("T_AWAIT"), pkr = r("T_CHECKS"), mkr = r("T_RSHIFT3_ASSIGN"), _kr = r("T_RSHIFT_ASSIGN"), ykr = r("T_LSHIFT_ASSIGN"), dkr = r("T_BIT_XOR_ASSIGN"), hkr = r("T_BIT_OR_ASSIGN"), kkr = r("T_BIT_AND_ASSIGN"), wkr = r("T_MOD_ASSIGN"), Ekr = r("T_DIV_ASSIGN"), Skr = r("T_MULT_ASSIGN"), gkr = r("T_EXP_ASSIGN"), Fkr = r("T_MINUS_ASSIGN"), Tkr = r("T_PLUS_ASSIGN"), Okr = r("T_NULLISH_ASSIGN"), Ikr = r("T_AND_ASSIGN"), Akr = r("T_OR_ASSIGN"), Nkr = r("T_ASSIGN"), Ckr = r("T_PLING_PERIOD"), Pkr = r("T_PLING_PLING"), Dkr = r("T_PLING"), Lkr = r("T_COLON"), Rkr = r("T_OR"), jkr = r("T_AND"), Gkr = r("T_BIT_OR"), Mkr = r("T_BIT_XOR"), Bkr = r("T_BIT_AND"), qkr = r("T_EQUAL"), Ukr = r("T_NOT_EQUAL"), Hkr = r("T_STRICT_EQUAL"), Xkr = r("T_STRICT_NOT_EQUAL"), Ykr = r("T_LESS_THAN_EQUAL"), Vkr = r("T_GREATER_THAN_EQUAL"), zkr = r("T_LESS_THAN"), Kkr = r("T_GREATER_THAN"), Wkr = r("T_LSHIFT"), Jkr = r("T_RSHIFT"), $kr = r("T_RSHIFT3"), Zkr = r("T_PLUS"), Qkr = r("T_MINUS"), rwr = r("T_DIV"), ewr = r("T_MULT"), nwr = r("T_EXP"), twr = r("T_MOD"), uwr = r("T_NOT"), iwr = r("T_BIT_NOT"), fwr = r("T_INCR"), xwr = r("T_DECR"), awr = r("T_EOF"), owr = r("T_ANY_TYPE"), cwr = r("T_MIXED_TYPE"), swr = r("T_EMPTY_TYPE"), vwr = r("T_NUMBER_TYPE"), lwr = r("T_BIGINT_TYPE"), bwr = r("T_STRING_TYPE"), pwr = r("T_VOID_TYPE"), mwr = r("T_SYMBOL_TYPE"), _wr = r("T_NUMBER"), ywr = r("T_BIGINT"), dwr = r("T_STRING"), hwr = r("T_TEMPLATE_PART"), kwr = r("T_IDENTIFIER"), wwr = r("T_REGEXP"), Ewr = r("T_ERROR"), Swr = r("T_JSX_IDENTIFIER"), gwr = r("T_JSX_TEXT"), Fwr = r("T_BOOLEAN_TYPE"), Twr = r("T_NUMBER_SINGLETON_TYPE"), Owr = r("T_BIGINT_SINGLETON_TYPE"), Iwr = [0, r(FX), VT, 9], Awr = [0, r(FX), N6, 9], Nwr = r(HH), Cwr = r("*/"), Pwr = r(HH), Dwr = r("unreachable line_comment"), Lwr = r("unreachable string_quote"), Rwr = r("\\"), jwr = r("unreachable template_part"), Gwr = r("${"), Mwr = r(zY), Bwr = r(zY), qwr = r(UI), Uwr = r("unreachable regexp_class"), Hwr = r(oY), Xwr = r("unreachable regexp_body"), Ywr = r(C), Vwr = r(C), zwr = r(C), Kwr = r(C), Wwr = r("unreachable jsxtext"), Jwr = r(D3), $wr = r(V2), Zwr = r(g3), Qwr = r(cv), rEr = r(SH), eEr = r(p3), nEr = r("{'}'}"), tEr = r(p3), uEr = r("{'>'}"), iEr = r(cv), fEr = r(b1), xEr = r("iexcl"), aEr = r("aelig"), oEr = r("Nu"), cEr = r("Eacute"), sEr = r("Atilde"), vEr = r("'int'"), lEr = r("AElig"), bEr = r("Aacute"), pEr = r("Acirc"), mEr = r("Agrave"), _Er = r("Alpha"), yEr = r("Aring"), dEr = [0, SY], hEr = [0, 913], kEr = [0, In], wEr = [0, iI], EEr = [0, VT], SEr = [0, _H], gEr = [0, 8747], FEr = r("Auml"), TEr = r("Beta"), OEr = r("Ccedil"), IEr = r("Chi"), AEr = r("Dagger"), NEr = r("Delta"), CEr = r("ETH"), PEr = [0, wH], DEr = [0, 916], LEr = [0, 8225], REr = [0, 935], jEr = [0, uX], GEr = [0, 914], MEr = [0, WX], BEr = [0, vY], qEr = r("Icirc"), UEr = r("Ecirc"), HEr = r("Egrave"), XEr = r("Epsilon"), YEr = r("Eta"), VEr = r("Euml"), zEr = r("Gamma"), KEr = r("Iacute"), WEr = [0, $H], JEr = [0, 915], $Er = [0, fV], ZEr = [0, 919], QEr = [0, 917], rSr = [0, RU], eSr = [0, xH], nSr = r("Igrave"), tSr = r("Iota"), uSr = r("Iuml"), iSr = r("Kappa"), fSr = r("Lambda"), xSr = r("Mu"), aSr = r("Ntilde"), oSr = [0, Zg], cSr = [0, 924], sSr = [0, 923], vSr = [0, 922], lSr = [0, LX], bSr = [0, 921], pSr = [0, rY], mSr = [0, CH], _Sr = [0, mY], ySr = r("Sigma"), dSr = r("Otilde"), hSr = r("OElig"), kSr = r("Oacute"), wSr = r("Ocirc"), ESr = r("Ograve"), SSr = r("Omega"), gSr = r("Omicron"), FSr = r("Oslash"), TSr = [0, d6], OSr = [0, 927], ISr = [0, 937], ASr = [0, N6], NSr = [0, EY], CSr = [0, EU], PSr = [0, 338], DSr = r("Ouml"), LSr = r("Phi"), RSr = r("Pi"), jSr = r("Prime"), GSr = r("Psi"), MSr = r("Rho"), BSr = r("Scaron"), qSr = [0, 352], USr = [0, 929], HSr = [0, 936], XSr = [0, 8243], YSr = [0, 928], VSr = [0, 934], zSr = [0, dT], KSr = [0, qX], WSr = r("Uuml"), JSr = r("THORN"), $Sr = r("Tau"), ZSr = r("Theta"), QSr = r("Uacute"), rgr = r("Ucirc"), egr = r("Ugrave"), ngr = r("Upsilon"), tgr = [0, 933], ugr = [0, sp], igr = [0, NU], fgr = [0, Lw], xgr = [0, 920], agr = [0, 932], ogr = [0, NX], cgr = r("Xi"), sgr = r("Yacute"), vgr = r("Yuml"), lgr = r("Zeta"), bgr = r("aacute"), pgr = r("acirc"), mgr = r("acute"), _gr = [0, mU], ygr = [0, tk], dgr = [0, HO], hgr = [0, 918], kgr = [0, 376], wgr = [0, HX], Egr = [0, 926], Sgr = [0, aA], ggr = [0, zX], Fgr = [0, 925], Tgr = r("delta"), Ogr = r("cap"), Igr = r("aring"), Agr = r("agrave"), Ngr = r("alefsym"), Cgr = r("alpha"), Pgr = r("amp"), Dgr = r("and"), Lgr = r("ang"), Rgr = r("apos"), jgr = [0, 39], Ggr = [0, 8736], Mgr = [0, 8743], Bgr = [0, 38], qgr = [0, 945], Ugr = [0, 8501], Hgr = [0, dv], Xgr = r("asymp"), Ygr = r("atilde"), Vgr = r("auml"), zgr = r("bdquo"), Kgr = r("beta"), Wgr = r("brvbar"), Jgr = r("bull"), $gr = [0, 8226], Zgr = [0, MY], Qgr = [0, 946], rFr = [0, 8222], eFr = [0, sV], nFr = [0, eX], tFr = [0, 8776], uFr = [0, dU], iFr = r("copy"), fFr = r("ccedil"), xFr = r("cedil"), aFr = r("cent"), oFr = r("chi"), cFr = r("circ"), sFr = r("clubs"), vFr = r("cong"), lFr = [0, 8773], bFr = [0, 9827], pFr = [0, iX], mFr = [0, 967], _Fr = [0, Sd], yFr = [0, wk], dFr = [0, VX], hFr = r("crarr"), kFr = r("cup"), wFr = r("curren"), EFr = r("dArr"), SFr = r("dagger"), gFr = r("darr"), FFr = r("deg"), TFr = [0, kV], OFr = [0, 8595], IFr = [0, 8224], AFr = [0, 8659], NFr = [0, PF], CFr = [0, 8746], PFr = [0, 8629], DFr = [0, RX], LFr = [0, 8745], RFr = r("fnof"), jFr = r("ensp"), GFr = r("diams"), MFr = r("divide"), BFr = r("eacute"), qFr = r("ecirc"), UFr = r("egrave"), HFr = r(v7), XFr = r("emsp"), YFr = [0, 8195], VFr = [0, 8709], zFr = [0, eT], KFr = [0, aH], WFr = [0, wT], JFr = [0, jw], $Fr = [0, 9830], ZFr = r("epsilon"), QFr = r("equiv"), rTr = r("eta"), eTr = r("eth"), nTr = r("euml"), tTr = r("euro"), uTr = r("exist"), iTr = [0, 8707], fTr = [0, 8364], xTr = [0, eH], aTr = [0, v1], oTr = [0, 951], cTr = [0, 8801], sTr = [0, 949], vTr = [0, 8194], lTr = r("gt"), bTr = r("forall"), pTr = r("frac12"), mTr = r("frac14"), _Tr = r("frac34"), yTr = r("frasl"), dTr = r("gamma"), hTr = r("ge"), kTr = [0, 8805], wTr = [0, 947], ETr = [0, 8260], STr = [0, PY], gTr = [0, cY], FTr = [0, sX], TTr = [0, 8704], OTr = r("hArr"), ITr = r("harr"), ATr = r("hearts"), NTr = r("hellip"), CTr = r("iacute"), PTr = r("icirc"), DTr = [0, pH], LTr = [0, YY], RTr = [0, 8230], jTr = [0, 9829], GTr = [0, 8596], MTr = [0, 8660], BTr = [0, 62], qTr = [0, 402], UTr = [0, 948], HTr = [0, Bd], XTr = r("prime"), YTr = r("ndash"), VTr = r("le"), zTr = r("kappa"), KTr = r("igrave"), WTr = r("image"), JTr = r("infin"), $Tr = r("iota"), ZTr = r("iquest"), QTr = r("isin"), rOr = r("iuml"), eOr = [0, f6], nOr = [0, 8712], tOr = [0, yX], uOr = [0, 953], iOr = [0, 8734], fOr = [0, 8465], xOr = [0, mO], aOr = r("lArr"), oOr = r("lambda"), cOr = r("lang"), sOr = r("laquo"), vOr = r("larr"), lOr = r("lceil"), bOr = r("ldquo"), pOr = [0, 8220], mOr = [0, 8968], _Or = [0, 8592], yOr = [0, yg], dOr = [0, 10216], hOr = [0, 955], kOr = [0, 8656], wOr = [0, 954], EOr = r("macr"), SOr = r("lfloor"), gOr = r("lowast"), FOr = r("loz"), TOr = r("lrm"), OOr = r("lsaquo"), IOr = r("lsquo"), AOr = r("lt"), NOr = [0, 60], COr = [0, 8216], POr = [0, 8249], DOr = [0, _U], LOr = [0, 9674], ROr = [0, 8727], jOr = [0, 8970], GOr = r("mdash"), MOr = r("micro"), BOr = r("middot"), qOr = r(pY), UOr = r("mu"), HOr = r("nabla"), XOr = r("nbsp"), YOr = [0, sY], VOr = [0, 8711], zOr = [0, 956], KOr = [0, 8722], WOr = [0, mS], JOr = [0, Ni], $Or = [0, 8212], ZOr = [0, dX], QOr = [0, 8804], rIr = r("or"), eIr = r("oacute"), nIr = r("ne"), tIr = r("ni"), uIr = r("not"), iIr = r("notin"), fIr = r("nsub"), xIr = r("ntilde"), aIr = r("nu"), oIr = [0, 957], cIr = [0, Wy], sIr = [0, 8836], vIr = [0, 8713], lIr = [0, BU], bIr = [0, 8715], pIr = [0, 8800], mIr = r("ocirc"), _Ir = r("oelig"), yIr = r("ograve"), dIr = r("oline"), hIr = r("omega"), kIr = r("omicron"), wIr = r("oplus"), EIr = [0, 8853], SIr = [0, 959], gIr = [0, 969], FIr = [0, 8254], TIr = [0, TT], OIr = [0, 339], IIr = [0, l8], AIr = [0, uH], NIr = r("part"), CIr = r("ordf"), PIr = r("ordm"), DIr = r("oslash"), LIr = r("otilde"), RIr = r("otimes"), jIr = r("ouml"), GIr = r("para"), MIr = [0, Kg], BIr = [0, $2], qIr = [0, 8855], UIr = [0, rV], HIr = [0, St], XIr = [0, dh], YIr = [0, Xg], VIr = r("permil"), zIr = r("perp"), KIr = r("phi"), WIr = r("pi"), JIr = r("piv"), $Ir = r("plusmn"), ZIr = r("pound"), QIr = [0, Sn], rAr = [0, oV], eAr = [0, 982], nAr = [0, 960], tAr = [0, 966], uAr = [0, 8869], iAr = [0, 8240], fAr = [0, 8706], xAr = [0, 8744], aAr = [0, 8211], oAr = r("sup1"), cAr = r("rlm"), sAr = r("raquo"), vAr = r("prod"), lAr = r("prop"), bAr = r("psi"), pAr = r("quot"), mAr = r("rArr"), _Ar = r("radic"), yAr = r("rang"), dAr = [0, 10217], hAr = [0, 8730], kAr = [0, 8658], wAr = [0, 34], EAr = [0, 968], SAr = [0, 8733], gAr = [0, 8719], FAr = r("rarr"), TAr = r("rceil"), OAr = r("rdquo"), IAr = r("real"), AAr = r("reg"), NAr = r("rfloor"), CAr = r("rho"), PAr = [0, 961], DAr = [0, 8971], LAr = [0, nH], RAr = [0, 8476], jAr = [0, 8221], GAr = [0, 8969], MAr = [0, 8594], BAr = [0, iw], qAr = r("sigma"), UAr = r("rsaquo"), HAr = r("rsquo"), XAr = r("sbquo"), YAr = r("scaron"), VAr = r("sdot"), zAr = r("sect"), KAr = r("shy"), WAr = [0, wY], JAr = [0, DT], $Ar = [0, 8901], ZAr = [0, 353], QAr = [0, 8218], rNr = [0, 8217], eNr = [0, 8250], nNr = r("sigmaf"), tNr = r("sim"), uNr = r("spades"), iNr = r("sub"), fNr = r("sube"), xNr = r("sum"), aNr = r("sup"), oNr = [0, 8835], cNr = [0, 8721], sNr = [0, 8838], vNr = [0, 8834], lNr = [0, 9824], bNr = [0, 8764], pNr = [0, 962], mNr = [0, 963], _Nr = [0, 8207], yNr = r("uarr"), dNr = r("thetasym"), hNr = r("sup2"), kNr = r("sup3"), wNr = r("supe"), ENr = r("szlig"), SNr = r("tau"), gNr = r("there4"), FNr = r("theta"), TNr = [0, 952], ONr = [0, 8756], INr = [0, 964], ANr = [0, d8], NNr = [0, 8839], CNr = [0, qY], PNr = [0, OO], DNr = r("thinsp"), LNr = r("thorn"), RNr = r("tilde"), jNr = r("times"), GNr = r("trade"), MNr = r("uArr"), BNr = r("uacute"), qNr = [0, nl], UNr = [0, 8657], HNr = [0, 8482], XNr = [0, cT], YNr = [0, 732], VNr = [0, gv], zNr = [0, 8201], KNr = [0, 977], WNr = r("xi"), JNr = r("ucirc"), $Nr = r("ugrave"), ZNr = r("uml"), QNr = r("upsih"), rCr = r("upsilon"), eCr = r("uuml"), nCr = r("weierp"), tCr = [0, cU], uCr = [0, Y2], iCr = [0, 965], fCr = [0, 978], xCr = [0, DY], aCr = [0, 249], oCr = [0, 251], cCr = r("yacute"), sCr = r("yen"), vCr = r("yuml"), lCr = r("zeta"), bCr = r("zwj"), pCr = r("zwnj"), mCr = [0, FY], _Cr = [0, 8205], yCr = [0, 950], dCr = [0, Ow], hCr = [0, nY], kCr = [0, ih], wCr = [0, 958], ECr = [0, 8593], SCr = [0, AU], gCr = [0, 8242], FCr = [0, WU], TCr = r($Y), OCr = r(Bh), ICr = r("unreachable jsx_child"), ACr = r("unreachable type_token wholenumber"), NCr = r("unreachable type_token wholebigint"), CCr = r("unreachable type_token floatbigint"), PCr = r("unreachable type_token scinumber"), DCr = r("unreachable type_token scibigint"), LCr = r("unreachable type_token hexnumber"), RCr = r("unreachable type_token hexbigint"), jCr = r("unreachable type_token legacyoctnumber"), GCr = r("unreachable type_token octnumber"), MCr = r("unreachable type_token octbigint"), BCr = r("unreachable type_token binnumber"), qCr = r("unreachable type_token bigbigint"), UCr = r("unreachable type_token"), HCr = r(o1), XCr = r(o1), YCr = r(FU), VCr = r(X8), zCr = r(t6), KCr = r(a1), WCr = r(I6), JCr = r(O2), $Cr = r(v7), ZCr = r(P7), QCr = r(Pi), rPr = r(r7), ePr = [9, 1], nPr = [9, 0], tPr = r(xs), uPr = r(hv), iPr = r(eu), fPr = r(Tv), xPr = r(W4), aPr = r(Mi), oPr = r(es), cPr = r(ns), sPr = r("unreachable template_tail"), vPr = r(p3), lPr = [0, r(C), r(C), r(C)], bPr = r("unreachable jsx_tag"), pPr = r(D3), mPr = r("unreachable regexp"), _Pr = r("unreachable token wholenumber"), yPr = r("unreachable token wholebigint"), dPr = r("unreachable token floatbigint"), hPr = r("unreachable token scinumber"), kPr = r("unreachable token scibigint"), wPr = r("unreachable token hexnumber"), EPr = r("unreachable token hexbigint"), SPr = r("unreachable token legacyoctnumber"), gPr = r("unreachable token legacynonoctnumber"), FPr = r("unreachable token octnumber"), TPr = r("unreachable token octbigint"), OPr = r("unreachable token bignumber"), IPr = r("unreachable token bigint"), APr = r("unreachable token"), NPr = r(o1), CPr = r(o1), PPr = r(FU), DPr = [6, r("#!")], LPr = r("expected ?"), RPr = r(j2), jPr = r(y4), GPr = r(D2), MPr = r(Os), BPr = r(wx), qPr = r(A7), UPr = r(k6), HPr = r(o6), XPr = r(q2), YPr = r(N7), VPr = r(I7), zPr = r(T2), KPr = r(_i), WPr = r(J2), JPr = r(tp), $Pr = r(H4), ZPr = r(p8), QPr = r(y3), rDr = r(P7), eDr = r(Pi), nDr = r(U8), tDr = r(M2), uDr = r(N3), iDr = r(gs), fDr = r(qu), xDr = r(R2), aDr = r(yv), oDr = r(d4), cDr = r(r7), sDr = r(G2), vDr = r(i1), lDr = r(xs), bDr = r(LS), pDr = r(ud), mDr = r(w4), _Dr = r(c6), yDr = r(S6), dDr = r(Wu), hDr = r(eu), kDr = r(es), wDr = r(D7), EDr = r(f1), SDr = r(F7), gDr = r(Mi), FDr = r(k4), TDr = r($c), ODr = r(U2), IDr = r(ns), ADr = r(W6), NDr = r(P8), CDr = r(ku), PDr = r("unreachable string_escape"), DDr = r($u), LDr = r(H2), RDr = r(H2), jDr = r($u), GDr = r(gX), MDr = r(lY), BDr = r("n"), qDr = r("r"), UDr = r("t"), HDr = r(hV), XDr = r(H2), YDr = r(b1), VDr = r(b1), zDr = r("unreachable id_char"), KDr = r(b1), WDr = r(b1), JDr = r("Invalid (lexer) bigint "), $Dr = r("Invalid (lexer) bigint binary/octal "), ZDr = r(H2), QDr = r(hH), rLr = r(lU), eLr = r(Dd), nLr = [10, r("token ILLEGAL")], tLr = r("\0"), uLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), iLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), fLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), xLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), aLr = r("\0\0"), oLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), cLr = r(""), sLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), vLr = r("\0"), lLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), bLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), pLr = r("\0\0\0\0"), mLr = r("\0\0\0"), _Lr = r("\x07\x07"), yLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), dLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), hLr = r(`\x07\b	
\v\f\r`), kLr = r(""), wLr = r("\0\0\0"), ELr = r("\0"), SLr = r("\0\0\0\0\0\0"), gLr = r(""), FLr = r(""), TLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), OLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), ILr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), ALr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), NLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), CLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), PLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), DLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), LLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), RLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), jLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), GLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\b\0\0\0\0\0\0	\x07\b"), MLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), BLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), qLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), ULr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), HLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), XLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), YLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), VLr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), zLr = r(`\x07\b	
\v\x07\f\r\x1B																										 	!																										"#$%																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																													`), KLr = r(""), WLr = r(""), JLr = r("\0\0\0\0"), $Lr = r(`\x07\b	
\v\f\r\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x1B\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07`), ZLr = r(`\x07\b	
\v\f\r\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07\x07`), QLr = r("\0\0"), rRr = r(""), eRr = r(""), nRr = r("\x07"), tRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), uRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), iRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), fRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), xRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), aRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), oRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), cRr = r("\0\0\0\0\0\0\0"), sRr = r("\x07"), vRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), lRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), bRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), pRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), mRr = r("\0"), _Rr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), yRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), dRr = r("\0\0"), hRr = r("\0"), kRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), wRr = r(""), ERr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), SRr = r(""), gRr = r(""), FRr = r(""), TRr = r("\0"), ORr = r("\0\0\0"), IRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), ARr = r(""), NRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), CRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), PRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), DRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), LRr = r("\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"), RRr = [0, [11, r("the identifier `"), [2, 0, [12, 96, 0]]], r("the identifier `%s`")], jRr = [0, 1], GRr = [0, 1], MRr = r("@flow"), BRr = r(EX), qRr = r(EX), URr = [0, [11, r("an identifier. When exporting a "), [2, 0, [11, r(" as a named export, you must specify a "), [2, 0, [11, r(" name. Did you mean `export default "), [2, 0, [11, r(" ...`?"), 0]]]]]]], r("an identifier. When exporting a %s as a named export, you must specify a %s name. Did you mean `export default %s ...`?")], HRr = r(F3), XRr = r("Peeking current location when not available"), YRr = r(r7), VRr = r(bv), zRr = r(t6), KRr = r(a1), WRr = r(I6), JRr = r(O2), $Rr = r(v7), ZRr = r(P7), QRr = r(Pi), rjr = r(X8), ejr = r(xs), njr = r(hv), tjr = r(eu), ujr = r(Tv), ijr = r(Mi), fjr = r(es), xjr = r(ns), ajr = r(Pi), ojr = r(xs), cjr = r(Mi), sjr = r(Pi), vjr = r(xs), ljr = r(Mi), bjr = r(C2), pjr = r("eval"), mjr = r(gs), _jr = r(r7), yjr = r(d4), djr = r(w4), hjr = r(c6), kjr = r(S6), wjr = r(eu), Ejr = r(ku), Sjr = r(p8), gjr = r(N3), Fjr = r(_i), Tjr = r(wx), Ojr = r(A7), Ijr = r(k6), Ajr = r(o6), Njr = r(q2), Cjr = r(D2), Pjr = r(N7), Djr = r(I7), Ljr = r(J2), Rjr = r(y4), jjr = r(H4), Gjr = r(y3), Mjr = r(P7), Bjr = r(U8), qjr = r(tp), Ujr = r(M2), Hjr = r(F7), Xjr = r(qu), Yjr = r(R2), Vjr = r(j2), zjr = r(i1), Kjr = r(Wu), Wjr = r(yv), Jjr = r(D7), $jr = r(f1), Zjr = r(k4), Qjr = r(es), rGr = r(U2), eGr = r(ns), nGr = r(W6), tGr = r(P8), uGr = r(ku), iGr = [0, r("src/parser/parser_env.ml"), 343, 9], fGr = r("Internal Error: Tried to add_declared_private with outside of class scope."), xGr = r("Internal Error: `exit_class` called before a matching `enter_class`"), aGr = r(C), oGr = [0, 0, 0], cGr = [0, 0, 0], sGr = r("Parser_env.Try.Rollback"), vGr = r(C), lGr = r(C), bGr = [0, r(ku), r(zx), r(ia), r(gU), r(AY), r(Ia), r(au), r(wc), r(fx), r(cc), r(Bf), r(Oa), r(Da), r(tc), r(Ca), r(Sf), r(Zo), r(fa), r(Dx), r(Of), r(sx), r(Ao), r(Hf), r(ja), r(Jo), r(Vx), r(Zx), r(dx), r(oa), r(xo), r(ua), r(F7), r(Aa), r(Lf), r(Ea), r(Qx), r(Zf), r(Ha), r(ha), r(D7), r(hc), r(Po), r(Fx), r(Kx), r(df), r(Fc), r(qf), r(vx), r(Wu), r(_x), r(mo), r(Ce), r(Qu), r(Qo), r(Va), r(So), r(ra), r(lc), r(co), r(uo), r(Df), r(qa), r(zf), r($f), r(Ec), r(bc), r(lo), r(mf), r(Ka), r(rx), r(nx), r(mi), r(ro), r(Ba), r(wf), r(Ko), r(Ya), r(pc), r(ac), r(Qa), r(ca), r(xx), r(Pf), r(xf), r(Vf), r(tx), r(_o), r(wo), r(Jf), r(uc), r(Tf), r(jx), r(Ua), r(mx), r(hf), r(Af), r(yc), r(rr), r(dc), r($x), r(Xx), r(Lo), r(Wx), r(ux), r(Rx), r(ko), r(Lx), r(kc), r(bx), r($a), r(Sc), r(Ro), r(Wa), r(nc), r(nf), r(Px), r(sa), r(Ax), r(xa), r(Ga), r(Na), r(_c), r(Cx), r(af), r(cf), r(ex), r(Ja), r(ho), r(sc), r(Gf), r(Wo), r(na), r(wa), r(sf), r(r7), r(Co), r(Ox), r(Do), r(Yx), r(ma), r(gc), r(qu), r(zo), r(fo), r(_f), r(yi), r(Kf), r(mc), r($o), r(G7), r(yx), r(po), r(bf), r(Uo), r(Ex), r(Ma), r(yo), r(ix), r(uf), r(jf), r(Tc), r(Nx), r(kx), r(No), r(Ic), r(pa), r(ga), r(li), r(xc), r(hx), r(jo), r(Vo), r(Oc), r(qx), r(Eo), r(Uf), r(Ff), r(ta), r(Ix), r(Iu), r(no), r(io), r(ec), r(lf), r(Fo), r(ba), r(Cf), r(Mx), r(rc), r(Nf), r(Mf), r(Ux), r(Xa), r(Hx), r(vo), r(eo), r(bo), r(v7), r(ka), r(Go), r(Sx), r(Ta), r(la), r(to), r(Wf), r(Mo), r(Io), r(ox), r(I7), r(N7), r(Za), r(ao), r(Qf), r(cH), r(da), r(oH), r(VU), r(kf), r(Fa), r(ax), r(Tx), r(Xf), r(Bo), r(Ef), r(ff), r(To), r(Rf), r(ic), r(yf), r(Ho), r(oo), r(Xo), r(gf), r(ef), r(lx), r(_a), r(px), r(If), r(A7), r(Yo), r(ln), r(Bx), r(of), r(pf), r(Jx), r(Yf), r(za), r(so), r(go), r(va), r(Gx), r(J4)], pGr = [0, r(ku), r(zx), r(ia), r(Ia), r(au), r(wc), r(fx), r(cc), r(Bf), r(Oa), r(Da), r(tc), r(Ca), r(Sf), r(Zo), r(fa), r(Dx), r(Of), r(sx), r(Ao), r(Hf), r(ja), r(Jo), r(Vx), r(Zx), r(dx), r(oa), r(xo), r(ua), r(F7), r(Aa), r(Lf), r(Ea), r(Qx), r(Zf), r(Ha), r(ha), r(D7), r(hc), r(Po), r(Fx), r(Kx), r(df), r(Fc), r(qf), r(vx), r(Wu), r(_x), r(mo), r(Ce), r(Qu), r(Qo), r(Va), r(So), r(ra), r(lc), r(co), r(uo), r(Df), r(qa), r(zf), r($f), r(Ec), r(bc), r(lo), r(mf), r(Ka), r(rx), r(nx), r(mi), r(ro), r(Ba), r(wf), r(Ko), r(Ya), r(pc), r(ac), r(Qa), r(ca), r(xx), r(Pf), r(xf), r(Vf), r(tx), r(_o), r(wo), r(Jf), r(uc), r(Tf), r(jx), r(Ua), r(mx), r(hf), r(Af), r(yc), r(rr), r(dc), r($x), r(Xx), r(Lo), r(Wx), r(ux), r(Rx), r(ko), r(Lx), r(kc), r(bx), r($a), r(Sc), r(Ro), r(Wa), r(nc), r(nf), r(Px), r(sa), r(Ax), r(xa), r(Ga), r(Na), r(_c), r(Cx), r(af), r(cf), r(ex), r(Ja), r(ho), r(sc), r(Gf), r(Wo), r(na), r(wa), r(sf), r(r7), r(Co), r(Ox), r(Do), r(Yx), r(ma), r(gc), r(qu), r(zo), r(fo), r(_f), r(yi), r(Kf), r(mc), r($o), r(G7), r(yx), r(po), r(bf), r(Uo), r(Ex), r(Ma), r(yo), r(ix), r(uf), r(jf), r(Tc), r(Nx), r(kx), r(No), r(Ic), r(pa), r(ga), r(li), r(xc), r(hx), r(jo), r(Vo), r(Oc), r(qx), r(Eo), r(Uf), r(Ff), r(ta), r(Ix), r(Iu), r(no), r(io), r(ec), r(lf), r(Fo), r(ba), r(Cf), r(Mx), r(rc), r(Nf), r(Mf), r(Ux), r(Xa), r(Hx), r(vo), r(eo), r(bo), r(v7), r(ka), r(Go), r(Sx), r(Ta), r(la), r(to), r(Wf), r(Mo), r(Io), r(ox), r(I7), r(N7), r(Za), r(ao), r(Qf), r(da), r(kf), r(Fa), r(ax), r(Tx), r(Xf), r(Bo), r(Ef), r(ff), r(To), r(Rf), r(ic), r(yf), r(Ho), r(oo), r(Xo), r(gf), r(ef), r(lx), r(_a), r(px), r(If), r(A7), r(Yo), r(ln), r(Bx), r(of), r(pf), r(Jx), r(Yf), r(za), r(so), r(go), r(va), r(Gx), r(J4)], mGr = [0, r(df), r(ex), r(yo), r(Kf), r(If), r(zf), r(Ua), r(tx), r(Px), r(wa), r(Jo), r(D7), r(Ya), r(no), r(ic), r(_c), r(mx), r(af), r(eo), r(Ux), r(zx), r(li), r(kc), r(jx), r($o), r(vo), r(Af), r(yi), r(Ia), r(qx), r(uo), r(Wf), r(lx), r(ix), r(ef), r(Ga), r(Cf), r(po), r(bc), r(xc), r(ha), r(Jx), r(_o), r(fo), r(Fx), r(bo), r(Lx), r(hf), r(ff), r(Fa), r(ro), r(So), r(Vf), r(Va), r(Wa), r(Xf), r(ac), r(Qu), r(Pf), r(Uo), r(yc), r(sa), r(Na), r(mc), r(ux), r(Za), r(Zx), r(Nf), r(xf), r(nc), r(Qf), r(Rx), r(Ma), r(co), r(go), r(la), r(Fo), r($x), r(nx), r(va), r(_a), r(vx), r(au), r(Qo), r(fa), r(zo), r(pf), r(ga), r(ua), r(sc), r(Rf), r(uc), r(Ha), r(v7), r(Vo), r(Vx), r(ku), r(xo), r(Io), r(tc), r(Ka), r(_x), r(Da), r(kf), r(Mo), r(cc), r(Cx), r(ra), r(na), r(Xa), r(Ff), r(pc), r(io), r(ko), r(mf), r(Eo), r(Of), r(oa), r(wc), r(Fc), r(Dx), r(Oa), r(Bo), r(hx), r(ax), r(Lo), r(Ex), r(Bf), r(da), r(Tf), r($a), r(Yf), r(Xx), r(oo), r(To), r(Co), r(lo), r(Ba), r(Sc), r(dc), r(qu), r(Wu), r(Yo), r(Zo), r(sx), r(hc), r(Ec), r(F7), r(I7), r(_f), r(Ko), r(Ix), r(cf), r(mi), r(Nx), r(Hx), r(Ox), r(Tx), r(uf), r(Wx), r(Ja), r(G7), r(bf), r(Sf), r(Mf), r(Ce), r(Ic), r(ma), r(rc), r(lf), r(Jf), r(qf), r(Do), r(ca), r(Df), r(dx), r(xx), r(Ao), r(px), r(Ta), r(Xo), r(to), r(Bx), r(Gf), r(Zf), r(yx), r(mo), r(gc), r(Ho), r(wo), r(xa), r(Ef), r(sf), r(ka), r(ja), r(Gx), r(fx), r(gf), r(Hf), r(Go), r(Ax), r(ho), r(ao), r(bx), r(qa), r(Wo), r(Uf), r(Ro), r(Ea), r(za), r($f), r(of), r(Iu), r(rx), r(ta), r(kx), r(No), r(Kx), r(N7), r(jf), r(lc), r(ba), r(Sx), r(Lf), r(Qx), r(Po), r(pa), r(ec), r(Ca), r(jo), r(wf), r(ln), r(Yx), r(yf), r(nf), r(Qa), r(Tc), r(ox), r(Mx), r(A7), r(so), r(r7), r(ia), r(Oc), r(Aa), r(rr)], _Gr = [0, r(df), r(ex), r(yo), r(Kf), r(If), r(zf), r(Ua), r(tx), r(Px), r(wa), r(Jo), r(D7), r(Ya), r(no), r(ic), r(_c), r(mx), r(af), r(eo), r(Ux), r(zx), r(li), r(kc), r(jx), r($o), r(vo), r(Af), r(yi), r(Ia), r(AY), r(qx), r(uo), r(Wf), r(lx), r(ix), r(ef), r(Ga), r(Cf), r(po), r(bc), r(xc), r(ha), r(Jx), r(_o), r(fo), r(Fx), r(bo), r(Lx), r(hf), r(ff), r(Fa), r(ro), r(So), r(oH), r(Vf), r(Va), r(Wa), r(Xf), r(ac), r(Qu), r(Pf), r(Uo), r(yc), r(sa), r(Na), r(mc), r(ux), r(Za), r(Zx), r(Nf), r(xf), r(nc), r(Qf), r(Rx), r(Ma), r(co), r(go), r(la), r(Fo), r($x), r(nx), r(va), r(_a), r(vx), r(au), r(Qo), r(fa), r(zo), r(pf), r(ga), r(ua), r(sc), r(Rf), r(uc), r(Ha), r(v7), r(Vo), r(Vx), r(ku), r(xo), r(Io), r(tc), r(Ka), r(_x), r(Da), r(kf), r(Mo), r(cc), r(Cx), r(ra), r(na), r(Xa), r(Ff), r(pc), r(io), r(ko), r(mf), r(Eo), r(Of), r(oa), r(wc), r(Fc), r(Dx), r(Oa), r(Bo), r(hx), r(ax), r(Lo), r(Ex), r(Bf), r(da), r(Tf), r($a), r(Yf), r(Xx), r(oo), r(To), r(Co), r(lo), r(Ba), r(Sc), r(dc), r(qu), r(Wu), r(Yo), r(Zo), r(sx), r(hc), r(Ec), r(F7), r(I7), r(_f), r(Ko), r(Ix), r(cf), r(mi), r(Nx), r(Hx), r(Ox), r(Tx), r(uf), r(Wx), r(Ja), r(G7), r(bf), r(Sf), r(Mf), r(Ce), r(Ic), r(ma), r(rc), r(lf), r(Jf), r(qf), r(Do), r(ca), r(Df), r(dx), r(xx), r(Ao), r(px), r(Ta), r(Xo), r(to), r(Bx), r(Gf), r(VU), r(Zf), r(yx), r(mo), r(gc), r(Ho), r(wo), r(xa), r(Ef), r(sf), r(ka), r(ja), r(cH), r(Gx), r(fx), r(gf), r(Hf), r(gU), r(Go), r(Ax), r(ho), r(ao), r(bx), r(qa), r(Wo), r(Uf), r(Ro), r(Ea), r(za), r($f), r(of), r(Iu), r(rx), r(ta), r(kx), r(No), r(Kx), r(N7), r(jf), r(lc), r(ba), r(Sx), r(Lf), r(Qx), r(Po), r(pa), r(ec), r(Ca), r(jo), r(wf), r(ln), r(Yx), r(yf), r(nf), r(Qa), r(Tc), r(ox), r(Mx), r(A7), r(so), r(r7), r(ia), r(Oc), r(Aa), r(rr)], yGr = r(V4), dGr = r(I2), hGr = [0, [11, r("Failure while looking up "), [2, 0, [11, r(". Index: "), [4, 0, 0, 0, [11, r(". Length: "), [4, 0, 0, 0, [12, 46, 0]]]]]]], r("Failure while looking up %s. Index: %d. Length: %d.")], kGr = [0, 0, 0, 0], wGr = r("Offset_utils.Offset_lookup_failed"), EGr = r(QY), SGr = r(wE), gGr = r(jY), FGr = r($X), TGr = r($X), OGr = r(jY), IGr = r($c), AGr = r(Xr), NGr = r($n), CGr = r("Program"), PGr = r(Yh), DGr = r("BreakStatement"), LGr = r(Yh), RGr = r("ContinueStatement"), jGr = r("DebuggerStatement"), GGr = r(vc), MGr = r("DeclareExportAllDeclaration"), BGr = r(vc), qGr = r(Cv), UGr = r(P2), HGr = r(_i), XGr = r("DeclareExportDeclaration"), YGr = r(Zc), VGr = r($n), zGr = r(yt), KGr = r("DeclareModule"), WGr = r(C7), JGr = r("DeclareModuleExports"), $Gr = r(Ts), ZGr = r($n), QGr = r("DoWhileStatement"), rMr = r("EmptyStatement"), eMr = r(_O), nMr = r(P2), tMr = r("ExportDefaultDeclaration"), uMr = r(_O), iMr = r(A4), fMr = r(vc), xMr = r("ExportAllDeclaration"), aMr = r(_O), oMr = r(vc), cMr = r(Cv), sMr = r(P2), vMr = r("ExportNamedDeclaration"), lMr = r(o7), bMr = r(Iu), pMr = r("ExpressionStatement"), mMr = r($n), _Mr = r(sU), yMr = r(Ts), dMr = r(Gi), hMr = r("ForStatement"), kMr = r(j8), wMr = r($n), EMr = r(Au), SMr = r(bi), gMr = r("ForInStatement"), FMr = r(wx), TMr = r($n), OMr = r(Au), IMr = r(bi), AMr = r("ForOfStatement"), NMr = r(_3), CMr = r(kv), PMr = r(Ts), DMr = r("IfStatement"), LMr = r($c), RMr = r(es), jMr = r(qn), GMr = r(pX), MMr = r(vc), BMr = r(Cv), qMr = r("ImportDeclaration"), UMr = r($n), HMr = r(Yh), XMr = r("LabeledStatement"), YMr = r(l7), VMr = r("ReturnStatement"), zMr = r(uY), KMr = r("discriminant"), WMr = r("SwitchStatement"), JMr = r(l7), $Mr = r("ThrowStatement"), ZMr = r(jH), QMr = r(XU), rBr = r(ln), eBr = r("TryStatement"), nBr = r($n), tBr = r(Ts), uBr = r("WhileStatement"), iBr = r($n), fBr = r(ck), xBr = r("WithStatement"), aBr = r(GH), oBr = r("ArrayExpression"), cBr = r(O7), sBr = r(m6), vBr = r(Iu), lBr = r(Qu), bBr = r(G7), pBr = r(Os), mBr = r($n), _Br = r(Lt), yBr = r(yt), dBr = r("ArrowFunctionExpression"), hBr = r(zO), kBr = r(Au), wBr = r(bi), EBr = r(ul), SBr = r("AssignmentExpression"), gBr = r(Au), FBr = r(bi), TBr = r(ul), OBr = r("BinaryExpression"), IBr = r("CallExpression"), ABr = r(O4), NBr = r(bY), CBr = r("ComprehensionExpression"), PBr = r(_3), DBr = r(kv), LBr = r(Ts), RBr = r("ConditionalExpression"), jBr = r(O4), GBr = r(bY), MBr = r("GeneratorExpression"), BBr = r(vc), qBr = r("ImportExpression"), UBr = r(ZH), HBr = r(XX), XBr = r(gn), YBr = r(Au), VBr = r(bi), zBr = r(ul), KBr = r("LogicalExpression"), WBr = r("MemberExpression"), JBr = r(Iv), $Br = r(el), ZBr = r("MetaProperty"), QBr = r(C2), rqr = r(CX), eqr = r(UH), nqr = r("NewExpression"), tqr = r(X4), uqr = r("ObjectExpression"), iqr = r(Bu), fqr = r("OptionalCallExpression"), xqr = r(Bu), aqr = r("OptionalMemberExpression"), oqr = r(Ug), cqr = r("SequenceExpression"), sqr = r("Super"), vqr = r("ThisExpression"), lqr = r(C7), bqr = r(Iu), pqr = r("TypeCastExpression"), mqr = r(l7), _qr = r("AwaitExpression"), yqr = r(Oo), dqr = r(as), hqr = r(ct), kqr = r(tV), wqr = r(es), Eqr = r(ns), Sqr = r(J2), gqr = r("matched above"), Fqr = r(l7), Tqr = r(XE), Oqr = r(ul), Iqr = r("UnaryExpression"), Aqr = r(lV), Nqr = r(mH), Cqr = r(XE), Pqr = r(l7), Dqr = r(ul), Lqr = r("UpdateExpression"), Rqr = r(yY), jqr = r(l7), Gqr = r("YieldExpression"), Mqr = r("Unexpected FunctionDeclaration with BodyExpression"), Bqr = r(O7), qqr = r(m6), Uqr = r(Iu), Hqr = r(Qu), Xqr = r(G7), Yqr = r(Os), Vqr = r($n), zqr = r(Lt), Kqr = r(yt), Wqr = r("FunctionDeclaration"), Jqr = r("Unexpected FunctionExpression with BodyExpression"), $qr = r(O7), Zqr = r(m6), Qqr = r(Iu), rUr = r(Qu), eUr = r(G7), nUr = r(Os), tUr = r($n), uUr = r(Lt), iUr = r(yt), fUr = r("FunctionExpression"), xUr = r(Bu), aUr = r(C7), oUr = r(ui), cUr = r(En), sUr = r(Bu), vUr = r(C7), lUr = r(ui), bUr = r("PrivateIdentifier"), pUr = r(Bu), mUr = r(C7), _Ur = r(ui), yUr = r(En), dUr = r(kv), hUr = r(Ts), kUr = r("SwitchCase"), wUr = r($n), EUr = r("param"), SUr = r("CatchClause"), gUr = r($n), FUr = r("BlockStatement"), TUr = r(yt), OUr = r("DeclareVariable"), IUr = r(Qu), AUr = r(yt), NUr = r("DeclareFunction"), CUr = r(Vy), PUr = r(gs), DUr = r(P7), LUr = r($n), RUr = r(O7), jUr = r(yt), GUr = r("DeclareClass"), MUr = r(P7), BUr = r($n), qUr = r(O7), UUr = r(yt), HUr = r("DeclareInterface"), XUr = r(qn), YUr = r($c), VUr = r(A4), zUr = r("ExportNamespaceSpecifier"), KUr = r(Au), WUr = r(O7), JUr = r(yt), $Ur = r("DeclareTypeAlias"), ZUr = r(Au), QUr = r(O7), rHr = r(yt), eHr = r("TypeAlias"), nHr = r("DeclareOpaqueType"), tHr = r("OpaqueType"), uHr = r(IX), iHr = r(kX), fHr = r(O7), xHr = r(yt), aHr = r("ClassDeclaration"), oHr = r("ClassExpression"), cHr = r(B_), sHr = r(gs), vHr = r("superTypeParameters"), lHr = r("superClass"), bHr = r(O7), pHr = r($n), mHr = r(yt), _Hr = r(Iu), yHr = r("Decorator"), dHr = r(O7), hHr = r(yt), kHr = r("ClassImplements"), wHr = r($n), EHr = r("ClassBody"), SHr = r(wv), gHr = r(F2), FHr = r(t1), THr = r(lv), OHr = r(B_), IHr = r(pv), AHr = r(eu), NHr = r(Zc), CHr = r(qn), PHr = r(ii), DHr = r("MethodDefinition"), LHr = r(T2), RHr = r(au), jHr = r(eu), GHr = r(pv), MHr = r(C7), BHr = r(qn), qHr = r(ii), UHr = r(vV), HHr = r("Internal Error: Private name found in class prop"), XHr = r(T2), YHr = r(au), VHr = r(eu), zHr = r(pv), KHr = r(C7), WHr = r(qn), JHr = r(ii), $Hr = r(vV), ZHr = r(yt), QHr = r(PX), rXr = r(Gi), eXr = r(yt), nXr = r("EnumStringMember"), tXr = r(yt), uXr = r(PX), iXr = r(Gi), fXr = r(yt), xXr = r("EnumNumberMember"), aXr = r(Gi), oXr = r(yt), cXr = r("EnumBooleanMember"), sXr = r(O8), vXr = r(jT), lXr = r(N4), bXr = r("EnumBooleanBody"), pXr = r(O8), mXr = r(jT), _Xr = r(N4), yXr = r("EnumNumberBody"), dXr = r(O8), hXr = r(jT), kXr = r(N4), wXr = r("EnumStringBody"), EXr = r(O8), SXr = r(N4), gXr = r("EnumSymbolBody"), FXr = r($n), TXr = r(yt), OXr = r("EnumDeclaration"), IXr = r(P7), AXr = r($n), NXr = r(O7), CXr = r(yt), PXr = r("InterfaceDeclaration"), DXr = r(O7), LXr = r(yt), RXr = r("InterfaceExtends"), jXr = r(C7), GXr = r(X4), MXr = r("ObjectPattern"), BXr = r(C7), qXr = r(GH), UXr = r("ArrayPattern"), HXr = r(Au), XXr = r(bi), YXr = r(jF), VXr = r(C7), zXr = r(ui), KXr = r(En), WXr = r(l7), JXr = r(cX), $Xr = r(l7), ZXr = r(cX), QXr = r(Au), rYr = r(bi), eYr = r(jF), nYr = r(Gi), tYr = r(Gi), uYr = r(t1), iYr = r(lv), fYr = r(bH), xYr = r(pv), aYr = r(x6), oYr = r(F2), cYr = r(Zc), sYr = r(qn), vYr = r(ii), lYr = r(wU), bYr = r(l7), pYr = r("SpreadProperty"), mYr = r(Au), _Yr = r(bi), yYr = r(jF), dYr = r(pv), hYr = r(x6), kYr = r(F2), wYr = r(Zc), EYr = r(qn), SYr = r(ii), gYr = r(wU), FYr = r(l7), TYr = r("SpreadElement"), OYr = r(j8), IYr = r(Au), AYr = r(bi), NYr = r("ComprehensionBlock"), CYr = r("We should not create Literal nodes for bigints"), PYr = r(UX), DYr = r(mi), LYr = r("regex"), RYr = r(c7), jYr = r(qn), GYr = r(c7), MYr = r(qn), BYr = r(X6), qYr = r(c7), UYr = r(qn), HYr = r(X6), XYr = r(a1), YYr = r(qn), VYr = r("BigIntLiteral"), zYr = r(c7), KYr = r(qn), WYr = r(X6), JYr = r(Mi), $Yr = r(Pi), ZYr = r(c7), QYr = r(qn), rVr = r(X6), eVr = r(Ug), nVr = r("quasis"), tVr = r("TemplateLiteral"), uVr = r(GY), iVr = r(c7), fVr = r(bU), xVr = r(qn), aVr = r("TemplateElement"), oVr = r(OY), cVr = r("tag"), sVr = r("TaggedTemplateExpression"), vVr = r(U2), lVr = r(G2), bVr = r(D2), pVr = r(Zc), mVr = r("declarations"), _Vr = r("VariableDeclaration"), yVr = r(Gi), dVr = r(yt), hVr = r("VariableDeclarator"), kVr = r(Zc), wVr = r("Variance"), EVr = r("AnyTypeAnnotation"), SVr = r("MixedTypeAnnotation"), gVr = r("EmptyTypeAnnotation"), FVr = r("VoidTypeAnnotation"), TVr = r("NullLiteralTypeAnnotation"), OVr = r("SymbolTypeAnnotation"), IVr = r("NumberTypeAnnotation"), AVr = r("BigIntTypeAnnotation"), NVr = r("StringTypeAnnotation"), CVr = r("BooleanTypeAnnotation"), PVr = r(C7), DVr = r("NullableTypeAnnotation"), LVr = r(O7), RVr = r(ch), jVr = r(m6), GVr = r(f1), MVr = r(Lt), BVr = r("FunctionTypeAnnotation"), qVr = r(Bu), UVr = r(C7), HVr = r(ui), XVr = r(qH), YVr = r(Bu), VVr = r(C7), zVr = r(ui), KVr = r(qH), WVr = [0, 0, 0, 0, 0], JVr = r("internalSlots"), $Vr = r("callProperties"), ZVr = r("indexers"), QVr = r(X4), rzr = r("exact"), ezr = r(HY), nzr = r("ObjectTypeAnnotation"), tzr = r(bH), uzr = r("There should not be computed object type property keys"), izr = r(Gi), fzr = r(t1), xzr = r(lv), azr = r(Zc), ozr = r(au), czr = r(Y3), szr = r(eu), vzr = r(Bu), lzr = r(F2), bzr = r(qn), pzr = r(ii), mzr = r("ObjectTypeProperty"), _zr = r(l7), yzr = r("ObjectTypeSpreadProperty"), dzr = r(au), hzr = r(eu), kzr = r(qn), wzr = r(ii), Ezr = r(yt), Szr = r("ObjectTypeIndexer"), gzr = r(eu), Fzr = r(qn), Tzr = r("ObjectTypeCallProperty"), Ozr = r(qn), Izr = r(F2), Azr = r(eu), Nzr = r(Bu), Czr = r(yt), Pzr = r("ObjectTypeInternalSlot"), Dzr = r($n), Lzr = r(P7), Rzr = r("InterfaceTypeAnnotation"), jzr = r("elementType"), Gzr = r("ArrayTypeAnnotation"), Mzr = r(yt), Bzr = r(fY), qzr = r("QualifiedTypeIdentifier"), Uzr = r(O7), Hzr = r(yt), Xzr = r("GenericTypeAnnotation"), Yzr = r("indexType"), Vzr = r("objectType"), zzr = r("IndexedAccessType"), Kzr = r(Bu), Wzr = r("OptionalIndexedAccessType"), Jzr = r(Z6), $zr = r("UnionTypeAnnotation"), Zzr = r(Z6), Qzr = r("IntersectionTypeAnnotation"), rKr = r(l7), eKr = r("TypeofTypeAnnotation"), nKr = r(yt), tKr = r(fY), uKr = r("QualifiedTypeofIdentifier"), iKr = r(Z6), fKr = r("TupleTypeAnnotation"), xKr = r(c7), aKr = r(qn), oKr = r("StringLiteralTypeAnnotation"), cKr = r(c7), sKr = r(qn), vKr = r("NumberLiteralTypeAnnotation"), lKr = r(c7), bKr = r(qn), pKr = r("BigIntLiteralTypeAnnotation"), mKr = r(Mi), _Kr = r(Pi), yKr = r(c7), dKr = r(qn), hKr = r("BooleanLiteralTypeAnnotation"), kKr = r("ExistsTypeAnnotation"), wKr = r(C7), EKr = r("TypeAnnotation"), SKr = r(Lt), gKr = r("TypeParameterDeclaration"), FKr = r(_i), TKr = r(au), OKr = r(MU), IKr = r(ui), AKr = r("TypeParameter"), NKr = r(Lt), CKr = r(AH), PKr = r(Lt), DKr = r(AH), LKr = r(bv), RKr = r(qe), jKr = r("closingElement"), GKr = r("openingElement"), MKr = r("JSXElement"), BKr = r("closingFragment"), qKr = r(qe), UKr = r("openingFragment"), HKr = r("JSXFragment"), XKr = r("selfClosing"), YKr = r(kY), VKr = r(ui), zKr = r("JSXOpeningElement"), KKr = r("JSXOpeningFragment"), WKr = r(ui), JKr = r("JSXClosingElement"), $Kr = r("JSXClosingFragment"), ZKr = r(qn), QKr = r(ui), rWr = r("JSXAttribute"), eWr = r(l7), nWr = r("JSXSpreadAttribute"), tWr = r("JSXEmptyExpression"), uWr = r(Iu), iWr = r("JSXExpressionContainer"), fWr = r(Iu), xWr = r("JSXSpreadChild"), aWr = r(c7), oWr = r(qn), cWr = r("JSXText"), sWr = r(Iv), vWr = r(ck), lWr = r("JSXMemberExpression"), bWr = r(ui), pWr = r("namespace"), mWr = r("JSXNamespacedName"), _Wr = r(ui), yWr = r("JSXIdentifier"), dWr = r(A4), hWr = r(B2), kWr = r("ExportSpecifier"), wWr = r(B2), EWr = r("ImportDefaultSpecifier"), SWr = r(B2), gWr = r("ImportNamespaceSpecifier"), FWr = r(pX), TWr = r(B2), OWr = r("imported"), IWr = r("ImportSpecifier"), AWr = r("Line"), NWr = r("Block"), CWr = r(qn), PWr = r(qn), DWr = r("DeclaredPredicate"), LWr = r("InferredPredicate"), RWr = r(C2), jWr = r(CX), GWr = r(UH), MWr = r(pv), BWr = r(Iv), qWr = r(ck), UWr = r("message"), HWr = r(wE), XWr = r(KH), YWr = r(g7), VWr = r(vc), zWr = r(I2), KWr = r(V4), WWr = [0, [3, 0, 0], r(zt)], JWr = r(M2), $Wr = r(N3), ZWr = r(R2), QWr = r(j2), rJr = r(Wu), eJr = r(D7), nJr = r(f1), tJr = r(F7), uJr = r(k4), iJr = r(U2), fJr = r(W6), xJr = r(P8), aJr = r(D2), oJr = r(G2), cJr = r(xs), sJr = r(Pi), vJr = r(Mi), lJr = r(A7), bJr = r(k6), pJr = r(o6), mJr = r(N7), _Jr = r(_i), yJr = r(y4), dJr = r(U8), hJr = r(tp), kJr = r(q2), wJr = r(P7), EJr = r(eu), SJr = r(H4), gJr = r(i1), FJr = r(J2), TJr = r(es), OJr = r(ns), IJr = r(p8), AJr = r(y3), NJr = r(qu), CJr = r(yv), PJr = r(gs), DJr = r(r7), LJr = r(d4), RJr = r(w4), jJr = r(c6), GJr = r(S6), MJr = r(ku), BJr = r(I7), qJr = r(T2), UJr = r($c), HJr = r(ud), XJr = r(LS), YJr = r(Os), VJr = r(wx), zJr = r(t6), KJr = r(X8), WJr = r(v7), JJr = r(hv), $Jr = r(a1), ZJr = r(Tv), QJr = r(ns), r$r = r(W4), e$r = r(O2), n$r = r(I6), t$r = [0, r(F3)], u$r = r(C), i$r = [7, 0], f$r = r(C), x$r = [0, 1], a$r = [0, 2], o$r = [0, 3], c$r = [0, 0], s$r = [0, 0], v$r = [0, 0, 0, 0, 0], l$r = [0, r(vv), 906, 6], b$r = [0, r(vv), tY, 6], p$r = [0, 0], m$r = [0, r(vv), 1012, 8], _$r = r(Y3), y$r = [0, r(vv), 1029, 8], d$r = r("Can not have both `static` and `proto`"), h$r = r(eu), k$r = r(Y3), w$r = r(t1), E$r = r(lv), S$r = r(t1), g$r = r(wv), F$r = r(lH), T$r = [0, 0, 0, 0], O$r = [0, [0, 0, 0, 0, 0]], I$r = r(f1), A$r = [0, r("a type")], N$r = [0, 0], C$r = [0, 0], P$r = [14, 1], D$r = [14, 0], L$r = [0, r(vv), OH, 15], R$r = [0, r(vv), L7, 15], j$r = [0, 44], G$r = [0, 44], M$r = r(M2), B$r = [0, r(C), 0], q$r = [0, 0, 0], U$r = [0, 0, 0], H$r = [0, 0, 0], X$r = [0, 41], Y$r = r(Zu), V$r = r(Zu), z$r = [0, r("a regular expression")], K$r = r(C), W$r = r(C), J$r = r(C), $$r = [0, r("src/parser/expression_parser.ml"), jU, 17], Z$r = [0, r("a template literal part")], Q$r = [0, [0, r(C), r(C)], 1], rZr = r(xs), eZr = r(xs), nZr = r(Mi), tZr = r(Pi), uZr = r("Invalid bigint "), iZr = r("Invalid bigint binary/octal "), fZr = r(H2), xZr = r(hH), aZr = r(Dd), oZr = r(Dd), cZr = r(lU), sZr = [0, 44], vZr = [0, 1], lZr = [0, 1], bZr = [0, 1], pZr = [0, 1], mZr = [0, 0], _Zr = r(bv), yZr = r(bv), dZr = r(i1), hZr = r(OS), kZr = [0, r("the identifier `target`")], wZr = [0, 0], EZr = r(qu), SZr = r(el), gZr = r(el), FZr = r(yv), TZr = [0, 0], OZr = [0, r("either a call or access of `super`")], IZr = r(yv), AZr = [0, 0], NZr = [0, 1], CZr = [0, 0], PZr = [0, 1], DZr = [0, 0], LZr = [0, 1], RZr = [0, 0], jZr = [0, 2], GZr = [0, 3], MZr = [0, 7], BZr = [0, 6], qZr = [0, 4], UZr = [0, 5], HZr = [0, [0, 17, [0, 2]]], XZr = [0, [0, 18, [0, 3]]], YZr = [0, [0, 19, [0, 4]]], VZr = [0, [0, 0, [0, 5]]], zZr = [0, [0, 1, [0, 5]]], KZr = [0, [0, 2, [0, 5]]], WZr = [0, [0, 3, [0, 5]]], JZr = [0, [0, 5, [0, 6]]], $Zr = [0, [0, 7, [0, 6]]], ZZr = [0, [0, 4, [0, 6]]], QZr = [0, [0, 6, [0, 6]]], rQr = [0, [0, 8, [0, 7]]], eQr = [0, [0, 9, [0, 7]]], nQr = [0, [0, 10, [0, 7]]], tQr = [0, [0, 11, [0, 8]]], uQr = [0, [0, 12, [0, 8]]], iQr = [0, [0, 15, [0, 9]]], fQr = [0, [0, 13, [0, 9]]], xQr = [0, [0, 14, [1, 10]]], aQr = [0, [0, 16, [0, 9]]], oQr = [0, [0, 21, [0, 6]]], cQr = [0, [0, 20, [0, 6]]], sQr = [23, r(gn)], vQr = [0, [0, 8]], lQr = [0, [0, 7]], bQr = [0, [0, 6]], pQr = [0, [0, 10]], mQr = [0, [0, 9]], _Qr = [0, [0, 11]], yQr = [0, [0, 5]], dQr = [0, [0, 4]], hQr = [0, [0, 2]], kQr = [0, [0, 3]], wQr = [0, [0, 1]], EQr = [0, [0, 0]], SQr = [0, [0, 12]], gQr = [0, [0, 13]], FQr = [0, [0, 14]], TQr = [0, 0], OQr = r(qu), IQr = r(i1), AQr = r(OS), NQr = r(el), CQr = r(Os), PQr = r(qu), DQr = r(i1), LQr = r(OS), RQr = r(el), jQr = r(o1), GQr = r(Ra), MQr = [17, r("JSX fragment")], BQr = [0, Ci], qQr = [1, Ci], UQr = r(C), HQr = [0, r(C)], XQr = [0, r(F3)], YQr = r(C), VQr = [0, 0, 0, 0], zQr = [0, r("src/hack_forked/utils/collections/flow_map.ml"), 717, 36], KQr = [0, 0, 0], WQr = r(q2), JQr = [0, r(C), 0], $Qr = r("unexpected PrivateName in Property, expected a PrivateField"), ZQr = r(wv), QQr = r(lH), r0e = [0, 0, 0], e0e = r(wv), n0e = r(wv), t0e = r(t1), u0e = r(lv), i0e = [0, 1], f0e = [0, 1], x0e = [0, 1], a0e = r(wv), o0e = r(t1), c0e = r(lv), s0e = r(zO), v0e = r(ku), l0e = r(wx), b0e = r("Internal Error: private name found in object props"), p0e = r(pV), m0e = [0, r(F3)], _0e = r(ku), y0e = r(wx), d0e = r(ku), h0e = r(wx), k0e = r(pV), w0e = [10, r(yi)], E0e = [0, 1], S0e = r(c1), g0e = r(K2), F0e = [0, r(GS), 1763, 21], T0e = r(K2), O0e = r(c1), I0e = [0, r("a declaration, statement or export specifiers")], A0e = [0, 40], N0e = r(c1), C0e = r(K2), P0e = [0, r(C), r(C), 0], D0e = [0, r(OU)], L0e = r(hU), R0e = r("exports"), j0e = [0, 1], G0e = [0, 1], M0e = [0, 0], B0e = r(hU), q0e = [0, 40], U0e = r(Vy), H0e = [0, 0], X0e = [0, 1], Y0e = [0, 83], V0e = [0, 0], z0e = [0, 1], K0e = r(c1), W0e = r(c1), J0e = r(K2), $0e = r(c1), Z0e = [0, r("the keyword `as`")], Q0e = r(c1), rre = r(K2), ere = [0, r(OU)], nre = [0, r("the keyword `from`")], tre = [0, r(C), r(C), 0], ure = [0, r(aU)], ire = r("Label"), fre = [0, r(aU)], xre = [0, 0, 0], are = [0, 29], ore = [0, r(GS), 431, 22], cre = [0, 28], sre = [0, r(GS), 450, 22], vre = [0, 0], lre = r("the token `;`"), bre = [0, 0], pre = [0, 0], mre = r(wx), _re = r(G2), yre = r(ku), dre = [0, r(KU)], hre = [15, [0, 0]], kre = [0, r(KU)], wre = r("use strict"), Ere = [0, 0, 0, 0], Sre = r(UI), gre = r("Nooo: "), Fre = r(_i), Tre = r("Parser error: No such thing as an expression pattern!"), Ore = r(C), Ire = [0, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], Are = [0, r("src/parser/parser_flow.ml"), DT, 28], Nre = [0, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], Cre = r(qn), Pre = r(QY), Dre = r(I2), Lre = r(V4), Rre = r(KH), jre = r(I2), Gre = r(V4), Mre = r(g7), Bre = r(wE), qre = r("normal"), Ure = r($c), Hre = r("jsxTag"), Xre = r("jsxChild"), Yre = r("template"), Vre = r(XH), zre = r("context"), Kre = r($c), Wre = r("use_strict"), Jre = r(Z6), $re = r("esproposal_export_star_as"), Zre = r("esproposal_decorators"), Qre = r("enums"), ree = r("Internal error: ");
            function Mt(t4) {
              if (typeof t4 == "number")
                return 0;
              switch (t4[0]) {
                case 0:
                  return [0, Mt(t4[1])];
                case 1:
                  return [1, Mt(t4[1])];
                case 2:
                  return [2, Mt(t4[1])];
                case 3:
                  return [3, Mt(t4[1])];
                case 4:
                  return [4, Mt(t4[1])];
                case 5:
                  return [5, Mt(t4[1])];
                case 6:
                  return [6, Mt(t4[1])];
                case 7:
                  return [7, Mt(t4[1])];
                case 8:
                  var n = t4[1];
                  return [8, n, Mt(t4[2])];
                case 9:
                  var e = t4[1];
                  return [9, e, e, Mt(t4[3])];
                case 10:
                  return [10, Mt(t4[1])];
                case 11:
                  return [11, Mt(t4[1])];
                case 12:
                  return [12, Mt(t4[1])];
                case 13:
                  return [13, Mt(t4[1])];
                default:
                  return [14, Mt(t4[1])];
              }
            }
            function t7(t4, n) {
              if (typeof t4 == "number")
                return n;
              switch (t4[0]) {
                case 0:
                  return [0, t7(t4[1], n)];
                case 1:
                  return [1, t7(t4[1], n)];
                case 2:
                  return [2, t7(t4[1], n)];
                case 3:
                  return [3, t7(t4[1], n)];
                case 4:
                  return [4, t7(t4[1], n)];
                case 5:
                  return [5, t7(t4[1], n)];
                case 6:
                  return [6, t7(t4[1], n)];
                case 7:
                  return [7, t7(t4[1], n)];
                case 8:
                  var e = t4[1];
                  return [8, e, t7(t4[2], n)];
                case 9:
                  var i = t4[2], x = t4[1];
                  return [9, x, i, t7(t4[3], n)];
                case 10:
                  return [10, t7(t4[1], n)];
                case 11:
                  return [11, t7(t4[1], n)];
                case 12:
                  return [12, t7(t4[1], n)];
                case 13:
                  return [13, t7(t4[1], n)];
                default:
                  return [14, t7(t4[1], n)];
              }
            }
            function Nt(t4, n) {
              if (typeof t4 == "number")
                return n;
              switch (t4[0]) {
                case 0:
                  return [0, Nt(t4[1], n)];
                case 1:
                  return [1, Nt(t4[1], n)];
                case 2:
                  var e = t4[1];
                  return [2, e, Nt(t4[2], n)];
                case 3:
                  var i = t4[1];
                  return [3, i, Nt(t4[2], n)];
                case 4:
                  var x = t4[3], c = t4[2], s = t4[1];
                  return [4, s, c, x, Nt(t4[4], n)];
                case 5:
                  var p = t4[3], y = t4[2], T = t4[1];
                  return [5, T, y, p, Nt(t4[4], n)];
                case 6:
                  var E = t4[3], h = t4[2], w = t4[1];
                  return [6, w, h, E, Nt(t4[4], n)];
                case 7:
                  var G = t4[3], A = t4[2], S = t4[1];
                  return [7, S, A, G, Nt(t4[4], n)];
                case 8:
                  var M = t4[3], K = t4[2], V = t4[1];
                  return [8, V, K, M, Nt(t4[4], n)];
                case 9:
                  var f0 = t4[1];
                  return [9, f0, Nt(t4[2], n)];
                case 10:
                  return [10, Nt(t4[1], n)];
                case 11:
                  var m0 = t4[1];
                  return [11, m0, Nt(t4[2], n)];
                case 12:
                  var k0 = t4[1];
                  return [12, k0, Nt(t4[2], n)];
                case 13:
                  var g0 = t4[2], e0 = t4[1];
                  return [13, e0, g0, Nt(t4[3], n)];
                case 14:
                  var x0 = t4[2], l = t4[1];
                  return [14, l, x0, Nt(t4[3], n)];
                case 15:
                  return [15, Nt(t4[1], n)];
                case 16:
                  return [16, Nt(t4[1], n)];
                case 17:
                  var c0 = t4[1];
                  return [17, c0, Nt(t4[2], n)];
                case 18:
                  var t0 = t4[1];
                  return [18, t0, Nt(t4[2], n)];
                case 19:
                  return [19, Nt(t4[1], n)];
                case 20:
                  var a0 = t4[2], w0 = t4[1];
                  return [20, w0, a0, Nt(t4[3], n)];
                case 21:
                  var _0 = t4[1];
                  return [21, _0, Nt(t4[2], n)];
                case 22:
                  return [22, Nt(t4[1], n)];
                case 23:
                  var E0 = t4[1];
                  return [23, E0, Nt(t4[2], n)];
                default:
                  var X0 = t4[2], b = t4[1];
                  return [24, b, X0, Nt(t4[3], n)];
              }
            }
            function iN(t4, n, e) {
              return t4[1] === n ? (t4[1] = e, 1) : 0;
            }
            function ke(t4) {
              throw [0, q7, t4];
            }
            function Nu(t4) {
              throw [0, eN, t4];
            }
            M7(0);
            function Fp(t4) {
              return 0 <= t4 ? t4 : -t4 | 0;
            }
            var eee = kH;
            function Te(t4, n) {
              var e = tn(t4), i = tn(n), x = Rt(e + i | 0);
              return As(t4, 0, x, 0, e), As(n, 0, x, e, i), x;
            }
            function nee(t4) {
              return t4 ? Si0 : gi0;
            }
            function xn(t4, n) {
              if (t4) {
                var e = t4[1];
                return [0, e, xn(t4[2], n)];
              }
              return n;
            }
            ti0(0);
            var tee = ZV(1), Lc = ZV(2);
            function uee(t4) {
              function n(e) {
                for (var i = e; ; ) {
                  if (i) {
                    var x = i[2], c = i[1];
                    try {
                      m1(c);
                    } catch (y) {
                      if (y = gt(y), y[1] !== nz)
                        throw y;
                      var s = y;
                    }
                    var i = x;
                    continue;
                  }
                  return 0;
                }
              }
              return n(ui0(0));
            }
            function vl(t4, n) {
              return JA(t4, n, 0, tn(n));
            }
            function cz(t4) {
              return vl(Lc, t4), QV(Lc, 10), m1(Lc);
            }
            var fN = [0, uee];
            function sz(t4) {
              for (; ; ) {
                var n = fN[1], e = [0, 1], i = 1 - iN(fN, n, function(x, c) {
                  return function(s) {
                    return iN(x, 1, 0) && u(t4, 0), u(c, 0);
                  };
                }(e, n));
                if (!i)
                  return i;
              }
            }
            function xN(t4) {
              return u(fN[1], 0);
            }
            ZA(r(mV), xN), vi0(0) && sz(function(t4) {
              return N70(t4);
            });
            function vz(t4) {
              return 25 < (t4 + V3 | 0) >>> 0 ? t4 : t4 + SU | 0;
            }
            var lz = bi0(0)[1], ll = (4 * si0(0) | 0) - 1 | 0;
            M7(0);
            var iee = ci0(0);
            function Rc(t4) {
              for (var n = 0, e = t4; ; ) {
                if (e) {
                  var n = n + 1 | 0, e = e[2];
                  continue;
                }
                return n;
              }
            }
            function bl(t4) {
              return t4 ? t4[1] : ke(Di0);
            }
            function bz(t4) {
              return t4 ? t4[2] : ke(Pi0);
            }
            function jc(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (e) {
                  var x = [0, e[1], i], e = e[2], i = x;
                  continue;
                }
                return i;
              }
            }
            function de(t4) {
              return jc(t4, 0);
            }
            function pl(t4) {
              if (t4) {
                var n = t4[1];
                return xn(n, pl(t4[2]));
              }
              return 0;
            }
            function k1(t4, n) {
              if (n) {
                var e = n[2], i = u(t4, n[1]);
                return [0, i, k1(t4, e)];
              }
              return 0;
            }
            function Tp(t4, n) {
              for (var e = 0, i = n; ; ) {
                if (i) {
                  var x = i[2], e = [0, u(t4, i[1]), e], i = x;
                  continue;
                }
                return e;
              }
            }
            function Cu(t4, n) {
              for (var e = n; ; ) {
                if (e) {
                  var i = e[2];
                  u(t4, e[1]);
                  var e = i;
                  continue;
                }
                return 0;
              }
            }
            function be(t4, n, e) {
              for (var i = n, x = e; ; ) {
                if (x) {
                  var c = x[2], i = a(t4, i, x[1]), x = c;
                  continue;
                }
                return i;
              }
            }
            function aN(t4, n, e) {
              if (n) {
                var i = n[1];
                return a(t4, i, aN(t4, n[2], e));
              }
              return e;
            }
            function pz(t4, n, e) {
              for (var i = n, x = e; ; ) {
                if (i) {
                  if (x) {
                    var c = x[2], s = i[2];
                    a(t4, i[1], x[1]);
                    var i = s, x = c;
                    continue;
                  }
                } else if (!x)
                  return 0;
                return Nu(Ci0);
              }
            }
            function oN(t4, n) {
              for (var e = n; ; ) {
                if (e) {
                  var i = e[2], x = BV(e[1], t4) === 0 ? 1 : 0;
                  if (x)
                    return x;
                  var e = i;
                  continue;
                }
                return 0;
              }
            }
            function fee(t4, n) {
              for (var e = n; ; ) {
                if (e) {
                  var i = e[1], x = e[2], c = i[2];
                  if (BV(i[1], t4) === 0)
                    return c;
                  var e = x;
                  continue;
                }
                throw Jt;
              }
            }
            function ml(t4) {
              var n = 0;
              return function(e) {
                for (var i = n, x = e; ; ) {
                  if (x) {
                    var c = x[2], s = x[1];
                    if (u(t4, s)) {
                      var i = [0, s, i], x = c;
                      continue;
                    }
                    var x = c;
                    continue;
                  }
                  return de(i);
                }
              };
            }
            function w1(t4, n) {
              var e = Rt(t4);
              return A70(e, 0, t4, n), e;
            }
            function mz(t4) {
              var n = b7(t4), e = Rt(n);
              return Is(t4, 0, e, 0, n), e;
            }
            function _z(t4, n, e) {
              if (0 <= n && 0 <= e && !((b7(t4) - e | 0) < n)) {
                var i = Rt(e);
                return Is(t4, n, i, 0, e), i;
              }
              return Nu(ji0);
            }
            function qv(t4, n, e) {
              return _z(t4, n, e);
            }
            function yz(t4, n, e, i, x) {
              return 0 <= x && 0 <= n && !((b7(t4) - x | 0) < n) && 0 <= i && !((b7(e) - x | 0) < i) ? Is(t4, n, e, i, x) : Nu(Ri0);
            }
            function ss(t4, n, e, i, x) {
              return 0 <= x && 0 <= n && !((tn(t4) - x | 0) < n) && 0 <= i && !((b7(e) - x | 0) < i) ? As(t4, n, e, i, x) : Nu(Li0);
            }
            function Op(t4, n) {
              return w1(t4, n);
            }
            function m7(t4, n, e) {
              return _z(t4, n, e);
            }
            var dz = Ee;
            function hz(t4, n) {
              var e = n.length - 1 - 1 | 0, i = 0;
              if (!(e < 0))
                for (var x = i; ; ) {
                  u(t4, n[1 + x]);
                  var c = x + 1 | 0;
                  if (e !== x) {
                    var x = c;
                    continue;
                  }
                  break;
                }
              return 0;
            }
            function Ip(t4, n) {
              var e = n.length - 1;
              if (e === 0)
                return [0];
              var i = Gv(e, u(t4, n[1])), x = e - 1 | 0, c = 1;
              if (!(x < 1))
                for (var s = c; ; ) {
                  i[1 + s] = u(t4, n[1 + s]);
                  var p = s + 1 | 0;
                  if (x !== s) {
                    var s = p;
                    continue;
                  }
                  break;
                }
              return i;
            }
            function _l(t4) {
              if (t4)
                for (var n = 0, e = t4, i = t4[2], x = t4[1]; ; ) {
                  if (e) {
                    var n = n + 1 | 0, e = e[2];
                    continue;
                  }
                  for (var c = Gv(n, x), s = 1, p = i; ; ) {
                    if (p) {
                      var y = p[2];
                      c[1 + s] = p[1];
                      var s = s + 1 | 0, p = y;
                      continue;
                    }
                    return c;
                  }
                }
              return [0];
            }
            M7(0);
            function cN(t4) {
              function n(v0) {
                return v0 ? v0[5] : 0;
              }
              function e(v0, P, L, Q) {
                var i0 = n(v0), l0 = n(Q), S0 = l0 <= i0 ? i0 + 1 | 0 : l0 + 1 | 0;
                return [0, v0, P, L, Q, S0];
              }
              function i(v0, P) {
                return [0, 0, v0, P, 0, 1];
              }
              function x(v0, P, L, Q) {
                var i0 = v0 ? v0[5] : 0, l0 = Q ? Q[5] : 0;
                if ((l0 + 2 | 0) < i0) {
                  if (v0) {
                    var S0 = v0[4], T0 = v0[3], er = v0[2], j0 = v0[1], B = n(S0);
                    if (B <= n(j0))
                      return e(j0, er, T0, e(S0, P, L, Q));
                    if (S0) {
                      var Z = S0[3], p0 = S0[2], b0 = S0[1], O0 = e(S0[4], P, L, Q);
                      return e(e(j0, er, T0, b0), p0, Z, O0);
                    }
                    return Nu(Xi0);
                  }
                  return Nu(Yi0);
                }
                if ((i0 + 2 | 0) < l0) {
                  if (Q) {
                    var q0 = Q[4], nr = Q[3], yr = Q[2], vr = Q[1], $0 = n(vr);
                    if ($0 <= n(q0))
                      return e(e(v0, P, L, vr), yr, nr, q0);
                    if (vr) {
                      var Sr = vr[3], Mr = vr[2], Br = vr[1], qr = e(vr[4], yr, nr, q0);
                      return e(e(v0, P, L, Br), Mr, Sr, qr);
                    }
                    return Nu(Vi0);
                  }
                  return Nu(zi0);
                }
                var jr = l0 <= i0 ? i0 + 1 | 0 : l0 + 1 | 0;
                return [0, v0, P, L, Q, jr];
              }
              var c = 0;
              function s(v0) {
                return v0 ? 0 : 1;
              }
              function p(v0, P, L) {
                if (L) {
                  var Q = L[4], i0 = L[3], l0 = L[2], S0 = L[1], T0 = L[5], er = a(t4[1], v0, l0);
                  if (er === 0)
                    return i0 === P ? L : [0, S0, v0, P, Q, T0];
                  if (0 <= er) {
                    var j0 = p(v0, P, Q);
                    return Q === j0 ? L : x(S0, l0, i0, j0);
                  }
                  var B = p(v0, P, S0);
                  return S0 === B ? L : x(B, l0, i0, Q);
                }
                return [0, 0, v0, P, 0, 1];
              }
              function y(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[3], l0 = L[1], S0 = a(t4[1], v0, L[2]);
                    if (S0 === 0)
                      return i0;
                    var T0 = 0 <= S0 ? Q : l0, L = T0;
                    continue;
                  }
                  throw Jt;
                }
              }
              function T(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[2], i0 = L[4], l0 = L[3], S0 = L[1];
                    if (u(v0, Q))
                      for (var T0 = Q, er = l0, j0 = S0; ; ) {
                        if (j0) {
                          var B = j0[2], Z = j0[4], p0 = j0[3], b0 = j0[1];
                          if (u(v0, B)) {
                            var T0 = B, er = p0, j0 = b0;
                            continue;
                          }
                          var j0 = Z;
                          continue;
                        }
                        return [0, T0, er];
                      }
                    var L = i0;
                    continue;
                  }
                  throw Jt;
                }
              }
              function E(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[2], i0 = L[4], l0 = L[3], S0 = L[1];
                    if (u(v0, Q))
                      for (var T0 = Q, er = l0, j0 = S0; ; ) {
                        if (j0) {
                          var B = j0[2], Z = j0[4], p0 = j0[3], b0 = j0[1];
                          if (u(v0, B)) {
                            var T0 = B, er = p0, j0 = b0;
                            continue;
                          }
                          var j0 = Z;
                          continue;
                        }
                        return [0, [0, T0, er]];
                      }
                    var L = i0;
                    continue;
                  }
                  return 0;
                }
              }
              function h(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[2], i0 = L[4], l0 = L[3], S0 = L[1];
                    if (u(v0, Q))
                      for (var T0 = Q, er = l0, j0 = i0; ; ) {
                        if (j0) {
                          var B = j0[2], Z = j0[4], p0 = j0[3], b0 = j0[1];
                          if (u(v0, B)) {
                            var T0 = B, er = p0, j0 = Z;
                            continue;
                          }
                          var j0 = b0;
                          continue;
                        }
                        return [0, T0, er];
                      }
                    var L = S0;
                    continue;
                  }
                  throw Jt;
                }
              }
              function w(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[2], i0 = L[4], l0 = L[3], S0 = L[1];
                    if (u(v0, Q))
                      for (var T0 = Q, er = l0, j0 = i0; ; ) {
                        if (j0) {
                          var B = j0[2], Z = j0[4], p0 = j0[3], b0 = j0[1];
                          if (u(v0, B)) {
                            var T0 = B, er = p0, j0 = Z;
                            continue;
                          }
                          var j0 = b0;
                          continue;
                        }
                        return [0, [0, T0, er]];
                      }
                    var L = S0;
                    continue;
                  }
                  return 0;
                }
              }
              function G(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[3], l0 = L[1], S0 = a(t4[1], v0, L[2]);
                    if (S0 === 0)
                      return [0, i0];
                    var T0 = 0 <= S0 ? Q : l0, L = T0;
                    continue;
                  }
                  return 0;
                }
              }
              function A(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[1], l0 = a(t4[1], v0, L[2]), S0 = l0 === 0 ? 1 : 0;
                    if (S0)
                      return S0;
                    var T0 = 0 <= l0 ? Q : i0, L = T0;
                    continue;
                  }
                  return 0;
                }
              }
              function S(v0) {
                for (var P = v0; ; ) {
                  if (P) {
                    var L = P[1];
                    if (L) {
                      var P = L;
                      continue;
                    }
                    return [0, P[2], P[3]];
                  }
                  throw Jt;
                }
              }
              function M(v0) {
                for (var P = v0; ; ) {
                  if (P) {
                    var L = P[1];
                    if (L) {
                      var P = L;
                      continue;
                    }
                    return [0, [0, P[2], P[3]]];
                  }
                  return 0;
                }
              }
              function K(v0) {
                for (var P = v0; ; ) {
                  if (P) {
                    if (P[4]) {
                      var P = P[4];
                      continue;
                    }
                    return [0, P[2], P[3]];
                  }
                  throw Jt;
                }
              }
              function V(v0) {
                for (var P = v0; ; ) {
                  if (P) {
                    if (P[4]) {
                      var P = P[4];
                      continue;
                    }
                    return [0, [0, P[2], P[3]]];
                  }
                  return 0;
                }
              }
              function f0(v0) {
                if (v0) {
                  var P = v0[1];
                  if (P) {
                    var L = v0[4], Q = v0[3], i0 = v0[2];
                    return x(f0(P), i0, Q, L);
                  }
                  return v0[4];
                }
                return Nu(Bi0);
              }
              function m0(v0, P) {
                if (v0) {
                  if (P) {
                    var L = S(P), Q = L[2], i0 = L[1];
                    return x(v0, i0, Q, f0(P));
                  }
                  return v0;
                }
                return P;
              }
              function k0(v0, P) {
                if (P) {
                  var L = P[4], Q = P[3], i0 = P[2], l0 = P[1], S0 = a(t4[1], v0, i0);
                  if (S0 === 0)
                    return m0(l0, L);
                  if (0 <= S0) {
                    var T0 = k0(v0, L);
                    return L === T0 ? P : x(l0, i0, Q, T0);
                  }
                  var er = k0(v0, l0);
                  return l0 === er ? P : x(er, i0, Q, L);
                }
                return 0;
              }
              function g0(v0, P, L) {
                if (L) {
                  var Q = L[4], i0 = L[3], l0 = L[2], S0 = L[1], T0 = L[5], er = a(t4[1], v0, l0);
                  if (er === 0) {
                    var j0 = u(P, [0, i0]);
                    if (j0) {
                      var B = j0[1];
                      return i0 === B ? L : [0, S0, v0, B, Q, T0];
                    }
                    return m0(S0, Q);
                  }
                  if (0 <= er) {
                    var Z = g0(v0, P, Q);
                    return Q === Z ? L : x(S0, l0, i0, Z);
                  }
                  var p0 = g0(v0, P, S0);
                  return S0 === p0 ? L : x(p0, l0, i0, Q);
                }
                var b0 = u(P, 0);
                return b0 ? [0, 0, v0, b0[1], 0, 1] : 0;
              }
              function e0(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[3], l0 = L[2];
                    e0(v0, L[1]), a(v0, l0, i0);
                    var L = Q;
                    continue;
                  }
                  return 0;
                }
              }
              function x0(v0, P) {
                if (P) {
                  var L = P[5], Q = P[4], i0 = P[3], l0 = P[2], S0 = x0(v0, P[1]), T0 = u(v0, i0);
                  return [0, S0, l0, T0, x0(v0, Q), L];
                }
                return 0;
              }
              function l(v0, P) {
                if (P) {
                  var L = P[2], Q = P[5], i0 = P[4], l0 = P[3], S0 = l(v0, P[1]), T0 = a(v0, L, l0);
                  return [0, S0, L, T0, l(v0, i0), Q];
                }
                return 0;
              }
              function c0(v0, P, L) {
                for (var Q = P, i0 = L; ; ) {
                  if (Q) {
                    var l0 = Q[4], S0 = Q[3], T0 = Q[2], er = ir(v0, T0, S0, c0(v0, Q[1], i0)), Q = l0, i0 = er;
                    continue;
                  }
                  return i0;
                }
              }
              function t0(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[1], l0 = a(v0, L[2], L[3]);
                    if (l0) {
                      var S0 = t0(v0, i0);
                      if (S0) {
                        var L = Q;
                        continue;
                      }
                      var T0 = S0;
                    } else
                      var T0 = l0;
                    return T0;
                  }
                  return 1;
                }
              }
              function a0(v0, P) {
                for (var L = P; ; ) {
                  if (L) {
                    var Q = L[4], i0 = L[1], l0 = a(v0, L[2], L[3]);
                    if (l0)
                      var S0 = l0;
                    else {
                      var T0 = a0(v0, i0);
                      if (!T0) {
                        var L = Q;
                        continue;
                      }
                      var S0 = T0;
                    }
                    return S0;
                  }
                  return 0;
                }
              }
              function w0(v0, P, L) {
                if (L) {
                  var Q = L[4], i0 = L[3], l0 = L[2];
                  return x(w0(v0, P, L[1]), l0, i0, Q);
                }
                return i(v0, P);
              }
              function _0(v0, P, L) {
                if (L) {
                  var Q = L[3], i0 = L[2], l0 = L[1];
                  return x(l0, i0, Q, _0(v0, P, L[4]));
                }
                return i(v0, P);
              }
              function E0(v0, P, L, Q) {
                if (v0) {
                  if (Q) {
                    var i0 = Q[5], l0 = v0[5], S0 = Q[4], T0 = Q[3], er = Q[2], j0 = Q[1], B = v0[4], Z = v0[3], p0 = v0[2], b0 = v0[1];
                    return (i0 + 2 | 0) < l0 ? x(b0, p0, Z, E0(B, P, L, Q)) : (l0 + 2 | 0) < i0 ? x(E0(v0, P, L, j0), er, T0, S0) : e(v0, P, L, Q);
                  }
                  return _0(P, L, v0);
                }
                return w0(P, L, Q);
              }
              function X0(v0, P) {
                if (v0) {
                  if (P) {
                    var L = S(P), Q = L[2], i0 = L[1];
                    return E0(v0, i0, Q, f0(P));
                  }
                  return v0;
                }
                return P;
              }
              function b(v0, P, L, Q) {
                return L ? E0(v0, P, L[1], Q) : X0(v0, Q);
              }
              function G0(v0, P) {
                if (P) {
                  var L = P[4], Q = P[3], i0 = P[2], l0 = P[1], S0 = a(t4[1], v0, i0);
                  if (S0 === 0)
                    return [0, l0, [0, Q], L];
                  if (0 <= S0) {
                    var T0 = G0(v0, L), er = T0[3], j0 = T0[2];
                    return [0, E0(l0, i0, Q, T0[1]), j0, er];
                  }
                  var B = G0(v0, l0), Z = B[2], p0 = B[1];
                  return [0, p0, Z, E0(B[3], i0, Q, L)];
                }
                return qi0;
              }
              function X(v0, P, L) {
                if (P) {
                  var Q = P[2], i0 = P[5], l0 = P[4], S0 = P[3], T0 = P[1];
                  if (n(L) <= i0) {
                    var er = G0(Q, L), j0 = er[2], B = er[1], Z = X(v0, l0, er[3]), p0 = ir(v0, Q, [0, S0], j0);
                    return b(X(v0, T0, B), Q, p0, Z);
                  }
                } else if (!L)
                  return 0;
                if (L) {
                  var b0 = L[2], O0 = L[4], q0 = L[3], nr = L[1], yr = G0(b0, P), vr = yr[2], $0 = yr[1], Sr = X(v0, yr[3], O0), Mr = ir(v0, b0, vr, [0, q0]);
                  return b(X(v0, $0, nr), b0, Mr, Sr);
                }
                throw [0, Fn, Ui0];
              }
              function s0(v0, P, L) {
                if (P) {
                  if (L) {
                    var Q = L[3], i0 = L[2], l0 = P[3], S0 = P[2], T0 = L[4], er = L[1], j0 = P[4], B = P[1];
                    if (L[5] <= P[5]) {
                      var Z = G0(S0, L), p0 = Z[2], b0 = Z[3], O0 = s0(v0, B, Z[1]), q0 = s0(v0, j0, b0);
                      return p0 ? b(O0, S0, ir(v0, S0, l0, p0[1]), q0) : E0(O0, S0, l0, q0);
                    }
                    var nr = G0(i0, P), yr = nr[2], vr = nr[3], $0 = s0(v0, nr[1], er), Sr = s0(v0, vr, T0);
                    return yr ? b($0, i0, ir(v0, i0, yr[1], Q), Sr) : E0($0, i0, Q, Sr);
                  }
                  var Mr = P;
                } else
                  var Mr = L;
                return Mr;
              }
              function dr(v0, P) {
                if (P) {
                  var L = P[4], Q = P[3], i0 = P[2], l0 = P[1], S0 = dr(v0, l0), T0 = a(v0, i0, Q), er = dr(v0, L);
                  return T0 ? l0 === S0 && L === er ? P : E0(S0, i0, Q, er) : X0(S0, er);
                }
                return 0;
              }
              function Ar(v0, P) {
                if (P) {
                  var L = P[2], Q = P[4], i0 = P[3], l0 = Ar(v0, P[1]), S0 = a(v0, L, i0), T0 = Ar(v0, Q);
                  return S0 ? E0(l0, L, S0[1], T0) : X0(l0, T0);
                }
                return 0;
              }
              function ar(v0, P) {
                if (P) {
                  var L = P[3], Q = P[2], i0 = P[4], l0 = ar(v0, P[1]), S0 = l0[2], T0 = l0[1], er = a(v0, Q, L), j0 = ar(v0, i0), B = j0[2], Z = j0[1];
                  if (er) {
                    var p0 = X0(S0, B);
                    return [0, E0(T0, Q, L, Z), p0];
                  }
                  var b0 = E0(S0, Q, L, B);
                  return [0, X0(T0, Z), b0];
                }
                return Hi0;
              }
              function W0(v0, P) {
                for (var L = v0, Q = P; ; ) {
                  if (L) {
                    var i0 = [0, L[2], L[3], L[4], Q], L = L[1], Q = i0;
                    continue;
                  }
                  return Q;
                }
              }
              function Lr(v0, P, L) {
                for (var Q = W0(L, 0), i0 = W0(P, 0), l0 = Q; ; ) {
                  if (i0) {
                    if (l0) {
                      var S0 = l0[4], T0 = l0[3], er = l0[2], j0 = i0[4], B = i0[3], Z = i0[2], p0 = a(t4[1], i0[1], l0[1]);
                      if (p0 === 0) {
                        var b0 = a(v0, Z, er);
                        if (b0 === 0) {
                          var O0 = W0(T0, S0), i0 = W0(B, j0), l0 = O0;
                          continue;
                        }
                        return b0;
                      }
                      return p0;
                    }
                    return 1;
                  }
                  return l0 ? -1 : 0;
                }
              }
              function Tr(v0, P, L) {
                for (var Q = W0(L, 0), i0 = W0(P, 0), l0 = Q; ; ) {
                  if (i0) {
                    if (l0) {
                      var S0 = l0[4], T0 = l0[3], er = l0[2], j0 = i0[4], B = i0[3], Z = i0[2], p0 = a(t4[1], i0[1], l0[1]) === 0 ? 1 : 0;
                      if (p0) {
                        var b0 = a(v0, Z, er);
                        if (b0) {
                          var O0 = W0(T0, S0), i0 = W0(B, j0), l0 = O0;
                          continue;
                        }
                        var q0 = b0;
                      } else
                        var q0 = p0;
                      return q0;
                    }
                    return 0;
                  }
                  return l0 ? 0 : 1;
                }
              }
              function Hr(v0) {
                if (v0) {
                  var P = v0[1], L = Hr(v0[4]);
                  return (Hr(P) + 1 | 0) + L | 0;
                }
                return 0;
              }
              function Or(v0, P) {
                for (var L = v0, Q = P; ; ) {
                  if (Q) {
                    var i0 = Q[3], l0 = Q[2], S0 = Q[1], L = [0, [0, l0, i0], Or(L, Q[4])], Q = S0;
                    continue;
                  }
                  return L;
                }
              }
              function xr(v0) {
                return Or(0, v0);
              }
              function Rr(v0, P) {
                for (var L = P, Q = v0; ; ) {
                  var i0 = u(Q, 0);
                  if (i0) {
                    var l0 = i0[1], S0 = i0[2], L = p(l0[1], l0[2], L), Q = S0;
                    continue;
                  }
                  return L;
                }
              }
              function Wr(v0) {
                return Rr(v0, c);
              }
              function Jr(v0, P) {
                if (v0) {
                  var L = v0[2], Q = v0[1], i0 = W0(v0[3], v0[4]);
                  return [0, [0, Q, L], function(l0) {
                    return Jr(i0, l0);
                  }];
                }
                return 0;
              }
              function or(v0) {
                var P = W0(v0, 0);
                return function(L) {
                  return Jr(P, L);
                };
              }
              function _r(v0, P) {
                for (var L = v0, Q = P; ; ) {
                  if (L) {
                    var i0 = [0, L[2], L[3], L[1], Q], L = L[4], Q = i0;
                    continue;
                  }
                  return Q;
                }
              }
              function Ir(v0, P) {
                if (v0) {
                  var L = v0[2], Q = v0[1], i0 = _r(v0[3], v0[4]);
                  return [0, [0, Q, L], function(l0) {
                    return Ir(i0, l0);
                  }];
                }
                return 0;
              }
              function fe(v0) {
                var P = _r(v0, 0);
                return function(L) {
                  return Ir(P, L);
                };
              }
              return [0, c, s, A, p, g0, i, k0, X, s0, Lr, Tr, e0, c0, t0, a0, dr, Ar, ar, Hr, xr, S, M, K, V, S, M, G0, y, G, T, E, h, w, x0, l, or, fe, function(v0, P) {
                for (var L = P, Q = 0; ; ) {
                  if (L) {
                    var i0 = L[4], l0 = L[3], S0 = L[2], T0 = L[1], er = a(t4[1], S0, v0);
                    if (er !== 0) {
                      if (0 <= er) {
                        var L = T0, Q = [0, S0, l0, i0, Q];
                        continue;
                      }
                      var L = i0;
                      continue;
                    }
                    var j0 = [0, S0, l0, i0, Q];
                  } else
                    var j0 = Q;
                  return function(B) {
                    return Jr(j0, B);
                  };
                }
              }, Rr, Wr];
            }
            M7(0);
            function yl(t4) {
              return [0, 0, 0];
            }
            function dl(t4) {
              return t4[1] = 0, t4[2] = 0, 0;
            }
            function E1(t4, n) {
              return n[1] = [0, t4, n[1]], n[2] = n[2] + 1 | 0, 0;
            }
            function Uv(t4) {
              var n = t4[1];
              if (n) {
                var e = n[1];
                return t4[1] = n[2], t4[2] = t4[2] - 1 | 0, [0, e];
              }
              return 0;
            }
            function Hv(t4) {
              var n = t4[1];
              return n ? [0, n[1]] : 0;
            }
            var xee = [St, Ki0, M7(0)];
            function kz(t4) {
              return [0, 0, 0, 0];
            }
            function sN(t4) {
              return t4[1] = 0, t4[2] = 0, t4[3] = 0, 0;
            }
            function vN(t4, n) {
              var e = [0, t4, 0], i = n[3];
              return i ? (n[1] = n[1] + 1 | 0, i[2] = e, n[3] = e, 0) : (n[1] = 1, n[2] = e, n[3] = e, 0);
            }
            var aee = [St, Wi0, M7(0)];
            function oee(t4) {
              throw aee;
            }
            function cee(t4) {
              var n = t4[1];
              t4[1] = oee;
              try {
                var e = u(n, 0);
                return fi0(t4, e), e;
              } catch (i) {
                throw i = gt(i), t4[1] = function(x) {
                  throw i;
                }, i;
              }
            }
            function Qn(t4) {
              var n = 1 <= t4 ? t4 : 1, e = ll < n ? ll : n, i = Rt(e);
              return [0, i, 0, e, i];
            }
            function Bt(t4) {
              return qv(t4[1], 0, t4[2]);
            }
            function lN(t4, n) {
              for (var e = t4[2], i = [0, t4[3]]; ; ) {
                if (i[1] < (e + n | 0)) {
                  i[1] = 2 * i[1] | 0;
                  continue;
                }
                ll < i[1] && ((e + n | 0) <= ll ? i[1] = ll : ke($i0));
                var x = Rt(i[1]);
                if (yz(t4[1], 0, x, 0, t4[2]), t4[1] = x, t4[3] = i[1], (t4[2] + n | 0) <= t4[3]) {
                  if ((e + n | 0) <= t4[3])
                    return 0;
                  throw [0, Fn, Qi0];
                }
                throw [0, Fn, Zi0];
              }
            }
            function Ui(t4, n) {
              var e = t4[2];
              return t4[3] <= e && lN(t4, 1), Zn(t4[1], e, n), t4[2] = e + 1 | 0, 0;
            }
            function wz(t4, n, e, i) {
              var x = e < 0 ? 1 : 0;
              if (x)
                var s = x;
              else
                var c = i < 0 ? 1 : 0, s = c || ((tn(n) - i | 0) < e ? 1 : 0);
              s && Nu(Ji0);
              var p = t4[2] + i | 0;
              return t4[3] < p && lN(t4, i), As(n, e, t4[1], t4[2], i), t4[2] = p, 0;
            }
            function bN(t4, n, e, i) {
              return wz(t4, n, e, i);
            }
            function dn(t4, n) {
              var e = tn(n), i = t4[2] + e | 0;
              return t4[3] < i && lN(t4, e), As(n, 0, t4[1], t4[2], e), t4[2] = i, 0;
            }
            function pN(t4) {
              return t4[2] === 5 ? 12 : -6;
            }
            function Ez(t4) {
              return [0, 0, Rt(t4)];
            }
            function Sz(t4, n) {
              var e = b7(t4[2]), i = t4[1] + n | 0, x = e < i ? 1 : 0;
              if (x) {
                var c = e * 2 | 0, s = i <= c ? c : i, p = Rt(s);
                yz(t4[2], 0, p, 0, e), t4[2] = p;
                var y = 0;
              } else
                var y = x;
              return y;
            }
            function Xv(t4, n) {
              return Sz(t4, 1), p1(t4[2], t4[1], n), t4[1] = t4[1] + 1 | 0, 0;
            }
            function Pu(t4, n) {
              var e = tn(n);
              return Sz(t4, e), ss(n, 0, t4[2], t4[1], e), t4[1] = t4[1] + e | 0, 0;
            }
            function gz(t4) {
              return qv(t4[2], 0, t4[1]);
            }
            function Fz(t4) {
              if (typeof t4 == "number")
                switch (t4) {
                  case 0:
                    return na0;
                  case 1:
                    return ta0;
                  case 2:
                    return ua0;
                  case 3:
                    return ia0;
                  case 4:
                    return fa0;
                  case 5:
                    return xa0;
                  default:
                    return aa0;
                }
              else
                switch (t4[0]) {
                  case 0:
                    return t4[1];
                  case 1:
                    return t4[1];
                  default:
                    return Te(oa0, Op(1, t4[1]));
                }
            }
            function mN(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 0;
                switch (e[0]) {
                  case 0:
                    var i = e[1];
                    Pu(t4, ef0);
                    var e = i;
                    continue;
                  case 1:
                    var x = e[1];
                    Pu(t4, nf0);
                    var e = x;
                    continue;
                  case 2:
                    var c = e[1];
                    Pu(t4, tf0);
                    var e = c;
                    continue;
                  case 3:
                    var s = e[1];
                    Pu(t4, uf0);
                    var e = s;
                    continue;
                  case 4:
                    var p = e[1];
                    Pu(t4, if0);
                    var e = p;
                    continue;
                  case 5:
                    var y = e[1];
                    Pu(t4, ff0);
                    var e = y;
                    continue;
                  case 6:
                    var T = e[1];
                    Pu(t4, xf0);
                    var e = T;
                    continue;
                  case 7:
                    var E = e[1];
                    Pu(t4, af0);
                    var e = E;
                    continue;
                  case 8:
                    var h = e[2], w = e[1];
                    Pu(t4, of0), mN(t4, w), Pu(t4, cf0);
                    var e = h;
                    continue;
                  case 9:
                    var G = e[3], A = e[1];
                    Pu(t4, sf0), mN(t4, A), Pu(t4, vf0);
                    var e = G;
                    continue;
                  case 10:
                    var S = e[1];
                    Pu(t4, lf0);
                    var e = S;
                    continue;
                  case 11:
                    var M = e[1];
                    Pu(t4, bf0);
                    var e = M;
                    continue;
                  case 12:
                    var K = e[1];
                    Pu(t4, pf0);
                    var e = K;
                    continue;
                  case 13:
                    var V = e[1];
                    Pu(t4, mf0);
                    var e = V;
                    continue;
                  default:
                    var f0 = e[1];
                    Pu(t4, _f0);
                    var e = f0;
                    continue;
                }
              }
            }
            function tu(t4) {
              if (typeof t4 == "number")
                return 0;
              switch (t4[0]) {
                case 0:
                  return [0, tu(t4[1])];
                case 1:
                  return [1, tu(t4[1])];
                case 2:
                  return [2, tu(t4[1])];
                case 3:
                  return [3, tu(t4[1])];
                case 4:
                  return [4, tu(t4[1])];
                case 5:
                  return [5, tu(t4[1])];
                case 6:
                  return [6, tu(t4[1])];
                case 7:
                  return [7, tu(t4[1])];
                case 8:
                  var n = t4[1];
                  return [8, n, tu(t4[2])];
                case 9:
                  var e = t4[2], i = t4[1];
                  return [9, e, i, tu(t4[3])];
                case 10:
                  return [10, tu(t4[1])];
                case 11:
                  return [11, tu(t4[1])];
                case 12:
                  return [12, tu(t4[1])];
                case 13:
                  return [13, tu(t4[1])];
                default:
                  return [14, tu(t4[1])];
              }
            }
            function Du(t4) {
              if (typeof t4 == "number") {
                var n = function(sr) {
                  return 0;
                }, e = function(sr) {
                  return 0;
                }, i = function(sr) {
                  return 0;
                };
                return [0, function(sr) {
                  return 0;
                }, i, e, n];
              } else
                switch (t4[0]) {
                  case 0:
                    var x = Du(t4[1]), c = x[4], s = x[3], p = x[2], y = x[1], T = function(sr) {
                      return u(p, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(y, 0), 0;
                    }, T, s, c];
                  case 1:
                    var E = Du(t4[1]), h = E[4], w = E[3], G = E[2], A = E[1], S = function(sr) {
                      return u(G, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(A, 0), 0;
                    }, S, w, h];
                  case 2:
                    var M = Du(t4[1]), K = M[4], V = M[3], f0 = M[2], m0 = M[1], k0 = function(sr) {
                      return u(f0, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(m0, 0), 0;
                    }, k0, V, K];
                  case 3:
                    var g0 = Du(t4[1]), e0 = g0[4], x0 = g0[3], l = g0[2], c0 = g0[1], t0 = function(sr) {
                      return u(l, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(c0, 0), 0;
                    }, t0, x0, e0];
                  case 4:
                    var a0 = Du(t4[1]), w0 = a0[4], _0 = a0[3], E0 = a0[2], X0 = a0[1], b = function(sr) {
                      return u(E0, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(X0, 0), 0;
                    }, b, _0, w0];
                  case 5:
                    var G0 = Du(t4[1]), X = G0[4], s0 = G0[3], dr = G0[2], Ar = G0[1], ar = function(sr) {
                      return u(dr, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(Ar, 0), 0;
                    }, ar, s0, X];
                  case 6:
                    var W0 = Du(t4[1]), Lr = W0[4], Tr = W0[3], Hr = W0[2], Or = W0[1], xr = function(sr) {
                      return u(Hr, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(Or, 0), 0;
                    }, xr, Tr, Lr];
                  case 7:
                    var Rr = Du(t4[1]), Wr = Rr[4], Jr = Rr[3], or = Rr[2], _r = Rr[1], Ir = function(sr) {
                      return u(or, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(_r, 0), 0;
                    }, Ir, Jr, Wr];
                  case 8:
                    var fe = Du(t4[2]), v0 = fe[4], P = fe[3], L = fe[2], Q = fe[1], i0 = function(sr) {
                      return u(L, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(Q, 0), 0;
                    }, i0, P, v0];
                  case 9:
                    var l0 = t4[2], S0 = t4[1], T0 = Du(t4[3]), er = T0[4], j0 = T0[3], B = T0[2], Z = T0[1], p0 = Du(vu(tu(S0), l0)), b0 = p0[4], O0 = p0[3], q0 = p0[2], nr = p0[1], yr = function(sr) {
                      return u(b0, 0), u(er, 0), 0;
                    }, vr = function(sr) {
                      return u(j0, 0), u(O0, 0), 0;
                    }, $0 = function(sr) {
                      return u(q0, 0), u(B, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(Z, 0), u(nr, 0), 0;
                    }, $0, vr, yr];
                  case 10:
                    var Sr = Du(t4[1]), Mr = Sr[4], Br = Sr[3], qr = Sr[2], jr = Sr[1], $r = function(sr) {
                      return u(qr, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(jr, 0), 0;
                    }, $r, Br, Mr];
                  case 11:
                    var ne = Du(t4[1]), Qr = ne[4], pe = ne[3], oe = ne[2], me = ne[1], ae = function(sr) {
                      return u(oe, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(me, 0), 0;
                    }, ae, pe, Qr];
                  case 12:
                    var ce = Du(t4[1]), ge = ce[4], H0 = ce[3], Fr = ce[2], _ = ce[1], k = function(sr) {
                      return u(Fr, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(_, 0), 0;
                    }, k, H0, ge];
                  case 13:
                    var I = Du(t4[1]), U = I[4], Y = I[3], y0 = I[2], D0 = I[1], A0 = function(sr) {
                      return u(U, 0), 0;
                    }, D = function(sr) {
                      return u(Y, 0), 0;
                    }, u0 = function(sr) {
                      return u(y0, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(D0, 0), 0;
                    }, u0, D, A0];
                  default:
                    var Y0 = Du(t4[1]), J0 = Y0[4], fr = Y0[3], Q0 = Y0[2], F0 = Y0[1], gr = function(sr) {
                      return u(J0, 0), 0;
                    }, mr = function(sr) {
                      return u(fr, 0), 0;
                    }, Cr = function(sr) {
                      return u(Q0, 0), 0;
                    };
                    return [0, function(sr) {
                      return u(F0, 0), 0;
                    }, Cr, mr, gr];
                }
            }
            function vu(t4, n) {
              var e = 0;
              if (typeof t4 == "number") {
                if (typeof n == "number")
                  return 0;
                switch (n[0]) {
                  case 10:
                    break;
                  case 11:
                    e = 1;
                    break;
                  case 12:
                    e = 2;
                    break;
                  case 13:
                    e = 3;
                    break;
                  case 14:
                    e = 4;
                    break;
                  case 8:
                    e = 5;
                    break;
                  case 9:
                    e = 6;
                    break;
                  default:
                    throw [0, Fn, yf0];
                }
              } else
                switch (t4[0]) {
                  case 0:
                    var i = 0, x = t4[1];
                    if (typeof n != "number")
                      switch (n[0]) {
                        case 0:
                          return [0, vu(x, n[1])];
                        case 8:
                          e = 5, i = 1;
                          break;
                        case 9:
                          e = 6, i = 1;
                          break;
                        case 10:
                          i = 1;
                          break;
                        case 11:
                          e = 1, i = 1;
                          break;
                        case 12:
                          e = 2, i = 1;
                          break;
                        case 13:
                          e = 3, i = 1;
                          break;
                        case 14:
                          e = 4, i = 1;
                          break;
                      }
                    i || (e = 7);
                    break;
                  case 1:
                    var c = 0, s = t4[1];
                    if (typeof n != "number")
                      switch (n[0]) {
                        case 1:
                          return [1, vu(s, n[1])];
                        case 8:
                          e = 5, c = 1;
                          break;
                        case 9:
                          e = 6, c = 1;
                          break;
                        case 10:
                          c = 1;
                          break;
                        case 11:
                          e = 1, c = 1;
                          break;
                        case 12:
                          e = 2, c = 1;
                          break;
                        case 13:
                          e = 3, c = 1;
                          break;
                        case 14:
                          e = 4, c = 1;
                          break;
                      }
                    c || (e = 7);
                    break;
                  case 2:
                    var p = 0, y = t4[1];
                    if (typeof n == "number")
                      p = 1;
                    else
                      switch (n[0]) {
                        case 2:
                          return [2, vu(y, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          p = 1;
                      }
                    p && (e = 7);
                    break;
                  case 3:
                    var T = 0, E = t4[1];
                    if (typeof n == "number")
                      T = 1;
                    else
                      switch (n[0]) {
                        case 3:
                          return [3, vu(E, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          T = 1;
                      }
                    T && (e = 7);
                    break;
                  case 4:
                    var h = 0, w = t4[1];
                    if (typeof n == "number")
                      h = 1;
                    else
                      switch (n[0]) {
                        case 4:
                          return [4, vu(w, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          h = 1;
                      }
                    h && (e = 7);
                    break;
                  case 5:
                    var G = 0, A = t4[1];
                    if (typeof n == "number")
                      G = 1;
                    else
                      switch (n[0]) {
                        case 5:
                          return [5, vu(A, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          G = 1;
                      }
                    G && (e = 7);
                    break;
                  case 6:
                    var S = 0, M = t4[1];
                    if (typeof n == "number")
                      S = 1;
                    else
                      switch (n[0]) {
                        case 6:
                          return [6, vu(M, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          S = 1;
                      }
                    S && (e = 7);
                    break;
                  case 7:
                    var K = 0, V = t4[1];
                    if (typeof n == "number")
                      K = 1;
                    else
                      switch (n[0]) {
                        case 7:
                          return [7, vu(V, n[1])];
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          e = 6;
                          break;
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          K = 1;
                      }
                    K && (e = 7);
                    break;
                  case 8:
                    var f0 = 0, m0 = t4[2], k0 = t4[1];
                    if (typeof n == "number")
                      f0 = 1;
                    else
                      switch (n[0]) {
                        case 8:
                          var g0 = n[1], e0 = vu(m0, n[2]);
                          return [8, vu(k0, g0), e0];
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          f0 = 1;
                      }
                    if (f0)
                      throw [0, Fn, If0];
                    break;
                  case 9:
                    var x0 = 0, l = t4[3], c0 = t4[2], t0 = t4[1];
                    if (typeof n == "number")
                      x0 = 1;
                    else
                      switch (n[0]) {
                        case 8:
                          e = 5;
                          break;
                        case 9:
                          var a0 = n[3], w0 = n[2], _0 = n[1], E0 = Du(vu(tu(c0), _0)), X0 = E0[4];
                          return u(E0[2], 0), u(X0, 0), [9, t0, w0, vu(l, a0)];
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          e = 4;
                          break;
                        default:
                          x0 = 1;
                      }
                    if (x0)
                      throw [0, Fn, Nf0];
                    break;
                  case 10:
                    var b = t4[1];
                    if (typeof n != "number" && n[0] === 10)
                      return [10, vu(b, n[1])];
                    throw [0, Fn, df0];
                  case 11:
                    var G0 = 0, X = t4[1];
                    if (typeof n == "number")
                      G0 = 1;
                    else
                      switch (n[0]) {
                        case 10:
                          break;
                        case 11:
                          return [11, vu(X, n[1])];
                        default:
                          G0 = 1;
                      }
                    if (G0)
                      throw [0, Fn, kf0];
                    break;
                  case 12:
                    var s0 = 0, dr = t4[1];
                    if (typeof n == "number")
                      s0 = 1;
                    else
                      switch (n[0]) {
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          return [12, vu(dr, n[1])];
                        default:
                          s0 = 1;
                      }
                    if (s0)
                      throw [0, Fn, Ef0];
                    break;
                  case 13:
                    var Ar = 0, ar = t4[1];
                    if (typeof n == "number")
                      Ar = 1;
                    else
                      switch (n[0]) {
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          return [13, vu(ar, n[1])];
                        default:
                          Ar = 1;
                      }
                    if (Ar)
                      throw [0, Fn, gf0];
                    break;
                  default:
                    var W0 = 0, Lr = t4[1];
                    if (typeof n == "number")
                      W0 = 1;
                    else
                      switch (n[0]) {
                        case 10:
                          break;
                        case 11:
                          e = 1;
                          break;
                        case 12:
                          e = 2;
                          break;
                        case 13:
                          e = 3;
                          break;
                        case 14:
                          return [14, vu(Lr, n[1])];
                        default:
                          W0 = 1;
                      }
                    if (W0)
                      throw [0, Fn, Tf0];
                }
              switch (e) {
                case 0:
                  throw [0, Fn, hf0];
                case 1:
                  throw [0, Fn, wf0];
                case 2:
                  throw [0, Fn, Sf0];
                case 3:
                  throw [0, Fn, Ff0];
                case 4:
                  throw [0, Fn, Of0];
                case 5:
                  throw [0, Fn, Af0];
                case 6:
                  throw [0, Fn, Cf0];
                default:
                  throw [0, Fn, Pf0];
              }
            }
            var Fu = [St, ca0, M7(0)];
            function Ap(t4, n) {
              if (typeof t4 == "number")
                return [0, 0, n];
              if (t4[0] === 0)
                return [0, [0, t4[1], t4[2]], n];
              if (typeof n != "number" && n[0] === 2)
                return [0, [1, t4[1]], n[1]];
              throw Fu;
            }
            function hl(t4, n, e) {
              var i = Ap(t4, e);
              if (typeof n == "number") {
                if (n) {
                  var x = i[2];
                  if (typeof x != "number" && x[0] === 2)
                    return [0, i[1], 1, x[1]];
                  throw Fu;
                }
                return [0, i[1], 0, i[2]];
              }
              return [0, i[1], [0, n[1]], i[2]];
            }
            function _7(t4, n, e) {
              if (typeof t4 == "number")
                return [0, 0, dt(n, e)];
              switch (t4[0]) {
                case 0:
                  if (typeof e != "number" && e[0] === 0) {
                    var i = _7(t4[1], n, e[1]);
                    return [0, [0, i[1]], i[2]];
                  }
                  break;
                case 1:
                  if (typeof e != "number" && e[0] === 1) {
                    var x = _7(t4[1], n, e[1]);
                    return [0, [1, x[1]], x[2]];
                  }
                  break;
                case 2:
                  if (typeof e != "number" && e[0] === 2) {
                    var c = _7(t4[1], n, e[1]);
                    return [0, [2, c[1]], c[2]];
                  }
                  break;
                case 3:
                  if (typeof e != "number" && e[0] === 3) {
                    var s = _7(t4[1], n, e[1]);
                    return [0, [3, s[1]], s[2]];
                  }
                  break;
                case 4:
                  if (typeof e != "number" && e[0] === 4) {
                    var p = _7(t4[1], n, e[1]);
                    return [0, [4, p[1]], p[2]];
                  }
                  break;
                case 5:
                  if (typeof e != "number" && e[0] === 5) {
                    var y = _7(t4[1], n, e[1]);
                    return [0, [5, y[1]], y[2]];
                  }
                  break;
                case 6:
                  if (typeof e != "number" && e[0] === 6) {
                    var T = _7(t4[1], n, e[1]);
                    return [0, [6, T[1]], T[2]];
                  }
                  break;
                case 7:
                  if (typeof e != "number" && e[0] === 7) {
                    var E = _7(t4[1], n, e[1]);
                    return [0, [7, E[1]], E[2]];
                  }
                  break;
                case 8:
                  if (typeof e != "number" && e[0] === 8) {
                    var h = e[1], w = e[2], G = t4[2];
                    if (cl([0, t4[1]], [0, h]))
                      throw Fu;
                    var A = _7(G, n, w);
                    return [0, [8, h, A[1]], A[2]];
                  }
                  break;
                case 9:
                  if (typeof e != "number" && e[0] === 9) {
                    var S = e[2], M = e[1], K = e[3], V = t4[3], f0 = t4[2], m0 = t4[1], k0 = [0, Mt(M)];
                    if (cl([0, Mt(m0)], k0))
                      throw Fu;
                    var g0 = [0, Mt(S)];
                    if (cl([0, Mt(f0)], g0))
                      throw Fu;
                    var e0 = Du(vu(tu(M), S)), x0 = e0[4];
                    u(e0[2], 0), u(x0, 0);
                    var l = _7(Mt(V), n, K), c0 = l[2];
                    return [0, [9, M, S, tu(l[1])], c0];
                  }
                  break;
                case 10:
                  if (typeof e != "number" && e[0] === 10) {
                    var t0 = _7(t4[1], n, e[1]);
                    return [0, [10, t0[1]], t0[2]];
                  }
                  break;
                case 11:
                  if (typeof e != "number" && e[0] === 11) {
                    var a0 = _7(t4[1], n, e[1]);
                    return [0, [11, a0[1]], a0[2]];
                  }
                  break;
                case 13:
                  if (typeof e != "number" && e[0] === 13) {
                    var w0 = _7(t4[1], n, e[1]);
                    return [0, [13, w0[1]], w0[2]];
                  }
                  break;
                case 14:
                  if (typeof e != "number" && e[0] === 14) {
                    var _0 = _7(t4[1], n, e[1]);
                    return [0, [14, _0[1]], _0[2]];
                  }
                  break;
              }
              throw Fu;
            }
            function dt(t4, n) {
              if (typeof t4 == "number")
                return [0, 0, n];
              switch (t4[0]) {
                case 0:
                  if (typeof n != "number" && n[0] === 0) {
                    var e = dt(t4[1], n[1]);
                    return [0, [0, e[1]], e[2]];
                  }
                  break;
                case 1:
                  if (typeof n != "number" && n[0] === 0) {
                    var i = dt(t4[1], n[1]);
                    return [0, [1, i[1]], i[2]];
                  }
                  break;
                case 2:
                  var x = t4[2], c = Ap(t4[1], n), s = c[2], p = c[1];
                  if (typeof s != "number" && s[0] === 1) {
                    var y = dt(x, s[1]);
                    return [0, [2, p, y[1]], y[2]];
                  }
                  throw Fu;
                case 3:
                  var T = t4[2], E = Ap(t4[1], n), h = E[2], w = E[1];
                  if (typeof h != "number" && h[0] === 1) {
                    var G = dt(T, h[1]);
                    return [0, [3, w, G[1]], G[2]];
                  }
                  throw Fu;
                case 4:
                  var A = t4[4], S = t4[1], M = hl(t4[2], t4[3], n), K = M[3], V = M[1];
                  if (typeof K != "number" && K[0] === 2) {
                    var f0 = M[2], m0 = dt(A, K[1]);
                    return [0, [4, S, V, f0, m0[1]], m0[2]];
                  }
                  throw Fu;
                case 5:
                  var k0 = t4[4], g0 = t4[1], e0 = hl(t4[2], t4[3], n), x0 = e0[3], l = e0[1];
                  if (typeof x0 != "number" && x0[0] === 3) {
                    var c0 = e0[2], t0 = dt(k0, x0[1]);
                    return [0, [5, g0, l, c0, t0[1]], t0[2]];
                  }
                  throw Fu;
                case 6:
                  var a0 = t4[4], w0 = t4[1], _0 = hl(t4[2], t4[3], n), E0 = _0[3], X0 = _0[1];
                  if (typeof E0 != "number" && E0[0] === 4) {
                    var b = _0[2], G0 = dt(a0, E0[1]);
                    return [0, [6, w0, X0, b, G0[1]], G0[2]];
                  }
                  throw Fu;
                case 7:
                  var X = t4[4], s0 = t4[1], dr = hl(t4[2], t4[3], n), Ar = dr[3], ar = dr[1];
                  if (typeof Ar != "number" && Ar[0] === 5) {
                    var W0 = dr[2], Lr = dt(X, Ar[1]);
                    return [0, [7, s0, ar, W0, Lr[1]], Lr[2]];
                  }
                  throw Fu;
                case 8:
                  var Tr = t4[4], Hr = t4[1], Or = hl(t4[2], t4[3], n), xr = Or[3], Rr = Or[1];
                  if (typeof xr != "number" && xr[0] === 6) {
                    var Wr = Or[2], Jr = dt(Tr, xr[1]);
                    return [0, [8, Hr, Rr, Wr, Jr[1]], Jr[2]];
                  }
                  throw Fu;
                case 9:
                  var or = t4[2], _r = Ap(t4[1], n), Ir = _r[2], fe = _r[1];
                  if (typeof Ir != "number" && Ir[0] === 7) {
                    var v0 = dt(or, Ir[1]);
                    return [0, [9, fe, v0[1]], v0[2]];
                  }
                  throw Fu;
                case 10:
                  var P = dt(t4[1], n);
                  return [0, [10, P[1]], P[2]];
                case 11:
                  var L = t4[1], Q = dt(t4[2], n);
                  return [0, [11, L, Q[1]], Q[2]];
                case 12:
                  var i0 = t4[1], l0 = dt(t4[2], n);
                  return [0, [12, i0, l0[1]], l0[2]];
                case 13:
                  if (typeof n != "number" && n[0] === 8) {
                    var S0 = n[1], T0 = n[2], er = t4[3], j0 = t4[1];
                    if (cl([0, t4[2]], [0, S0]))
                      throw Fu;
                    var B = dt(er, T0);
                    return [0, [13, j0, S0, B[1]], B[2]];
                  }
                  break;
                case 14:
                  if (typeof n != "number" && n[0] === 9) {
                    var Z = n[1], p0 = n[3], b0 = t4[3], O0 = t4[2], q0 = t4[1], nr = [0, Mt(Z)];
                    if (cl([0, Mt(O0)], nr))
                      throw Fu;
                    var yr = dt(b0, Mt(p0));
                    return [0, [14, q0, Z, yr[1]], yr[2]];
                  }
                  break;
                case 15:
                  if (typeof n != "number" && n[0] === 10) {
                    var vr = dt(t4[1], n[1]);
                    return [0, [15, vr[1]], vr[2]];
                  }
                  break;
                case 16:
                  if (typeof n != "number" && n[0] === 11) {
                    var $0 = dt(t4[1], n[1]);
                    return [0, [16, $0[1]], $0[2]];
                  }
                  break;
                case 17:
                  var Sr = t4[1], Mr = dt(t4[2], n);
                  return [0, [17, Sr, Mr[1]], Mr[2]];
                case 18:
                  var Br = t4[2], qr = t4[1];
                  if (qr[0] === 0) {
                    var jr = qr[1], $r = jr[2], ne = dt(jr[1], n), Qr = ne[1], pe = dt(Br, ne[2]);
                    return [0, [18, [0, [0, Qr, $r]], pe[1]], pe[2]];
                  }
                  var oe = qr[1], me = oe[2], ae = dt(oe[1], n), ce = ae[1], ge = dt(Br, ae[2]);
                  return [0, [18, [1, [0, ce, me]], ge[1]], ge[2]];
                case 19:
                  if (typeof n != "number" && n[0] === 13) {
                    var H0 = dt(t4[1], n[1]);
                    return [0, [19, H0[1]], H0[2]];
                  }
                  break;
                case 20:
                  if (typeof n != "number" && n[0] === 1) {
                    var Fr = t4[2], _ = t4[1], k = dt(t4[3], n[1]);
                    return [0, [20, _, Fr, k[1]], k[2]];
                  }
                  break;
                case 21:
                  if (typeof n != "number" && n[0] === 2) {
                    var I = t4[1], U = dt(t4[2], n[1]);
                    return [0, [21, I, U[1]], U[2]];
                  }
                  break;
                case 23:
                  var Y = t4[2], y0 = t4[1];
                  if (typeof y0 == "number")
                    switch (y0) {
                      case 0:
                        return U7(y0, Y, n);
                      case 1:
                        return U7(y0, Y, n);
                      case 2:
                        if (typeof n != "number" && n[0] === 14) {
                          var D0 = dt(Y, n[1]);
                          return [0, [23, 2, D0[1]], D0[2]];
                        }
                        throw Fu;
                      default:
                        return U7(y0, Y, n);
                    }
                  else
                    switch (y0[0]) {
                      case 0:
                        return U7(y0, Y, n);
                      case 1:
                        return U7(y0, Y, n);
                      case 2:
                        return U7(y0, Y, n);
                      case 3:
                        return U7(y0, Y, n);
                      case 4:
                        return U7(y0, Y, n);
                      case 5:
                        return U7(y0, Y, n);
                      case 6:
                        return U7(y0, Y, n);
                      case 7:
                        return U7(y0, Y, n);
                      case 8:
                        return U7([8, y0[1], y0[2]], Y, n);
                      case 9:
                        var A0 = y0[1], D = _7(y0[2], Y, n), u0 = D[2];
                        return [0, [23, [9, A0, D[1]], u0[1]], u0[2]];
                      case 10:
                        return U7(y0, Y, n);
                      default:
                        return U7(y0, Y, n);
                    }
              }
              throw Fu;
            }
            function U7(t4, n, e) {
              var i = dt(n, e);
              return [0, [23, t4, i[1]], i[2]];
            }
            function H7(t4, n, e) {
              var i = tn(e), x = 0 <= n ? t4 : 0, c = Fp(n);
              if (c <= i)
                return e;
              var s = x === 2 ? 48 : 32, p = w1(c, s);
              switch (x) {
                case 0:
                  ss(e, 0, p, 0, i);
                  break;
                case 1:
                  ss(e, 0, p, c - i | 0, i);
                  break;
                default:
                  var y = 0;
                  if (0 < i) {
                    var T = 0;
                    At(e, 0) !== 43 && At(e, 0) !== 45 && At(e, 0) !== 32 && (y = 1, T = 1), T || (p1(p, 0, At(e, 0)), ss(e, 1, p, (c - i | 0) + 1 | 0, i - 1 | 0));
                  } else
                    y = 1;
                  if (y) {
                    var E = 0;
                    if (1 < i && At(e, 0) === 48) {
                      var h = 0;
                      fc !== At(e, 1) && At(e, 1) !== 88 && (E = 1, h = 1), h || (p1(p, 1, At(e, 1)), ss(e, 2, p, (c - i | 0) + 2 | 0, i - 2 | 0));
                    } else
                      E = 1;
                    E && ss(e, 0, p, c - i | 0, i);
                  }
              }
              return p;
            }
            function Yv(t4, n) {
              var e = Fp(t4), i = tn(n), x = At(n, 0), c = 0;
              if (58 <= x)
                71 <= x ? 5 < (x + V3 | 0) >>> 0 || (c = 1) : 65 <= x && (c = 1);
              else {
                var s = 0;
                if (x !== 32)
                  if (43 <= x)
                    switch (x + cy | 0) {
                      case 5:
                        if (i < (e + 2 | 0) && 1 < i) {
                          var p = 0;
                          if ((fc === At(n, 1) || At(n, 1) === 88) && (p = 1), p) {
                            var y = w1(e + 2 | 0, 48);
                            return p1(y, 1, At(n, 1)), ss(n, 2, y, (e - i | 0) + 4 | 0, i - 2 | 0), y;
                          }
                        }
                        c = 1, s = 1;
                        break;
                      case 0:
                      case 2:
                        break;
                      case 1:
                      case 3:
                      case 4:
                        s = 1;
                        break;
                      default:
                        c = 1, s = 1;
                    }
                  else
                    s = 1;
                if (!s && i < (e + 1 | 0)) {
                  var T = w1(e + 1 | 0, 48);
                  return p1(T, 0, x), ss(n, 1, T, (e - i | 0) + 2 | 0, i - 1 | 0), T;
                }
              }
              if (c && i < e) {
                var E = w1(e, 48);
                return ss(n, 0, E, e - i | 0, i), E;
              }
              return n;
            }
            function see(t4) {
              for (var n = 0, e = tn(t4); ; ) {
                if (e <= n)
                  var i = t4;
                else {
                  var x = Vr(t4, n) + SU | 0, c = 0;
                  if (59 < x >>> 0 ? 33 < (x + TS | 0) >>> 0 && (c = 1) : x === 2 && (c = 1), !c) {
                    var n = n + 1 | 0;
                    continue;
                  }
                  var s = t4, p = [0, 0], y = b7(s) - 1 | 0, T = 0;
                  if (!(y < 0))
                    for (var E = T; ; ) {
                      var h = Hu(s, E), w = 0;
                      if (32 <= h) {
                        var G = h - 34 | 0, A = 0;
                        if (58 < G >>> 0 ? 93 <= G && (A = 1) : 56 < (G - 1 | 0) >>> 0 && (w = 1, A = 1), !A) {
                          var S = 1;
                          w = 2;
                        }
                      } else
                        11 <= h ? h === 13 && (w = 1) : 8 <= h && (w = 1);
                      switch (w) {
                        case 0:
                          var S = 4;
                          break;
                        case 1:
                          var S = 2;
                          break;
                      }
                      p[1] = p[1] + S | 0;
                      var M = E + 1 | 0;
                      if (y !== E) {
                        var E = M;
                        continue;
                      }
                      break;
                    }
                  if (p[1] === b7(s))
                    var K = mz(s);
                  else {
                    var V = Rt(p[1]);
                    p[1] = 0;
                    var f0 = b7(s) - 1 | 0, m0 = 0;
                    if (!(f0 < 0))
                      for (var k0 = m0; ; ) {
                        var g0 = Hu(s, k0), e0 = 0;
                        if (35 <= g0)
                          g0 === 92 ? e0 = 2 : Kn <= g0 ? e0 = 1 : e0 = 3;
                        else if (32 <= g0)
                          34 <= g0 ? e0 = 2 : e0 = 3;
                        else if (14 <= g0)
                          e0 = 1;
                        else
                          switch (g0) {
                            case 8:
                              Zn(V, p[1], 92), p[1]++, Zn(V, p[1], 98);
                              break;
                            case 9:
                              Zn(V, p[1], 92), p[1]++, Zn(V, p[1], x1);
                              break;
                            case 10:
                              Zn(V, p[1], 92), p[1]++, Zn(V, p[1], Yt);
                              break;
                            case 13:
                              Zn(V, p[1], 92), p[1]++, Zn(V, p[1], u1);
                              break;
                            default:
                              e0 = 1;
                          }
                        switch (e0) {
                          case 1:
                            Zn(V, p[1], 92), p[1]++, Zn(V, p[1], 48 + (g0 / ti | 0) | 0), p[1]++, Zn(V, p[1], 48 + ((g0 / 10 | 0) % 10 | 0) | 0), p[1]++, Zn(V, p[1], 48 + (g0 % 10 | 0) | 0);
                            break;
                          case 2:
                            Zn(V, p[1], 92), p[1]++, Zn(V, p[1], g0);
                            break;
                          case 3:
                            Zn(V, p[1], g0);
                            break;
                        }
                        p[1]++;
                        var x0 = k0 + 1 | 0;
                        if (f0 !== k0) {
                          var k0 = x0;
                          continue;
                        }
                        break;
                      }
                    var K = V;
                  }
                  var i = K;
                }
                var l = tn(i), c0 = w1(l + 2 | 0, 34);
                return As(i, 0, c0, 1, l), c0;
              }
            }
            function Tz(t4, n) {
              var e = Fp(n), i = iz ? iz[1] : 70;
              switch (t4[2]) {
                case 0:
                  var x = ji;
                  break;
                case 1:
                  var x = R7;
                  break;
                case 2:
                  var x = 69;
                  break;
                case 3:
                  var x = s7;
                  break;
                case 4:
                  var x = 71;
                  break;
                case 5:
                  var x = i;
                  break;
                case 6:
                  var x = L7;
                  break;
                case 7:
                  var x = 72;
                  break;
                default:
                  var x = 70;
              }
              var c = Ez(16);
              switch (Xv(c, 37), t4[1]) {
                case 0:
                  break;
                case 1:
                  Xv(c, 43);
                  break;
                default:
                  Xv(c, 32);
              }
              return 8 <= t4[2] && Xv(c, 35), Xv(c, 46), Pu(c, r(C + e)), Xv(c, x), gz(c);
            }
            function Np(t4, n) {
              if (13 <= t4) {
                var e = [0, 0], i = tn(n) - 1 | 0, x = 0;
                if (!(i < 0))
                  for (var c = x; ; ) {
                    9 < (Vr(n, c) + Wt | 0) >>> 0 || e[1]++;
                    var s = c + 1 | 0;
                    if (i !== c) {
                      var c = s;
                      continue;
                    }
                    break;
                  }
                var p = e[1], y = Rt(tn(n) + ((p - 1 | 0) / 3 | 0) | 0), T = [0, 0], E = function(K) {
                  return p1(y, T[1], K), T[1]++, 0;
                }, h = [0, ((p - 1 | 0) % 3 | 0) + 1 | 0], w = tn(n) - 1 | 0, G = 0;
                if (!(w < 0))
                  for (var A = G; ; ) {
                    var S = Vr(n, A);
                    9 < (S + Wt | 0) >>> 0 || (h[1] === 0 && (E(95), h[1] = 3), h[1] += -1), E(S);
                    var M = A + 1 | 0;
                    if (w !== A) {
                      var A = M;
                      continue;
                    }
                    break;
                  }
                return y;
              }
              return n;
            }
            function vee(t4, n) {
              switch (t4) {
                case 1:
                  var e = Hx0;
                  break;
                case 2:
                  var e = Xx0;
                  break;
                case 4:
                  var e = Yx0;
                  break;
                case 5:
                  var e = Vx0;
                  break;
                case 6:
                  var e = zx0;
                  break;
                case 7:
                  var e = Kx0;
                  break;
                case 8:
                  var e = Wx0;
                  break;
                case 9:
                  var e = Jx0;
                  break;
                case 10:
                  var e = $x0;
                  break;
                case 11:
                  var e = Zx0;
                  break;
                case 0:
                case 13:
                  var e = Qx0;
                  break;
                case 3:
                case 14:
                  var e = ra0;
                  break;
                default:
                  var e = ea0;
              }
              return Np(t4, hp(e, n));
            }
            function lee(t4, n) {
              switch (t4) {
                case 1:
                  var e = _x0;
                  break;
                case 2:
                  var e = yx0;
                  break;
                case 4:
                  var e = dx0;
                  break;
                case 5:
                  var e = hx0;
                  break;
                case 6:
                  var e = kx0;
                  break;
                case 7:
                  var e = wx0;
                  break;
                case 8:
                  var e = Ex0;
                  break;
                case 9:
                  var e = Sx0;
                  break;
                case 10:
                  var e = gx0;
                  break;
                case 11:
                  var e = Fx0;
                  break;
                case 0:
                case 13:
                  var e = Tx0;
                  break;
                case 3:
                case 14:
                  var e = Ox0;
                  break;
                default:
                  var e = Ix0;
              }
              return Np(t4, hp(e, n));
            }
            function bee(t4, n) {
              switch (t4) {
                case 1:
                  var e = ux0;
                  break;
                case 2:
                  var e = ix0;
                  break;
                case 4:
                  var e = fx0;
                  break;
                case 5:
                  var e = xx0;
                  break;
                case 6:
                  var e = ax0;
                  break;
                case 7:
                  var e = ox0;
                  break;
                case 8:
                  var e = cx0;
                  break;
                case 9:
                  var e = sx0;
                  break;
                case 10:
                  var e = vx0;
                  break;
                case 11:
                  var e = lx0;
                  break;
                case 0:
                case 13:
                  var e = bx0;
                  break;
                case 3:
                case 14:
                  var e = px0;
                  break;
                default:
                  var e = mx0;
              }
              return Np(t4, hp(e, n));
            }
            function pee(t4, n) {
              switch (t4) {
                case 1:
                  var e = Ax0;
                  break;
                case 2:
                  var e = Nx0;
                  break;
                case 4:
                  var e = Cx0;
                  break;
                case 5:
                  var e = Px0;
                  break;
                case 6:
                  var e = Dx0;
                  break;
                case 7:
                  var e = Lx0;
                  break;
                case 8:
                  var e = Rx0;
                  break;
                case 9:
                  var e = jx0;
                  break;
                case 10:
                  var e = Gx0;
                  break;
                case 11:
                  var e = Mx0;
                  break;
                case 0:
                case 13:
                  var e = Bx0;
                  break;
                case 3:
                case 14:
                  var e = qx0;
                  break;
                default:
                  var e = Ux0;
              }
              return Np(t4, G70(e, n));
            }
            function vs(t4, n, e) {
              function i(m0) {
                switch (t4[1]) {
                  case 0:
                    var k0 = 45;
                    break;
                  case 1:
                    var k0 = 43;
                    break;
                  default:
                    var k0 = 32;
                }
                return D70(e, n, k0);
              }
              function x(m0) {
                var k0 = m70(e);
                return k0 === 3 ? e < 0 ? ex0 : nx0 : 4 <= k0 ? rx0 : m0;
              }
              switch (t4[2]) {
                case 5:
                  for (var c = zA(Tz(t4, n), e), s = 0, p = tn(c); ; ) {
                    if (s === p)
                      var y = 0;
                    else {
                      var T = At(c, s) + l1 | 0, E = 0;
                      if (23 < T >>> 0 ? T === 55 && (E = 1) : 21 < (T - 1 | 0) >>> 0 && (E = 1), !E) {
                        var s = s + 1 | 0;
                        continue;
                      }
                      var y = 1;
                    }
                    var h = y ? c : Te(c, tx0);
                    return x(h);
                  }
                case 6:
                  return i(0);
                case 7:
                  var w = i(0), G = b7(w);
                  if (G === 0)
                    var A = w;
                  else {
                    var S = Rt(G), M = G - 1 | 0, K = 0;
                    if (!(M < 0))
                      for (var V = K; ; ) {
                        Zn(S, V, vz(Hu(w, V)));
                        var f0 = V + 1 | 0;
                        if (M !== V) {
                          var V = f0;
                          continue;
                        }
                        break;
                      }
                    var A = S;
                  }
                  return A;
                case 8:
                  return x(i(0));
                default:
                  return zA(Tz(t4, n), e);
              }
            }
            function kl(t4, n, e, i) {
              for (var x = n, c = e, s = i; ; ) {
                if (typeof s == "number")
                  return u(x, c);
                switch (s[0]) {
                  case 0:
                    var p = s[1];
                    return function(or) {
                      return Yn(x, [5, c, or], p);
                    };
                  case 1:
                    var y = s[1];
                    return function(or) {
                      var _r = 0;
                      if (40 <= or)
                        if (or === 92)
                          var Ir = Fi0;
                        else
                          Kn <= or ? _r = 1 : _r = 2;
                      else if (32 <= or)
                        if (39 <= or)
                          var Ir = Ti0;
                        else
                          _r = 2;
                      else if (14 <= or)
                        _r = 1;
                      else
                        switch (or) {
                          case 8:
                            var Ir = Oi0;
                            break;
                          case 9:
                            var Ir = Ii0;
                            break;
                          case 10:
                            var Ir = Ai0;
                            break;
                          case 13:
                            var Ir = Ni0;
                            break;
                          default:
                            _r = 1;
                        }
                      switch (_r) {
                        case 1:
                          var fe = Rt(4);
                          Zn(fe, 0, 92), Zn(fe, 1, 48 + (or / ti | 0) | 0), Zn(fe, 2, 48 + ((or / 10 | 0) % 10 | 0) | 0), Zn(fe, 3, 48 + (or % 10 | 0) | 0);
                          var Ir = fe;
                          break;
                        case 2:
                          var v0 = Rt(1);
                          Zn(v0, 0, or);
                          var Ir = v0;
                          break;
                      }
                      var P = tn(Ir), L = w1(P + 2 | 0, 39);
                      return As(Ir, 0, L, 1, P), Yn(x, [4, c, L], y);
                    };
                  case 2:
                    var T = s[2], E = s[1];
                    return dN(x, c, T, E, function(or) {
                      return or;
                    });
                  case 3:
                    return dN(x, c, s[2], s[1], see);
                  case 4:
                    return Cp(x, c, s[4], s[2], s[3], vee, s[1]);
                  case 5:
                    return Cp(x, c, s[4], s[2], s[3], lee, s[1]);
                  case 6:
                    return Cp(x, c, s[4], s[2], s[3], bee, s[1]);
                  case 7:
                    return Cp(x, c, s[4], s[2], s[3], pee, s[1]);
                  case 8:
                    var h = s[4], w = s[3], G = s[2], A = s[1];
                    if (typeof G == "number") {
                      if (typeof w == "number")
                        return w ? function(or, _r) {
                          return Yn(x, [4, c, vs(A, or, _r)], h);
                        } : function(or) {
                          return Yn(x, [4, c, vs(A, pN(A), or)], h);
                        };
                      var S = w[1];
                      return function(or) {
                        return Yn(x, [4, c, vs(A, S, or)], h);
                      };
                    } else {
                      if (G[0] === 0) {
                        var M = G[2], K = G[1];
                        if (typeof w == "number")
                          return w ? function(or, _r) {
                            return Yn(x, [4, c, H7(K, M, vs(A, or, _r))], h);
                          } : function(or) {
                            return Yn(x, [4, c, H7(K, M, vs(A, pN(A), or))], h);
                          };
                        var V = w[1];
                        return function(or) {
                          return Yn(x, [4, c, H7(K, M, vs(A, V, or))], h);
                        };
                      }
                      var f0 = G[1];
                      if (typeof w == "number")
                        return w ? function(or, _r, Ir) {
                          return Yn(x, [4, c, H7(f0, or, vs(A, _r, Ir))], h);
                        } : function(or, _r) {
                          return Yn(x, [4, c, H7(f0, or, vs(A, pN(A), _r))], h);
                        };
                      var m0 = w[1];
                      return function(or, _r) {
                        return Yn(x, [4, c, H7(f0, or, vs(A, m0, _r))], h);
                      };
                    }
                  case 9:
                    return dN(x, c, s[2], s[1], nee);
                  case 10:
                    var c = [7, c], s = s[1];
                    continue;
                  case 11:
                    var c = [2, c, s[1]], s = s[2];
                    continue;
                  case 12:
                    var c = [3, c, s[1]], s = s[2];
                    continue;
                  case 13:
                    var k0 = s[3], g0 = s[2], e0 = Ez(16);
                    mN(e0, g0);
                    var x0 = gz(e0);
                    return function(or) {
                      return Yn(x, [4, c, x0], k0);
                    };
                  case 14:
                    var l = s[3], c0 = s[2];
                    return function(or) {
                      var _r = or[1], Ir = dt(_r, Mt(tu(c0)));
                      if (typeof Ir[2] == "number")
                        return Yn(x, c, Nt(Ir[1], l));
                      throw Fu;
                    };
                  case 15:
                    var t0 = s[1];
                    return function(or, _r) {
                      return Yn(x, [6, c, function(Ir) {
                        return a(or, Ir, _r);
                      }], t0);
                    };
                  case 16:
                    var a0 = s[1];
                    return function(or) {
                      return Yn(x, [6, c, or], a0);
                    };
                  case 17:
                    var c = [0, c, s[1]], s = s[2];
                    continue;
                  case 18:
                    var w0 = s[1];
                    if (w0[0] === 0) {
                      var _0 = s[2], E0 = w0[1][1], X0 = 0, x = function(fe, v0, P) {
                        return function(L) {
                          return Yn(v0, [1, fe, [0, L]], P);
                        };
                      }(c, x, _0), c = X0, s = E0;
                      continue;
                    }
                    var b = s[2], G0 = w0[1][1], X = 0, x = function(or, _r, Ir) {
                      return function(fe) {
                        return Yn(_r, [1, or, [1, fe]], Ir);
                      };
                    }(c, x, b), c = X, s = G0;
                    continue;
                  case 19:
                    throw [0, Fn, Lf0];
                  case 20:
                    var s0 = s[3], dr = [8, c, Rf0];
                    return function(or) {
                      return Yn(x, dr, s0);
                    };
                  case 21:
                    var Ar = s[2];
                    return function(or) {
                      return Yn(x, [4, c, hp(Df0, or)], Ar);
                    };
                  case 22:
                    var ar = s[1];
                    return function(or) {
                      return Yn(x, [5, c, or], ar);
                    };
                  case 23:
                    var W0 = s[2], Lr = s[1];
                    if (typeof Lr == "number")
                      switch (Lr) {
                        case 0:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 1:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 2:
                          throw [0, Fn, jf0];
                        default:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                      }
                    else
                      switch (Lr[0]) {
                        case 0:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 1:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 2:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 3:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 4:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 5:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 6:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 7:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 8:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        case 9:
                          var Tr = Lr[2];
                          return t4 < 50 ? _N(t4 + 1 | 0, x, c, Tr, W0) : gu(_N, [0, x, c, Tr, W0]);
                        case 10:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                        default:
                          return t4 < 50 ? vt(t4 + 1 | 0, x, c, W0) : gu(vt, [0, x, c, W0]);
                      }
                  default:
                    var Hr = s[3], Or = s[1], xr = u(s[2], 0);
                    return t4 < 50 ? yN(t4 + 1 | 0, x, c, Hr, Or, xr) : gu(yN, [0, x, c, Hr, Or, xr]);
                }
              }
            }
            function _N(t4, n, e, i, x) {
              if (typeof i == "number")
                return t4 < 50 ? vt(t4 + 1 | 0, n, e, x) : gu(vt, [0, n, e, x]);
              switch (i[0]) {
                case 0:
                  var c = i[1];
                  return function(m0) {
                    return fi(n, e, c, x);
                  };
                case 1:
                  var s = i[1];
                  return function(m0) {
                    return fi(n, e, s, x);
                  };
                case 2:
                  var p = i[1];
                  return function(m0) {
                    return fi(n, e, p, x);
                  };
                case 3:
                  var y = i[1];
                  return function(m0) {
                    return fi(n, e, y, x);
                  };
                case 4:
                  var T = i[1];
                  return function(m0) {
                    return fi(n, e, T, x);
                  };
                case 5:
                  var E = i[1];
                  return function(m0) {
                    return fi(n, e, E, x);
                  };
                case 6:
                  var h = i[1];
                  return function(m0) {
                    return fi(n, e, h, x);
                  };
                case 7:
                  var w = i[1];
                  return function(m0) {
                    return fi(n, e, w, x);
                  };
                case 8:
                  var G = i[2];
                  return function(m0) {
                    return fi(n, e, G, x);
                  };
                case 9:
                  var A = i[3], S = i[2], M = vu(tu(i[1]), S);
                  return function(m0) {
                    return fi(n, e, t7(M, A), x);
                  };
                case 10:
                  var K = i[1];
                  return function(m0, k0) {
                    return fi(n, e, K, x);
                  };
                case 11:
                  var V = i[1];
                  return function(m0) {
                    return fi(n, e, V, x);
                  };
                case 12:
                  var f0 = i[1];
                  return function(m0) {
                    return fi(n, e, f0, x);
                  };
                case 13:
                  throw [0, Fn, Gf0];
                default:
                  throw [0, Fn, Mf0];
              }
            }
            function vt(t4, n, e, i) {
              var x = [8, e, Bf0];
              return t4 < 50 ? kl(t4 + 1 | 0, n, x, i) : gu(kl, [0, n, x, i]);
            }
            function yN(t4, n, e, i, x, c) {
              if (x) {
                var s = x[1];
                return function(y) {
                  return mee(n, e, i, s, u(c, y));
                };
              }
              var p = [4, e, c];
              return t4 < 50 ? kl(t4 + 1 | 0, n, p, i) : gu(kl, [0, n, p, i]);
            }
            function Yn(t4, n, e) {
              return QA(kl(0, t4, n, e));
            }
            function fi(t4, n, e, i) {
              return QA(_N(0, t4, n, e, i));
            }
            function mee(t4, n, e, i, x) {
              return QA(yN(0, t4, n, e, i, x));
            }
            function dN(t4, n, e, i, x) {
              if (typeof i == "number")
                return function(y) {
                  return Yn(t4, [4, n, u(x, y)], e);
                };
              if (i[0] === 0) {
                var c = i[2], s = i[1];
                return function(y) {
                  return Yn(t4, [4, n, H7(s, c, u(x, y))], e);
                };
              }
              var p = i[1];
              return function(y, T) {
                return Yn(t4, [4, n, H7(p, y, u(x, T))], e);
              };
            }
            function Cp(t4, n, e, i, x, c, s) {
              if (typeof i == "number") {
                if (typeof x == "number")
                  return x ? function(G, A) {
                    return Yn(t4, [4, n, Yv(G, a(c, s, A))], e);
                  } : function(G) {
                    return Yn(t4, [4, n, a(c, s, G)], e);
                  };
                var p = x[1];
                return function(G) {
                  return Yn(t4, [4, n, Yv(p, a(c, s, G))], e);
                };
              } else {
                if (i[0] === 0) {
                  var y = i[2], T = i[1];
                  if (typeof x == "number")
                    return x ? function(G, A) {
                      return Yn(t4, [4, n, H7(T, y, Yv(G, a(c, s, A)))], e);
                    } : function(G) {
                      return Yn(t4, [4, n, H7(T, y, a(c, s, G))], e);
                    };
                  var E = x[1];
                  return function(G) {
                    return Yn(t4, [4, n, H7(T, y, Yv(E, a(c, s, G)))], e);
                  };
                }
                var h = i[1];
                if (typeof x == "number")
                  return x ? function(G, A, S) {
                    return Yn(t4, [4, n, H7(h, G, Yv(A, a(c, s, S)))], e);
                  } : function(G, A) {
                    return Yn(t4, [4, n, H7(h, G, a(c, s, A))], e);
                  };
                var w = x[1];
                return function(G, A) {
                  return Yn(t4, [4, n, H7(h, G, Yv(w, a(c, s, A)))], e);
                };
              }
            }
            function ls(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 0;
                switch (e[0]) {
                  case 0:
                    var i = e[1], x = Fz(e[2]);
                    return ls(t4, i), vl(t4, x);
                  case 1:
                    var c = e[2], s = e[1];
                    if (c[0] === 0) {
                      var p = c[1];
                      ls(t4, s), vl(t4, qf0);
                      var e = p;
                      continue;
                    }
                    var y = c[1];
                    ls(t4, s), vl(t4, Uf0);
                    var e = y;
                    continue;
                  case 6:
                    var T = e[2];
                    return ls(t4, e[1]), u(T, t4);
                  case 7:
                    return ls(t4, e[1]), m1(t4);
                  case 8:
                    var E = e[2];
                    return ls(t4, e[1]), Nu(E);
                  case 2:
                  case 4:
                    var h = e[2];
                    return ls(t4, e[1]), vl(t4, h);
                  default:
                    var w = e[2];
                    return ls(t4, e[1]), QV(t4, w);
                }
              }
            }
            function bs(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 0;
                switch (e[0]) {
                  case 0:
                    var i = e[1], x = Fz(e[2]);
                    return bs(t4, i), dn(t4, x);
                  case 1:
                    var c = e[2], s = e[1];
                    if (c[0] === 0) {
                      var p = c[1];
                      bs(t4, s), dn(t4, Hf0);
                      var e = p;
                      continue;
                    }
                    var y = c[1];
                    bs(t4, s), dn(t4, Xf0);
                    var e = y;
                    continue;
                  case 6:
                    var T = e[2];
                    return bs(t4, e[1]), dn(t4, u(T, 0));
                  case 7:
                    var e = e[1];
                    continue;
                  case 8:
                    var E = e[2];
                    return bs(t4, e[1]), Nu(E);
                  case 2:
                  case 4:
                    var h = e[2];
                    return bs(t4, e[1]), dn(t4, h);
                  default:
                    var w = e[2];
                    return bs(t4, e[1]), Ui(t4, w);
                }
              }
            }
            function _ee(t4) {
              if (Un(t4, Vf0))
                return zf0;
              var n = tn(t4);
              function e(S) {
                var M = Yf0[1], K = Qn(C4);
                return u(Yn(function(V) {
                  return bs(K, V), ke(Bt(K));
                }, 0, M), t4);
              }
              function i(S) {
                for (var M = S; ; ) {
                  if (M === n)
                    return M;
                  var K = At(t4, M);
                  if (K !== 9 && K !== 32)
                    return M;
                  var M = M + 1 | 0;
                }
              }
              function x(S, M) {
                for (var K = M; ; ) {
                  if (K === n || 25 < (At(t4, K) + V3 | 0) >>> 0)
                    return K;
                  var K = K + 1 | 0;
                }
              }
              function c(S, M) {
                for (var K = M; ; ) {
                  if (K === n)
                    return K;
                  var V = At(t4, K), f0 = 0;
                  if (48 <= V ? 58 <= V || (f0 = 1) : V === 45 && (f0 = 1), f0) {
                    var K = K + 1 | 0;
                    continue;
                  }
                  return K;
                }
              }
              var s = i(0), p = x(s, s), y = m7(t4, s, p - s | 0), T = i(p), E = c(T, T);
              if (T === E)
                var h = 0;
              else
                try {
                  var w = qi(m7(t4, T, E - T | 0)), h = w;
                } catch (S) {
                  if (S = gt(S), S[1] !== q7)
                    throw S;
                  var h = e(0);
                }
              i(E) !== n && e(0);
              var G = 0;
              if (n0(y, Kf0) && n0(y, Wf0))
                var A = n0(y, Jf0) ? n0(y, $f0) ? n0(y, Zf0) ? n0(y, Qf0) ? e(0) : 1 : 2 : 3 : 0;
              else
                G = 1;
              if (G)
                var A = 4;
              return [0, h, A];
            }
            function hN(t4, n) {
              var e = n[1], i = 0;
              return Yn(function(x) {
                return ls(t4, x), 0;
              }, i, e);
            }
            function kN(t4) {
              return hN(Lc, t4);
            }
            function et(t4) {
              var n = t4[1];
              return Yn(function(e) {
                var i = Qn(64);
                return bs(i, e), Bt(i);
              }, 0, n);
            }
            var wN = [0, 0];
            function EN(t4, n) {
              var e = t4[1 + n];
              if (1 - (typeof e == "number" ? 1 : 0)) {
                if (h1(e) === Y2)
                  return u(et(ja0), e);
                if (h1(e) === ih)
                  for (var i = zA(wi0, e), x = 0, c = tn(i); ; ) {
                    if (c <= x)
                      return Te(i, Ei0);
                    var s = At(i, x), p = 0;
                    if (48 <= s ? 58 <= s || (p = 1) : s === 45 && (p = 1), p) {
                      var x = x + 1 | 0;
                      continue;
                    }
                    return i;
                  }
                return Ga0;
              }
              return u(et(Ra0), e);
            }
            function Oz(t4, n) {
              if (t4.length - 1 <= n)
                return sa0;
              var e = Oz(t4, n + 1 | 0), i = EN(t4, n);
              return a(et(va0), i, e);
            }
            function Pp(t4) {
              function n(k0) {
                for (var g0 = k0; ; ) {
                  if (g0) {
                    var e0 = g0[2], x0 = g0[1];
                    try {
                      var l = 0, c0 = u(x0, t4);
                      l = 1;
                    } catch {
                    }
                    if (l && c0)
                      return [0, c0[1]];
                    var g0 = e0;
                    continue;
                  }
                  return 0;
                }
              }
              var e = n(wN[1]);
              if (e)
                return e[1];
              if (t4 === rN)
                return Ta0;
              if (t4 === uz)
                return Oa0;
              if (t4[1] === tz) {
                var i = t4[2], x = i[3], c = i[2], s = i[1];
                return p7(et(nN), s, c, x, x + 5 | 0, Ia0);
              }
              if (t4[1] === Fn) {
                var p = t4[2], y = p[3], T = p[2], E = p[1];
                return p7(et(nN), E, T, y, y + 6 | 0, Aa0);
              }
              if (t4[1] === sl) {
                var h = t4[2], w = h[3], G = h[2], A = h[1];
                return p7(et(nN), A, G, w, w + 6 | 0, Na0);
              }
              if (h1(t4) === 0) {
                var S = t4.length - 1, M = t4[1][1];
                if (2 < S >>> 0)
                  var K = Oz(t4, 2), V = EN(t4, 1), f0 = a(et(Ca0), V, K);
                else
                  switch (S) {
                    case 0:
                      var f0 = Pa0;
                      break;
                    case 1:
                      var f0 = Da0;
                      break;
                    default:
                      var m0 = EN(t4, 1), f0 = u(et(La0), m0);
                  }
                return Te(M, f0);
              }
              return t4[1];
            }
            function SN(t4, n) {
              var e = I70(n), i = e.length - 1 - 1 | 0, x = 0;
              if (!(i < 0))
                for (var c = x; ; ) {
                  var s = nu(e, c)[1 + c], p = function(f0) {
                    return function(m0) {
                      return m0 ? f0 === 0 ? da0 : ha0 : f0 === 0 ? ka0 : wa0;
                    };
                  }(c);
                  if (s[0] === 0)
                    var y = s[5], T = s[4], E = s[3], h = s[6] ? Ea0 : Sa0, w = s[2], G = s[7], A = p(s[1]), M = [0, di0(et(ga0), A, G, w, h, E, T, y)];
                  else if (s[1])
                    var M = 0;
                  else
                    var S = p(0), M = [0, u(et(Fa0), S)];
                  if (M) {
                    var K = M[1];
                    u(hN(t4, _a0), K);
                  }
                  var V = c + 1 | 0;
                  if (i !== c) {
                    var c = V;
                    continue;
                  }
                  break;
                }
              return 0;
            }
            function Iz(t4) {
              for (; ; ) {
                var n = wN[1], e = 1 - iN(wN, n, [0, t4, n]);
                if (!e)
                  return e;
              }
            }
            var yee = Ma0.slice();
            function dee(t4, n) {
              var e = Pp(t4);
              u(kN(ma0), e), SN(Lc, n);
              var i = Y70(0);
              if (i < 0) {
                var x = Fp(i);
                cz(nu(yee, x)[1 + x]);
              }
              return m1(Lc);
            }
            var hee = [0];
            ZA(r(BH), function(t4, n) {
              try {
                try {
                  var e = n ? hee : HV(0);
                  try {
                    xN(0);
                  } catch {
                  }
                  try {
                    var i = dee(t4, e), x = i;
                  } catch (y) {
                    y = gt(y);
                    var c = Pp(t4);
                    u(kN(la0), c), SN(Lc, e);
                    var s = Pp(y);
                    u(kN(ba0), s), SN(Lc, HV(0));
                    var x = m1(Lc);
                  }
                  var p = x;
                } catch (y) {
                  if (y = gt(y), y !== rN)
                    throw y;
                  var p = cz(pa0);
                }
                return p;
              } catch {
                return 0;
              }
            });
            var gN = [St, fo0, M7(0)], Dp = 0, Az = -1;
            function wl(t4, n) {
              return t4[13] = t4[13] + n[3] | 0, vN(n, t4[28]);
            }
            var Nz = 1000000010;
            function FN(t4, n) {
              return ir(t4[17], n, 0, tn(n));
            }
            function Lp(t4) {
              return u(t4[19], 0);
            }
            function Cz(t4, n, e) {
              return t4[9] = t4[9] - n | 0, FN(t4, e), t4[11] = 0, 0;
            }
            function Rp(t4, n) {
              var e = n0(n, io0);
              return e && Cz(t4, tn(n), n);
            }
            function Vv(t4, n, e) {
              var i = n[3], x = n[2];
              Rp(t4, n[1]), Lp(t4), t4[11] = 1;
              var c = (t4[6] - e | 0) + x | 0, s = t4[8], p = s <= c ? s : c;
              return t4[10] = p, t4[9] = t4[6] - t4[10] | 0, u(t4[21], t4[10]), Rp(t4, i);
            }
            function Pz(t4, n) {
              return Vv(t4, uo0, n);
            }
            function El(t4, n) {
              var e = n[2], i = n[3];
              return Rp(t4, n[1]), t4[9] = t4[9] - e | 0, u(t4[20], e), Rp(t4, i);
            }
            function Dz(t4) {
              for (; ; ) {
                var n = t4[28][2], e = n ? [0, n[1]] : 0;
                if (e) {
                  var i = e[1], x = i[1], c = i[2], s = 0 <= x ? 1 : 0, p = i[3], y = t4[13] - t4[12] | 0, T = s || (t4[9] <= y ? 1 : 0);
                  if (T) {
                    var E = t4[28], h = E[2];
                    if (h) {
                      if (h[2]) {
                        var w = h[2];
                        E[1] = E[1] - 1 | 0, E[2] = w;
                      } else
                        sN(E);
                      var G = 0 <= x ? x : Nz;
                      if (typeof c == "number")
                        switch (c) {
                          case 0:
                            var A = Hv(t4[3]);
                            if (A) {
                              var S = A[1][1], M = function(L, Q) {
                                if (Q) {
                                  var i0 = Q[1], l0 = Q[2];
                                  return X70(L, i0) ? [0, L, Q] : [0, i0, M(L, l0)];
                                }
                                return [0, L, 0];
                              };
                              S[1] = M(t4[6] - t4[9] | 0, S[1]);
                            }
                            break;
                          case 1:
                            Uv(t4[2]);
                            break;
                          case 2:
                            Uv(t4[3]);
                            break;
                          case 3:
                            var K = Hv(t4[2]);
                            K ? Pz(t4, K[1][2]) : Lp(t4);
                            break;
                          case 4:
                            if (t4[10] !== (t4[6] - t4[9] | 0)) {
                              var V = t4[28], f0 = V[2];
                              if (f0) {
                                var m0 = f0[1];
                                if (f0[2]) {
                                  var k0 = f0[2];
                                  V[1] = V[1] - 1 | 0, V[2] = k0;
                                  var g0 = [0, m0];
                                } else {
                                  sN(V);
                                  var g0 = [0, m0];
                                }
                              } else
                                var g0 = 0;
                              if (g0) {
                                var e0 = g0[1], x0 = e0[1];
                                t4[12] = t4[12] - e0[3] | 0, t4[9] = t4[9] + x0 | 0;
                              }
                            }
                            break;
                          default:
                            var l = Uv(t4[5]);
                            l && FN(t4, u(t4[25], l[1]));
                        }
                      else
                        switch (c[0]) {
                          case 0:
                            Cz(t4, G, c[1]);
                            break;
                          case 1:
                            var c0 = c[2], t0 = c[1], a0 = c0[1], w0 = c0[2], _0 = Hv(t4[2]);
                            if (_0) {
                              var E0 = _0[1], X0 = E0[2];
                              switch (E0[1]) {
                                case 0:
                                  El(t4, t0);
                                  break;
                                case 1:
                                  Vv(t4, c0, X0);
                                  break;
                                case 2:
                                  Vv(t4, c0, X0);
                                  break;
                                case 3:
                                  t4[9] < (G + tn(a0) | 0) ? Vv(t4, c0, X0) : El(t4, t0);
                                  break;
                                case 4:
                                  t4[11] || !(t4[9] < (G + tn(a0) | 0) || ((t4[6] - X0 | 0) + w0 | 0) < t4[10]) ? El(t4, t0) : Vv(t4, c0, X0);
                                  break;
                                default:
                                  El(t4, t0);
                              }
                            }
                            break;
                          case 2:
                            var b = t4[6] - t4[9] | 0, G0 = c[2], X = c[1], s0 = Hv(t4[3]);
                            if (s0) {
                              var dr = s0[1][1], Ar = dr[1];
                              if (Ar)
                                for (var ar = dr[1], W0 = Ar[1]; ; ) {
                                  if (ar) {
                                    var Lr = ar[1], Tr = ar[2];
                                    if (!(b <= Lr)) {
                                      var ar = Tr;
                                      continue;
                                    }
                                    var Hr = Lr;
                                  } else
                                    var Hr = W0;
                                  var Or = Hr;
                                  break;
                                }
                              else
                                var Or = b;
                              var xr = Or - b | 0;
                              0 <= xr ? El(t4, [0, eo0, xr + X | 0, ro0]) : Vv(t4, [0, to0, Or + G0 | 0, no0], t4[6]);
                            }
                            break;
                          case 3:
                            var Rr = c[2], Wr = c[1];
                            if (t4[8] < (t4[6] - t4[9] | 0)) {
                              var Jr = Hv(t4[2]);
                              if (Jr) {
                                var or = Jr[1], _r = or[2], Ir = or[1];
                                t4[9] < _r && !(3 < (Ir - 1 | 0) >>> 0) && Pz(t4, _r);
                              } else
                                Lp(t4);
                            }
                            var fe = t4[9] - Wr | 0, v0 = Rr === 1 ? 1 : t4[9] < G ? Rr : 5;
                            E1([0, v0, fe], t4[2]);
                            break;
                          case 4:
                            E1(c[1], t4[3]);
                            break;
                          default:
                            var P = c[1];
                            FN(t4, u(t4[24], P)), E1(P, t4[5]);
                        }
                      t4[12] = p + t4[12] | 0;
                      continue;
                    }
                    throw xee;
                  }
                  return T;
                }
                return 0;
              }
            }
            function Lz(t4, n) {
              return wl(t4, n), Dz(t4);
            }
            function Rz(t4, n, e) {
              return Lz(t4, [0, n, [0, e], n]);
            }
            function TN(t4) {
              return dl(t4), E1([0, -1, [0, Az, Qa0, 0]], t4);
            }
            function ON(t4, n) {
              var e = Hv(t4[1]);
              if (e) {
                var i = e[1], x = i[2], c = x[1];
                if (i[1] < t4[12])
                  return TN(t4[1]);
                var s = x[2];
                if (typeof s != "number")
                  switch (s[0]) {
                    case 3:
                      var p = 1 - n, y = p && (x[1] = t4[13] + c | 0, Uv(t4[1]), 0);
                      return y;
                    case 1:
                    case 2:
                      var T = n && (x[1] = t4[13] + c | 0, Uv(t4[1]), 0);
                      return T;
                  }
                return 0;
              }
              return 0;
            }
            function jz(t4, n, e) {
              return wl(t4, e), n && ON(t4, 1), E1([0, t4[13], e], t4[1]);
            }
            function Gz(t4, n, e) {
              if (t4[14] = t4[14] + 1 | 0, t4[14] < t4[15])
                return jz(t4, 0, [0, -t4[13] | 0, [3, n, e], 0]);
              var i = t4[14] === t4[15] ? 1 : 0;
              if (i) {
                var x = t4[16];
                return Rz(t4, tn(x), x);
              }
              return i;
            }
            function Mz(t4, n) {
              var e = 1 < t4[14] ? 1 : 0;
              if (e) {
                t4[14] < t4[15] && (wl(t4, [0, Dp, 1, 0]), ON(t4, 1), ON(t4, 0)), t4[14] = t4[14] - 1 | 0;
                var i = 0;
              } else
                var i = e;
              return i;
            }
            function Bz(t4, n) {
              t4[23] && wl(t4, [0, Dp, 5, 0]);
              var e = t4[22];
              if (e) {
                var i = Uv(t4[4]);
                if (i)
                  return u(t4[27], i[1]);
                var x = 0;
              } else
                var x = e;
              return x;
            }
            function IN(t4, n) {
              var e = t4[4];
              function i(x) {
                return Bz(t4, 0);
              }
              for (Cu(i, e[1]); ; ) {
                if (1 < t4[14]) {
                  Mz(t4, 0);
                  continue;
                }
                return t4[13] = Nz, Dz(t4), n && Lp(t4), t4[12] = 1, t4[13] = 1, sN(t4[28]), TN(t4[1]), dl(t4[2]), dl(t4[3]), dl(t4[4]), dl(t4[5]), t4[10] = 0, t4[14] = 0, t4[9] = t4[6], Gz(t4, 0, 3);
              }
            }
            function AN(t4, n, e) {
              var i = t4[14] < t4[15] ? 1 : 0;
              return i && Rz(t4, n, e);
            }
            function qz(t4, n, e) {
              return AN(t4, n, e);
            }
            function g(t4, n) {
              return qz(t4, tn(n), n);
            }
            function Sl(t4, n) {
              return qz(t4, 1, Op(1, n));
            }
            function gl(t4, n) {
              return IN(t4, 0), u(t4[18], 0);
            }
            var Uz = Op(80, 32);
            function Hz(t4, n) {
              for (var e = n; ; ) {
                var i = 0 < e ? 1 : 0;
                if (i) {
                  if (80 < e) {
                    ir(t4[17], Uz, 0, 80);
                    var e = e + fX | 0;
                    continue;
                  }
                  return ir(t4[17], Uz, 0, e);
                }
                return i;
              }
            }
            function kee(t4) {
              return t4[1] === gN ? Te(Va0, Te(t4[2], Ya0)) : za0;
            }
            function wee(t4) {
              return t4[1] === gN ? Te(Ha0, Te(t4[2], Ua0)) : Xa0;
            }
            function Eee(t4) {
              return 0;
            }
            function See(t4) {
              return 0;
            }
            function Xz(t4, n) {
              function e(w) {
                return 0;
              }
              function i(w) {
                return 0;
              }
              function x(w) {
                return 0;
              }
              var c = kz(0), s = [0, Az, Ba0, 0];
              vN(s, c);
              var p = yl(0);
              TN(p), E1([0, 1, s], p);
              var y = yl(0), T = yl(0), E = yl(0), h = [0, p, yl(0), E, T, y, 78, 10, 68, 78, 0, 1, 1, 1, 1, eee, qa0, t4, n, x, i, e, 0, 0, kee, wee, Eee, See, c];
              return h[19] = function(w) {
                return ir(h[17], Ka0, 0, 1);
              }, h[20] = function(w) {
                return Hz(h, w);
              }, h[21] = function(w) {
                return Hz(h, w);
              }, h;
            }
            function Yz(t4) {
              function n(e) {
                return m1(t4);
              }
              return Xz(function(e, i, x) {
                return 0 <= i && 0 <= x && !((tn(e) - x | 0) < i) ? JA(t4, e, i, x) : Nu(ki0);
              }, n);
            }
            function NN(t4) {
              function n(e) {
                return 0;
              }
              return Xz(function(e, i, x) {
                return wz(t4, e, i, x);
              }, n);
            }
            var gee = CI;
            function Vz(t4) {
              return Qn(gee);
            }
            var Fee = Vz(0), Tee = Yz(tee), Oee = Yz(Lc);
            NN(Fee);
            function zz(t4, n) {
              var e = Qn(16), i = NN(e);
              a(t4, i, n), gl(i, 0);
              var x = e[2];
              if (2 <= x) {
                var c = x - 2 | 0, s = 1;
                return 0 <= c && !((e[2] - c | 0) < 1) ? qv(e[1], s, c) : Nu(rf0);
              }
              return Bt(e);
            }
            function X7(t4, n) {
              var e = 0;
              if (typeof n == "number")
                return 0;
              switch (n[0]) {
                case 0:
                  var i = n[2];
                  if (X7(t4, n[1]), typeof i == "number")
                    switch (i) {
                      case 0:
                        return Mz(t4, 0);
                      case 1:
                        return Bz(t4, 0);
                      case 2:
                        return gl(t4, 0);
                      case 3:
                        var x = t4[14] < t4[15] ? 1 : 0;
                        return x && Lz(t4, [0, Dp, 3, 0]);
                      case 4:
                        return IN(t4, 1), u(t4[18], 0);
                      case 5:
                        return Sl(t4, 64);
                      default:
                        return Sl(t4, 37);
                    }
                  else
                    switch (i[0]) {
                      case 0:
                        var c = [0, Za0, i[2], $a0], s = t4[14] < t4[15] ? 1 : 0, p = [0, Ja0, i[3], Wa0], y = c[3], T = c[2], E = c[1];
                        return s && jz(t4, 1, [0, -t4[13] | 0, [1, c, p], (tn(E) + T | 0) + tn(y) | 0]);
                      case 1:
                        return 0;
                      default:
                        var h = i[1];
                        return Sl(t4, 64), Sl(t4, h);
                    }
                case 1:
                  var w = n[2], G = n[1];
                  if (w[0] === 0) {
                    var A = w[1];
                    X7(t4, G);
                    var S = [0, gN, zz(X7, A)];
                    t4[22] && (E1(S, t4[4]), u(t4[26], S));
                    var M = t4[23];
                    return M && wl(t4, [0, Dp, [5, S], 0]);
                  }
                  var K = w[1];
                  X7(t4, G);
                  var V = _ee(zz(X7, K));
                  return Gz(t4, V[1], V[2]);
                case 2:
                  var f0 = n[1], m0 = 0;
                  if (typeof f0 != "number" && f0[0] === 0) {
                    var k0 = f0[2], g0 = 0;
                    if (typeof k0 != "number" && k0[0] === 1) {
                      var e0 = n[2], x0 = k0[2], l = f0[1];
                      m0 = 1, g0 = 1;
                    }
                  }
                  if (!m0) {
                    var c0 = n[2], t0 = f0;
                    e = 2;
                  }
                  break;
                case 3:
                  var a0 = n[1], w0 = 0;
                  if (typeof a0 != "number" && a0[0] === 0) {
                    var _0 = a0[2], E0 = 0;
                    if (typeof _0 != "number" && _0[0] === 1) {
                      var X0 = n[2], b = _0[2], G0 = a0[1];
                      e = 1, w0 = 1, E0 = 1;
                    }
                  }
                  if (!w0) {
                    var X = n[2], s0 = a0;
                    e = 3;
                  }
                  break;
                case 4:
                  var dr = n[1], Ar = 0;
                  if (typeof dr != "number" && dr[0] === 0) {
                    var ar = dr[2], W0 = 0;
                    if (typeof ar != "number" && ar[0] === 1) {
                      var e0 = n[2], x0 = ar[2], l = dr[1];
                      Ar = 1, W0 = 1;
                    }
                  }
                  if (!Ar) {
                    var c0 = n[2], t0 = dr;
                    e = 2;
                  }
                  break;
                case 5:
                  var Lr = n[1], Tr = 0;
                  if (typeof Lr == "number" || Lr[0] !== 0)
                    Tr = 1;
                  else {
                    var Hr = Lr[2], Or = 0;
                    if (typeof Hr != "number" && Hr[0] === 1) {
                      var X0 = n[2], b = Hr[2], G0 = Lr[1];
                      e = 1, Or = 1;
                    }
                    Or || (Tr = 1);
                  }
                  if (Tr) {
                    var X = n[2], s0 = Lr;
                    e = 3;
                  }
                  break;
                case 6:
                  var xr = n[2];
                  return X7(t4, n[1]), u(xr, t4);
                case 7:
                  return X7(t4, n[1]), gl(t4, 0);
                default:
                  var Rr = n[2];
                  return X7(t4, n[1]), Nu(Rr);
              }
              switch (e) {
                case 0:
                  return X7(t4, l), AN(t4, x0, e0);
                case 1:
                  return X7(t4, G0), AN(t4, b, Op(1, X0));
                case 2:
                  return X7(t4, t0), g(t4, c0);
                default:
                  return X7(t4, s0), Sl(t4, X);
              }
            }
            function f(t4) {
              return function(n) {
                var e = n[1], i = 0;
                return Yn(function(x) {
                  return X7(t4, x), 0;
                }, i, e);
              };
            }
            function P0(t4) {
              var n = t4[1], e = Vz(0), i = NN(e);
              return Yn(function(x) {
                X7(i, x), IN(i, 0);
                var c = Bt(e);
                return e[2] = 0, e[1] = e[4], e[3] = b7(e[1]), c;
              }, 0, n);
            }
            sz(function(t4) {
              return gl(Tee, 0), gl(Oee, 0);
            });
            function Iee(t4, n) {
              var e = h1(n) === St ? n : n[1];
              return ZA(t4, e);
            }
            var Aee = 2;
            function Nee(t4) {
              var n = [0, 0], e = tn(t4) - 1 | 0, i = 0;
              if (!(e < 0))
                for (var x = i; ; ) {
                  var c = At(t4, x);
                  n[1] = (d8 * n[1] | 0) + c | 0;
                  var s = x + 1 | 0;
                  if (e !== x) {
                    var x = s;
                    continue;
                  }
                  break;
                }
              n[1] = n[1] & kH;
              var p = 1073741823 < n[1] ? n[1] + 2147483648 | 0 : n[1];
              return p;
            }
            var ps = cN([0, Ee]), S1 = cN([0, Ee]), Cs = cN([0, Cc]), Kz = $A(0, 0), Cee = [0, 0];
            function Wz(t4) {
              return 2 < t4 ? Wz((t4 + 1 | 0) / 2 | 0) * 2 | 0 : t4;
            }
            function Jz(t4) {
              Cee[1]++;
              var n = t4.length - 1, e = Gv((n * 2 | 0) + 2 | 0, Kz);
              nu(e, 0)[1] = n;
              var i = ((Wz(n) * 32 | 0) / 8 | 0) - 1 | 0;
              nu(e, 1)[2] = i;
              var x = n - 1 | 0, c = 0;
              if (!(x < 0))
                for (var s = c; ; ) {
                  var p = (s * 2 | 0) + 3 | 0, y = nu(t4, s)[1 + s];
                  nu(e, p)[1 + p] = y;
                  var T = s + 1 | 0;
                  if (x !== s) {
                    var s = T;
                    continue;
                  }
                  break;
                }
              return [0, Aee, e, S1[1], Cs[1], 0, 0, ps[1], 0];
            }
            function CN(t4, n) {
              var e = t4[2].length - 1, i = e < n ? 1 : 0;
              if (i) {
                var x = Gv(n, Kz), c = t4[2], s = 0;
                0 <= e && !((c.length - 1 - e | 0) < 0) && !((x.length - 1 - e | 0) < 0) && (v70(c, 0, x, 0, e), s = 1), s || Nu(Gi0), t4[2] = x;
                var p = 0;
              } else
                var p = i;
              return p;
            }
            var $z = [0, 0], Pee = [0, 0];
            function PN(t4) {
              var n = t4[2].length - 1;
              return CN(t4, n + 1 | 0), n;
            }
            function Fl(t4, n) {
              try {
                var e = a(S1[28], n, t4[3]);
                return e;
              } catch (x) {
                if (x = gt(x), x === Jt) {
                  var i = PN(t4);
                  return t4[3] = ir(S1[4], n, i, t4[3]), t4[4] = ir(Cs[4], i, 1, t4[4]), i;
                }
                throw x;
              }
            }
            function DN(t4, n) {
              return Ip(function(e) {
                return Fl(t4, e);
              }, n);
            }
            function Zz(t4, n, e) {
              return Pee[1]++, a(Cs[28], n, t4[4]) ? (CN(t4, n + 1 | 0), nu(t4[2], n)[1 + n] = e, 0) : (t4[6] = [0, [0, n, e], t4[6]], 0);
            }
            function Dee(t4, n) {
              try {
                var e = fee(n, t4[6]);
                return e;
              } catch (i) {
                if (i = gt(i), i === Jt)
                  return nu(t4[2], n)[1 + n];
                throw i;
              }
            }
            function LN(t4) {
              if (t4 === 0)
                return 0;
              for (var n = t4.length - 1 - 1 | 0, e = 0; ; ) {
                if (0 <= n) {
                  var i = [0, t4[1 + n], e], n = n - 1 | 0, e = i;
                  continue;
                }
                return e;
              }
            }
            function Lee(t4) {
              var n = t4[1];
              return t4[1] = n + 1 | 0, n;
            }
            function RN(t4, n) {
              try {
                var e = a(ps[28], n, t4[7]);
                return e;
              } catch (x) {
                if (x = gt(x), x === Jt) {
                  var i = Lee(t4);
                  return n0(n, ao0) && (t4[7] = ir(ps[4], n, i, t4[7])), i;
                }
                throw x;
              }
            }
            function jN(t4) {
              return qV(t4, 0) ? [0] : t4;
            }
            function Ree(t4, n) {
              try {
                var e = a(ps[28], n, t4[7]);
                return e;
              } catch (i) {
                throw i = gt(i), i === Jt ? [0, Fn, xo0] : i;
              }
            }
            function GN(t4, n, e, i, x, c) {
              var s = x[2], p = x[4], y = LN(n), T = LN(e), E = LN(i), h = k1(function(b) {
                return Fl(t4, b);
              }, T), w = k1(function(b) {
                return Fl(t4, b);
              }, E);
              t4[5] = [0, [0, t4[3], t4[4], t4[6], t4[7], h, y], t4[5]];
              var G = ps[1], A = t4[7];
              function S(b, G0, X) {
                return oN(b, y) ? ir(ps[4], b, G0, X) : X;
              }
              t4[7] = ir(ps[13], S, A, G);
              var M = [0, S1[1]], K = [0, Cs[1]];
              pz(function(b, G0) {
                M[1] = ir(S1[4], b, G0, M[1]);
                var X = K[1];
                try {
                  var s0 = a(Cs[28], G0, t4[4]), dr = s0;
                } catch (Ar) {
                  if (Ar = gt(Ar), Ar !== Jt)
                    throw Ar;
                  var dr = 1;
                }
                return K[1] = ir(Cs[4], G0, dr, X), 0;
              }, E, w), pz(function(b, G0) {
                return M[1] = ir(S1[4], b, G0, M[1]), K[1] = ir(Cs[4], G0, 0, K[1]), 0;
              }, T, h), t4[3] = M[1], t4[4] = K[1];
              var V = 0, f0 = t4[6];
              t4[6] = aN(function(b, G0) {
                return oN(b[1], h) ? G0 : [0, b, G0];
              }, f0, V);
              var m0 = c ? a(s, t4, p) : u(s, t4), k0 = bl(t4[5]), g0 = k0[6], e0 = k0[5], x0 = k0[4], l = k0[3], c0 = k0[2], t0 = k0[1];
              t4[5] = bz(t4[5]), t4[7] = be(function(b, G0) {
                var X = a(ps[28], G0, t4[7]);
                return ir(ps[4], G0, X, b);
              }, x0, g0), t4[3] = t0, t4[4] = c0;
              var a0 = t4[6];
              t4[6] = aN(function(b, G0) {
                return oN(b[1], e0) ? G0 : [0, b, G0];
              }, a0, l);
              var w0 = 0, _0 = jN(i), E0 = [0, Ip(function(b) {
                return Dee(t4, Fl(t4, b));
              }, _0), w0], X0 = jN(n);
              return l70([0, [0, m0], [0, Ip(function(b) {
                return Ree(t4, b);
              }, X0), E0]]);
            }
            function jp(t4, n) {
              if (t4 === 0)
                var e = Jz([0]);
              else {
                var i = Jz(Ip(Nee, t4)), x = t4.length - 1 - 1 | 0, c = 0;
                if (!(x < 0))
                  for (var s = c; ; ) {
                    var p = (s * 2 | 0) + 2 | 0;
                    i[3] = ir(S1[4], t4[1 + s], p, i[3]), i[4] = ir(Cs[4], p, 1, i[4]);
                    var y = s + 1 | 0;
                    if (x !== s) {
                      var s = y;
                      continue;
                    }
                    break;
                  }
                var e = i;
              }
              var T = u(n, e);
              return $z[1] = ($z[1] + e[1] | 0) - 1 | 0, e[8] = de(e[8]), CN(e, 3 + ((nu(e[2], 1)[2] * 16 | 0) / 32 | 0) | 0), [0, u(T, 0), n, T, 0];
            }
            function Gp(t4, n) {
              if (t4)
                return t4;
              var e = $A(St, n[1]);
              return e[1] = n[2], xi0(e);
            }
            function MN(t4, n, e) {
              if (t4)
                return n;
              var i = e[8];
              if (i !== 0)
                for (var x = i; ; ) {
                  if (x) {
                    var c = x[2];
                    u(x[1], n);
                    var x = c;
                    continue;
                  }
                  break;
                }
              return n;
            }
            function Mp(t4) {
              var n = PN(t4), e = 0;
              if (n % 2 | 0 && !((2 + ((nu(t4[2], 1)[2] * 16 | 0) / 32 | 0) | 0) < n)) {
                var i = PN(t4);
                e = 1;
              }
              if (!e)
                var i = n;
              return nu(t4[2], i)[1 + i] = 0, i;
            }
            function BN(t4, n) {
              for (var e = [0, 0], i = n.length - 1; ; ) {
                if (e[1] < i) {
                  var x = e[1], c = nu(n, x)[1 + x], s = function(p0) {
                    e[1]++;
                    var b0 = e[1];
                    return nu(n, b0)[1 + b0];
                  }, p = s(0);
                  if (typeof p == "number")
                    switch (p) {
                      case 0:
                        var y = s(0), Z = function(b0) {
                          return function(O0) {
                            return b0;
                          };
                        }(y);
                        break;
                      case 1:
                        var T = s(0), Z = function(b0) {
                          return function(O0) {
                            return O0[1 + b0];
                          };
                        }(T);
                        break;
                      case 2:
                        var E = s(0), h = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return q0[1 + b0][1 + O0];
                          };
                        }(E, h);
                        break;
                      case 3:
                        var w = s(0), Z = function(b0) {
                          return function(O0) {
                            return u(O0[1][1 + b0], O0);
                          };
                        }(w);
                        break;
                      case 4:
                        var G = s(0), Z = function(b0) {
                          return function(O0, q0) {
                            return O0[1 + b0] = q0, 0;
                          };
                        }(G);
                        break;
                      case 5:
                        var A = s(0), S = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return u(b0, O0);
                          };
                        }(A, S);
                        break;
                      case 6:
                        var M = s(0), K = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return u(b0, q0[1 + O0]);
                          };
                        }(M, K);
                        break;
                      case 7:
                        var V = s(0), f0 = s(0), m0 = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return u(b0, nr[1 + O0][1 + q0]);
                          };
                        }(V, f0, m0);
                        break;
                      case 8:
                        var k0 = s(0), g0 = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return u(b0, u(q0[1][1 + O0], q0));
                          };
                        }(k0, g0);
                        break;
                      case 9:
                        var e0 = s(0), x0 = s(0), l = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(b0, O0, q0);
                          };
                        }(e0, x0, l);
                        break;
                      case 10:
                        var c0 = s(0), t0 = s(0), a0 = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(b0, O0, nr[1 + q0]);
                          };
                        }(c0, t0, a0);
                        break;
                      case 11:
                        var w0 = s(0), _0 = s(0), E0 = s(0), X0 = s(0), Z = function(b0, O0, q0, nr) {
                          return function(yr) {
                            return a(b0, O0, yr[1 + q0][1 + nr]);
                          };
                        }(w0, _0, E0, X0);
                        break;
                      case 12:
                        var b = s(0), G0 = s(0), X = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(b0, O0, u(nr[1][1 + q0], nr));
                          };
                        }(b, G0, X);
                        break;
                      case 13:
                        var s0 = s(0), dr = s(0), Ar = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(b0, nr[1 + O0], q0);
                          };
                        }(s0, dr, Ar);
                        break;
                      case 14:
                        var ar = s(0), W0 = s(0), Lr = s(0), Tr = s(0), Z = function(b0, O0, q0, nr) {
                          return function(yr) {
                            return a(b0, yr[1 + O0][1 + q0], nr);
                          };
                        }(ar, W0, Lr, Tr);
                        break;
                      case 15:
                        var Hr = s(0), Or = s(0), xr = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(b0, u(nr[1][1 + O0], nr), q0);
                          };
                        }(Hr, Or, xr);
                        break;
                      case 16:
                        var Rr = s(0), Wr = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return a(q0[1][1 + b0], q0, O0);
                          };
                        }(Rr, Wr);
                        break;
                      case 17:
                        var Jr = s(0), or = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            return a(q0[1][1 + b0], q0, q0[1 + O0]);
                          };
                        }(Jr, or);
                        break;
                      case 18:
                        var _r = s(0), Ir = s(0), fe = s(0), Z = function(b0, O0, q0) {
                          return function(nr) {
                            return a(nr[1][1 + b0], nr, nr[1 + O0][1 + q0]);
                          };
                        }(_r, Ir, fe);
                        break;
                      case 19:
                        var v0 = s(0), P = s(0), Z = function(b0, O0) {
                          return function(q0) {
                            var nr = u(q0[1][1 + O0], q0);
                            return a(q0[1][1 + b0], q0, nr);
                          };
                        }(v0, P);
                        break;
                      case 20:
                        var L = s(0), Q = s(0);
                        Mp(t4);
                        var Z = function(b0, O0) {
                          return function(q0) {
                            return u(Qe(O0, b0, 0), O0);
                          };
                        }(L, Q);
                        break;
                      case 21:
                        var i0 = s(0), l0 = s(0);
                        Mp(t4);
                        var Z = function(b0, O0) {
                          return function(q0) {
                            var nr = q0[1 + O0];
                            return u(Qe(nr, b0, 0), nr);
                          };
                        }(i0, l0);
                        break;
                      case 22:
                        var S0 = s(0), T0 = s(0), er = s(0);
                        Mp(t4);
                        var Z = function(b0, O0, q0) {
                          return function(nr) {
                            var yr = nr[1 + O0][1 + q0];
                            return u(Qe(yr, b0, 0), yr);
                          };
                        }(S0, T0, er);
                        break;
                      default:
                        var j0 = s(0), B = s(0);
                        Mp(t4);
                        var Z = function(b0, O0) {
                          return function(q0) {
                            var nr = u(q0[1][1 + O0], q0);
                            return u(Qe(nr, b0, 0), nr);
                          };
                        }(j0, B);
                    }
                  else
                    var Z = p;
                  Zz(t4, c, Z), e[1]++;
                  continue;
                }
                return 0;
              }
            }
            function Qz(t4, n) {
              var e = n.length - 1, i = $A(0, e), x = e - 1 | 0, c = 0;
              if (!(x < 0))
                for (var s = c; ; ) {
                  var p = nu(n, s)[1 + s];
                  if (typeof p == "number")
                    switch (p) {
                      case 0:
                        var E = function(G) {
                          function A(S) {
                            var M = i[1 + G];
                            if (A === M)
                              throw [0, sl, t4];
                            return u(M, S);
                          }
                          return A;
                        }(s);
                        break;
                      case 1:
                        var y = [];
                        N(y, [$2, function(G, A) {
                          return function(S) {
                            var M = i[1 + A];
                            if (G === M)
                              throw [0, sl, t4];
                            var K = h1(M);
                            return nl === K ? M[1] : $2 === K ? cee(M) : M;
                          };
                        }(y, s)]);
                        var E = y;
                        break;
                      default:
                        var T = function(G) {
                          throw [0, sl, t4];
                        }, E = [0, T, T, T, 0];
                    }
                  else
                    var E = p[0] === 0 ? Qz(t4, p[1]) : p[1];
                  i[1 + s] = E;
                  var h = s + 1 | 0;
                  if (x !== s) {
                    var s = h;
                    continue;
                  }
                  break;
                }
              return i;
            }
            function lu(t4, n) {
              return typeof n != "number" && n[0] === 0 ? Qz(t4, n[1]) : ke(vo0);
            }
            function rK(t4, n, e) {
              if (h1(e) === 0 && t4.length - 1 <= e.length - 1) {
                var i = t4.length - 1 - 1 | 0, x = 0;
                if (!(i < 0))
                  for (var c = x; ; ) {
                    var s = e[1 + c], p = nu(t4, c)[1 + c];
                    if (typeof p == "number")
                      if (p === 2) {
                        var y = 0;
                        if (h1(s) === 0 && s.length - 1 === 4)
                          for (var T = 0, E = n[1 + c]; ; ) {
                            E[1 + T] = s[1 + T];
                            var h = T + 1 | 0;
                            if (T !== 3) {
                              var T = h;
                              continue;
                            }
                            break;
                          }
                        else
                          y = 1;
                        if (y)
                          throw [0, Fn, oo0];
                      } else
                        n[1 + c] = s;
                    else
                      p[0] === 0 && rK(p[1], n[1 + c], s);
                    var w = c + 1 | 0;
                    if (i !== c) {
                      var c = w;
                      continue;
                    }
                    break;
                  }
                return 0;
              }
              throw [0, Fn, co0];
            }
            function bu(t4, n, e) {
              return typeof t4 != "number" && t4[0] === 0 ? rK(t4[1], n, e) : ke(so0);
            }
            try {
              rz(lo0);
            } catch (t4) {
              if (t4 = gt(t4), t4 !== Jt)
                throw t4;
            }
            try {
              rz(bo0);
            } catch (t4) {
              if (t4 = gt(t4), t4 !== Jt)
                throw t4;
            }
            n0(lz, po0) && n0(lz, mo0);
            function g1(t4, n) {
              function e(i) {
                return Ui(t4, i);
              }
              return ow <= n ? (e(v1 | n >>> 18 | 0), e(Gt | (n >>> 12 | 0) & 63), e(Gt | (n >>> 6 | 0) & 63), e(Gt | n & 63)) : Vd <= n ? (e(dv | n >>> 12 | 0), e(Gt | (n >>> 6 | 0) & 63), e(Gt | n & 63)) : Gt <= n ? (e(In | n >>> 6 | 0), e(Gt | n & 63)) : e(n);
            }
            var qN = L0, u7 = null, eK = void 0;
            function Bp(t4) {
              return t4 !== eK ? 1 : 0;
            }
            var jee = qN.Array, UN = [St, yo0, M7(0)], Gee = qN.Error;
            Iee(do0, [0, UN, {}]);
            function nK(t4) {
              throw t4;
            }
            Iz(function(t4) {
              return t4[1] === UN ? [0, B7(t4[2].toString())] : 0;
            }), Iz(function(t4) {
              return t4 instanceof jee ? 0 : [0, B7(t4.toString())];
            });
            var Dr = lu(d3r, y3r), jn = lu(k3r, h3r), qp = lu(E3r, w3r), Tl = lu(g3r, S3r), F1 = lu(T3r, F3r), HN = lu(I3r, O3r), tK = lu(N3r, A3r), XN = lu(P3r, C3r), zv = lu(L3r, D3r), Up = lu(j3r, R3r), Je = lu(M3r, G3r), Xu = lu(q3r, B3r), Ue = lu(H3r, U3r), YN = lu(Y3r, X3r), hi = lu(z3r, V3r), uu = lu(W3r, K3r), T1 = lu($3r, J3r), Ps = lu(Q3r, Z3r), VN = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, uK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Mee = lu(e6r, r6r);
            N(VN, function(t4, n, e, i) {
              u(f(e), e3r), a(f(e), t3r, n3r);
              var x = i[1];
              u(f(e), u3r);
              var c = 0;
              be(function(y, T) {
                y && u(f(e), r3r);
                function E(h) {
                  return u(t4, h);
                }
                return ir(uu[1], E, e, T), 1;
              }, c, x), u(f(e), i3r), u(f(e), f3r), u(f(e), x3r), a(f(e), o3r, a3r);
              var s = i[2];
              u(f(e), c3r);
              var p = 0;
              return be(function(y, T) {
                y && u(f(e), Q8r);
                function E(h) {
                  return u(t4, h);
                }
                return ir(uu[1], E, e, T), 1;
              }, p, s), u(f(e), s3r), u(f(e), v3r), u(f(e), l3r), a(f(e), p3r, b3r), a(n, e, i[3]), u(f(e), m3r), u(f(e), _3r);
            }), N(uK, function(t4, n, e) {
              var i = a(VN, t4, n);
              return a(P0(Z8r), i, e);
            }), bu(n6r, Dr, [0, VN, uK]);
            var zN = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, iK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Hp = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, fK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(zN, function(t4, n, e, i) {
              u(f(e), W8r), a(n, e, i[1]), u(f(e), J8r);
              var x = i[2];
              return ir(Hp, function(c) {
                return u(t4, c);
              }, e, x), u(f(e), $8r);
            }), N(iK, function(t4, n, e) {
              var i = a(zN, t4, n);
              return a(P0(K8r), i, e);
            }), N(Hp, function(t4, n, e) {
              u(f(n), L8r), a(f(n), j8r, R8r);
              var i = e[1];
              a(f(n), G8r, i), u(f(n), M8r), u(f(n), B8r), a(f(n), U8r, q8r);
              var x = e[2];
              if (x) {
                g(n, H8r);
                var c = x[1], s = function(y, T) {
                  return g(y, D8r);
                }, p = function(y) {
                  return u(t4, y);
                };
                R(Dr[1], p, s, n, c), g(n, X8r);
              } else
                g(n, Y8r);
              return u(f(n), V8r), u(f(n), z8r);
            }), N(fK, function(t4, n) {
              var e = u(Hp, t4);
              return a(P0(P8r), e, n);
            }), bu(t6r, jn, [0, zN, iK, Hp, fK]);
            var KN = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, xK = function t4(n, e) {
              return t4.fun(n, e);
            }, Xp = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, aK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(KN, function(t4, n, e) {
              u(f(n), A8r), a(t4, n, e[1]), u(f(n), N8r);
              var i = e[2];
              return ir(Xp, function(x) {
                return u(t4, x);
              }, n, i), u(f(n), C8r);
            }), N(xK, function(t4, n) {
              var e = u(KN, t4);
              return a(P0(I8r), e, n);
            }), N(Xp, function(t4, n, e) {
              u(f(n), m8r), a(f(n), y8r, _8r);
              var i = e[1];
              a(f(n), d8r, i), u(f(n), h8r), u(f(n), k8r), a(f(n), E8r, w8r);
              var x = e[2];
              if (x) {
                g(n, S8r);
                var c = x[1], s = function(y, T) {
                  return g(y, p8r);
                }, p = function(y) {
                  return u(t4, y);
                };
                R(Dr[1], p, s, n, c), g(n, g8r);
              } else
                g(n, F8r);
              return u(f(n), T8r), u(f(n), O8r);
            }), N(aK, function(t4, n) {
              var e = u(Xp, t4);
              return a(P0(b8r), e, n);
            }), bu(u6r, qp, [0, KN, xK, Xp, aK]);
            function oK(t4, n) {
              u(f(t4), n8r), a(f(t4), u8r, t8r);
              var e = n[1];
              a(f(t4), i8r, e), u(f(t4), f8r), u(f(t4), x8r), a(f(t4), o8r, a8r);
              var i = n[2];
              return a(f(t4), c8r, i), u(f(t4), s8r), u(f(t4), v8r);
            }
            var cK = [0, oK, function(t4) {
              return a(P0(l8r), oK, t4);
            }], WN = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, sK = function t4(n, e) {
              return t4.fun(n, e);
            }, Yp = function t4(n, e) {
              return t4.fun(n, e);
            }, vK = function t4(n) {
              return t4.fun(n);
            };
            N(WN, function(t4, n, e) {
              u(f(n), M4r), a(f(n), q4r, B4r), a(Yp, n, e[1]), u(f(n), U4r), u(f(n), H4r), a(f(n), Y4r, X4r);
              var i = e[2];
              a(f(n), V4r, i), u(f(n), z4r), u(f(n), K4r), a(f(n), J4r, W4r);
              var x = e[3];
              if (x) {
                g(n, $4r);
                var c = x[1], s = function(y, T) {
                  return g(y, G4r);
                }, p = function(y) {
                  return u(t4, y);
                };
                R(Dr[1], p, s, n, c), g(n, Z4r);
              } else
                g(n, Q4r);
              return u(f(n), r8r), u(f(n), e8r);
            }), N(sK, function(t4, n) {
              var e = u(WN, t4);
              return a(P0(j4r), e, n);
            }), N(Yp, function(t4, n) {
              if (typeof n == "number")
                return g(t4, w4r);
              switch (n[0]) {
                case 0:
                  u(f(t4), E4r);
                  var e = n[1];
                  return a(f(t4), S4r, e), u(f(t4), g4r);
                case 1:
                  u(f(t4), F4r);
                  var i = n[1];
                  return a(f(t4), T4r, i), u(f(t4), O4r);
                case 2:
                  u(f(t4), I4r);
                  var x = n[1];
                  return a(f(t4), A4r, x), u(f(t4), N4r);
                case 3:
                  u(f(t4), C4r);
                  var c = n[1];
                  return a(f(t4), P4r, c), u(f(t4), D4r);
                default:
                  return u(f(t4), L4r), a(cK[1], t4, n[1]), u(f(t4), R4r);
              }
            }), N(vK, function(t4) {
              return a(P0(k4r), Yp, t4);
            }), bu(i6r, Tl, [0, cK, WN, sK, Yp, vK]);
            var JN = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, lK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(JN, function(t4, n, e) {
              u(f(n), t4r), a(f(n), i4r, u4r);
              var i = e[1];
              a(f(n), f4r, i), u(f(n), x4r), u(f(n), a4r), a(f(n), c4r, o4r);
              var x = e[2];
              a(f(n), s4r, x), u(f(n), v4r), u(f(n), l4r), a(f(n), p4r, b4r);
              var c = e[3];
              if (c) {
                g(n, m4r);
                var s = c[1], p = function(T, E) {
                  return g(T, n4r);
                }, y = function(T) {
                  return u(t4, T);
                };
                R(Dr[1], y, p, n, s), g(n, _4r);
              } else
                g(n, y4r);
              return u(f(n), d4r), u(f(n), h4r);
            }), N(lK, function(t4, n) {
              var e = u(JN, t4);
              return a(P0(e4r), e, n);
            }), bu(f6r, F1, [0, JN, lK]);
            var $N = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, bK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N($N, function(t4, n, e) {
              u(f(n), jbr), a(f(n), Mbr, Gbr);
              var i = e[1];
              a(f(n), Bbr, i), u(f(n), qbr), u(f(n), Ubr), a(f(n), Xbr, Hbr);
              var x = e[2];
              a(f(n), Ybr, x), u(f(n), Vbr), u(f(n), zbr), a(f(n), Wbr, Kbr);
              var c = e[3];
              if (c) {
                g(n, Jbr);
                var s = c[1], p = function(T, E) {
                  return g(T, Rbr);
                }, y = function(T) {
                  return u(t4, T);
                };
                R(Dr[1], y, p, n, s), g(n, $br);
              } else
                g(n, Zbr);
              return u(f(n), Qbr), u(f(n), r4r);
            }), N(bK, function(t4, n) {
              var e = u($N, t4);
              return a(P0(Lbr), e, n);
            }), bu(x6r, HN, [0, $N, bK]);
            var ZN = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, pK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(ZN, function(t4, n, e) {
              u(f(n), _br), a(f(n), dbr, ybr);
              var i = e[1];
              a(f(n), hbr, i), u(f(n), kbr), u(f(n), wbr), a(f(n), Sbr, Ebr);
              var x = e[2];
              a(f(n), gbr, x), u(f(n), Fbr), u(f(n), Tbr), a(f(n), Ibr, Obr);
              var c = e[3];
              if (c) {
                g(n, Abr);
                var s = c[1], p = function(T, E) {
                  return g(T, mbr);
                }, y = function(T) {
                  return u(t4, T);
                };
                R(Dr[1], y, p, n, s), g(n, Nbr);
              } else
                g(n, Cbr);
              return u(f(n), Pbr), u(f(n), Dbr);
            }), N(pK, function(t4, n) {
              var e = u(ZN, t4);
              return a(P0(pbr), e, n);
            }), bu(a6r, tK, [0, ZN, pK]);
            var QN = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, mK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(QN, function(t4, n, e) {
              u(f(n), nbr), a(f(n), ubr, tbr);
              var i = e[1];
              a(f(n), ibr, i), u(f(n), fbr), u(f(n), xbr), a(f(n), obr, abr);
              var x = e[2];
              if (x) {
                g(n, cbr);
                var c = x[1], s = function(y, T) {
                  return g(y, ebr);
                }, p = function(y) {
                  return u(t4, y);
                };
                R(Dr[1], p, s, n, c), g(n, sbr);
              } else
                g(n, vbr);
              return u(f(n), lbr), u(f(n), bbr);
            }), N(mK, function(t4, n) {
              var e = u(QN, t4);
              return a(P0(rbr), e, n);
            }), bu(o6r, XN, [0, QN, mK]);
            var rC = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, _K = function t4(n, e) {
              return t4.fun(n, e);
            }, Vp = function t4(n, e) {
              return t4.fun(n, e);
            }, yK = function t4(n) {
              return t4.fun(n);
            }, zp = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, dK = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(rC, function(t4, n, e) {
              u(f(n), $lr), a(t4, n, e[1]), u(f(n), Zlr);
              var i = e[2];
              return ir(zp, function(x) {
                return u(t4, x);
              }, n, i), u(f(n), Qlr);
            }), N(_K, function(t4, n) {
              var e = u(rC, t4);
              return a(P0(Jlr), e, n);
            }), N(Vp, function(t4, n) {
              return n ? g(t4, Klr) : g(t4, Wlr);
            }), N(yK, function(t4) {
              return a(P0(zlr), Vp, t4);
            }), N(zp, function(t4, n, e) {
              u(f(n), Llr), a(f(n), jlr, Rlr), a(Vp, n, e[1]), u(f(n), Glr), u(f(n), Mlr), a(f(n), qlr, Blr);
              var i = e[2];
              if (i) {
                g(n, Ulr);
                var x = i[1], c = function(p, y) {
                  return g(p, Dlr);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, Hlr);
              } else
                g(n, Xlr);
              return u(f(n), Ylr), u(f(n), Vlr);
            }), N(dK, function(t4, n) {
              var e = u(zp, t4);
              return a(P0(Plr), e, n);
            }), bu(c6r, zv, [0, rC, _K, Vp, yK, zp, dK]);
            var eC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, hK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, nC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, kK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(eC, function(t4, n, e, i) {
              u(f(e), Alr), a(t4, e, i[1]), u(f(e), Nlr);
              var x = i[2];
              function c(p) {
                return u(n, p);
              }
              function s(p) {
                return u(t4, p);
              }
              return R(Up[3], s, c, e, x), u(f(e), Clr);
            }), N(hK, function(t4, n, e) {
              var i = a(eC, t4, n);
              return a(P0(Ilr), i, e);
            }), N(nC, function(t4, n, e, i) {
              u(f(e), _lr), a(f(e), dlr, ylr);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), hlr), u(f(e), klr), a(f(e), Elr, wlr);
              var p = i[2];
              if (p) {
                g(e, Slr);
                var y = p[1], T = function(h, w) {
                  return g(h, mlr);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, glr);
              } else
                g(e, Flr);
              return u(f(e), Tlr), u(f(e), Olr);
            }), N(kK, function(t4, n, e) {
              var i = a(nC, t4, n);
              return a(P0(plr), i, e);
            }), bu(s6r, Up, [0, eC, hK, nC, kK]);
            var tC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, wK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Kp = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, EK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(tC, function(t4, n, e, i) {
              u(f(e), vlr), a(t4, e, i[1]), u(f(e), llr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Kp, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), blr);
            }), N(wK, function(t4, n, e) {
              var i = a(tC, t4, n);
              return a(P0(slr), i, e);
            }), N(Kp, function(t4, n, e, i) {
              u(f(e), K2r), a(f(e), J2r, W2r);
              var x = i[1];
              if (x) {
                g(e, $2r);
                var c = x[1], s = function(w) {
                  return u(n, w);
                }, p = function(w) {
                  return u(t4, w);
                };
                R(jn[1], p, s, e, c), g(e, Z2r);
              } else
                g(e, Q2r);
              u(f(e), rlr), u(f(e), elr), a(f(e), tlr, nlr);
              var y = i[2];
              function T(w) {
                return u(n, w);
              }
              function E(w) {
                return u(t4, w);
              }
              R(Je[13], E, T, e, y), u(f(e), ulr), u(f(e), ilr), a(f(e), xlr, flr);
              var h = i[3];
              return a(f(e), alr, h), u(f(e), olr), u(f(e), clr);
            }), N(EK, function(t4, n, e) {
              var i = a(Kp, t4, n);
              return a(P0(z2r), i, e);
            });
            var uC = [0, tC, wK, Kp, EK], iC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, SK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Wp = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, gK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(iC, function(t4, n, e, i) {
              u(f(e), X2r), a(t4, e, i[1]), u(f(e), Y2r);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Wp, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), V2r);
            }), N(SK, function(t4, n, e) {
              var i = a(iC, t4, n);
              return a(P0(H2r), i, e);
            }), N(Wp, function(t4, n, e, i) {
              u(f(e), N2r), a(f(e), P2r, C2r);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(uC[1], s, c, e, x), u(f(e), D2r), u(f(e), L2r), a(f(e), j2r, R2r);
              var p = i[2];
              if (p) {
                g(e, G2r);
                var y = p[1], T = function(h, w) {
                  return g(h, A2r);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, M2r);
              } else
                g(e, B2r);
              return u(f(e), q2r), u(f(e), U2r);
            }), N(gK, function(t4, n, e) {
              var i = a(Wp, t4, n);
              return a(P0(I2r), i, e);
            });
            var FK = [0, iC, SK, Wp, gK], fC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, TK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Jp = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, OK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(fC, function(t4, n, e, i) {
              u(f(e), F2r), a(t4, e, i[1]), u(f(e), T2r);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Jp, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), O2r);
            }), N(TK, function(t4, n, e) {
              var i = a(fC, t4, n);
              return a(P0(g2r), i, e);
            }), N(Jp, function(t4, n, e, i) {
              u(f(e), l2r), a(f(e), p2r, b2r);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[17], s, c, e, x), u(f(e), m2r), u(f(e), _2r), a(f(e), d2r, y2r);
              var p = i[2];
              if (p) {
                g(e, h2r);
                var y = p[1], T = function(h, w) {
                  return g(h, v2r);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, k2r);
              } else
                g(e, w2r);
              return u(f(e), E2r), u(f(e), S2r);
            }), N(OK, function(t4, n, e) {
              var i = a(Jp, t4, n);
              return a(P0(s2r), i, e);
            });
            var IK = [0, fC, TK, Jp, OK], xC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, AK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, $p = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, NK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(xC, function(t4, n, e, i) {
              u(f(e), a2r), a(t4, e, i[1]), u(f(e), o2r);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R($p, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), c2r);
            }), N(AK, function(t4, n, e) {
              var i = a(xC, t4, n);
              return a(P0(x2r), i, e);
            }), N($p, function(t4, n, e, i) {
              u(f(e), Pvr), a(f(e), Lvr, Dvr);
              var x = i[1];
              if (x) {
                g(e, Rvr);
                var c = x[1], s = function(V) {
                  return u(n, V);
                }, p = function(V) {
                  return u(t4, V);
                };
                R(IK[1], p, s, e, c), g(e, jvr);
              } else
                g(e, Gvr);
              u(f(e), Mvr), u(f(e), Bvr), a(f(e), Uvr, qvr);
              var y = i[2];
              u(f(e), Hvr);
              var T = 0;
              be(function(V, f0) {
                V && u(f(e), Cvr);
                function m0(g0) {
                  return u(n, g0);
                }
                function k0(g0) {
                  return u(t4, g0);
                }
                return R(uC[1], k0, m0, e, f0), 1;
              }, T, y), u(f(e), Xvr), u(f(e), Yvr), u(f(e), Vvr), a(f(e), Kvr, zvr);
              var E = i[3];
              if (E) {
                g(e, Wvr);
                var h = E[1], w = function(V) {
                  return u(n, V);
                }, G = function(V) {
                  return u(t4, V);
                };
                R(FK[1], G, w, e, h), g(e, Jvr);
              } else
                g(e, $vr);
              u(f(e), Zvr), u(f(e), Qvr), a(f(e), e2r, r2r);
              var A = i[4];
              if (A) {
                g(e, n2r);
                var S = A[1], M = function(V, f0) {
                  u(f(V), Avr);
                  var m0 = 0;
                  return be(function(k0, g0) {
                    k0 && u(f(V), Ivr);
                    function e0(x0) {
                      return u(t4, x0);
                    }
                    return ir(uu[1], e0, V, g0), 1;
                  }, m0, f0), u(f(V), Nvr);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, t2r);
              } else
                g(e, u2r);
              return u(f(e), i2r), u(f(e), f2r);
            }), N(NK, function(t4, n, e) {
              var i = a($p, t4, n);
              return a(P0(Ovr), i, e);
            });
            var CK = [0, xC, AK, $p, NK], aC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, PK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(aC, function(t4, n, e, i) {
              u(f(e), ivr), a(f(e), xvr, fvr);
              var x = i[1];
              if (x) {
                g(e, avr);
                var c = x[1], s = function(V) {
                  return u(n, V);
                }, p = function(V) {
                  return u(t4, V);
                };
                R(Je[22][1], p, s, e, c), g(e, ovr);
              } else
                g(e, cvr);
              u(f(e), svr), u(f(e), vvr), a(f(e), bvr, lvr);
              var y = i[2];
              function T(V) {
                return u(n, V);
              }
              function E(V) {
                return u(t4, V);
              }
              R(CK[1], E, T, e, y), u(f(e), pvr), u(f(e), mvr), a(f(e), yvr, _vr);
              var h = i[3];
              function w(V) {
                return u(n, V);
              }
              function G(V) {
                return u(t4, V);
              }
              R(Je[13], G, w, e, h), u(f(e), dvr), u(f(e), hvr), a(f(e), wvr, kvr);
              var A = i[4];
              if (A) {
                g(e, Evr);
                var S = A[1], M = function(V, f0) {
                  return g(V, uvr);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, Svr);
              } else
                g(e, gvr);
              return u(f(e), Fvr), u(f(e), Tvr);
            }), N(PK, function(t4, n, e) {
              var i = a(aC, t4, n);
              return a(P0(tvr), i, e);
            });
            var Ol = [0, uC, FK, IK, CK, aC, PK], Zp = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, DK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Qp = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, LK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, r5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, RK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Zp, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), Q1r);
                var x = i[1], c = function(T) {
                  return u(n, T);
                }, s = function(T) {
                  return u(t4, T);
                };
                return R(jn[1], s, c, e, x), u(f(e), rvr);
              }
              u(f(e), evr);
              var p = i[1];
              function y(T) {
                return u(n, T);
              }
              return R(Qp, function(T) {
                return u(t4, T);
              }, y, e, p), u(f(e), nvr);
            }), N(DK, function(t4, n, e) {
              var i = a(Zp, t4, n);
              return a(P0(Z1r), i, e);
            }), N(Qp, function(t4, n, e, i) {
              u(f(e), W1r), a(t4, e, i[1]), u(f(e), J1r);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(r5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), $1r);
            }), N(LK, function(t4, n, e) {
              var i = a(Qp, t4, n);
              return a(P0(K1r), i, e);
            }), N(r5, function(t4, n, e, i) {
              u(f(e), M1r), a(f(e), q1r, B1r);
              var x = i[1];
              function c(T) {
                return u(n, T);
              }
              R(Zp, function(T) {
                return u(t4, T);
              }, c, e, x), u(f(e), U1r), u(f(e), H1r), a(f(e), Y1r, X1r);
              var s = i[2];
              function p(T) {
                return u(n, T);
              }
              function y(T) {
                return u(t4, T);
              }
              return R(jn[1], y, p, e, s), u(f(e), V1r), u(f(e), z1r);
            }), N(RK, function(t4, n, e) {
              var i = a(r5, t4, n);
              return a(P0(G1r), i, e);
            });
            var jK = [0, Zp, DK, Qp, LK, r5, RK], oC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, GK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(oC, function(t4, n, e, i) {
              u(f(e), d1r), a(f(e), k1r, h1r);
              var x = i[1];
              function c(S) {
                return u(n, S);
              }
              function s(S) {
                return u(t4, S);
              }
              R(jK[1], s, c, e, x), u(f(e), w1r), u(f(e), E1r), a(f(e), g1r, S1r);
              var p = i[2];
              if (p) {
                g(e, F1r);
                var y = p[1], T = function(S) {
                  return u(n, S);
                }, E = function(S) {
                  return u(t4, S);
                };
                R(Je[23][1], E, T, e, y), g(e, T1r);
              } else
                g(e, O1r);
              u(f(e), I1r), u(f(e), A1r), a(f(e), C1r, N1r);
              var h = i[3];
              if (h) {
                g(e, P1r);
                var w = h[1], G = function(S, M) {
                  return g(S, y1r);
                }, A = function(S) {
                  return u(t4, S);
                };
                R(Dr[1], A, G, e, w), g(e, D1r);
              } else
                g(e, L1r);
              return u(f(e), R1r), u(f(e), j1r);
            }), N(GK, function(t4, n, e) {
              var i = a(oC, t4, n);
              return a(P0(_1r), i, e);
            });
            var cC = [0, jK, oC, GK], sC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, MK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(sC, function(t4, n, e, i) {
              u(f(e), e1r), a(f(e), t1r, n1r);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Je[13], s, c, e, x), u(f(e), u1r), u(f(e), i1r), a(f(e), x1r, f1r);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Je[13], T, y, e, p), u(f(e), a1r), u(f(e), o1r), a(f(e), s1r, c1r);
              var E = i[3];
              if (E) {
                g(e, v1r);
                var h = E[1], w = function(A, S) {
                  return g(A, r1r);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, l1r);
              } else
                g(e, b1r);
              return u(f(e), p1r), u(f(e), m1r);
            }), N(MK, function(t4, n, e) {
              var i = a(sC, t4, n);
              return a(P0(Qsr), i, e);
            });
            var vC = [0, sC, MK], lC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, BK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(lC, function(t4, n, e, i) {
              u(f(e), Hsr), a(f(e), Ysr, Xsr);
              var x = i[1];
              function c(y) {
                return u(n, y);
              }
              function s(y) {
                return u(t4, y);
              }
              R(vC[1], s, c, e, x), u(f(e), Vsr), u(f(e), zsr), a(f(e), Wsr, Ksr);
              var p = i[2];
              return a(f(e), Jsr, p), u(f(e), $sr), u(f(e), Zsr);
            }), N(BK, function(t4, n, e) {
              var i = a(lC, t4, n);
              return a(P0(Usr), i, e);
            });
            var qK = [0, lC, BK], bC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, UK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, e5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, HK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, n5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, XK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(bC, function(t4, n, e, i) {
              u(f(e), Msr), a(t4, e, i[1]), u(f(e), Bsr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(e5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), qsr);
            }), N(UK, function(t4, n, e) {
              var i = a(bC, t4, n);
              return a(P0(Gsr), i, e);
            }), N(e5, function(t4, n, e, i) {
              u(f(e), Wcr), a(f(e), $cr, Jcr);
              var x = i[1];
              function c(m0) {
                return u(n, m0);
              }
              function s(m0) {
                return u(t4, m0);
              }
              R(Ue[7][1][1], s, c, e, x), u(f(e), Zcr), u(f(e), Qcr), a(f(e), esr, rsr);
              var p = i[2];
              function y(m0) {
                return u(n, m0);
              }
              R(n5, function(m0) {
                return u(t4, m0);
              }, y, e, p), u(f(e), nsr), u(f(e), tsr), a(f(e), isr, usr);
              var T = i[3];
              a(f(e), fsr, T), u(f(e), xsr), u(f(e), asr), a(f(e), csr, osr);
              var E = i[4];
              a(f(e), ssr, E), u(f(e), vsr), u(f(e), lsr), a(f(e), psr, bsr);
              var h = i[5];
              a(f(e), msr, h), u(f(e), _sr), u(f(e), ysr), a(f(e), hsr, dsr);
              var w = i[6];
              a(f(e), ksr, w), u(f(e), wsr), u(f(e), Esr), a(f(e), gsr, Ssr);
              var G = i[7];
              if (G) {
                g(e, Fsr);
                var A = G[1], S = function(m0) {
                  return u(t4, m0);
                };
                ir(zv[1], S, e, A), g(e, Tsr);
              } else
                g(e, Osr);
              u(f(e), Isr), u(f(e), Asr), a(f(e), Csr, Nsr);
              var M = i[8];
              if (M) {
                g(e, Psr);
                var K = M[1], V = function(m0, k0) {
                  return g(m0, Kcr);
                }, f0 = function(m0) {
                  return u(t4, m0);
                };
                R(Dr[1], f0, V, e, K), g(e, Dsr);
              } else
                g(e, Lsr);
              return u(f(e), Rsr), u(f(e), jsr);
            }), N(HK, function(t4, n, e) {
              var i = a(e5, t4, n);
              return a(P0(zcr), i, e);
            }), N(n5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), Lcr);
                  var x = i[1], c = function(S) {
                    return u(n, S);
                  }, s = function(S) {
                    return u(t4, S);
                  };
                  return R(Je[13], s, c, e, x), u(f(e), Rcr);
                case 1:
                  var p = i[1];
                  u(f(e), jcr), u(f(e), Gcr), a(t4, e, p[1]), u(f(e), Mcr);
                  var y = p[2], T = function(S) {
                    return u(n, S);
                  }, E = function(S) {
                    return u(t4, S);
                  };
                  return R(Ol[5], E, T, e, y), u(f(e), Bcr), u(f(e), qcr);
                default:
                  var h = i[1];
                  u(f(e), Ucr), u(f(e), Hcr), a(t4, e, h[1]), u(f(e), Xcr);
                  var w = h[2], G = function(S) {
                    return u(n, S);
                  }, A = function(S) {
                    return u(t4, S);
                  };
                  return R(Ol[5], A, G, e, w), u(f(e), Ycr), u(f(e), Vcr);
              }
            }), N(XK, function(t4, n, e) {
              var i = a(n5, t4, n);
              return a(P0(Dcr), i, e);
            });
            var YK = [0, bC, UK, e5, HK, n5, XK], pC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, VK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, t5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, zK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(pC, function(t4, n, e, i) {
              u(f(e), Ncr), a(t4, e, i[1]), u(f(e), Ccr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(t5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Pcr);
            }), N(VK, function(t4, n, e) {
              var i = a(pC, t4, n);
              return a(P0(Acr), i, e);
            }), N(t5, function(t4, n, e, i) {
              u(f(e), ycr), a(f(e), hcr, dcr);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[13], s, c, e, x), u(f(e), kcr), u(f(e), wcr), a(f(e), Scr, Ecr);
              var p = i[2];
              if (p) {
                g(e, gcr);
                var y = p[1], T = function(h, w) {
                  return g(h, _cr);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Fcr);
              } else
                g(e, Tcr);
              return u(f(e), Ocr), u(f(e), Icr);
            }), N(zK, function(t4, n, e) {
              var i = a(t5, t4, n);
              return a(P0(mcr), i, e);
            });
            var KK = [0, pC, VK, t5, zK], u5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, WK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, mC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, JK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(u5, function(t4, n, e, i) {
              u(f(e), Lor), a(f(e), jor, Ror);
              var x = i[1];
              if (x) {
                g(e, Gor);
                var c = x[1], s = function(g0) {
                  return u(t4, g0);
                }, p = function(g0) {
                  return u(t4, g0);
                };
                R(jn[1], p, s, e, c), g(e, Mor);
              } else
                g(e, Bor);
              u(f(e), qor), u(f(e), Uor), a(f(e), Xor, Hor);
              var y = i[2];
              function T(g0) {
                return u(n, g0);
              }
              function E(g0) {
                return u(t4, g0);
              }
              R(Je[13], E, T, e, y), u(f(e), Yor), u(f(e), Vor), a(f(e), Kor, zor);
              var h = i[3];
              function w(g0) {
                return u(n, g0);
              }
              function G(g0) {
                return u(t4, g0);
              }
              R(Je[13], G, w, e, h), u(f(e), Wor), u(f(e), Jor), a(f(e), Zor, $or);
              var A = i[4];
              a(f(e), Qor, A), u(f(e), rcr), u(f(e), ecr), a(f(e), tcr, ncr);
              var S = i[5];
              if (S) {
                g(e, ucr);
                var M = S[1], K = function(g0) {
                  return u(t4, g0);
                };
                ir(zv[1], K, e, M), g(e, icr);
              } else
                g(e, fcr);
              u(f(e), xcr), u(f(e), acr), a(f(e), ccr, ocr);
              var V = i[6];
              if (V) {
                g(e, scr);
                var f0 = V[1], m0 = function(g0, e0) {
                  return g(g0, Dor);
                }, k0 = function(g0) {
                  return u(t4, g0);
                };
                R(Dr[1], k0, m0, e, f0), g(e, vcr);
              } else
                g(e, lcr);
              return u(f(e), bcr), u(f(e), pcr);
            }), N(WK, function(t4, n, e) {
              var i = a(u5, t4, n);
              return a(P0(Por), i, e);
            }), N(mC, function(t4, n, e, i) {
              u(f(e), Aor), a(t4, e, i[1]), u(f(e), Nor);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(u5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Cor);
            }), N(JK, function(t4, n, e) {
              var i = a(mC, t4, n);
              return a(P0(Ior), i, e);
            });
            var $K = [0, u5, WK, mC, JK], _C = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, ZK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, i5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, QK = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(_C, function(t4, n, e, i) {
              u(f(e), For), a(t4, e, i[1]), u(f(e), Tor);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(i5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Oor);
            }), N(ZK, function(t4, n, e) {
              var i = a(_C, t4, n);
              return a(P0(gor), i, e);
            }), N(i5, function(t4, n, e, i) {
              u(f(e), uor), a(f(e), xor, ior);
              var x = i[1];
              u(f(e), aor), a(t4, e, x[1]), u(f(e), oor);
              var c = x[2];
              function s(G) {
                return u(n, G);
              }
              function p(G) {
                return u(t4, G);
              }
              R(Ol[5], p, s, e, c), u(f(e), cor), u(f(e), sor), u(f(e), vor), a(f(e), bor, lor);
              var y = i[2];
              a(f(e), por, y), u(f(e), mor), u(f(e), _or), a(f(e), dor, yor);
              var T = i[3];
              if (T) {
                g(e, hor);
                var E = T[1], h = function(G, A) {
                  return g(G, tor);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, kor);
              } else
                g(e, wor);
              return u(f(e), Eor), u(f(e), Sor);
            }), N(QK, function(t4, n, e) {
              var i = a(i5, t4, n);
              return a(P0(nor), i, e);
            });
            var rW = [0, _C, ZK, i5, QK], yC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, eW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, f5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, nW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(yC, function(t4, n, e, i) {
              u(f(e), Qar), a(t4, e, i[1]), u(f(e), ror);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(f5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), eor);
            }), N(eW, function(t4, n, e) {
              var i = a(yC, t4, n);
              return a(P0(Zar), i, e);
            }), N(f5, function(t4, n, e, i) {
              u(f(e), kar), a(f(e), Ear, war);
              var x = i[1];
              function c(K) {
                return u(t4, K);
              }
              function s(K) {
                return u(t4, K);
              }
              R(jn[1], s, c, e, x), u(f(e), Sar), u(f(e), gar), a(f(e), Tar, Far);
              var p = i[2];
              function y(K) {
                return u(n, K);
              }
              function T(K) {
                return u(t4, K);
              }
              R(Je[13], T, y, e, p), u(f(e), Oar), u(f(e), Iar), a(f(e), Nar, Aar);
              var E = i[3];
              a(f(e), Car, E), u(f(e), Par), u(f(e), Dar), a(f(e), Rar, Lar);
              var h = i[4];
              a(f(e), jar, h), u(f(e), Gar), u(f(e), Mar), a(f(e), qar, Bar);
              var w = i[5];
              a(f(e), Uar, w), u(f(e), Har), u(f(e), Xar), a(f(e), Var, Yar);
              var G = i[6];
              if (G) {
                g(e, zar);
                var A = G[1], S = function(K, V) {
                  return g(K, har);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, Kar);
              } else
                g(e, War);
              return u(f(e), Jar), u(f(e), $ar);
            }), N(nW, function(t4, n, e) {
              var i = a(f5, t4, n);
              return a(P0(dar), i, e);
            });
            var tW = [0, yC, eW, f5, nW], dC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, uW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, x5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, iW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(dC, function(t4, n, e, i) {
              u(f(e), Kxr), a(f(e), Jxr, Wxr);
              var x = i[1];
              a(f(e), $xr, x), u(f(e), Zxr), u(f(e), Qxr), a(f(e), ear, rar);
              var c = i[2];
              a(f(e), nar, c), u(f(e), tar), u(f(e), uar), a(f(e), far, iar);
              var s = i[3];
              u(f(e), xar);
              var p = 0;
              be(function(w, G) {
                w && u(f(e), zxr);
                function A(S) {
                  return u(n, S);
                }
                return R(x5, function(S) {
                  return u(t4, S);
                }, A, e, G), 1;
              }, p, s), u(f(e), aar), u(f(e), oar), u(f(e), car), a(f(e), lar, sar);
              var y = i[4];
              if (y) {
                g(e, bar);
                var T = y[1], E = function(w, G) {
                  u(f(w), Yxr);
                  var A = 0;
                  return be(function(S, M) {
                    S && u(f(w), Xxr);
                    function K(V) {
                      return u(t4, V);
                    }
                    return ir(uu[1], K, w, M), 1;
                  }, A, G), u(f(w), Vxr);
                }, h = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], h, E, e, T), g(e, par);
              } else
                g(e, mar);
              return u(f(e), _ar), u(f(e), yar);
            }), N(uW, function(t4, n, e) {
              var i = a(dC, t4, n);
              return a(P0(Hxr), i, e);
            }), N(x5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), Pxr);
                  var x = i[1], c = function(f0) {
                    return u(n, f0);
                  }, s = function(f0) {
                    return u(t4, f0);
                  };
                  return R(YK[1], s, c, e, x), u(f(e), Dxr);
                case 1:
                  u(f(e), Lxr);
                  var p = i[1], y = function(f0) {
                    return u(n, f0);
                  }, T = function(f0) {
                    return u(t4, f0);
                  };
                  return R(KK[1], T, y, e, p), u(f(e), Rxr);
                case 2:
                  u(f(e), jxr);
                  var E = i[1], h = function(f0) {
                    return u(n, f0);
                  }, w = function(f0) {
                    return u(t4, f0);
                  };
                  return R($K[3], w, h, e, E), u(f(e), Gxr);
                case 3:
                  u(f(e), Mxr);
                  var G = i[1], A = function(f0) {
                    return u(n, f0);
                  }, S = function(f0) {
                    return u(t4, f0);
                  };
                  return R(rW[1], S, A, e, G), u(f(e), Bxr);
                default:
                  u(f(e), qxr);
                  var M = i[1], K = function(f0) {
                    return u(n, f0);
                  }, V = function(f0) {
                    return u(t4, f0);
                  };
                  return R(tW[1], V, K, e, M), u(f(e), Uxr);
              }
            }), N(iW, function(t4, n, e) {
              var i = a(x5, t4, n);
              return a(P0(Cxr), i, e);
            });
            var hC = [0, YK, KK, $K, rW, tW, dC, uW, x5, iW], kC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, fW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(kC, function(t4, n, e, i) {
              u(f(e), sxr), a(f(e), lxr, vxr);
              var x = i[1];
              u(f(e), bxr), a(t4, e, x[1]), u(f(e), pxr);
              var c = x[2];
              function s(A) {
                return u(n, A);
              }
              function p(A) {
                return u(t4, A);
              }
              R(hC[6], p, s, e, c), u(f(e), mxr), u(f(e), _xr), u(f(e), yxr), a(f(e), hxr, dxr);
              var y = i[2];
              u(f(e), kxr);
              var T = 0;
              be(function(A, S) {
                A && u(f(e), xxr), u(f(e), axr), a(t4, e, S[1]), u(f(e), oxr);
                var M = S[2];
                function K(f0) {
                  return u(n, f0);
                }
                function V(f0) {
                  return u(t4, f0);
                }
                return R(cC[2], V, K, e, M), u(f(e), cxr), 1;
              }, T, y), u(f(e), wxr), u(f(e), Exr), u(f(e), Sxr), a(f(e), Fxr, gxr);
              var E = i[3];
              if (E) {
                g(e, Txr);
                var h = E[1], w = function(A, S) {
                  return g(A, fxr);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, Oxr);
              } else
                g(e, Ixr);
              return u(f(e), Axr), u(f(e), Nxr);
            }), N(fW, function(t4, n, e) {
              var i = a(kC, t4, n);
              return a(P0(ixr), i, e);
            });
            var xW = [0, kC, fW], wC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, aW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(wC, function(t4, n, e, i) {
              u(f(e), zfr), a(f(e), Wfr, Kfr);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[13], s, c, e, x), u(f(e), Jfr), u(f(e), $fr), a(f(e), Qfr, Zfr);
              var p = i[2];
              if (p) {
                g(e, rxr);
                var y = p[1], T = function(h, w) {
                  return g(h, Vfr);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, exr);
              } else
                g(e, nxr);
              return u(f(e), txr), u(f(e), uxr);
            }), N(aW, function(t4, n, e) {
              var i = a(wC, t4, n);
              return a(P0(Yfr), i, e);
            });
            var oW = [0, wC, aW], a5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, cW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, o5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, sW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, c5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, vW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(a5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), qfr);
                var x = i[1], c = function(T) {
                  return u(n, T);
                }, s = function(T) {
                  return u(t4, T);
                };
                return R(jn[1], s, c, e, x), u(f(e), Ufr);
              }
              u(f(e), Hfr);
              var p = i[1];
              function y(T) {
                return u(n, T);
              }
              return R(c5, function(T) {
                return u(t4, T);
              }, y, e, p), u(f(e), Xfr);
            }), N(cW, function(t4, n, e) {
              var i = a(a5, t4, n);
              return a(P0(Bfr), i, e);
            }), N(o5, function(t4, n, e, i) {
              u(f(e), Nfr), a(f(e), Pfr, Cfr);
              var x = i[1];
              function c(T) {
                return u(n, T);
              }
              R(a5, function(T) {
                return u(t4, T);
              }, c, e, x), u(f(e), Dfr), u(f(e), Lfr), a(f(e), jfr, Rfr);
              var s = i[2];
              function p(T) {
                return u(n, T);
              }
              function y(T) {
                return u(t4, T);
              }
              return R(jn[1], y, p, e, s), u(f(e), Gfr), u(f(e), Mfr);
            }), N(sW, function(t4, n, e) {
              var i = a(o5, t4, n);
              return a(P0(Afr), i, e);
            }), N(c5, function(t4, n, e, i) {
              u(f(e), Tfr), a(n, e, i[1]), u(f(e), Ofr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(o5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Ifr);
            }), N(vW, function(t4, n, e) {
              var i = a(c5, t4, n);
              return a(P0(Ffr), i, e);
            });
            var lW = [0, a5, cW, o5, sW, c5, vW], EC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, bW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(EC, function(t4, n, e, i) {
              u(f(e), bfr), a(f(e), mfr, pfr);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(lW[1], s, c, e, x), u(f(e), _fr), u(f(e), yfr), a(f(e), hfr, dfr);
              var p = i[2];
              if (p) {
                g(e, kfr);
                var y = p[1], T = function(h, w) {
                  return g(h, lfr);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, wfr);
              } else
                g(e, Efr);
              return u(f(e), Sfr), u(f(e), gfr);
            }), N(bW, function(t4, n, e) {
              var i = a(EC, t4, n);
              return a(P0(vfr), i, e);
            });
            var pW = [0, lW, EC, bW], SC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, mW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(SC, function(t4, n, e, i) {
              u(f(e), Zir), a(f(e), rfr, Qir);
              var x = i[1];
              u(f(e), efr);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), $ir);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(Je[13], G, w, e, h), 1;
              }, c, x), u(f(e), nfr), u(f(e), tfr), u(f(e), ufr), a(f(e), ffr, ifr);
              var s = i[2];
              if (s) {
                g(e, xfr);
                var p = s[1], y = function(E, h) {
                  return g(E, Jir);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, afr);
              } else
                g(e, ofr);
              return u(f(e), cfr), u(f(e), sfr);
            }), N(mW, function(t4, n, e) {
              var i = a(SC, t4, n);
              return a(P0(Wir), i, e);
            });
            var _W = [0, SC, mW], gC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, yW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(gC, function(t4, n, e, i) {
              u(f(e), jir), a(f(e), Mir, Gir);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[13], s, c, e, x), u(f(e), Bir), u(f(e), qir), a(f(e), Hir, Uir);
              var p = i[2];
              if (p) {
                g(e, Xir);
                var y = p[1], T = function(h, w) {
                  return g(h, Rir);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Yir);
              } else
                g(e, Vir);
              return u(f(e), zir), u(f(e), Kir);
            }), N(yW, function(t4, n, e) {
              var i = a(gC, t4, n);
              return a(P0(Lir), i, e);
            });
            var dW = [0, gC, yW], FC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, hW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(FC, function(t4, n, e, i) {
              u(f(e), _ir), a(f(e), dir, yir);
              var x = i[1];
              u(f(e), hir);
              var c = x[1];
              function s(K) {
                return u(n, K);
              }
              function p(K) {
                return u(t4, K);
              }
              R(Je[13], p, s, e, c), u(f(e), kir);
              var y = x[2];
              function T(K) {
                return u(n, K);
              }
              function E(K) {
                return u(t4, K);
              }
              R(Je[13], E, T, e, y), u(f(e), wir), u(f(e), Eir);
              var h = x[3], w = 0;
              be(function(K, V) {
                K && u(f(e), mir);
                function f0(k0) {
                  return u(n, k0);
                }
                function m0(k0) {
                  return u(t4, k0);
                }
                return R(Je[13], m0, f0, e, V), 1;
              }, w, h), u(f(e), Sir), u(f(e), gir), u(f(e), Fir), u(f(e), Tir), a(f(e), Iir, Oir);
              var G = i[2];
              if (G) {
                g(e, Air);
                var A = G[1], S = function(K, V) {
                  return g(K, pir);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, Nir);
              } else
                g(e, Cir);
              return u(f(e), Pir), u(f(e), Dir);
            }), N(hW, function(t4, n, e) {
              var i = a(FC, t4, n);
              return a(P0(bir), i, e);
            });
            var kW = [0, FC, hW], TC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, wW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(TC, function(t4, n, e, i) {
              u(f(e), J7r), a(f(e), Z7r, $7r);
              var x = i[1];
              u(f(e), Q7r);
              var c = x[1];
              function s(K) {
                return u(n, K);
              }
              function p(K) {
                return u(t4, K);
              }
              R(Je[13], p, s, e, c), u(f(e), rir);
              var y = x[2];
              function T(K) {
                return u(n, K);
              }
              function E(K) {
                return u(t4, K);
              }
              R(Je[13], E, T, e, y), u(f(e), eir), u(f(e), nir);
              var h = x[3], w = 0;
              be(function(K, V) {
                K && u(f(e), W7r);
                function f0(k0) {
                  return u(n, k0);
                }
                function m0(k0) {
                  return u(t4, k0);
                }
                return R(Je[13], m0, f0, e, V), 1;
              }, w, h), u(f(e), tir), u(f(e), uir), u(f(e), iir), u(f(e), fir), a(f(e), air, xir);
              var G = i[2];
              if (G) {
                g(e, oir);
                var A = G[1], S = function(K, V) {
                  return g(K, K7r);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, cir);
              } else
                g(e, sir);
              return u(f(e), vir), u(f(e), lir);
            }), N(wW, function(t4, n, e) {
              var i = a(TC, t4, n);
              return a(P0(z7r), i, e);
            });
            var EW = [0, TC, wW], s5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, SW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, v5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, gW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, OC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, FW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, IC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, TW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(s5, function(t4, n, e, i) {
              u(f(e), X7r), a(n, e, i[1]), u(f(e), Y7r);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(v5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), V7r);
            }), N(SW, function(t4, n, e) {
              var i = a(s5, t4, n);
              return a(P0(H7r), i, e);
            }), N(v5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  var x = i[1];
                  if (u(f(e), cur), x) {
                    g(e, sur);
                    var c = x[1], s = function(U, Y) {
                      return g(U, our);
                    }, p = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], p, s, e, c), g(e, vur);
                  } else
                    g(e, lur);
                  return u(f(e), bur);
                case 1:
                  var y = i[1];
                  if (u(f(e), pur), y) {
                    g(e, mur);
                    var T = y[1], E = function(U, Y) {
                      return g(U, aur);
                    }, h = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], h, E, e, T), g(e, _ur);
                  } else
                    g(e, yur);
                  return u(f(e), dur);
                case 2:
                  var w = i[1];
                  if (u(f(e), hur), w) {
                    g(e, kur);
                    var G = w[1], A = function(U, Y) {
                      return g(U, xur);
                    }, S = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], S, A, e, G), g(e, wur);
                  } else
                    g(e, Eur);
                  return u(f(e), Sur);
                case 3:
                  var M = i[1];
                  if (u(f(e), gur), M) {
                    g(e, Fur);
                    var K = M[1], V = function(U, Y) {
                      return g(U, fur);
                    }, f0 = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], f0, V, e, K), g(e, Tur);
                  } else
                    g(e, Our);
                  return u(f(e), Iur);
                case 4:
                  var m0 = i[1];
                  if (u(f(e), Aur), m0) {
                    g(e, Nur);
                    var k0 = m0[1], g0 = function(U, Y) {
                      return g(U, iur);
                    }, e0 = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], e0, g0, e, k0), g(e, Cur);
                  } else
                    g(e, Pur);
                  return u(f(e), Dur);
                case 5:
                  var x0 = i[1];
                  if (u(f(e), Lur), x0) {
                    g(e, Rur);
                    var l = x0[1], c0 = function(U, Y) {
                      return g(U, uur);
                    }, t0 = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], t0, c0, e, l), g(e, jur);
                  } else
                    g(e, Gur);
                  return u(f(e), Mur);
                case 6:
                  var a0 = i[1];
                  if (u(f(e), Bur), a0) {
                    g(e, qur);
                    var w0 = a0[1], _0 = function(U, Y) {
                      return g(U, tur);
                    }, E0 = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], E0, _0, e, w0), g(e, Uur);
                  } else
                    g(e, Hur);
                  return u(f(e), Xur);
                case 7:
                  var X0 = i[1];
                  if (u(f(e), Yur), X0) {
                    g(e, Vur);
                    var b = X0[1], G0 = function(U, Y) {
                      return g(U, nur);
                    }, X = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], X, G0, e, b), g(e, zur);
                  } else
                    g(e, Kur);
                  return u(f(e), Wur);
                case 8:
                  var s0 = i[1];
                  if (u(f(e), Jur), s0) {
                    g(e, $ur);
                    var dr = s0[1], Ar = function(U, Y) {
                      return g(U, eur);
                    }, ar = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], ar, Ar, e, dr), g(e, Zur);
                  } else
                    g(e, Qur);
                  return u(f(e), r7r);
                case 9:
                  var W0 = i[1];
                  if (u(f(e), e7r), W0) {
                    g(e, n7r);
                    var Lr = W0[1], Tr = function(U, Y) {
                      return g(U, rur);
                    }, Hr = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], Hr, Tr, e, Lr), g(e, t7r);
                  } else
                    g(e, u7r);
                  return u(f(e), i7r);
                case 10:
                  var Or = i[1];
                  if (u(f(e), f7r), Or) {
                    g(e, x7r);
                    var xr = Or[1], Rr = function(U, Y) {
                      return g(U, Qtr);
                    }, Wr = function(U) {
                      return u(t4, U);
                    };
                    R(Dr[1], Wr, Rr, e, xr), g(e, a7r);
                  } else
                    g(e, o7r);
                  return u(f(e), c7r);
                case 11:
                  u(f(e), s7r);
                  var Jr = i[1], or = function(U) {
                    return u(n, U);
                  }, _r = function(U) {
                    return u(t4, U);
                  };
                  return R(oW[1], _r, or, e, Jr), u(f(e), v7r);
                case 12:
                  u(f(e), l7r);
                  var Ir = i[1], fe = function(U) {
                    return u(n, U);
                  }, v0 = function(U) {
                    return u(t4, U);
                  };
                  return R(Ol[5], v0, fe, e, Ir), u(f(e), b7r);
                case 13:
                  u(f(e), p7r);
                  var P = i[1], L = function(U) {
                    return u(n, U);
                  }, Q = function(U) {
                    return u(t4, U);
                  };
                  return R(hC[6], Q, L, e, P), u(f(e), m7r);
                case 14:
                  u(f(e), _7r);
                  var i0 = i[1], l0 = function(U) {
                    return u(n, U);
                  }, S0 = function(U) {
                    return u(t4, U);
                  };
                  return R(xW[1], S0, l0, e, i0), u(f(e), y7r);
                case 15:
                  u(f(e), d7r);
                  var T0 = i[1], er = function(U) {
                    return u(n, U);
                  }, j0 = function(U) {
                    return u(t4, U);
                  };
                  return R(dW[1], j0, er, e, T0), u(f(e), h7r);
                case 16:
                  u(f(e), k7r);
                  var B = i[1], Z = function(U) {
                    return u(n, U);
                  }, p0 = function(U) {
                    return u(t4, U);
                  };
                  return R(cC[2], p0, Z, e, B), u(f(e), w7r);
                case 17:
                  u(f(e), E7r);
                  var b0 = i[1], O0 = function(U) {
                    return u(n, U);
                  }, q0 = function(U) {
                    return u(t4, U);
                  };
                  return R(vC[1], q0, O0, e, b0), u(f(e), S7r);
                case 18:
                  u(f(e), g7r);
                  var nr = i[1], yr = function(U) {
                    return u(n, U);
                  }, vr = function(U) {
                    return u(t4, U);
                  };
                  return R(qK[1], vr, yr, e, nr), u(f(e), F7r);
                case 19:
                  u(f(e), T7r);
                  var $0 = i[1], Sr = function(U) {
                    return u(n, U);
                  }, Mr = function(U) {
                    return u(t4, U);
                  };
                  return R(kW[1], Mr, Sr, e, $0), u(f(e), O7r);
                case 20:
                  u(f(e), I7r);
                  var Br = i[1], qr = function(U) {
                    return u(n, U);
                  }, jr = function(U) {
                    return u(t4, U);
                  };
                  return R(EW[1], jr, qr, e, Br), u(f(e), A7r);
                case 21:
                  u(f(e), N7r);
                  var $r = i[1], ne = function(U) {
                    return u(n, U);
                  }, Qr = function(U) {
                    return u(t4, U);
                  };
                  return R(pW[2], Qr, ne, e, $r), u(f(e), C7r);
                case 22:
                  u(f(e), P7r);
                  var pe = i[1], oe = function(U) {
                    return u(n, U);
                  }, me = function(U) {
                    return u(t4, U);
                  };
                  return R(_W[1], me, oe, e, pe), u(f(e), D7r);
                case 23:
                  u(f(e), L7r);
                  var ae = i[1], ce = function(U) {
                    return u(t4, U);
                  };
                  return ir(F1[1], ce, e, ae), u(f(e), R7r);
                case 24:
                  u(f(e), j7r);
                  var ge = i[1], H0 = function(U) {
                    return u(t4, U);
                  };
                  return ir(HN[1], H0, e, ge), u(f(e), G7r);
                case 25:
                  u(f(e), M7r);
                  var Fr = i[1], _ = function(U) {
                    return u(t4, U);
                  };
                  return ir(tK[1], _, e, Fr), u(f(e), B7r);
                default:
                  u(f(e), q7r);
                  var k = i[1], I = function(U) {
                    return u(t4, U);
                  };
                  return ir(XN[1], I, e, k), u(f(e), U7r);
              }
            }), N(gW, function(t4, n, e) {
              var i = a(v5, t4, n);
              return a(P0(Ztr), i, e);
            }), N(OC, function(t4, n, e, i) {
              u(f(e), Wtr), a(t4, e, i[1]), u(f(e), Jtr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(s5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), $tr);
            }), N(FW, function(t4, n, e) {
              var i = a(OC, t4, n);
              return a(P0(Ktr), i, e);
            }), N(IC, function(t4, n, e, i) {
              if (i[0] === 0)
                return u(f(e), Xtr), a(n, e, i[1]), u(f(e), Ytr);
              u(f(e), Vtr);
              var x = i[1];
              function c(p) {
                return u(n, p);
              }
              function s(p) {
                return u(t4, p);
              }
              return R(Je[17], s, c, e, x), u(f(e), ztr);
            }), N(TW, function(t4, n, e) {
              var i = a(IC, t4, n);
              return a(P0(Htr), i, e);
            });
            var AC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, OW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, l5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, IW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(AC, function(t4, n, e, i) {
              u(f(e), Btr), a(t4, e, i[1]), u(f(e), qtr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(l5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Utr);
            }), N(OW, function(t4, n, e) {
              var i = a(AC, t4, n);
              return a(P0(Mtr), i, e);
            }), N(l5, function(t4, n, e, i) {
              u(f(e), mtr), a(f(e), ytr, _tr);
              var x = i[1];
              function c(K) {
                return u(t4, K);
              }
              function s(K) {
                return u(t4, K);
              }
              R(jn[1], s, c, e, x), u(f(e), dtr), u(f(e), htr), a(f(e), wtr, ktr);
              var p = i[2];
              function y(K) {
                return u(n, K);
              }
              function T(K) {
                return u(t4, K);
              }
              R(Je[19], T, y, e, p), u(f(e), Etr), u(f(e), Str), a(f(e), Ftr, gtr);
              var E = i[3];
              if (E) {
                g(e, Ttr);
                var h = E[1], w = function(K) {
                  return u(t4, K);
                };
                ir(zv[1], w, e, h), g(e, Otr);
              } else
                g(e, Itr);
              u(f(e), Atr), u(f(e), Ntr), a(f(e), Ptr, Ctr);
              var G = i[4];
              if (G) {
                g(e, Dtr);
                var A = G[1], S = function(K) {
                  return u(n, K);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Je[13], M, S, e, A), g(e, Ltr);
              } else
                g(e, Rtr);
              return u(f(e), jtr), u(f(e), Gtr);
            }), N(IW, function(t4, n, e) {
              var i = a(l5, t4, n);
              return a(P0(ptr), i, e);
            });
            var AW = [0, AC, OW, l5, IW], NC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, NW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, b5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, CW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(NC, function(t4, n, e, i) {
              u(f(e), vtr), a(t4, e, i[1]), u(f(e), ltr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(b5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), btr);
            }), N(NW, function(t4, n, e) {
              var i = a(NC, t4, n);
              return a(P0(str), i, e);
            }), N(b5, function(t4, n, e, i) {
              u(f(e), $nr), a(f(e), Qnr, Znr);
              var x = i[1];
              u(f(e), rtr);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), Jnr);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(AW[1], G, w, e, h), 1;
              }, c, x), u(f(e), etr), u(f(e), ntr), u(f(e), ttr), a(f(e), itr, utr);
              var s = i[2];
              if (s) {
                g(e, ftr);
                var p = s[1], y = function(E, h) {
                  u(f(E), Knr);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), znr);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), Wnr);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, xtr);
              } else
                g(e, atr);
              return u(f(e), otr), u(f(e), ctr);
            }), N(CW, function(t4, n, e) {
              var i = a(b5, t4, n);
              return a(P0(Vnr), i, e);
            });
            var CC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, PW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, p5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, DW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Bee = [0, NC, NW, b5, CW];
            N(CC, function(t4, n, e, i) {
              u(f(e), Hnr), a(t4, e, i[1]), u(f(e), Xnr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(p5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Ynr);
            }), N(PW, function(t4, n, e) {
              var i = a(CC, t4, n);
              return a(P0(Unr), i, e);
            }), N(p5, function(t4, n, e, i) {
              u(f(e), Onr), a(f(e), Anr, Inr);
              var x = i[1];
              u(f(e), Nnr);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), Tnr);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(Je[13], G, w, e, h), 1;
              }, c, x), u(f(e), Cnr), u(f(e), Pnr), u(f(e), Dnr), a(f(e), Rnr, Lnr);
              var s = i[2];
              if (s) {
                g(e, jnr);
                var p = s[1], y = function(E, h) {
                  u(f(E), gnr);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), Snr);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), Fnr);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, Gnr);
              } else
                g(e, Mnr);
              return u(f(e), Bnr), u(f(e), qnr);
            }), N(DW, function(t4, n, e) {
              var i = a(p5, t4, n);
              return a(P0(Enr), i, e);
            });
            var PC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, LW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, m5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, RW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, _5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, jW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, qee = [0, CC, PW, p5, DW];
            N(PC, function(t4, n, e, i) {
              u(f(e), hnr), a(t4, e, i[1]), u(f(e), knr);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(m5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), wnr);
            }), N(LW, function(t4, n, e) {
              var i = a(PC, t4, n);
              return a(P0(dnr), i, e);
            }), N(m5, function(t4, n, e, i) {
              u(f(e), xnr), a(f(e), onr, anr);
              var x = i[1];
              function c(E) {
                return u(n, E);
              }
              R(_5, function(E) {
                return u(t4, E);
              }, c, e, x), u(f(e), cnr), u(f(e), snr), a(f(e), lnr, vnr);
              var s = i[2];
              if (s) {
                g(e, bnr);
                var p = s[1], y = function(E, h) {
                  return g(E, fnr);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, pnr);
              } else
                g(e, mnr);
              return u(f(e), _nr), u(f(e), ynr);
            }), N(RW, function(t4, n, e) {
              var i = a(m5, t4, n);
              return a(P0(inr), i, e);
            }), N(_5, function(t4, n, e, i) {
              if (i) {
                u(f(e), nnr);
                var x = i[1], c = function(p) {
                  return u(n, p);
                }, s = function(p) {
                  return u(t4, p);
                };
                return R(Ue[31], s, c, e, x), u(f(e), tnr);
              }
              return g(e, unr);
            }), N(jW, function(t4, n, e) {
              var i = a(_5, t4, n);
              return a(P0(enr), i, e);
            }), bu(v6r, Je, [0, Ol, cC, vC, qK, hC, xW, oW, pW, _W, dW, kW, EW, s5, SW, v5, gW, OC, FW, IC, TW, AW, Bee, qee, [0, PC, LW, m5, RW, _5, jW]]);
            var DC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, GW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(DC, function(t4, n, e, i) {
              u(f(e), qer), a(f(e), Her, Uer);
              var x = i[1];
              u(f(e), Xer);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), Ber);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(Xu[35], G, w, e, h), 1;
              }, c, x), u(f(e), Yer), u(f(e), Ver), u(f(e), zer), a(f(e), Wer, Ker);
              var s = i[2];
              if (s) {
                g(e, Jer);
                var p = s[1], y = function(E, h) {
                  u(f(E), Ger);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), jer);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), Mer);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, $er);
              } else
                g(e, Zer);
              return u(f(e), Qer), u(f(e), rnr);
            }), N(GW, function(t4, n, e) {
              var i = a(DC, t4, n);
              return a(P0(Rer), i, e);
            });
            var Kv = [0, DC, GW], LC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, MW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, y5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, BW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(LC, function(t4, n, e, i) {
              u(f(e), Per), a(t4, e, i[1]), u(f(e), Der);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(y5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Ler);
            }), N(MW, function(t4, n, e) {
              var i = a(LC, t4, n);
              return a(P0(Cer), i, e);
            }), N(y5, function(t4, n, e, i) {
              u(f(e), her), a(f(e), wer, ker);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Xu[35], s, c, e, x), u(f(e), Eer), u(f(e), Ser), a(f(e), Fer, ger);
              var p = i[2];
              if (p) {
                g(e, Ter);
                var y = p[1], T = function(h, w) {
                  return g(h, der);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Oer);
              } else
                g(e, Ier);
              return u(f(e), Aer), u(f(e), Ner);
            }), N(BW, function(t4, n, e) {
              var i = a(y5, t4, n);
              return a(P0(yer), i, e);
            });
            var qW = [0, LC, MW, y5, BW], RC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, UW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(RC, function(t4, n, e, i) {
              u(f(e), Wrr), a(f(e), $rr, Jrr);
              var x = i[1];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(Ue[31], s, c, e, x), u(f(e), Zrr), u(f(e), Qrr), a(f(e), eer, rer);
              var p = i[2];
              function y(V) {
                return u(n, V);
              }
              function T(V) {
                return u(t4, V);
              }
              R(Xu[35], T, y, e, p), u(f(e), ner), u(f(e), ter), a(f(e), ier, uer);
              var E = i[3];
              if (E) {
                g(e, fer);
                var h = E[1], w = function(V) {
                  return u(n, V);
                }, G = function(V) {
                  return u(t4, V);
                };
                R(qW[1], G, w, e, h), g(e, xer);
              } else
                g(e, aer);
              u(f(e), oer), u(f(e), cer), a(f(e), ver, ser);
              var A = i[4];
              if (A) {
                g(e, ler);
                var S = A[1], M = function(V, f0) {
                  return g(V, Krr);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, ber);
              } else
                g(e, per);
              return u(f(e), mer), u(f(e), _er);
            }), N(UW, function(t4, n, e) {
              var i = a(RC, t4, n);
              return a(P0(zrr), i, e);
            });
            var HW = [0, qW, RC, UW], jC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, XW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(jC, function(t4, n, e, i) {
              u(f(e), Nrr), a(f(e), Prr, Crr);
              var x = i[1];
              function c(A) {
                return u(t4, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(jn[1], s, c, e, x), u(f(e), Drr), u(f(e), Lrr), a(f(e), jrr, Rrr);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Xu[35], T, y, e, p), u(f(e), Grr), u(f(e), Mrr), a(f(e), qrr, Brr);
              var E = i[3];
              if (E) {
                g(e, Urr);
                var h = E[1], w = function(A, S) {
                  return g(A, Arr);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, Hrr);
              } else
                g(e, Xrr);
              return u(f(e), Yrr), u(f(e), Vrr);
            }), N(XW, function(t4, n, e) {
              var i = a(jC, t4, n);
              return a(P0(Irr), i, e);
            });
            var YW = [0, jC, XW], GC = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, VW = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(GC, function(t4, n, e) {
              u(f(n), brr), a(f(n), mrr, prr);
              var i = e[1];
              if (i) {
                g(n, _rr);
                var x = i[1], c = function(h) {
                  return u(t4, h);
                }, s = function(h) {
                  return u(t4, h);
                };
                R(jn[1], s, c, n, x), g(n, yrr);
              } else
                g(n, drr);
              u(f(n), hrr), u(f(n), krr), a(f(n), Err, wrr);
              var p = e[2];
              if (p) {
                g(n, Srr);
                var y = p[1], T = function(h, w) {
                  return g(h, lrr);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, n, y), g(n, grr);
              } else
                g(n, Frr);
              return u(f(n), Trr), u(f(n), Orr);
            }), N(VW, function(t4, n) {
              var e = u(GC, t4);
              return a(P0(vrr), e, n);
            });
            var zW = [0, GC, VW], MC = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, KW = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(MC, function(t4, n, e) {
              u(f(n), $0r), a(f(n), Q0r, Z0r);
              var i = e[1];
              if (i) {
                g(n, rrr);
                var x = i[1], c = function(h) {
                  return u(t4, h);
                }, s = function(h) {
                  return u(t4, h);
                };
                R(jn[1], s, c, n, x), g(n, err);
              } else
                g(n, nrr);
              u(f(n), trr), u(f(n), urr), a(f(n), frr, irr);
              var p = e[2];
              if (p) {
                g(n, xrr);
                var y = p[1], T = function(h, w) {
                  return g(h, J0r);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, n, y), g(n, arr);
              } else
                g(n, orr);
              return u(f(n), crr), u(f(n), srr);
            }), N(KW, function(t4, n) {
              var e = u(MC, t4);
              return a(P0(W0r), e, n);
            });
            var WW = [0, MC, KW], BC = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, JW = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(BC, function(t4, n, e) {
              u(f(n), q0r), a(f(n), H0r, U0r);
              var i = e[1];
              if (i) {
                g(n, X0r);
                var x = i[1], c = function(p, y) {
                  return g(p, B0r);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, Y0r);
              } else
                g(n, V0r);
              return u(f(n), z0r), u(f(n), K0r);
            }), N(JW, function(t4, n) {
              var e = u(BC, t4);
              return a(P0(M0r), e, n);
            });
            var $W = [0, BC, JW], qC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, ZW = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(qC, function(t4, n, e, i) {
              u(f(e), E0r), a(f(e), g0r, S0r);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Ue[31], s, c, e, x), u(f(e), F0r), u(f(e), T0r), a(f(e), I0r, O0r);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Xu[35], T, y, e, p), u(f(e), A0r), u(f(e), N0r), a(f(e), P0r, C0r);
              var E = i[3];
              if (E) {
                g(e, D0r);
                var h = E[1], w = function(A, S) {
                  return g(A, w0r);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, L0r);
              } else
                g(e, R0r);
              return u(f(e), j0r), u(f(e), G0r);
            }), N(ZW, function(t4, n, e) {
              var i = a(qC, t4, n);
              return a(P0(k0r), i, e);
            });
            var QW = [0, qC, ZW], UC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, rJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(UC, function(t4, n, e, i) {
              u(f(e), ZQ0), a(f(e), r0r, QQ0);
              var x = i[1];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(jn[1], s, c, e, x), u(f(e), e0r), u(f(e), n0r), a(f(e), u0r, t0r);
              var p = i[2];
              if (p) {
                g(e, i0r);
                var y = p[1], T = function(V) {
                  return u(n, V);
                }, E = function(V) {
                  return u(t4, V);
                };
                R(Je[22][1], E, T, e, y), g(e, f0r);
              } else
                g(e, x0r);
              u(f(e), a0r), u(f(e), o0r), a(f(e), s0r, c0r);
              var h = i[3];
              function w(V) {
                return u(n, V);
              }
              function G(V) {
                return u(t4, V);
              }
              R(Je[13], G, w, e, h), u(f(e), v0r), u(f(e), l0r), a(f(e), p0r, b0r);
              var A = i[4];
              if (A) {
                g(e, m0r);
                var S = A[1], M = function(V, f0) {
                  return g(V, $Q0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, _0r);
              } else
                g(e, y0r);
              return u(f(e), d0r), u(f(e), h0r);
            }), N(rJ, function(t4, n, e) {
              var i = a(UC, t4, n);
              return a(P0(JQ0), i, e);
            });
            var d5 = [0, UC, rJ], HC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, eJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(HC, function(t4, n, e, i) {
              u(f(e), _Q0), a(f(e), dQ0, yQ0);
              var x = i[1];
              function c(e0) {
                return u(n, e0);
              }
              function s(e0) {
                return u(t4, e0);
              }
              R(jn[1], s, c, e, x), u(f(e), hQ0), u(f(e), kQ0), a(f(e), EQ0, wQ0);
              var p = i[2];
              if (p) {
                g(e, SQ0);
                var y = p[1], T = function(e0) {
                  return u(n, e0);
                }, E = function(e0) {
                  return u(t4, e0);
                };
                R(Je[22][1], E, T, e, y), g(e, gQ0);
              } else
                g(e, FQ0);
              u(f(e), TQ0), u(f(e), OQ0), a(f(e), AQ0, IQ0);
              var h = i[3];
              if (h) {
                g(e, NQ0);
                var w = h[1], G = function(e0) {
                  return u(n, e0);
                }, A = function(e0) {
                  return u(t4, e0);
                };
                R(Je[13], A, G, e, w), g(e, CQ0);
              } else
                g(e, PQ0);
              u(f(e), DQ0), u(f(e), LQ0), a(f(e), jQ0, RQ0);
              var S = i[4];
              if (S) {
                g(e, GQ0);
                var M = S[1], K = function(e0) {
                  return u(n, e0);
                }, V = function(e0) {
                  return u(t4, e0);
                };
                R(Je[13], V, K, e, M), g(e, MQ0);
              } else
                g(e, BQ0);
              u(f(e), qQ0), u(f(e), UQ0), a(f(e), XQ0, HQ0);
              var f0 = i[5];
              if (f0) {
                g(e, YQ0);
                var m0 = f0[1], k0 = function(e0, x0) {
                  return g(e0, mQ0);
                }, g0 = function(e0) {
                  return u(t4, e0);
                };
                R(Dr[1], g0, k0, e, m0), g(e, VQ0);
              } else
                g(e, zQ0);
              return u(f(e), KQ0), u(f(e), WQ0);
            }), N(eJ, function(t4, n, e) {
              var i = a(HC, t4, n);
              return a(P0(pQ0), i, e);
            });
            var h5 = [0, HC, eJ], XC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, nJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, k5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, tJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(XC, function(t4, n, e, i) {
              u(f(e), vQ0), a(t4, e, i[1]), u(f(e), lQ0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(k5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), bQ0);
            }), N(nJ, function(t4, n, e) {
              var i = a(XC, t4, n);
              return a(P0(sQ0), i, e);
            }), N(k5, function(t4, n, e, i) {
              u(f(e), XZ0), a(f(e), VZ0, YZ0);
              var x = i[1];
              if (x) {
                g(e, zZ0);
                var c = x[1], s = function(A) {
                  return u(n, A);
                }, p = function(A) {
                  return u(t4, A);
                };
                R(Ue[31], p, s, e, c), g(e, KZ0);
              } else
                g(e, WZ0);
              u(f(e), JZ0), u(f(e), $Z0), a(f(e), QZ0, ZZ0);
              var y = i[2];
              u(f(e), rQ0);
              var T = 0;
              be(function(A, S) {
                A && u(f(e), HZ0);
                function M(V) {
                  return u(n, V);
                }
                function K(V) {
                  return u(t4, V);
                }
                return R(Xu[35], K, M, e, S), 1;
              }, T, y), u(f(e), eQ0), u(f(e), nQ0), u(f(e), tQ0), a(f(e), iQ0, uQ0);
              var E = i[3];
              if (E) {
                g(e, fQ0);
                var h = E[1], w = function(A, S) {
                  return g(A, UZ0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, xQ0);
              } else
                g(e, aQ0);
              return u(f(e), oQ0), u(f(e), cQ0);
            }), N(tJ, function(t4, n, e) {
              var i = a(k5, t4, n);
              return a(P0(qZ0), i, e);
            });
            var uJ = [0, XC, nJ, k5, tJ], YC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, iJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(YC, function(t4, n, e, i) {
              u(f(e), dZ0), a(f(e), kZ0, hZ0);
              var x = i[1];
              function c(G) {
                return u(n, G);
              }
              function s(G) {
                return u(t4, G);
              }
              R(Ue[31], s, c, e, x), u(f(e), wZ0), u(f(e), EZ0), a(f(e), gZ0, SZ0);
              var p = i[2];
              u(f(e), FZ0);
              var y = 0;
              be(function(G, A) {
                G && u(f(e), yZ0);
                function S(K) {
                  return u(n, K);
                }
                function M(K) {
                  return u(t4, K);
                }
                return R(uJ[1], M, S, e, A), 1;
              }, y, p), u(f(e), TZ0), u(f(e), OZ0), u(f(e), IZ0), a(f(e), NZ0, AZ0);
              var T = i[3];
              if (T) {
                g(e, CZ0);
                var E = T[1], h = function(G, A) {
                  return g(G, _Z0);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, PZ0);
              } else
                g(e, DZ0);
              return u(f(e), LZ0), u(f(e), RZ0), a(f(e), GZ0, jZ0), a(n, e, i[4]), u(f(e), MZ0), u(f(e), BZ0);
            }), N(iJ, function(t4, n, e) {
              var i = a(YC, t4, n);
              return a(P0(mZ0), i, e);
            });
            var fJ = [0, uJ, YC, iJ], VC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, xJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(VC, function(t4, n, e, i) {
              u(f(e), $$0), a(f(e), Q$0, Z$0);
              var x = i[1];
              if (x) {
                g(e, rZ0);
                var c = x[1], s = function(w) {
                  return u(n, w);
                }, p = function(w) {
                  return u(t4, w);
                };
                R(Ue[31], p, s, e, c), g(e, eZ0);
              } else
                g(e, nZ0);
              u(f(e), tZ0), u(f(e), uZ0), a(f(e), fZ0, iZ0);
              var y = i[2];
              if (y) {
                g(e, xZ0);
                var T = y[1], E = function(w, G) {
                  return g(w, J$0);
                }, h = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], h, E, e, T), g(e, aZ0);
              } else
                g(e, oZ0);
              return u(f(e), cZ0), u(f(e), sZ0), a(f(e), lZ0, vZ0), a(n, e, i[3]), u(f(e), bZ0), u(f(e), pZ0);
            }), N(xJ, function(t4, n, e) {
              var i = a(VC, t4, n);
              return a(P0(W$0), i, e);
            });
            var aJ = [0, VC, xJ], zC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, oJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(zC, function(t4, n, e, i) {
              u(f(e), j$0), a(f(e), M$0, G$0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), B$0), u(f(e), q$0), a(f(e), H$0, U$0);
              var p = i[2];
              if (p) {
                g(e, X$0);
                var y = p[1], T = function(h, w) {
                  return g(h, R$0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Y$0);
              } else
                g(e, V$0);
              return u(f(e), z$0), u(f(e), K$0);
            }), N(oJ, function(t4, n, e) {
              var i = a(zC, t4, n);
              return a(P0(L$0), i, e);
            });
            var cJ = [0, zC, oJ], KC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, sJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, w5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, vJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(KC, function(t4, n, e, i) {
              u(f(e), C$0), a(t4, e, i[1]), u(f(e), P$0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(w5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), D$0);
            }), N(sJ, function(t4, n, e) {
              var i = a(KC, t4, n);
              return a(P0(N$0), i, e);
            }), N(w5, function(t4, n, e, i) {
              u(f(e), o$0), a(f(e), s$0, c$0);
              var x = i[1];
              if (x) {
                g(e, v$0);
                var c = x[1], s = function(M) {
                  return u(n, M);
                }, p = function(M) {
                  return u(t4, M);
                };
                R(hi[5], p, s, e, c), g(e, l$0);
              } else
                g(e, b$0);
              u(f(e), p$0), u(f(e), m$0), a(f(e), y$0, _$0);
              var y = i[2];
              u(f(e), d$0), a(t4, e, y[1]), u(f(e), h$0);
              var T = y[2];
              function E(M) {
                return u(n, M);
              }
              function h(M) {
                return u(t4, M);
              }
              R(Kv[1], h, E, e, T), u(f(e), k$0), u(f(e), w$0), u(f(e), E$0), a(f(e), g$0, S$0);
              var w = i[3];
              if (w) {
                g(e, F$0);
                var G = w[1], A = function(M, K) {
                  return g(M, a$0);
                }, S = function(M) {
                  return u(t4, M);
                };
                R(Dr[1], S, A, e, G), g(e, T$0);
              } else
                g(e, O$0);
              return u(f(e), I$0), u(f(e), A$0);
            }), N(vJ, function(t4, n, e) {
              var i = a(w5, t4, n);
              return a(P0(x$0), i, e);
            });
            var lJ = [0, KC, sJ, w5, vJ], WC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, bJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(WC, function(t4, n, e, i) {
              u(f(e), IJ0), a(f(e), NJ0, AJ0);
              var x = i[1];
              u(f(e), CJ0), a(t4, e, x[1]), u(f(e), PJ0);
              var c = x[2];
              function s(k0) {
                return u(n, k0);
              }
              function p(k0) {
                return u(t4, k0);
              }
              R(Kv[1], p, s, e, c), u(f(e), DJ0), u(f(e), LJ0), u(f(e), RJ0), a(f(e), GJ0, jJ0);
              var y = i[2];
              if (y) {
                g(e, MJ0);
                var T = y[1], E = function(k0) {
                  return u(n, k0);
                }, h = function(k0) {
                  return u(t4, k0);
                };
                R(lJ[1], h, E, e, T), g(e, BJ0);
              } else
                g(e, qJ0);
              u(f(e), UJ0), u(f(e), HJ0), a(f(e), YJ0, XJ0);
              var w = i[3];
              if (w) {
                var G = w[1];
                g(e, VJ0), u(f(e), zJ0), a(t4, e, G[1]), u(f(e), KJ0);
                var A = G[2], S = function(k0) {
                  return u(n, k0);
                }, M = function(k0) {
                  return u(t4, k0);
                };
                R(Kv[1], M, S, e, A), u(f(e), WJ0), g(e, JJ0);
              } else
                g(e, $J0);
              u(f(e), ZJ0), u(f(e), QJ0), a(f(e), e$0, r$0);
              var K = i[4];
              if (K) {
                g(e, n$0);
                var V = K[1], f0 = function(k0, g0) {
                  return g(k0, OJ0);
                }, m0 = function(k0) {
                  return u(t4, k0);
                };
                R(Dr[1], m0, f0, e, V), g(e, t$0);
              } else
                g(e, u$0);
              return u(f(e), i$0), u(f(e), f$0);
            }), N(bJ, function(t4, n, e) {
              var i = a(WC, t4, n);
              return a(P0(TJ0), i, e);
            });
            var pJ = [0, lJ, WC, bJ], JC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, mJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, E5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, _J = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(JC, function(t4, n, e, i) {
              u(f(e), SJ0), a(t4, e, i[1]), u(f(e), gJ0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(E5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), FJ0);
            }), N(mJ, function(t4, n, e) {
              var i = a(JC, t4, n);
              return a(P0(EJ0), i, e);
            }), N(E5, function(t4, n, e, i) {
              u(f(e), sJ0), a(f(e), lJ0, vJ0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), bJ0), u(f(e), pJ0), a(f(e), _J0, mJ0);
              var p = i[2];
              if (p) {
                g(e, yJ0);
                var y = p[1], T = function(h) {
                  return u(n, h);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Ue[31], E, T, e, y), g(e, dJ0);
              } else
                g(e, hJ0);
              return u(f(e), kJ0), u(f(e), wJ0);
            }), N(_J, function(t4, n, e) {
              var i = a(E5, t4, n);
              return a(P0(cJ0), i, e);
            });
            var yJ = [0, JC, mJ, E5, _J], $C = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, dJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, S5 = function t4(n, e) {
              return t4.fun(n, e);
            }, hJ = function t4(n) {
              return t4.fun(n);
            };
            N($C, function(t4, n, e, i) {
              u(f(e), VW0), a(f(e), KW0, zW0);
              var x = i[1];
              u(f(e), WW0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), YW0);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(yJ[1], G, w, e, h), 1;
              }, c, x), u(f(e), JW0), u(f(e), $W0), u(f(e), ZW0), a(f(e), rJ0, QW0), a(S5, e, i[2]), u(f(e), eJ0), u(f(e), nJ0), a(f(e), uJ0, tJ0);
              var s = i[3];
              if (s) {
                g(e, iJ0);
                var p = s[1], y = function(E, h) {
                  return g(E, XW0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, fJ0);
              } else
                g(e, xJ0);
              return u(f(e), aJ0), u(f(e), oJ0);
            }), N(dJ, function(t4, n, e) {
              var i = a($C, t4, n);
              return a(P0(HW0), i, e);
            }), N(S5, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, BW0);
                case 1:
                  return g(t4, qW0);
                default:
                  return g(t4, UW0);
              }
            }), N(hJ, function(t4) {
              return a(P0(MW0), S5, t4);
            });
            var Il = [0, yJ, $C, dJ, S5, hJ], ZC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, kJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(ZC, function(t4, n, e, i) {
              u(f(e), EW0), a(f(e), gW0, SW0);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Ue[31], s, c, e, x), u(f(e), FW0), u(f(e), TW0), a(f(e), IW0, OW0);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Xu[35], T, y, e, p), u(f(e), AW0), u(f(e), NW0), a(f(e), PW0, CW0);
              var E = i[3];
              if (E) {
                g(e, DW0);
                var h = E[1], w = function(A, S) {
                  return g(A, wW0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, LW0);
              } else
                g(e, RW0);
              return u(f(e), jW0), u(f(e), GW0);
            }), N(kJ, function(t4, n, e) {
              var i = a(ZC, t4, n);
              return a(P0(kW0), i, e);
            });
            var wJ = [0, ZC, kJ], QC = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, EJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(QC, function(t4, n, e, i) {
              u(f(e), iW0), a(f(e), xW0, fW0);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Xu[35], s, c, e, x), u(f(e), aW0), u(f(e), oW0), a(f(e), sW0, cW0);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Ue[31], T, y, e, p), u(f(e), vW0), u(f(e), lW0), a(f(e), pW0, bW0);
              var E = i[3];
              if (E) {
                g(e, mW0);
                var h = E[1], w = function(A, S) {
                  return g(A, uW0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, _W0);
              } else
                g(e, yW0);
              return u(f(e), dW0), u(f(e), hW0);
            }), N(EJ, function(t4, n, e) {
              var i = a(QC, t4, n);
              return a(P0(tW0), i, e);
            });
            var SJ = [0, QC, EJ], rP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, gJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, g5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, FJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(rP, function(t4, n, e, i) {
              u(f(e), SK0), a(f(e), FK0, gK0);
              var x = i[1];
              if (x) {
                g(e, TK0);
                var c = x[1], s = function(g0) {
                  return u(n, g0);
                };
                R(g5, function(g0) {
                  return u(t4, g0);
                }, s, e, c), g(e, OK0);
              } else
                g(e, IK0);
              u(f(e), AK0), u(f(e), NK0), a(f(e), PK0, CK0);
              var p = i[2];
              if (p) {
                g(e, DK0);
                var y = p[1], T = function(g0) {
                  return u(n, g0);
                }, E = function(g0) {
                  return u(t4, g0);
                };
                R(Ue[31], E, T, e, y), g(e, LK0);
              } else
                g(e, RK0);
              u(f(e), jK0), u(f(e), GK0), a(f(e), BK0, MK0);
              var h = i[3];
              if (h) {
                g(e, qK0);
                var w = h[1], G = function(g0) {
                  return u(n, g0);
                }, A = function(g0) {
                  return u(t4, g0);
                };
                R(Ue[31], A, G, e, w), g(e, UK0);
              } else
                g(e, HK0);
              u(f(e), XK0), u(f(e), YK0), a(f(e), zK0, VK0);
              var S = i[4];
              function M(g0) {
                return u(n, g0);
              }
              function K(g0) {
                return u(t4, g0);
              }
              R(Xu[35], K, M, e, S), u(f(e), KK0), u(f(e), WK0), a(f(e), $K0, JK0);
              var V = i[5];
              if (V) {
                g(e, ZK0);
                var f0 = V[1], m0 = function(g0, e0) {
                  return g(g0, EK0);
                }, k0 = function(g0) {
                  return u(t4, g0);
                };
                R(Dr[1], k0, m0, e, f0), g(e, QK0);
              } else
                g(e, rW0);
              return u(f(e), eW0), u(f(e), nW0);
            }), N(gJ, function(t4, n, e) {
              var i = a(rP, t4, n);
              return a(P0(wK0), i, e);
            }), N(g5, function(t4, n, e, i) {
              if (i[0] === 0) {
                var x = i[1];
                u(f(e), pK0), u(f(e), mK0), a(t4, e, x[1]), u(f(e), _K0);
                var c = x[2], s = function(h) {
                  return u(n, h);
                }, p = function(h) {
                  return u(t4, h);
                };
                return R(Il[2], p, s, e, c), u(f(e), yK0), u(f(e), dK0);
              }
              u(f(e), hK0);
              var y = i[1];
              function T(h) {
                return u(n, h);
              }
              function E(h) {
                return u(t4, h);
              }
              return R(Ue[31], E, T, e, y), u(f(e), kK0);
            }), N(FJ, function(t4, n, e) {
              var i = a(g5, t4, n);
              return a(P0(bK0), i, e);
            });
            var TJ = [0, rP, gJ, g5, FJ], eP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, OJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, F5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, IJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(eP, function(t4, n, e, i) {
              u(f(e), Hz0), a(f(e), Yz0, Xz0);
              var x = i[1];
              function c(K) {
                return u(n, K);
              }
              R(F5, function(K) {
                return u(t4, K);
              }, c, e, x), u(f(e), Vz0), u(f(e), zz0), a(f(e), Wz0, Kz0);
              var s = i[2];
              function p(K) {
                return u(n, K);
              }
              function y(K) {
                return u(t4, K);
              }
              R(Ue[31], y, p, e, s), u(f(e), Jz0), u(f(e), $z0), a(f(e), Qz0, Zz0);
              var T = i[3];
              function E(K) {
                return u(n, K);
              }
              function h(K) {
                return u(t4, K);
              }
              R(Xu[35], h, E, e, T), u(f(e), rK0), u(f(e), eK0), a(f(e), tK0, nK0);
              var w = i[4];
              a(f(e), uK0, w), u(f(e), iK0), u(f(e), fK0), a(f(e), aK0, xK0);
              var G = i[5];
              if (G) {
                g(e, oK0);
                var A = G[1], S = function(K, V) {
                  return g(K, Uz0);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, cK0);
              } else
                g(e, sK0);
              return u(f(e), vK0), u(f(e), lK0);
            }), N(OJ, function(t4, n, e) {
              var i = a(eP, t4, n);
              return a(P0(qz0), i, e);
            }), N(F5, function(t4, n, e, i) {
              if (i[0] === 0) {
                var x = i[1];
                u(f(e), Dz0), u(f(e), Lz0), a(t4, e, x[1]), u(f(e), Rz0);
                var c = x[2], s = function(h) {
                  return u(n, h);
                }, p = function(h) {
                  return u(t4, h);
                };
                return R(Il[2], p, s, e, c), u(f(e), jz0), u(f(e), Gz0);
              }
              u(f(e), Mz0);
              var y = i[1];
              function T(h) {
                return u(n, h);
              }
              function E(h) {
                return u(t4, h);
              }
              return R(hi[5], E, T, e, y), u(f(e), Bz0);
            }), N(IJ, function(t4, n, e) {
              var i = a(F5, t4, n);
              return a(P0(Pz0), i, e);
            });
            var AJ = [0, eP, OJ, F5, IJ], nP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, NJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, T5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, CJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(nP, function(t4, n, e, i) {
              u(f(e), az0), a(f(e), cz0, oz0);
              var x = i[1];
              function c(K) {
                return u(n, K);
              }
              R(T5, function(K) {
                return u(t4, K);
              }, c, e, x), u(f(e), sz0), u(f(e), vz0), a(f(e), bz0, lz0);
              var s = i[2];
              function p(K) {
                return u(n, K);
              }
              function y(K) {
                return u(t4, K);
              }
              R(Ue[31], y, p, e, s), u(f(e), pz0), u(f(e), mz0), a(f(e), yz0, _z0);
              var T = i[3];
              function E(K) {
                return u(n, K);
              }
              function h(K) {
                return u(t4, K);
              }
              R(Xu[35], h, E, e, T), u(f(e), dz0), u(f(e), hz0), a(f(e), wz0, kz0);
              var w = i[4];
              a(f(e), Ez0, w), u(f(e), Sz0), u(f(e), gz0), a(f(e), Tz0, Fz0);
              var G = i[5];
              if (G) {
                g(e, Oz0);
                var A = G[1], S = function(K, V) {
                  return g(K, xz0);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, Iz0);
              } else
                g(e, Az0);
              return u(f(e), Nz0), u(f(e), Cz0);
            }), N(NJ, function(t4, n, e) {
              var i = a(nP, t4, n);
              return a(P0(fz0), i, e);
            }), N(T5, function(t4, n, e, i) {
              if (i[0] === 0) {
                var x = i[1];
                u(f(e), QV0), u(f(e), rz0), a(t4, e, x[1]), u(f(e), ez0);
                var c = x[2], s = function(h) {
                  return u(n, h);
                }, p = function(h) {
                  return u(t4, h);
                };
                return R(Il[2], p, s, e, c), u(f(e), nz0), u(f(e), tz0);
              }
              u(f(e), uz0);
              var y = i[1];
              function T(h) {
                return u(n, h);
              }
              function E(h) {
                return u(t4, h);
              }
              return R(hi[5], E, T, e, y), u(f(e), iz0);
            }), N(CJ, function(t4, n, e) {
              var i = a(T5, t4, n);
              return a(P0(ZV0), i, e);
            });
            var PJ = [0, nP, NJ, T5, CJ], tP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, DJ = function t4(n, e) {
              return t4.fun(n, e);
            }, O5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, LJ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(tP, function(t4, n, e) {
              u(f(n), WV0), a(t4, n, e[1]), u(f(n), JV0);
              var i = e[2];
              return ir(O5, function(x) {
                return u(t4, x);
              }, n, i), u(f(n), $V0);
            }), N(DJ, function(t4, n) {
              var e = u(tP, t4);
              return a(P0(KV0), e, n);
            }), N(O5, function(t4, n, e) {
              u(f(n), HV0), a(f(n), YV0, XV0);
              var i = e[1];
              function x(s) {
                return u(t4, s);
              }
              function c(s) {
                return u(t4, s);
              }
              return R(jn[1], c, x, n, i), u(f(n), VV0), u(f(n), zV0);
            }), N(LJ, function(t4, n) {
              var e = u(O5, t4);
              return a(P0(UV0), e, n);
            });
            var uP = [0, tP, DJ, O5, LJ], iP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, RJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, I5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, jJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(iP, function(t4, n, e, i) {
              u(f(e), MV0), a(n, e, i[1]), u(f(e), BV0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(I5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), qV0);
            }), N(RJ, function(t4, n, e) {
              var i = a(iP, t4, n);
              return a(P0(GV0), i, e);
            }), N(I5, function(t4, n, e, i) {
              u(f(e), FV0), a(f(e), OV0, TV0);
              var x = i[1];
              function c(y) {
                return u(n, y);
              }
              function s(y) {
                return u(n, y);
              }
              R(jn[1], s, c, e, x), u(f(e), IV0), u(f(e), AV0), a(f(e), CV0, NV0);
              var p = i[2];
              return u(f(e), PV0), a(n, e, p[1]), u(f(e), DV0), a(t4, e, p[2]), u(f(e), LV0), u(f(e), RV0), u(f(e), jV0);
            }), N(jJ, function(t4, n, e) {
              var i = a(I5, t4, n);
              return a(P0(gV0), i, e);
            });
            var A5 = [0, iP, RJ, I5, jJ], fP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, GJ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(fP, function(t4, n, e) {
              u(f(n), eV0), a(f(n), tV0, nV0);
              var i = e[1];
              u(f(n), uV0);
              var x = 0;
              be(function(h, w) {
                h && u(f(n), rV0);
                function G(S) {
                  return u(t4, S);
                }
                function A(S) {
                  function M(K) {
                    return u(t4, K);
                  }
                  return a(XN[1], M, S);
                }
                return R(A5[1], A, G, n, w), 1;
              }, x, i), u(f(n), iV0), u(f(n), fV0), u(f(n), xV0), a(f(n), oV0, aV0);
              var c = e[2];
              a(f(n), cV0, c), u(f(n), sV0), u(f(n), vV0), a(f(n), bV0, lV0);
              var s = e[3];
              a(f(n), pV0, s), u(f(n), mV0), u(f(n), _V0), a(f(n), dV0, yV0);
              var p = e[4];
              if (p) {
                g(n, hV0);
                var y = p[1], T = function(h, w) {
                  u(f(h), ZY0);
                  var G = 0;
                  return be(function(A, S) {
                    A && u(f(h), $Y0);
                    function M(K) {
                      return u(t4, K);
                    }
                    return ir(uu[1], M, h, S), 1;
                  }, G, w), u(f(h), QY0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, n, y), g(n, kV0);
              } else
                g(n, wV0);
              return u(f(n), EV0), u(f(n), SV0);
            }), N(GJ, function(t4, n) {
              var e = u(fP, t4);
              return a(P0(JY0), e, n);
            });
            var MJ = [0, fP, GJ], xP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, BJ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(xP, function(t4, n, e) {
              u(f(n), FY0), a(f(n), OY0, TY0);
              var i = e[1];
              u(f(n), IY0);
              var x = 0;
              be(function(h, w) {
                h && u(f(n), gY0);
                function G(S) {
                  return u(t4, S);
                }
                function A(S) {
                  function M(K) {
                    return u(t4, K);
                  }
                  return a(HN[1], M, S);
                }
                return R(A5[1], A, G, n, w), 1;
              }, x, i), u(f(n), AY0), u(f(n), NY0), u(f(n), CY0), a(f(n), DY0, PY0);
              var c = e[2];
              a(f(n), LY0, c), u(f(n), RY0), u(f(n), jY0), a(f(n), MY0, GY0);
              var s = e[3];
              a(f(n), BY0, s), u(f(n), qY0), u(f(n), UY0), a(f(n), XY0, HY0);
              var p = e[4];
              if (p) {
                g(n, YY0);
                var y = p[1], T = function(h, w) {
                  u(f(h), EY0);
                  var G = 0;
                  return be(function(A, S) {
                    A && u(f(h), wY0);
                    function M(K) {
                      return u(t4, K);
                    }
                    return ir(uu[1], M, h, S), 1;
                  }, G, w), u(f(h), SY0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, n, y), g(n, VY0);
              } else
                g(n, zY0);
              return u(f(n), KY0), u(f(n), WY0);
            }), N(BJ, function(t4, n) {
              var e = u(xP, t4);
              return a(P0(kY0), e, n);
            });
            var qJ = [0, xP, BJ], aP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, UJ = function t4(n, e) {
              return t4.fun(n, e);
            }, N5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, HJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(aP, function(t4, n, e) {
              u(f(n), QX0), a(f(n), eY0, rY0);
              var i = e[1];
              function x(h) {
                return u(t4, h);
              }
              R(N5, function(h) {
                function w(G) {
                  return u(t4, G);
                }
                return a(F1[1], w, h);
              }, x, n, i), u(f(n), nY0), u(f(n), tY0), a(f(n), iY0, uY0);
              var c = e[2];
              a(f(n), fY0, c), u(f(n), xY0), u(f(n), aY0), a(f(n), cY0, oY0);
              var s = e[3];
              a(f(n), sY0, s), u(f(n), vY0), u(f(n), lY0), a(f(n), pY0, bY0);
              var p = e[4];
              if (p) {
                g(n, mY0);
                var y = p[1], T = function(h, w) {
                  u(f(h), $X0);
                  var G = 0;
                  return be(function(A, S) {
                    A && u(f(h), JX0);
                    function M(K) {
                      return u(t4, K);
                    }
                    return ir(uu[1], M, h, S), 1;
                  }, G, w), u(f(h), ZX0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, n, y), g(n, _Y0);
              } else
                g(n, yY0);
              return u(f(n), dY0), u(f(n), hY0);
            }), N(UJ, function(t4, n) {
              var e = u(aP, t4);
              return a(P0(WX0), e, n);
            }), N(N5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), qX0), u(f(e), UX0);
                var x = i[1], c = 0;
                return be(function(y, T) {
                  y && u(f(e), BX0);
                  function E(h) {
                    return u(n, h);
                  }
                  return ir(uP[1], E, e, T), 1;
                }, c, x), u(f(e), HX0), u(f(e), XX0);
              }
              u(f(e), YX0), u(f(e), VX0);
              var s = i[1], p = 0;
              return be(function(y, T) {
                y && u(f(e), MX0);
                function E(w) {
                  return u(n, w);
                }
                function h(w) {
                  return u(t4, w);
                }
                return R(A5[1], h, E, e, T), 1;
              }, p, s), u(f(e), zX0), u(f(e), KX0);
            }), N(HJ, function(t4, n, e) {
              var i = a(N5, t4, n);
              return a(P0(GX0), i, e);
            });
            var XJ = [0, aP, UJ, N5, HJ], oP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, YJ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(oP, function(t4, n, e) {
              u(f(n), dX0), a(f(n), kX0, hX0);
              var i = e[1];
              u(f(n), wX0);
              var x = 0;
              be(function(E, h) {
                E && u(f(n), yX0);
                function w(G) {
                  return u(t4, G);
                }
                return ir(uP[1], w, n, h), 1;
              }, x, i), u(f(n), EX0), u(f(n), SX0), u(f(n), gX0), a(f(n), TX0, FX0);
              var c = e[2];
              a(f(n), OX0, c), u(f(n), IX0), u(f(n), AX0), a(f(n), CX0, NX0);
              var s = e[3];
              if (s) {
                g(n, PX0);
                var p = s[1], y = function(E, h) {
                  u(f(E), mX0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), pX0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), _X0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, n, p), g(n, DX0);
              } else
                g(n, LX0);
              return u(f(n), RX0), u(f(n), jX0);
            }), N(YJ, function(t4, n) {
              var e = u(oP, t4);
              return a(P0(bX0), e, n);
            });
            var VJ = [0, oP, YJ], cP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, zJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, C5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, KJ = function t4(n, e) {
              return t4.fun(n, e);
            }, P5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, WJ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(cP, function(t4, n, e, i) {
              u(f(e), ZH0), a(f(e), rX0, QH0);
              var x = i[1];
              function c(w) {
                return u(n, w);
              }
              function s(w) {
                return u(t4, w);
              }
              R(jn[1], s, c, e, x), u(f(e), eX0), u(f(e), nX0), a(f(e), uX0, tX0);
              var p = i[2];
              ir(C5, function(w) {
                return u(t4, w);
              }, e, p), u(f(e), iX0), u(f(e), fX0), a(f(e), aX0, xX0);
              var y = i[3];
              if (y) {
                g(e, oX0);
                var T = y[1], E = function(w, G) {
                  return g(w, $H0);
                }, h = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], h, E, e, T), g(e, cX0);
              } else
                g(e, sX0);
              return u(f(e), vX0), u(f(e), lX0);
            }), N(zJ, function(t4, n, e) {
              var i = a(cP, t4, n);
              return a(P0(JH0), i, e);
            }), N(C5, function(t4, n, e) {
              u(f(n), zH0), a(t4, n, e[1]), u(f(n), KH0);
              var i = e[2];
              return ir(P5, function(x) {
                return u(t4, x);
              }, n, i), u(f(n), WH0);
            }), N(KJ, function(t4, n) {
              var e = u(C5, t4);
              return a(P0(VH0), e, n);
            }), N(P5, function(t4, n, e) {
              switch (e[0]) {
                case 0:
                  u(f(n), GH0);
                  var i = e[1], x = function(h) {
                    return u(t4, h);
                  };
                  return ir(MJ[1], x, n, i), u(f(n), MH0);
                case 1:
                  u(f(n), BH0);
                  var c = e[1], s = function(h) {
                    return u(t4, h);
                  };
                  return ir(qJ[1], s, n, c), u(f(n), qH0);
                case 2:
                  u(f(n), UH0);
                  var p = e[1], y = function(h) {
                    return u(t4, h);
                  };
                  return ir(XJ[1], y, n, p), u(f(n), HH0);
                default:
                  u(f(n), XH0);
                  var T = e[1], E = function(h) {
                    return u(t4, h);
                  };
                  return ir(VJ[1], E, n, T), u(f(n), YH0);
              }
            }), N(WJ, function(t4, n) {
              var e = u(P5, t4);
              return a(P0(jH0), e, n);
            });
            var JJ = [0, uP, A5, MJ, qJ, XJ, VJ, cP, zJ, C5, KJ, P5, WJ], sP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, $J = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(sP, function(t4, n, e, i) {
              u(f(e), iH0), a(f(e), xH0, fH0);
              var x = i[1];
              function c(k0) {
                return u(n, k0);
              }
              function s(k0) {
                return u(t4, k0);
              }
              R(jn[1], s, c, e, x), u(f(e), aH0), u(f(e), oH0), a(f(e), sH0, cH0);
              var p = i[2];
              if (p) {
                g(e, vH0);
                var y = p[1], T = function(k0) {
                  return u(n, k0);
                }, E = function(k0) {
                  return u(t4, k0);
                };
                R(Je[22][1], E, T, e, y), g(e, lH0);
              } else
                g(e, bH0);
              u(f(e), pH0), u(f(e), mH0), a(f(e), yH0, _H0);
              var h = i[3];
              u(f(e), dH0);
              var w = 0;
              be(function(k0, g0) {
                k0 && u(f(e), eH0), u(f(e), nH0), a(t4, e, g0[1]), u(f(e), tH0);
                var e0 = g0[2];
                function x0(c0) {
                  return u(n, c0);
                }
                function l(c0) {
                  return u(t4, c0);
                }
                return R(Je[2][2], l, x0, e, e0), u(f(e), uH0), 1;
              }, w, h), u(f(e), hH0), u(f(e), kH0), u(f(e), wH0), a(f(e), SH0, EH0);
              var G = i[4];
              u(f(e), gH0), a(t4, e, G[1]), u(f(e), FH0);
              var A = G[2];
              function S(k0) {
                return u(n, k0);
              }
              function M(k0) {
                return u(t4, k0);
              }
              R(Je[5][6], M, S, e, A), u(f(e), TH0), u(f(e), OH0), u(f(e), IH0), a(f(e), NH0, AH0);
              var K = i[5];
              if (K) {
                g(e, CH0);
                var V = K[1], f0 = function(k0, g0) {
                  return g(k0, rH0);
                }, m0 = function(k0) {
                  return u(t4, k0);
                };
                R(Dr[1], m0, f0, e, V), g(e, PH0);
              } else
                g(e, DH0);
              return u(f(e), LH0), u(f(e), RH0);
            }), N($J, function(t4, n, e) {
              var i = a(sP, t4, n);
              return a(P0(QU0), i, e);
            });
            var D5 = [0, sP, $J], vP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, ZJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(vP, function(t4, n, e, i) {
              u(f(e), uU0), a(f(e), fU0, iU0);
              var x = i[1];
              function c(_0) {
                return u(n, _0);
              }
              function s(_0) {
                return u(t4, _0);
              }
              R(jn[1], s, c, e, x), u(f(e), xU0), u(f(e), aU0), a(f(e), cU0, oU0);
              var p = i[2];
              if (p) {
                g(e, sU0);
                var y = p[1], T = function(_0) {
                  return u(n, _0);
                }, E = function(_0) {
                  return u(t4, _0);
                };
                R(Je[22][1], E, T, e, y), g(e, vU0);
              } else
                g(e, lU0);
              u(f(e), bU0), u(f(e), pU0), a(f(e), _U0, mU0);
              var h = i[3];
              u(f(e), yU0), a(t4, e, h[1]), u(f(e), dU0);
              var w = h[2];
              function G(_0) {
                return u(n, _0);
              }
              function A(_0) {
                return u(t4, _0);
              }
              R(Je[5][6], A, G, e, w), u(f(e), hU0), u(f(e), kU0), u(f(e), wU0), a(f(e), SU0, EU0);
              var S = i[4];
              if (S) {
                var M = S[1];
                g(e, gU0), u(f(e), FU0), a(t4, e, M[1]), u(f(e), TU0);
                var K = M[2], V = function(_0) {
                  return u(n, _0);
                }, f0 = function(_0) {
                  return u(t4, _0);
                };
                R(Je[2][2], f0, V, e, K), u(f(e), OU0), g(e, IU0);
              } else
                g(e, AU0);
              u(f(e), NU0), u(f(e), CU0), a(f(e), DU0, PU0);
              var m0 = i[5];
              u(f(e), LU0);
              var k0 = 0;
              be(function(_0, E0) {
                _0 && u(f(e), rU0), u(f(e), eU0), a(t4, e, E0[1]), u(f(e), nU0);
                var X0 = E0[2];
                function b(X) {
                  return u(n, X);
                }
                function G0(X) {
                  return u(t4, X);
                }
                return R(Je[2][2], G0, b, e, X0), u(f(e), tU0), 1;
              }, k0, m0), u(f(e), RU0), u(f(e), jU0), u(f(e), GU0), a(f(e), BU0, MU0);
              var g0 = i[6];
              if (g0) {
                g(e, qU0);
                var e0 = g0[1], x0 = function(_0) {
                  return u(n, _0);
                }, l = function(_0) {
                  return u(t4, _0);
                };
                R(T1[5][2], l, x0, e, e0), g(e, UU0);
              } else
                g(e, HU0);
              u(f(e), XU0), u(f(e), YU0), a(f(e), zU0, VU0);
              var c0 = i[7];
              if (c0) {
                g(e, KU0);
                var t0 = c0[1], a0 = function(_0, E0) {
                  return g(_0, Qq0);
                }, w0 = function(_0) {
                  return u(t4, _0);
                };
                R(Dr[1], w0, a0, e, t0), g(e, WU0);
              } else
                g(e, JU0);
              return u(f(e), $U0), u(f(e), ZU0);
            }), N(ZJ, function(t4, n, e) {
              var i = a(vP, t4, n);
              return a(P0(Zq0), i, e);
            });
            var lP = [0, vP, ZJ], bP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, QJ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(bP, function(t4, n, e, i) {
              u(f(e), Rq0), a(f(e), Gq0, jq0);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(jn[1], s, c, e, x), u(f(e), Mq0), u(f(e), Bq0), a(f(e), Uq0, qq0);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Je[17], T, y, e, p), u(f(e), Hq0), u(f(e), Xq0), a(f(e), Vq0, Yq0);
              var E = i[3];
              if (E) {
                g(e, zq0);
                var h = E[1], w = function(A, S) {
                  return g(A, Lq0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, Kq0);
              } else
                g(e, Wq0);
              return u(f(e), Jq0), u(f(e), $q0);
            }), N(QJ, function(t4, n, e) {
              var i = a(bP, t4, n);
              return a(P0(Dq0), i, e);
            });
            var pP = [0, bP, QJ], mP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, r$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(mP, function(t4, n, e, i) {
              u(f(e), sq0), a(f(e), lq0, vq0);
              var x = i[1];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(jn[1], s, c, e, x), u(f(e), bq0), u(f(e), pq0), a(f(e), _q0, mq0);
              var p = i[2];
              function y(V) {
                return u(n, V);
              }
              function T(V) {
                return u(t4, V);
              }
              R(Je[17], T, y, e, p), u(f(e), yq0), u(f(e), dq0), a(f(e), kq0, hq0);
              var E = i[3];
              if (E) {
                g(e, wq0);
                var h = E[1], w = function(V) {
                  return u(n, V);
                }, G = function(V) {
                  return u(t4, V);
                };
                R(Je[24][1], G, w, e, h), g(e, Eq0);
              } else
                g(e, Sq0);
              u(f(e), gq0), u(f(e), Fq0), a(f(e), Oq0, Tq0);
              var A = i[4];
              if (A) {
                g(e, Iq0);
                var S = A[1], M = function(V, f0) {
                  return g(V, cq0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, Aq0);
              } else
                g(e, Nq0);
              return u(f(e), Cq0), u(f(e), Pq0);
            }), N(r$, function(t4, n, e) {
              var i = a(mP, t4, n);
              return a(P0(oq0), i, e);
            });
            var _P = [0, mP, r$], L5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, e$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, R5 = function t4(n, e) {
              return t4.fun(n, e);
            }, n$ = function t4(n) {
              return t4.fun(n);
            }, yP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, t$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(L5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), nq0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(jn[1], s, c, e, x), u(f(e), tq0);
              }
              var p = i[1];
              u(f(e), uq0), u(f(e), iq0), a(n, e, p[1]), u(f(e), fq0);
              var y = p[2];
              function T(E) {
                return u(t4, E);
              }
              return ir(F1[1], T, e, y), u(f(e), xq0), u(f(e), aq0);
            }), N(e$, function(t4, n, e) {
              var i = a(L5, t4, n);
              return a(P0(eq0), i, e);
            }), N(R5, function(t4, n) {
              return n ? g(t4, QB0) : g(t4, rq0);
            }), N(n$, function(t4) {
              return a(P0(ZB0), R5, t4);
            }), N(yP, function(t4, n, e, i) {
              u(f(e), IB0), a(f(e), NB0, AB0);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              R(L5, function(A) {
                return u(t4, A);
              }, c, e, x), u(f(e), CB0), u(f(e), PB0), a(f(e), LB0, DB0);
              var s = i[2];
              u(f(e), RB0), a(t4, e, s[1]), u(f(e), jB0);
              var p = s[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Kv[1], T, y, e, p), u(f(e), GB0), u(f(e), MB0), u(f(e), BB0), a(f(e), UB0, qB0), a(R5, e, i[3]), u(f(e), HB0), u(f(e), XB0), a(f(e), VB0, YB0);
              var E = i[4];
              if (E) {
                g(e, zB0);
                var h = E[1], w = function(A, S) {
                  return g(A, OB0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, KB0);
              } else
                g(e, WB0);
              return u(f(e), JB0), u(f(e), $B0);
            }), N(t$, function(t4, n, e) {
              var i = a(yP, t4, n);
              return a(P0(TB0), i, e);
            });
            var u$ = [0, L5, e$, R5, n$, yP, t$], dP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, i$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(dP, function(t4, n, e, i) {
              u(f(e), pB0), a(f(e), _B0, mB0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[17], s, c, e, x), u(f(e), yB0), u(f(e), dB0), a(f(e), kB0, hB0);
              var p = i[2];
              if (p) {
                g(e, wB0);
                var y = p[1], T = function(h, w) {
                  return g(h, bB0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, EB0);
              } else
                g(e, SB0);
              return u(f(e), gB0), u(f(e), FB0);
            }), N(i$, function(t4, n, e) {
              var i = a(dP, t4, n);
              return a(P0(lB0), i, e);
            });
            var f$ = [0, dP, i$], hP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, x$ = function t4(n, e) {
              return t4.fun(n, e);
            }, j5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, a$ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(hP, function(t4, n, e) {
              u(f(n), cB0), a(t4, n, e[1]), u(f(n), sB0);
              var i = e[2];
              return ir(j5, function(x) {
                return u(t4, x);
              }, n, i), u(f(n), vB0);
            }), N(x$, function(t4, n) {
              var e = u(hP, t4);
              return a(P0(oB0), e, n);
            }), N(j5, function(t4, n, e) {
              u(f(n), $M0), a(f(n), QM0, ZM0);
              var i = e[1];
              function x(E) {
                return u(t4, E);
              }
              function c(E) {
                return u(t4, E);
              }
              R(jn[1], c, x, n, i), u(f(n), rB0), u(f(n), eB0), a(f(n), tB0, nB0);
              var s = e[2];
              if (s) {
                g(n, uB0);
                var p = s[1], y = function(E) {
                  return u(t4, E);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(jn[1], T, y, n, p), g(n, iB0);
              } else
                g(n, fB0);
              return u(f(n), xB0), u(f(n), aB0);
            }), N(a$, function(t4, n) {
              var e = u(j5, t4);
              return a(P0(JM0), e, n);
            });
            var o$ = [0, hP, x$, j5, a$], kP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, c$ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(kP, function(t4, n, e) {
              var i = e[2];
              if (u(f(n), XM0), a(t4, n, e[1]), u(f(n), YM0), i) {
                g(n, VM0);
                var x = i[1], c = function(p) {
                  return u(t4, p);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(jn[1], s, c, n, x), g(n, zM0);
              } else
                g(n, KM0);
              return u(f(n), WM0);
            }), N(c$, function(t4, n) {
              var e = u(kP, t4);
              return a(P0(HM0), e, n);
            });
            var s$ = [0, kP, c$], wP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, v$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, G5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, l$ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(wP, function(t4, n, e, i) {
              u(f(e), xM0), a(f(e), oM0, aM0);
              var x = i[1];
              if (x) {
                g(e, cM0);
                var c = x[1], s = function(V) {
                  return u(n, V);
                }, p = function(V) {
                  return u(t4, V);
                };
                R(Xu[35], p, s, e, c), g(e, sM0);
              } else
                g(e, vM0);
              u(f(e), lM0), u(f(e), bM0), a(f(e), mM0, pM0);
              var y = i[2];
              if (y) {
                g(e, _M0);
                var T = y[1];
                ir(G5, function(V) {
                  return u(t4, V);
                }, e, T), g(e, yM0);
              } else
                g(e, dM0);
              u(f(e), hM0), u(f(e), kM0), a(f(e), EM0, wM0);
              var E = i[3];
              if (E) {
                var h = E[1];
                g(e, SM0), u(f(e), gM0), a(t4, e, h[1]), u(f(e), FM0);
                var w = h[2], G = function(V) {
                  return u(t4, V);
                };
                ir(F1[1], G, e, w), u(f(e), TM0), g(e, OM0);
              } else
                g(e, IM0);
              u(f(e), AM0), u(f(e), NM0), a(f(e), PM0, CM0), a(Xu[33], e, i[4]), u(f(e), DM0), u(f(e), LM0), a(f(e), jM0, RM0);
              var A = i[5];
              if (A) {
                g(e, GM0);
                var S = A[1], M = function(V, f0) {
                  return g(V, fM0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, MM0);
              } else
                g(e, BM0);
              return u(f(e), qM0), u(f(e), UM0);
            }), N(v$, function(t4, n, e) {
              var i = a(wP, t4, n);
              return a(P0(iM0), i, e);
            }), N(G5, function(t4, n, e) {
              if (e[0] === 0) {
                u(f(n), QG0), u(f(n), rM0);
                var i = e[1], x = 0;
                return be(function(p, y) {
                  p && u(f(n), ZG0);
                  function T(E) {
                    return u(t4, E);
                  }
                  return ir(o$[1], T, n, y), 1;
                }, x, i), u(f(n), eM0), u(f(n), nM0);
              }
              u(f(n), tM0);
              var c = e[1];
              function s(p) {
                return u(t4, p);
              }
              return ir(s$[1], s, n, c), u(f(n), uM0);
            }), N(l$, function(t4, n) {
              var e = u(G5, t4);
              return a(P0($G0), e, n);
            });
            var EP = [0, o$, s$, wP, v$, G5, l$], SP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, b$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, M5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, p$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(SP, function(t4, n, e, i) {
              u(f(e), LG0), a(f(e), jG0, RG0), a(t4, e, i[1]), u(f(e), GG0), u(f(e), MG0), a(f(e), qG0, BG0);
              var x = i[2];
              function c(E) {
                return u(n, E);
              }
              R(M5, function(E) {
                return u(t4, E);
              }, c, e, x), u(f(e), UG0), u(f(e), HG0), a(f(e), YG0, XG0);
              var s = i[3];
              if (s) {
                g(e, VG0);
                var p = s[1], y = function(E, h) {
                  return g(E, DG0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, zG0);
              } else
                g(e, KG0);
              return u(f(e), WG0), u(f(e), JG0);
            }), N(b$, function(t4, n, e) {
              var i = a(SP, t4, n);
              return a(P0(PG0), i, e);
            }), N(M5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), IG0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(Xu[35], s, c, e, x), u(f(e), AG0);
              }
              u(f(e), NG0);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(Ue[31], T, y, e, p), u(f(e), CG0);
            }), N(p$, function(t4, n, e) {
              var i = a(M5, t4, n);
              return a(P0(OG0), i, e);
            });
            var m$ = [0, SP, b$, M5, p$], B5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, _$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, gP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, y$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(B5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  var x = i[1];
                  u(f(e), Jj0), u(f(e), $j0), a(t4, e, x[1]), u(f(e), Zj0);
                  var c = x[2], s = function(E0) {
                    return u(n, E0);
                  }, p = function(E0) {
                    return u(t4, E0);
                  };
                  return R(pP[1], p, s, e, c), u(f(e), Qj0), u(f(e), rG0);
                case 1:
                  var y = i[1];
                  u(f(e), eG0), u(f(e), nG0), a(t4, e, y[1]), u(f(e), tG0);
                  var T = y[2], E = function(E0) {
                    return u(n, E0);
                  }, h = function(E0) {
                    return u(t4, E0);
                  };
                  return R(_P[1], h, E, e, T), u(f(e), uG0), u(f(e), iG0);
                case 2:
                  var w = i[1];
                  u(f(e), fG0), u(f(e), xG0), a(t4, e, w[1]), u(f(e), aG0);
                  var G = w[2], A = function(E0) {
                    return u(n, E0);
                  }, S = function(E0) {
                    return u(t4, E0);
                  };
                  return R(lP[1], S, A, e, G), u(f(e), oG0), u(f(e), cG0);
                case 3:
                  u(f(e), sG0);
                  var M = i[1], K = function(E0) {
                    return u(n, E0);
                  }, V = function(E0) {
                    return u(t4, E0);
                  };
                  return R(Je[13], V, K, e, M), u(f(e), vG0);
                case 4:
                  var f0 = i[1];
                  u(f(e), lG0), u(f(e), bG0), a(t4, e, f0[1]), u(f(e), pG0);
                  var m0 = f0[2], k0 = function(E0) {
                    return u(n, E0);
                  }, g0 = function(E0) {
                    return u(t4, E0);
                  };
                  return R(d5[1], g0, k0, e, m0), u(f(e), mG0), u(f(e), _G0);
                case 5:
                  var e0 = i[1];
                  u(f(e), yG0), u(f(e), dG0), a(t4, e, e0[1]), u(f(e), hG0);
                  var x0 = e0[2], l = function(E0) {
                    return u(n, E0);
                  }, c0 = function(E0) {
                    return u(t4, E0);
                  };
                  return R(h5[1], c0, l, e, x0), u(f(e), kG0), u(f(e), wG0);
                default:
                  var t0 = i[1];
                  u(f(e), EG0), u(f(e), SG0), a(t4, e, t0[1]), u(f(e), gG0);
                  var a0 = t0[2], w0 = function(E0) {
                    return u(n, E0);
                  }, _0 = function(E0) {
                    return u(t4, E0);
                  };
                  return R(D5[1], _0, w0, e, a0), u(f(e), FG0), u(f(e), TG0);
              }
            }), N(_$, function(t4, n, e) {
              var i = a(B5, t4, n);
              return a(P0(Wj0), i, e);
            }), N(gP, function(t4, n, e, i) {
              u(f(e), cj0), a(f(e), vj0, sj0);
              var x = i[1];
              x ? (g(e, lj0), a(t4, e, x[1]), g(e, bj0)) : g(e, pj0), u(f(e), mj0), u(f(e), _j0), a(f(e), dj0, yj0);
              var c = i[2];
              if (c) {
                g(e, hj0);
                var s = c[1], p = function(f0) {
                  return u(n, f0);
                };
                R(B5, function(f0) {
                  return u(t4, f0);
                }, p, e, s), g(e, kj0);
              } else
                g(e, wj0);
              u(f(e), Ej0), u(f(e), Sj0), a(f(e), Fj0, gj0);
              var y = i[3];
              if (y) {
                g(e, Tj0);
                var T = y[1], E = function(f0) {
                  return u(t4, f0);
                };
                ir(EP[5], E, e, T), g(e, Oj0);
              } else
                g(e, Ij0);
              u(f(e), Aj0), u(f(e), Nj0), a(f(e), Pj0, Cj0);
              var h = i[4];
              if (h) {
                var w = h[1];
                g(e, Dj0), u(f(e), Lj0), a(t4, e, w[1]), u(f(e), Rj0);
                var G = w[2], A = function(f0) {
                  return u(t4, f0);
                };
                ir(F1[1], A, e, G), u(f(e), jj0), g(e, Gj0);
              } else
                g(e, Mj0);
              u(f(e), Bj0), u(f(e), qj0), a(f(e), Hj0, Uj0);
              var S = i[5];
              if (S) {
                g(e, Xj0);
                var M = S[1], K = function(f0, m0) {
                  return g(f0, oj0);
                }, V = function(f0) {
                  return u(t4, f0);
                };
                R(Dr[1], V, K, e, M), g(e, Yj0);
              } else
                g(e, Vj0);
              return u(f(e), zj0), u(f(e), Kj0);
            }), N(y$, function(t4, n, e) {
              var i = a(gP, t4, n);
              return a(P0(aj0), i, e);
            });
            var d$ = [0, B5, _$, gP, y$], Al = function t4(n, e) {
              return t4.fun(n, e);
            }, h$ = function t4(n) {
              return t4.fun(n);
            }, q5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, k$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, U5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, w$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, FP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, E$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Al, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, ij0);
                case 1:
                  return g(t4, fj0);
                default:
                  return g(t4, xj0);
              }
            }), N(h$, function(t4) {
              return a(P0(uj0), Al, t4);
            }), N(q5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), WR0), u(f(e), JR0);
                var x = i[1], c = 0;
                return be(function(E, h) {
                  E && u(f(e), KR0);
                  function w(G) {
                    return u(n, G);
                  }
                  return R(U5, function(G) {
                    return u(t4, G);
                  }, w, e, h), 1;
                }, c, x), u(f(e), $R0), u(f(e), ZR0);
              }
              var s = i[1];
              u(f(e), QR0), u(f(e), rj0), a(t4, e, s[1]), u(f(e), ej0);
              var p = s[2];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(jn[1], T, y, e, p), u(f(e), nj0), u(f(e), tj0);
            }), N(k$, function(t4, n, e) {
              var i = a(q5, t4, n);
              return a(P0(zR0), i, e);
            }), N(U5, function(t4, n, e, i) {
              u(f(e), OR0), a(f(e), AR0, IR0);
              var x = i[1];
              x ? (g(e, NR0), a(Al, e, x[1]), g(e, CR0)) : g(e, PR0), u(f(e), DR0), u(f(e), LR0), a(f(e), jR0, RR0);
              var c = i[2];
              if (c) {
                g(e, GR0);
                var s = c[1], p = function(w) {
                  return u(n, w);
                }, y = function(w) {
                  return u(t4, w);
                };
                R(jn[1], y, p, e, s), g(e, MR0);
              } else
                g(e, BR0);
              u(f(e), qR0), u(f(e), UR0), a(f(e), XR0, HR0);
              var T = i[3];
              function E(w) {
                return u(n, w);
              }
              function h(w) {
                return u(t4, w);
              }
              return R(jn[1], h, E, e, T), u(f(e), YR0), u(f(e), VR0);
            }), N(w$, function(t4, n, e) {
              var i = a(U5, t4, n);
              return a(P0(TR0), i, e);
            }), N(FP, function(t4, n, e, i) {
              u(f(e), KL0), a(f(e), JL0, WL0), a(Al, e, i[1]), u(f(e), $L0), u(f(e), ZL0), a(f(e), rR0, QL0);
              var x = i[2];
              u(f(e), eR0), a(t4, e, x[1]), u(f(e), nR0);
              var c = x[2];
              function s(V) {
                return u(t4, V);
              }
              ir(F1[1], s, e, c), u(f(e), tR0), u(f(e), uR0), u(f(e), iR0), a(f(e), xR0, fR0);
              var p = i[3];
              if (p) {
                g(e, aR0);
                var y = p[1], T = function(V) {
                  return u(n, V);
                }, E = function(V) {
                  return u(t4, V);
                };
                R(jn[1], E, T, e, y), g(e, oR0);
              } else
                g(e, cR0);
              u(f(e), sR0), u(f(e), vR0), a(f(e), bR0, lR0);
              var h = i[4];
              if (h) {
                g(e, pR0);
                var w = h[1], G = function(V) {
                  return u(n, V);
                };
                R(q5, function(V) {
                  return u(t4, V);
                }, G, e, w), g(e, mR0);
              } else
                g(e, _R0);
              u(f(e), yR0), u(f(e), dR0), a(f(e), kR0, hR0);
              var A = i[5];
              if (A) {
                g(e, wR0);
                var S = A[1], M = function(V, f0) {
                  return g(V, zL0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, ER0);
              } else
                g(e, SR0);
              return u(f(e), gR0), u(f(e), FR0);
            }), N(E$, function(t4, n, e) {
              var i = a(FP, t4, n);
              return a(P0(VL0), i, e);
            });
            var S$ = [0, Al, h$, q5, k$, U5, w$, FP, E$], TP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, g$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(TP, function(t4, n, e, i) {
              u(f(e), FL0), a(f(e), OL0, TL0);
              var x = i[1];
              function c(G) {
                return u(n, G);
              }
              function s(G) {
                return u(t4, G);
              }
              R(Ue[31], s, c, e, x), u(f(e), IL0), u(f(e), AL0), a(f(e), CL0, NL0);
              var p = i[2];
              if (p) {
                g(e, PL0);
                var y = p[1];
                a(f(e), DL0, y), g(e, LL0);
              } else
                g(e, RL0);
              u(f(e), jL0), u(f(e), GL0), a(f(e), BL0, ML0);
              var T = i[3];
              if (T) {
                g(e, qL0);
                var E = T[1], h = function(G, A) {
                  return g(G, gL0);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, UL0);
              } else
                g(e, HL0);
              return u(f(e), XL0), u(f(e), YL0);
            }), N(g$, function(t4, n, e) {
              var i = a(TP, t4, n);
              return a(P0(SL0), i, e);
            });
            var F$ = [0, TP, g$], OP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, T$ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(OP, function(t4, n, e) {
              u(f(n), mL0), a(f(n), yL0, _L0);
              var i = e[1];
              if (i) {
                g(n, dL0);
                var x = i[1], c = function(p, y) {
                  return g(p, pL0);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, hL0);
              } else
                g(n, kL0);
              return u(f(n), wL0), u(f(n), EL0);
            }), N(T$, function(t4, n) {
              var e = u(OP, t4);
              return a(P0(bL0), e, n);
            });
            var O$ = [0, OP, T$], IP = function t4(n, e) {
              return t4.fun(n, e);
            }, I$ = function t4(n) {
              return t4.fun(n);
            }, AP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, A$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, H5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, N$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(IP, function(t4, n) {
              return n ? g(t4, vL0) : g(t4, lL0);
            }), N(I$, function(t4) {
              return a(P0(sL0), IP, t4);
            }), N(AP, function(t4, n, e, i) {
              u(f(e), aL0), a(t4, e, i[1]), u(f(e), oL0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(H5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), cL0);
            }), N(A$, function(t4, n, e) {
              var i = a(AP, t4, n);
              return a(P0(xL0), i, e);
            }), N(H5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), qP0);
                  var x = i[1], c = function(d0) {
                    return u(n, d0);
                  }, s = function(d0) {
                    return u(t4, d0);
                  };
                  return R(Kv[1], s, c, e, x), u(f(e), UP0);
                case 1:
                  u(f(e), HP0);
                  var p = i[1], y = function(d0) {
                    return u(t4, d0);
                  };
                  return ir(zW[1], y, e, p), u(f(e), XP0);
                case 2:
                  u(f(e), YP0);
                  var T = i[1], E = function(d0) {
                    return u(n, d0);
                  }, h = function(d0) {
                    return u(t4, d0);
                  };
                  return R(T1[8], h, E, e, T), u(f(e), VP0);
                case 3:
                  u(f(e), zP0);
                  var w = i[1], G = function(d0) {
                    return u(t4, d0);
                  };
                  return ir(WW[1], G, e, w), u(f(e), KP0);
                case 4:
                  u(f(e), WP0);
                  var A = i[1], S = function(d0) {
                    return u(t4, d0);
                  };
                  return ir($W[1], S, e, A), u(f(e), JP0);
                case 5:
                  u(f(e), $P0);
                  var M = i[1], K = function(d0) {
                    return u(n, d0);
                  }, V = function(d0) {
                    return u(t4, d0);
                  };
                  return R(lP[1], V, K, e, M), u(f(e), ZP0);
                case 6:
                  u(f(e), QP0);
                  var f0 = i[1], m0 = function(d0) {
                    return u(n, d0);
                  }, k0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(d$[3], k0, m0, e, f0), u(f(e), rD0);
                case 7:
                  u(f(e), eD0);
                  var g0 = i[1], e0 = function(d0) {
                    return u(n, d0);
                  }, x0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(_P[1], x0, e0, e, g0), u(f(e), nD0);
                case 8:
                  u(f(e), tD0);
                  var l = i[1], c0 = function(d0) {
                    return u(n, d0);
                  }, t0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(D5[1], t0, c0, e, l), u(f(e), uD0);
                case 9:
                  u(f(e), iD0);
                  var a0 = i[1], w0 = function(d0) {
                    return u(n, d0);
                  }, _0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(u$[5], _0, w0, e, a0), u(f(e), fD0);
                case 10:
                  u(f(e), xD0);
                  var E0 = i[1], X0 = function(d0) {
                    return u(n, d0);
                  }, b = function(d0) {
                    return u(t4, d0);
                  };
                  return R(f$[1], b, X0, e, E0), u(f(e), aD0);
                case 11:
                  u(f(e), oD0);
                  var G0 = i[1], X = function(d0) {
                    return u(n, d0);
                  }, s0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(d5[1], s0, X, e, G0), u(f(e), cD0);
                case 12:
                  u(f(e), sD0);
                  var dr = i[1], Ar = function(d0) {
                    return u(n, d0);
                  }, ar = function(d0) {
                    return u(t4, d0);
                  };
                  return R(h5[1], ar, Ar, e, dr), u(f(e), vD0);
                case 13:
                  u(f(e), lD0);
                  var W0 = i[1], Lr = function(d0) {
                    return u(n, d0);
                  }, Tr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(pP[1], Tr, Lr, e, W0), u(f(e), bD0);
                case 14:
                  u(f(e), pD0);
                  var Hr = i[1], Or = function(d0) {
                    return u(n, d0);
                  }, xr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(SJ[1], xr, Or, e, Hr), u(f(e), mD0);
                case 15:
                  u(f(e), _D0);
                  var Rr = i[1], Wr = function(d0) {
                    return u(t4, d0);
                  };
                  return ir(O$[1], Wr, e, Rr), u(f(e), yD0);
                case 16:
                  u(f(e), dD0);
                  var Jr = i[1], or = function(d0) {
                    return u(n, d0);
                  }, _r = function(d0) {
                    return u(t4, d0);
                  };
                  return R(JJ[7], _r, or, e, Jr), u(f(e), hD0);
                case 17:
                  u(f(e), kD0);
                  var Ir = i[1], fe = function(d0) {
                    return u(n, d0);
                  }, v0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(m$[1], v0, fe, e, Ir), u(f(e), wD0);
                case 18:
                  u(f(e), ED0);
                  var P = i[1], L = function(d0) {
                    return u(n, d0);
                  }, Q = function(d0) {
                    return u(t4, d0);
                  };
                  return R(EP[3], Q, L, e, P), u(f(e), SD0);
                case 19:
                  u(f(e), gD0);
                  var i0 = i[1], l0 = function(d0) {
                    return u(n, d0);
                  }, S0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(F$[1], S0, l0, e, i0), u(f(e), FD0);
                case 20:
                  u(f(e), TD0);
                  var T0 = i[1], er = function(d0) {
                    return u(n, d0);
                  }, j0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(TJ[1], j0, er, e, T0), u(f(e), OD0);
                case 21:
                  u(f(e), ID0);
                  var B = i[1], Z = function(d0) {
                    return u(n, d0);
                  }, p0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(AJ[1], p0, Z, e, B), u(f(e), AD0);
                case 22:
                  u(f(e), ND0);
                  var b0 = i[1], O0 = function(d0) {
                    return u(n, d0);
                  }, q0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(PJ[1], q0, O0, e, b0), u(f(e), CD0);
                case 23:
                  u(f(e), PD0);
                  var nr = i[1], yr = function(d0) {
                    return u(n, d0);
                  }, vr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(Ps[5], vr, yr, e, nr), u(f(e), DD0);
                case 24:
                  u(f(e), LD0);
                  var $0 = i[1], Sr = function(d0) {
                    return u(n, d0);
                  }, Mr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(HW[2], Mr, Sr, e, $0), u(f(e), RD0);
                case 25:
                  u(f(e), jD0);
                  var Br = i[1], qr = function(d0) {
                    return u(n, d0);
                  }, jr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(S$[7], jr, qr, e, Br), u(f(e), GD0);
                case 26:
                  u(f(e), MD0);
                  var $r = i[1], ne = function(d0) {
                    return u(n, d0);
                  }, Qr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(D5[1], Qr, ne, e, $r), u(f(e), BD0);
                case 27:
                  u(f(e), qD0);
                  var pe = i[1], oe = function(d0) {
                    return u(n, d0);
                  }, me = function(d0) {
                    return u(t4, d0);
                  };
                  return R(YW[1], me, oe, e, pe), u(f(e), UD0);
                case 28:
                  u(f(e), HD0);
                  var ae = i[1], ce = function(d0) {
                    return u(n, d0);
                  }, ge = function(d0) {
                    return u(t4, d0);
                  };
                  return R(aJ[1], ge, ce, e, ae), u(f(e), XD0);
                case 29:
                  u(f(e), YD0);
                  var H0 = i[1], Fr = function(d0) {
                    return u(n, d0);
                  }, _ = function(d0) {
                    return u(t4, d0);
                  };
                  return R(fJ[2], _, Fr, e, H0), u(f(e), VD0);
                case 30:
                  u(f(e), zD0);
                  var k = i[1], I = function(d0) {
                    return u(n, d0);
                  }, U = function(d0) {
                    return u(t4, d0);
                  };
                  return R(cJ[1], U, I, e, k), u(f(e), KD0);
                case 31:
                  u(f(e), WD0);
                  var Y = i[1], y0 = function(d0) {
                    return u(n, d0);
                  }, D0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(pJ[2], D0, y0, e, Y), u(f(e), JD0);
                case 32:
                  u(f(e), $D0);
                  var A0 = i[1], D = function(d0) {
                    return u(n, d0);
                  }, u0 = function(d0) {
                    return u(t4, d0);
                  };
                  return R(d5[1], u0, D, e, A0), u(f(e), ZD0);
                case 33:
                  u(f(e), QD0);
                  var Y0 = i[1], J0 = function(d0) {
                    return u(n, d0);
                  }, fr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(h5[1], fr, J0, e, Y0), u(f(e), rL0);
                case 34:
                  u(f(e), eL0);
                  var Q0 = i[1], F0 = function(d0) {
                    return u(n, d0);
                  }, gr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(Il[2], gr, F0, e, Q0), u(f(e), nL0);
                case 35:
                  u(f(e), tL0);
                  var mr = i[1], Cr = function(d0) {
                    return u(n, d0);
                  }, sr = function(d0) {
                    return u(t4, d0);
                  };
                  return R(wJ[1], sr, Cr, e, mr), u(f(e), uL0);
                default:
                  u(f(e), iL0);
                  var Pr = i[1], K0 = function(d0) {
                    return u(n, d0);
                  }, Ur = function(d0) {
                    return u(t4, d0);
                  };
                  return R(QW[1], Ur, K0, e, Pr), u(f(e), fL0);
              }
            }), N(N$, function(t4, n, e) {
              var i = a(H5, t4, n);
              return a(P0(BP0), i, e);
            }), bu(l6r, Xu, [0, Kv, HW, YW, zW, WW, $W, QW, d5, h5, fJ, aJ, cJ, pJ, Il, wJ, SJ, TJ, AJ, PJ, JJ, D5, lP, pP, _P, u$, f$, EP, m$, d$, S$, F$, O$, IP, I$, AP, A$, H5, N$]);
            var NP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, C$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, X5 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, P$ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(NP, function(t4, n, e, i) {
              u(f(e), jP0), a(n, e, i[1]), u(f(e), GP0);
              var x = i[2];
              return ir(X5, function(c) {
                return u(t4, c);
              }, e, x), u(f(e), MP0);
            }), N(C$, function(t4, n, e) {
              var i = a(NP, t4, n);
              return a(P0(RP0), i, e);
            }), N(X5, function(t4, n, e) {
              u(f(n), OP0), a(f(n), AP0, IP0);
              var i = e[1];
              if (i) {
                g(n, NP0);
                var x = i[1], c = function(p, y) {
                  return g(p, TP0);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, CP0);
              } else
                g(n, PP0);
              return u(f(n), DP0), u(f(n), LP0);
            }), N(P$, function(t4, n) {
              var e = u(X5, t4);
              return a(P0(FP0), e, n);
            });
            var D$ = [0, NP, C$, X5, P$], CP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, L$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(CP, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), wP0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(Je[13], s, c, e, x), u(f(e), EP0);
              }
              u(f(e), SP0);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(D$[1], T, y, e, p), u(f(e), gP0);
            }), N(L$, function(t4, n, e) {
              var i = a(CP, t4, n);
              return a(P0(kP0), i, e);
            });
            var R$ = [0, D$, CP, L$], PP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, j$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Y5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, G$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(PP, function(t4, n, e, i) {
              u(f(e), yP0), a(t4, e, i[1]), u(f(e), dP0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Y5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), hP0);
            }), N(j$, function(t4, n, e) {
              var i = a(PP, t4, n);
              return a(P0(_P0), i, e);
            }), N(Y5, function(t4, n, e, i) {
              u(f(e), tP0), a(f(e), iP0, uP0);
              var x = i[1];
              u(f(e), fP0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), nP0);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(R$[2], G, w, e, h), 1;
              }, c, x), u(f(e), xP0), u(f(e), aP0), u(f(e), oP0), a(f(e), sP0, cP0);
              var s = i[2];
              if (s) {
                g(e, vP0);
                var p = s[1], y = function(E, h) {
                  u(f(E), rP0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), QC0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), eP0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, lP0);
              } else
                g(e, bP0);
              return u(f(e), pP0), u(f(e), mP0);
            }), N(G$, function(t4, n, e) {
              var i = a(Y5, t4, n);
              return a(P0(ZC0), i, e);
            });
            var DP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, M$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, V5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, B$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Uee = [0, PP, j$, Y5, G$];
            N(DP, function(t4, n, e, i) {
              u(f(e), WC0), a(t4, e, i[1]), u(f(e), JC0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(V5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), $C0);
            }), N(M$, function(t4, n, e) {
              var i = a(DP, t4, n);
              return a(P0(KC0), i, e);
            }), N(V5, function(t4, n, e, i) {
              u(f(e), RC0), a(f(e), GC0, jC0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), MC0), u(f(e), BC0), a(f(e), UC0, qC0);
              var p = i[2];
              if (p) {
                g(e, HC0);
                var y = p[1], T = function(h, w) {
                  return g(h, LC0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, XC0);
              } else
                g(e, YC0);
              return u(f(e), VC0), u(f(e), zC0);
            }), N(B$, function(t4, n, e) {
              var i = a(V5, t4, n);
              return a(P0(DC0), i, e);
            });
            var LP = [0, DP, M$, V5, B$], z5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, q$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(z5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), OC0);
                  var x = i[1], c = function(E) {
                    return u(n, E);
                  }, s = function(E) {
                    return u(t4, E);
                  };
                  return R(Ue[31], s, c, e, x), u(f(e), IC0);
                case 1:
                  u(f(e), AC0);
                  var p = i[1], y = function(E) {
                    return u(n, E);
                  }, T = function(E) {
                    return u(t4, E);
                  };
                  return R(LP[1], T, y, e, p), u(f(e), NC0);
                default:
                  return u(f(e), CC0), a(t4, e, i[1]), u(f(e), PC0);
              }
            }), N(q$, function(t4, n, e) {
              var i = a(z5, t4, n);
              return a(P0(TC0), i, e);
            });
            var RP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, U$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(RP, function(t4, n, e, i) {
              u(f(e), lC0), a(f(e), pC0, bC0);
              var x = i[1];
              u(f(e), mC0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), vC0);
                function w(G) {
                  return u(n, G);
                }
                return R(z5, function(G) {
                  return u(t4, G);
                }, w, e, h), 1;
              }, c, x), u(f(e), _C0), u(f(e), yC0), u(f(e), dC0), a(f(e), kC0, hC0);
              var s = i[2];
              if (s) {
                g(e, wC0);
                var p = s[1], y = function(E, h) {
                  u(f(E), cC0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), oC0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), sC0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, EC0);
              } else
                g(e, SC0);
              return u(f(e), gC0), u(f(e), FC0);
            }), N(U$, function(t4, n, e) {
              var i = a(RP, t4, n);
              return a(P0(aC0), i, e);
            });
            var H$ = [0, z5, q$, RP, U$], K5 = function t4(n, e) {
              return t4.fun(n, e);
            }, X$ = function t4(n) {
              return t4.fun(n);
            }, jP = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Y$ = function t4(n, e) {
              return t4.fun(n, e);
            }, W5 = function t4(n, e) {
              return t4.fun(n, e);
            }, V$ = function t4(n) {
              return t4.fun(n);
            };
            N(K5, function(t4, n) {
              u(f(t4), $N0), a(f(t4), QN0, ZN0);
              var e = n[1];
              a(f(t4), rC0, e), u(f(t4), eC0), u(f(t4), nC0), a(f(t4), uC0, tC0);
              var i = n[2];
              return a(f(t4), iC0, i), u(f(t4), fC0), u(f(t4), xC0);
            }), N(X$, function(t4) {
              return a(P0(JN0), K5, t4);
            }), N(jP, function(t4, n, e) {
              return u(f(n), zN0), a(t4, n, e[1]), u(f(n), KN0), a(W5, n, e[2]), u(f(n), WN0);
            }), N(Y$, function(t4, n) {
              var e = u(jP, t4);
              return a(P0(VN0), e, n);
            }), N(W5, function(t4, n) {
              u(f(t4), RN0), a(f(t4), GN0, jN0), a(K5, t4, n[1]), u(f(t4), MN0), u(f(t4), BN0), a(f(t4), UN0, qN0);
              var e = n[2];
              return a(f(t4), HN0, e), u(f(t4), XN0), u(f(t4), YN0);
            }), N(V$, function(t4) {
              return a(P0(LN0), W5, t4);
            });
            var z$ = [0, K5, X$, jP, Y$, W5, V$], GP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, K$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(GP, function(t4, n, e, i) {
              u(f(e), pN0), a(f(e), _N0, mN0);
              var x = i[1];
              u(f(e), yN0);
              var c = 0;
              be(function(w, G) {
                w && u(f(e), bN0);
                function A(S) {
                  return u(t4, S);
                }
                return ir(z$[3], A, e, G), 1;
              }, c, x), u(f(e), dN0), u(f(e), hN0), u(f(e), kN0), a(f(e), EN0, wN0);
              var s = i[2];
              u(f(e), SN0);
              var p = 0;
              be(function(w, G) {
                w && u(f(e), lN0);
                function A(M) {
                  return u(n, M);
                }
                function S(M) {
                  return u(t4, M);
                }
                return R(Ue[31], S, A, e, G), 1;
              }, p, s), u(f(e), gN0), u(f(e), FN0), u(f(e), TN0), a(f(e), IN0, ON0);
              var y = i[3];
              if (y) {
                g(e, AN0);
                var T = y[1], E = function(w, G) {
                  return g(w, vN0);
                }, h = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], h, E, e, T), g(e, NN0);
              } else
                g(e, CN0);
              return u(f(e), PN0), u(f(e), DN0);
            }), N(K$, function(t4, n, e) {
              var i = a(GP, t4, n);
              return a(P0(sN0), i, e);
            });
            var MP = [0, z$, GP, K$], BP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, W$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(BP, function(t4, n, e, i) {
              u(f(e), VA0), a(f(e), KA0, zA0);
              var x = i[1];
              function c(S) {
                return u(n, S);
              }
              function s(S) {
                return u(t4, S);
              }
              R(Ue[31], s, c, e, x), u(f(e), WA0), u(f(e), JA0), a(f(e), ZA0, $A0);
              var p = i[2];
              u(f(e), QA0), a(t4, e, p[1]), u(f(e), rN0);
              var y = p[2];
              function T(S) {
                return u(n, S);
              }
              function E(S) {
                return u(t4, S);
              }
              R(MP[2], E, T, e, y), u(f(e), eN0), u(f(e), nN0), u(f(e), tN0), a(f(e), iN0, uN0);
              var h = i[3];
              if (h) {
                g(e, fN0);
                var w = h[1], G = function(S, M) {
                  return g(S, YA0);
                }, A = function(S) {
                  return u(t4, S);
                };
                R(Dr[1], A, G, e, w), g(e, xN0);
              } else
                g(e, aN0);
              return u(f(e), oN0), u(f(e), cN0);
            }), N(W$, function(t4, n, e) {
              var i = a(BP, t4, n);
              return a(P0(XA0), i, e);
            });
            var J$ = [0, BP, W$], O1 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, $$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, qP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, Z$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, J5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, Q$ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(O1, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  var x = i[1];
                  u(f(e), PA0), u(f(e), DA0), a(n, e, x[1]), u(f(e), LA0);
                  var c = x[2], s = function(S) {
                    return u(t4, S);
                  };
                  return ir(Tl[2], s, e, c), u(f(e), RA0), u(f(e), jA0);
                case 1:
                  u(f(e), GA0);
                  var p = i[1], y = function(S) {
                    return u(n, S);
                  }, T = function(S) {
                    return u(t4, S);
                  };
                  return R(jn[1], T, y, e, p), u(f(e), MA0);
                case 2:
                  u(f(e), BA0);
                  var E = i[1], h = function(S) {
                    return u(t4, S);
                  };
                  return ir(qp[1], h, e, E), u(f(e), qA0);
                default:
                  u(f(e), UA0);
                  var w = i[1], G = function(S) {
                    return u(n, S);
                  }, A = function(S) {
                    return u(t4, S);
                  };
                  return R(Up[1], A, G, e, w), u(f(e), HA0);
              }
            }), N($$, function(t4, n, e) {
              var i = a(O1, t4, n);
              return a(P0(CA0), i, e);
            }), N(qP, function(t4, n, e, i) {
              u(f(e), IA0), a(t4, e, i[1]), u(f(e), AA0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(J5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), NA0);
            }), N(Z$, function(t4, n, e) {
              var i = a(qP, t4, n);
              return a(P0(OA0), i, e);
            }), N(J5, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), yI0), a(f(e), hI0, dI0);
                  var x = i[1], c = function(s0) {
                    return u(n, s0);
                  };
                  R(O1, function(s0) {
                    return u(t4, s0);
                  }, c, e, x), u(f(e), kI0), u(f(e), wI0), a(f(e), SI0, EI0);
                  var s = i[2], p = function(s0) {
                    return u(n, s0);
                  }, y = function(s0) {
                    return u(t4, s0);
                  };
                  R(Ue[31], y, p, e, s), u(f(e), gI0), u(f(e), FI0), a(f(e), OI0, TI0);
                  var T = i[3];
                  return a(f(e), II0, T), u(f(e), AI0), u(f(e), NI0);
                case 1:
                  var E = i[2];
                  u(f(e), CI0), a(f(e), DI0, PI0);
                  var h = i[1], w = function(s0) {
                    return u(n, s0);
                  };
                  R(O1, function(s0) {
                    return u(t4, s0);
                  }, w, e, h), u(f(e), LI0), u(f(e), RI0), a(f(e), GI0, jI0), u(f(e), MI0), a(t4, e, E[1]), u(f(e), BI0);
                  var G = E[2], A = function(s0) {
                    return u(n, s0);
                  }, S = function(s0) {
                    return u(t4, s0);
                  };
                  return R(Ps[5], S, A, e, G), u(f(e), qI0), u(f(e), UI0), u(f(e), HI0);
                case 2:
                  var M = i[3], K = i[2];
                  u(f(e), XI0), a(f(e), VI0, YI0);
                  var V = i[1], f0 = function(s0) {
                    return u(n, s0);
                  };
                  R(O1, function(s0) {
                    return u(t4, s0);
                  }, f0, e, V), u(f(e), zI0), u(f(e), KI0), a(f(e), JI0, WI0), u(f(e), $I0), a(t4, e, K[1]), u(f(e), ZI0);
                  var m0 = K[2], k0 = function(s0) {
                    return u(n, s0);
                  }, g0 = function(s0) {
                    return u(t4, s0);
                  };
                  if (R(Ps[5], g0, k0, e, m0), u(f(e), QI0), u(f(e), rA0), u(f(e), eA0), a(f(e), tA0, nA0), M) {
                    g(e, uA0);
                    var e0 = M[1], x0 = function(s0, dr) {
                      return g(s0, _I0);
                    }, l = function(s0) {
                      return u(t4, s0);
                    };
                    R(Dr[1], l, x0, e, e0), g(e, iA0);
                  } else
                    g(e, fA0);
                  return u(f(e), xA0), u(f(e), aA0);
                default:
                  var c0 = i[3], t0 = i[2];
                  u(f(e), oA0), a(f(e), sA0, cA0);
                  var a0 = i[1], w0 = function(s0) {
                    return u(n, s0);
                  };
                  R(O1, function(s0) {
                    return u(t4, s0);
                  }, w0, e, a0), u(f(e), vA0), u(f(e), lA0), a(f(e), pA0, bA0), u(f(e), mA0), a(t4, e, t0[1]), u(f(e), _A0);
                  var _0 = t0[2], E0 = function(s0) {
                    return u(n, s0);
                  }, X0 = function(s0) {
                    return u(t4, s0);
                  };
                  if (R(Ps[5], X0, E0, e, _0), u(f(e), yA0), u(f(e), dA0), u(f(e), hA0), a(f(e), wA0, kA0), c0) {
                    g(e, EA0);
                    var b = c0[1], G0 = function(s0, dr) {
                      return g(s0, mI0);
                    }, X = function(s0) {
                      return u(t4, s0);
                    };
                    R(Dr[1], X, G0, e, b), g(e, SA0);
                  } else
                    g(e, gA0);
                  return u(f(e), FA0), u(f(e), TA0);
              }
            }), N(Q$, function(t4, n, e) {
              var i = a(J5, t4, n);
              return a(P0(pI0), i, e);
            });
            var rZ = [0, O1, $$, qP, Z$, J5, Q$], UP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, eZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, $5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, nZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(UP, function(t4, n, e, i) {
              u(f(e), vI0), a(t4, e, i[1]), u(f(e), lI0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R($5, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), bI0);
            }), N(eZ, function(t4, n, e) {
              var i = a(UP, t4, n);
              return a(P0(sI0), i, e);
            }), N($5, function(t4, n, e, i) {
              u(f(e), QO0), a(f(e), eI0, rI0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), nI0), u(f(e), tI0), a(f(e), iI0, uI0);
              var p = i[2];
              if (p) {
                g(e, fI0);
                var y = p[1], T = function(h, w) {
                  return g(h, ZO0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, xI0);
              } else
                g(e, aI0);
              return u(f(e), oI0), u(f(e), cI0);
            }), N(nZ, function(t4, n, e) {
              var i = a($5, t4, n);
              return a(P0($O0), i, e);
            });
            var tZ = [0, UP, eZ, $5, nZ], Z5 = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, uZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, HP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, iZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Z5, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), zO0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(rZ[3], s, c, e, x), u(f(e), KO0);
              }
              u(f(e), WO0);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(tZ[1], T, y, e, p), u(f(e), JO0);
            }), N(uZ, function(t4, n, e) {
              var i = a(Z5, t4, n);
              return a(P0(VO0), i, e);
            }), N(HP, function(t4, n, e, i) {
              u(f(e), CO0), a(f(e), DO0, PO0);
              var x = i[1];
              u(f(e), LO0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), NO0);
                function w(G) {
                  return u(n, G);
                }
                return R(Z5, function(G) {
                  return u(t4, G);
                }, w, e, h), 1;
              }, c, x), u(f(e), RO0), u(f(e), jO0), u(f(e), GO0), a(f(e), BO0, MO0);
              var s = i[2];
              if (s) {
                g(e, qO0);
                var p = s[1], y = function(E, h) {
                  u(f(E), IO0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), OO0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), AO0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, UO0);
              } else
                g(e, HO0);
              return u(f(e), XO0), u(f(e), YO0);
            }), N(iZ, function(t4, n, e) {
              var i = a(HP, t4, n);
              return a(P0(TO0), i, e);
            });
            var fZ = [0, rZ, tZ, Z5, uZ, HP, iZ], XP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, xZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(XP, function(t4, n, e, i) {
              u(f(e), lO0), a(f(e), pO0, bO0);
              var x = i[1];
              u(f(e), mO0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), vO0);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(Ue[31], G, w, e, h), 1;
              }, c, x), u(f(e), _O0), u(f(e), yO0), u(f(e), dO0), a(f(e), kO0, hO0);
              var s = i[2];
              if (s) {
                g(e, wO0);
                var p = s[1], y = function(E, h) {
                  return g(E, sO0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, EO0);
              } else
                g(e, SO0);
              return u(f(e), gO0), u(f(e), FO0);
            }), N(xZ, function(t4, n, e) {
              var i = a(XP, t4, n);
              return a(P0(cO0), i, e);
            });
            var aZ = [0, XP, xZ], Q5 = function t4(n, e) {
              return t4.fun(n, e);
            }, oZ = function t4(n) {
              return t4.fun(n);
            }, YP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, cZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Q5, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, nO0);
                case 1:
                  return g(t4, tO0);
                case 2:
                  return g(t4, uO0);
                case 3:
                  return g(t4, iO0);
                case 4:
                  return g(t4, fO0);
                case 5:
                  return g(t4, xO0);
                case 6:
                  return g(t4, aO0);
                default:
                  return g(t4, oO0);
              }
            }), N(oZ, function(t4) {
              return a(P0(eO0), Q5, t4);
            }), N(YP, function(t4, n, e, i) {
              u(f(e), MT0), a(f(e), qT0, BT0), a(Q5, e, i[1]), u(f(e), UT0), u(f(e), HT0), a(f(e), YT0, XT0);
              var x = i[2];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), VT0), u(f(e), zT0), a(f(e), WT0, KT0);
              var p = i[3];
              if (p) {
                g(e, JT0);
                var y = p[1], T = function(h, w) {
                  return g(h, GT0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, $T0);
              } else
                g(e, ZT0);
              return u(f(e), QT0), u(f(e), rO0);
            }), N(cZ, function(t4, n, e) {
              var i = a(YP, t4, n);
              return a(P0(jT0), i, e);
            });
            var sZ = [0, Q5, oZ, YP, cZ], rm = function t4(n, e) {
              return t4.fun(n, e);
            }, vZ = function t4(n) {
              return t4.fun(n);
            }, VP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, lZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(rm, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, pT0);
                case 1:
                  return g(t4, mT0);
                case 2:
                  return g(t4, _T0);
                case 3:
                  return g(t4, yT0);
                case 4:
                  return g(t4, dT0);
                case 5:
                  return g(t4, hT0);
                case 6:
                  return g(t4, kT0);
                case 7:
                  return g(t4, wT0);
                case 8:
                  return g(t4, ET0);
                case 9:
                  return g(t4, ST0);
                case 10:
                  return g(t4, gT0);
                case 11:
                  return g(t4, FT0);
                case 12:
                  return g(t4, TT0);
                case 13:
                  return g(t4, OT0);
                case 14:
                  return g(t4, IT0);
                case 15:
                  return g(t4, AT0);
                case 16:
                  return g(t4, NT0);
                case 17:
                  return g(t4, CT0);
                case 18:
                  return g(t4, PT0);
                case 19:
                  return g(t4, DT0);
                case 20:
                  return g(t4, LT0);
                default:
                  return g(t4, RT0);
              }
            }), N(vZ, function(t4) {
              return a(P0(bT0), rm, t4);
            }), N(VP, function(t4, n, e, i) {
              u(f(e), KF0), a(f(e), JF0, WF0), a(rm, e, i[1]), u(f(e), $F0), u(f(e), ZF0), a(f(e), rT0, QF0);
              var x = i[2];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Ue[31], s, c, e, x), u(f(e), eT0), u(f(e), nT0), a(f(e), uT0, tT0);
              var p = i[3];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Ue[31], T, y, e, p), u(f(e), iT0), u(f(e), fT0), a(f(e), aT0, xT0);
              var E = i[4];
              if (E) {
                g(e, oT0);
                var h = E[1], w = function(A, S) {
                  return g(A, zF0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, cT0);
              } else
                g(e, sT0);
              return u(f(e), vT0), u(f(e), lT0);
            }), N(lZ, function(t4, n, e) {
              var i = a(VP, t4, n);
              return a(P0(VF0), i, e);
            });
            var bZ = [0, rm, vZ, VP, lZ], em = function t4(n, e) {
              return t4.fun(n, e);
            }, pZ = function t4(n) {
              return t4.fun(n);
            }, zP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, mZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(em, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, NF0);
                case 1:
                  return g(t4, CF0);
                case 2:
                  return g(t4, PF0);
                case 3:
                  return g(t4, DF0);
                case 4:
                  return g(t4, LF0);
                case 5:
                  return g(t4, RF0);
                case 6:
                  return g(t4, jF0);
                case 7:
                  return g(t4, GF0);
                case 8:
                  return g(t4, MF0);
                case 9:
                  return g(t4, BF0);
                case 10:
                  return g(t4, qF0);
                case 11:
                  return g(t4, UF0);
                case 12:
                  return g(t4, HF0);
                case 13:
                  return g(t4, XF0);
                default:
                  return g(t4, YF0);
              }
            }), N(pZ, function(t4) {
              return a(P0(AF0), em, t4);
            }), N(zP, function(t4, n, e, i) {
              u(f(e), xF0), a(f(e), oF0, aF0);
              var x = i[1];
              x ? (g(e, cF0), a(em, e, x[1]), g(e, sF0)) : g(e, vF0), u(f(e), lF0), u(f(e), bF0), a(f(e), mF0, pF0);
              var c = i[2];
              function s(S) {
                return u(n, S);
              }
              function p(S) {
                return u(t4, S);
              }
              R(hi[5], p, s, e, c), u(f(e), _F0), u(f(e), yF0), a(f(e), hF0, dF0);
              var y = i[3];
              function T(S) {
                return u(n, S);
              }
              function E(S) {
                return u(t4, S);
              }
              R(Ue[31], E, T, e, y), u(f(e), kF0), u(f(e), wF0), a(f(e), SF0, EF0);
              var h = i[4];
              if (h) {
                g(e, gF0);
                var w = h[1], G = function(S, M) {
                  return g(S, fF0);
                }, A = function(S) {
                  return u(t4, S);
                };
                R(Dr[1], A, G, e, w), g(e, FF0);
              } else
                g(e, TF0);
              return u(f(e), OF0), u(f(e), IF0);
            }), N(mZ, function(t4, n, e) {
              var i = a(zP, t4, n);
              return a(P0(iF0), i, e);
            });
            var _Z = [0, em, pZ, zP, mZ], nm = function t4(n, e) {
              return t4.fun(n, e);
            }, yZ = function t4(n) {
              return t4.fun(n);
            }, KP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, dZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(nm, function(t4, n) {
              return n ? g(t4, tF0) : g(t4, uF0);
            }), N(yZ, function(t4) {
              return a(P0(nF0), nm, t4);
            }), N(KP, function(t4, n, e, i) {
              u(f(e), Lg0), a(f(e), jg0, Rg0), a(nm, e, i[1]), u(f(e), Gg0), u(f(e), Mg0), a(f(e), qg0, Bg0);
              var x = i[2];
              function c(w) {
                return u(n, w);
              }
              function s(w) {
                return u(t4, w);
              }
              R(Ue[31], s, c, e, x), u(f(e), Ug0), u(f(e), Hg0), a(f(e), Yg0, Xg0);
              var p = i[3];
              a(f(e), Vg0, p), u(f(e), zg0), u(f(e), Kg0), a(f(e), Jg0, Wg0);
              var y = i[4];
              if (y) {
                g(e, $g0);
                var T = y[1], E = function(w, G) {
                  return g(w, Dg0);
                }, h = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], h, E, e, T), g(e, Zg0);
              } else
                g(e, Qg0);
              return u(f(e), rF0), u(f(e), eF0);
            }), N(dZ, function(t4, n, e) {
              var i = a(KP, t4, n);
              return a(P0(Pg0), i, e);
            });
            var hZ = [0, nm, yZ, KP, dZ], tm = function t4(n, e) {
              return t4.fun(n, e);
            }, kZ = function t4(n) {
              return t4.fun(n);
            }, WP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, wZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(tm, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, Ag0);
                case 1:
                  return g(t4, Ng0);
                default:
                  return g(t4, Cg0);
              }
            }), N(kZ, function(t4) {
              return a(P0(Ig0), tm, t4);
            }), N(WP, function(t4, n, e, i) {
              u(f(e), og0), a(f(e), sg0, cg0), a(tm, e, i[1]), u(f(e), vg0), u(f(e), lg0), a(f(e), pg0, bg0);
              var x = i[2];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Ue[31], s, c, e, x), u(f(e), mg0), u(f(e), _g0), a(f(e), dg0, yg0);
              var p = i[3];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Ue[31], T, y, e, p), u(f(e), hg0), u(f(e), kg0), a(f(e), Eg0, wg0);
              var E = i[4];
              if (E) {
                g(e, Sg0);
                var h = E[1], w = function(A, S) {
                  return g(A, ag0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, gg0);
              } else
                g(e, Fg0);
              return u(f(e), Tg0), u(f(e), Og0);
            }), N(wZ, function(t4, n, e) {
              var i = a(WP, t4, n);
              return a(P0(xg0), i, e);
            });
            var EZ = [0, tm, kZ, WP, wZ], JP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, SZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(JP, function(t4, n, e, i) {
              u(f(e), qS0), a(f(e), HS0, US0);
              var x = i[1];
              function c(K) {
                return u(n, K);
              }
              function s(K) {
                return u(t4, K);
              }
              R(Ue[31], s, c, e, x), u(f(e), XS0), u(f(e), YS0), a(f(e), zS0, VS0);
              var p = i[2];
              function y(K) {
                return u(n, K);
              }
              function T(K) {
                return u(t4, K);
              }
              R(Ue[31], T, y, e, p), u(f(e), KS0), u(f(e), WS0), a(f(e), $S0, JS0);
              var E = i[3];
              function h(K) {
                return u(n, K);
              }
              function w(K) {
                return u(t4, K);
              }
              R(Ue[31], w, h, e, E), u(f(e), ZS0), u(f(e), QS0), a(f(e), eg0, rg0);
              var G = i[4];
              if (G) {
                g(e, ng0);
                var A = G[1], S = function(K, V) {
                  return g(K, BS0);
                }, M = function(K) {
                  return u(t4, K);
                };
                R(Dr[1], M, S, e, A), g(e, tg0);
              } else
                g(e, ug0);
              return u(f(e), ig0), u(f(e), fg0);
            }), N(SZ, function(t4, n, e) {
              var i = a(JP, t4, n);
              return a(P0(MS0), i, e);
            });
            var gZ = [0, JP, SZ], um = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, FZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(um, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), LS0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(Ue[31], s, c, e, x), u(f(e), RS0);
              }
              u(f(e), jS0);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(LP[1], T, y, e, p), u(f(e), GS0);
            }), N(FZ, function(t4, n, e) {
              var i = a(um, t4, n);
              return a(P0(DS0), i, e);
            });
            var $P = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, TZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, im = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, OZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N($P, function(t4, n, e, i) {
              u(f(e), NS0), a(t4, e, i[1]), u(f(e), CS0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(im, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), PS0);
            }), N(TZ, function(t4, n, e) {
              var i = a($P, t4, n);
              return a(P0(AS0), i, e);
            }), N(im, function(t4, n, e, i) {
              u(f(e), mS0), a(f(e), yS0, _S0);
              var x = i[1];
              u(f(e), dS0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), pS0);
                function w(G) {
                  return u(n, G);
                }
                return R(um, function(G) {
                  return u(t4, G);
                }, w, e, h), 1;
              }, c, x), u(f(e), hS0), u(f(e), kS0), u(f(e), wS0), a(f(e), SS0, ES0);
              var s = i[2];
              if (s) {
                g(e, gS0);
                var p = s[1], y = function(E, h) {
                  u(f(E), lS0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), vS0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), bS0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, FS0);
              } else
                g(e, TS0);
              return u(f(e), OS0), u(f(e), IS0);
            }), N(OZ, function(t4, n, e) {
              var i = a(im, t4, n);
              return a(P0(sS0), i, e);
            });
            var ZP = [0, $P, TZ, im, OZ], QP = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, IZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(QP, function(t4, n, e, i) {
              u(f(e), ME0), a(f(e), qE0, BE0);
              var x = i[1];
              function c(f0) {
                return u(n, f0);
              }
              function s(f0) {
                return u(t4, f0);
              }
              R(Ue[31], s, c, e, x), u(f(e), UE0), u(f(e), HE0), a(f(e), YE0, XE0);
              var p = i[2];
              if (p) {
                g(e, VE0);
                var y = p[1], T = function(f0) {
                  return u(n, f0);
                }, E = function(f0) {
                  return u(t4, f0);
                };
                R(Ue[2][1], E, T, e, y), g(e, zE0);
              } else
                g(e, KE0);
              u(f(e), WE0), u(f(e), JE0), a(f(e), ZE0, $E0);
              var h = i[3];
              if (h) {
                g(e, QE0);
                var w = h[1], G = function(f0) {
                  return u(n, f0);
                }, A = function(f0) {
                  return u(t4, f0);
                };
                R(ZP[1], A, G, e, w), g(e, rS0);
              } else
                g(e, eS0);
              u(f(e), nS0), u(f(e), tS0), a(f(e), iS0, uS0);
              var S = i[4];
              if (S) {
                g(e, fS0);
                var M = S[1], K = function(f0, m0) {
                  return g(f0, GE0);
                }, V = function(f0) {
                  return u(t4, f0);
                };
                R(Dr[1], V, K, e, M), g(e, xS0);
              } else
                g(e, aS0);
              return u(f(e), oS0), u(f(e), cS0);
            }), N(IZ, function(t4, n, e) {
              var i = a(QP, t4, n);
              return a(P0(jE0), i, e);
            });
            var AZ = [0, QP, IZ], rD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, NZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(rD, function(t4, n, e, i) {
              u(f(e), bE0), a(f(e), mE0, pE0);
              var x = i[1];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(Ue[31], s, c, e, x), u(f(e), _E0), u(f(e), yE0), a(f(e), hE0, dE0);
              var p = i[2];
              if (p) {
                g(e, kE0);
                var y = p[1], T = function(V) {
                  return u(n, V);
                }, E = function(V) {
                  return u(t4, V);
                };
                R(Ue[2][1], E, T, e, y), g(e, wE0);
              } else
                g(e, EE0);
              u(f(e), SE0), u(f(e), gE0), a(f(e), TE0, FE0);
              var h = i[3];
              function w(V) {
                return u(n, V);
              }
              function G(V) {
                return u(t4, V);
              }
              R(ZP[1], G, w, e, h), u(f(e), OE0), u(f(e), IE0), a(f(e), NE0, AE0);
              var A = i[4];
              if (A) {
                g(e, CE0);
                var S = A[1], M = function(V, f0) {
                  return g(V, lE0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, PE0);
              } else
                g(e, DE0);
              return u(f(e), LE0), u(f(e), RE0);
            }), N(NZ, function(t4, n, e) {
              var i = a(rD, t4, n);
              return a(P0(vE0), i, e);
            });
            var eD = [0, rD, NZ], nD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, CZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(nD, function(t4, n, e, i) {
              u(f(e), Zw0), a(f(e), rE0, Qw0);
              var x = i[1];
              function c(y) {
                return u(n, y);
              }
              function s(y) {
                return u(t4, y);
              }
              R(eD[1], s, c, e, x), u(f(e), eE0), u(f(e), nE0), a(f(e), uE0, tE0), a(n, e, i[2]), u(f(e), iE0), u(f(e), fE0), a(f(e), aE0, xE0);
              var p = i[3];
              return a(f(e), oE0, p), u(f(e), cE0), u(f(e), sE0);
            }), N(CZ, function(t4, n, e) {
              var i = a(nD, t4, n);
              return a(P0($w0), i, e);
            });
            var PZ = [0, nD, CZ], fm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, DZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, tD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, LZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(fm, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), Yw0);
                  var x = i[1], c = function(w) {
                    return u(n, w);
                  }, s = function(w) {
                    return u(t4, w);
                  };
                  return R(jn[1], s, c, e, x), u(f(e), Vw0);
                case 1:
                  u(f(e), zw0);
                  var p = i[1], y = function(w) {
                    return u(t4, w);
                  };
                  return ir(qp[1], y, e, p), u(f(e), Kw0);
                default:
                  u(f(e), Ww0);
                  var T = i[1], E = function(w) {
                    return u(n, w);
                  }, h = function(w) {
                    return u(t4, w);
                  };
                  return R(Ue[31], h, E, e, T), u(f(e), Jw0);
              }
            }), N(DZ, function(t4, n, e) {
              var i = a(fm, t4, n);
              return a(P0(Xw0), i, e);
            }), N(tD, function(t4, n, e, i) {
              u(f(e), Ow0), a(f(e), Aw0, Iw0);
              var x = i[1];
              function c(G) {
                return u(n, G);
              }
              function s(G) {
                return u(t4, G);
              }
              R(Ue[31], s, c, e, x), u(f(e), Nw0), u(f(e), Cw0), a(f(e), Dw0, Pw0);
              var p = i[2];
              function y(G) {
                return u(n, G);
              }
              R(fm, function(G) {
                return u(t4, G);
              }, y, e, p), u(f(e), Lw0), u(f(e), Rw0), a(f(e), Gw0, jw0);
              var T = i[3];
              if (T) {
                g(e, Mw0);
                var E = T[1], h = function(G, A) {
                  return g(G, Tw0);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, Bw0);
              } else
                g(e, qw0);
              return u(f(e), Uw0), u(f(e), Hw0);
            }), N(LZ, function(t4, n, e) {
              var i = a(tD, t4, n);
              return a(P0(Fw0), i, e);
            });
            var uD = [0, fm, DZ, tD, LZ], iD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, RZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(iD, function(t4, n, e, i) {
              u(f(e), vw0), a(f(e), bw0, lw0);
              var x = i[1];
              function c(y) {
                return u(n, y);
              }
              function s(y) {
                return u(t4, y);
              }
              R(uD[3], s, c, e, x), u(f(e), pw0), u(f(e), mw0), a(f(e), yw0, _w0), a(n, e, i[2]), u(f(e), dw0), u(f(e), hw0), a(f(e), ww0, kw0);
              var p = i[3];
              return a(f(e), Ew0, p), u(f(e), Sw0), u(f(e), gw0);
            }), N(RZ, function(t4, n, e) {
              var i = a(iD, t4, n);
              return a(P0(sw0), i, e);
            });
            var jZ = [0, iD, RZ], fD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, GZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(fD, function(t4, n, e, i) {
              u(f(e), qk0), a(f(e), Hk0, Uk0);
              var x = i[1];
              if (x) {
                g(e, Xk0);
                var c = x[1], s = function(G) {
                  return u(n, G);
                }, p = function(G) {
                  return u(t4, G);
                };
                R(Ue[31], p, s, e, c), g(e, Yk0);
              } else
                g(e, Vk0);
              u(f(e), zk0), u(f(e), Kk0), a(f(e), Jk0, Wk0);
              var y = i[2];
              if (y) {
                g(e, $k0);
                var T = y[1], E = function(G, A) {
                  return g(G, Bk0);
                }, h = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], h, E, e, T), g(e, Zk0);
              } else
                g(e, Qk0);
              u(f(e), rw0), u(f(e), ew0), a(f(e), tw0, nw0);
              var w = i[3];
              return a(f(e), uw0, w), u(f(e), iw0), u(f(e), fw0), a(f(e), aw0, xw0), a(n, e, i[4]), u(f(e), ow0), u(f(e), cw0);
            }), N(GZ, function(t4, n, e) {
              var i = a(fD, t4, n);
              return a(P0(Mk0), i, e);
            });
            var MZ = [0, fD, GZ], xD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, BZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, xm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, qZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(xD, function(t4, n, e, i) {
              u(f(e), Rk0), a(t4, e, i[1]), u(f(e), jk0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(xm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Gk0);
            }), N(BZ, function(t4, n, e) {
              var i = a(xD, t4, n);
              return a(P0(Lk0), i, e);
            }), N(xm, function(t4, n, e, i) {
              u(f(e), kk0), a(f(e), Ek0, wk0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), Sk0), u(f(e), gk0), a(f(e), Tk0, Fk0);
              var p = i[2];
              function y(h) {
                return u(n, h);
              }
              function T(h) {
                return u(t4, h);
              }
              R(Ue[31], T, y, e, p), u(f(e), Ok0), u(f(e), Ik0), a(f(e), Nk0, Ak0);
              var E = i[3];
              return a(f(e), Ck0, E), u(f(e), Pk0), u(f(e), Dk0);
            }), N(qZ, function(t4, n, e) {
              var i = a(xm, t4, n);
              return a(P0(hk0), i, e);
            });
            var UZ = [0, xD, BZ, xm, qZ], aD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, HZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(aD, function(t4, n, e, i) {
              u(f(e), fk0), a(f(e), ak0, xk0);
              var x = i[1];
              u(f(e), ok0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), ik0);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(UZ[1], G, w, e, h), 1;
              }, c, x), u(f(e), ck0), u(f(e), sk0), u(f(e), vk0), a(f(e), bk0, lk0);
              var s = i[2];
              if (s) {
                g(e, pk0);
                var p = s[1], y = function(E) {
                  return u(n, E);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Ue[31], T, y, e, p), g(e, mk0);
              } else
                g(e, _k0);
              return u(f(e), yk0), u(f(e), dk0);
            }), N(HZ, function(t4, n, e) {
              var i = a(aD, t4, n);
              return a(P0(uk0), i, e);
            });
            var oD = [0, UZ, aD, HZ], cD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, XZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(cD, function(t4, n, e, i) {
              u(f(e), Xh0), a(f(e), Vh0, Yh0);
              var x = i[1];
              u(f(e), zh0);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), Hh0);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(oD[1][1], G, w, e, h), 1;
              }, c, x), u(f(e), Kh0), u(f(e), Wh0), u(f(e), Jh0), a(f(e), Zh0, $h0);
              var s = i[2];
              if (s) {
                g(e, Qh0);
                var p = s[1], y = function(E) {
                  return u(n, E);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Ue[31], T, y, e, p), g(e, rk0);
              } else
                g(e, ek0);
              return u(f(e), nk0), u(f(e), tk0);
            }), N(XZ, function(t4, n, e) {
              var i = a(cD, t4, n);
              return a(P0(Uh0), i, e);
            });
            var YZ = [0, cD, XZ], sD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, VZ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(sD, function(t4, n, e, i) {
              u(f(e), Fh0), a(f(e), Oh0, Th0);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              function s(A) {
                return u(t4, A);
              }
              R(Ue[31], s, c, e, x), u(f(e), Ih0), u(f(e), Ah0), a(f(e), Ch0, Nh0);
              var p = i[2];
              function y(A) {
                return u(n, A);
              }
              function T(A) {
                return u(t4, A);
              }
              R(Je[17], T, y, e, p), u(f(e), Ph0), u(f(e), Dh0), a(f(e), Rh0, Lh0);
              var E = i[3];
              if (E) {
                g(e, jh0);
                var h = E[1], w = function(A, S) {
                  return g(A, gh0);
                }, G = function(A) {
                  return u(t4, A);
                };
                R(Dr[1], G, w, e, h), g(e, Gh0);
              } else
                g(e, Mh0);
              return u(f(e), Bh0), u(f(e), qh0);
            }), N(VZ, function(t4, n, e) {
              var i = a(sD, t4, n);
              return a(P0(Sh0), i, e);
            });
            var zZ = [0, sD, VZ], vD = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, KZ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(vD, function(t4, n, e) {
              u(f(n), ah0), a(f(n), ch0, oh0);
              var i = e[1];
              function x(G) {
                return u(t4, G);
              }
              function c(G) {
                return u(t4, G);
              }
              R(jn[1], c, x, n, i), u(f(n), sh0), u(f(n), vh0), a(f(n), bh0, lh0);
              var s = e[2];
              function p(G) {
                return u(t4, G);
              }
              function y(G) {
                return u(t4, G);
              }
              R(jn[1], y, p, n, s), u(f(n), ph0), u(f(n), mh0), a(f(n), yh0, _h0);
              var T = e[3];
              if (T) {
                g(n, dh0);
                var E = T[1], h = function(G, A) {
                  return g(G, xh0);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, n, E), g(n, hh0);
              } else
                g(n, kh0);
              return u(f(n), wh0), u(f(n), Eh0);
            }), N(KZ, function(t4, n) {
              var e = u(vD, t4);
              return a(P0(fh0), e, n);
            });
            var WZ = [0, vD, KZ], lD = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, JZ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(lD, function(t4, n, e) {
              u(f(n), Zd0), a(f(n), rh0, Qd0);
              var i = e[1];
              if (i) {
                g(n, eh0);
                var x = i[1], c = function(p, y) {
                  return g(p, $d0);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, nh0);
              } else
                g(n, th0);
              return u(f(n), uh0), u(f(n), ih0);
            }), N(JZ, function(t4, n) {
              var e = u(lD, t4);
              return a(P0(Jd0), e, n);
            });
            var $Z = [0, lD, JZ], bD = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, ZZ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(bD, function(t4, n, e) {
              u(f(n), Ud0), a(f(n), Xd0, Hd0);
              var i = e[1];
              if (i) {
                g(n, Yd0);
                var x = i[1], c = function(p, y) {
                  return g(p, qd0);
                }, s = function(p) {
                  return u(t4, p);
                };
                R(Dr[1], s, c, n, x), g(n, Vd0);
              } else
                g(n, zd0);
              return u(f(n), Kd0), u(f(n), Wd0);
            }), N(ZZ, function(t4, n) {
              var e = u(bD, t4);
              return a(P0(Bd0), e, n);
            });
            var QZ = [0, bD, ZZ], pD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, rQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(pD, function(t4, n, e, i) {
              u(f(e), Od0), a(f(e), Ad0, Id0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), Nd0), u(f(e), Cd0), a(f(e), Dd0, Pd0);
              var p = i[2];
              if (p) {
                g(e, Ld0);
                var y = p[1], T = function(h, w) {
                  return g(h, Td0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Rd0);
              } else
                g(e, jd0);
              return u(f(e), Gd0), u(f(e), Md0);
            }), N(rQ, function(t4, n, e) {
              var i = a(pD, t4, n);
              return a(P0(Fd0), i, e);
            });
            var eQ = [0, pD, rQ], mD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, nQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, am = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, tQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(mD, function(t4, n, e, i) {
              u(f(e), Ed0), a(n, e, i[1]), u(f(e), Sd0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(am, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), gd0);
            }), N(nQ, function(t4, n, e) {
              var i = a(mD, t4, n);
              return a(P0(wd0), i, e);
            }), N(am, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), by0);
                  var x = i[1], c = function(Y) {
                    return u(n, Y);
                  }, s = function(Y) {
                    return u(t4, Y);
                  };
                  return R(H$[3], s, c, e, x), u(f(e), py0);
                case 1:
                  u(f(e), my0);
                  var p = i[1], y = function(Y) {
                    return u(n, Y);
                  }, T = function(Y) {
                    return u(t4, Y);
                  };
                  return R(Ps[5], T, y, e, p), u(f(e), _y0);
                case 2:
                  u(f(e), yy0);
                  var E = i[1], h = function(Y) {
                    return u(n, Y);
                  }, w = function(Y) {
                    return u(t4, Y);
                  };
                  return R(_Z[3], w, h, e, E), u(f(e), dy0);
                case 3:
                  u(f(e), hy0);
                  var G = i[1], A = function(Y) {
                    return u(n, Y);
                  }, S = function(Y) {
                    return u(t4, Y);
                  };
                  return R(bZ[3], S, A, e, G), u(f(e), ky0);
                case 4:
                  u(f(e), wy0);
                  var M = i[1], K = function(Y) {
                    return u(n, Y);
                  }, V = function(Y) {
                    return u(t4, Y);
                  };
                  return R(eD[1], V, K, e, M), u(f(e), Ey0);
                case 5:
                  u(f(e), Sy0);
                  var f0 = i[1], m0 = function(Y) {
                    return u(n, Y);
                  }, k0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(T1[8], k0, m0, e, f0), u(f(e), gy0);
                case 6:
                  u(f(e), Fy0);
                  var g0 = i[1], e0 = function(Y) {
                    return u(n, Y);
                  }, x0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(oD[2], x0, e0, e, g0), u(f(e), Ty0);
                case 7:
                  u(f(e), Oy0);
                  var l = i[1], c0 = function(Y) {
                    return u(n, Y);
                  }, t0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(gZ[1], t0, c0, e, l), u(f(e), Iy0);
                case 8:
                  u(f(e), Ay0);
                  var a0 = i[1], w0 = function(Y) {
                    return u(n, Y);
                  }, _0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(Ps[5], _0, w0, e, a0), u(f(e), Ny0);
                case 9:
                  u(f(e), Cy0);
                  var E0 = i[1], X0 = function(Y) {
                    return u(n, Y);
                  }, b = function(Y) {
                    return u(t4, Y);
                  };
                  return R(YZ[1], b, X0, e, E0), u(f(e), Py0);
                case 10:
                  u(f(e), Dy0);
                  var G0 = i[1], X = function(Y) {
                    return u(n, Y);
                  }, s0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(jn[1], s0, X, e, G0), u(f(e), Ly0);
                case 11:
                  u(f(e), Ry0);
                  var dr = i[1], Ar = function(Y) {
                    return u(n, Y);
                  }, ar = function(Y) {
                    return u(t4, Y);
                  };
                  return R(eQ[1], ar, Ar, e, dr), u(f(e), jy0);
                case 12:
                  u(f(e), Gy0);
                  var W0 = i[1], Lr = function(Y) {
                    return u(n, Y);
                  }, Tr = function(Y) {
                    return u(t4, Y);
                  };
                  return R(YN[17], Tr, Lr, e, W0), u(f(e), My0);
                case 13:
                  u(f(e), By0);
                  var Hr = i[1], Or = function(Y) {
                    return u(n, Y);
                  }, xr = function(Y) {
                    return u(t4, Y);
                  };
                  return R(YN[19], xr, Or, e, Hr), u(f(e), qy0);
                case 14:
                  u(f(e), Uy0);
                  var Rr = i[1], Wr = function(Y) {
                    return u(t4, Y);
                  };
                  return ir(Tl[2], Wr, e, Rr), u(f(e), Hy0);
                case 15:
                  u(f(e), Xy0);
                  var Jr = i[1], or = function(Y) {
                    return u(n, Y);
                  }, _r = function(Y) {
                    return u(t4, Y);
                  };
                  return R(EZ[3], _r, or, e, Jr), u(f(e), Yy0);
                case 16:
                  u(f(e), Vy0);
                  var Ir = i[1], fe = function(Y) {
                    return u(n, Y);
                  }, v0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(uD[3], v0, fe, e, Ir), u(f(e), zy0);
                case 17:
                  u(f(e), Ky0);
                  var P = i[1], L = function(Y) {
                    return u(t4, Y);
                  };
                  return ir(WZ[1], L, e, P), u(f(e), Wy0);
                case 18:
                  u(f(e), Jy0);
                  var Q = i[1], i0 = function(Y) {
                    return u(n, Y);
                  }, l0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(AZ[1], l0, i0, e, Q), u(f(e), $y0);
                case 19:
                  u(f(e), Zy0);
                  var S0 = i[1], T0 = function(Y) {
                    return u(n, Y);
                  }, er = function(Y) {
                    return u(t4, Y);
                  };
                  return R(fZ[5], er, T0, e, S0), u(f(e), Qy0);
                case 20:
                  u(f(e), rd0);
                  var j0 = i[1], B = function(Y) {
                    return u(n, Y);
                  }, Z = function(Y) {
                    return u(t4, Y);
                  };
                  return R(PZ[1], Z, B, e, j0), u(f(e), ed0);
                case 21:
                  u(f(e), nd0);
                  var p0 = i[1], b0 = function(Y) {
                    return u(n, Y);
                  }, O0 = function(Y) {
                    return u(t4, Y);
                  };
                  return R(jZ[1], O0, b0, e, p0), u(f(e), td0);
                case 22:
                  u(f(e), ud0);
                  var q0 = i[1], nr = function(Y) {
                    return u(n, Y);
                  }, yr = function(Y) {
                    return u(t4, Y);
                  };
                  return R(aZ[1], yr, nr, e, q0), u(f(e), id0);
                case 23:
                  u(f(e), fd0);
                  var vr = i[1], $0 = function(Y) {
                    return u(t4, Y);
                  };
                  return ir(QZ[1], $0, e, vr), u(f(e), xd0);
                case 24:
                  u(f(e), ad0);
                  var Sr = i[1], Mr = function(Y) {
                    return u(n, Y);
                  }, Br = function(Y) {
                    return u(t4, Y);
                  };
                  return R(J$[1], Br, Mr, e, Sr), u(f(e), od0);
                case 25:
                  u(f(e), cd0);
                  var qr = i[1], jr = function(Y) {
                    return u(n, Y);
                  }, $r = function(Y) {
                    return u(t4, Y);
                  };
                  return R(MP[2], $r, jr, e, qr), u(f(e), sd0);
                case 26:
                  u(f(e), vd0);
                  var ne = i[1], Qr = function(Y) {
                    return u(t4, Y);
                  };
                  return ir($Z[1], Qr, e, ne), u(f(e), ld0);
                case 27:
                  u(f(e), bd0);
                  var pe = i[1], oe = function(Y) {
                    return u(n, Y);
                  }, me = function(Y) {
                    return u(t4, Y);
                  };
                  return R(zZ[1], me, oe, e, pe), u(f(e), pd0);
                case 28:
                  u(f(e), md0);
                  var ae = i[1], ce = function(Y) {
                    return u(n, Y);
                  }, ge = function(Y) {
                    return u(t4, Y);
                  };
                  return R(sZ[3], ge, ce, e, ae), u(f(e), _d0);
                case 29:
                  u(f(e), yd0);
                  var H0 = i[1], Fr = function(Y) {
                    return u(n, Y);
                  }, _ = function(Y) {
                    return u(t4, Y);
                  };
                  return R(hZ[3], _, Fr, e, H0), u(f(e), dd0);
                default:
                  u(f(e), hd0);
                  var k = i[1], I = function(Y) {
                    return u(n, Y);
                  }, U = function(Y) {
                    return u(t4, Y);
                  };
                  return R(MZ[1], U, I, e, k), u(f(e), kd0);
              }
            }), N(tQ, function(t4, n, e) {
              var i = a(am, t4, n);
              return a(P0(ly0), i, e);
            }), bu(b6r, Ue, [0, R$, Uee, LP, H$, MP, J$, fZ, aZ, sZ, bZ, _Z, hZ, EZ, gZ, um, FZ, ZP, AZ, eD, PZ, uD, jZ, MZ, oD, YZ, zZ, WZ, $Z, QZ, eQ, mD, nQ, am, tQ]);
            var _D = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, uQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, om = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, iQ = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(_D, function(t4, n, e, i) {
              u(f(e), cy0), a(n, e, i[1]), u(f(e), sy0);
              var x = i[2];
              return ir(om, function(c) {
                return u(t4, c);
              }, e, x), u(f(e), vy0);
            }), N(uQ, function(t4, n, e) {
              var i = a(_D, t4, n);
              return a(P0(oy0), i, e);
            }), N(om, function(t4, n, e) {
              u(f(n), J_0), a(f(n), Z_0, $_0);
              var i = e[1];
              a(f(n), Q_0, i), u(f(n), ry0), u(f(n), ey0), a(f(n), ty0, ny0);
              var x = e[2];
              if (x) {
                g(n, uy0);
                var c = x[1], s = function(y, T) {
                  return g(y, W_0);
                }, p = function(y) {
                  return u(t4, y);
                };
                R(Dr[1], p, s, n, c), g(n, iy0);
              } else
                g(n, fy0);
              return u(f(n), xy0), u(f(n), ay0);
            }), N(iQ, function(t4, n) {
              var e = u(om, t4);
              return a(P0(K_0), e, n);
            });
            var I1 = [0, _D, uQ, om, iQ], yD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, fQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, cm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, xQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(yD, function(t4, n, e, i) {
              u(f(e), Y_0), a(t4, e, i[1]), u(f(e), V_0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(cm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), z_0);
            }), N(fQ, function(t4, n, e) {
              var i = a(yD, t4, n);
              return a(P0(X_0), i, e);
            }), N(cm, function(t4, n, e, i) {
              u(f(e), L_0), a(f(e), j_0, R_0);
              var x = i[1];
              function c(E) {
                return u(n, E);
              }
              function s(E) {
                return u(t4, E);
              }
              R(I1[1], s, c, e, x), u(f(e), G_0), u(f(e), M_0), a(f(e), q_0, B_0);
              var p = i[2];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(I1[1], T, y, e, p), u(f(e), U_0), u(f(e), H_0);
            }), N(xQ, function(t4, n, e) {
              var i = a(cm, t4, n);
              return a(P0(D_0), i, e);
            });
            var dD = [0, yD, fQ, cm, xQ], hD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, aQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, sm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, oQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(hD, function(t4, n, e, i) {
              u(f(e), w_0), a(f(e), S_0, E_0);
              var x = i[1];
              function c(E) {
                return u(n, E);
              }
              R(sm, function(E) {
                return u(t4, E);
              }, c, e, x), u(f(e), g_0), u(f(e), F_0), a(f(e), O_0, T_0);
              var s = i[2];
              if (s) {
                g(e, I_0);
                var p = s[1], y = function(E, h) {
                  u(f(E), h_0);
                  var w = 0;
                  return be(function(G, A) {
                    G && u(f(E), d_0);
                    function S(M) {
                      return u(t4, M);
                    }
                    return ir(uu[1], S, E, A), 1;
                  }, w, h), u(f(E), k_0);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, A_0);
              } else
                g(e, N_0);
              return u(f(e), C_0), u(f(e), P_0);
            }), N(aQ, function(t4, n, e) {
              var i = a(hD, t4, n);
              return a(P0(y_0), i, e);
            }), N(sm, function(t4, n, e, i) {
              if (i) {
                u(f(e), p_0);
                var x = i[1], c = function(p) {
                  return u(n, p);
                }, s = function(p) {
                  return u(t4, p);
                };
                return R(Ue[31], s, c, e, x), u(f(e), m_0);
              }
              return g(e, __0);
            }), N(oQ, function(t4, n, e) {
              var i = a(sm, t4, n);
              return a(P0(b_0), i, e);
            });
            var kD = [0, hD, aQ, sm, oQ];
            function cQ(t4, n) {
              u(f(t4), n_0), a(f(t4), u_0, t_0);
              var e = n[1];
              a(f(t4), i_0, e), u(f(t4), f_0), u(f(t4), x_0), a(f(t4), o_0, a_0);
              var i = n[2];
              return a(f(t4), c_0, i), u(f(t4), s_0), u(f(t4), v_0);
            }
            var sQ = [0, cQ, function(t4) {
              return a(P0(l_0), cQ, t4);
            }], wD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, vQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, vm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, lQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, lm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, bQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, bm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, pQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(wD, function(t4, n, e, i) {
              u(f(e), Q90), a(t4, e, i[1]), u(f(e), r_0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(bm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), e_0);
            }), N(vQ, function(t4, n, e) {
              var i = a(wD, t4, n);
              return a(P0(Z90), i, e);
            }), N(vm, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), K90);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(I1[1], s, c, e, x), u(f(e), W90);
              }
              u(f(e), J90);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(dD[1], T, y, e, p), u(f(e), $90);
            }), N(lQ, function(t4, n, e) {
              var i = a(vm, t4, n);
              return a(P0(z90), i, e);
            }), N(lm, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), q90), a(n, e, i[1]), u(f(e), U90);
                var x = i[2], c = function(T) {
                  return u(t4, T);
                };
                return ir(Tl[2], c, e, x), u(f(e), H90);
              }
              u(f(e), X90), a(n, e, i[1]), u(f(e), Y90);
              var s = i[2];
              function p(T) {
                return u(n, T);
              }
              function y(T) {
                return u(t4, T);
              }
              return R(kD[1], y, p, e, s), u(f(e), V90);
            }), N(bQ, function(t4, n, e) {
              var i = a(lm, t4, n);
              return a(P0(B90), i, e);
            }), N(bm, function(t4, n, e, i) {
              u(f(e), O90), a(f(e), A90, I90);
              var x = i[1];
              function c(T) {
                return u(n, T);
              }
              R(vm, function(T) {
                return u(t4, T);
              }, c, e, x), u(f(e), N90), u(f(e), C90), a(f(e), D90, P90);
              var s = i[2];
              if (s) {
                g(e, L90);
                var p = s[1], y = function(T) {
                  return u(n, T);
                };
                R(lm, function(T) {
                  return u(t4, T);
                }, y, e, p), g(e, R90);
              } else
                g(e, j90);
              return u(f(e), G90), u(f(e), M90);
            }), N(pQ, function(t4, n, e) {
              var i = a(bm, t4, n);
              return a(P0(T90), i, e);
            });
            var mQ = [0, wD, vQ, vm, lQ, lm, bQ, bm, pQ], ED = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, _Q = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, pm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, yQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(ED, function(t4, n, e, i) {
              u(f(e), S90), a(t4, e, i[1]), u(f(e), g90);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(pm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), F90);
            }), N(_Q, function(t4, n, e) {
              var i = a(ED, t4, n);
              return a(P0(E90), i, e);
            }), N(pm, function(t4, n, e, i) {
              u(f(e), s90), a(f(e), l90, v90);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), b90), u(f(e), p90), a(f(e), _90, m90);
              var p = i[2];
              if (p) {
                g(e, y90);
                var y = p[1], T = function(h, w) {
                  return g(h, c90);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, d90);
              } else
                g(e, h90);
              return u(f(e), k90), u(f(e), w90);
            }), N(yQ, function(t4, n, e) {
              var i = a(pm, t4, n);
              return a(P0(o90), i, e);
            });
            var dQ = [0, ED, _Q, pm, yQ], mm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, hQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, _m = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, kQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, ym = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, wQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(mm, function(t4, n, e, i) {
              u(f(e), f90), a(t4, e, i[1]), u(f(e), x90);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(ym, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), a90);
            }), N(hQ, function(t4, n, e) {
              var i = a(mm, t4, n);
              return a(P0(i90), i, e);
            }), N(_m, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), e90);
                var x = i[1], c = function(T) {
                  return u(n, T);
                }, s = function(T) {
                  return u(t4, T);
                };
                return R(I1[1], s, c, e, x), u(f(e), n90);
              }
              u(f(e), t90);
              var p = i[1];
              function y(T) {
                return u(n, T);
              }
              return R(mm, function(T) {
                return u(t4, T);
              }, y, e, p), u(f(e), u90);
            }), N(kQ, function(t4, n, e) {
              var i = a(_m, t4, n);
              return a(P0(r90), i, e);
            }), N(ym, function(t4, n, e, i) {
              u(f(e), Ym0), a(f(e), zm0, Vm0);
              var x = i[1];
              function c(T) {
                return u(n, T);
              }
              R(_m, function(T) {
                return u(t4, T);
              }, c, e, x), u(f(e), Km0), u(f(e), Wm0), a(f(e), $m0, Jm0);
              var s = i[2];
              function p(T) {
                return u(n, T);
              }
              function y(T) {
                return u(t4, T);
              }
              return R(I1[1], y, p, e, s), u(f(e), Zm0), u(f(e), Qm0);
            }), N(wQ, function(t4, n, e) {
              var i = a(ym, t4, n);
              return a(P0(Xm0), i, e);
            });
            var EQ = [0, mm, hQ, _m, kQ, ym, wQ], Nl = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, SQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Nl, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), Gm0);
                  var x = i[1], c = function(G) {
                    return u(n, G);
                  }, s = function(G) {
                    return u(t4, G);
                  };
                  return R(I1[1], s, c, e, x), u(f(e), Mm0);
                case 1:
                  u(f(e), Bm0);
                  var p = i[1], y = function(G) {
                    return u(n, G);
                  }, T = function(G) {
                    return u(t4, G);
                  };
                  return R(dD[1], T, y, e, p), u(f(e), qm0);
                default:
                  u(f(e), Um0);
                  var E = i[1], h = function(G) {
                    return u(n, G);
                  }, w = function(G) {
                    return u(t4, G);
                  };
                  return R(EQ[1], w, h, e, E), u(f(e), Hm0);
              }
            }), N(SQ, function(t4, n, e) {
              var i = a(Nl, t4, n);
              return a(P0(jm0), i, e);
            });
            var SD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, gQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, dm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, FQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, hm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, TQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(SD, function(t4, n, e, i) {
              u(f(e), Dm0), a(t4, e, i[1]), u(f(e), Lm0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(hm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Rm0);
            }), N(gQ, function(t4, n, e) {
              var i = a(SD, t4, n);
              return a(P0(Pm0), i, e);
            }), N(dm, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), Im0);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(mQ[1], s, c, e, x), u(f(e), Am0);
              }
              u(f(e), Nm0);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(dQ[1], T, y, e, p), u(f(e), Cm0);
            }), N(FQ, function(t4, n, e) {
              var i = a(dm, t4, n);
              return a(P0(Om0), i, e);
            }), N(hm, function(t4, n, e, i) {
              u(f(e), vm0), a(f(e), bm0, lm0);
              var x = i[1];
              function c(T) {
                return u(n, T);
              }
              R(Nl, function(T) {
                return u(t4, T);
              }, c, e, x), u(f(e), pm0), u(f(e), mm0), a(f(e), ym0, _m0);
              var s = i[2];
              a(f(e), dm0, s), u(f(e), hm0), u(f(e), km0), a(f(e), Em0, wm0);
              var p = i[3];
              u(f(e), Sm0);
              var y = 0;
              return be(function(T, E) {
                T && u(f(e), sm0);
                function h(w) {
                  return u(n, w);
                }
                return R(dm, function(w) {
                  return u(t4, w);
                }, h, e, E), 1;
              }, y, p), u(f(e), gm0), u(f(e), Fm0), u(f(e), Tm0);
            }), N(TQ, function(t4, n, e) {
              var i = a(hm, t4, n);
              return a(P0(cm0), i, e);
            });
            var OQ = [0, SD, gQ, dm, FQ, hm, TQ], gD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, IQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, km = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, AQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(gD, function(t4, n, e, i) {
              u(f(e), xm0), a(t4, e, i[1]), u(f(e), am0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(km, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), om0);
            }), N(IQ, function(t4, n, e) {
              var i = a(gD, t4, n);
              return a(P0(fm0), i, e);
            }), N(km, function(t4, n, e, i) {
              u(f(e), em0), a(f(e), tm0, nm0);
              var x = i[1];
              function c(s) {
                return u(n, s);
              }
              return R(Nl, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), um0), u(f(e), im0);
            }), N(AQ, function(t4, n, e) {
              var i = a(km, t4, n);
              return a(P0(rm0), i, e);
            });
            var NQ = [0, gD, IQ, km, AQ], FD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, CQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(FD, function(t4, n, e, i) {
              u(f(e), U50), a(f(e), X50, H50);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), Y50), u(f(e), V50), a(f(e), K50, z50);
              var p = i[2];
              if (p) {
                g(e, W50);
                var y = p[1], T = function(h, w) {
                  return g(h, q50);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, J50);
              } else
                g(e, $50);
              return u(f(e), Z50), u(f(e), Q50);
            }), N(CQ, function(t4, n, e) {
              var i = a(FD, t4, n);
              return a(P0(B50), i, e);
            });
            var PQ = [0, FD, CQ], Cl = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, DQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, wm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, LQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Em = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, RQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Sm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, jQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Cl, function(t4, n, e, i) {
              u(f(e), j50), a(t4, e, i[1]), u(f(e), G50);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(wm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), M50);
            }), N(DQ, function(t4, n, e) {
              var i = a(Cl, t4, n);
              return a(P0(R50), i, e);
            }), N(wm, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), F50);
                  var x = i[1], c = function(A) {
                    return u(n, A);
                  };
                  return R(Em, function(A) {
                    return u(t4, A);
                  }, c, e, x), u(f(e), T50);
                case 1:
                  u(f(e), O50);
                  var s = i[1], p = function(A) {
                    return u(n, A);
                  };
                  return R(Sm, function(A) {
                    return u(t4, A);
                  }, p, e, s), u(f(e), I50);
                case 2:
                  u(f(e), A50);
                  var y = i[1], T = function(A) {
                    return u(n, A);
                  }, E = function(A) {
                    return u(t4, A);
                  };
                  return R(kD[1], E, T, e, y), u(f(e), N50);
                case 3:
                  u(f(e), C50);
                  var h = i[1], w = function(A) {
                    return u(n, A);
                  }, G = function(A) {
                    return u(t4, A);
                  };
                  return R(PQ[1], G, w, e, h), u(f(e), P50);
                default:
                  return u(f(e), D50), a(sQ[1], e, i[1]), u(f(e), L50);
              }
            }), N(LQ, function(t4, n, e) {
              var i = a(wm, t4, n);
              return a(P0(g50), i, e);
            }), N(Em, function(t4, n, e, i) {
              u(f(e), $p0), a(f(e), Qp0, Zp0);
              var x = i[1];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(OQ[1], s, c, e, x), u(f(e), r50), u(f(e), e50), a(f(e), t50, n50);
              var p = i[2];
              if (p) {
                g(e, u50);
                var y = p[1], T = function(V) {
                  return u(n, V);
                }, E = function(V) {
                  return u(t4, V);
                };
                R(NQ[1], E, T, e, y), g(e, i50);
              } else
                g(e, f50);
              u(f(e), x50), u(f(e), a50), a(f(e), c50, o50);
              var h = i[3];
              u(f(e), s50), a(t4, e, h[1]), u(f(e), v50), u(f(e), l50);
              var w = h[2], G = 0;
              be(function(V, f0) {
                V && u(f(e), Jp0);
                function m0(k0) {
                  return u(n, k0);
                }
                return R(Cl, function(k0) {
                  return u(t4, k0);
                }, m0, e, f0), 1;
              }, G, w), u(f(e), b50), u(f(e), p50), u(f(e), m50), u(f(e), _50), a(f(e), d50, y50);
              var A = i[4];
              if (A) {
                g(e, h50);
                var S = A[1], M = function(V, f0) {
                  return g(V, Wp0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, k50);
              } else
                g(e, w50);
              return u(f(e), E50), u(f(e), S50);
            }), N(RQ, function(t4, n, e) {
              var i = a(Em, t4, n);
              return a(P0(Kp0), i, e);
            }), N(Sm, function(t4, n, e, i) {
              u(f(e), Ep0), a(f(e), gp0, Sp0), a(t4, e, i[1]), u(f(e), Fp0), u(f(e), Tp0), a(f(e), Ip0, Op0), a(t4, e, i[2]), u(f(e), Ap0), u(f(e), Np0), a(f(e), Pp0, Cp0);
              var x = i[3];
              u(f(e), Dp0), a(t4, e, x[1]), u(f(e), Lp0), u(f(e), Rp0);
              var c = x[2], s = 0;
              be(function(h, w) {
                h && u(f(e), wp0);
                function G(A) {
                  return u(n, A);
                }
                return R(Cl, function(A) {
                  return u(t4, A);
                }, G, e, w), 1;
              }, s, c), u(f(e), jp0), u(f(e), Gp0), u(f(e), Mp0), u(f(e), Bp0), a(f(e), Up0, qp0);
              var p = i[4];
              if (p) {
                g(e, Hp0);
                var y = p[1], T = function(h, w) {
                  return g(h, kp0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Xp0);
              } else
                g(e, Yp0);
              return u(f(e), Vp0), u(f(e), zp0);
            }), N(jQ, function(t4, n, e) {
              var i = a(Sm, t4, n);
              return a(P0(hp0), i, e);
            }), bu(p6r, YN, [0, I1, dD, kD, sQ, mQ, dQ, EQ, Nl, SQ, OQ, NQ, PQ, Cl, DQ, wm, LQ, Em, RQ, Sm, jQ]);
            var TD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, GQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, gm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, MQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(TD, function(t4, n, e, i) {
              u(f(e), _p0), a(t4, e, i[1]), u(f(e), yp0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(gm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), dp0);
            }), N(GQ, function(t4, n, e) {
              var i = a(TD, t4, n);
              return a(P0(mp0), i, e);
            }), N(gm, function(t4, n, e, i) {
              u(f(e), up0), a(f(e), fp0, ip0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), xp0), u(f(e), ap0), a(f(e), cp0, op0);
              var p = i[2];
              if (p) {
                g(e, sp0);
                var y = p[1], T = function(h, w) {
                  return g(h, tp0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, vp0);
              } else
                g(e, lp0);
              return u(f(e), bp0), u(f(e), pp0);
            }), N(MQ, function(t4, n, e) {
              var i = a(gm, t4, n);
              return a(P0(np0), i, e);
            });
            var OD = [0, TD, GQ, gm, MQ], Fm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, BQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, ID = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, qQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Tm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, UQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Fm, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  var x = i[1];
                  u(f(e), z60), u(f(e), K60), a(t4, e, x[1]), u(f(e), W60);
                  var c = x[2], s = function(G) {
                    return u(t4, G);
                  };
                  return ir(Tl[2], s, e, c), u(f(e), J60), u(f(e), $60);
                case 1:
                  u(f(e), Z60);
                  var p = i[1], y = function(G) {
                    return u(n, G);
                  }, T = function(G) {
                    return u(t4, G);
                  };
                  return R(jn[1], T, y, e, p), u(f(e), Q60);
                default:
                  u(f(e), rp0);
                  var E = i[1], h = function(G) {
                    return u(n, G);
                  }, w = function(G) {
                    return u(t4, G);
                  };
                  return R(Up[1], w, h, e, E), u(f(e), ep0);
              }
            }), N(BQ, function(t4, n, e) {
              var i = a(Fm, t4, n);
              return a(P0(V60), i, e);
            }), N(ID, function(t4, n, e, i) {
              u(f(e), H60), a(t4, e, i[1]), u(f(e), X60);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Tm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Y60);
            }), N(qQ, function(t4, n, e) {
              var i = a(ID, t4, n);
              return a(P0(U60), i, e);
            }), N(Tm, function(t4, n, e, i) {
              u(f(e), k60), a(f(e), E60, w60);
              var x = i[1];
              function c(A) {
                return u(n, A);
              }
              R(Fm, function(A) {
                return u(t4, A);
              }, c, e, x), u(f(e), S60), u(f(e), g60), a(f(e), T60, F60);
              var s = i[2];
              function p(A) {
                return u(n, A);
              }
              function y(A) {
                return u(t4, A);
              }
              R(hi[5], y, p, e, s), u(f(e), O60), u(f(e), I60), a(f(e), N60, A60);
              var T = i[3];
              if (T) {
                g(e, C60);
                var E = T[1], h = function(A) {
                  return u(n, A);
                }, w = function(A) {
                  return u(t4, A);
                };
                R(Ue[31], w, h, e, E), g(e, P60);
              } else
                g(e, D60);
              u(f(e), L60), u(f(e), R60), a(f(e), G60, j60);
              var G = i[4];
              return a(f(e), M60, G), u(f(e), B60), u(f(e), q60);
            }), N(UQ, function(t4, n, e) {
              var i = a(Tm, t4, n);
              return a(P0(h60), i, e);
            });
            var HQ = [0, Fm, BQ, ID, qQ, Tm, UQ], Om = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, XQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, AD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, YQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Om, function(t4, n, e, i) {
              if (i[0] === 0) {
                u(f(e), m60);
                var x = i[1], c = function(E) {
                  return u(n, E);
                }, s = function(E) {
                  return u(t4, E);
                };
                return R(HQ[3], s, c, e, x), u(f(e), _60);
              }
              u(f(e), y60);
              var p = i[1];
              function y(E) {
                return u(n, E);
              }
              function T(E) {
                return u(t4, E);
              }
              return R(OD[1], T, y, e, p), u(f(e), d60);
            }), N(XQ, function(t4, n, e) {
              var i = a(Om, t4, n);
              return a(P0(p60), i, e);
            }), N(AD, function(t4, n, e, i) {
              u(f(e), $30), a(f(e), Q30, Z30);
              var x = i[1];
              u(f(e), r60);
              var c = 0;
              be(function(G, A) {
                G && u(f(e), J30);
                function S(M) {
                  return u(n, M);
                }
                return R(Om, function(M) {
                  return u(t4, M);
                }, S, e, A), 1;
              }, c, x), u(f(e), e60), u(f(e), n60), u(f(e), t60), a(f(e), i60, u60);
              var s = i[2];
              function p(G) {
                return u(n, G);
              }
              function y(G) {
                return u(t4, G);
              }
              R(Je[19], y, p, e, s), u(f(e), f60), u(f(e), x60), a(f(e), o60, a60);
              var T = i[3];
              if (T) {
                g(e, c60);
                var E = T[1], h = function(G, A) {
                  u(f(G), K30);
                  var S = 0;
                  return be(function(M, K) {
                    M && u(f(G), z30);
                    function V(f0) {
                      return u(t4, f0);
                    }
                    return ir(uu[1], V, G, K), 1;
                  }, S, A), u(f(G), W30);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, s60);
              } else
                g(e, v60);
              return u(f(e), l60), u(f(e), b60);
            }), N(YQ, function(t4, n, e) {
              var i = a(AD, t4, n);
              return a(P0(V30), i, e);
            });
            var VQ = [0, HQ, Om, XQ, AD, YQ], ND = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, zQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Im = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, KQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(ND, function(t4, n, e, i) {
              u(f(e), H30), a(t4, e, i[1]), u(f(e), X30);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Im, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Y30);
            }), N(zQ, function(t4, n, e) {
              var i = a(ND, t4, n);
              return a(P0(U30), i, e);
            }), N(Im, function(t4, n, e, i) {
              u(f(e), A30), a(f(e), C30, N30);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), P30), u(f(e), D30), a(f(e), R30, L30);
              var p = i[2];
              if (p) {
                g(e, j30);
                var y = p[1], T = function(h) {
                  return u(n, h);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Ue[31], E, T, e, y), g(e, G30);
              } else
                g(e, M30);
              return u(f(e), B30), u(f(e), q30);
            }), N(KQ, function(t4, n, e) {
              var i = a(Im, t4, n);
              return a(P0(I30), i, e);
            });
            var WQ = [0, ND, zQ, Im, KQ], Am = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, JQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, CD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, $Q = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(Am, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), E30);
                  var x = i[1], c = function(E) {
                    return u(n, E);
                  }, s = function(E) {
                    return u(t4, E);
                  };
                  return R(WQ[1], s, c, e, x), u(f(e), S30);
                case 1:
                  u(f(e), g30);
                  var p = i[1], y = function(E) {
                    return u(n, E);
                  }, T = function(E) {
                    return u(t4, E);
                  };
                  return R(OD[1], T, y, e, p), u(f(e), F30);
                default:
                  return u(f(e), T30), a(t4, e, i[1]), u(f(e), O30);
              }
            }), N(JQ, function(t4, n, e) {
              var i = a(Am, t4, n);
              return a(P0(w30), i, e);
            }), N(CD, function(t4, n, e, i) {
              u(f(e), u30), a(f(e), f30, i30);
              var x = i[1];
              u(f(e), x30);
              var c = 0;
              be(function(G, A) {
                G && u(f(e), t30);
                function S(M) {
                  return u(n, M);
                }
                return R(Am, function(M) {
                  return u(t4, M);
                }, S, e, A), 1;
              }, c, x), u(f(e), a30), u(f(e), o30), u(f(e), c30), a(f(e), v30, s30);
              var s = i[2];
              function p(G) {
                return u(n, G);
              }
              function y(G) {
                return u(t4, G);
              }
              R(Je[19], y, p, e, s), u(f(e), l30), u(f(e), b30), a(f(e), m30, p30);
              var T = i[3];
              if (T) {
                g(e, _30);
                var E = T[1], h = function(G, A) {
                  u(f(G), e30);
                  var S = 0;
                  return be(function(M, K) {
                    M && u(f(G), r30);
                    function V(f0) {
                      return u(t4, f0);
                    }
                    return ir(uu[1], V, G, K), 1;
                  }, S, A), u(f(G), n30);
                }, w = function(G) {
                  return u(t4, G);
                };
                R(Dr[1], w, h, e, E), g(e, y30);
              } else
                g(e, d30);
              return u(f(e), h30), u(f(e), k30);
            }), N($Q, function(t4, n, e) {
              var i = a(CD, t4, n);
              return a(P0(Q80), i, e);
            });
            var ZQ = [0, WQ, Am, JQ, CD, $Q], PD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, QQ = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(PD, function(t4, n, e, i) {
              u(f(e), M80), a(f(e), q80, B80);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(jn[1], s, c, e, x), u(f(e), U80), u(f(e), H80), a(f(e), Y80, X80);
              var p = i[2];
              function y(h) {
                return u(n, h);
              }
              function T(h) {
                return u(t4, h);
              }
              R(Je[19], T, y, e, p), u(f(e), V80), u(f(e), z80), a(f(e), W80, K80);
              var E = i[3];
              return a(f(e), J80, E), u(f(e), $80), u(f(e), Z80);
            }), N(QQ, function(t4, n, e) {
              var i = a(PD, t4, n);
              return a(P0(G80), i, e);
            });
            var r00 = [0, PD, QQ], DD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, e00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Nm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, n00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(DD, function(t4, n, e, i) {
              u(f(e), L80), a(n, e, i[1]), u(f(e), R80);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Nm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), j80);
            }), N(e00, function(t4, n, e) {
              var i = a(DD, t4, n);
              return a(P0(D80), i, e);
            }), N(Nm, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), F80);
                  var x = i[1], c = function(M) {
                    return u(n, M);
                  }, s = function(M) {
                    return u(t4, M);
                  };
                  return R(VQ[4], s, c, e, x), u(f(e), T80);
                case 1:
                  u(f(e), O80);
                  var p = i[1], y = function(M) {
                    return u(n, M);
                  }, T = function(M) {
                    return u(t4, M);
                  };
                  return R(ZQ[4], T, y, e, p), u(f(e), I80);
                case 2:
                  u(f(e), A80);
                  var E = i[1], h = function(M) {
                    return u(n, M);
                  }, w = function(M) {
                    return u(t4, M);
                  };
                  return R(r00[1], w, h, e, E), u(f(e), N80);
                default:
                  u(f(e), C80);
                  var G = i[1], A = function(M) {
                    return u(n, M);
                  }, S = function(M) {
                    return u(t4, M);
                  };
                  return R(Ue[31], S, A, e, G), u(f(e), P80);
              }
            }), N(n00, function(t4, n, e) {
              var i = a(Nm, t4, n);
              return a(P0(g80), i, e);
            }), bu(m6r, hi, [0, OD, VQ, ZQ, r00, DD, e00, Nm, n00]);
            var LD = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, t00 = function t4(n, e) {
              return t4.fun(n, e);
            }, Cm = function t4(n, e) {
              return t4.fun(n, e);
            }, u00 = function t4(n) {
              return t4.fun(n);
            }, Pm = function t4(n, e) {
              return t4.fun(n, e);
            }, i00 = function t4(n) {
              return t4.fun(n);
            };
            N(LD, function(t4, n, e) {
              return u(f(n), w80), a(t4, n, e[1]), u(f(n), E80), a(Pm, n, e[2]), u(f(n), S80);
            }), N(t00, function(t4, n) {
              var e = u(LD, t4);
              return a(P0(k80), e, n);
            }), N(Cm, function(t4, n) {
              return n ? g(t4, d80) : g(t4, h80);
            }), N(u00, function(t4) {
              return a(P0(y80), Cm, t4);
            }), N(Pm, function(t4, n) {
              u(f(t4), t80), a(f(t4), i80, u80), a(Cm, t4, n[1]), u(f(t4), f80), u(f(t4), x80), a(f(t4), o80, a80);
              var e = n[2];
              a(f(t4), c80, e), u(f(t4), s80), u(f(t4), v80), a(f(t4), b80, l80);
              var i = n[3];
              return a(f(t4), p80, i), u(f(t4), m80), u(f(t4), _80);
            }), N(i00, function(t4) {
              return a(P0(n80), Pm, t4);
            }), bu(_6r, uu, [0, LD, t00, Cm, u00, Pm, i00]);
            var RD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, f00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Dm = function t4(n, e) {
              return t4.fun(n, e);
            }, x00 = function t4(n) {
              return t4.fun(n);
            }, Lm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, a00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(RD, function(t4, n, e, i) {
              u(f(e), Q40), a(n, e, i[1]), u(f(e), r80);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Lm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), e80);
            }), N(f00, function(t4, n, e) {
              var i = a(RD, t4, n);
              return a(P0(Z40), i, e);
            }), N(Dm, function(t4, n) {
              switch (n) {
                case 0:
                  return g(t4, K40);
                case 1:
                  return g(t4, W40);
                case 2:
                  return g(t4, J40);
                default:
                  return g(t4, $40);
              }
            }), N(x00, function(t4) {
              return a(P0(z40), Dm, t4);
            }), N(Lm, function(t4, n, e, i) {
              u(f(e), l40), a(f(e), p40, b40), a(Dm, e, i[1]), u(f(e), m40), u(f(e), _40), a(f(e), d40, y40);
              var x = i[2];
              function c(V) {
                return u(n, V);
              }
              function s(V) {
                return u(t4, V);
              }
              R(Ue[7][1][1], s, c, e, x), u(f(e), h40), u(f(e), k40), a(f(e), E40, w40);
              var p = i[3];
              u(f(e), S40), a(t4, e, p[1]), u(f(e), g40);
              var y = p[2];
              function T(V) {
                return u(n, V);
              }
              function E(V) {
                return u(t4, V);
              }
              R(Ps[5], E, T, e, y), u(f(e), F40), u(f(e), T40), u(f(e), O40), a(f(e), A40, I40);
              var h = i[4];
              a(f(e), N40, h), u(f(e), C40), u(f(e), P40), a(f(e), L40, D40);
              var w = i[5];
              u(f(e), R40);
              var G = 0;
              be(function(V, f0) {
                V && u(f(e), v40);
                function m0(g0) {
                  return u(n, g0);
                }
                function k0(g0) {
                  return u(t4, g0);
                }
                return R(T1[7][1], k0, m0, e, f0), 1;
              }, G, w), u(f(e), j40), u(f(e), G40), u(f(e), M40), a(f(e), q40, B40);
              var A = i[6];
              if (A) {
                g(e, U40);
                var S = A[1], M = function(V, f0) {
                  return g(V, s40);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, H40);
              } else
                g(e, X40);
              return u(f(e), Y40), u(f(e), V40);
            }), N(a00, function(t4, n, e) {
              var i = a(Lm, t4, n);
              return a(P0(c40), i, e);
            });
            var o00 = [0, RD, f00, Dm, x00, Lm, a00], jD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, c00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Rm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, s00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, jm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, v00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(jD, function(t4, n, e, i) {
              u(f(e), x40), a(n, e, i[1]), u(f(e), a40);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Rm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), o40);
            }), N(c00, function(t4, n, e) {
              var i = a(jD, t4, n);
              return a(P0(f40), i, e);
            }), N(Rm, function(t4, n, e, i) {
              u(f(e), Ob0), a(f(e), Ab0, Ib0);
              var x = i[1];
              function c(m0) {
                return u(n, m0);
              }
              function s(m0) {
                return u(t4, m0);
              }
              R(Ue[7][1][1], s, c, e, x), u(f(e), Nb0), u(f(e), Cb0), a(f(e), Db0, Pb0);
              var p = i[2];
              function y(m0) {
                return u(n, m0);
              }
              R(jm, function(m0) {
                return u(t4, m0);
              }, y, e, p), u(f(e), Lb0), u(f(e), Rb0), a(f(e), Gb0, jb0);
              var T = i[3];
              function E(m0) {
                return u(n, m0);
              }
              function h(m0) {
                return u(t4, m0);
              }
              R(Je[19], h, E, e, T), u(f(e), Mb0), u(f(e), Bb0), a(f(e), Ub0, qb0);
              var w = i[4];
              a(f(e), Hb0, w), u(f(e), Xb0), u(f(e), Yb0), a(f(e), zb0, Vb0);
              var G = i[5];
              if (G) {
                g(e, Kb0);
                var A = G[1], S = function(m0) {
                  return u(t4, m0);
                };
                ir(zv[1], S, e, A), g(e, Wb0);
              } else
                g(e, Jb0);
              u(f(e), $b0), u(f(e), Zb0), a(f(e), r40, Qb0);
              var M = i[6];
              if (M) {
                g(e, e40);
                var K = M[1], V = function(m0, k0) {
                  return g(m0, Tb0);
                }, f0 = function(m0) {
                  return u(t4, m0);
                };
                R(Dr[1], f0, V, e, K), g(e, n40);
              } else
                g(e, t40);
              return u(f(e), u40), u(f(e), i40);
            }), N(s00, function(t4, n, e) {
              var i = a(Rm, t4, n);
              return a(P0(Fb0), i, e);
            }), N(jm, function(t4, n, e, i) {
              if (typeof i == "number")
                return i ? g(e, wb0) : g(e, Eb0);
              u(f(e), Sb0);
              var x = i[1];
              function c(p) {
                return u(n, p);
              }
              function s(p) {
                return u(t4, p);
              }
              return R(Ue[31], s, c, e, x), u(f(e), gb0);
            }), N(v00, function(t4, n, e) {
              var i = a(jm, t4, n);
              return a(P0(kb0), i, e);
            });
            var l00 = [0, jD, c00, Rm, s00, jm, v00], GD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, b00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Gm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, p00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(GD, function(t4, n, e, i) {
              u(f(e), yb0), a(n, e, i[1]), u(f(e), db0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Gm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), hb0);
            }), N(b00, function(t4, n, e) {
              var i = a(GD, t4, n);
              return a(P0(_b0), i, e);
            }), N(Gm, function(t4, n, e, i) {
              u(f(e), Ml0), a(f(e), ql0, Bl0);
              var x = i[1];
              function c(m0) {
                return u(t4, m0);
              }
              ir(qp[1], c, e, x), u(f(e), Ul0), u(f(e), Hl0), a(f(e), Yl0, Xl0);
              var s = i[2];
              function p(m0) {
                return u(n, m0);
              }
              function y(m0) {
                return u(t4, m0);
              }
              R(T1[2][5], y, p, e, s), u(f(e), Vl0), u(f(e), zl0), a(f(e), Wl0, Kl0);
              var T = i[3];
              function E(m0) {
                return u(n, m0);
              }
              function h(m0) {
                return u(t4, m0);
              }
              R(Je[19], h, E, e, T), u(f(e), Jl0), u(f(e), $l0), a(f(e), Ql0, Zl0);
              var w = i[4];
              a(f(e), rb0, w), u(f(e), eb0), u(f(e), nb0), a(f(e), ub0, tb0);
              var G = i[5];
              if (G) {
                g(e, ib0);
                var A = G[1], S = function(m0) {
                  return u(t4, m0);
                };
                ir(zv[1], S, e, A), g(e, fb0);
              } else
                g(e, xb0);
              u(f(e), ab0), u(f(e), ob0), a(f(e), sb0, cb0);
              var M = i[6];
              if (M) {
                g(e, vb0);
                var K = M[1], V = function(m0, k0) {
                  return g(m0, Gl0);
                }, f0 = function(m0) {
                  return u(t4, m0);
                };
                R(Dr[1], f0, V, e, K), g(e, lb0);
              } else
                g(e, bb0);
              return u(f(e), pb0), u(f(e), mb0);
            }), N(p00, function(t4, n, e) {
              var i = a(Gm, t4, n);
              return a(P0(jl0), i, e);
            });
            var m00 = [0, GD, b00, Gm, p00], MD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, _00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Mm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, y00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(MD, function(t4, n, e, i) {
              u(f(e), Dl0), a(t4, e, i[1]), u(f(e), Ll0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Mm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Rl0);
            }), N(_00, function(t4, n, e) {
              var i = a(MD, t4, n);
              return a(P0(Pl0), i, e);
            }), N(Mm, function(t4, n, e, i) {
              u(f(e), bl0), a(f(e), ml0, pl0);
              var x = i[1];
              function c(S) {
                return u(n, S);
              }
              function s(S) {
                return u(t4, S);
              }
              R(Ue[31], s, c, e, x), u(f(e), _l0), u(f(e), yl0), a(f(e), hl0, dl0);
              var p = i[2];
              if (p) {
                g(e, kl0);
                var y = p[1], T = function(S) {
                  return u(n, S);
                }, E = function(S) {
                  return u(t4, S);
                };
                R(Je[23][1], E, T, e, y), g(e, wl0);
              } else
                g(e, El0);
              u(f(e), Sl0), u(f(e), gl0), a(f(e), Tl0, Fl0);
              var h = i[3];
              if (h) {
                g(e, Ol0);
                var w = h[1], G = function(S, M) {
                  return g(S, ll0);
                }, A = function(S) {
                  return u(t4, S);
                };
                R(Dr[1], A, G, e, w), g(e, Il0);
              } else
                g(e, Al0);
              return u(f(e), Nl0), u(f(e), Cl0);
            }), N(y00, function(t4, n, e) {
              var i = a(Mm, t4, n);
              return a(P0(vl0), i, e);
            });
            var d00 = [0, MD, _00, Mm, y00], BD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, h00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Bm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, k00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(BD, function(t4, n, e, i) {
              u(f(e), ol0), a(t4, e, i[1]), u(f(e), cl0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Bm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), sl0);
            }), N(h00, function(t4, n, e) {
              var i = a(BD, t4, n);
              return a(P0(al0), i, e);
            }), N(Bm, function(t4, n, e, i) {
              u(f(e), J20), a(f(e), Z20, $20);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(jn[1], s, c, e, x), u(f(e), Q20), u(f(e), rl0), a(f(e), nl0, el0);
              var p = i[2];
              if (p) {
                g(e, tl0);
                var y = p[1], T = function(h) {
                  return u(n, h);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Je[23][1], E, T, e, y), g(e, ul0);
              } else
                g(e, il0);
              return u(f(e), fl0), u(f(e), xl0);
            }), N(k00, function(t4, n, e) {
              var i = a(Bm, t4, n);
              return a(P0(W20), i, e);
            });
            var w00 = [0, BD, h00, Bm, k00], qD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, E00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, qm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, S00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(qD, function(t4, n, e, i) {
              u(f(e), V20), a(t4, e, i[1]), u(f(e), z20);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(qm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), K20);
            }), N(E00, function(t4, n, e) {
              var i = a(qD, t4, n);
              return a(P0(Y20), i, e);
            }), N(qm, function(t4, n, e, i) {
              u(f(e), N20), a(f(e), P20, C20);
              var x = i[1];
              u(f(e), D20);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), A20);
                function w(A) {
                  return u(n, A);
                }
                function G(A) {
                  return u(t4, A);
                }
                return R(w00[1], G, w, e, h), 1;
              }, c, x), u(f(e), L20), u(f(e), R20), u(f(e), j20), a(f(e), M20, G20);
              var s = i[2];
              if (s) {
                g(e, B20);
                var p = s[1], y = function(E, h) {
                  return g(E, I20);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, q20);
              } else
                g(e, U20);
              return u(f(e), H20), u(f(e), X20);
            }), N(S00, function(t4, n, e) {
              var i = a(qm, t4, n);
              return a(P0(O20), i, e);
            });
            var g00 = [0, w00, qD, E00, qm, S00], UD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, F00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Um = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, T00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Hm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, O00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(UD, function(t4, n, e, i) {
              u(f(e), g20), a(t4, e, i[1]), u(f(e), F20);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Um, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), T20);
            }), N(F00, function(t4, n, e) {
              var i = a(UD, t4, n);
              return a(P0(S20), i, e);
            }), N(Um, function(t4, n, e, i) {
              u(f(e), c20), a(f(e), v20, s20);
              var x = i[1];
              u(f(e), l20);
              var c = 0;
              be(function(E, h) {
                E && u(f(e), o20);
                function w(G) {
                  return u(n, G);
                }
                return R(Hm, function(G) {
                  return u(t4, G);
                }, w, e, h), 1;
              }, c, x), u(f(e), b20), u(f(e), p20), u(f(e), m20), a(f(e), y20, _20);
              var s = i[2];
              if (s) {
                g(e, d20);
                var p = s[1], y = function(E, h) {
                  return g(E, a20);
                }, T = function(E) {
                  return u(t4, E);
                };
                R(Dr[1], T, y, e, p), g(e, h20);
              } else
                g(e, k20);
              return u(f(e), w20), u(f(e), E20);
            }), N(T00, function(t4, n, e) {
              var i = a(Um, t4, n);
              return a(P0(x20), i, e);
            }), N(Hm, function(t4, n, e, i) {
              switch (i[0]) {
                case 0:
                  u(f(e), e20);
                  var x = i[1], c = function(G) {
                    return u(n, G);
                  }, s = function(G) {
                    return u(t4, G);
                  };
                  return R(o00[1], s, c, e, x), u(f(e), n20);
                case 1:
                  u(f(e), t20);
                  var p = i[1], y = function(G) {
                    return u(n, G);
                  }, T = function(G) {
                    return u(t4, G);
                  };
                  return R(l00[1], T, y, e, p), u(f(e), u20);
                default:
                  u(f(e), i20);
                  var E = i[1], h = function(G) {
                    return u(n, G);
                  }, w = function(G) {
                    return u(t4, G);
                  };
                  return R(m00[1], w, h, e, E), u(f(e), f20);
              }
            }), N(O00, function(t4, n, e) {
              var i = a(Hm, t4, n);
              return a(P0(r20), i, e);
            });
            var HD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, I00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Xm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, A00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Hee = [0, UD, F00, Um, T00, Hm, O00];
            N(HD, function(t4, n, e, i) {
              u(f(e), $v0), a(t4, e, i[1]), u(f(e), Zv0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Xm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), Qv0);
            }), N(I00, function(t4, n, e) {
              var i = a(HD, t4, n);
              return a(P0(Jv0), i, e);
            }), N(Xm, function(t4, n, e, i) {
              u(f(e), Gv0), a(f(e), Bv0, Mv0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Ue[31], s, c, e, x), u(f(e), qv0), u(f(e), Uv0), a(f(e), Xv0, Hv0);
              var p = i[2];
              if (p) {
                g(e, Yv0);
                var y = p[1], T = function(h, w) {
                  return g(h, jv0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Vv0);
              } else
                g(e, zv0);
              return u(f(e), Kv0), u(f(e), Wv0);
            }), N(A00, function(t4, n, e) {
              var i = a(Xm, t4, n);
              return a(P0(Rv0), i, e);
            });
            var N00 = [0, HD, I00, Xm, A00], XD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, C00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(XD, function(t4, n, e, i) {
              u(f(e), X10), a(f(e), V10, Y10);
              var x = i[1];
              if (x) {
                g(e, z10);
                var c = x[1], s = function(w0) {
                  return u(n, w0);
                }, p = function(w0) {
                  return u(t4, w0);
                };
                R(jn[1], p, s, e, c), g(e, K10);
              } else
                g(e, W10);
              u(f(e), J10), u(f(e), $10), a(f(e), Q10, Z10);
              var y = i[2];
              function T(w0) {
                return u(n, w0);
              }
              function E(w0) {
                return u(t4, w0);
              }
              R(T1[6][1], E, T, e, y), u(f(e), rv0), u(f(e), ev0), a(f(e), tv0, nv0);
              var h = i[3];
              if (h) {
                g(e, uv0);
                var w = h[1], G = function(w0) {
                  return u(n, w0);
                }, A = function(w0) {
                  return u(t4, w0);
                };
                R(Je[22][1], A, G, e, w), g(e, iv0);
              } else
                g(e, fv0);
              u(f(e), xv0), u(f(e), av0), a(f(e), cv0, ov0);
              var S = i[4];
              if (S) {
                g(e, sv0);
                var M = S[1], K = function(w0) {
                  return u(n, w0);
                }, V = function(w0) {
                  return u(t4, w0);
                };
                R(d00[1], V, K, e, M), g(e, vv0);
              } else
                g(e, lv0);
              u(f(e), bv0), u(f(e), pv0), a(f(e), _v0, mv0);
              var f0 = i[5];
              if (f0) {
                g(e, yv0);
                var m0 = f0[1], k0 = function(w0) {
                  return u(n, w0);
                }, g0 = function(w0) {
                  return u(t4, w0);
                };
                R(g00[2], g0, k0, e, m0), g(e, dv0);
              } else
                g(e, hv0);
              u(f(e), kv0), u(f(e), wv0), a(f(e), Sv0, Ev0);
              var e0 = i[6];
              u(f(e), gv0);
              var x0 = 0;
              be(function(w0, _0) {
                w0 && u(f(e), H10);
                function E0(b) {
                  return u(n, b);
                }
                function X0(b) {
                  return u(t4, b);
                }
                return R(N00[1], X0, E0, e, _0), 1;
              }, x0, e0), u(f(e), Fv0), u(f(e), Tv0), u(f(e), Ov0), a(f(e), Av0, Iv0);
              var l = i[7];
              if (l) {
                g(e, Nv0);
                var c0 = l[1], t0 = function(w0, _0) {
                  return g(w0, U10);
                }, a0 = function(w0) {
                  return u(t4, w0);
                };
                R(Dr[1], a0, t0, e, c0), g(e, Cv0);
              } else
                g(e, Pv0);
              return u(f(e), Dv0), u(f(e), Lv0);
            }), N(C00, function(t4, n, e) {
              var i = a(XD, t4, n);
              return a(P0(q10), i, e);
            }), bu(y6r, T1, [0, o00, l00, m00, d00, g00, Hee, N00, XD, C00]);
            var YD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, P00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Ym = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, D00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(YD, function(t4, n, e, i) {
              u(f(e), G10), a(t4, e, i[1]), u(f(e), M10);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Ym, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), B10);
            }), N(P00, function(t4, n, e) {
              var i = a(YD, t4, n);
              return a(P0(j10), i, e);
            }), N(Ym, function(t4, n, e, i) {
              u(f(e), g10), a(f(e), T10, F10);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), O10), u(f(e), I10), a(f(e), N10, A10);
              var p = i[2];
              if (p) {
                g(e, C10);
                var y = p[1], T = function(h, w) {
                  return g(h, S10);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, P10);
              } else
                g(e, D10);
              return u(f(e), L10), u(f(e), R10);
            }), N(D00, function(t4, n, e) {
              var i = a(Ym, t4, n);
              return a(P0(E10), i, e);
            });
            var L00 = [0, YD, P00, Ym, D00], VD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, R00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Vm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, j00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(VD, function(t4, n, e, i) {
              u(f(e), h10), a(t4, e, i[1]), u(f(e), k10);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Vm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), w10);
            }), N(R00, function(t4, n, e) {
              var i = a(VD, t4, n);
              return a(P0(d10), i, e);
            }), N(Vm, function(t4, n, e, i) {
              u(f(e), x10), a(f(e), o10, a10);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(hi[5], s, c, e, x), u(f(e), c10), u(f(e), s10), a(f(e), l10, v10);
              var p = i[2];
              if (p) {
                g(e, b10);
                var y = p[1], T = function(h) {
                  return u(n, h);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Ue[31], E, T, e, y), g(e, p10);
              } else
                g(e, m10);
              return u(f(e), _10), u(f(e), y10);
            }), N(j00, function(t4, n, e) {
              var i = a(Vm, t4, n);
              return a(P0(f10), i, e);
            });
            var G00 = [0, VD, R00, Vm, j00], zD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, M00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, zm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, B00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(zD, function(t4, n, e, i) {
              u(f(e), t10), a(t4, e, i[1]), u(f(e), u10);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(zm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), i10);
            }), N(M00, function(t4, n, e) {
              var i = a(zD, t4, n);
              return a(P0(n10), i, e);
            }), N(zm, function(t4, n, e, i) {
              u(f(e), Xs0), a(f(e), Vs0, Ys0);
              var x = i[1];
              function c(h) {
                return u(n, h);
              }
              function s(h) {
                return u(t4, h);
              }
              R(Je[17], s, c, e, x), u(f(e), zs0), u(f(e), Ks0), a(f(e), Js0, Ws0);
              var p = i[2];
              if (p) {
                g(e, $s0);
                var y = p[1], T = function(h, w) {
                  return g(h, Hs0);
                }, E = function(h) {
                  return u(t4, h);
                };
                R(Dr[1], E, T, e, y), g(e, Zs0);
              } else
                g(e, Qs0);
              return u(f(e), r10), u(f(e), e10);
            }), N(B00, function(t4, n, e) {
              var i = a(zm, t4, n);
              return a(P0(Us0), i, e);
            });
            var q00 = [0, zD, M00, zm, B00], KD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, U00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Km = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, H00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(KD, function(t4, n, e, i) {
              u(f(e), Ms0), a(t4, e, i[1]), u(f(e), Bs0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Km, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), qs0);
            }), N(U00, function(t4, n, e) {
              var i = a(KD, t4, n);
              return a(P0(Gs0), i, e);
            }), N(Km, function(t4, n, e, i) {
              u(f(e), cs0), a(f(e), vs0, ss0);
              var x = i[1];
              if (x) {
                g(e, ls0);
                var c = x[1], s = function(V) {
                  return u(n, V);
                }, p = function(V) {
                  return u(t4, V);
                };
                R(q00[1], p, s, e, c), g(e, bs0);
              } else
                g(e, ps0);
              u(f(e), ms0), u(f(e), _s0), a(f(e), ds0, ys0);
              var y = i[2];
              u(f(e), hs0);
              var T = 0;
              be(function(V, f0) {
                V && u(f(e), os0);
                function m0(g0) {
                  return u(n, g0);
                }
                function k0(g0) {
                  return u(t4, g0);
                }
                return R(G00[1], k0, m0, e, f0), 1;
              }, T, y), u(f(e), ks0), u(f(e), ws0), u(f(e), Es0), a(f(e), gs0, Ss0);
              var E = i[3];
              if (E) {
                g(e, Fs0);
                var h = E[1], w = function(V) {
                  return u(n, V);
                }, G = function(V) {
                  return u(t4, V);
                };
                R(L00[1], G, w, e, h), g(e, Ts0);
              } else
                g(e, Os0);
              u(f(e), Is0), u(f(e), As0), a(f(e), Cs0, Ns0);
              var A = i[4];
              if (A) {
                g(e, Ps0);
                var S = A[1], M = function(V, f0) {
                  u(f(V), xs0);
                  var m0 = 0;
                  return be(function(k0, g0) {
                    k0 && u(f(V), fs0);
                    function e0(x0) {
                      return u(t4, x0);
                    }
                    return ir(uu[1], e0, V, g0), 1;
                  }, m0, f0), u(f(V), as0);
                }, K = function(V) {
                  return u(t4, V);
                };
                R(Dr[1], K, M, e, S), g(e, Ds0);
              } else
                g(e, Ls0);
              return u(f(e), Rs0), u(f(e), js0);
            }), N(H00, function(t4, n, e) {
              var i = a(Km, t4, n);
              return a(P0(is0), i, e);
            });
            var X00 = [0, KD, U00, Km, H00], WD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, Y00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Wm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, V00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(WD, function(t4, n, e, i) {
              u(f(e), uc0), a(f(e), fc0, ic0);
              var x = i[1];
              if (x) {
                g(e, xc0);
                var c = x[1], s = function(_0) {
                  return u(n, _0);
                }, p = function(_0) {
                  return u(t4, _0);
                };
                R(jn[1], p, s, e, c), g(e, ac0);
              } else
                g(e, oc0);
              u(f(e), cc0), u(f(e), sc0), a(f(e), lc0, vc0);
              var y = i[2];
              function T(_0) {
                return u(n, _0);
              }
              function E(_0) {
                return u(t4, _0);
              }
              R(X00[1], E, T, e, y), u(f(e), bc0), u(f(e), pc0), a(f(e), _c0, mc0);
              var h = i[3];
              function w(_0) {
                return u(n, _0);
              }
              R(Wm, function(_0) {
                return u(t4, _0);
              }, w, e, h), u(f(e), yc0), u(f(e), dc0), a(f(e), kc0, hc0);
              var G = i[4];
              a(f(e), wc0, G), u(f(e), Ec0), u(f(e), Sc0), a(f(e), Fc0, gc0);
              var A = i[5];
              a(f(e), Tc0, A), u(f(e), Oc0), u(f(e), Ic0), a(f(e), Nc0, Ac0);
              var S = i[6];
              if (S) {
                g(e, Cc0);
                var M = S[1], K = function(_0) {
                  return u(n, _0);
                }, V = function(_0) {
                  return u(t4, _0);
                };
                R(Je[24][1], V, K, e, M), g(e, Pc0);
              } else
                g(e, Dc0);
              u(f(e), Lc0), u(f(e), Rc0), a(f(e), Gc0, jc0);
              var f0 = i[7];
              function m0(_0) {
                return u(n, _0);
              }
              function k0(_0) {
                return u(t4, _0);
              }
              R(Je[19], k0, m0, e, f0), u(f(e), Mc0), u(f(e), Bc0), a(f(e), Uc0, qc0);
              var g0 = i[8];
              if (g0) {
                g(e, Hc0);
                var e0 = g0[1], x0 = function(_0) {
                  return u(n, _0);
                }, l = function(_0) {
                  return u(t4, _0);
                };
                R(Je[22][1], l, x0, e, e0), g(e, Xc0);
              } else
                g(e, Yc0);
              u(f(e), Vc0), u(f(e), zc0), a(f(e), Wc0, Kc0);
              var c0 = i[9];
              if (c0) {
                g(e, Jc0);
                var t0 = c0[1], a0 = function(_0, E0) {
                  return g(_0, tc0);
                }, w0 = function(_0) {
                  return u(t4, _0);
                };
                R(Dr[1], w0, a0, e, t0), g(e, $c0);
              } else
                g(e, Zc0);
              return u(f(e), Qc0), u(f(e), rs0), a(f(e), ns0, es0), a(t4, e, i[10]), u(f(e), ts0), u(f(e), us0);
            }), N(Y00, function(t4, n, e) {
              var i = a(WD, t4, n);
              return a(P0(nc0), i, e);
            }), N(Wm, function(t4, n, e, i) {
              if (i[0] === 0) {
                var x = i[1];
                u(f(e), Wo0), u(f(e), Jo0), a(t4, e, x[1]), u(f(e), $o0);
                var c = x[2], s = function(h) {
                  return u(n, h);
                }, p = function(h) {
                  return u(t4, h);
                };
                return R(Xu[1][1], p, s, e, c), u(f(e), Zo0), u(f(e), Qo0);
              }
              u(f(e), rc0);
              var y = i[1];
              function T(h) {
                return u(n, h);
              }
              function E(h) {
                return u(t4, h);
              }
              return R(Ue[31], E, T, e, y), u(f(e), ec0);
            }), N(V00, function(t4, n, e) {
              var i = a(Wm, t4, n);
              return a(P0(Ko0), i, e);
            }), bu(d6r, Ps, [0, L00, G00, q00, X00, WD, Y00, Wm, V00]);
            var JD = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, z00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Jm = function t4(n, e, i, x) {
              return t4.fun(n, e, i, x);
            }, K00 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            };
            N(JD, function(t4, n, e, i) {
              u(f(e), Yo0), a(t4, e, i[1]), u(f(e), Vo0);
              var x = i[2];
              function c(s) {
                return u(n, s);
              }
              return R(Jm, function(s) {
                return u(t4, s);
              }, c, e, x), u(f(e), zo0);
            }), N(z00, function(t4, n, e) {
              var i = a(JD, t4, n);
              return a(P0(Xo0), i, e);
            }), N(Jm, function(t4, n, e, i) {
              u(f(e), So0), a(f(e), Fo0, go0);
              var x = i[1];
              u(f(e), To0);
              var c = 0;
              be(function(w, G) {
                w && u(f(e), Eo0);
                function A(M) {
                  return u(n, M);
                }
                function S(M) {
                  return u(t4, M);
                }
                return R(Xu[35], S, A, e, G), 1;
              }, c, x), u(f(e), Oo0), u(f(e), Io0), u(f(e), Ao0), a(f(e), Co0, No0);
              var s = i[2];
              if (s) {
                g(e, Po0);
                var p = s[1], y = function(w, G) {
                  return g(w, wo0);
                }, T = function(w) {
                  return u(t4, w);
                };
                R(Dr[1], T, y, e, p), g(e, Do0);
              } else
                g(e, Lo0);
              u(f(e), Ro0), u(f(e), jo0), a(f(e), Mo0, Go0);
              var E = i[3];
              u(f(e), Bo0);
              var h = 0;
              return be(function(w, G) {
                w && u(f(e), ko0);
                function A(S) {
                  return u(t4, S);
                }
                return ir(uu[1], A, e, G), 1;
              }, h, E), u(f(e), qo0), u(f(e), Uo0), u(f(e), Ho0);
            }), N(K00, function(t4, n, e) {
              var i = a(Jm, t4, n);
              return a(P0(ho0), i, e);
            }), bu(h6r, Mee, [0, JD, z00, Jm, K00]);
            function ze(t4, n) {
              if (n) {
                var e = n[1], i = u(t4, e);
                return e === i ? n : [0, i];
              }
              return n;
            }
            function te(t4, n, e, i, x) {
              var c = a(t4, n, e);
              return e === c ? i : u(x, c);
            }
            function ee(t4, n, e, i) {
              var x = u(t4, n);
              return n === x ? e : u(i, x);
            }
            function pu(t4, n) {
              var e = n[1];
              function i(x) {
                return [0, e, x];
              }
              return te(t4, e, n[2], n, i);
            }
            function Hn(t4, n) {
              var e = be(function(i, x) {
                var c = u(t4, x), s = i[2], p = s || (c !== x ? 1 : 0);
                return [0, [0, c, i[1]], p];
              }, N6r, n);
              return e[2] ? de(e[1]) : n;
            }
            var $D = jp(P6r, function(t4) {
              var n = DN(t4, C6r), e = n[1], i = n[2], x = n[3], c = n[4], s = n[5], p = n[6], y = n[7], T = n[8], E = n[9], h = n[10], w = n[11], G = n[12], A = n[13], S = n[14], M = n[15], K = n[16], V = n[17], f0 = n[18], m0 = n[19], k0 = n[20], g0 = n[21], e0 = n[22], x0 = n[23], l = n[24], c0 = n[25], t0 = n[26], a0 = n[27], w0 = n[28], _0 = n[29], E0 = n[30], X0 = n[31], b = n[32], G0 = n[33], X = n[34], s0 = n[35], dr = n[36], Ar = n[37], ar = n[38], W0 = n[39], Lr = n[40], Tr = n[41], Hr = n[42], Or = n[43], xr = n[44], Rr = n[45], Wr = n[46], Jr = n[47], or = n[49], _r = n[50], Ir = n[51], fe = n[52], v0 = n[53], P = n[54], L = n[55], Q = n[56], i0 = n[57], l0 = n[58], S0 = n[59], T0 = n[60], er = n[61], j0 = n[62], B = n[63], Z = n[65], p0 = n[66], b0 = n[67], O0 = n[68], q0 = n[69], nr = n[70], yr = n[71], vr = n[72], $0 = n[73], Sr = n[74], Mr = n[75], Br = n[76], qr = n[77], jr = n[78], $r = n[79], ne = n[80], Qr = n[81], pe = n[82], oe = n[83], me = n[84], ae = n[85], ce = n[86], ge = n[87], H0 = n[88], Fr = n[89], _ = n[90], k = n[91], I = n[92], U = n[93], Y = n[94], y0 = n[95], D0 = n[96], A0 = n[97], D = n[98], u0 = n[99], Y0 = n[ti], J0 = n[R7], fr = n[ji], Q0 = n[s7], F0 = n[L7], gr = n[j7], mr = n[Vt], Cr = n[Qc], sr = n[fs2], Pr = n[Fv], K0 = n[Yt], Ur = n[vf], d0 = n[T7], Kr = n[Ln], re = n[u1], xe = n[Av], je = n[x1], le = n[A2], Ie = n[z2], Me = n[Sv], Be = n[fc], an = n[tl], Ke = n[Nn], Ae = n[us], on = n[X2], rn = n[br], kn = n[DX], sn = n[Kn], Pe = n[Gt], We = n[eV], en = n[Jw], _n = n[Qg], Dn = n[YH], Xn = n[133], On = n[134], bt = n[135], Ct = n[QH], Tt = n[137], Zt = n[OH], Ut = n[139], Ot = n[gH], Pt = n[141], yu = n[142], Ku = n[143], pt = n[cV], xu = n[145], Gu = n[146], K7 = n[MX], Vi = n[148], a7 = n[fH], Yc = n[150], W7 = n[151], Ht = n[152], mt = n[153], U0 = n[NH], R0 = n[155], Re = n[156], Xe = n[157], he = n[158], _e = n[159], rt = n[sY], wn = n[WU], ft = n[Sd], xt = n[Sn], Gn = n[PF], tt = n[nY], wt = n[MY], un = n[DT], vn = n[DY], ut = n[RX], It = n[Xg], Ti = n[yg], hs = n[BU], Ou = n[wY], Vs = n[nH], zi = n[dX], zs = n[kV], Ks = n[oV], nn = n[OO], si = n[qY], Ws = n[mU], c2 = n[Ni], B9 = n[Kg], q9 = n[mS], U9 = n[wk], Js = n[AU], s2 = n[dh], H9 = n[iw], X9 = n[cY], Y9 = n[sX], X1 = n[PY], vi = n[yX], ob = n[In], cb = n[VT], sb = n[iI], V9 = n[vY], z9 = n[WX], K9 = n[SY], vb = n[_H], W9 = n[uX], J9 = n[RU], $9 = n[mY], Z9 = n[xH], lb = n[fV], Q9 = n[rY], Y1 = n[$H], v2 = n[CH], bb = n[LX], pb = n[wH], mb = n[Zg], An = n[N6], Mn = n[EU], V1 = n[EY], _b = n[qX], yb = n[dT], r_ = n[cT], Vc = n[d6], e_ = n[sp], l2 = n[Lw], db = n[NU], zc = n[aA], n_ = n[HX], $s = n[NX], hb = n[d8], z1 = n[dv], t_ = n[HO], ks = n[tk], u_ = n[eX], K1 = n[sV], i_ = n[dU], b2 = n[Bd], f_ = n[VX], Zs = n[eT], kb = n[wT], Qs = n[aH], x_ = n[eH], Ki = n[mO], Kc = n[YY], r1 = n[pH], a_ = n[f6], p2 = n[v1], m2 = n[Wy], _2 = n[TT], o_ = n[uH], e1 = n[l8], c_ = n[rV], y2 = n[$2], XL = n[48], W1 = n[64];
              function YL(o, F, m) {
                var O = m[2], H = m[1], $7 = ze(u(o[1][1 + nn], o), H), r0 = a(o[1][1 + s0], o, O);
                return O === r0 && H === $7 ? m : [0, $7, r0, m[3], m[4]];
              }
              function J1(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + Kc], o, r0), z0 = ze(u(o[1][1 + V], o), $7), Nr = a(o[1][1 + t0], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && H === Nr && $7 === z0 && O === Gr ? m : [0, M0, z0, Nr, Gr];
              }
              function VL(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = a(o[1][1 + Or], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function $1(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + _r], o, $7), M0 = a(o[1][1 + Or], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function zL(o, F, m) {
                var O = m[2], H = O[2], $7 = O[1], r0 = ir(o[1][1 + p], o, F, $7), M0 = ze(u(o[1][1 + nn], o), H);
                return $7 === r0 && H === M0 ? m : [0, m[1], [0, r0, M0]];
              }
              function Oi(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = Hn(a(o[1][1 + y], o, H), $7), M0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && O === M0 ? m : [0, r0, H, M0];
              }
              function KL(o, F, m) {
                var O = m[4], H = m[2], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, m[1], $7, m[3], r0];
              }
              function WL(o, F, m) {
                var O = m[3], H = m[2], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, m[1], $7, r0];
              }
              function d2(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = a(o[1][1 + l], o, H), z0 = a(o[1][1 + s0], o, O);
                return r0 === $7 && M0 === H && z0 === O ? m : [0, r0, M0, z0];
              }
              function JL(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = pu(u(o[1][1 + Ki], o), r0);
                if ($7)
                  var z0 = $7[1], Nr = z0[1], Gr = function(Qt) {
                    return [0, [0, Nr, Qt]];
                  }, Fe = z0[2], ye = te(u(o[1][1 + K1], o), Nr, Fe, $7, Gr);
                else
                  var ye = $7;
                if (H)
                  var Rn = H[1], yn = Rn[1], at = function(Qt) {
                    return [0, [0, yn, Qt]];
                  }, _t = Rn[2], Et = te(u(o[1][1 + Ki], o), yn, _t, H, at);
                else
                  var Et = H;
                var Wn = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === ye && H === Et && O === Wn ? m : [0, M0, ye, Et, Wn];
              }
              function Z1(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function $L(o, F, m) {
                var O = m[1], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, H];
              }
              function Q1(o, F) {
                return F;
              }
              function ZL(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = Hn(u(o[1][1 + b], o), $7), M0 = Hn(u(o[1][1 + nn], o), H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function wb(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = pu(u(o[1][1 + G0], o), H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function QL(o, F) {
                var m = F[2], O = m[3], H = m[2], $7 = m[1], r0 = ze(u(o[1][1 + nn], o), $7), M0 = a(o[1][1 + Tr], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? F : [0, F[1], [0, r0, M0, z0]];
              }
              function Eb(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = Hn(u(o[1][1 + Ar], o), H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0, m[4]];
              }
              function rR(o, F, m) {
                var O = m[1], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, H];
              }
              function eR(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function h2(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function nR(o, F) {
                return [0, a(o[1][1 + Or], o, F), 0];
              }
              function tR(o, F) {
                var m = u(o[1][1 + Hr], o), O = be(function(H, $7) {
                  var r0 = H[1], M0 = u(m, $7);
                  if (M0) {
                    if (M0[2])
                      return [0, jc(M0, r0), 1];
                    var z0 = M0[1], Nr = H[2], Gr = Nr || ($7 !== z0 ? 1 : 0);
                    return [0, [0, z0, r0], Gr];
                  }
                  return [0, r0, 1];
                }, A6r, F);
                return O[2] ? de(O[1]) : F;
              }
              function s_(o, F) {
                return a(o[1][1 + Tr], o, F);
              }
              function uR(o, F, m) {
                var O = m[2], H = m[1], $7 = Hn(u(o[1][1 + nn], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function k2(o, F, m) {
                var O = m[2], H = m[1], $7 = ze(u(o[1][1 + nn], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0, m[3]];
              }
              function iR(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + Re], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function w2(o, F) {
                return a(o[1][1 + nn], o, F);
              }
              function fR(o, F) {
                var m = F[2], O = m[2], H = m[1];
                if (H)
                  var $7 = function(Nr) {
                    return [0, Nr];
                  }, r0 = H[1], M0 = ee(u(o[1][1 + nn], o), r0, H, $7);
                else
                  var M0 = H;
                var z0 = a(o[1][1 + s0], o, O);
                return H === M0 && O === z0 ? F : [0, F[1], [0, M0, z0]];
              }
              function rv(o, F) {
                return a(o[1][1 + nn], o, F);
              }
              function xR(o, F, m) {
                return ir(o[1][1 + nr], o, F, m);
              }
              function Sb(o, F, m) {
                return ir(o[1][1 + nr], o, F, m);
              }
              function aR(o, F, m) {
                var O = m[2], H = O[2], $7 = O[1], r0 = ir(o[1][1 + Z], o, F, $7), M0 = a(o[1][1 + s0], o, H);
                return r0 === $7 && H === M0 ? m : [0, m[1], [0, r0, M0]];
              }
              function gb(o, F, m) {
                return ir(o[1][1 + nr], o, F, m);
              }
              function oR(o, F, m) {
                var O = m[2], H = O[2], $7 = O[1], r0 = ir(o[1][1 + b0], o, F, $7), M0 = ze(u(o[1][1 + nn], o), H);
                return $7 === r0 && H === M0 ? m : [0, m[1], [0, r0, M0]];
              }
              function Fb(o, F, m) {
                switch (m[0]) {
                  case 0:
                    var O = function(M0) {
                      return [0, M0];
                    }, H = m[1];
                    return ee(a(o[1][1 + O0], o, F), H, m, O);
                  case 1:
                    var $7 = function(M0) {
                      return [1, M0];
                    }, r0 = m[1];
                    return ee(a(o[1][1 + p0], o, F), r0, m, $7);
                  default:
                    return m;
                }
              }
              function cR(o, F, m) {
                return ir(o[1][1 + nr], o, F, m);
              }
              function Bn(o, F, m) {
                return ir(o[1][1 + nr], o, F, m);
              }
              function v_(o, F, m) {
                var O = m[2], H = O[2], $7 = O[1], r0 = ir(o[1][1 + fe], o, F, $7), M0 = a(o[1][1 + s0], o, H);
                return r0 === $7 && H === M0 ? m : [0, m[1], [0, r0, M0]];
              }
              function sR(o, F, m) {
                return a(o[1][1 + An], o, m);
              }
              function vR(o, F, m) {
                return ir(o[1][1 + j0], o, F, m);
              }
              function ev(o, F, m) {
                var O = m[1];
                function H(r0) {
                  return [0, O, r0];
                }
                var $7 = m[2];
                return te(a(o[1][1 + er], o, F), O, $7, m, H);
              }
              function Tb(o, F, m) {
                switch (m[0]) {
                  case 0:
                    var O = function(Nr) {
                      return [0, Nr];
                    }, H = m[1];
                    return ee(a(o[1][1 + L], o, F), H, m, O);
                  case 1:
                    var $7 = function(Nr) {
                      return [1, Nr];
                    }, r0 = m[1];
                    return ee(a(o[1][1 + i0], o, F), r0, m, $7);
                  default:
                    var M0 = function(Nr) {
                      return [2, Nr];
                    }, z0 = m[1];
                    return ee(a(o[1][1 + l0], o, F), z0, m, M0);
                }
              }
              function l_(o, F, m) {
                var O = m[2], H = O[4], $7 = O[3], r0 = O[2], M0 = O[1], z0 = ir(o[1][1 + Q], o, F, M0), Nr = ir(o[1][1 + P], o, F, r0), Gr = ze(u(o[1][1 + nn], o), $7);
                if (H) {
                  var Fe = 0;
                  if (z0[0] === 1) {
                    var ye = Nr[2];
                    if (ye[0] === 2)
                      var yn = Un(z0[1][2][1], ye[1][1][2][1]);
                    else
                      Fe = 1;
                  } else
                    Fe = 1;
                  if (Fe)
                    var Rn = M0 === z0 ? 1 : 0, yn = Rn && (r0 === Nr ? 1 : 0);
                } else
                  var yn = H;
                return z0 === M0 && Nr === r0 && Gr === $7 && H === yn ? m : [0, m[1], [0, z0, Nr, Gr, yn]];
              }
              function Ob(o, F, m) {
                if (m[0] === 0) {
                  var O = function(M0) {
                    return [0, M0];
                  }, H = m[1];
                  return ee(a(o[1][1 + S0], o, F), H, m, O);
                }
                function $7(M0) {
                  return [1, M0];
                }
                var r0 = m[1];
                return ee(a(o[1][1 + v0], o, F), r0, m, $7);
              }
              function lR(o, F, m, O) {
                return ir(o[1][1 + J0], o, m, O);
              }
              function b_(o, F, m) {
                return a(o[1][1 + pt], o, m);
              }
              function bR(o, F, m) {
                var O = m[2];
                switch (O[0]) {
                  case 0:
                    var H = O[1], $7 = H[3], r0 = H[2], M0 = H[1], z0 = Hn(a(o[1][1 + T0], o, F), M0), Nr = a(o[1][1 + x0], o, r0), Gr = a(o[1][1 + s0], o, $7), Fe = 0;
                    if (z0 === M0 && Nr === r0 && Gr === $7) {
                      var ye = O;
                      Fe = 1;
                    }
                    if (!Fe)
                      var ye = [0, [0, z0, Nr, Gr]];
                    var $i = ye;
                    break;
                  case 1:
                    var Rn = O[1], yn = Rn[3], at = Rn[2], _t = Rn[1], Et = Hn(a(o[1][1 + q0], o, F), _t), Wn = a(o[1][1 + x0], o, at), Qt = a(o[1][1 + s0], o, yn), J7 = 0;
                    if (yn === Qt && Et === _t && Wn === at) {
                      var $72 = O;
                      J7 = 1;
                    }
                    if (!J7)
                      var $72 = [1, [0, Et, Wn, Qt]];
                    var $i = $72;
                    break;
                  case 2:
                    var E7 = O[1], Z7 = E7[2], Q7 = E7[1], ri = ir(o[1][1 + j0], o, F, Q7), ei = a(o[1][1 + x0], o, Z7), ni = 0;
                    if (Q7 === ri && Z7 === ei) {
                      var Ji = O;
                      ni = 1;
                    }
                    if (!ni)
                      var Ji = [2, [0, ri, ei, E7[3]]];
                    var $i = Ji;
                    break;
                  default:
                    var uv = function(fv) {
                      return [3, fv];
                    }, iv = O[1], $i = ee(u(o[1][1 + B], o), iv, O, uv);
                }
                return O === $i ? m : [0, m[1], $i];
              }
              function p_(o, F) {
                return ir(o[1][1 + nr], o, 0, F);
              }
              function Ib(o, F, m) {
                var O = F && F[1];
                return ir(o[1][1 + nr], o, [0, O], m);
              }
              function m_(o, F) {
                return a(o[1][1 + m2], o, F);
              }
              function pR(o, F) {
                return a(o[1][1 + m2], o, F);
              }
              function __(o, F) {
                return ir(o[1][1 + r1], o, I6r, F);
              }
              function Ab(o, F, m) {
                return ir(o[1][1 + r1], o, [0, F], m);
              }
              function mR(o, F) {
                return ir(o[1][1 + r1], o, O6r, F);
              }
              function _R(o, F, m) {
                var O = m[5], H = m[4], $7 = m[3], r0 = m[2], M0 = m[1], z0 = a(o[1][1 + Kc], o, M0), Nr = ze(u(o[1][1 + V], o), r0), Gr = ze(u(o[1][1 + t0], o), $7), Fe = ze(u(o[1][1 + t0], o), H), ye = a(o[1][1 + s0], o, O);
                return M0 === z0 && $7 === Gr && r0 === Nr && $7 === Gr && H === Fe && O === ye ? m : [0, z0, Nr, Gr, Fe, ye];
              }
              function yR(o, F) {
                return a(o[1][1 + An], o, F);
              }
              function Nb(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function dR(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + J0], o), m, H, F, O);
              }
              function hR(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = function(Gr) {
                      return [0, Gr];
                    }, O = F[1];
                    return ee(u(o[1][1 + pe], o), O, F, m);
                  case 1:
                    var H = function(Gr) {
                      return [1, Gr];
                    }, $7 = F[1];
                    return ee(u(o[1][1 + oe], o), $7, F, H);
                  case 2:
                    var r0 = function(Gr) {
                      return [2, Gr];
                    }, M0 = F[1];
                    return ee(u(o[1][1 + or], o), M0, F, r0);
                  default:
                    var z0 = function(Gr) {
                      return [3, Gr];
                    }, Nr = F[1];
                    return ee(u(o[1][1 + me], o), Nr, F, z0);
                }
              }
              function y_(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + ae], o, r0), z0 = a(o[1][1 + nn], o, $7);
                    if (H) {
                      var Nr = 0;
                      if (M0[0] === 1) {
                        var Gr = z0[2];
                        if (Gr[0] === 10)
                          var ye = Un(M0[1][2][1], Gr[1][2][1]);
                        else
                          Nr = 1;
                      } else
                        Nr = 1;
                      if (Nr)
                        var Fe = r0 === M0 ? 1 : 0, ye = Fe && ($7 === z0 ? 1 : 0);
                    } else
                      var ye = H;
                    return r0 === M0 && $7 === z0 && H === ye ? F : [0, O, [0, M0, z0, ye]];
                  case 1:
                    var Rn = m[2], yn = m[1], at = a(o[1][1 + ae], o, yn), _t = pu(u(o[1][1 + _e], o), Rn);
                    return yn === at && Rn === _t ? F : [0, O, [1, at, _t]];
                  case 2:
                    var Et = m[3], Wn = m[2], Qt = m[1], J7 = a(o[1][1 + ae], o, Qt), $72 = pu(u(o[1][1 + _e], o), Wn), E7 = a(o[1][1 + s0], o, Et);
                    return Qt === J7 && Wn === $72 && Et === E7 ? F : [0, O, [2, J7, $72, E7]];
                  default:
                    var Z7 = m[3], Q7 = m[2], ri = m[1], ei = a(o[1][1 + ae], o, ri), ni = pu(u(o[1][1 + _e], o), Q7), Ji = a(o[1][1 + s0], o, Z7);
                    return ri === ei && Q7 === ni && Z7 === Ji ? F : [0, O, [3, ei, ni, Ji]];
                }
              }
              function kR(o, F, m) {
                var O = m[2], H = m[1], $7 = Hn(function(M0) {
                  if (M0[0] === 0) {
                    var z0 = M0[1], Nr = a(o[1][1 + Qr], o, z0);
                    return z0 === Nr ? M0 : [0, Nr];
                  }
                  var Gr = M0[1], Fe = a(o[1][1 + xr], o, Gr);
                  return Gr === Fe ? M0 : [1, Fe];
                }, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function Cb(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + nn], o, r0), z0 = ze(u(o[1][1 + b2], o), $7), Nr = ze(u(o[1][1 + Zs], o), H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, Gr];
              }
              function wR(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + pt], o, $7), M0 = a(o[1][1 + pt], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function ER(o, F) {
                return a(o[1][1 + nn], o, F);
              }
              function d_(o, F) {
                return a(o[1][1 + or], o, F);
              }
              function SR(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function E2(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = function(z0) {
                      return [0, z0];
                    }, O = F[1];
                    return ee(u(o[1][1 + y0], o), O, F, m);
                  case 1:
                    var H = function(z0) {
                      return [1, z0];
                    }, $7 = F[1];
                    return ee(u(o[1][1 + D], o), $7, F, H);
                  default:
                    var r0 = function(z0) {
                      return [2, z0];
                    }, M0 = F[1];
                    return ee(u(o[1][1 + D0], o), M0, F, r0);
                }
              }
              function gR(o, F, m) {
                var O = m[1], H = ir(o[1][1 + u0], o, F, O);
                return O === H ? m : [0, H, m[2], m[3]];
              }
              function FR(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = a(o[1][1 + A0], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function TR(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = a(o[1][1 + nn], o, $7), M0 = a(o[1][1 + nn], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, m[1], r0, M0, z0];
              }
              function Pb(o, F, m) {
                var O = m[3], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, m[1], m[2], H];
              }
              function OR(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + Q0], o, $7), M0 = a(o[1][1 + Or], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function IR(o, F) {
                var m = F[2], O = m[2], H = a(o[1][1 + s0], o, O);
                return O === H ? F : [0, F[1], [0, m[1], H]];
              }
              function Db(o, F) {
                return a(o[1][1 + le], o, F);
              }
              function AR(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + K0], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + Ur], o), $7, F, H);
              }
              function NR(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + Pr], o, H), r0 = a(o[1][1 + d0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function du(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + d0], o, H), r0 = a(o[1][1 + d0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function hu(o, F) {
                return a(o[1][1 + Ur], o, F);
              }
              function Ii(o, F) {
                return a(o[1][1 + sr], o, F);
              }
              function w7(o, F) {
                return a(o[1][1 + d0], o, F);
              }
              function Wi(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = function(z0) {
                      return [0, z0];
                    }, O = F[1];
                    return ee(u(o[1][1 + le], o), O, F, m);
                  case 1:
                    var H = function(z0) {
                      return [1, z0];
                    }, $7 = F[1];
                    return ee(u(o[1][1 + xe], o), $7, F, H);
                  default:
                    var r0 = function(z0) {
                      return [2, z0];
                    }, M0 = F[1];
                    return ee(u(o[1][1 + je], o), M0, F, r0);
                }
              }
              function nv(o, F) {
                var m = F[2], O = F[1], H = a(o[1][1 + nn], o, O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, $7];
              }
              function Lb(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + s0], o, O);
                if (H) {
                  var r0 = H[1], M0 = a(o[1][1 + nn], o, r0);
                  return r0 === M0 && O === $7 ? m : [0, [0, M0], $7];
                }
                return O === $7 ? m : [0, 0, $7];
              }
              function tv(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = function(ye) {
                      return [0, O, [0, ye]];
                    }, $7 = m[1];
                    return te(u(o[1][1 + Me], o), O, $7, F, H);
                  case 1:
                    var r0 = function(ye) {
                      return [0, O, [1, ye]];
                    }, M0 = m[1];
                    return te(u(o[1][1 + Kr], o), O, M0, F, r0);
                  case 2:
                    var z0 = function(ye) {
                      return [0, O, [2, ye]];
                    }, Nr = m[1];
                    return te(u(o[1][1 + re], o), O, Nr, F, z0);
                  case 3:
                    var Gr = function(ye) {
                      return [0, O, [3, ye]];
                    }, Fe = m[1];
                    return ee(u(o[1][1 + F0], o), Fe, F, Gr);
                  default:
                    return F;
                }
              }
              function Rb(o, F) {
                var m = F[2], O = Hn(u(o[1][1 + Ke], o), m);
                return m === O ? F : [0, F[1], O];
              }
              function jb(o, F, m) {
                return ir(o[1][1 + J0], o, F, m);
              }
              function CR(o, F, m) {
                return ir(o[1][1 + re], o, F, m);
              }
              function Une(o, F) {
                if (F[0] === 0) {
                  var m = F[1], O = function(z0) {
                    return [0, m, z0];
                  }, H = F[2];
                  return te(u(o[1][1 + Ae], o), m, H, F, O);
                }
                var $7 = F[1];
                function r0(z0) {
                  return [1, $7, z0];
                }
                var M0 = F[2];
                return te(u(o[1][1 + on], o), $7, M0, F, r0);
              }
              function Hne(o, F) {
                return a(o[1][1 + sr], o, F);
              }
              function Xne(o, F) {
                return a(o[1][1 + d0], o, F);
              }
              function Yne(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + sn], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + kn], o), $7, F, H);
              }
              function Vne(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + Pe], o, H), r0 = ze(u(o[1][1 + rn], o), O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function zne(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function Kne(o, F) {
                if (F[0] === 0) {
                  var m = function(z0) {
                    return [0, z0];
                  }, O = F[1];
                  return ee(u(o[1][1 + We], o), O, F, m);
                }
                var H = F[1], $7 = H[1];
                function r0(z0) {
                  return [1, [0, $7, z0]];
                }
                var M0 = H[2];
                return te(u(o[1][1 + gr], o), $7, M0, F, r0);
              }
              function Wne(o, F) {
                var m = F[2][1], O = a(o[1][1 + Ie], o, m);
                return m === O ? F : [0, F[1], [0, O]];
              }
              function Jne(o, F) {
                var m = F[2], O = m[3], H = m[1], $7 = a(o[1][1 + Ie], o, H), r0 = Hn(u(o[1][1 + Cr], o), O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, m[2], r0]];
              }
              function $ne(o, F, m) {
                var O = m[4], H = m[3], $7 = a(o[1][1 + an], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, m[1], m[2], $7, r0];
              }
              function Zne(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + mr], o, r0), z0 = ze(u(o[1][1 + Be], o), $7), Nr = a(o[1][1 + an], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, Gr];
              }
              function Qne(o, F, m, O) {
                var H = 2 <= F ? a(o[1][1 + j0], o, T6r) : u(o[1][1 + Kc], o);
                return u(H, O);
              }
              function rte(o, F, m) {
                var O = 2 <= F ? a(o[1][1 + j0], o, F6r) : u(o[1][1 + Kc], o);
                return u(O, m);
              }
              function ete(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = 0;
                if (F) {
                  var M0 = 0;
                  if ($7)
                    switch ($7[1]) {
                      case 2:
                        break;
                      case 0:
                        r0 = 1, M0 = 2;
                        break;
                      default:
                        M0 = 1;
                    }
                  var z0 = 0;
                  switch (M0) {
                    case 2:
                      z0 = 1;
                      break;
                    case 0:
                      if (2 <= F) {
                        var Nr = 0, Gr = 0;
                        z0 = 1;
                      }
                      break;
                  }
                  if (!z0)
                    var Nr = 1, Gr = 0;
                } else
                  r0 = 1;
                if (r0)
                  var Nr = 1, Gr = 1;
                var Fe = a(Gr ? o[1][1 + m0] : o[1][1 + pt], o, O);
                if (H)
                  var ye = Nr ? u(o[1][1 + Kc], o) : a(o[1][1 + j0], o, g6r), Rn = function(at) {
                    return [0, at];
                  }, yn = ee(ye, H[1], H, Rn);
                else
                  var yn = H;
                return H === yn && O === Fe ? m : [0, $7, yn, Fe];
              }
              function nte(o, F, m) {
                if (m[0] === 0) {
                  var O = m[1], H = Hn(a(o[1][1 + Tt], o, F), O);
                  return O === H ? m : [0, H];
                }
                var $7 = m[1], r0 = $7[1];
                function M0(Nr) {
                  return [1, [0, r0, Nr]];
                }
                var z0 = $7[2];
                return te(a(o[1][1 + Ct], o, F), r0, z0, m, M0);
              }
              function tte(o, F, m) {
                var O = m[5], H = m[4], $7 = m[3], r0 = m[1], M0 = ze(a(o[1][1 + bt], o, r0), H), z0 = ze(a(o[1][1 + Zt], o, r0), $7), Nr = a(o[1][1 + s0], o, O);
                return H === M0 && $7 === z0 && O === Nr ? m : [0, r0, m[2], z0, M0, Nr];
              }
              function ute(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + _r], o, r0), z0 = ir(o[1][1 + yu], o, H !== 0 ? 1 : 0, $7), Nr = u(o[1][1 + Ku], o), Gr = ze(function(ye) {
                  return pu(Nr, ye);
                }, H), Fe = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Gr && O === Fe ? m : [0, M0, z0, Gr, Fe];
              }
              function ite(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + Or], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function fte(o, F, m) {
                return a(o[1][1 + Or], o, m);
              }
              function xte(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function ate(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function ote(o, F) {
                var m = F[2], O = m[2], H = a(o[1][1 + s0], o, O);
                return O === H ? F : [0, F[1], [0, m[1], H]];
              }
              function cte(o, F, m) {
                return ir(o[1][1 + Xn], o, F, m);
              }
              function ste(o, F, m) {
                var O = m[5], H = m[4], $7 = m[3], r0 = m[2], M0 = m[1], z0 = a(o[1][1 + Kc], o, M0), Nr = ze(u(o[1][1 + V], o), r0), Gr = u(o[1][1 + xu], o), Fe = Hn(function(yn) {
                  return pu(Gr, yn);
                }, $7), ye = pu(u(o[1][1 + qr], o), H), Rn = a(o[1][1 + s0], o, O);
                return z0 === M0 && Nr === r0 && Fe === $7 && ye === H && Rn === O ? m : [0, z0, Nr, Fe, ye, Rn];
              }
              function vte(o, F) {
                return a(o[1][1 + k0], o, F);
              }
              function lte(o, F) {
                return a(o[1][1 + k0], o, F);
              }
              function bte(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function pte(o, F) {
                var m = F[2], O = m[2], H = a(o[1][1 + s0], o, O);
                return O === H ? F : [0, F[1], [0, m[1], H]];
              }
              function mte(o, F, m) {
                return m;
              }
              function _te(o, F) {
                return ir(o[1][1 + j0], o, S6r, F);
              }
              function yte(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + Ki], o), m, H, F, O);
              }
              function dte(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + xt], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + nn], o), $7, F, H);
              }
              function hte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + Re], o, H), r0 = ze(u(o[1][1 + nn], o), O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function kte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + l], o, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function wte(o, F) {
                var m = F[2], O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = Hn(u(o[1][1 + Xe], o), $7), z0 = ze(u(o[1][1 + mt], o), H), Nr = ze(u(o[1][1 + W7], o), r0), Gr = a(o[1][1 + s0], o, O);
                return $7 === M0 && H === z0 && O === Gr && r0 === Nr ? F : [0, F[1], [0, Nr, M0, z0, Gr]];
              }
              function Ete(o, F, m) {
                var O = m[9], H = m[8], $7 = m[7], r0 = m[6], M0 = m[3], z0 = m[2], Nr = m[1], Gr = ze(u(o[1][1 + he], o), Nr), Fe = a(o[1][1 + U0], o, z0), ye = a(o[1][1 + x0], o, $7), Rn = a(o[1][1 + ft], o, M0), yn = ze(u(o[1][1 + Ir], o), r0), at = ze(u(o[1][1 + V], o), H), _t = a(o[1][1 + s0], o, O);
                return Nr === Gr && z0 === Fe && M0 === Rn && r0 === yn && $7 === ye && H === at && O === _t ? m : [0, Gr, Fe, Rn, m[4], m[5], yn, ye, at, _t, m[10]];
              }
              function Ste(o, F, m) {
                return ir(o[1][1 + Gn], o, F, m);
              }
              function gte(o, F, m) {
                return ir(o[1][1 + _e], o, F, m);
              }
              function Fte(o, F, m) {
                return ir(o[1][1 + Gn], o, F, m);
              }
              function Tte(o, F) {
                if (F[0] === 0)
                  return F;
                var m = F[1], O = a(o[1][1 + l], o, m);
                return O === m ? F : [1, O];
              }
              function Ote(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return ee(u(o[1][1 + t0], o), H, F, O);
              }
              function Ite(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = function($e) {
                      return [0, O, [0, $e]];
                    }, $7 = m[1];
                    return ee(u(o[1][1 + s0], o), $7, F, H);
                  case 1:
                    var r0 = function($e) {
                      return [0, O, [1, $e]];
                    }, M0 = m[1];
                    return ee(u(o[1][1 + s0], o), M0, F, r0);
                  case 2:
                    var z0 = function($e) {
                      return [0, O, [2, $e]];
                    }, Nr = m[1];
                    return ee(u(o[1][1 + s0], o), Nr, F, z0);
                  case 3:
                    var Gr = function($e) {
                      return [0, O, [3, $e]];
                    }, Fe = m[1];
                    return ee(u(o[1][1 + s0], o), Fe, F, Gr);
                  case 4:
                    var ye = function($e) {
                      return [0, O, [4, $e]];
                    }, Rn = m[1];
                    return ee(u(o[1][1 + s0], o), Rn, F, ye);
                  case 5:
                    var yn = function($e) {
                      return [0, O, [5, $e]];
                    }, at = m[1];
                    return ee(u(o[1][1 + s0], o), at, F, yn);
                  case 6:
                    var _t = function($e) {
                      return [0, O, [6, $e]];
                    }, Et = m[1];
                    return ee(u(o[1][1 + s0], o), Et, F, _t);
                  case 7:
                    var Wn = function($e) {
                      return [0, O, [7, $e]];
                    }, Qt = m[1];
                    return ee(u(o[1][1 + s0], o), Qt, F, Wn);
                  case 8:
                    var J7 = function($e) {
                      return [0, O, [8, $e]];
                    }, $72 = m[1];
                    return ee(u(o[1][1 + s0], o), $72, F, J7);
                  case 9:
                    var E7 = function($e) {
                      return [0, O, [9, $e]];
                    }, Z7 = m[1];
                    return ee(u(o[1][1 + s0], o), Z7, F, E7);
                  case 10:
                    var Q7 = function($e) {
                      return [0, O, [10, $e]];
                    }, ri = m[1];
                    return ee(u(o[1][1 + s0], o), ri, F, Q7);
                  case 11:
                    var ei = function($e) {
                      return [0, O, [11, $e]];
                    }, ni = m[1];
                    return ee(u(o[1][1 + k], o), ni, F, ei);
                  case 12:
                    var Ji = function($e) {
                      return [0, O, [12, $e]];
                    }, uv = m[1];
                    return te(u(o[1][1 + a7], o), O, uv, F, Ji);
                  case 13:
                    var iv = function($e) {
                      return [0, O, [13, $e]];
                    }, $i = m[1];
                    return te(u(o[1][1 + qr], o), O, $i, F, iv);
                  case 14:
                    var fv = function($e) {
                      return [0, O, [14, $e]];
                    }, Gb = m[1];
                    return te(u(o[1][1 + _n], o), O, Gb, F, fv);
                  case 15:
                    var Mb = function($e) {
                      return [0, O, [15, $e]];
                    }, Bb = m[1];
                    return ee(u(o[1][1 + e1], o), Bb, F, Mb);
                  case 16:
                    var qb = function($e) {
                      return [0, O, [16, $e]];
                    }, Ub = m[1];
                    return te(u(o[1][1 + xu], o), O, Ub, F, qb);
                  case 17:
                    var Hb = function($e) {
                      return [0, O, [17, $e]];
                    }, Xb = m[1];
                    return te(u(o[1][1 + On], o), O, Xb, F, Hb);
                  case 18:
                    var Yb = function($e) {
                      return [0, O, [18, $e]];
                    }, Vb = m[1];
                    return te(u(o[1][1 + vr], o), O, Vb, F, Yb);
                  case 19:
                    var zb = function($e) {
                      return [0, O, [19, $e]];
                    }, Kb = m[1];
                    return te(u(o[1][1 + h], o), O, Kb, F, zb);
                  case 20:
                    var Wb = function($e) {
                      return [0, O, [20, $e]];
                    }, Jb = m[1];
                    return te(u(o[1][1 + en], o), O, Jb, F, Wb);
                  case 21:
                    var $b = function($e) {
                      return [0, O, [21, $e]];
                    }, Zb = m[1];
                    return ee(u(o[1][1 + G], o), Zb, F, $b);
                  case 22:
                    var Qb = function($e) {
                      return [0, O, [22, $e]];
                    }, r4 = m[1];
                    return ee(u(o[1][1 + a0], o), r4, F, Qb);
                  case 23:
                    var e4 = function($e) {
                      return [0, O, [23, $e]];
                    }, n4 = m[1];
                    return te(u(o[1][1 + Lr], o), O, n4, F, e4);
                  case 24:
                    var t42 = function($e) {
                      return [0, O, [24, $e]];
                    }, u4 = m[1];
                    return te(u(o[1][1 + _], o), O, u4, F, t42);
                  case 25:
                    var i4 = function($e) {
                      return [0, O, [25, $e]];
                    }, f4 = m[1];
                    return te(u(o[1][1 + p2], o), O, f4, F, i4);
                  default:
                    var x4 = function($e) {
                      return [0, O, [26, $e]];
                    }, a4 = m[1];
                    return te(u(o[1][1 + x_], o), O, a4, F, x4);
                }
              }
              function Ate(o, F, m) {
                var O = m[2], H = m[1], $7 = H[3], r0 = H[2], M0 = H[1], z0 = a(o[1][1 + t0], o, M0), Nr = a(o[1][1 + t0], o, r0), Gr = Hn(u(o[1][1 + t0], o), $7), Fe = a(o[1][1 + s0], o, O);
                return z0 === M0 && Nr === r0 && Gr === $7 && Fe === O ? m : [0, [0, z0, Nr, Gr], Fe];
              }
              function Nte(o, F, m) {
                var O = m[2], H = m[1], $7 = H[3], r0 = H[2], M0 = H[1], z0 = a(o[1][1 + t0], o, M0), Nr = a(o[1][1 + t0], o, r0), Gr = Hn(u(o[1][1 + t0], o), $7), Fe = a(o[1][1 + s0], o, O);
                return z0 === M0 && Nr === r0 && Gr === $7 && Fe === O ? m : [0, [0, z0, Nr, Gr], Fe];
              }
              function Cte(o, F) {
                var m = F[2], O = F[1], H = a(o[1][1 + t0], o, O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, $7];
              }
              function Pte(o, F) {
                var m = F[2], O = F[1], H = Hn(u(o[1][1 + t0], o), O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, $7];
              }
              function Dte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + K], o, H), r0 = a(o[1][1 + S], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function Lte(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function Rte(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function jte(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + M], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + A], o), $7, F, H);
              }
              function Gte(o, F) {
                var m = F[2], O = F[1], H = a(o[1][1 + K], o, O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, $7];
              }
              function Mte(o, F) {
                var m = F[2], O = F[1], H = a(o[1][1 + t0], o, O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, $7];
              }
              function Bte(o, F, m) {
                var O = m[2], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, m[1], H];
              }
              function qte(o, F, m) {
                var O = m[3], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, m[1], m[2], H];
              }
              function Ute(o, F, m) {
                var O = m[3], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, m[1], m[2], H];
              }
              function Hte(o, F, m) {
                var O = m[3], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, m[1], m[2], H];
              }
              function Xte(o, F, m) {
                var O = m[1], H = ir(o[1][1 + On], o, F, O);
                return H === O ? m : [0, H, m[2]];
              }
              function Yte(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + t0], o, $7), M0 = a(o[1][1 + t0], o, H), z0 = a(o[1][1 + s0], o, O);
                return r0 === $7 && M0 === H && z0 === O ? m : [0, r0, M0, z0];
              }
              function Vte(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + K7], o, $7), M0 = ze(u(o[1][1 + e0], o), H), z0 = a(o[1][1 + s0], o, O);
                return r0 === $7 && M0 === H && z0 === O ? m : [0, r0, M0, z0];
              }
              function zte(o, F) {
                var m = F[2], O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + x0], o, $7), z0 = a(o[1][1 + c], o, H), Nr = ze(u(o[1][1 + t0], o), O), Gr = a(o[1][1 + Kc], o, r0);
                return Gr === r0 && M0 === $7 && z0 === H && Nr === O ? F : [0, F[1], [0, Gr, M0, z0, Nr]];
              }
              function Kte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + f0], o), H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function Wte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + t0], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function Jte(o, F) {
                return ze(u(o[1][1 + s], o), F);
              }
              function $te(o, F) {
                var m = F[2], O = m[2], H = a(o[1][1 + s0], o, O);
                return O === H ? F : [0, F[1], [0, m[1], H]];
              }
              function Zte(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function Qte(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + K7], o, H), r0 = a(o[1][1 + Y], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function rue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + m0], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + Gu], o), $7, F, H);
              }
              function eue(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = u(o[1][1 + xu], o), M0 = Hn(function(Gr) {
                  return pu(r0, Gr);
                }, H), z0 = pu(u(o[1][1 + qr], o), $7), Nr = a(o[1][1 + s0], o, O);
                return M0 === H && z0 === $7 && O === Nr ? m : [0, z0, M0, Nr];
              }
              function nue(o, F, m) {
                var O = m[4], H = m[3], $7 = Hn(function(M0) {
                  switch (M0[0]) {
                    case 0:
                      var z0 = function(Wn) {
                        return [0, Wn];
                      }, Nr = M0[1];
                      return ee(u(o[1][1 + ne], o), Nr, M0, z0);
                    case 1:
                      var Gr = function(Wn) {
                        return [1, Wn];
                      }, Fe = M0[1];
                      return ee(u(o[1][1 + jr], o), Fe, M0, Gr);
                    case 2:
                      var ye = function(Wn) {
                        return [2, Wn];
                      }, Rn = M0[1];
                      return ee(u(o[1][1 + ge], o), Rn, M0, ye);
                    case 3:
                      var yn = function(Wn) {
                        return [3, Wn];
                      }, at = M0[1];
                      return ee(u(o[1][1 + H0], o), at, M0, yn);
                    default:
                      var _t = function(Wn) {
                        return [4, Wn];
                      }, Et = M0[1];
                      return ee(u(o[1][1 + ce], o), Et, M0, _t);
                  }
                }, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && O === r0 ? m : [0, m[1], m[2], $7, r0];
              }
              function tue(o, F) {
                var m = F[2], O = m[3], H = m[1], $7 = H[2], r0 = H[1], M0 = ir(o[1][1 + a7], o, r0, $7), z0 = a(o[1][1 + s0], o, O);
                return $7 === M0 && O === z0 ? F : [0, F[1], [0, [0, r0, M0], m[2], z0]];
              }
              function uue(o, F) {
                var m = F[2], O = m[6], H = m[2], $7 = m[1], r0 = a(o[1][1 + pt], o, $7), M0 = a(o[1][1 + t0], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? F : [0, F[1], [0, r0, M0, m[3], m[4], m[5], z0]];
              }
              function iue(o, F) {
                var m = F[2], O = m[6], H = m[5], $7 = m[3], r0 = m[2], M0 = a(o[1][1 + t0], o, r0), z0 = a(o[1][1 + t0], o, $7), Nr = a(o[1][1 + c], o, H), Gr = a(o[1][1 + s0], o, O);
                return M0 === r0 && z0 === $7 && Nr === H && Gr === O ? F : [0, F[1], [0, m[1], M0, z0, m[4], Nr, Gr]];
              }
              function fue(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + t0], o, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function xue(o, F) {
                var m = F[2], O = m[8], H = m[7], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + ae], o, r0), z0 = a(o[1][1 + $r], o, $7), Nr = a(o[1][1 + c], o, H), Gr = a(o[1][1 + s0], o, O);
                return M0 === r0 && z0 === $7 && Nr === H && Gr === O ? F : [0, F[1], [0, M0, z0, m[3], m[4], m[5], m[6], Nr, Gr]];
              }
              function aue(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + a7], o), m, H, F, O);
              }
              function oue(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + a7], o), m, H, F, O);
              }
              function cue(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = function(z0) {
                      return [0, z0];
                    }, O = F[1];
                    return ee(u(o[1][1 + t0], o), O, F, m);
                  case 1:
                    var H = function(z0) {
                      return [1, z0];
                    }, $7 = F[1];
                    return ee(u(o[1][1 + Br], o), $7, F, H);
                  default:
                    var r0 = function(z0) {
                      return [2, z0];
                    }, M0 = F[1];
                    return ee(u(o[1][1 + Mr], o), M0, F, r0);
                }
              }
              function sue(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function vue(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = $7[2], M0 = r0[4], z0 = r0[3], Nr = r0[2], Gr = r0[1], Fe = m[1], ye = ze(u(o[1][1 + Yc], o), Gr), Rn = Hn(u(o[1][1 + R0], o), Nr), yn = ze(u(o[1][1 + Ht], o), z0), at = a(o[1][1 + t0], o, H), _t = ze(u(o[1][1 + V], o), Fe), Et = a(o[1][1 + s0], o, O), Wn = a(o[1][1 + s0], o, M0);
                return Rn === Nr && yn === z0 && at === H && _t === Fe && Et === O && Wn === M0 && ye === Gr ? m : [0, _t, [0, $7[1], [0, ye, Rn, yn, Wn]], at, Et];
              }
              function lue(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + l], o, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function bue(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + R0], o, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && r0 === O ? F : [0, F[1], [0, $7, r0]];
              }
              function pue(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + t0], o, O), r0 = ze(u(o[1][1 + pt], o), H);
                return $7 === O && r0 === H ? F : [0, F[1], [0, r0, $7, m[3]]];
              }
              function mue(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + T], o), m, H, F, O);
              }
              function _ue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + Ti], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + nn], o), $7, F, H);
              }
              function yue(o, F, m) {
                var O = m[5], H = m[4], $7 = m[3], r0 = m[2], M0 = m[1], z0 = ze(u(o[1][1 + tt], o), M0), Nr = ze(u(o[1][1 + _r], o), r0), Gr = ze(u(o[1][1 + nn], o), $7), Fe = a(o[1][1 + Or], o, H), ye = a(o[1][1 + s0], o, O);
                return M0 === z0 && r0 === Nr && $7 === Gr && H === Fe && O === ye ? m : [0, z0, Nr, Gr, Fe, ye];
              }
              function due(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + T], o), m, H, F, O);
              }
              function hue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + ut], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + It], o), $7, F, H);
              }
              function kue(o, F, m) {
                var O = m[5], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + un], o, r0), z0 = a(o[1][1 + nn], o, $7), Nr = a(o[1][1 + Or], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, m[4], Gr];
              }
              function wue(o, F) {
                var m = F[1];
                function O($7) {
                  return [0, m, $7];
                }
                var H = F[2];
                return te(u(o[1][1 + T], o), m, H, F, O);
              }
              function Eue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + Vs], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + zi], o), $7, F, H);
              }
              function Sue(o, F, m) {
                var O = m[5], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + hs], o, r0), z0 = a(o[1][1 + nn], o, $7), Nr = a(o[1][1 + Or], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, m[4], Gr];
              }
              function gue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + nn], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + Rr], o), $7, F, H);
              }
              function Fue(o, F, m) {
                var O = m[3], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, m[2], r0];
              }
              function Tue(o, F) {
                if (F[0] === 0) {
                  var m = F[1], O = Hn(u(o[1][1 + Ws], o), m);
                  return m === O ? F : [0, O];
                }
                var H = F[1], $7 = a(o[1][1 + U9], o, H);
                return H === $7 ? F : [1, $7];
              }
              function Oue(o, F) {
                var m = F[2], O = ze(u(o[1][1 + pt], o), m);
                return m === O ? F : [0, F[1], O];
              }
              function Iue(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + pt], o, H), r0 = ze(u(o[1][1 + pt], o), O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function Aue(o, F, m) {
                var O = m[5], H = m[2], $7 = m[1], r0 = ze(u(o[1][1 + si], o), H), M0 = ze(u(o[1][1 + Or], o), $7), z0 = a(o[1][1 + s0], o, O);
                return H === r0 && $7 === M0 && O === z0 ? m : [0, M0, r0, m[3], m[4], z0];
              }
              function Nue(o, F) {
                if (F[0] === 0) {
                  var m = function(r0) {
                    return [0, r0];
                  }, O = F[1];
                  return ee(u(o[1][1 + Or], o), O, F, m);
                }
                function H(r0) {
                  return [1, r0];
                }
                var $7 = F[1];
                return ee(u(o[1][1 + nn], o), $7, F, H);
              }
              function Cue(o, F, m) {
                var O = m[3], H = m[2], $7 = a(o[1][1 + B9], o, H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && r0 === O ? m : [0, m[1], $7, r0];
              }
              function Pue(o, F) {
                return a(o[1][1 + pt], o, F);
              }
              function Due(o, F) {
                var m = F[2], O = m[1], H = a(o[1][1 + X1], o, O);
                return O === H ? F : [0, F[1], [0, H, m[2]]];
              }
              function Lue(o, F) {
                var m = F[2], O = m[1], H = a(o[1][1 + X1], o, O);
                return O === H ? F : [0, F[1], [0, H, m[2]]];
              }
              function Rue(o, F) {
                var m = F[2], O = m[1], H = a(o[1][1 + X1], o, O);
                return O === H ? F : [0, F[1], [0, H, m[2]]];
              }
              function jue(o, F) {
                var m = F[2][1], O = a(o[1][1 + X1], o, m);
                return m === O ? F : [0, F[1], [0, O]];
              }
              function Gue(o, F) {
                var m = F[3], O = F[1], H = Hn(u(o[1][1 + vi], o), O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, F[2], $7];
              }
              function Mue(o, F) {
                var m = F[4], O = F[1];
                if (O[0] === 0)
                  var H = function(ye) {
                    return [0, ye];
                  }, $7 = O[1], r0 = u(o[1][1 + vi], o), Gr = ee(function(ye) {
                    return Hn(r0, ye);
                  }, $7, O, H);
                else
                  var M0 = function(ye) {
                    return [1, ye];
                  }, z0 = O[1], Nr = u(o[1][1 + s2], o), Gr = ee(function(ye) {
                    return Hn(Nr, ye);
                  }, z0, O, M0);
                var Fe = a(o[1][1 + s0], o, m);
                return O === Gr && m === Fe ? F : [0, Gr, F[2], F[3], Fe];
              }
              function Bue(o, F) {
                var m = F[4], O = F[1], H = Hn(u(o[1][1 + X9], o), O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, F[2], F[3], $7];
              }
              function que(o, F) {
                var m = F[4], O = F[1], H = Hn(u(o[1][1 + cb], o), O), $7 = a(o[1][1 + s0], o, m);
                return O === H && m === $7 ? F : [0, H, F[2], F[3], $7];
              }
              function Uue(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = function(ye) {
                      return [0, O, [0, ye]];
                    }, $7 = m[1];
                    return ee(u(o[1][1 + sb], o), $7, F, H);
                  case 1:
                    var r0 = function(ye) {
                      return [0, O, [1, ye]];
                    }, M0 = m[1];
                    return ee(u(o[1][1 + Y9], o), M0, F, r0);
                  case 2:
                    var z0 = function(ye) {
                      return [0, O, [2, ye]];
                    }, Nr = m[1];
                    return ee(u(o[1][1 + H9], o), Nr, F, z0);
                  default:
                    var Gr = function(ye) {
                      return [0, O, [3, ye]];
                    }, Fe = m[1];
                    return ee(u(o[1][1 + Js], o), Fe, F, Gr);
                }
              }
              function Hue(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = ir(o[1][1 + j0], o, E6r, $7), M0 = a(o[1][1 + V9], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function Xue(o, F, m) {
                var O = m[1], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, H];
              }
              function Yue(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + Or], o, $7), M0 = a(o[1][1 + _r], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function Vue(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = ir(o[1][1 + j0], o, w6r, $7), M0 = a(o[1][1 + l], o, H), z0 = a(o[1][1 + s0], o, O);
                return r0 === $7 && M0 === H && z0 === O ? m : [0, r0, M0, z0];
              }
              function zue(o, F, m) {
                return ir(o[1][1 + c0], o, F, m);
              }
              function Kue(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + l], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function Wue(o, F, m) {
                var O = m[4], H = m[2], $7 = pu(u(o[1][1 + Ki], o), H), r0 = a(o[1][1 + s0], o, O);
                return $7 === H && O === r0 ? m : [0, m[1], $7, m[3], r0];
              }
              function Jue(o, F, m) {
                return ir(o[1][1 + Xn], o, F, m);
              }
              function $ue(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + he], o, r0), z0 = a(o[1][1 + l], o, $7), Nr = ze(u(o[1][1 + Ir], o), H), Gr = a(o[1][1 + s0], o, O);
                return M0 === r0 && z0 === $7 && Nr === H && Gr === O ? m : [0, M0, z0, Nr, Gr];
              }
              function Zue(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = F[1], O = m[2], H = m[1], $7 = ir(o[1][1 + vb], o, H, O);
                    return $7 === O ? F : [0, [0, H, $7]];
                  case 1:
                    var r0 = F[1], M0 = r0[2], z0 = r0[1], Nr = ir(o[1][1 + lb], o, z0, M0);
                    return Nr === M0 ? F : [1, [0, z0, Nr]];
                  case 2:
                    var Gr = F[1], Fe = Gr[2], ye = Gr[1], Rn = ir(o[1][1 + v2], o, ye, Fe);
                    return Rn === Fe ? F : [2, [0, ye, Rn]];
                  case 3:
                    var yn = F[1], at = a(o[1][1 + t0], o, yn);
                    return at === yn ? F : [3, at];
                  case 4:
                    var _t = F[1], Et = _t[2], Wn = _t[1], Qt = ir(o[1][1 + c0], o, Wn, Et);
                    return Qt === Et ? F : [4, [0, Wn, Qt]];
                  case 5:
                    var J7 = F[1], $72 = J7[2], E7 = J7[1], Z7 = ir(o[1][1 + Sr], o, E7, $72);
                    return Z7 === $72 ? F : [5, [0, E7, Z7]];
                  default:
                    var Q7 = F[1], ri = Q7[2], ei = Q7[1], ni = ir(o[1][1 + Xn], o, ei, ri);
                    return ni === ri ? F : [6, [0, ei, ni]];
                }
              }
              function Que(o, F, m) {
                var O = m[5], H = m[3], $7 = m[2], r0 = ze(u(o[1][1 + si], o), H), M0 = ze(u(o[1][1 + Q9], o), $7), z0 = a(o[1][1 + s0], o, O);
                return H === r0 && $7 === M0 && O === z0 ? m : [0, m[1], M0, r0, m[4], z0];
              }
              function r7e(o, F, m) {
                var O = m[7], H = m[6], $7 = m[5], r0 = m[4], M0 = m[3], z0 = m[2], Nr = m[1], Gr = a(o[1][1 + db], o, Nr), Fe = ze(u(o[1][1 + V], o), z0), ye = pu(u(o[1][1 + qr], o), M0), Rn = u(o[1][1 + xu], o), yn = ze(function(Qt) {
                  return pu(Rn, Qt);
                }, r0), at = u(o[1][1 + xu], o), _t = Hn(function(Qt) {
                  return pu(at, Qt);
                }, $7), Et = ze(u(o[1][1 + l2], o), H), Wn = a(o[1][1 + s0], o, O);
                return Gr === Nr && Fe === z0 && ye === M0 && yn === r0 && _t === $7 && Et === H && Wn === O ? m : [0, Gr, Fe, ye, yn, _t, Et, Wn];
              }
              function e7e(o, F, m) {
                var O = m[1], H = a(o[1][1 + s0], o, O);
                return O === H ? m : [0, H];
              }
              function n7e(o, F, m) {
                var O = m[2], H = m[1], $7 = ze(u(o[1][1 + Q0], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function t7e(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + _r], o, r0), z0 = a(o[1][1 + nn], o, $7), Nr = a(o[1][1 + nn], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, Gr];
              }
              function u7e(o, F, m) {
                return m;
              }
              function i7e(o, F, m) {
                var O = m[6], H = m[5], $7 = m[3], r0 = m[2], M0 = m[1], z0 = a(o[1][1 + or], o, M0), Nr = a(o[1][1 + _b], o, r0), Gr = a(o[1][1 + x0], o, $7), Fe = a(o[1][1 + c], o, H), ye = a(o[1][1 + s0], o, O);
                return M0 === z0 && r0 === Nr && Gr === $7 && Fe === H && ye === O ? m : [0, z0, Nr, Gr, m[4], Fe, ye];
              }
              function f7e(o, F) {
                if (typeof F == "number")
                  return F;
                var m = F[1], O = a(o[1][1 + nn], o, m);
                return m === O ? F : [0, O];
              }
              function x7e(o, F, m) {
                var O = m[6], H = m[5], $7 = m[3], r0 = m[2], M0 = m[1], z0 = a(o[1][1 + ae], o, M0), Nr = a(o[1][1 + _b], o, r0), Gr = a(o[1][1 + x0], o, $7), Fe = a(o[1][1 + c], o, H), ye = a(o[1][1 + s0], o, O);
                return M0 === z0 && r0 === Nr && Gr === $7 && Fe === H && ye === O ? m : [0, z0, Nr, Gr, m[4], Fe, ye];
              }
              function a7e(o, F, m) {
                var O = m[6], H = m[5], $7 = m[3], r0 = m[2], M0 = a(o[1][1 + ae], o, r0), z0 = pu(u(o[1][1 + _e], o), $7), Nr = Hn(u(o[1][1 + hb], o), H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, m[1], M0, z0, m[4], Nr, Gr];
              }
              function o7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + m0], o, H), r0 = ze(u(o[1][1 + e0], o), O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function c7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + e_], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function s7e(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = F[1], O = m[1], H = function(yn) {
                      return [0, [0, O, yn]];
                    }, $7 = m[2];
                    return te(u(o[1][1 + Vc], o), O, $7, F, H);
                  case 1:
                    var r0 = F[1], M0 = r0[1], z0 = function(yn) {
                      return [1, [0, M0, yn]];
                    }, Nr = r0[2];
                    return te(u(o[1][1 + yb], o), M0, Nr, F, z0);
                  default:
                    var Gr = F[1], Fe = Gr[1], ye = function(yn) {
                      return [2, [0, Fe, yn]];
                    }, Rn = Gr[2];
                    return te(u(o[1][1 + r_], o), Fe, Rn, F, ye);
                }
              }
              function v7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = a(o[1][1 + nn], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function l7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + $s], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function b7e(o, F) {
                return ir(o[1][1 + j0], o, k6r, F);
              }
              function p7e(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + nn], o, $7), M0 = ze(u(o[1][1 + e0], o), H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function m7e(o, F, m) {
                var O = m[7], H = m[6], $7 = m[5], r0 = m[4], M0 = m[3], z0 = m[2], Nr = m[1], Gr = ze(u(o[1][1 + db], o), Nr), Fe = a(o[1][1 + t_], o, z0), ye = ze(u(o[1][1 + V], o), M0), Rn = u(o[1][1 + zc], o), yn = ze(function(Wn) {
                  return pu(Rn, Wn);
                }, r0), at = ze(u(o[1][1 + l2], o), $7), _t = Hn(u(o[1][1 + hb], o), H), Et = a(o[1][1 + s0], o, O);
                return Nr === Gr && z0 === Fe && r0 === yn && $7 === at && H === _t && O === Et && M0 === ye ? m : [0, Gr, Fe, ye, yn, at, _t, Et];
              }
              function _7e(o, F, m) {
                return ir(o[1][1 + ks], o, F, m);
              }
              function y7e(o, F, m) {
                return ir(o[1][1 + ks], o, F, m);
              }
              function d7e(o, F, m) {
                var O = m[3], H = m[2], $7 = m[1], r0 = ze(u(o[1][1 + u_], o), $7), M0 = a(o[1][1 + i_], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, r0, M0, z0];
              }
              function h7e(o, F) {
                return pu(u(o[1][1 + Ki], o), F);
              }
              function k7e(o, F) {
                if (F[0] === 0) {
                  var m = F[1], O = a(o[1][1 + t0], o, m);
                  return O === m ? F : [0, O];
                }
                var H = F[1], $7 = H[2][1], r0 = a(o[1][1 + s0], o, $7);
                return $7 === r0 ? F : [1, [0, H[1], [0, r0]]];
              }
              function w7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + f_], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function E7e(o, F, m) {
                var O = m[1], H = ir(o[1][1 + kb], o, F, O);
                return O === H ? m : [0, H, m[2], m[3]];
              }
              function S7e(o, F) {
                var m = F[2], O = m[2], H = m[1], $7 = Hn(u(o[1][1 + Ks], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? F : [0, F[1], [0, $7, r0]];
              }
              function g7e(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = m[1], M0 = a(o[1][1 + nn], o, r0), z0 = ze(u(o[1][1 + b2], o), $7), Nr = a(o[1][1 + Zs], o, H), Gr = a(o[1][1 + s0], o, O);
                return r0 === M0 && $7 === z0 && H === Nr && O === Gr ? m : [0, M0, z0, Nr, Gr];
              }
              function F7e(o, F, m) {
                var O = m[2], H = m[1], $7 = ze(u(o[1][1 + Q0], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function T7e(o, F, m) {
                var O = m[2], H = m[1], $7 = a(o[1][1 + Tr], o, H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function O7e(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = a(o[1][1 + nn], o, $7), M0 = a(o[1][1 + nn], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, m[1], r0, M0, z0];
              }
              function I7e(o, F, m) {
                var O = m[4], H = m[3], $7 = m[2], r0 = a(o[1][1 + m2], o, $7), M0 = a(o[1][1 + nn], o, H), z0 = a(o[1][1 + s0], o, O);
                return $7 === r0 && H === M0 && O === z0 ? m : [0, m[1], r0, M0, z0];
              }
              function A7e(o, F, m) {
                return ir(o[1][1 + Gn], o, F, m);
              }
              function N7e(o, F) {
                switch (F[0]) {
                  case 0:
                    var m = function(r0) {
                      return [0, r0];
                    }, O = F[1];
                    return ee(u(o[1][1 + nn], o), O, F, m);
                  case 1:
                    var H = function(r0) {
                      return [1, r0];
                    }, $7 = F[1];
                    return ee(u(o[1][1 + Rr], o), $7, F, H);
                  default:
                    return F;
                }
              }
              function C7e(o, F, m) {
                var O = m[2], H = m[1], $7 = Hn(u(o[1][1 + c_], o), H), r0 = a(o[1][1 + s0], o, O);
                return H === $7 && O === r0 ? m : [0, $7, r0];
              }
              function P7e(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = function(He) {
                      return [0, O, [0, He]];
                    }, $7 = m[1];
                    return te(u(o[1][1 + y2], o), O, $7, F, H);
                  case 1:
                    var r0 = function(He) {
                      return [0, O, [1, He]];
                    }, M0 = m[1];
                    return te(u(o[1][1 + o_], o), O, M0, F, r0);
                  case 2:
                    var z0 = function(He) {
                      return [0, O, [2, He]];
                    }, Nr = m[1];
                    return te(u(o[1][1 + _2], o), O, Nr, F, z0);
                  case 3:
                    var Gr = function(He) {
                      return [0, O, [3, He]];
                    }, Fe = m[1];
                    return te(u(o[1][1 + a_], o), O, Fe, F, Gr);
                  case 4:
                    var ye = function(He) {
                      return [0, O, [4, He]];
                    }, Rn = m[1];
                    return te(u(o[1][1 + kb], o), O, Rn, F, ye);
                  case 5:
                    var yn = function(He) {
                      return [0, O, [5, He]];
                    }, at = m[1];
                    return te(u(o[1][1 + n_], o), O, at, F, yn);
                  case 6:
                    var _t = function(He) {
                      return [0, O, [6, He]];
                    }, Et = m[1];
                    return te(u(o[1][1 + Mn], o), O, Et, F, _t);
                  case 7:
                    var Wn = function(He) {
                      return [0, O, [7, He]];
                    }, Qt = m[1];
                    return te(u(o[1][1 + mb], o), O, Qt, F, Wn);
                  case 8:
                    var J7 = function(He) {
                      return [0, O, [8, He]];
                    }, $72 = m[1];
                    return te(u(o[1][1 + rt], o), O, $72, F, J7);
                  case 9:
                    var E7 = function(He) {
                      return [0, O, [9, He]];
                    }, Z7 = m[1];
                    return te(u(o[1][1 + Vi], o), O, Z7, F, E7);
                  case 10:
                    var Q7 = function(He) {
                      return [0, O, [10, He]];
                    }, ri = m[1];
                    return ee(u(o[1][1 + pt], o), ri, F, Q7);
                  case 11:
                    var ei = function(He) {
                      return [0, O, [11, He]];
                    }, ni = m[1];
                    return ee(a(o[1][1 + Ot], o, O), ni, F, ei);
                  case 12:
                    var Ji = function(He) {
                      return [0, O, [12, He]];
                    }, uv = m[1];
                    return te(u(o[1][1 + Me], o), O, uv, F, Ji);
                  case 13:
                    var iv = function(He) {
                      return [0, O, [13, He]];
                    }, $i = m[1];
                    return te(u(o[1][1 + Kr], o), O, $i, F, iv);
                  case 14:
                    var fv = function(He) {
                      return [0, O, [14, He]];
                    }, Gb = m[1];
                    return te(u(o[1][1 + J0], o), O, Gb, F, fv);
                  case 15:
                    var Mb = function(He) {
                      return [0, O, [15, He]];
                    }, Bb = m[1];
                    return te(u(o[1][1 + Y0], o), O, Bb, F, Mb);
                  case 16:
                    var qb = function(He) {
                      return [0, O, [16, He]];
                    }, Ub = m[1];
                    return te(u(o[1][1 + u0], o), O, Ub, F, qb);
                  case 17:
                    var Hb = function(He) {
                      return [0, O, [17, He]];
                    }, Xb = m[1];
                    return te(u(o[1][1 + U], o), O, Xb, F, Hb);
                  case 18:
                    var Yb = function(He) {
                      return [0, O, [18, He]];
                    }, Vb = m[1];
                    return te(u(o[1][1 + I], o), O, Vb, F, Yb);
                  case 19:
                    var zb = function(He) {
                      return [0, O, [19, He]];
                    }, Kb = m[1];
                    return te(u(o[1][1 + Fr], o), O, Kb, F, zb);
                  case 20:
                    var Wb = function(He) {
                      return [0, O, [20, He]];
                    }, Jb = m[1];
                    return ee(a(o[1][1 + $0], o, O), Jb, F, Wb);
                  case 21:
                    var $b = function(He) {
                      return [0, O, [21, He]];
                    }, Zb = m[1];
                    return te(u(o[1][1 + yr], o), O, Zb, F, $b);
                  case 22:
                    var Qb = function(He) {
                      return [0, O, [22, He]];
                    }, r4 = m[1];
                    return te(u(o[1][1 + Wr], o), O, r4, F, Qb);
                  case 23:
                    var e4 = function(He) {
                      return [0, O, [23, He]];
                    }, n4 = m[1];
                    return te(u(o[1][1 + W0], o), O, n4, F, e4);
                  case 24:
                    var t42 = function(He) {
                      return [0, O, [24, He]];
                    }, u4 = m[1];
                    return te(u(o[1][1 + X], o), O, u4, F, t42);
                  case 25:
                    var i4 = function(He) {
                      return [0, O, [25, He]];
                    }, f4 = m[1];
                    return te(u(o[1][1 + G0], o), O, f4, F, i4);
                  case 26:
                    var x4 = function(He) {
                      return [0, O, [26, He]];
                    }, a4 = m[1];
                    return te(u(o[1][1 + X0], o), O, a4, F, x4);
                  case 27:
                    var $e = function(He) {
                      return [0, O, [27, He]];
                    }, PR = m[1];
                    return te(u(o[1][1 + g0], o), O, PR, F, $e);
                  case 28:
                    var DR = function(He) {
                      return [0, O, [28, He]];
                    }, LR = m[1];
                    return te(u(o[1][1 + w], o), O, LR, F, DR);
                  case 29:
                    var RR = function(He) {
                      return [0, O, [29, He]];
                    }, jR = m[1];
                    return te(u(o[1][1 + E], o), O, jR, F, RR);
                  default:
                    var GR = function(He) {
                      return [0, O, [30, He]];
                    }, MR = m[1];
                    return te(u(o[1][1 + e], o), O, MR, F, GR);
                }
              }
              function D7e(o, F) {
                var m = F[2], O = F[1], H = Hn(u(o[1][1 + V1], o), O), $7 = Hn(u(o[1][1 + V1], o), m);
                return O === H && m === $7 ? F : [0, H, $7, F[3]];
              }
              var L7e = 8;
              function R7e(o, F) {
                return F;
              }
              function j7e(o, F) {
                var m = F[2], O = F[1];
                switch (m[0]) {
                  case 0:
                    var H = function(Oe) {
                      return [0, O, [0, Oe]];
                    }, $7 = m[1];
                    return te(u(o[1][1 + Ki], o), O, $7, F, H);
                  case 1:
                    var r0 = function(Oe) {
                      return [0, O, [1, Oe]];
                    }, M0 = m[1];
                    return te(u(o[1][1 + Qs], o), O, M0, F, r0);
                  case 2:
                    var z0 = function(Oe) {
                      return [0, O, [2, Oe]];
                    }, Nr = m[1];
                    return te(u(o[1][1 + z1], o), O, Nr, F, z0);
                  case 3:
                    var Gr = function(Oe) {
                      return [0, O, [3, Oe]];
                    }, Fe = m[1];
                    return te(u(o[1][1 + pb], o), O, Fe, F, Gr);
                  case 4:
                    var ye = function(Oe) {
                      return [0, O, [4, Oe]];
                    }, Rn = m[1];
                    return te(u(o[1][1 + bb], o), O, Rn, F, ye);
                  case 5:
                    var yn = function(Oe) {
                      return [0, O, [5, Oe]];
                    }, at = m[1];
                    return te(u(o[1][1 + v2], o), O, at, F, yn);
                  case 6:
                    var _t = function(Oe) {
                      return [0, O, [6, Oe]];
                    }, Et = m[1];
                    return te(u(o[1][1 + Y1], o), O, Et, F, _t);
                  case 7:
                    var Wn = function(Oe) {
                      return [0, O, [7, Oe]];
                    }, Qt = m[1];
                    return te(u(o[1][1 + lb], o), O, Qt, F, Wn);
                  case 8:
                    var J7 = function(Oe) {
                      return [0, O, [8, Oe]];
                    }, $72 = m[1];
                    return te(u(o[1][1 + Z9], o), O, $72, F, J7);
                  case 9:
                    var E7 = function(Oe) {
                      return [0, O, [9, Oe]];
                    }, Z7 = m[1];
                    return te(u(o[1][1 + $9], o), O, Z7, F, E7);
                  case 10:
                    var Q7 = function(Oe) {
                      return [0, O, [10, Oe]];
                    }, ri = m[1];
                    return te(u(o[1][1 + J9], o), O, ri, F, Q7);
                  case 11:
                    var ei = function(Oe) {
                      return [0, O, [11, Oe]];
                    }, ni = m[1];
                    return te(u(o[1][1 + W9], o), O, ni, F, ei);
                  case 12:
                    var Ji = function(Oe) {
                      return [0, O, [33, Oe]];
                    }, uv = m[1];
                    return te(u(o[1][1 + Sr], o), O, uv, F, Ji);
                  case 13:
                    var iv = function(Oe) {
                      return [0, O, [13, Oe]];
                    }, $i = m[1];
                    return te(u(o[1][1 + vb], o), O, $i, F, iv);
                  case 14:
                    var fv = function(Oe) {
                      return [0, O, [14, Oe]];
                    }, Gb = m[1];
                    return te(u(o[1][1 + K9], o), O, Gb, F, fv);
                  case 15:
                    var Mb = function(Oe) {
                      return [0, O, [15, Oe]];
                    }, Bb = m[1];
                    return te(u(o[1][1 + z9], o), O, Bb, F, Mb);
                  case 16:
                    var qb = function(Oe) {
                      return [0, O, [16, Oe]];
                    }, Ub = m[1];
                    return te(u(o[1][1 + ob], o), O, Ub, F, qb);
                  case 17:
                    var Hb = function(Oe) {
                      return [0, O, [17, Oe]];
                    }, Xb = m[1];
                    return te(u(o[1][1 + q9], o), O, Xb, F, Hb);
                  case 18:
                    var Yb = function(Oe) {
                      return [0, O, [18, Oe]];
                    }, Vb = m[1];
                    return te(u(o[1][1 + c2], o), O, Vb, F, Yb);
                  case 19:
                    var zb = function(Oe) {
                      return [0, O, [19, Oe]];
                    }, Kb = m[1];
                    return te(u(o[1][1 + zs], o), O, Kb, F, zb);
                  case 20:
                    var Wb = function(Oe) {
                      return [0, O, [20, Oe]];
                    }, Jb = m[1];
                    return te(u(o[1][1 + wt], o), O, Jb, F, Wb);
                  case 21:
                    var $b = function(Oe) {
                      return [0, O, [21, Oe]];
                    }, Zb = m[1];
                    return te(u(o[1][1 + Ou], o), O, Zb, F, $b);
                  case 22:
                    var Qb = function(Oe) {
                      return [0, O, [22, Oe]];
                    }, r4 = m[1];
                    return te(u(o[1][1 + vn], o), O, r4, F, Qb);
                  case 23:
                    var e4 = function(Oe) {
                      return [0, O, [23, Oe]];
                    }, n4 = m[1];
                    return te(u(o[1][1 + wn], o), O, n4, F, e4);
                  case 24:
                    var t42 = function(Oe) {
                      return [0, O, [24, Oe]];
                    }, u4 = m[1];
                    return te(u(o[1][1 + Pt], o), O, u4, F, t42);
                  case 25:
                    var i4 = function(Oe) {
                      return [0, O, [25, Oe]];
                    }, f4 = m[1];
                    return te(u(o[1][1 + Ut], o), O, f4, F, i4);
                  case 26:
                    var x4 = function(Oe) {
                      return [0, O, [26, Oe]];
                    }, a4 = m[1];
                    return te(u(o[1][1 + Dn], o), O, a4, F, x4);
                  case 27:
                    var $e = function(Oe) {
                      return [0, O, [27, Oe]];
                    }, PR = m[1];
                    return te(u(o[1][1 + fr], o), O, PR, F, $e);
                  case 28:
                    var DR = function(Oe) {
                      return [0, O, [28, Oe]];
                    }, LR = m[1];
                    return te(u(o[1][1 + Jr], o), O, LR, F, DR);
                  case 29:
                    var RR = function(Oe) {
                      return [0, O, [29, Oe]];
                    }, jR = m[1];
                    return te(u(o[1][1 + ar], o), O, jR, F, RR);
                  case 30:
                    var GR = function(Oe) {
                      return [0, O, [30, Oe]];
                    }, MR = m[1];
                    return te(u(o[1][1 + E0], o), O, MR, F, GR);
                  case 31:
                    var He = function(Oe) {
                      return [0, O, [31, Oe]];
                    }, G7e = m[1];
                    return te(u(o[1][1 + w0], o), O, G7e, F, He);
                  case 32:
                    var M7e = function(Oe) {
                      return [0, O, [32, Oe]];
                    }, B7e = m[1];
                    return te(u(o[1][1 + c0], o), O, B7e, F, M7e);
                  case 33:
                    var q7e = function(Oe) {
                      return [0, O, [33, Oe]];
                    }, U7e = m[1];
                    return te(u(o[1][1 + Sr], o), O, U7e, F, q7e);
                  case 34:
                    var H7e = function(Oe) {
                      return [0, O, [34, Oe]];
                    }, X7e = m[1];
                    return te(u(o[1][1 + T], o), O, X7e, F, H7e);
                  case 35:
                    var Y7e = function(Oe) {
                      return [0, O, [35, Oe]];
                    }, V7e = m[1];
                    return te(u(o[1][1 + x], o), O, V7e, F, Y7e);
                  default:
                    var z7e = function(Oe) {
                      return [0, O, [36, Oe]];
                    }, K7e = m[1];
                    return te(u(o[1][1 + i], o), O, K7e, F, z7e);
                }
              }
              return BN(t4, [0, XL, function(o, F) {
                var m = F[2], O = m[3], H = m[2], $7 = m[1], r0 = a(o[1][1 + _0], o, $7), M0 = a(o[1][1 + s0], o, H), z0 = Hn(u(o[1][1 + V1], o), O);
                return $7 === r0 && H === M0 && O === z0 ? F : [0, F[1], [0, r0, M0, z0]];
              }, Or, j7e, V1, R7e, s0, L7e, ze, dr, dr, D7e, nn, P7e, y2, C7e, c_, N7e, o_, A7e, _2, I7e, a_, O7e, Ki, T7e, Qs, F7e, kb, g7e, Zs, S7e, $0, E7e, b2, w7e, f_, k7e, i_, h7e, K1, d7e, z1, y7e, n_, _7e, ks, m7e, zc, p7e, db, b7e, t_, l7e, hb, v7e, $s, s7e, l2, c7e, e_, o7e, Vc, a7e, yb, x7e, _b, f7e, r_, i7e, Mn, u7e, mb, t7e, pb, n7e, bb, e7e, v2, r7e, Y1, Que, Q9, Zue, lb, $ue, Z9, Jue, $9, Wue, J9, Kue, W9, zue, vb, Vue, K9, Yue, z9, Xue, ob, Hue, V9, Uue, sb, que, Y9, Bue, H9, Mue, Js, Gue, vi, jue, cb, Rue, X9, Lue, s2, Due, X1, Pue, q9, Cue, B9, Nue, c2, Aue, Ws, Iue, U9, Oue, si, Tue, zs, Fue, Ks, gue, Ou, Sue, hs, Eue, Vs, wue, vn, kue, un, hue, ut, due, wt, yue, tt, _ue, Ti, mue, R0, pue, Ht, bue, Yc, lue, a7, vue, Q0, sue, $r, cue, Br, oue, Mr, aue, ne, xue, jr, fue, ge, iue, ce, uue, H0, tue, qr, nue, _n, eue, K7, rue, Gu, Qte, Y, Zte, s, $te, c, Jte, e0, Wte, V, Kte, f0, zte, xu, Vte, On, Yte, vr, Xte, Lr, Hte, _, Ute, p2, qte, x_, Bte, k, Mte, G, Gte, K, jte, M, Rte, S, Lte, A, Dte, a0, Pte, e1, Cte, h, Nte, en, Ate, t0, Ite, l, Ote, x0, Tte, wn, Fte, rt, gte, _e, Ste, Gn, Ete, U0, wte, W7, kte, Xe, hte, ft, dte, xt, yte, he, _te, Vi, mte, pt, pte, k0, bte, m0, lte, Kc, vte, Xn, ste, Dn, cte, or, ote, An, ate, Ot, xte, yu, fte, Ku, ite, Pt, ute, Ut, tte, bt, nte, Tt, ete, Zt, rte, Ct, Qne, Me, Zne, Kr, $ne, mr, Jne, Be, Wne, Cr, Kne, gr, zne, We, Vne, Pe, Yne, sn, Xne, kn, Hne, rn, Une, on, CR, Ae, jb, an, Rb, Ke, tv, re, Lb, F0, nv, Ie, Wi, le, w7, xe, Ii, je, hu, sr, du, Ur, NR, Pr, AR, K0, Db, d0, IR, fr, OR, J0, Pb, Y0, TR, u0, FR, yr, gR, A0, E2, y0, SR, D, d_, D0, ER, U, wR, I, Cb, Fr, kR, Qr, y_, ae, hR, pe, dR, oe, Nb, me, yR, Sr, _R, Re, mR, p, Ab, u_, __, zi, pR, It, m_, r1, Ib, m2, p_, nr, bR, j0, b_, er, lR, T0, Ob, S0, l_, Q, Tb, L, ev, i0, vR, l0, sR, v0, v_, P, Bn, fe, cR, q0, Fb, O0, oR, b0, gb, p0, aR, Z, Sb, W1, xR, B, rv, Ir, fR, _r, w2, mt, iR, Jr, k2, Wr, uR, _0, s_, Tr, tR, Hr, nR, Rr, h2, xr, eR, W0, rR, ar, Eb, Ar, QL, X, wb, G0, ZL, b, Q1, X0, $L, E0, Z1, w0, JL, g0, d2, w, WL, E, KL, T, Oi, y, zL, x, $1, i, VL, c0, J1, e, YL]), function(o, F) {
                return Gp(F, t4);
              };
            });
            function W00(t4) {
              switch (t4[0]) {
                case 0:
                  return 1;
                case 3:
                  return 3;
                default:
                  return 2;
              }
            }
            function J00(t4, n) {
              u(f(t4), V6r), a(f(t4), K6r, z6r);
              var e = n[1];
              a(f(t4), W6r, e), u(f(t4), J6r), u(f(t4), $6r), a(f(t4), Q6r, Z6r);
              var i = n[2];
              return a(f(t4), rpr, i), u(f(t4), epr), u(f(t4), npr);
            }
            var $00 = function t4(n, e) {
              return t4.fun(n, e);
            }, Xee = function t4(n) {
              return t4.fun(n);
            };
            N($00, function(t4, n) {
              u(f(t4), upr), a(f(t4), fpr, ipr);
              var e = n[1];
              if (e) {
                g(t4, xpr);
                var i = e[1];
                switch (i[0]) {
                  case 0:
                    u(f(t4), D6r);
                    var x = i[1];
                    a(f(t4), L6r, x), u(f(t4), R6r);
                    break;
                  case 1:
                    u(f(t4), j6r);
                    var c = i[1];
                    a(f(t4), G6r, c), u(f(t4), M6r);
                    break;
                  case 2:
                    u(f(t4), B6r);
                    var s = i[1];
                    a(f(t4), q6r, s), u(f(t4), U6r);
                    break;
                  default:
                    u(f(t4), H6r);
                    var p = i[1];
                    a(f(t4), X6r, p), u(f(t4), Y6r);
                }
                g(t4, apr);
              } else
                g(t4, opr);
              return u(f(t4), cpr), u(f(t4), spr), a(f(t4), lpr, vpr), J00(t4, n[2]), u(f(t4), bpr), u(f(t4), ppr), a(f(t4), _pr, mpr), J00(t4, n[3]), u(f(t4), ypr), u(f(t4), dpr);
            }), N(Xee, function(t4) {
              return a(P0(tpr), $00, t4);
            });
            function ht(t4, n) {
              return [0, t4[1], t4[2], n[3]];
            }
            function ms(t4, n) {
              var e = t4[1] - n[1] | 0;
              return e === 0 ? t4[2] - n[2] | 0 : e;
            }
            function Z00(t4, n) {
              var e = n[1], i = t4[1];
              if (i)
                if (e)
                  var x = e[1], c = i[1], s = W00(x), p = W00(c) - s | 0, T = p === 0 ? Ee(c[1], x[1]) : p;
                else
                  var T = -1;
              else
                var y = e && 1, T = y;
              if (T === 0) {
                var E = ms(t4[2], n[2]);
                return E === 0 ? ms(t4[3], n[3]) : E;
              }
              return T;
            }
            function Wv(t4, n) {
              return Z00(t4, n) === 0 ? 1 : 0;
            }
            var ZD = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Yee = jp(wpr, function(t4) {
              var n = DN(t4, kpr)[35], e = GN(t4, 0, 0, hpr, $D, 1)[1];
              return Zz(t4, n, function(i, x) {
                return 0;
              }), function(i, x) {
                var c = Gp(x, t4);
                return u(e, c), MN(x, c, t4);
              };
            });
            N(ZD, function(t4, n, e) {
              var i = e[2];
              switch (i[0]) {
                case 0:
                  var x = i[1][1];
                  return be(function(s, p) {
                    var y = p[0] === 0 ? p[1][2][2] : p[1][2][1];
                    return ir(ZD, t4, s, y);
                  }, n, x);
                case 1:
                  var c = i[1][1];
                  return be(function(s, p) {
                    return p[0] === 2 ? s : ir(ZD, t4, s, p[1][2][1]);
                  }, n, c);
                case 2:
                  return a(t4, n, i[1][1]);
                default:
                  return n;
              }
            });
            function Gc(t4, n) {
              return [0, n[1], [0, n[2], t4]];
            }
            function Q00(t4, n, e) {
              var i = t4 && t4[1], x = n && n[1];
              return [0, i, x, e];
            }
            function lr(t4, n, e) {
              var i = t4 && t4[1], x = n && n[1];
              return !i && !x ? x : [0, Q00([0, i], [0, x], 0)];
            }
            function mu(t4, n, e, i) {
              var x = t4 && t4[1], c = n && n[1];
              return !x && !c && !e ? e : [0, Q00([0, x], [0, c], e)];
            }
            function y7(t4, n) {
              if (t4) {
                if (n) {
                  var e = n[1], i = t4[1], x = [0, xn(i[2], e[2])];
                  return lr([0, xn(e[1], i[1])], x, 0);
                }
                var c = t4;
              } else
                var c = n;
              return c;
            }
            function QD(t4, n) {
              if (n) {
                if (t4) {
                  var e = n[1], i = t4[1], x = i[3], c = [0, xn(i[2], e[2])];
                  return mu([0, xn(e[1], i[1])], c, x, 0);
                }
                var s = n[1];
                return mu([0, s[1]], [0, s[2]], 0, 0);
              }
              return t4;
            }
            function Jv(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (typeof e == "number")
                  return i;
                if (e[0] === 0)
                  return [0, e[1], 0, i];
                var x = [0, e[2], e[4], i], e = e[3], i = x;
              }
            }
            function rr0(t4, n) {
              if (t4)
                var e = Jv(t4[2], t4[3]), i = function(c) {
                  return rr0(e, c);
                }, x = [0, t4[1], i];
              else
                var x = t4;
              return x;
            }
            function Vee(t4) {
              var n = Jv(t4, 0);
              return function(e) {
                return rr0(n, e);
              };
            }
            function _s(t4) {
              return typeof t4 == "number" ? 0 : t4[0] === 0 ? 1 : t4[1];
            }
            function zee(t4) {
              return [0, t4];
            }
            function Y7(t4, n, e) {
              var i = 0;
              if (typeof t4 == "number") {
                if (typeof e == "number")
                  return [0, n];
                e[0] === 1 && (i = 1);
              } else if (t4[0] === 0)
                typeof e != "number" && e[0] === 1 && (i = 1);
              else {
                var x = t4[1];
                if (typeof e != "number" && e[0] === 1) {
                  var c = e[1], s = c <= x ? x + 1 | 0 : c + 1 | 0;
                  return [1, s, n, t4, e];
                }
                var p = x;
                i = 2;
              }
              switch (i) {
                case 1:
                  var p = e[1];
                  break;
                case 0:
                  return [1, 2, n, t4, e];
              }
              return [1, p + 1 | 0, n, t4, e];
            }
            function Ds(t4, n, e) {
              var i = _s(t4), x = _s(e), c = x <= i ? i + 1 | 0 : x + 1 | 0;
              return [1, c, n, t4, e];
            }
            function rL(t4, n) {
              var e = n !== 0 ? 1 : 0;
              if (e) {
                if (n !== 1) {
                  var i = n >>> 1 | 0, x = rL(t4, i), c = u(t4, 0), s = rL(t4, (n - i | 0) - 1 | 0);
                  return [1, _s(x) + 1 | 0, c, x, s];
                }
                var p = [0, u(t4, 0)];
              } else
                var p = e;
              return p;
            }
            function ki(t4, n, e) {
              var i = _s(t4), x = _s(e);
              if ((x + 2 | 0) < i) {
                var c = t4[4], s = t4[3], p = t4[2], y = _s(c);
                if (y <= _s(s))
                  return Ds(s, p, Y7(c, n, e));
                var T = Y7(c[4], n, e), E = c[2];
                return Ds(Y7(s, p, c[3]), E, T);
              }
              if ((i + 2 | 0) < x) {
                var h = e[4], w = e[3], G = e[2], A = _s(w);
                if (A <= _s(h))
                  return Ds(Y7(t4, n, w), G, h);
                var S = Y7(w[4], G, h), M = w[2];
                return Ds(Y7(t4, n, w[3]), M, S);
              }
              return Y7(t4, n, e);
            }
            function er0(t4, n) {
              if (typeof n == "number")
                return [0, t4];
              if (n[0] === 0)
                return Y7([0, t4], n[1], 0);
              var e = n[4], i = n[2];
              return ki(er0(t4, n[3]), i, e);
            }
            function nr0(t4, n) {
              if (typeof n == "number")
                return [0, t4];
              if (n[0] === 0)
                return Y7(0, n[1], [0, t4]);
              var e = nr0(t4, n[4]);
              return ki(n[3], n[2], e);
            }
            function Yu(t4, n, e) {
              if (typeof t4 == "number")
                return er0(n, e);
              if (t4[0] === 0) {
                if (typeof e != "number") {
                  if (e[0] === 0)
                    return Y7(t4, n, e);
                  if (3 < e[1]) {
                    var i = e[4], x = e[2];
                    return ki(Yu(t4, n, e[3]), x, i);
                  }
                  return Ds(t4, n, e);
                }
              } else {
                var c = t4[4], s = t4[3], p = t4[2], y = t4[1];
                if (typeof e != "number") {
                  if (e[0] === 0)
                    return 3 < y ? ki(s, p, Yu(c, n, e)) : Ds(t4, n, e);
                  var T = e[1];
                  if ((T + 2 | 0) < y)
                    return ki(s, p, Yu(c, n, e));
                  if ((y + 2 | 0) < T) {
                    var E = e[4], h = e[2];
                    return ki(Yu(t4, n, e[3]), h, E);
                  }
                  return Ds(t4, n, e);
                }
              }
              return nr0(n, t4);
            }
            function Pl(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  throw Jt;
                if (n[0] === 0)
                  return n[1];
                if (typeof n[3] == "number")
                  return n[2];
                var n = n[3];
              }
            }
            function tr0(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  return 0;
                if (n[0] === 0)
                  return [0, n[1]];
                if (typeof n[3] == "number")
                  return [0, n[2]];
                var n = n[3];
              }
            }
            function ur0(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  throw Jt;
                if (n[0] === 0)
                  return n[1];
                if (typeof n[4] == "number")
                  return n[2];
                var n = n[4];
              }
            }
            function Kee(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  return 0;
                if (n[0] === 0)
                  return [0, n[1]];
                if (typeof n[4] == "number")
                  return [0, n[2]];
                var n = n[4];
              }
            }
            function eL(t4) {
              if (typeof t4 == "number")
                return Nu(f5r);
              if (t4[0] === 0)
                return 0;
              if (typeof t4[3] == "number")
                return t4[4];
              var n = t4[4], e = t4[2];
              return ki(eL(t4[3]), e, n);
            }
            function Dl(t4, n) {
              if (typeof t4 == "number")
                return n;
              if (typeof n == "number")
                return t4;
              var e = eL(n);
              return Yu(t4, Pl(n), e);
            }
            function nL(t4) {
              if (typeof t4 == "number")
                return 0;
              if (t4[0] === 0)
                return 1;
              var n = nL(t4[4]);
              return (nL(t4[3]) + 1 | 0) + n | 0;
            }
            function ir0(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (typeof i == "number")
                  return e;
                if (i[0] === 0)
                  return [0, i[1], e];
                var x = i[3], c = ir0(e, i[4]), e = [0, i[2], c], i = x;
              }
            }
            function fr0(t4) {
              return ir0(0, t4);
            }
            var lt = 0;
            function tL(t4) {
              var n = typeof t4 == "number" ? 1 : 0, e = n && 1;
              return e;
            }
            function uL(t4) {
              function n(e0, x0) {
                if (typeof x0 == "number")
                  return [0, e0];
                if (x0[0] === 0) {
                  var l = x0[1], c0 = a(t4[1], e0, l);
                  return c0 === 0 ? x0 : 0 <= c0 ? Y7(x0, e0, lt) : Y7([0, e0], l, lt);
                }
                var t0 = x0[4], a0 = x0[3], w0 = x0[2], _0 = a(t4[1], e0, w0);
                if (_0 === 0)
                  return x0;
                if (0 <= _0) {
                  var E0 = n(e0, t0);
                  return t0 === E0 ? x0 : ki(a0, w0, E0);
                }
                var X0 = n(e0, a0);
                return a0 === X0 ? x0 : ki(X0, w0, t0);
              }
              function e(e0, x0) {
                if (typeof x0 == "number")
                  return [0, lt, 0, lt];
                if (x0[0] === 0) {
                  var l = a(t4[1], e0, x0[1]);
                  return l === 0 ? [0, lt, 1, lt] : 0 <= l ? [0, x0, 0, lt] : [0, lt, 0, x0];
                }
                var c0 = x0[4], t0 = x0[3], a0 = x0[2], w0 = a(t4[1], e0, a0);
                if (w0 === 0)
                  return [0, t0, 1, c0];
                if (0 <= w0) {
                  var _0 = e(e0, c0), E0 = _0[3], X0 = _0[2];
                  return [0, Yu(t0, a0, _0[1]), X0, E0];
                }
                var b = e(e0, t0), G0 = Yu(b[3], a0, c0);
                return [0, b[1], b[2], G0];
              }
              function i(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    return 0;
                  if (l[0] === 0)
                    return a(t4[1], e0, l[1]) === 0 ? 1 : 0;
                  var c0 = a(t4[1], e0, l[2]), t0 = c0 === 0 ? 1 : 0;
                  if (t0)
                    return t0;
                  var a0 = 0 <= c0 ? l[4] : l[3], l = a0;
                }
              }
              function x(e0, x0) {
                if (typeof x0 == "number")
                  return lt;
                if (x0[0] === 0)
                  return a(t4[1], e0, x0[1]) === 0 ? lt : x0;
                var l = x0[4], c0 = x0[3], t0 = x0[2], a0 = a(t4[1], e0, t0);
                if (a0 === 0) {
                  if (typeof c0 == "number")
                    return l;
                  if (typeof l == "number")
                    return c0;
                  var w0 = eL(l);
                  return ki(c0, Pl(l), w0);
                }
                if (0 <= a0) {
                  var _0 = x(e0, l);
                  return l === _0 ? x0 : ki(c0, t0, _0);
                }
                var E0 = x(e0, c0);
                return c0 === E0 ? x0 : ki(E0, t0, l);
              }
              function c(e0, x0) {
                if (typeof e0 == "number")
                  return x0;
                if (e0[0] === 1) {
                  var l = e0[2], c0 = e0[1];
                  if (typeof x0 != "number") {
                    if (x0[0] === 0)
                      return n(x0[1], e0);
                    var t0 = x0[2], a0 = x0[1];
                    if (a0 <= c0) {
                      if (a0 === 1)
                        return n(t0, e0);
                      var w0 = e(l, x0), _0 = c(e0[4], w0[3]);
                      return Yu(c(e0[3], w0[1]), l, _0);
                    }
                    if (c0 === 1)
                      return n(l, x0);
                    var E0 = e(t0, e0), X0 = c(E0[3], x0[4]);
                    return Yu(c(E0[1], x0[3]), t0, X0);
                  }
                }
                return typeof x0 == "number" ? e0 : n(e0[1], x0);
              }
              function s(e0, x0) {
                if (typeof e0 == "number" || typeof x0 == "number")
                  return lt;
                if (typeof e0 != "number" && e0[0] !== 0) {
                  var l = e0[4], c0 = e0[3], t0 = e0[2], a0 = e(t0, x0), w0 = a0[1];
                  if (a0[2]) {
                    var _0 = s(l, a0[3]);
                    return Yu(s(c0, w0), t0, _0);
                  }
                  var E0 = s(l, a0[3]);
                  return Dl(s(c0, w0), E0);
                }
                return i(e0[1], x0) ? e0 : lt;
              }
              function p(e0, x0) {
                if (typeof x0 == "number")
                  return [0, lt, function(s0) {
                    return lt;
                  }];
                if (x0[0] === 0)
                  return a(t4[1], e0, x0[1]) === 0 ? 0 : [0, lt, function(s0) {
                    return lt;
                  }];
                var l = x0[4], c0 = x0[3], t0 = x0[2], a0 = a(t4[1], e0, t0);
                if (a0 === 0)
                  return 0;
                if (0 <= a0) {
                  var w0 = p(e0, l);
                  if (w0)
                    var _0 = w0[2], E0 = [0, Yu(c0, t0, w0[1]), _0];
                  else
                    var E0 = w0;
                  return E0;
                }
                var X0 = p(e0, c0);
                if (X0)
                  var b = X0[2], G0 = function(s0) {
                    return Yu(u(b, 0), t0, l);
                  }, X = [0, X0[1], G0];
                else
                  var X = X0;
                return X;
              }
              function y(e0, x0) {
                for (var l = e0, c0 = x0; ; ) {
                  if (typeof l != "number" && typeof c0 != "number") {
                    var t0 = 0;
                    if (typeof l != "number" && l[0] !== 0) {
                      if (typeof c0 != "number" && c0[0] !== 0) {
                        if (l === c0)
                          return 0;
                        var a0 = p(l[2], c0);
                        if (a0) {
                          var w0 = y(l[3], a0[1]);
                          if (w0) {
                            var _0 = u(a0[2], 0), l = l[4], c0 = _0;
                            continue;
                          }
                          var E0 = w0;
                        } else
                          var E0 = a0;
                        return E0;
                      }
                      var X0 = l, b = c0[1];
                      t0 = 1;
                    }
                    if (!t0)
                      var X0 = c0, b = l[1];
                    return 1 - i(b, X0);
                  }
                  return 1;
                }
              }
              function T(e0, x0) {
                if (typeof e0 == "number")
                  return lt;
                if (typeof x0 == "number")
                  return e0;
                if (typeof e0 != "number" && e0[0] !== 0) {
                  var l = e0[4], c0 = e0[3], t0 = e0[2], a0 = e(t0, x0), w0 = a0[1];
                  if (a0[2]) {
                    var _0 = T(l, a0[3]);
                    return Dl(T(c0, w0), _0);
                  }
                  var E0 = T(l, a0[3]);
                  return Yu(T(c0, w0), t0, E0);
                }
                return i(e0[1], x0) ? lt : e0;
              }
              function E(e0, x0) {
                for (var l = Jv(x0, 0), c0 = Jv(e0, 0), t0 = l; ; ) {
                  if (c0) {
                    if (t0) {
                      var a0 = a(t4[1], c0[1], t0[1]);
                      if (a0 === 0) {
                        var w0 = Jv(t0[2], t0[3]), c0 = Jv(c0[2], c0[3]), t0 = w0;
                        continue;
                      }
                      return a0;
                    }
                    return 1;
                  }
                  var _0 = t0 && -1;
                  return _0;
                }
              }
              function h(e0, x0) {
                return E(e0, x0) === 0 ? 1 : 0;
              }
              function w(e0, x0) {
                for (var l = e0, c0 = x0; ; ) {
                  if (typeof l == "number")
                    return 1;
                  if (l[0] === 0) {
                    var t0 = l[1];
                    if (typeof c0 != "number") {
                      if (c0[0] === 0) {
                        var a0 = a(t4[1], t0, c0[1]) === 0 ? 1 : 0, w0 = a0 && 1;
                        return w0;
                      }
                      var _0 = a(t4[1], t0, c0[2]);
                      if (_0 === 0)
                        return 1;
                      if (0 <= _0) {
                        var c0 = c0[4];
                        continue;
                      }
                      var c0 = c0[3];
                      continue;
                    }
                  } else {
                    var E0 = l[4], X0 = l[3], b = l[2];
                    if (typeof c0 != "number") {
                      if (c0[0] === 0) {
                        var G0 = l[1] === 1 ? 1 : 0, X = G0 && (a(t4[1], b, c0[1]) === 0 ? 1 : 0);
                        return X;
                      }
                      var s0 = c0[4], dr = c0[3], Ar = a(t4[1], b, c0[2]);
                      if (Ar === 0) {
                        var ar = w(X0, dr);
                        if (ar) {
                          var l = E0, c0 = s0;
                          continue;
                        }
                        return ar;
                      }
                      if (0 <= Ar) {
                        var W0 = w(Y7(lt, b, E0), s0);
                        if (W0) {
                          var l = X0;
                          continue;
                        }
                        return W0;
                      }
                      var Lr = w(Y7(X0, b, lt), dr);
                      if (Lr) {
                        var l = E0;
                        continue;
                      }
                      return Lr;
                    }
                  }
                  return 0;
                }
              }
              function G(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    return 0;
                  if (l[0] === 0)
                    return u(e0, l[1]);
                  G(e0, l[3]), u(e0, l[2]);
                  var l = l[4];
                }
              }
              function A(e0, x0, l) {
                for (var c0 = x0, t0 = l; ; ) {
                  if (typeof c0 == "number")
                    return t0;
                  if (c0[0] === 0)
                    return a(e0, c0[1], t0);
                  var a0 = A(e0, c0[3], t0), w0 = a(e0, c0[2], a0), c0 = c0[4], t0 = w0;
                }
              }
              function S(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    return 1;
                  if (l[0] === 0)
                    return u(e0, l[1]);
                  var c0 = u(e0, l[2]);
                  if (c0) {
                    var t0 = S(e0, l[3]);
                    if (t0) {
                      var l = l[4];
                      continue;
                    }
                    var a0 = t0;
                  } else
                    var a0 = c0;
                  return a0;
                }
              }
              function M(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    return 0;
                  if (l[0] === 0)
                    return u(e0, l[1]);
                  var c0 = u(e0, l[2]);
                  if (c0)
                    var t0 = c0;
                  else {
                    var a0 = M(e0, l[3]);
                    if (!a0) {
                      var l = l[4];
                      continue;
                    }
                    var t0 = a0;
                  }
                  return t0;
                }
              }
              function K(e0, x0) {
                if (typeof x0 == "number")
                  return lt;
                if (x0[0] === 0)
                  return u(e0, x0[1]) ? x0 : lt;
                var l = x0[4], c0 = x0[3], t0 = x0[2], a0 = K(e0, c0), w0 = u(e0, t0), _0 = K(e0, l);
                return w0 ? c0 === a0 && l === _0 ? x0 : Yu(a0, t0, _0) : Dl(a0, _0);
              }
              function V(e0, x0) {
                if (typeof x0 == "number")
                  return [0, lt, lt];
                if (x0[0] === 0)
                  return u(e0, x0[1]) ? [0, x0, lt] : [0, lt, x0];
                var l = x0[2], c0 = V(e0, x0[3]), t0 = c0[2], a0 = c0[1], w0 = u(e0, l), _0 = V(e0, x0[4]), E0 = _0[2], X0 = _0[1];
                if (w0) {
                  var b = Dl(t0, E0);
                  return [0, Yu(a0, l, X0), b];
                }
                var G0 = Yu(t0, l, E0);
                return [0, Dl(a0, X0), G0];
              }
              function f0(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    throw Jt;
                  if (l[0] === 0) {
                    var c0 = l[1];
                    if (a(t4[1], e0, c0) === 0)
                      return c0;
                    throw Jt;
                  }
                  var t0 = l[2], a0 = a(t4[1], e0, t0);
                  if (a0 === 0)
                    return t0;
                  var w0 = 0 <= a0 ? l[4] : l[3], l = w0;
                }
              }
              function m0(e0, x0) {
                for (var l = x0; ; ) {
                  if (typeof l == "number")
                    return 0;
                  if (l[0] === 0) {
                    var c0 = l[1], t0 = a(t4[1], e0, c0) === 0 ? 1 : 0, a0 = t0 && [0, c0];
                    return a0;
                  }
                  var w0 = l[2], _0 = a(t4[1], e0, w0);
                  if (_0 === 0)
                    return [0, w0];
                  var E0 = 0 <= _0 ? l[4] : l[3], l = E0;
                }
              }
              function k0(e0, x0) {
                if (typeof x0 == "number")
                  return lt;
                if (x0[0] === 0) {
                  var l = x0[1], c0 = u(e0, l);
                  return l === c0 ? x0 : [0, c0];
                }
                var t0 = x0[4], a0 = x0[3], w0 = x0[2], _0 = k0(e0, a0), E0 = u(e0, w0), X0 = k0(e0, t0);
                if (a0 === _0 && w0 === E0 && t0 === X0)
                  return x0;
                var b = 0;
                if (!tL(_0)) {
                  var G0 = ur0(_0);
                  0 <= a(t4[1], G0, E0) && (b = 1);
                }
                if (!b) {
                  var X = 0;
                  if (!tL(X0)) {
                    var s0 = Pl(X0);
                    0 <= a(t4[1], E0, s0) && (X = 1);
                  }
                  if (!X)
                    return Yu(_0, E0, X0);
                }
                return c(_0, n(E0, X0));
              }
              function g0(e0) {
                if (e0) {
                  var x0 = e0[2], l = e0[1];
                  if (x0) {
                    var c0 = x0[2], t0 = x0[1];
                    if (c0) {
                      var a0 = c0[2], w0 = c0[1];
                      if (a0) {
                        var _0 = a0[2], E0 = a0[1];
                        if (_0) {
                          if (_0[2]) {
                            var X0 = t4[1], b = function(ar, W0) {
                              if (ar === 2) {
                                if (W0) {
                                  var Lr = W0[2];
                                  if (Lr) {
                                    var Tr = Lr[1], Hr = W0[1], Or = Lr[2], xr = a(X0, Hr, Tr), Rr = xr === 0 ? [0, Hr, 0] : 0 < xr ? [0, Hr, [0, Tr, 0]] : [0, Tr, [0, Hr, 0]];
                                    return [0, Rr, Or];
                                  }
                                }
                              } else if (ar === 3 && W0) {
                                var Wr = W0[2];
                                if (Wr) {
                                  var Jr = Wr[2];
                                  if (Jr) {
                                    var or = Jr[1], _r = Wr[1], Ir = W0[1], fe = Jr[2], v0 = a(X0, Ir, _r);
                                    if (v0 === 0)
                                      var P = a(X0, _r, or), L = P === 0 ? [0, _r, 0] : 0 < P ? [0, _r, [0, or, 0]] : [0, or, [0, _r, 0]], Q = L;
                                    else if (0 < v0) {
                                      var i0 = a(X0, _r, or);
                                      if (i0 === 0)
                                        var T0 = [0, Ir, [0, _r, 0]];
                                      else if (0 < i0)
                                        var T0 = [0, Ir, [0, _r, [0, or, 0]]];
                                      else
                                        var l0 = a(X0, Ir, or), S0 = l0 === 0 ? [0, Ir, [0, _r, 0]] : 0 < l0 ? [0, Ir, [0, or, [0, _r, 0]]] : [0, or, [0, Ir, [0, _r, 0]]], T0 = S0;
                                      var Q = T0;
                                    } else {
                                      var er = a(X0, Ir, or);
                                      if (er === 0)
                                        var Z = [0, _r, [0, Ir, 0]];
                                      else if (0 < er)
                                        var Z = [0, _r, [0, Ir, [0, or, 0]]];
                                      else
                                        var j0 = a(X0, _r, or), B = j0 === 0 ? [0, _r, [0, Ir, 0]] : 0 < j0 ? [0, _r, [0, or, [0, Ir, 0]]] : [0, or, [0, _r, [0, Ir, 0]]], Z = B;
                                      var Q = Z;
                                    }
                                    return [0, Q, fe];
                                  }
                                }
                              }
                              for (var p0 = ar >> 1, b0 = G0(p0, W0), O0 = b0[1], q0 = G0(ar - p0 | 0, b0[2]), nr = O0, yr = q0[1], vr = 0, $0 = q0[2]; ; ) {
                                if (nr) {
                                  if (yr) {
                                    var Sr = yr[2], Mr = yr[1], Br = nr[2], qr = nr[1], jr = a(X0, qr, Mr);
                                    if (jr === 0) {
                                      var nr = Br, yr = Sr, vr = [0, qr, vr];
                                      continue;
                                    }
                                    if (0 <= jr) {
                                      var yr = Sr, vr = [0, Mr, vr];
                                      continue;
                                    }
                                    var nr = Br, vr = [0, qr, vr];
                                    continue;
                                  }
                                  var $r = jc(nr, vr);
                                } else
                                  var $r = jc(yr, vr);
                                return [0, $r, $0];
                              }
                            }, G0 = function(ar, W0) {
                              if (ar === 2) {
                                if (W0) {
                                  var Lr = W0[2];
                                  if (Lr) {
                                    var Tr = Lr[1], Hr = W0[1], Or = Lr[2], xr = a(X0, Hr, Tr), Rr = xr === 0 ? [0, Hr, 0] : 0 <= xr ? [0, Tr, [0, Hr, 0]] : [0, Hr, [0, Tr, 0]];
                                    return [0, Rr, Or];
                                  }
                                }
                              } else if (ar === 3 && W0) {
                                var Wr = W0[2];
                                if (Wr) {
                                  var Jr = Wr[2];
                                  if (Jr) {
                                    var or = Jr[1], _r = Wr[1], Ir = W0[1], fe = Jr[2], v0 = a(X0, Ir, _r);
                                    if (v0 === 0)
                                      var P = a(X0, _r, or), L = P === 0 ? [0, _r, 0] : 0 <= P ? [0, or, [0, _r, 0]] : [0, _r, [0, or, 0]], Q = L;
                                    else if (0 <= v0) {
                                      var i0 = a(X0, Ir, or);
                                      if (i0 === 0)
                                        var T0 = [0, _r, [0, Ir, 0]];
                                      else if (0 <= i0)
                                        var l0 = a(X0, _r, or), S0 = l0 === 0 ? [0, _r, [0, Ir, 0]] : 0 <= l0 ? [0, or, [0, _r, [0, Ir, 0]]] : [0, _r, [0, or, [0, Ir, 0]]], T0 = S0;
                                      else
                                        var T0 = [0, _r, [0, Ir, [0, or, 0]]];
                                      var Q = T0;
                                    } else {
                                      var er = a(X0, _r, or);
                                      if (er === 0)
                                        var Z = [0, Ir, [0, _r, 0]];
                                      else if (0 <= er)
                                        var j0 = a(X0, Ir, or), B = j0 === 0 ? [0, Ir, [0, _r, 0]] : 0 <= j0 ? [0, or, [0, Ir, [0, _r, 0]]] : [0, Ir, [0, or, [0, _r, 0]]], Z = B;
                                      else
                                        var Z = [0, Ir, [0, _r, [0, or, 0]]];
                                      var Q = Z;
                                    }
                                    return [0, Q, fe];
                                  }
                                }
                              }
                              for (var p0 = ar >> 1, b0 = b(p0, W0), O0 = b0[1], q0 = b(ar - p0 | 0, b0[2]), nr = O0, yr = q0[1], vr = 0, $0 = q0[2]; ; ) {
                                if (nr) {
                                  if (yr) {
                                    var Sr = yr[2], Mr = yr[1], Br = nr[2], qr = nr[1], jr = a(X0, qr, Mr);
                                    if (jr === 0) {
                                      var nr = Br, yr = Sr, vr = [0, qr, vr];
                                      continue;
                                    }
                                    if (0 < jr) {
                                      var nr = Br, vr = [0, qr, vr];
                                      continue;
                                    }
                                    var yr = Sr, vr = [0, Mr, vr];
                                    continue;
                                  }
                                  var $r = jc(nr, vr);
                                } else
                                  var $r = jc(yr, vr);
                                return [0, $r, $0];
                              }
                            }, X = Rc(e0), s0 = 2 <= X ? G0(X, e0)[1] : e0, dr = function(ar, W0) {
                              if (!(3 < ar >>> 0))
                                switch (ar) {
                                  case 0:
                                    return [0, 0, W0];
                                  case 1:
                                    if (W0)
                                      return [0, [0, W0[1]], W0[2]];
                                    break;
                                  case 2:
                                    if (W0) {
                                      var Lr = W0[2];
                                      if (Lr)
                                        return [0, [1, 2, Lr[1], [0, W0[1]], 0], Lr[2]];
                                    }
                                    break;
                                  default:
                                    if (W0) {
                                      var Tr = W0[2];
                                      if (Tr) {
                                        var Hr = Tr[2];
                                        if (Hr)
                                          return [0, [1, 2, Tr[1], [0, W0[1]], [0, Hr[1]]], Hr[2]];
                                      }
                                    }
                                }
                              var Or = ar / 2 | 0, xr = dr(Or, W0), Rr = xr[2];
                              if (Rr) {
                                var Wr = dr((ar - Or | 0) - 1 | 0, Rr[2]), Jr = Wr[2];
                                return [0, Ds(xr[1], Rr[1], Wr[1]), Jr];
                              }
                              throw [0, Fn, v5r];
                            };
                            return dr(Rc(s0), s0)[1];
                          }
                          var Ar = n(E0, n(w0, n(t0, [0, l])));
                          return n(_0[1], Ar);
                        }
                        return n(E0, n(w0, n(t0, [0, l])));
                      }
                      return n(w0, n(t0, [0, l]));
                    }
                    return n(t0, [0, l]);
                  }
                  return [0, l];
                }
                return lt;
              }
              return [0, lt, tL, i, n, zee, x, c, s, y, T, E, h, w, G, k0, A, S, M, K, V, nL, fr0, Pl, tr0, ur0, Kee, Pl, tr0, f0, m0, Vee, g0, function(e0, x0, l) {
                u(f(x0), a5r);
                var c0 = fr0(l);
                c0 && u(f(x0), o5r);
                var t0 = 0;
                return be(function(a0, w0) {
                  return a0 && u(f(x0), x5r), a(e0, x0, w0), 1;
                }, t0, c0), c0 && u(f(x0), c5r), u(f(x0), s5r);
              }, rL];
            }
            var xr0 = l5r.slice();
            function iL(t4) {
              for (var n = 0, e = xr0.length - 1 - 1 | 0; ; ) {
                if (e < n)
                  return 0;
                var i = n + ((e - n | 0) / 2 | 0) | 0, x = xr0[1 + i];
                if (t4 < x[1]) {
                  var e = i - 1 | 0;
                  continue;
                }
                if (x[2] <= t4) {
                  var n = i + 1 | 0;
                  continue;
                }
                return 1;
              }
            }
            var ar0 = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(ar0, function(t4, n) {
              if (typeof t4 == "number") {
                var e = t4;
                if (55 <= e)
                  switch (e) {
                    case 55:
                      if (typeof n == "number") {
                        var i = n !== 55 ? 1 : 0;
                        if (!i)
                          return i;
                      }
                      break;
                    case 56:
                      if (typeof n == "number") {
                        var x = n !== 56 ? 1 : 0;
                        if (!x)
                          return x;
                      }
                      break;
                    case 57:
                      if (typeof n == "number") {
                        var c = n !== 57 ? 1 : 0;
                        if (!c)
                          return c;
                      }
                      break;
                    case 58:
                      if (typeof n == "number") {
                        var s = n !== 58 ? 1 : 0;
                        if (!s)
                          return s;
                      }
                      break;
                    case 59:
                      if (typeof n == "number") {
                        var p = n !== 59 ? 1 : 0;
                        if (!p)
                          return p;
                      }
                      break;
                    case 60:
                      if (typeof n == "number") {
                        var y = n !== 60 ? 1 : 0;
                        if (!y)
                          return y;
                      }
                      break;
                    case 61:
                      if (typeof n == "number") {
                        var T = n !== 61 ? 1 : 0;
                        if (!T)
                          return T;
                      }
                      break;
                    case 62:
                      if (typeof n == "number") {
                        var E = n !== 62 ? 1 : 0;
                        if (!E)
                          return E;
                      }
                      break;
                    case 63:
                      if (typeof n == "number") {
                        var h = n !== 63 ? 1 : 0;
                        if (!h)
                          return h;
                      }
                      break;
                    case 64:
                      if (typeof n == "number") {
                        var w = n !== 64 ? 1 : 0;
                        if (!w)
                          return w;
                      }
                      break;
                    case 65:
                      if (typeof n == "number") {
                        var G = n !== 65 ? 1 : 0;
                        if (!G)
                          return G;
                      }
                      break;
                    case 66:
                      if (typeof n == "number") {
                        var A = n !== 66 ? 1 : 0;
                        if (!A)
                          return A;
                      }
                      break;
                    case 67:
                      if (typeof n == "number") {
                        var S = n !== 67 ? 1 : 0;
                        if (!S)
                          return S;
                      }
                      break;
                    case 68:
                      if (typeof n == "number") {
                        var M = n !== 68 ? 1 : 0;
                        if (!M)
                          return M;
                      }
                      break;
                    case 69:
                      if (typeof n == "number") {
                        var K = n !== 69 ? 1 : 0;
                        if (!K)
                          return K;
                      }
                      break;
                    case 70:
                      if (typeof n == "number") {
                        var V = n !== 70 ? 1 : 0;
                        if (!V)
                          return V;
                      }
                      break;
                    case 71:
                      if (typeof n == "number") {
                        var f0 = n !== 71 ? 1 : 0;
                        if (!f0)
                          return f0;
                      }
                      break;
                    case 72:
                      if (typeof n == "number") {
                        var m0 = n !== 72 ? 1 : 0;
                        if (!m0)
                          return m0;
                      }
                      break;
                    case 73:
                      if (typeof n == "number") {
                        var k0 = n !== 73 ? 1 : 0;
                        if (!k0)
                          return k0;
                      }
                      break;
                    case 74:
                      if (typeof n == "number") {
                        var g0 = n !== 74 ? 1 : 0;
                        if (!g0)
                          return g0;
                      }
                      break;
                    case 75:
                      if (typeof n == "number") {
                        var e0 = n !== 75 ? 1 : 0;
                        if (!e0)
                          return e0;
                      }
                      break;
                    case 76:
                      if (typeof n == "number") {
                        var x0 = n !== 76 ? 1 : 0;
                        if (!x0)
                          return x0;
                      }
                      break;
                    case 77:
                      if (typeof n == "number") {
                        var l = n !== 77 ? 1 : 0;
                        if (!l)
                          return l;
                      }
                      break;
                    case 78:
                      if (typeof n == "number") {
                        var c0 = n !== 78 ? 1 : 0;
                        if (!c0)
                          return c0;
                      }
                      break;
                    case 79:
                      if (typeof n == "number") {
                        var t0 = n !== 79 ? 1 : 0;
                        if (!t0)
                          return t0;
                      }
                      break;
                    case 80:
                      if (typeof n == "number") {
                        var a0 = n !== 80 ? 1 : 0;
                        if (!a0)
                          return a0;
                      }
                      break;
                    case 81:
                      if (typeof n == "number") {
                        var w0 = n !== 81 ? 1 : 0;
                        if (!w0)
                          return w0;
                      }
                      break;
                    case 82:
                      if (typeof n == "number") {
                        var _0 = n !== 82 ? 1 : 0;
                        if (!_0)
                          return _0;
                      }
                      break;
                    case 83:
                      if (typeof n == "number") {
                        var E0 = n !== 83 ? 1 : 0;
                        if (!E0)
                          return E0;
                      }
                      break;
                    case 84:
                      if (typeof n == "number") {
                        var X0 = n !== 84 ? 1 : 0;
                        if (!X0)
                          return X0;
                      }
                      break;
                    case 85:
                      if (typeof n == "number") {
                        var b = n !== 85 ? 1 : 0;
                        if (!b)
                          return b;
                      }
                      break;
                    case 86:
                      if (typeof n == "number") {
                        var G0 = n !== 86 ? 1 : 0;
                        if (!G0)
                          return G0;
                      }
                      break;
                    case 87:
                      if (typeof n == "number") {
                        var X = n !== 87 ? 1 : 0;
                        if (!X)
                          return X;
                      }
                      break;
                    case 88:
                      if (typeof n == "number") {
                        var s0 = n !== 88 ? 1 : 0;
                        if (!s0)
                          return s0;
                      }
                      break;
                    case 89:
                      if (typeof n == "number") {
                        var dr = n !== 89 ? 1 : 0;
                        if (!dr)
                          return dr;
                      }
                      break;
                    case 90:
                      if (typeof n == "number") {
                        var Ar = n !== 90 ? 1 : 0;
                        if (!Ar)
                          return Ar;
                      }
                      break;
                    case 91:
                      if (typeof n == "number") {
                        var ar = n !== 91 ? 1 : 0;
                        if (!ar)
                          return ar;
                      }
                      break;
                    case 92:
                      if (typeof n == "number") {
                        var W0 = n !== 92 ? 1 : 0;
                        if (!W0)
                          return W0;
                      }
                      break;
                    case 93:
                      if (typeof n == "number") {
                        var Lr = n !== 93 ? 1 : 0;
                        if (!Lr)
                          return Lr;
                      }
                      break;
                    case 94:
                      if (typeof n == "number") {
                        var Tr = n !== 94 ? 1 : 0;
                        if (!Tr)
                          return Tr;
                      }
                      break;
                    case 95:
                      if (typeof n == "number") {
                        var Hr = n !== 95 ? 1 : 0;
                        if (!Hr)
                          return Hr;
                      }
                      break;
                    case 96:
                      if (typeof n == "number") {
                        var Or = n !== 96 ? 1 : 0;
                        if (!Or)
                          return Or;
                      }
                      break;
                    case 97:
                      if (typeof n == "number") {
                        var xr = n !== 97 ? 1 : 0;
                        if (!xr)
                          return xr;
                      }
                      break;
                    case 98:
                      if (typeof n == "number") {
                        var Rr = n !== 98 ? 1 : 0;
                        if (!Rr)
                          return Rr;
                      }
                      break;
                    case 99:
                      if (typeof n == "number") {
                        var Wr = n !== 99 ? 1 : 0;
                        if (!Wr)
                          return Wr;
                      }
                      break;
                    case 100:
                      if (typeof n == "number") {
                        var Jr = ti !== n ? 1 : 0;
                        if (!Jr)
                          return Jr;
                      }
                      break;
                    case 101:
                      if (typeof n == "number") {
                        var or = R7 !== n ? 1 : 0;
                        if (!or)
                          return or;
                      }
                      break;
                    case 102:
                      if (typeof n == "number") {
                        var _r = ji !== n ? 1 : 0;
                        if (!_r)
                          return _r;
                      }
                      break;
                    case 103:
                      if (typeof n == "number") {
                        var Ir = s7 !== n ? 1 : 0;
                        if (!Ir)
                          return Ir;
                      }
                      break;
                    case 104:
                      if (typeof n == "number") {
                        var fe = L7 !== n ? 1 : 0;
                        if (!fe)
                          return fe;
                      }
                      break;
                    case 105:
                      if (typeof n == "number") {
                        var v0 = j7 !== n ? 1 : 0;
                        if (!v0)
                          return v0;
                      }
                      break;
                    case 106:
                      if (typeof n == "number") {
                        var P = Vt !== n ? 1 : 0;
                        if (!P)
                          return P;
                      }
                      break;
                    case 107:
                      if (typeof n == "number") {
                        var L = Qc !== n ? 1 : 0;
                        if (!L)
                          return L;
                      }
                      break;
                    default:
                      if (typeof n == "number" && fs2 <= n)
                        return 0;
                  }
                else
                  switch (e) {
                    case 0:
                      if (typeof n == "number" && !n)
                        return n;
                      break;
                    case 1:
                      if (typeof n == "number") {
                        var Q = n !== 1 ? 1 : 0;
                        if (!Q)
                          return Q;
                      }
                      break;
                    case 2:
                      if (typeof n == "number") {
                        var i0 = n !== 2 ? 1 : 0;
                        if (!i0)
                          return i0;
                      }
                      break;
                    case 3:
                      if (typeof n == "number") {
                        var l0 = n !== 3 ? 1 : 0;
                        if (!l0)
                          return l0;
                      }
                      break;
                    case 4:
                      if (typeof n == "number") {
                        var S0 = n !== 4 ? 1 : 0;
                        if (!S0)
                          return S0;
                      }
                      break;
                    case 5:
                      if (typeof n == "number") {
                        var T0 = n !== 5 ? 1 : 0;
                        if (!T0)
                          return T0;
                      }
                      break;
                    case 6:
                      if (typeof n == "number") {
                        var er = n !== 6 ? 1 : 0;
                        if (!er)
                          return er;
                      }
                      break;
                    case 7:
                      if (typeof n == "number") {
                        var j0 = n !== 7 ? 1 : 0;
                        if (!j0)
                          return j0;
                      }
                      break;
                    case 8:
                      if (typeof n == "number") {
                        var B = n !== 8 ? 1 : 0;
                        if (!B)
                          return B;
                      }
                      break;
                    case 9:
                      if (typeof n == "number") {
                        var Z = n !== 9 ? 1 : 0;
                        if (!Z)
                          return Z;
                      }
                      break;
                    case 10:
                      if (typeof n == "number") {
                        var p0 = n !== 10 ? 1 : 0;
                        if (!p0)
                          return p0;
                      }
                      break;
                    case 11:
                      if (typeof n == "number") {
                        var b0 = n !== 11 ? 1 : 0;
                        if (!b0)
                          return b0;
                      }
                      break;
                    case 12:
                      if (typeof n == "number") {
                        var O0 = n !== 12 ? 1 : 0;
                        if (!O0)
                          return O0;
                      }
                      break;
                    case 13:
                      if (typeof n == "number") {
                        var q0 = n !== 13 ? 1 : 0;
                        if (!q0)
                          return q0;
                      }
                      break;
                    case 14:
                      if (typeof n == "number") {
                        var nr = n !== 14 ? 1 : 0;
                        if (!nr)
                          return nr;
                      }
                      break;
                    case 15:
                      if (typeof n == "number") {
                        var yr = n !== 15 ? 1 : 0;
                        if (!yr)
                          return yr;
                      }
                      break;
                    case 16:
                      if (typeof n == "number") {
                        var vr = n !== 16 ? 1 : 0;
                        if (!vr)
                          return vr;
                      }
                      break;
                    case 17:
                      if (typeof n == "number") {
                        var $0 = n !== 17 ? 1 : 0;
                        if (!$0)
                          return $0;
                      }
                      break;
                    case 18:
                      if (typeof n == "number") {
                        var Sr = n !== 18 ? 1 : 0;
                        if (!Sr)
                          return Sr;
                      }
                      break;
                    case 19:
                      if (typeof n == "number") {
                        var Mr = n !== 19 ? 1 : 0;
                        if (!Mr)
                          return Mr;
                      }
                      break;
                    case 20:
                      if (typeof n == "number") {
                        var Br = n !== 20 ? 1 : 0;
                        if (!Br)
                          return Br;
                      }
                      break;
                    case 21:
                      if (typeof n == "number") {
                        var qr = n !== 21 ? 1 : 0;
                        if (!qr)
                          return qr;
                      }
                      break;
                    case 22:
                      if (typeof n == "number") {
                        var jr = n !== 22 ? 1 : 0;
                        if (!jr)
                          return jr;
                      }
                      break;
                    case 23:
                      if (typeof n == "number") {
                        var $r = n !== 23 ? 1 : 0;
                        if (!$r)
                          return $r;
                      }
                      break;
                    case 24:
                      if (typeof n == "number") {
                        var ne = n !== 24 ? 1 : 0;
                        if (!ne)
                          return ne;
                      }
                      break;
                    case 25:
                      if (typeof n == "number") {
                        var Qr = n !== 25 ? 1 : 0;
                        if (!Qr)
                          return Qr;
                      }
                      break;
                    case 26:
                      if (typeof n == "number") {
                        var pe = n !== 26 ? 1 : 0;
                        if (!pe)
                          return pe;
                      }
                      break;
                    case 27:
                      if (typeof n == "number") {
                        var oe = n !== 27 ? 1 : 0;
                        if (!oe)
                          return oe;
                      }
                      break;
                    case 28:
                      if (typeof n == "number") {
                        var me = n !== 28 ? 1 : 0;
                        if (!me)
                          return me;
                      }
                      break;
                    case 29:
                      if (typeof n == "number") {
                        var ae = n !== 29 ? 1 : 0;
                        if (!ae)
                          return ae;
                      }
                      break;
                    case 30:
                      if (typeof n == "number") {
                        var ce = n !== 30 ? 1 : 0;
                        if (!ce)
                          return ce;
                      }
                      break;
                    case 31:
                      if (typeof n == "number") {
                        var ge = n !== 31 ? 1 : 0;
                        if (!ge)
                          return ge;
                      }
                      break;
                    case 32:
                      if (typeof n == "number") {
                        var H0 = n !== 32 ? 1 : 0;
                        if (!H0)
                          return H0;
                      }
                      break;
                    case 33:
                      if (typeof n == "number") {
                        var Fr = n !== 33 ? 1 : 0;
                        if (!Fr)
                          return Fr;
                      }
                      break;
                    case 34:
                      if (typeof n == "number") {
                        var _ = n !== 34 ? 1 : 0;
                        if (!_)
                          return _;
                      }
                      break;
                    case 35:
                      if (typeof n == "number") {
                        var k = n !== 35 ? 1 : 0;
                        if (!k)
                          return k;
                      }
                      break;
                    case 36:
                      if (typeof n == "number") {
                        var I = n !== 36 ? 1 : 0;
                        if (!I)
                          return I;
                      }
                      break;
                    case 37:
                      if (typeof n == "number") {
                        var U = n !== 37 ? 1 : 0;
                        if (!U)
                          return U;
                      }
                      break;
                    case 38:
                      if (typeof n == "number") {
                        var Y = n !== 38 ? 1 : 0;
                        if (!Y)
                          return Y;
                      }
                      break;
                    case 39:
                      if (typeof n == "number") {
                        var y0 = n !== 39 ? 1 : 0;
                        if (!y0)
                          return y0;
                      }
                      break;
                    case 40:
                      if (typeof n == "number") {
                        var D0 = n !== 40 ? 1 : 0;
                        if (!D0)
                          return D0;
                      }
                      break;
                    case 41:
                      if (typeof n == "number") {
                        var A0 = n !== 41 ? 1 : 0;
                        if (!A0)
                          return A0;
                      }
                      break;
                    case 42:
                      if (typeof n == "number") {
                        var D = n !== 42 ? 1 : 0;
                        if (!D)
                          return D;
                      }
                      break;
                    case 43:
                      if (typeof n == "number") {
                        var u0 = n !== 43 ? 1 : 0;
                        if (!u0)
                          return u0;
                      }
                      break;
                    case 44:
                      if (typeof n == "number") {
                        var Y0 = n !== 44 ? 1 : 0;
                        if (!Y0)
                          return Y0;
                      }
                      break;
                    case 45:
                      if (typeof n == "number") {
                        var J0 = n !== 45 ? 1 : 0;
                        if (!J0)
                          return J0;
                      }
                      break;
                    case 46:
                      if (typeof n == "number") {
                        var fr = n !== 46 ? 1 : 0;
                        if (!fr)
                          return fr;
                      }
                      break;
                    case 47:
                      if (typeof n == "number") {
                        var Q0 = n !== 47 ? 1 : 0;
                        if (!Q0)
                          return Q0;
                      }
                      break;
                    case 48:
                      if (typeof n == "number") {
                        var F0 = n !== 48 ? 1 : 0;
                        if (!F0)
                          return F0;
                      }
                      break;
                    case 49:
                      if (typeof n == "number") {
                        var gr = n !== 49 ? 1 : 0;
                        if (!gr)
                          return gr;
                      }
                      break;
                    case 50:
                      if (typeof n == "number") {
                        var mr = n !== 50 ? 1 : 0;
                        if (!mr)
                          return mr;
                      }
                      break;
                    case 51:
                      if (typeof n == "number") {
                        var Cr = n !== 51 ? 1 : 0;
                        if (!Cr)
                          return Cr;
                      }
                      break;
                    case 52:
                      if (typeof n == "number") {
                        var sr = n !== 52 ? 1 : 0;
                        if (!sr)
                          return sr;
                      }
                      break;
                    case 53:
                      if (typeof n == "number") {
                        var Pr = n !== 53 ? 1 : 0;
                        if (!Pr)
                          return Pr;
                      }
                      break;
                    default:
                      if (typeof n == "number") {
                        var K0 = n !== 54 ? 1 : 0;
                        if (!K0)
                          return K0;
                      }
                  }
              } else
                switch (t4[0]) {
                  case 0:
                    if (typeof n != "number" && n[0] === 0) {
                      var Ur = Ee(t4[1], n[1]);
                      return Ur === 0 ? Ee(t4[2], n[2]) : Ur;
                    }
                    break;
                  case 1:
                    if (typeof n != "number" && n[0] === 1) {
                      var d0 = Ee(t4[1], n[1]);
                      return d0 === 0 ? Ee(t4[2], n[2]) : d0;
                    }
                    break;
                  case 2:
                    if (typeof n != "number" && n[0] === 2)
                      return Ee(t4[1], n[1]);
                    break;
                  case 3:
                    if (typeof n != "number" && n[0] === 3) {
                      var Kr = n[2], re = t4[2], xe = Ee(t4[1], n[1]);
                      if (xe === 0) {
                        if (re)
                          return Kr ? Ee(re[1], Kr[1]) : 1;
                        var je = Kr && -1;
                        return je;
                      }
                      return xe;
                    }
                    break;
                  case 4:
                    if (typeof n != "number" && n[0] === 4)
                      return Ee(t4[1], n[1]);
                    break;
                  case 5:
                    if (typeof n != "number" && n[0] === 5) {
                      var le = n[2], Ie = t4[2], Me = Ee(t4[1], n[1]);
                      if (Me === 0) {
                        if (Ie)
                          if (le) {
                            var Be = le[1], an = Ie[1], Ke = 0;
                            switch (an) {
                              case 0:
                                if (Be)
                                  Ke = 1;
                                else
                                  var sn = Be;
                                break;
                              case 1:
                                var Ae = Be !== 1 ? 1 : 0;
                                if (Ae)
                                  Ke = 1;
                                else
                                  var sn = Ae;
                                break;
                              case 2:
                                var on = Be !== 2 ? 1 : 0;
                                if (on)
                                  Ke = 1;
                                else
                                  var sn = on;
                                break;
                              default:
                                if (3 <= Be)
                                  var sn = 0;
                                else
                                  Ke = 1;
                            }
                            if (Ke)
                              var rn = function(Pt) {
                                switch (Pt) {
                                  case 0:
                                    return 0;
                                  case 1:
                                    return 1;
                                  case 2:
                                    return 2;
                                  default:
                                    return 3;
                                }
                              }, kn = rn(Be), sn = Cc(rn(an), kn);
                            var Pe = sn;
                          } else
                            var Pe = 1;
                        else
                          var Pe = le && -1;
                        return Pe === 0 ? Ee(t4[3], n[3]) : Pe;
                      }
                      return Me;
                    }
                    break;
                  case 6:
                    if (typeof n != "number" && n[0] === 6) {
                      var We = Ee(t4[1], n[1]);
                      return We === 0 ? Ee(t4[2], n[2]) : We;
                    }
                    break;
                  case 7:
                    if (typeof n != "number" && n[0] === 7)
                      return Cc(t4[1], n[1]);
                    break;
                  case 8:
                    if (typeof n != "number" && n[0] === 8) {
                      var en = Ee(t4[1], n[1]);
                      return en === 0 ? Ee(t4[2], n[2]) : en;
                    }
                    break;
                  case 9:
                    if (typeof n != "number" && n[0] === 9)
                      return Ee(t4[1], n[1]);
                    break;
                  case 10:
                    if (typeof n != "number" && n[0] === 10)
                      return Ee(t4[1], n[1]);
                    break;
                  case 11:
                    if (typeof n != "number" && n[0] === 11) {
                      var _n = Ee(t4[1], n[1]);
                      return _n === 0 ? Ee(t4[2], n[2]) : _n;
                    }
                    break;
                  case 12:
                    if (typeof n != "number" && n[0] === 12) {
                      var Dn = Ee(t4[1], n[1]);
                      return Dn === 0 ? Ee(t4[2], n[2]) : Dn;
                    }
                    break;
                  case 13:
                    if (typeof n != "number" && n[0] === 13)
                      return Ee(t4[1], n[1]);
                    break;
                  case 14:
                    if (typeof n != "number" && n[0] === 14)
                      return Cc(t4[1], n[1]);
                    break;
                  case 15:
                    if (typeof n != "number" && n[0] === 15)
                      return Ee(t4[1], n[1]);
                    break;
                  case 16:
                    if (typeof n != "number" && n[0] === 16) {
                      var Xn = Ee(t4[1], n[1]);
                      return Xn === 0 ? Ee(t4[2], n[2]) : Xn;
                    }
                    break;
                  case 17:
                    if (typeof n != "number" && n[0] === 17)
                      return Ee(t4[1], n[1]);
                    break;
                  case 18:
                    if (typeof n != "number" && n[0] === 18)
                      return Cc(t4[1], n[1]);
                    break;
                  case 19:
                    if (typeof n != "number" && n[0] === 19)
                      return Ee(t4[1], n[1]);
                    break;
                  case 20:
                    if (typeof n != "number" && n[0] === 20)
                      return Ee(t4[1], n[1]);
                    break;
                  case 21:
                    if (typeof n != "number" && n[0] === 21) {
                      var On = Ee(t4[1], n[1]);
                      if (On === 0) {
                        var bt = Cc(t4[2], n[2]);
                        if (bt === 0) {
                          var Ct = Cc(t4[3], n[3]);
                          return Ct === 0 ? Cc(t4[4], n[4]) : Ct;
                        }
                        return bt;
                      }
                      return On;
                    }
                    break;
                  case 22:
                    if (typeof n != "number" && n[0] === 22)
                      return Ee(t4[1], n[1]);
                    break;
                  default:
                    if (typeof n != "number" && n[0] === 23)
                      return Ee(t4[1], n[1]);
                }
              function Tt(Ut) {
                if (typeof Ut == "number") {
                  var Ot = Ut;
                  if (55 <= Ot)
                    switch (Ot) {
                      case 55:
                        return 72;
                      case 56:
                        return 73;
                      case 57:
                        return 74;
                      case 58:
                        return 76;
                      case 59:
                        return 77;
                      case 60:
                        return 78;
                      case 61:
                        return 80;
                      case 62:
                        return 81;
                      case 63:
                        return 82;
                      case 64:
                        return 83;
                      case 65:
                        return 84;
                      case 66:
                        return 85;
                      case 67:
                        return 86;
                      case 68:
                        return 87;
                      case 69:
                        return 88;
                      case 70:
                        return 89;
                      case 71:
                        return 90;
                      case 72:
                        return 91;
                      case 73:
                        return 92;
                      case 74:
                        return 93;
                      case 75:
                        return 94;
                      case 76:
                        return 96;
                      case 77:
                        return 97;
                      case 78:
                        return 98;
                      case 79:
                        return 99;
                      case 80:
                        return ti;
                      case 81:
                        return R7;
                      case 82:
                        return ji;
                      case 83:
                        return s7;
                      case 84:
                        return L7;
                      case 85:
                        return j7;
                      case 86:
                        return Vt;
                      case 87:
                        return Qc;
                      case 88:
                        return Yt;
                      case 89:
                        return T7;
                      case 90:
                        return Ln;
                      case 91:
                        return u1;
                      case 92:
                        return Av;
                      case 93:
                        return x1;
                      case 94:
                        return A2;
                      case 95:
                        return z2;
                      case 96:
                        return Sv;
                      case 97:
                        return fc;
                      case 98:
                        return tl;
                      case 99:
                        return Nn;
                      case 100:
                        return us;
                      case 101:
                        return br;
                      case 102:
                        return DX;
                      case 103:
                        return Kn;
                      case 104:
                        return Gt;
                      case 105:
                        return eV;
                      case 106:
                        return Jw;
                      case 107:
                        return Qg;
                      default:
                        return YH;
                    }
                  switch (Ot) {
                    case 0:
                      return 4;
                    case 1:
                      return 8;
                    case 2:
                      return 15;
                    case 3:
                      return 16;
                    case 4:
                      return 17;
                    case 5:
                      return 18;
                    case 6:
                      return 19;
                    case 7:
                      return 20;
                    case 8:
                      return 21;
                    case 9:
                      return 22;
                    case 10:
                      return 23;
                    case 11:
                      return 24;
                    case 12:
                      return 25;
                    case 13:
                      return 26;
                    case 14:
                      return 27;
                    case 15:
                      return 28;
                    case 16:
                      return 29;
                    case 17:
                      return 30;
                    case 18:
                      return 31;
                    case 19:
                      return 32;
                    case 20:
                      return 33;
                    case 21:
                      return 34;
                    case 22:
                      return 35;
                    case 23:
                      return 36;
                    case 24:
                      return 37;
                    case 25:
                      return 39;
                    case 26:
                      return 40;
                    case 27:
                      return 41;
                    case 28:
                      return 42;
                    case 29:
                      return 43;
                    case 30:
                      return 45;
                    case 31:
                      return 46;
                    case 32:
                      return 47;
                    case 33:
                      return 48;
                    case 34:
                      return 51;
                    case 35:
                      return 52;
                    case 36:
                      return 53;
                    case 37:
                      return 54;
                    case 38:
                      return 55;
                    case 39:
                      return 56;
                    case 40:
                      return 57;
                    case 41:
                      return 58;
                    case 42:
                      return 59;
                    case 43:
                      return 60;
                    case 44:
                      return 61;
                    case 45:
                      return 62;
                    case 46:
                      return 63;
                    case 47:
                      return 64;
                    case 48:
                      return 65;
                    case 49:
                      return 66;
                    case 50:
                      return 67;
                    case 51:
                      return 68;
                    case 52:
                      return 69;
                    case 53:
                      return 70;
                    default:
                      return 71;
                  }
                } else
                  switch (Ut[0]) {
                    case 0:
                      return 0;
                    case 1:
                      return 1;
                    case 2:
                      return 2;
                    case 3:
                      return 3;
                    case 4:
                      return 5;
                    case 5:
                      return 6;
                    case 6:
                      return 7;
                    case 7:
                      return 9;
                    case 8:
                      return 10;
                    case 9:
                      return 11;
                    case 10:
                      return 12;
                    case 11:
                      return 13;
                    case 12:
                      return 14;
                    case 13:
                      return 38;
                    case 14:
                      return 44;
                    case 15:
                      return 49;
                    case 16:
                      return 50;
                    case 17:
                      return 75;
                    case 18:
                      return 79;
                    case 19:
                      return 95;
                    case 20:
                      return fs2;
                    case 21:
                      return Fv;
                    case 22:
                      return vf;
                    default:
                      return X2;
                  }
              }
              var Zt = Tt(n);
              return Cc(Tt(t4), Zt);
            });
            var Wee = [St, __r, M7(0)];
            M7(0);
            var A1 = [St, d_r, M7(0)], or0 = 0, cr0 = 0, sr0 = 0, vr0 = 0, lr0 = 0, br0 = 0, pr0 = 0, mr0 = 0, _r0 = 0, yr0 = 0;
            function j(t4) {
              if (t4[3] === t4[2])
                return -1;
              var n = t4[1][1 + t4[3]];
              return t4[3] = t4[3] + 1 | 0, n === 10 && (t4[5] !== 0 && (t4[5] = t4[5] + 1 | 0), t4[4] = t4[3]), n;
            }
            function B0(t4, n) {
              return t4[9] = t4[3], t4[10] = t4[4], t4[11] = t4[5], t4[12] = n, 0;
            }
            function Tn(t4) {
              return t4[6] = t4[3], t4[7] = t4[4], t4[8] = t4[5], B0(t4, -1);
            }
            function q(t4) {
              return t4[3] = t4[9], t4[4] = t4[10], t4[5] = t4[11], t4[12];
            }
            function $v(t4) {
              return t4[3] = t4[6], t4[4] = t4[7], t4[5] = t4[8], 0;
            }
            function fL(t4, n) {
              return t4[6] = n, 0;
            }
            function $m(t4) {
              return t4[3] - t4[6] | 0;
            }
            function Ll(t4) {
              var n = t4[3] - t4[6] | 0, e = t4[6], i = t4[1];
              return 0 <= e && 0 <= n && !((i.length - 1 - n | 0) < e) ? b70(i, e, n) : Nu(Mi0);
            }
            function dr0(t4) {
              var n = t4[6];
              return nu(t4[1], n)[1 + n];
            }
            function Rl(t4, n, e, i) {
              for (var x = 0, c = e, s = n; ; ) {
                if (0 < c) {
                  var p = t4[1 + s];
                  if (0 <= p) {
                    if (Kn < p)
                      if (xX < p)
                        if (H8 < p) {
                          if (mI < p)
                            throw A1;
                          Zn(i, x, v1 | p >>> 18 | 0), Zn(i, x + 1 | 0, Gt | (p >>> 12 | 0) & 63), Zn(i, x + 2 | 0, Gt | (p >>> 6 | 0) & 63), Zn(i, x + 3 | 0, Gt | p & 63);
                          var y = x + 4 | 0;
                        } else {
                          Zn(i, x, dv | p >>> 12 | 0), Zn(i, x + 1 | 0, Gt | (p >>> 6 | 0) & 63), Zn(i, x + 2 | 0, Gt | p & 63);
                          var y = x + 3 | 0;
                        }
                      else {
                        Zn(i, x, In | p >>> 6 | 0), Zn(i, x + 1 | 0, Gt | p & 63);
                        var y = x + 2 | 0;
                      }
                    else {
                      Zn(i, x, p);
                      var y = x + 1 | 0;
                    }
                    var x = y, c = c - 1 | 0, s = s + 1 | 0;
                    continue;
                  }
                  throw A1;
                }
                return x;
              }
            }
            function hr0(t4) {
              for (var n = tn(t4), e = Gv(n, 0), i = 0, x = 0; ; ) {
                if (x < n) {
                  var c = Vr(t4, x), s = 0;
                  if (In <= c)
                    if (v1 <= c)
                      if (St <= c)
                        s = 1;
                      else {
                        var p = Vr(t4, x + 1 | 0), y = Vr(t4, x + 2 | 0), T = Vr(t4, x + 3 | 0), E = (p >>> 6 | 0) !== 2 ? 1 : 0;
                        if (E)
                          var w = E;
                        else
                          var h = (y >>> 6 | 0) !== 2 ? 1 : 0, w = h || ((T >>> 6 | 0) !== 2 ? 1 : 0);
                        if (w)
                          throw A1;
                        e[1 + i] = (c & 7) << 18 | (p & 63) << 12 | (y & 63) << 6 | T & 63;
                        var G = x + 4 | 0;
                      }
                    else if (dv <= c) {
                      var A = Vr(t4, x + 1 | 0), S = Vr(t4, x + 2 | 0), M = (c & 15) << 12 | (A & 63) << 6 | S & 63, K = (A >>> 6 | 0) !== 2 ? 1 : 0, V = K || ((S >>> 6 | 0) !== 2 ? 1 : 0);
                      if (V)
                        var m0 = V;
                      else
                        var f0 = 55296 <= M ? 1 : 0, m0 = f0 && (M <= 57088 ? 1 : 0);
                      if (m0)
                        throw A1;
                      e[1 + i] = M;
                      var G = x + 3 | 0;
                    } else {
                      var k0 = Vr(t4, x + 1 | 0);
                      if ((k0 >>> 6 | 0) !== 2)
                        throw A1;
                      e[1 + i] = (c & 31) << 6 | k0 & 63;
                      var G = x + 2 | 0;
                    }
                  else if (Gt <= c)
                    s = 1;
                  else {
                    e[1 + i] = c;
                    var G = x + 1 | 0;
                  }
                  if (s)
                    throw A1;
                  var i = i + 1 | 0, x = G;
                  continue;
                }
                return [0, e, i, yr0, _r0, mr0, pr0, br0, lr0, vr0, sr0, cr0, or0];
              }
            }
            function jl(t4, n, e) {
              var i = t4[6] + n | 0, x = Rt(e * 4 | 0), c = t4[1];
              if ((i + e | 0) <= c.length - 1)
                return qv(x, 0, Rl(c, i, e, x));
              throw [0, Fn, y_r];
            }
            function Se(t4) {
              var n = t4[6], e = t4[3] - n | 0, i = Rt(e * 4 | 0);
              return qv(i, 0, Rl(t4[1], n, e, i));
            }
            function Gl(t4, n) {
              var e = t4[6], i = t4[3] - e | 0, x = Rt(i * 4 | 0);
              return bN(n, x, 0, Rl(t4[1], e, i, x));
            }
            function xL(t4) {
              var n = t4.length - 1, e = Rt(n * 4 | 0);
              return qv(e, 0, Rl(t4, 0, n, e));
            }
            function kr0(t4, n) {
              return t4[3] = t4[3] - n | 0, 0;
            }
            var wr0 = 0;
            function Jee(t4, n, e) {
              return [0, t4, n, h_r, 0, e, wr0, k_r];
            }
            function Er0(t4) {
              var n = t4[2];
              return [0, t4[1], [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12]], t4[3], t4[4], t4[5], t4[6], t4[7]];
            }
            function Sr0(t4) {
              return t4[3][1];
            }
            function Zm(t4, n) {
              return t4 !== n[4] ? [0, n[1], n[2], n[3], t4, n[5], n[6], n[7]] : n;
            }
            var aL = function t4(n, e) {
              return t4.fun(n, e);
            }, gr0 = function t4(n, e) {
              return t4.fun(n, e);
            }, oL = function t4(n, e) {
              return t4.fun(n, e);
            }, cL = function t4(n, e) {
              return t4.fun(n, e);
            }, Fr0 = function t4(n, e) {
              return t4.fun(n, e);
            };
            N(aL, function(t4, n) {
              if (typeof t4 == "number") {
                var e = t4;
                if (61 <= e)
                  if (92 <= e)
                    switch (e) {
                      case 92:
                        if (typeof n == "number" && n === 92)
                          return 1;
                        break;
                      case 93:
                        if (typeof n == "number" && n === 93)
                          return 1;
                        break;
                      case 94:
                        if (typeof n == "number" && n === 94)
                          return 1;
                        break;
                      case 95:
                        if (typeof n == "number" && n === 95)
                          return 1;
                        break;
                      case 96:
                        if (typeof n == "number" && n === 96)
                          return 1;
                        break;
                      case 97:
                        if (typeof n == "number" && n === 97)
                          return 1;
                        break;
                      case 98:
                        if (typeof n == "number" && n === 98)
                          return 1;
                        break;
                      case 99:
                        if (typeof n == "number" && n === 99)
                          return 1;
                        break;
                      case 100:
                        if (typeof n == "number" && ti === n)
                          return 1;
                        break;
                      case 101:
                        if (typeof n == "number" && R7 === n)
                          return 1;
                        break;
                      case 102:
                        if (typeof n == "number" && ji === n)
                          return 1;
                        break;
                      case 103:
                        if (typeof n == "number" && s7 === n)
                          return 1;
                        break;
                      case 104:
                        if (typeof n == "number" && L7 === n)
                          return 1;
                        break;
                      case 105:
                        if (typeof n == "number" && j7 === n)
                          return 1;
                        break;
                      case 106:
                        if (typeof n == "number" && Vt === n)
                          return 1;
                        break;
                      case 107:
                        if (typeof n == "number" && Qc === n)
                          return 1;
                        break;
                      case 108:
                        if (typeof n == "number" && fs2 === n)
                          return 1;
                        break;
                      case 109:
                        if (typeof n == "number" && Fv === n)
                          return 1;
                        break;
                      case 110:
                        if (typeof n == "number" && Yt === n)
                          return 1;
                        break;
                      case 111:
                        if (typeof n == "number" && vf === n)
                          return 1;
                        break;
                      case 112:
                        if (typeof n == "number" && T7 === n)
                          return 1;
                        break;
                      case 113:
                        if (typeof n == "number" && Ln === n)
                          return 1;
                        break;
                      case 114:
                        if (typeof n == "number" && u1 === n)
                          return 1;
                        break;
                      case 115:
                        if (typeof n == "number" && Av === n)
                          return 1;
                        break;
                      case 116:
                        if (typeof n == "number" && x1 === n)
                          return 1;
                        break;
                      case 117:
                        if (typeof n == "number" && A2 === n)
                          return 1;
                        break;
                      case 118:
                        if (typeof n == "number" && z2 === n)
                          return 1;
                        break;
                      case 119:
                        if (typeof n == "number" && Sv === n)
                          return 1;
                        break;
                      case 120:
                        if (typeof n == "number" && fc === n)
                          return 1;
                        break;
                      default:
                        if (typeof n == "number" && tl <= n)
                          return 1;
                    }
                  else
                    switch (e) {
                      case 61:
                        if (typeof n == "number" && n === 61)
                          return 1;
                        break;
                      case 62:
                        if (typeof n == "number" && n === 62)
                          return 1;
                        break;
                      case 63:
                        if (typeof n == "number" && n === 63)
                          return 1;
                        break;
                      case 64:
                        if (typeof n == "number" && n === 64)
                          return 1;
                        break;
                      case 65:
                        if (typeof n == "number" && n === 65)
                          return 1;
                        break;
                      case 66:
                        if (typeof n == "number" && n === 66)
                          return 1;
                        break;
                      case 67:
                        if (typeof n == "number" && n === 67)
                          return 1;
                        break;
                      case 68:
                        if (typeof n == "number" && n === 68)
                          return 1;
                        break;
                      case 69:
                        if (typeof n == "number" && n === 69)
                          return 1;
                        break;
                      case 70:
                        if (typeof n == "number" && n === 70)
                          return 1;
                        break;
                      case 71:
                        if (typeof n == "number" && n === 71)
                          return 1;
                        break;
                      case 72:
                        if (typeof n == "number" && n === 72)
                          return 1;
                        break;
                      case 73:
                        if (typeof n == "number" && n === 73)
                          return 1;
                        break;
                      case 74:
                        if (typeof n == "number" && n === 74)
                          return 1;
                        break;
                      case 75:
                        if (typeof n == "number" && n === 75)
                          return 1;
                        break;
                      case 76:
                        if (typeof n == "number" && n === 76)
                          return 1;
                        break;
                      case 77:
                        if (typeof n == "number" && n === 77)
                          return 1;
                        break;
                      case 78:
                        if (typeof n == "number" && n === 78)
                          return 1;
                        break;
                      case 79:
                        if (typeof n == "number" && n === 79)
                          return 1;
                        break;
                      case 80:
                        if (typeof n == "number" && n === 80)
                          return 1;
                        break;
                      case 81:
                        if (typeof n == "number" && n === 81)
                          return 1;
                        break;
                      case 82:
                        if (typeof n == "number" && n === 82)
                          return 1;
                        break;
                      case 83:
                        if (typeof n == "number" && n === 83)
                          return 1;
                        break;
                      case 84:
                        if (typeof n == "number" && n === 84)
                          return 1;
                        break;
                      case 85:
                        if (typeof n == "number" && n === 85)
                          return 1;
                        break;
                      case 86:
                        if (typeof n == "number" && n === 86)
                          return 1;
                        break;
                      case 87:
                        if (typeof n == "number" && n === 87)
                          return 1;
                        break;
                      case 88:
                        if (typeof n == "number" && n === 88)
                          return 1;
                        break;
                      case 89:
                        if (typeof n == "number" && n === 89)
                          return 1;
                        break;
                      case 90:
                        if (typeof n == "number" && n === 90)
                          return 1;
                        break;
                      default:
                        if (typeof n == "number" && n === 91)
                          return 1;
                    }
                else if (31 <= e)
                  switch (e) {
                    case 31:
                      if (typeof n == "number" && n === 31)
                        return 1;
                      break;
                    case 32:
                      if (typeof n == "number" && n === 32)
                        return 1;
                      break;
                    case 33:
                      if (typeof n == "number" && n === 33)
                        return 1;
                      break;
                    case 34:
                      if (typeof n == "number" && n === 34)
                        return 1;
                      break;
                    case 35:
                      if (typeof n == "number" && n === 35)
                        return 1;
                      break;
                    case 36:
                      if (typeof n == "number" && n === 36)
                        return 1;
                      break;
                    case 37:
                      if (typeof n == "number" && n === 37)
                        return 1;
                      break;
                    case 38:
                      if (typeof n == "number" && n === 38)
                        return 1;
                      break;
                    case 39:
                      if (typeof n == "number" && n === 39)
                        return 1;
                      break;
                    case 40:
                      if (typeof n == "number" && n === 40)
                        return 1;
                      break;
                    case 41:
                      if (typeof n == "number" && n === 41)
                        return 1;
                      break;
                    case 42:
                      if (typeof n == "number" && n === 42)
                        return 1;
                      break;
                    case 43:
                      if (typeof n == "number" && n === 43)
                        return 1;
                      break;
                    case 44:
                      if (typeof n == "number" && n === 44)
                        return 1;
                      break;
                    case 45:
                      if (typeof n == "number" && n === 45)
                        return 1;
                      break;
                    case 46:
                      if (typeof n == "number" && n === 46)
                        return 1;
                      break;
                    case 47:
                      if (typeof n == "number" && n === 47)
                        return 1;
                      break;
                    case 48:
                      if (typeof n == "number" && n === 48)
                        return 1;
                      break;
                    case 49:
                      if (typeof n == "number" && n === 49)
                        return 1;
                      break;
                    case 50:
                      if (typeof n == "number" && n === 50)
                        return 1;
                      break;
                    case 51:
                      if (typeof n == "number" && n === 51)
                        return 1;
                      break;
                    case 52:
                      if (typeof n == "number" && n === 52)
                        return 1;
                      break;
                    case 53:
                      if (typeof n == "number" && n === 53)
                        return 1;
                      break;
                    case 54:
                      if (typeof n == "number" && n === 54)
                        return 1;
                      break;
                    case 55:
                      if (typeof n == "number" && n === 55)
                        return 1;
                      break;
                    case 56:
                      if (typeof n == "number" && n === 56)
                        return 1;
                      break;
                    case 57:
                      if (typeof n == "number" && n === 57)
                        return 1;
                      break;
                    case 58:
                      if (typeof n == "number" && n === 58)
                        return 1;
                      break;
                    case 59:
                      if (typeof n == "number" && n === 59)
                        return 1;
                      break;
                    default:
                      if (typeof n == "number" && n === 60)
                        return 1;
                  }
                else
                  switch (e) {
                    case 0:
                      if (typeof n == "number" && !n)
                        return 1;
                      break;
                    case 1:
                      if (typeof n == "number" && n === 1)
                        return 1;
                      break;
                    case 2:
                      if (typeof n == "number" && n === 2)
                        return 1;
                      break;
                    case 3:
                      if (typeof n == "number" && n === 3)
                        return 1;
                      break;
                    case 4:
                      if (typeof n == "number" && n === 4)
                        return 1;
                      break;
                    case 5:
                      if (typeof n == "number" && n === 5)
                        return 1;
                      break;
                    case 6:
                      if (typeof n == "number" && n === 6)
                        return 1;
                      break;
                    case 7:
                      if (typeof n == "number" && n === 7)
                        return 1;
                      break;
                    case 8:
                      if (typeof n == "number" && n === 8)
                        return 1;
                      break;
                    case 9:
                      if (typeof n == "number" && n === 9)
                        return 1;
                      break;
                    case 10:
                      if (typeof n == "number" && n === 10)
                        return 1;
                      break;
                    case 11:
                      if (typeof n == "number" && n === 11)
                        return 1;
                      break;
                    case 12:
                      if (typeof n == "number" && n === 12)
                        return 1;
                      break;
                    case 13:
                      if (typeof n == "number" && n === 13)
                        return 1;
                      break;
                    case 14:
                      if (typeof n == "number" && n === 14)
                        return 1;
                      break;
                    case 15:
                      if (typeof n == "number" && n === 15)
                        return 1;
                      break;
                    case 16:
                      if (typeof n == "number" && n === 16)
                        return 1;
                      break;
                    case 17:
                      if (typeof n == "number" && n === 17)
                        return 1;
                      break;
                    case 18:
                      if (typeof n == "number" && n === 18)
                        return 1;
                      break;
                    case 19:
                      if (typeof n == "number" && n === 19)
                        return 1;
                      break;
                    case 20:
                      if (typeof n == "number" && n === 20)
                        return 1;
                      break;
                    case 21:
                      if (typeof n == "number" && n === 21)
                        return 1;
                      break;
                    case 22:
                      if (typeof n == "number" && n === 22)
                        return 1;
                      break;
                    case 23:
                      if (typeof n == "number" && n === 23)
                        return 1;
                      break;
                    case 24:
                      if (typeof n == "number" && n === 24)
                        return 1;
                      break;
                    case 25:
                      if (typeof n == "number" && n === 25)
                        return 1;
                      break;
                    case 26:
                      if (typeof n == "number" && n === 26)
                        return 1;
                      break;
                    case 27:
                      if (typeof n == "number" && n === 27)
                        return 1;
                      break;
                    case 28:
                      if (typeof n == "number" && n === 28)
                        return 1;
                      break;
                    case 29:
                      if (typeof n == "number" && n === 29)
                        return 1;
                      break;
                    default:
                      if (typeof n == "number" && n === 30)
                        return 1;
                  }
              } else
                switch (t4[0]) {
                  case 0:
                    if (typeof n != "number" && n[0] === 0) {
                      var i = n[1], x = u(u(oL, t4[1]), i), c = x && Un(t4[2], n[2]);
                      return c;
                    }
                    break;
                  case 1:
                    if (typeof n != "number" && n[0] === 1) {
                      var s = n[1], p = u(u(cL, t4[1]), s), y = p && Un(t4[2], n[2]);
                      return y;
                    }
                    break;
                  case 2:
                    if (typeof n != "number" && n[0] === 2) {
                      var T = n[1], E = t4[1], h = Wv(E[1], T[1]), w = h && Un(E[2], T[2]), G = w && Un(E[3], T[3]), A = G && (E[4] === T[4] ? 1 : 0);
                      return A;
                    }
                    break;
                  case 3:
                    if (typeof n != "number" && n[0] === 3) {
                      var S = n[1], M = t4[1], K = Wv(M[1], S[1]);
                      if (K)
                        var V = S[2], f0 = u(u(Fr0, M[2]), V);
                      else
                        var f0 = K;
                      var m0 = f0 && (M[3] === S[3] ? 1 : 0);
                      return m0;
                    }
                    break;
                  case 4:
                    if (typeof n != "number" && n[0] === 4) {
                      var k0 = Wv(t4[1], n[1]), g0 = k0 && Un(t4[2], n[2]), e0 = g0 && Un(t4[3], n[3]);
                      return e0;
                    }
                    break;
                  case 5:
                    if (typeof n != "number" && n[0] === 5) {
                      var x0 = Wv(t4[1], n[1]), l = x0 && Un(t4[2], n[2]), c0 = l && Un(t4[3], n[3]);
                      return c0;
                    }
                    break;
                  case 6:
                    if (typeof n != "number" && n[0] === 6)
                      return Un(t4[1], n[1]);
                    break;
                  case 7:
                    if (typeof n != "number" && n[0] === 7) {
                      var t0 = Un(t4[1], n[1]);
                      return t0 && Wv(t4[2], n[2]);
                    }
                    break;
                  case 8:
                    if (typeof n != "number" && n[0] === 8) {
                      var a0 = Wv(t4[1], n[1]), w0 = a0 && Un(t4[2], n[2]), _0 = w0 && Un(t4[3], n[3]);
                      return _0;
                    }
                    break;
                  case 9:
                    if (typeof n != "number" && n[0] === 9) {
                      var E0 = n[1];
                      return u(u(gr0, t4[1]), E0);
                    }
                    break;
                  case 10:
                    if (typeof n != "number" && n[0] === 10) {
                      var X0 = n[1], b = u(u(oL, t4[1]), X0), G0 = b && (t4[2] == n[2] ? 1 : 0), X = G0 && Un(t4[3], n[3]);
                      return X;
                    }
                    break;
                  default:
                    if (typeof n != "number" && n[0] === 11) {
                      var s0 = n[1], dr = u(u(cL, t4[1]), s0), Ar = dr && (t4[2] == n[2] ? 1 : 0), ar = Ar && Un(t4[3], n[3]);
                      return ar;
                    }
                }
              return 0;
            }), N(gr0, function(t4, n) {
              if (t4) {
                if (n)
                  return 1;
              } else if (!n)
                return 1;
              return 0;
            }), N(oL, function(t4, n) {
              switch (t4) {
                case 0:
                  if (!n)
                    return 1;
                  break;
                case 1:
                  if (n === 1)
                    return 1;
                  break;
                case 2:
                  if (n === 2)
                    return 1;
                  break;
                case 3:
                  if (n === 3)
                    return 1;
                  break;
                default:
                  if (4 <= n)
                    return 1;
              }
              return 0;
            }), N(cL, function(t4, n) {
              switch (t4) {
                case 0:
                  if (!n)
                    return 1;
                  break;
                case 1:
                  if (n === 1)
                    return 1;
                  break;
                default:
                  if (2 <= n)
                    return 1;
              }
              return 0;
            }), N(Fr0, function(t4, n) {
              var e = Un(t4[1], n[1]), i = e && Un(t4[2], n[2]), x = i && Un(t4[3], n[3]);
              return x;
            });
            function Tr0(t4) {
              if (typeof t4 == "number") {
                var n = t4;
                if (61 <= n) {
                  if (92 <= n)
                    switch (n) {
                      case 92:
                        return qkr;
                      case 93:
                        return Ukr;
                      case 94:
                        return Hkr;
                      case 95:
                        return Xkr;
                      case 96:
                        return Ykr;
                      case 97:
                        return Vkr;
                      case 98:
                        return zkr;
                      case 99:
                        return Kkr;
                      case 100:
                        return Wkr;
                      case 101:
                        return Jkr;
                      case 102:
                        return $kr;
                      case 103:
                        return Zkr;
                      case 104:
                        return Qkr;
                      case 105:
                        return rwr;
                      case 106:
                        return ewr;
                      case 107:
                        return nwr;
                      case 108:
                        return twr;
                      case 109:
                        return uwr;
                      case 110:
                        return iwr;
                      case 111:
                        return fwr;
                      case 112:
                        return xwr;
                      case 113:
                        return awr;
                      case 114:
                        return owr;
                      case 115:
                        return cwr;
                      case 116:
                        return swr;
                      case 117:
                        return vwr;
                      case 118:
                        return lwr;
                      case 119:
                        return bwr;
                      case 120:
                        return pwr;
                      default:
                        return mwr;
                    }
                  switch (n) {
                    case 61:
                      return ckr;
                    case 62:
                      return skr;
                    case 63:
                      return vkr;
                    case 64:
                      return lkr;
                    case 65:
                      return bkr;
                    case 66:
                      return pkr;
                    case 67:
                      return mkr;
                    case 68:
                      return _kr;
                    case 69:
                      return ykr;
                    case 70:
                      return dkr;
                    case 71:
                      return hkr;
                    case 72:
                      return kkr;
                    case 73:
                      return wkr;
                    case 74:
                      return Ekr;
                    case 75:
                      return Skr;
                    case 76:
                      return gkr;
                    case 77:
                      return Fkr;
                    case 78:
                      return Tkr;
                    case 79:
                      return Okr;
                    case 80:
                      return Ikr;
                    case 81:
                      return Akr;
                    case 82:
                      return Nkr;
                    case 83:
                      return Ckr;
                    case 84:
                      return Pkr;
                    case 85:
                      return Dkr;
                    case 86:
                      return Lkr;
                    case 87:
                      return Rkr;
                    case 88:
                      return jkr;
                    case 89:
                      return Gkr;
                    case 90:
                      return Mkr;
                    default:
                      return Bkr;
                  }
                }
                if (31 <= n)
                  switch (n) {
                    case 31:
                      return Dhr;
                    case 32:
                      return Lhr;
                    case 33:
                      return Rhr;
                    case 34:
                      return jhr;
                    case 35:
                      return Ghr;
                    case 36:
                      return Mhr;
                    case 37:
                      return Bhr;
                    case 38:
                      return qhr;
                    case 39:
                      return Uhr;
                    case 40:
                      return Hhr;
                    case 41:
                      return Xhr;
                    case 42:
                      return Yhr;
                    case 43:
                      return Vhr;
                    case 44:
                      return zhr;
                    case 45:
                      return Khr;
                    case 46:
                      return Whr;
                    case 47:
                      return Jhr;
                    case 48:
                      return $hr;
                    case 49:
                      return Zhr;
                    case 50:
                      return Qhr;
                    case 51:
                      return rkr;
                    case 52:
                      return ekr;
                    case 53:
                      return nkr;
                    case 54:
                      return tkr;
                    case 55:
                      return ukr;
                    case 56:
                      return ikr;
                    case 57:
                      return fkr;
                    case 58:
                      return xkr;
                    case 59:
                      return akr;
                    default:
                      return okr;
                  }
                switch (n) {
                  case 0:
                    return thr;
                  case 1:
                    return uhr;
                  case 2:
                    return ihr;
                  case 3:
                    return fhr;
                  case 4:
                    return xhr;
                  case 5:
                    return ahr;
                  case 6:
                    return ohr;
                  case 7:
                    return chr;
                  case 8:
                    return shr;
                  case 9:
                    return vhr;
                  case 10:
                    return lhr;
                  case 11:
                    return bhr;
                  case 12:
                    return phr;
                  case 13:
                    return mhr;
                  case 14:
                    return _hr;
                  case 15:
                    return yhr;
                  case 16:
                    return dhr;
                  case 17:
                    return hhr;
                  case 18:
                    return khr;
                  case 19:
                    return whr;
                  case 20:
                    return Ehr;
                  case 21:
                    return Shr;
                  case 22:
                    return ghr;
                  case 23:
                    return Fhr;
                  case 24:
                    return Thr;
                  case 25:
                    return Ohr;
                  case 26:
                    return Ihr;
                  case 27:
                    return Ahr;
                  case 28:
                    return Nhr;
                  case 29:
                    return Chr;
                  default:
                    return Phr;
                }
              } else
                switch (t4[0]) {
                  case 0:
                    return _wr;
                  case 1:
                    return ywr;
                  case 2:
                    return dwr;
                  case 3:
                    return hwr;
                  case 4:
                    return kwr;
                  case 5:
                    return wwr;
                  case 6:
                    return Ewr;
                  case 7:
                    return Swr;
                  case 8:
                    return gwr;
                  case 9:
                    return Fwr;
                  case 10:
                    return Twr;
                  default:
                    return Owr;
                }
            }
            function sL(t4) {
              if (typeof t4 == "number") {
                var n = t4;
                if (61 <= n) {
                  if (92 <= n)
                    switch (n) {
                      case 92:
                        return Edr;
                      case 93:
                        return Sdr;
                      case 94:
                        return gdr;
                      case 95:
                        return Fdr;
                      case 96:
                        return Tdr;
                      case 97:
                        return Odr;
                      case 98:
                        return Idr;
                      case 99:
                        return Adr;
                      case 100:
                        return Ndr;
                      case 101:
                        return Cdr;
                      case 102:
                        return Pdr;
                      case 103:
                        return Ddr;
                      case 104:
                        return Ldr;
                      case 105:
                        return Rdr;
                      case 106:
                        return jdr;
                      case 107:
                        return Gdr;
                      case 108:
                        return Mdr;
                      case 109:
                        return Bdr;
                      case 110:
                        return qdr;
                      case 111:
                        return Udr;
                      case 112:
                        return Hdr;
                      case 113:
                        return Xdr;
                      case 114:
                        return Ydr;
                      case 115:
                        return Vdr;
                      case 116:
                        return zdr;
                      case 117:
                        return Kdr;
                      case 118:
                        return Wdr;
                      case 119:
                        return Jdr;
                      case 120:
                        return $dr;
                      default:
                        return Zdr;
                    }
                  switch (n) {
                    case 61:
                      return Vyr;
                    case 62:
                      return zyr;
                    case 63:
                      return Kyr;
                    case 64:
                      return Wyr;
                    case 65:
                      return Jyr;
                    case 66:
                      return $yr;
                    case 67:
                      return Zyr;
                    case 68:
                      return Qyr;
                    case 69:
                      return rdr;
                    case 70:
                      return edr;
                    case 71:
                      return ndr;
                    case 72:
                      return tdr;
                    case 73:
                      return udr;
                    case 74:
                      return idr;
                    case 75:
                      return fdr;
                    case 76:
                      return xdr;
                    case 77:
                      return adr;
                    case 78:
                      return odr;
                    case 79:
                      return cdr;
                    case 80:
                      return sdr;
                    case 81:
                      return vdr;
                    case 82:
                      return ldr;
                    case 83:
                      return bdr;
                    case 84:
                      return pdr;
                    case 85:
                      return mdr;
                    case 86:
                      return _dr;
                    case 87:
                      return ydr;
                    case 88:
                      return ddr;
                    case 89:
                      return hdr;
                    case 90:
                      return kdr;
                    default:
                      return wdr;
                  }
                }
                if (31 <= n)
                  switch (n) {
                    case 31:
                      return myr;
                    case 32:
                      return _yr;
                    case 33:
                      return yyr;
                    case 34:
                      return dyr;
                    case 35:
                      return hyr;
                    case 36:
                      return kyr;
                    case 37:
                      return wyr;
                    case 38:
                      return Eyr;
                    case 39:
                      return Syr;
                    case 40:
                      return gyr;
                    case 41:
                      return Fyr;
                    case 42:
                      return Tyr;
                    case 43:
                      return Oyr;
                    case 44:
                      return Iyr;
                    case 45:
                      return Ayr;
                    case 46:
                      return Nyr;
                    case 47:
                      return Cyr;
                    case 48:
                      return Pyr;
                    case 49:
                      return Dyr;
                    case 50:
                      return Lyr;
                    case 51:
                      return Ryr;
                    case 52:
                      return jyr;
                    case 53:
                      return Gyr;
                    case 54:
                      return Myr;
                    case 55:
                      return Byr;
                    case 56:
                      return qyr;
                    case 57:
                      return Uyr;
                    case 58:
                      return Hyr;
                    case 59:
                      return Xyr;
                    default:
                      return Yyr;
                  }
                switch (n) {
                  case 0:
                    return M_r;
                  case 1:
                    return B_r;
                  case 2:
                    return q_r;
                  case 3:
                    return U_r;
                  case 4:
                    return H_r;
                  case 5:
                    return X_r;
                  case 6:
                    return Y_r;
                  case 7:
                    return V_r;
                  case 8:
                    return z_r;
                  case 9:
                    return K_r;
                  case 10:
                    return W_r;
                  case 11:
                    return J_r;
                  case 12:
                    return $_r;
                  case 13:
                    return Z_r;
                  case 14:
                    return Q_r;
                  case 15:
                    return ryr;
                  case 16:
                    return eyr;
                  case 17:
                    return nyr;
                  case 18:
                    return tyr;
                  case 19:
                    return uyr;
                  case 20:
                    return iyr;
                  case 21:
                    return fyr;
                  case 22:
                    return xyr;
                  case 23:
                    return ayr;
                  case 24:
                    return oyr;
                  case 25:
                    return cyr;
                  case 26:
                    return syr;
                  case 27:
                    return vyr;
                  case 28:
                    return lyr;
                  case 29:
                    return byr;
                  default:
                    return pyr;
                }
              } else
                switch (t4[0]) {
                  case 2:
                    return t4[1][3];
                  case 3:
                    return t4[1][2][3];
                  case 5:
                    var e = Te(Qdr, t4[3]);
                    return Te(rhr, Te(t4[2], e));
                  case 9:
                    return t4[1] ? ehr : nhr;
                  case 0:
                  case 1:
                    return t4[2];
                  case 6:
                  case 7:
                    return t4[1];
                  default:
                    return t4[3];
                }
            }
            function Ml(t4) {
              return u(et(G_r), t4);
            }
            function vL(t4, n) {
              var e = t4 && t4[1], i = 0;
              if (typeof n == "number")
                if (Ln === n)
                  var x = w_r, c = E_r;
                else
                  i = 1;
              else
                switch (n[0]) {
                  case 3:
                    var x = S_r, c = g_r;
                    break;
                  case 5:
                    var x = F_r, c = T_r;
                    break;
                  case 6:
                  case 9:
                    i = 1;
                    break;
                  case 0:
                  case 10:
                    var x = I_r, c = A_r;
                    break;
                  case 1:
                  case 11:
                    var x = N_r, c = C_r;
                    break;
                  case 2:
                  case 8:
                    var x = P_r, c = D_r;
                    break;
                  default:
                    var x = L_r, c = R_r;
                }
              if (i)
                var x = O_r, c = Ml(sL(n));
              return e ? Te(x, Te(j_r, c)) : c;
            }
            function lL(t4) {
              return 45 < t4 ? 46 < t4 ? -1 : 0 : -1;
            }
            function Mc(t4) {
              if (8 < t4) {
                if (Ev < t4) {
                  if (tf < t4) {
                    if (La < t4)
                      return -1;
                    if (ea < t4) {
                      var n = t4 <= qo ? 1 : 0, e = n && -1;
                      return e;
                    }
                    if (aa < t4) {
                      if (oc < t4) {
                        if (cx < t4) {
                          var i = t4 <= Sa ? 1 : 0, x = i && -1;
                          return x;
                        }
                        return 0;
                      }
                      return -1;
                    }
                    if (Pa < t4) {
                      var c = t4 <= ya ? 1 : 0, s = c && -1;
                      return s;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(uLr, t4 - 9 | 0) - 1 | 0;
              }
              return -1;
            }
            function pn(t4) {
              return 47 < t4 ? 57 < t4 ? -1 : 0 : -1;
            }
            function Pn(t4) {
              return 47 < t4 ? ji < t4 ? -1 : Vr(pRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function wi(t4) {
              return 47 < t4 ? Yt < t4 ? -1 : Vr(fRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function Zv(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(OLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Qm(t4) {
              return 87 < t4 ? fc < t4 ? -1 : Vr(uN, t4 - 88 | 0) - 1 | 0 : -1;
            }
            function r9(t4) {
              return 45 < t4 ? 57 < t4 ? -1 : Vr(mRr, t4 + l1 | 0) - 1 | 0 : -1;
            }
            function Or0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(ILr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function N1(t4) {
              return 47 < t4 ? br < t4 ? -1 : Vr(tRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function Qv(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(ALr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function C1(t4) {
              if (8 < t4) {
                if (Ev < t4) {
                  if (tf < t4) {
                    if (La < t4)
                      return -1;
                    if (ea < t4) {
                      var n = t4 <= qo ? 1 : 0, e = n && -1;
                      return e;
                    }
                    if (aa < t4) {
                      if (oc < t4) {
                        if (cx < t4) {
                          var i = t4 <= Sa ? 1 : 0, x = i && -1;
                          return x;
                        }
                        return 0;
                      }
                      return -1;
                    }
                    if (Pa < t4) {
                      var c = t4 <= ya ? 1 : 0, s = c && -1;
                      return s;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(iLr, t4 - 9 | 0) - 1 | 0;
              }
              return -1;
            }
            function e9(t4) {
              return 45 < t4 ? R7 < t4 ? -1 : Vr(yLr, t4 + l1 | 0) - 1 | 0 : -1;
            }
            function Ir0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(NLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function n9(t4) {
              return 47 < t4 ? 95 < t4 ? -1 : Vr(IRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function t9(t4) {
              return 47 < t4 ? Yt < t4 ? -1 : Vr(NRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function u9(t4) {
              return 47 < t4 ? Yt < t4 ? -1 : Vr(xRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function i9(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(CLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function f9(t4) {
              if (8 < t4) {
                if (Ev < t4) {
                  if (tf < t4) {
                    if (La < t4)
                      return -1;
                    if (ea < t4) {
                      var n = t4 <= qo ? 1 : 0, e = n && -1;
                      return e;
                    }
                    if (aa < t4) {
                      if (oc < t4) {
                        if (cx < t4) {
                          var i = t4 <= Sa ? 1 : 0, x = i && -1;
                          return x;
                        }
                        return 0;
                      }
                      return -1;
                    }
                    if (Pa < t4) {
                      var c = t4 <= ya ? 1 : 0, s = c && -1;
                      return s;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(fLr, t4 - 9 | 0) - 1 | 0;
              }
              return -1;
            }
            function x9(t4) {
              return 44 < t4 ? 57 < t4 ? -1 : Vr(vLr, t4 + mv | 0) - 1 | 0 : -1;
            }
            function Bc(t4) {
              return 47 < t4 ? 49 < t4 ? -1 : 0 : -1;
            }
            function a9(t4) {
              return 47 < t4 ? 95 < t4 ? -1 : Vr(lLr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function P1(t4) {
              return 47 < t4 ? 57 < t4 ? -1 : Vr(ARr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function o9(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(PLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Ar0(t4) {
              return u1 < t4 ? Av < t4 ? -1 : 0 : -1;
            }
            function Hi(t4) {
              return 60 < t4 ? 61 < t4 ? -1 : 0 : -1;
            }
            function Nr0(t4) {
              if (-1 < t4) {
                if (Nn < t4) {
                  if (us < t4) {
                    if (Ju < t4) {
                      var n = t4 <= Uu ? 1 : 0, e = n && -1;
                      return e;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(SLr, t4) - 1 | 0;
              }
              return -1;
            }
            function r2(t4) {
              return 47 < t4 ? Yt < t4 ? -1 : Vr(aRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function c9(t4) {
              return 47 < t4 ? Yt < t4 ? -1 : Vr(bRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function bL(t4) {
              return 60 < t4 ? 62 < t4 ? -1 : Vr(tN, t4 + TS | 0) - 1 | 0 : -1;
            }
            function s9(t4) {
              return 65 < t4 ? 98 < t4 ? -1 : Vr(uN, t4 - 66 | 0) - 1 | 0 : -1;
            }
            function qt(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(DLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function v9(t4) {
              return Av < t4 ? x1 < t4 ? -1 : 0 : -1;
            }
            function Vu(t4) {
              return 47 < t4 ? 55 < t4 ? -1 : 0 : -1;
            }
            function pL(t4) {
              return Fv < t4 ? Yt < t4 ? -1 : 0 : -1;
            }
            function l9(t4) {
              return Yt < t4 ? vf < t4 ? -1 : 0 : -1;
            }
            function Bl(t4) {
              return 98 < t4 ? 99 < t4 ? -1 : 0 : -1;
            }
            function Ls(t4) {
              return 47 < t4 ? 48 < t4 ? -1 : 0 : -1;
            }
            function ql(t4) {
              if (8 < t4) {
                if (Ev < t4) {
                  if (tf < t4) {
                    if (La < t4)
                      return -1;
                    if (ea < t4) {
                      var n = t4 <= qo ? 1 : 0, e = n && -1;
                      return e;
                    }
                    if (aa < t4) {
                      if (oc < t4) {
                        if (cx < t4) {
                          var i = t4 <= Sa ? 1 : 0, x = i && -1;
                          return x;
                        }
                        return 0;
                      }
                      return -1;
                    }
                    if (Pa < t4) {
                      var c = t4 <= ya ? 1 : 0, s = c && -1;
                      return s;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(xLr, t4 - 9 | 0) - 1 | 0;
              }
              return -1;
            }
            function b9(t4) {
              return 45 < t4 ? R7 < t4 ? -1 : Vr(bLr, t4 + l1 | 0) - 1 | 0 : -1;
            }
            function p9(t4) {
              return 78 < t4 ? vf < t4 ? -1 : Vr(uN, t4 - 79 | 0) - 1 | 0 : -1;
            }
            function Cr0(t4) {
              return 41 < t4 ? 42 < t4 ? -1 : 0 : -1;
            }
            function Pr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(LLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function m9(t4) {
              return 47 < t4 ? R7 < t4 ? -1 : Vr(uRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function Rs(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(RLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Dr0(t4) {
              return 41 < t4 ? 61 < t4 ? -1 : Vr(vRr, t4 + hy | 0) - 1 | 0 : -1;
            }
            function D1(t4) {
              return 44 < t4 ? 48 < t4 ? -1 : Vr(QLr, t4 + mv | 0) - 1 | 0 : -1;
            }
            function Lr0(t4) {
              return 44 < t4 ? 45 < t4 ? -1 : 0 : -1;
            }
            function Rr0(t4) {
              return L7 < t4 ? j7 < t4 ? -1 : 0 : -1;
            }
            function _9(t4) {
              return Qc < t4 ? fs2 < t4 ? -1 : 0 : -1;
            }
            function jr0(t4) {
              return 99 < t4 ? ti < t4 ? -1 : 0 : -1;
            }
            function y9(t4) {
              return 47 < t4 ? ji < t4 ? -1 : Vr(_Rr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function d9(t4) {
              return Ln < t4 ? u1 < t4 ? -1 : 0 : -1;
            }
            function L1(t4) {
              return 45 < t4 ? 57 < t4 ? -1 : Vr(hRr, t4 + l1 | 0) - 1 | 0 : -1;
            }
            function Gr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(jLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function R1(t4) {
              return 47 < t4 ? us < t4 ? -1 : Vr(CRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function mL(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(GLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function xi(t4) {
              return 9 < t4 ? 10 < t4 ? -1 : 0 : -1;
            }
            function Mr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(MLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Br0(t4) {
              return 96 < t4 ? 97 < t4 ? -1 : 0 : -1;
            }
            function qc(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(BLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function h9(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(qLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function js(t4) {
              return 47 < t4 ? 95 < t4 ? -1 : Vr(oRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function qr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(ULr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Ul(t4) {
              return ti < t4 ? R7 < t4 ? -1 : 0 : -1;
            }
            function Ur0(t4) {
              if (8 < t4) {
                if (Ev < t4) {
                  if (tf < t4) {
                    if (La < t4)
                      return -1;
                    if (ea < t4) {
                      var n = t4 <= qo ? 1 : 0, e = n && -1;
                      return e;
                    }
                    if (aa < t4) {
                      if (oc < t4) {
                        if (cx < t4) {
                          var i = t4 <= Sa ? 1 : 0, x = i && -1;
                          return x;
                        }
                        return 0;
                      }
                      return -1;
                    }
                    if (Pa < t4) {
                      var c = t4 <= ya ? 1 : 0, s = c && -1;
                      return s;
                    }
                    return 0;
                  }
                  return -1;
                }
                return Vr(oLr, t4 - 9 | 0) - 1 | 0;
              }
              return -1;
            }
            function Hr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(kRr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function k9(t4) {
              return 41 < t4 ? 47 < t4 ? -1 : Vr(JLr, t4 + hy | 0) - 1 | 0 : -1;
            }
            function w9(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(HLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Xr0(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(XLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Yr0(t4) {
              return z2 < t4 ? Sv < t4 ? -1 : 0 : -1;
            }
            function E9(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(YLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function i7(t4) {
              return 47 < t4 ? R7 < t4 ? -1 : Vr(iRr, t4 + Wt | 0) - 1 | 0 : -1;
            }
            function S9(t4) {
              return 42 < t4 ? 57 < t4 ? -1 : Vr(wLr, t4 + cy | 0) - 1 | 0 : -1;
            }
            function Uc(t4) {
              return 45 < t4 ? 95 < t4 ? -1 : Vr(TLr, t4 + l1 | 0) - 1 | 0 : -1;
            }
            function Gs(t4) {
              return x1 < t4 ? A2 < t4 ? -1 : 0 : -1;
            }
            function Vr0(t4) {
              return 46 < t4 ? 47 < t4 ? -1 : 0 : -1;
            }
            function zr0(t4) {
              return 57 < t4 ? 58 < t4 ? -1 : 0 : -1;
            }
            function hn(t4) {
              return 35 < t4 ? Nn < t4 ? -1 : Vr(VLr, t4 + cu | 0) - 1 | 0 : -1;
            }
            function Kr0(t4) {
              for (; ; ) {
                Tn(t4);
                var n = j(t4), e = Nn < n ? 1 : Vr(gRr, n + 1 | 0) - 1 | 0;
                if (3 < e >>> 0)
                  var i = q(t4);
                else
                  switch (e) {
                    case 0:
                      var i = 1;
                      break;
                    case 1:
                      var i = 2;
                      break;
                    case 2:
                      var i = 0;
                      break;
                    default:
                      if (B0(t4, 2), Gs(j(t4)) === 0) {
                        var x = R1(j(t4));
                        if (x === 0)
                          if (Pn(j(t4)) === 0 && Pn(j(t4)) === 0)
                            var c = Pn(j(t4)) !== 0 ? 1 : 0, i = c && q(t4);
                          else
                            var i = q(t4);
                        else if (x === 1 && Pn(j(t4)) === 0)
                          for (; ; ) {
                            var s = N1(j(t4));
                            if (s !== 0) {
                              var p = s !== 1 ? 1 : 0, i = p && q(t4);
                              break;
                            }
                          }
                        else
                          var i = q(t4);
                      } else
                        var i = q(t4);
                  }
                if (2 < i >>> 0)
                  throw [0, Fn, Iwr];
                switch (i) {
                  case 0:
                    continue;
                  case 1:
                    return 1;
                  default:
                    if (iL(dr0(t4)))
                      continue;
                    return kr0(t4, 1), 0;
                }
              }
            }
            function g9(t4, n) {
              var e = n - t4[3][2] | 0;
              return [0, Sr0(t4), e];
            }
            function Hl(t4, n, e) {
              var i = g9(t4, e), x = g9(t4, n);
              return [0, t4[1], x, i];
            }
            function Lu(t4, n) {
              return g9(t4, n[6]);
            }
            function d7(t4, n) {
              return g9(t4, n[3]);
            }
            function nt(t4, n) {
              return Hl(t4, n[6], n[3]);
            }
            function Wr0(t4, n) {
              var e = 0;
              if (typeof n == "number")
                e = 1;
              else
                switch (n[0]) {
                  case 2:
                    var i = n[1][1];
                    break;
                  case 3:
                    return n[1][1];
                  case 4:
                    var i = n[1];
                    break;
                  case 7:
                    var i = n[2];
                    break;
                  case 5:
                  case 8:
                    return n[1];
                  default:
                    e = 1;
                }
              return e ? nt(t4, t4[2]) : i;
            }
            function Ru(t4, n, e) {
              return [0, t4[1], t4[2], t4[3], t4[4], t4[5], [0, [0, n, e], t4[6]], t4[7]];
            }
            function Jr0(t4, n, e) {
              return Ru(t4, n, [10, Ml(e)]);
            }
            function _L(t4, n, e, i) {
              return Ru(t4, n, [12, e, i]);
            }
            function Ei(t4, n) {
              return Ru(t4, n, nLr);
            }
            function h7(t4, n) {
              var e = n[3], i = [0, Sr0(t4) + 1 | 0, e];
              return [0, t4[1], t4[2], i, t4[4], t4[5], t4[6], t4[7]];
            }
            function $r0(t4) {
              var n = tn(t4);
              return n !== 0 && Yt === At(t4, n - 1 | 0) ? m7(t4, 0, n - 1 | 0) : t4;
            }
            function Si(t4, n, e, i, x) {
              var c = [0, t4[1], n, e], s = Bt(i), p = x ? 0 : 1;
              return [0, c, [0, p, s, t4[7][3][1] < c[2][1] ? 1 : 0]];
            }
            function Hc(t4, n) {
              if (At(n, 0) === 45)
                var e = m7(n, 1, tn(n) - 1 | 0), i = 1;
              else
                var e = n, i = 0;
              switch (t4) {
                case 1:
                  try {
                    var x = jv(Rv(Te(ZDr, e))), c = x;
                  } catch (T) {
                    if (T = gt(T), T[1] !== q7)
                      throw T;
                    var c = ke(Te(QDr, e));
                  }
                  break;
                case 0:
                case 3:
                  try {
                    var s = jv(Rv(e)), c = s;
                  } catch (T) {
                    if (T = gt(T), T[1] !== q7)
                      throw T;
                    var c = ke(Te(rLr, e));
                  }
                  break;
                default:
                  try {
                    var p = al(e), c = p;
                  } catch (T) {
                    if (T = gt(T), T[1] !== q7)
                      throw T;
                    var c = ke(Te(eLr, e));
                  }
              }
              var y = i ? -c : c;
              return [10, t4, y, n];
            }
            function Xi(t4, n) {
              if (At(n, 0) === 45)
                var e = m7(n, 1, tn(n) - 1 | 0), i = 1;
              else
                var e = n, i = 0;
              if (2 <= t4) {
                var x = $r0(e);
                try {
                  var c = al(x), s = c;
                } catch (w) {
                  if (w = gt(w), w[1] !== q7)
                    throw w;
                  var s = ke(Te(JDr, x));
                }
                var p = s;
              } else {
                var y = $r0(e);
                try {
                  var T = jv(Rv(y)), E = T;
                } catch (G) {
                  if (G = gt(G), G[1] !== q7)
                    throw G;
                  var E = ke(Te($Dr, y));
                }
                var p = E;
              }
              var h = i ? -p : p;
              return [11, t4, h, n];
            }
            function Zr0(t4, n, e) {
              return iL(e) ? t4 : Ru(t4, n, 37);
            }
            function Qr0(t4, n, e, i, x) {
              var c = Hl(t4, n + e[6] | 0, n + e[3] | 0);
              return [0, c, jl(e, i, ($m(e) - i | 0) - x | 0)];
            }
            function re0(t4, n) {
              for (var e = t4[2][6], i = [0, n, n.length - 1, yr0, _r0, mr0, pr0, br0, lr0, vr0, sr0, cr0, or0], x = Qn(n.length - 1), c = t4; ; ) {
                Tn(i);
                var s = j(i), p = 92 < s ? 1 : Vr(eRr, s + 1 | 0) - 1 | 0;
                if (2 < p >>> 0)
                  var y = q(i);
                else
                  switch (p) {
                    case 0:
                      var y = 2;
                      break;
                    case 1:
                      for (; ; ) {
                        B0(i, 3);
                        var T = j(i);
                        if (-1 < T)
                          if (91 < T)
                            var E = T <= 92 ? 1 : 0, h = E && -1;
                          else
                            var h = 0;
                        else
                          var h = -1;
                        if (h !== 0) {
                          var y = q(i);
                          break;
                        }
                      }
                      break;
                    default:
                      if (B0(i, 3), Gs(j(i)) === 0) {
                        var w = R1(j(i));
                        if (w === 0)
                          if (Pn(j(i)) === 0 && Pn(j(i)) === 0)
                            var G = Pn(j(i)) !== 0 ? 1 : 0, y = G && q(i);
                          else
                            var y = q(i);
                        else if (w === 1 && Pn(j(i)) === 0)
                          for (; ; ) {
                            var A = N1(j(i));
                            if (A !== 0) {
                              var y = A === 1 ? 1 : q(i);
                              break;
                            }
                          }
                        else
                          var y = q(i);
                      } else
                        var y = q(i);
                  }
                if (3 < y >>> 0)
                  return ke(zDr);
                switch (y) {
                  case 0:
                    var S = Qr0(c, e, i, 2, 0), M = S[1], K = qi(Te(KDr, S[2])), V = 0 <= K ? 1 : 0, f0 = V && (K <= 55295 ? 1 : 0);
                    if (f0)
                      var k0 = f0;
                    else
                      var m0 = 57344 <= K ? 1 : 0, k0 = m0 && (K <= mI ? 1 : 0);
                    var g0 = k0 ? Zr0(c, M, K) : Ru(c, M, 37);
                    g1(x, K);
                    var c = g0;
                    continue;
                  case 1:
                    var e0 = Qr0(c, e, i, 3, 1), x0 = qi(Te(WDr, e0[2])), l = Zr0(c, e0[1], x0);
                    g1(x, x0);
                    var c = l;
                    continue;
                  case 2:
                    return [0, c, Bt(x)];
                  default:
                    Gl(i, x);
                    continue;
                }
              }
            }
            function jt(t4, n, e) {
              var i = Ei(t4, nt(t4, n));
              return $v(n), a(e, i, n);
            }
            function j1(t4, n, e) {
              for (var i = t4; ; ) {
                Tn(e);
                var x = j(e);
                if (-1 < x)
                  if (42 < x)
                    var c = x <= Uu ? 1 : 0, s = c && (Ju < x ? 1 : 0);
                  else
                    var s = Vr(cLr, x) - 1 | 0;
                else
                  var s = -1;
                if (3 < s >>> 0)
                  var p = q(e);
                else
                  switch (s) {
                    case 0:
                      for (; ; ) {
                        B0(e, 3);
                        var y = j(e);
                        if (-1 < y)
                          if (41 < y)
                            if (42 < y)
                              if (Ju < y)
                                var T = y <= Uu ? 1 : 0, E = T && -1;
                              else
                                var E = 0;
                            else
                              var E = -1;
                          else
                            var E = Vr(dRr, y) - 1 | 0;
                        else
                          var E = -1;
                        if (E !== 0) {
                          var p = q(e);
                          break;
                        }
                      }
                      break;
                    case 1:
                      var p = 0;
                      break;
                    case 2:
                      B0(e, 0);
                      var h = xi(j(e)) !== 0 ? 1 : 0, p = h && q(e);
                      break;
                    default:
                      B0(e, 3);
                      var w = j(e), G = 44 < w ? 47 < w ? -1 : Vr(TRr, w + mv | 0) - 1 | 0 : -1, p = G === 0 ? Vr0(j(e)) === 0 ? 2 : q(e) : G === 1 ? 1 : q(e);
                  }
                if (3 < p >>> 0) {
                  var A = Ei(i, nt(i, e));
                  return [0, A, d7(A, e)];
                }
                switch (p) {
                  case 0:
                    var S = h7(i, e);
                    Gl(e, n);
                    var i = S;
                    continue;
                  case 1:
                    var M = i[4] ? _L(i, nt(i, e), Cwr, Nwr) : i;
                    return [0, M, d7(M, e)];
                  case 2:
                    if (i[4])
                      return [0, i, d7(i, e)];
                    dn(n, Pwr);
                    continue;
                  default:
                    Gl(e, n);
                    continue;
                }
              }
            }
            function e2(t4, n, e) {
              for (; ; ) {
                Tn(e);
                var i = j(e), x = 13 < i ? Uu < i ? 1 : Ju < i ? 2 : 1 : Vr(WLr, i + 1 | 0) - 1 | 0;
                if (3 < x >>> 0)
                  var c = q(e);
                else
                  switch (x) {
                    case 0:
                      var c = 0;
                      break;
                    case 1:
                      for (; ; ) {
                        B0(e, 2);
                        var s = j(e);
                        if (-1 < s)
                          if (12 < s)
                            if (13 < s)
                              if (Ju < s)
                                var p = s <= Uu ? 1 : 0, y = p && -1;
                              else
                                var y = 0;
                            else
                              var y = -1;
                          else
                            var y = Vr(tLr, s) - 1 | 0;
                        else
                          var y = -1;
                        if (y !== 0) {
                          var c = q(e);
                          break;
                        }
                      }
                      break;
                    case 2:
                      var c = 1;
                      break;
                    default:
                      B0(e, 1);
                      var c = xi(j(e)) === 0 ? 1 : q(e);
                  }
                if (2 < c >>> 0)
                  return ke(Dwr);
                switch (c) {
                  case 0:
                    return [0, t4, d7(t4, e)];
                  case 1:
                    var T = d7(t4, e), E = h7(t4, e), h = $m(e);
                    return [0, E, [0, T[1], T[2] - h | 0]];
                  default:
                    Gl(e, n);
                    continue;
                }
              }
            }
            function ee0(t4, n) {
              function e(k0) {
                return B0(k0, 3), Vu(j(k0)) === 0 ? 2 : q(k0);
              }
              Tn(n);
              var i = j(n), x = fc < i ? Uu < i ? 1 : Ju < i ? 2 : 1 : Vr(hLr, i + 1 | 0) - 1 | 0;
              if (14 < x >>> 0)
                var c = q(n);
              else
                switch (x) {
                  case 1:
                    var c = 16;
                    break;
                  case 2:
                    var c = 15;
                    break;
                  case 3:
                    B0(n, 15);
                    var c = xi(j(n)) === 0 ? 15 : q(n);
                    break;
                  case 4:
                    B0(n, 4);
                    var c = Vu(j(n)) === 0 ? e(n) : q(n);
                    break;
                  case 5:
                    B0(n, 11);
                    var c = Vu(j(n)) === 0 ? e(n) : q(n);
                    break;
                  case 7:
                    var c = 5;
                    break;
                  case 8:
                    var c = 6;
                    break;
                  case 9:
                    var c = 7;
                    break;
                  case 10:
                    var c = 8;
                    break;
                  case 11:
                    var c = 9;
                    break;
                  case 12:
                    B0(n, 14);
                    var s = R1(j(n));
                    if (s === 0)
                      var c = Pn(j(n)) === 0 && Pn(j(n)) === 0 && Pn(j(n)) === 0 ? 12 : q(n);
                    else if (s === 1 && Pn(j(n)) === 0)
                      for (; ; ) {
                        var p = N1(j(n));
                        if (p !== 0) {
                          var c = p === 1 ? 13 : q(n);
                          break;
                        }
                      }
                    else
                      var c = q(n);
                    break;
                  case 13:
                    var c = 10;
                    break;
                  case 14:
                    B0(n, 14);
                    var c = Pn(j(n)) === 0 && Pn(j(n)) === 0 ? 1 : q(n);
                    break;
                  default:
                    var c = 0;
                }
              if (16 < c >>> 0)
                return ke(PDr);
              switch (c) {
                case 1:
                  var y = Se(n);
                  return [0, t4, y, [0, qi(Te(DDr, y))], 0];
                case 2:
                  var T = Se(n), E = qi(Te(LDr, T));
                  return C4 <= E ? [0, t4, T, [0, E >>> 3 | 0, 48 + (E & 7) | 0], 1] : [0, t4, T, [0, E], 1];
                case 3:
                  var h = Se(n);
                  return [0, t4, h, [0, qi(Te(RDr, h))], 1];
                case 4:
                  return [0, t4, jDr, [0, 0], 0];
                case 5:
                  return [0, t4, GDr, [0, 8], 0];
                case 6:
                  return [0, t4, MDr, [0, 12], 0];
                case 7:
                  return [0, t4, BDr, [0, 10], 0];
                case 8:
                  return [0, t4, qDr, [0, 13], 0];
                case 9:
                  return [0, t4, UDr, [0, 9], 0];
                case 10:
                  return [0, t4, HDr, [0, 11], 0];
                case 11:
                  var w = Se(n);
                  return [0, t4, w, [0, qi(Te(XDr, w))], 1];
                case 12:
                  var G = Se(n);
                  return [0, t4, G, [0, qi(Te(YDr, m7(G, 1, tn(G) - 1 | 0)))], 0];
                case 13:
                  var A = Se(n), S = qi(Te(VDr, m7(A, 2, tn(A) - 3 | 0))), M = mI < S ? Ei(t4, nt(t4, n)) : t4;
                  return [0, M, A, [0, S], 0];
                case 14:
                  var K = Se(n), V = Ll(n);
                  return [0, Ei(t4, nt(t4, n)), K, V, 0];
                case 15:
                  var f0 = Se(n);
                  return [0, h7(t4, n), f0, [0], 0];
                default:
                  var m0 = Se(n);
                  return [0, t4, m0, Ll(n), 0];
              }
            }
            function ne0(t4, n, e, i, x, c) {
              for (var s = t4, p = x; ; ) {
                Tn(c);
                var y = j(c), T = 92 < y ? 1 : Vr(rRr, y + 1 | 0) - 1 | 0;
                if (4 < T >>> 0)
                  var E = q(c);
                else
                  switch (T) {
                    case 0:
                      var E = 3;
                      break;
                    case 1:
                      for (; ; ) {
                        B0(c, 4);
                        var h = j(c);
                        if (-1 < h)
                          if (91 < h)
                            var w = h <= 92 ? 1 : 0, G = w && -1;
                          else
                            var G = Vr(mLr, h) - 1 | 0;
                        else
                          var G = -1;
                        if (G !== 0) {
                          var E = q(c);
                          break;
                        }
                      }
                      break;
                    case 2:
                      var E = 2;
                      break;
                    case 3:
                      var E = 0;
                      break;
                    default:
                      var E = 1;
                  }
                if (4 < E >>> 0)
                  return ke(Lwr);
                switch (E) {
                  case 0:
                    var A = Se(c);
                    if (dn(i, A), Un(n, A))
                      return [0, s, d7(s, c), p];
                    dn(e, A);
                    continue;
                  case 1:
                    dn(i, Rwr);
                    var S = ee0(s, c), M = S[4], K = M || p;
                    dn(i, S[2]);
                    var V = S[3];
                    hz(function(w0) {
                      return g1(e, w0);
                    }, V);
                    var s = S[1], p = K;
                    continue;
                  case 2:
                    var f0 = Se(c);
                    dn(i, f0);
                    var m0 = h7(Ei(s, nt(s, c)), c);
                    return dn(e, f0), [0, m0, d7(m0, c), p];
                  case 3:
                    var k0 = Se(c);
                    dn(i, k0);
                    var g0 = Ei(s, nt(s, c));
                    return dn(e, k0), [0, g0, d7(g0, c), p];
                  default:
                    var e0 = c[6], x0 = c[3] - e0 | 0, l = Rt(x0 * 4 | 0), c0 = Rl(c[1], e0, x0, l);
                    bN(i, l, 0, c0), bN(e, l, 0, c0);
                    continue;
                }
              }
            }
            function te0(t4, n, e, i, x) {
              for (var c = t4; ; ) {
                Tn(x);
                var s = j(x), p = 96 < s ? 1 : Vr(sRr, s + 1 | 0) - 1 | 0;
                if (6 < p >>> 0)
                  var y = q(x);
                else
                  switch (p) {
                    case 0:
                      var y = 0;
                      break;
                    case 1:
                      for (; ; ) {
                        B0(x, 6);
                        var T = j(x);
                        if (-1 < T)
                          if (95 < T)
                            var E = T <= 96 ? 1 : 0, h = E && -1;
                          else
                            var h = Vr(pLr, T) - 1 | 0;
                        else
                          var h = -1;
                        if (h !== 0) {
                          var y = q(x);
                          break;
                        }
                      }
                      break;
                    case 2:
                      var y = 5;
                      break;
                    case 3:
                      B0(x, 5);
                      var y = xi(j(x)) === 0 ? 4 : q(x);
                      break;
                    case 4:
                      B0(x, 6);
                      var w = j(x), G = Nn < w ? us < w ? -1 : 0 : -1, y = G === 0 ? 2 : q(x);
                      break;
                    case 5:
                      var y = 3;
                      break;
                    default:
                      var y = 1;
                  }
                if (6 < y >>> 0)
                  return ke(jwr);
                switch (y) {
                  case 0:
                    return [0, Ei(c, nt(c, x)), 1];
                  case 1:
                    return Ui(i, 96), [0, c, 1];
                  case 2:
                    return dn(i, Gwr), [0, c, 0];
                  case 3:
                    Ui(e, 92), Ui(i, 92);
                    var A = ee0(c, x), S = A[2];
                    dn(e, S), dn(i, S);
                    var M = A[3];
                    hz(function(m0) {
                      return g1(n, m0);
                    }, M);
                    var c = A[1];
                    continue;
                  case 4:
                    dn(e, Mwr), dn(i, Bwr), dn(n, qwr);
                    var c = h7(c, x);
                    continue;
                  case 5:
                    var K = Se(x);
                    dn(e, K), dn(i, K), Ui(n, 10);
                    var c = h7(c, x);
                    continue;
                  default:
                    var V = Se(x);
                    dn(e, V), dn(i, V), dn(n, V);
                    continue;
                }
              }
            }
            function $ee(t4, n) {
              function e(U0) {
                for (; ; )
                  if (B0(U0, 33), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function i(U0) {
                for (; ; )
                  if (B0(U0, 27), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function x(U0) {
                B0(U0, 26);
                var R0 = qt(j(U0));
                if (R0 === 0) {
                  for (; ; )
                    if (B0(U0, 25), hn(j(U0)) !== 0)
                      return q(U0);
                }
                return R0 === 1 ? i(U0) : q(U0);
              }
              function c(U0) {
                for (; ; )
                  if (B0(U0, 27), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function s(U0) {
                B0(U0, 26);
                var R0 = qt(j(U0));
                if (R0 === 0) {
                  for (; ; )
                    if (B0(U0, 25), hn(j(U0)) !== 0)
                      return q(U0);
                }
                return R0 === 1 ? c(U0) : q(U0);
              }
              function p(U0) {
                r:
                  for (; ; ) {
                    if (pn(j(U0)) === 0)
                      for (; ; ) {
                        B0(U0, 28);
                        var R0 = qc(j(U0));
                        if (3 < R0 >>> 0)
                          return q(U0);
                        switch (R0) {
                          case 0:
                            return c(U0);
                          case 1:
                            continue;
                          case 2:
                            continue r;
                          default:
                            return s(U0);
                        }
                      }
                    return q(U0);
                  }
              }
              function y(U0) {
                B0(U0, 33);
                var R0 = Hr0(j(U0));
                if (3 < R0 >>> 0)
                  return q(U0);
                switch (R0) {
                  case 0:
                    return e(U0);
                  case 1:
                    var Re = P1(j(U0));
                    if (Re === 0)
                      for (; ; ) {
                        B0(U0, 28);
                        var Xe = Qv(j(U0));
                        if (2 < Xe >>> 0)
                          return q(U0);
                        switch (Xe) {
                          case 0:
                            return c(U0);
                          case 1:
                            continue;
                          default:
                            return s(U0);
                        }
                      }
                    if (Re === 1)
                      for (; ; ) {
                        B0(U0, 28);
                        var he = qc(j(U0));
                        if (3 < he >>> 0)
                          return q(U0);
                        switch (he) {
                          case 0:
                            return c(U0);
                          case 1:
                            continue;
                          case 2:
                            return p(U0);
                          default:
                            return s(U0);
                        }
                      }
                    return q(U0);
                  case 2:
                    for (; ; ) {
                      B0(U0, 28);
                      var _e = Qv(j(U0));
                      if (2 < _e >>> 0)
                        return q(U0);
                      switch (_e) {
                        case 0:
                          return i(U0);
                        case 1:
                          continue;
                        default:
                          return x(U0);
                      }
                    }
                  default:
                    for (; ; ) {
                      B0(U0, 28);
                      var rt = qc(j(U0));
                      if (3 < rt >>> 0)
                        return q(U0);
                      switch (rt) {
                        case 0:
                          return i(U0);
                        case 1:
                          continue;
                        case 2:
                          return p(U0);
                        default:
                          return x(U0);
                      }
                    }
                }
              }
              function T(U0) {
                B0(U0, 31);
                var R0 = qt(j(U0));
                if (R0 === 0) {
                  for (; ; )
                    if (B0(U0, 29), hn(j(U0)) !== 0)
                      return q(U0);
                }
                return R0 === 1 ? e(U0) : q(U0);
              }
              function E(U0) {
                return B0(U0, 3), zr0(j(U0)) === 0 ? 3 : q(U0);
              }
              function h(U0) {
                return _9(j(U0)) === 0 && l9(j(U0)) === 0 && Yr0(j(U0)) === 0 && Lr0(j(U0)) === 0 && Rr0(j(U0)) === 0 && pL(j(U0)) === 0 && Bl(j(U0)) === 0 && _9(j(U0)) === 0 && Gs(j(U0)) === 0 && jr0(j(U0)) === 0 && Ul(j(U0)) === 0 ? 3 : q(U0);
              }
              function w(U0) {
                B0(U0, 34);
                var R0 = Pr0(j(U0));
                if (3 < R0 >>> 0)
                  return q(U0);
                switch (R0) {
                  case 0:
                    return e(U0);
                  case 1:
                    for (; ; ) {
                      B0(U0, 34);
                      var Re = Rs(j(U0));
                      if (4 < Re >>> 0)
                        return q(U0);
                      switch (Re) {
                        case 0:
                          return e(U0);
                        case 1:
                          continue;
                        case 2:
                          return y(U0);
                        case 3:
                          r:
                            for (; ; ) {
                              if (pn(j(U0)) === 0)
                                for (; ; ) {
                                  B0(U0, 34);
                                  var Xe = Rs(j(U0));
                                  if (4 < Xe >>> 0)
                                    return q(U0);
                                  switch (Xe) {
                                    case 0:
                                      return e(U0);
                                    case 1:
                                      continue;
                                    case 2:
                                      return y(U0);
                                    case 3:
                                      continue r;
                                    default:
                                      return T(U0);
                                  }
                                }
                              return q(U0);
                            }
                        default:
                          return T(U0);
                      }
                    }
                  case 2:
                    return y(U0);
                  default:
                    return T(U0);
                }
              }
              function G(U0) {
                for (; ; )
                  if (B0(U0, 19), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function A(U0) {
                B0(U0, 34);
                var R0 = Qv(j(U0));
                if (2 < R0 >>> 0)
                  return q(U0);
                switch (R0) {
                  case 0:
                    return e(U0);
                  case 1:
                    for (; ; ) {
                      B0(U0, 34);
                      var Re = qc(j(U0));
                      if (3 < Re >>> 0)
                        return q(U0);
                      switch (Re) {
                        case 0:
                          return e(U0);
                        case 1:
                          continue;
                        case 2:
                          r:
                            for (; ; ) {
                              if (pn(j(U0)) === 0)
                                for (; ; ) {
                                  B0(U0, 34);
                                  var Xe = qc(j(U0));
                                  if (3 < Xe >>> 0)
                                    return q(U0);
                                  switch (Xe) {
                                    case 0:
                                      return e(U0);
                                    case 1:
                                      continue;
                                    case 2:
                                      continue r;
                                    default:
                                      return T(U0);
                                  }
                                }
                              return q(U0);
                            }
                        default:
                          return T(U0);
                      }
                    }
                  default:
                    return T(U0);
                }
              }
              function S(U0) {
                for (; ; )
                  if (B0(U0, 17), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function M(U0) {
                for (; ; )
                  if (B0(U0, 17), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function K(U0) {
                for (; ; )
                  if (B0(U0, 11), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function V(U0) {
                for (; ; )
                  if (B0(U0, 11), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function f0(U0) {
                for (; ; )
                  if (B0(U0, 15), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function m0(U0) {
                for (; ; )
                  if (B0(U0, 15), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function k0(U0) {
                for (; ; )
                  if (B0(U0, 23), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function g0(U0) {
                for (; ; )
                  if (B0(U0, 23), hn(j(U0)) !== 0)
                    return q(U0);
              }
              function e0(U0) {
                B0(U0, 32);
                var R0 = qt(j(U0));
                if (R0 === 0) {
                  for (; ; )
                    if (B0(U0, 30), hn(j(U0)) !== 0)
                      return q(U0);
                }
                return R0 === 1 ? e(U0) : q(U0);
              }
              function x0(U0) {
                r:
                  for (; ; ) {
                    if (pn(j(U0)) === 0)
                      for (; ; ) {
                        B0(U0, 34);
                        var R0 = qr0(j(U0));
                        if (4 < R0 >>> 0)
                          return q(U0);
                        switch (R0) {
                          case 0:
                            return e(U0);
                          case 1:
                            return A(U0);
                          case 2:
                            continue;
                          case 3:
                            continue r;
                          default:
                            return e0(U0);
                        }
                      }
                    return q(U0);
                  }
              }
              Tn(n);
              var l = j(n), c0 = tf < l ? pw < l ? -1 : Yk < l ? P3 < l ? Hw < l ? FE < l ? Zy < l ? 1 : 8 : Qh < l ? mE < l ? xF < l ? 1 : 8 : eO < l ? 1 : 8 : ZF < l ? _A < l ? 1 : 8 : bI < l ? 1 : 8 : P6 < l ? S4 < l ? a6 < l ? z8 < l ? G3 < l ? e3 < l ? LO < l ? 1 : 8 : GI < l ? 1 : 8 : Cy < l ? wg < l ? 1 : 8 : Uw < l ? 1 : 8 : R3 < l ? E8 < l ? Bg < l ? 1 : 8 : Z4 < l ? 1 : 8 : J8 < l ? JT < l ? 1 : 8 : Sk < l ? 1 : 8 : I4 < l ? KO < l ? b3 < l ? nw < l ? 1 : 8 : ok < l ? 1 : 8 : ap < l ? z6 < l ? 1 : 8 : Ah < l ? 1 : 8 : M8 < l ? v4 < l ? u6 < l ? 1 : 8 : U6 < l ? 1 : 8 : q6 < l ? g4 < l ? 1 : 8 : Ze < l ? 1 : 8 : GE < l ? B4 < l ? F6 < l ? TF < l ? f8 < l ? 1 : 8 : k8 < l ? 1 : 8 : T4 < l ? QF < l ? 1 : 8 : dd < l ? 1 : 8 : H6 < l ? t8 < l ? v3 < l ? 1 : 8 : g8 < l ? 1 : 8 : HS < l ? R8 < l ? 1 : 8 : W3 < l ? 1 : 8 : _8 < l ? x8 < l ? a8 < l ? E3 < l ? 1 : 8 : y6 < l ? 1 : 8 : v6 < l ? sF < l ? 1 : 8 : eI < l ? 1 : 8 : c3 < l ? jS < l ? n8 < l ? 1 : 8 : F8 < l ? 1 : 8 : $3 < l ? bF < l ? 1 : 8 : ag < l ? 1 : 8 : aw < l ? Fk < l ? gk < l ? Xk < l ? IT < l ? Wk < l ? 1 : 8 : xA < l ? 1 : 8 : Ey < l ? WS < l ? 1 : 8 : hh < l ? 1 : 8 : Ad < l ? yF < l ? IE < l ? 1 : 8 : eE < l ? 1 : 8 : Ty < l ? G_ < l ? 1 : 8 : LE < l ? 1 : 8 : GF < l ? Ww < l ? Uy < l ? tw < l ? 1 : 8 : zI < l ? 1 : 8 : BO < l ? cp < l ? 1 : 8 : BT < l ? 1 : 8 : ot < l ? NA < l ? OA < l ? 1 : 8 : 1 : 8 : s6 < l ? E6 < l ? b6 < l ? w3 < l ? WE < l ? 1 : 8 : Xw < l ? 1 : 8 : l4 < l ? iE < l ? 1 : 8 : Ay < l ? 1 : 8 : s3 < l ? z4 < l ? ug < l ? 1 : 8 : XF < l ? 1 : 8 : Y4 < l ? hT < l ? 1 : 8 : Ny < l ? 1 : 8 : L6 < l ? L4 < l ? z3 < l ? US < l ? 1 : 8 : Zw < l ? 1 : 8 : ly < l ? By < l ? 1 : 8 : WT < l ? 1 : 8 : q4 < l ? _d < l ? QT < l ? 1 : 8 : M3 < l ? 1 : 8 : e6 < l ? bO < l ? 1 : 8 : eS < l ? 1 : 8 : xT < l ? Q4 < l ? Kh < l ? rp < l ? R4 < l ? C6 < l ? lp < l ? j_ < l ? 1 : 8 : Rh < l ? 1 : 8 : yh < l ? Mg < l ? 1 : 8 : NS < l ? 1 : 8 : M6 < l ? A3 < l ? xk < l ? 1 : 8 : lE < l ? 1 : 8 : b8 < l ? b4 < l ? 1 : 8 : td < l ? 1 : 8 : B3 < l ? IS < l ? DE < l ? vT < l ? 1 : 8 : ST < l ? 1 : 8 : xS < l ? k3 < l ? 1 : 8 : Jh < l ? 1 : 8 : my < l ? O6 < l ? Rg < l ? 1 : 8 : py < l ? 1 : 8 : GO < l ? kF < l ? 1 : 8 : KF < l ? 1 : 8 : jI < l ? Mu < l ? BF < l ? Pd < l ? PO < l ? 1 : 8 : Lh < l ? 1 : 8 : Xd < l ? PS < l ? 1 : 8 : mA < l ? 1 : 8 : lO < l ? PI < l ? cI < l ? 1 : 8 : H_ < l ? 1 : 8 : wS < l ? oT < l ? 1 : 8 : dg < l ? 1 : 8 : DO < l ? Dw < l ? Kd < l ? mw < l ? 1 : 8 : nF < l ? 1 : 8 : Wg < l ? Gk < l ? 1 : 8 : XO < l ? 1 : 8 : aS < l ? p6 < l ? h6 < l ? 1 : 8 : rT < l ? 1 : 8 : yd < l ? tT < l ? 1 : 8 : VS < l ? 1 : 8 : JO < l ? Lk < l ? kS < l ? Cw < l ? LI < l ? $g < l ? 1 : 8 : WO < l ? 1 : 8 : Uk < l ? Ss < l ? 1 : 8 : RF < l ? 1 : 8 : Sh < l ? AS < l ? gI < l ? 1 : 8 : cg < l ? 1 : 8 : Mh < l ? Ed < l ? 1 : 8 : sI < l ? 1 : 8 : sT < l ? mg < l ? fF < l ? $I < l ? 1 : 8 : yk < l ? 1 : 8 : q_ < l ? Sw < l ? 1 : 8 : nT < l ? 1 : 8 : Bk < l ? IO < l ? dA < l ? 1 : 8 : hg < l ? 1 : 8 : ZE < l ? mF < l ? 1 : 8 : UF < l ? 1 : 8 : h4 < l ? h3 < l ? pT < l ? BI < l ? dS < l ? 1 : 8 : lA < l ? 1 : 8 : jE < l ? Jk < l ? 1 : 8 : Gg < l ? 1 : 8 : PT < l ? j6 < l ? _k < l ? 1 : 8 : aT < l ? 1 : 8 : YS < l ? HT < l ? 1 : 8 : pE < l ? 1 : 8 : Jc < l ? Tk < l ? L3 < l ? zg < l ? 1 : 8 : oh < l ? 1 : 8 : CF < l ? mh < l ? 1 : 8 : iA < l ? 1 : 8 : HE < l ? J3 < l ? by < l ? 1 : 8 : SI < l ? 1 : 8 : WF < l ? oS < l ? 1 : 8 : D4 < l ? 1 : 8 : pS < l ? Bw < l ? ak < l ? wO < l ? aI < l ? _g < l ? Dh < l ? 1 : 8 : i3 < l ? 1 : 8 : bE < l ? Gh < l ? 1 : 8 : zk < l ? 1 : 8 : ip < l ? wd < l ? B8 < l ? 1 : 8 : m3 < l ? 1 : 8 : Fw < l ? yE < l ? 1 : 8 : Hg < l ? 1 : 8 : _y < l ? ew < l ? rO < l ? JF < l ? 1 : 8 : Hh < l ? 1 : 8 : rw < l ? AI < l ? 1 : 8 : yO < l ? 1 : 8 : bS < l ? MO < l ? SA < l ? 1 : 8 : gA < l ? 1 : 8 : og < l ? XI < l ? 1 : 8 : ES < l ? 1 : 8 : wI < l ? DI < l ? iS < l ? zy < l ? Q_ < l ? 1 : 8 : _T < l ? 1 : 8 : rI < l ? Fg < l ? 1 : 8 : sA < l ? 1 : 8 : xE < l ? FT < l ? Eg < l ? 1 : 8 : AT < l ? 1 : 8 : Py < l ? i8 < l ? 1 : 8 : eg < l ? 1 : 8 : qd < l ? U_ < l ? TO < l ? md < l ? 1 : 8 : zE < l ? 1 : 8 : r6 < l ? Q6 < l ? 1 : 8 : Nh < l ? 1 : 8 : J6 < l ? MF < l ? Xy < l ? 1 : 8 : Dk < l ? 1 : 8 : RE < l ? Ag < l ? 1 : 8 : NI < l ? 1 : 8 : N8 < l ? R_ < l ? P4 < l ? rF < l ? Yd < l ? ZS < l ? 1 : 8 : G6 < l ? 1 : 8 : hE < l ? oI < l ? 1 : 8 : Rw < l ? 1 : 8 : x3 < l ? c8 < l ? YF < l ? 1 : 8 : Gw < l ? 1 : 8 : dk < l ? vI < l ? 1 : 8 : ky < l ? 1 : 8 : I8 < l ? xI < l ? i6 < l ? Sy < l ? 1 : 8 : qI < l ? 1 : 8 : s8 < l ? Nw < l ? 1 : 8 : _E < l ? 1 : 8 : d3 < l ? xp < l ? uE < l ? 1 : 8 : A8 < l ? 1 : 8 : lw < l ? $F < l ? 1 : 8 : WI < l ? 1 : 8 : Jd < l ? nI < l ? h8 < l ? wy < l ? uw < l ? 1 : 8 : f3 < l ? 1 : 8 : yI < l ? EA < l ? 1 : 8 : Xh < l ? 1 : 8 : Sg < l ? aE < l ? AO < l ? 1 : 8 : Y6 < l ? 1 : 8 : Mw < l ? vw < l ? 1 : 8 : T3 < l ? 1 : 8 : Ck < l ? NF < l ? Gy < l ? _4 < l ? 1 : 8 : lh < l ? 1 : 8 : Jg < l ? Qk < l ? 1 : 8 : vS < l ? 1 : 8 : q3 < l ? CO < l ? ww < l ? 1 : 8 : dE < l ? 1 : 8 : rg < l ? nA < l ? 1 : 8 : IA < l ? 1 : 8 : sh < l ? $E < l ? Mk < l ? $6 < l ? Uh < l ? cF < l ? eF < l ? bd < l ? uT < l ? 1 : 8 : KI < l ? 1 : 8 : ME < l ? NT < l ? 1 : 8 : $8 < l ? 1 : 8 : CA < l ? EE < l ? XT < l ? 1 : 8 : wh < l ? 1 : 8 : Ch < l ? Ud < l ? 1 : 8 : hS < l ? 1 : 8 : FA < l ? RO < l ? Vg < l ? bg < l ? 1 : 8 : Yg < l ? 1 : 8 : zw < l ? fh < l ? 1 : 8 : jg < l ? 1 : 8 : Pg < l ? _S < l ? Zh < l ? 1 : 8 : Ig < l ? 1 : 8 : fA < l ? gT < l ? 1 : 8 : jk < l ? 1 : 8 : tS < l ? Q8 < l ? QI < l ? PE < l ? UE < l ? 1 : 8 : yA < l ? 1 : 8 : FO < l ? qy < l ? 1 : 8 : oA < l ? 1 : 8 : cA < l ? p4 < l ? hk < l ? 1 : 8 : sO < l ? 1 : 8 : gh < l ? S7 < l ? 1 : 8 : rk < l ? 1 : 8 : Y8 < l ? J_ < l ? Ih < l ? Rd < l ? 1 : 8 : ET < l ? 1 : 8 : jh < l ? Nk < l ? 1 : 8 : vd < l ? 1 : 8 : id < l ? vg < l ? rE < l ? 1 : 8 : ZT < l ? 1 : 8 : ng < l ? Iw < l ? 1 : 8 : GT < l ? 1 : 8 : Cd < l ? pk < l ? fn < l ? m8 < l ? OT < l ? B6 < l ? 1 : 8 : Od < l ? 1 : 8 : $4 < l ? ny < l ? 1 : 8 : op < l ? 1 : 8 : pO < l ? qE < l ? ld < l ? 1 : 8 : X_ < l ? 1 : 8 : FS < l ? YT < l ? 1 : 8 : BS < l ? 1 : 8 : Yw < l ? fy < l ? bA < l ? Wd < l ? 1 : 8 : bT < l ? 1 : 8 : aF < l ? ek < l ? 1 : 8 : II < l ? 1 : 8 : cO < l ? fd < l ? ig < l ? 1 : 8 : _h < l ? 1 : 8 : aO < l ? hO < l ? 1 : 8 : uO < l ? 1 : 8 : CS < l ? JE < l ? oO < l ? lk < l ? cd < l ? 1 : 8 : xh < l ? 1 : 8 : QS < l ? hw < l ? 1 : 8 : Iy < l ? 1 : 8 : pA < l ? rS < l ? $T < l ? 1 : 8 : tI < l ? 1 : 8 : xy < l ? Aw < l ? 1 : 8 : 1 : iT < l ? Q3 < l ? uk < l ? 8 : rd < l ? 1 : 8 : qF < l ? nE < l ? 1 : 8 : bk < l ? 1 : 8 : pg < l ? iO < l ? fI < l ? 1 : 8 : qO < l ? 1 : 8 : My < l ? 1 : 8 : L8 < l ? Fh < l ? cw < l ? Nd < l ? tA < l ? 8 : rh < l ? fT < l ? 1 : 8 : pF < l ? 1 : 8 : nd < l ? JI < l ? ty < l ? 1 : 8 : kd < l ? 1 : 8 : VE < l ? Qd < l ? 1 : 8 : wF < l ? 1 : 8 : ep < l ? K4 < l ? g6 < l ? yy < l ? 1 : 8 : tg < l ? 1 : 8 : Z8 < l ? kO < l ? 1 : 8 : Hk < l ? 1 : 8 : Ok < l ? H8 < l ? FF < l ? 1 : 8 : gy < l ? 1 : 8 : sg < l ? Ak < l ? 1 : 8 : gE < l ? 1 : 8 : qw < l ? ry < l ? uy < l ? yS < l ? sE < l ? 1 : 8 : 1 : 8 : Ew < l ? 8 : r8 < l ? CT < l ? 1 : 8 : kg < l ? 1 : 8 : uI < l ? u3 < l ? qo < l ? La < l ? 1 : 2 : HI < l ? 1 : 8 : sw < l ? UT < l ? 1 : 8 : KS < l ? 1 : 8 : kI < l ? fS < l ? eh < l ? 1 : 8 : LT < l ? 1 : 8 : qT < l ? $w < l ? 1 : 8 : TI < l ? 1 : 8 : YI < l ? fk < l ? Jn < l ? j4 < l ? U3 < l ? ah < l ? 1 : 8 : hF < l ? 1 : 8 : K3 < l ? R6 < l ? 1 : 8 : od < l ? 1 : 8 : RT < l ? fp < l ? xw < l ? 1 : 8 : uS < l ? 1 : 8 : fO < l ? n3 < l ? 1 : 8 : sd < l ? 1 : 8 : Ek < l ? JS < l ? nh < l ? xg < l ? 1 : 8 : ay < l ? 1 : 8 : Zk < l ? $h < l ? 1 : 8 : AE < l ? 1 : 8 : Eh < l ? dy < l ? lF < l ? 1 : 8 : hA < l ? 1 : 8 : Dy < l ? 1 : 8 : zh < l ? X3 < l ? o3 < l ? Qw < l ? 1 : 8 : ov < l ? 8 : MT < l ? 1 : 8 : OF < l ? w6 < l ? DF < l ? 1 : 8 : Zd < l ? 1 : 8 : qk < l ? jd < l ? 1 : 8 : eA < l ? 1 : 8 : Wh < l ? lS < l ? mT < l ? lI < l ? 1 : 8 : 1 : jy < l ? 8 : Qy < l ? 1 : 8 : IF < l ? bh < l ? 1 : 8 : zT < l ? NO < l ? 1 : 8 : vO < l ? 1 : 8 : gd < l ? T8 < l ? Z_ < l ? xd < l ? SO < l ? uh < l ? FI < l ? Pw < l ? 1 : 8 : kA < l ? 1 : 8 : Hd < l ? oy < l ? 1 : 8 : vk < l ? 1 : 8 : LF < l ? AA < l ? bp < l ? 1 : 8 : 1 : 8 : kT < l ? Vh < l ? SS < l ? Jy < l ? 1 : 8 : gS < l ? 1 : 8 : l6 < l ? Vk < l ? 1 : 8 : SE < l ? 1 : 8 : Tw < l ? yw < l ? 1 : 8 : hd < l ? ZO < l ? 1 : 8 : w8 < l ? 1 : 8 : SF < l ? jO < l ? zF < l ? Oy < l ? Th < l ? 1 : 8 : uA < l ? 1 : 8 : ey < l ? QE < l ? 1 : 8 : vy < l ? 1 : 8 : $y < l ? y8 < l ? Yy < l ? 1 : 8 : t3 < l ? 1 : 8 : tE < l ? sy < l ? 1 : 8 : lg < l ? 1 : 8 : Ky < l ? TA < l ? cS < l ? tF < l ? 1 : 8 : zd < l ? 1 : 8 : dI < l ? mk < l ? 1 : 8 : xO < l ? 1 : 8 : RS < l && vA < l ? 1 : 8 : kk < l ? Md < l ? fg < l ? ik < l ? 8 : ed < l ? _I < l ? 1 : 8 : Ld < l ? 1 : 8 : cE < l ? sk < l ? W_ < l ? 1 : 8 : 1 : 8 : Ng < l ? YO < l && sS < l ? 1 : 8 : _w < l ? tO < l ? Gd < l ? 1 : 8 : 1 : EF < l ? 8 : 1 : Fd < l ? OE < l ? H3 < l ? 8 : fw < l ? 1 : 8 : EI < l ? nk < l ? gO < l ? 1 : 8 : M_ < l ? 1 : 8 : Td < l ? 1 : 8 : HF < l ? Og < l ? Ph < l ? 1 : 8 : zS < l ? 1 : 8 : $k < l ? KE < l ? 8 : ad < l ? 1 : 8 : Y_ < l ? kE < l ? 1 : 8 : Xt < l ? 1 : 8 : qS < l ? BE < l ? EO < l ? U4 < l ? Fy < l ? S8 < l ? MI < l ? 1 : 8 : iF < l ? 1 : 8 : VF < l ? 1 : 8 : gw < l ? S3 < l ? se < l ? 1 : 8 : 1 : 8 : Cg < l ? qh < l ? z_ < l ? V_ < l ? 1 : 8 : 1 : 8 : Vw < l ? O3 < l ? ph < l ? 1 : 8 : oF < l ? 1 : 8 : gg < l ? 1 : 8 : K8 < l ? G8 < l ? Sa < l ? RI < l ? 8 : ea < l ? 1 : 2 : T6 < l ? Hy < l ? 1 : 8 : CE < l ? 1 : 8 : W8 < l ? K6 < l ? Lg < l ? 1 : 8 : lT < l ? 1 : 8 : o8 < l ? it2 < l ? 1 : 8 : Pk < l ? 1 : 8 : DS < l ? fE < l ? G4 < l ? Dg < l ? 1 : 8 : rA < l ? 1 : 8 : D6 < l ? AF < l ? 1 : 8 : m4 < l ? 1 : 8 : hI < l ? oE < l ? OI < l ? 1 : 8 : C3 < l ? 1 : 8 : M4 < l ? q8 < l ? 1 : 8 : Tg < l ? 1 : 8 : C8 < l ? nS < l ? vE < l ? Kk < l ? yT < l ? $_ < l ? 1 : 8 : gF < l ? 1 : 8 : YE < l ? 1 : 8 : th < l ? pI < l ? 8 : 1 : 8 : UO < l ? dw < l ? KT < l ? v8 < l ? 1 : 8 : PA < l ? 1 : 8 : Kw < l ? K_ < l ? 1 : 8 : 1 : 8 : qg < l ? QO < l ? Z3 < l ? vp < l ? D8 < l ? 1 : 8 : r3 < l ? 1 : 8 : hr < l ? u8 < l ? 1 : 8 : 1 : F4 < l ? $S < l ? 8 : _6 < l ? 1 : 8 : dF < l ? Ly < l ? 1 : 8 : j3 < l ? 1 : 8 : Rk < l ? VI < l ? nO < l ? a3 < l ? 1 : 8 : dO < l ? 1 : 8 : Ry < l ? I3 < l ? 1 : 8 : np < l ? 1 : 8 : ya < l ? oc < l ? cx < l ? 1 : 2 : aa < l ? 1 : 2 : Ju < l ? Uu < l ? 1 : 3 : Pa < l ? 1 : 2 : Vr(zLr, l + 1 | 0) - 1 | 0;
              if (36 < c0 >>> 0)
                var t0 = q(n);
              else
                switch (c0) {
                  case 0:
                    var t0 = 98;
                    break;
                  case 1:
                    var t0 = 99;
                    break;
                  case 2:
                    if (B0(n, 1), Mc(j(n)) === 0) {
                      for (; ; )
                        if (B0(n, 1), Mc(j(n)) !== 0) {
                          var t0 = q(n);
                          break;
                        }
                    } else
                      var t0 = q(n);
                    break;
                  case 3:
                    var t0 = 0;
                    break;
                  case 4:
                    B0(n, 0);
                    var a0 = xi(j(n)) !== 0 ? 1 : 0, t0 = a0 && q(n);
                    break;
                  case 5:
                    B0(n, 88);
                    var t0 = Hi(j(n)) === 0 ? (B0(n, 58), Hi(j(n)) === 0 ? 54 : q(n)) : q(n);
                    break;
                  case 6:
                    var t0 = 7;
                    break;
                  case 7:
                    B0(n, 95);
                    var w0 = j(n), _0 = 32 < w0 ? 33 < w0 ? -1 : 0 : -1, t0 = _0 === 0 ? 6 : q(n);
                    break;
                  case 8:
                    var t0 = 97;
                    break;
                  case 9:
                    B0(n, 84);
                    var t0 = Hi(j(n)) === 0 ? 71 : q(n);
                    break;
                  case 10:
                    B0(n, 86);
                    var E0 = j(n), X0 = 37 < E0 ? 61 < E0 ? -1 : Vr(PRr, E0 - 38 | 0) - 1 | 0 : -1, t0 = X0 === 0 ? (B0(n, 51), Hi(j(n)) === 0 ? 76 : q(n)) : X0 === 1 ? 72 : q(n);
                    break;
                  case 11:
                    var t0 = 38;
                    break;
                  case 12:
                    var t0 = 39;
                    break;
                  case 13:
                    B0(n, 82);
                    var b = Dr0(j(n));
                    if (2 < b >>> 0)
                      var t0 = q(n);
                    else
                      switch (b) {
                        case 0:
                          B0(n, 83);
                          var t0 = Hi(j(n)) === 0 ? 70 : q(n);
                          break;
                        case 1:
                          var t0 = 4;
                          break;
                        default:
                          var t0 = 69;
                      }
                    break;
                  case 14:
                    B0(n, 80);
                    var G0 = j(n), X = 42 < G0 ? 61 < G0 ? -1 : Vr(DRr, G0 + cy | 0) - 1 | 0 : -1, t0 = X === 0 ? 59 : X === 1 ? 67 : q(n);
                    break;
                  case 15:
                    var t0 = 45;
                    break;
                  case 16:
                    B0(n, 81);
                    var s0 = j(n), dr = 44 < s0 ? 61 < s0 ? -1 : Vr(dLr, s0 + mv | 0) - 1 | 0 : -1, t0 = dr === 0 ? 60 : dr === 1 ? 68 : q(n);
                    break;
                  case 17:
                    B0(n, 43);
                    var Ar = L1(j(n));
                    if (Ar === 0)
                      var t0 = lL(j(n)) === 0 ? 42 : q(n);
                    else if (Ar === 1)
                      for (; ; ) {
                        B0(n, 34);
                        var ar = Rs(j(n));
                        if (4 < ar >>> 0)
                          var t0 = q(n);
                        else
                          switch (ar) {
                            case 0:
                              var t0 = e(n);
                              break;
                            case 1:
                              continue;
                            case 2:
                              var t0 = y(n);
                              break;
                            case 3:
                              r:
                                for (; ; ) {
                                  if (pn(j(n)) === 0)
                                    for (; ; ) {
                                      B0(n, 34);
                                      var W0 = Rs(j(n));
                                      if (4 < W0 >>> 0)
                                        var Lr = q(n);
                                      else
                                        switch (W0) {
                                          case 0:
                                            var Lr = e(n);
                                            break;
                                          case 1:
                                            continue;
                                          case 2:
                                            var Lr = y(n);
                                            break;
                                          case 3:
                                            continue r;
                                          default:
                                            var Lr = T(n);
                                        }
                                      break;
                                    }
                                  else
                                    var Lr = q(n);
                                  var t0 = Lr;
                                  break;
                                }
                              break;
                            default:
                              var t0 = T(n);
                          }
                        break;
                      }
                    else
                      var t0 = q(n);
                    break;
                  case 18:
                    B0(n, 93);
                    var Tr = Dr0(j(n));
                    if (2 < Tr >>> 0)
                      var t0 = q(n);
                    else
                      switch (Tr) {
                        case 0:
                          B0(n, 2);
                          var Hr = f9(j(n));
                          if (2 < Hr >>> 0)
                            var t0 = q(n);
                          else
                            switch (Hr) {
                              case 0:
                                for (; ; ) {
                                  var Or = f9(j(n));
                                  if (2 < Or >>> 0)
                                    var t0 = q(n);
                                  else
                                    switch (Or) {
                                      case 0:
                                        continue;
                                      case 1:
                                        var t0 = E(n);
                                        break;
                                      default:
                                        var t0 = h(n);
                                    }
                                  break;
                                }
                                break;
                              case 1:
                                var t0 = E(n);
                                break;
                              default:
                                var t0 = h(n);
                            }
                          break;
                        case 1:
                          var t0 = 5;
                          break;
                        default:
                          var t0 = 92;
                      }
                    break;
                  case 19:
                    B0(n, 34);
                    var xr = mL(j(n));
                    if (8 < xr >>> 0)
                      var t0 = q(n);
                    else
                      switch (xr) {
                        case 0:
                          var t0 = e(n);
                          break;
                        case 1:
                          var t0 = w(n);
                          break;
                        case 2:
                          for (; ; ) {
                            B0(n, 20);
                            var Rr = Xr0(j(n));
                            if (4 < Rr >>> 0)
                              var t0 = q(n);
                            else
                              switch (Rr) {
                                case 0:
                                  var t0 = G(n);
                                  break;
                                case 1:
                                  var t0 = A(n);
                                  break;
                                case 2:
                                  continue;
                                case 3:
                                  for (; ; ) {
                                    B0(n, 18);
                                    var Wr = i9(j(n));
                                    if (3 < Wr >>> 0)
                                      var t0 = q(n);
                                    else
                                      switch (Wr) {
                                        case 0:
                                          var t0 = S(n);
                                          break;
                                        case 1:
                                          var t0 = A(n);
                                          break;
                                        case 2:
                                          continue;
                                        default:
                                          B0(n, 17);
                                          var Jr = qt(j(n));
                                          if (Jr === 0) {
                                            for (; ; )
                                              if (B0(n, 17), hn(j(n)) !== 0) {
                                                var t0 = q(n);
                                                break;
                                              }
                                          } else
                                            var t0 = Jr === 1 ? S(n) : q(n);
                                      }
                                    break;
                                  }
                                  break;
                                default:
                                  B0(n, 19);
                                  var or = qt(j(n));
                                  if (or === 0) {
                                    for (; ; )
                                      if (B0(n, 19), hn(j(n)) !== 0) {
                                        var t0 = q(n);
                                        break;
                                      }
                                  } else
                                    var t0 = or === 1 ? G(n) : q(n);
                              }
                            break;
                          }
                          break;
                        case 3:
                          for (; ; ) {
                            B0(n, 18);
                            var _r = i9(j(n));
                            if (3 < _r >>> 0)
                              var t0 = q(n);
                            else
                              switch (_r) {
                                case 0:
                                  var t0 = M(n);
                                  break;
                                case 1:
                                  var t0 = A(n);
                                  break;
                                case 2:
                                  continue;
                                default:
                                  B0(n, 17);
                                  var Ir = qt(j(n));
                                  if (Ir === 0) {
                                    for (; ; )
                                      if (B0(n, 17), hn(j(n)) !== 0) {
                                        var t0 = q(n);
                                        break;
                                      }
                                  } else
                                    var t0 = Ir === 1 ? M(n) : q(n);
                              }
                            break;
                          }
                          break;
                        case 4:
                          B0(n, 33);
                          var fe = Gr0(j(n));
                          if (fe === 0)
                            var t0 = e(n);
                          else if (fe === 1)
                            for (; ; ) {
                              B0(n, 12);
                              var v0 = w9(j(n));
                              if (3 < v0 >>> 0)
                                var t0 = q(n);
                              else
                                switch (v0) {
                                  case 0:
                                    var t0 = K(n);
                                    break;
                                  case 1:
                                    continue;
                                  case 2:
                                    r:
                                      for (; ; ) {
                                        if (Bc(j(n)) === 0)
                                          for (; ; ) {
                                            B0(n, 12);
                                            var P = w9(j(n));
                                            if (3 < P >>> 0)
                                              var Q = q(n);
                                            else
                                              switch (P) {
                                                case 0:
                                                  var Q = V(n);
                                                  break;
                                                case 1:
                                                  continue;
                                                case 2:
                                                  continue r;
                                                default:
                                                  B0(n, 10);
                                                  var L = qt(j(n));
                                                  if (L === 0) {
                                                    for (; ; )
                                                      if (B0(n, 9), hn(j(n)) !== 0) {
                                                        var Q = q(n);
                                                        break;
                                                      }
                                                  } else
                                                    var Q = L === 1 ? V(n) : q(n);
                                              }
                                            break;
                                          }
                                        else
                                          var Q = q(n);
                                        var t0 = Q;
                                        break;
                                      }
                                    break;
                                  default:
                                    B0(n, 10);
                                    var i0 = qt(j(n));
                                    if (i0 === 0) {
                                      for (; ; )
                                        if (B0(n, 9), hn(j(n)) !== 0) {
                                          var t0 = q(n);
                                          break;
                                        }
                                    } else
                                      var t0 = i0 === 1 ? K(n) : q(n);
                                }
                              break;
                            }
                          else
                            var t0 = q(n);
                          break;
                        case 5:
                          var t0 = y(n);
                          break;
                        case 6:
                          B0(n, 33);
                          var l0 = Mr0(j(n));
                          if (l0 === 0)
                            var t0 = e(n);
                          else if (l0 === 1)
                            for (; ; ) {
                              B0(n, 16);
                              var S0 = h9(j(n));
                              if (3 < S0 >>> 0)
                                var t0 = q(n);
                              else
                                switch (S0) {
                                  case 0:
                                    var t0 = f0(n);
                                    break;
                                  case 1:
                                    continue;
                                  case 2:
                                    r:
                                      for (; ; ) {
                                        if (Vu(j(n)) === 0)
                                          for (; ; ) {
                                            B0(n, 16);
                                            var T0 = h9(j(n));
                                            if (3 < T0 >>> 0)
                                              var j0 = q(n);
                                            else
                                              switch (T0) {
                                                case 0:
                                                  var j0 = m0(n);
                                                  break;
                                                case 1:
                                                  continue;
                                                case 2:
                                                  continue r;
                                                default:
                                                  B0(n, 14);
                                                  var er = qt(j(n));
                                                  if (er === 0) {
                                                    for (; ; )
                                                      if (B0(n, 13), hn(j(n)) !== 0) {
                                                        var j0 = q(n);
                                                        break;
                                                      }
                                                  } else
                                                    var j0 = er === 1 ? m0(n) : q(n);
                                              }
                                            break;
                                          }
                                        else
                                          var j0 = q(n);
                                        var t0 = j0;
                                        break;
                                      }
                                    break;
                                  default:
                                    B0(n, 14);
                                    var B = qt(j(n));
                                    if (B === 0) {
                                      for (; ; )
                                        if (B0(n, 13), hn(j(n)) !== 0) {
                                          var t0 = q(n);
                                          break;
                                        }
                                    } else
                                      var t0 = B === 1 ? f0(n) : q(n);
                                }
                              break;
                            }
                          else
                            var t0 = q(n);
                          break;
                        case 7:
                          B0(n, 33);
                          var Z = Or0(j(n));
                          if (Z === 0)
                            var t0 = e(n);
                          else if (Z === 1)
                            for (; ; ) {
                              B0(n, 24);
                              var p0 = E9(j(n));
                              if (3 < p0 >>> 0)
                                var t0 = q(n);
                              else
                                switch (p0) {
                                  case 0:
                                    var t0 = k0(n);
                                    break;
                                  case 1:
                                    continue;
                                  case 2:
                                    r:
                                      for (; ; ) {
                                        if (Pn(j(n)) === 0)
                                          for (; ; ) {
                                            B0(n, 24);
                                            var b0 = E9(j(n));
                                            if (3 < b0 >>> 0)
                                              var q0 = q(n);
                                            else
                                              switch (b0) {
                                                case 0:
                                                  var q0 = g0(n);
                                                  break;
                                                case 1:
                                                  continue;
                                                case 2:
                                                  continue r;
                                                default:
                                                  B0(n, 22);
                                                  var O0 = qt(j(n));
                                                  if (O0 === 0) {
                                                    for (; ; )
                                                      if (B0(n, 21), hn(j(n)) !== 0) {
                                                        var q0 = q(n);
                                                        break;
                                                      }
                                                  } else
                                                    var q0 = O0 === 1 ? g0(n) : q(n);
                                              }
                                            break;
                                          }
                                        else
                                          var q0 = q(n);
                                        var t0 = q0;
                                        break;
                                      }
                                    break;
                                  default:
                                    B0(n, 22);
                                    var nr = qt(j(n));
                                    if (nr === 0) {
                                      for (; ; )
                                        if (B0(n, 21), hn(j(n)) !== 0) {
                                          var t0 = q(n);
                                          break;
                                        }
                                    } else
                                      var t0 = nr === 1 ? k0(n) : q(n);
                                }
                              break;
                            }
                          else
                            var t0 = q(n);
                          break;
                        default:
                          var t0 = e0(n);
                      }
                    break;
                  case 20:
                    B0(n, 34);
                    var yr = o9(j(n));
                    if (5 < yr >>> 0)
                      var t0 = q(n);
                    else
                      switch (yr) {
                        case 0:
                          var t0 = e(n);
                          break;
                        case 1:
                          var t0 = w(n);
                          break;
                        case 2:
                          for (; ; ) {
                            B0(n, 34);
                            var vr = o9(j(n));
                            if (5 < vr >>> 0)
                              var t0 = q(n);
                            else
                              switch (vr) {
                                case 0:
                                  var t0 = e(n);
                                  break;
                                case 1:
                                  var t0 = w(n);
                                  break;
                                case 2:
                                  continue;
                                case 3:
                                  var t0 = y(n);
                                  break;
                                case 4:
                                  var t0 = x0(n);
                                  break;
                                default:
                                  var t0 = e0(n);
                              }
                            break;
                          }
                          break;
                        case 3:
                          var t0 = y(n);
                          break;
                        case 4:
                          var t0 = x0(n);
                          break;
                        default:
                          var t0 = e0(n);
                      }
                    break;
                  case 21:
                    var t0 = 46;
                    break;
                  case 22:
                    var t0 = 44;
                    break;
                  case 23:
                    B0(n, 78);
                    var $0 = j(n), Sr = 59 < $0 ? 61 < $0 ? -1 : Vr(tN, $0 - 60 | 0) - 1 | 0 : -1, t0 = Sr === 0 ? (B0(n, 62), Hi(j(n)) === 0 ? 61 : q(n)) : Sr === 1 ? 55 : q(n);
                    break;
                  case 24:
                    B0(n, 90);
                    var Mr = bL(j(n)), t0 = Mr === 0 ? (B0(n, 57), Hi(j(n)) === 0 ? 53 : q(n)) : Mr === 1 ? 91 : q(n);
                    break;
                  case 25:
                    B0(n, 79);
                    var Br = bL(j(n));
                    if (Br === 0)
                      var t0 = 56;
                    else if (Br === 1) {
                      B0(n, 66);
                      var qr = bL(j(n)), t0 = qr === 0 ? 63 : qr === 1 ? (B0(n, 65), Hi(j(n)) === 0 ? 64 : q(n)) : q(n);
                    } else
                      var t0 = q(n);
                    break;
                  case 26:
                    B0(n, 50);
                    var jr = j(n), $r = 45 < jr ? 63 < jr ? -1 : Vr(sLr, jr + l1 | 0) - 1 | 0 : -1, t0 = $r === 0 ? (B0(n, 48), pn(j(n)) === 0 ? 47 : q(n)) : $r === 1 ? (B0(n, 49), Hi(j(n)) === 0 ? 75 : q(n)) : q(n);
                    break;
                  case 27:
                    B0(n, 94);
                    var ne = j(n), Qr = 63 < ne ? 64 < ne ? -1 : 0 : -1;
                    if (Qr === 0) {
                      var pe = j(n), oe = 96 < pe ? j7 < pe ? -1 : Vr(cRr, pe + V3 | 0) - 1 | 0 : -1;
                      if (oe === 0)
                        if (Ar0(j(n)) === 0) {
                          var me = j(n), ae = fc < me ? tl < me ? -1 : 0 : -1;
                          if (ae === 0 && pL(j(n)) === 0 && Bl(j(n)) === 0)
                            var ce = j(n), ge = 72 < ce ? 73 < ce ? -1 : 0 : -1, t0 = ge === 0 && v9(j(n)) === 0 && Ul(j(n)) === 0 && d9(j(n)) === 0 && Br0(j(n)) === 0 && v9(j(n)) === 0 && l9(j(n)) === 0 && d9(j(n)) === 0 ? 35 : q(n);
                          else
                            var t0 = q(n);
                        } else
                          var t0 = q(n);
                      else
                        var t0 = oe === 1 && v9(j(n)) === 0 && Ul(j(n)) === 0 && d9(j(n)) === 0 && Br0(j(n)) === 0 && v9(j(n)) === 0 && l9(j(n)) === 0 && d9(j(n)) === 0 ? 35 : q(n);
                    } else
                      var t0 = q(n);
                    break;
                  case 28:
                    var t0 = 40;
                    break;
                  case 29:
                    if (B0(n, 96), Gs(j(n)) === 0) {
                      var H0 = R1(j(n));
                      if (H0 === 0)
                        var t0 = Pn(j(n)) === 0 && Pn(j(n)) === 0 && Pn(j(n)) === 0 ? 97 : q(n);
                      else if (H0 === 1 && Pn(j(n)) === 0)
                        for (; ; ) {
                          var Fr = N1(j(n));
                          if (Fr !== 0) {
                            var t0 = Fr === 1 ? 97 : q(n);
                            break;
                          }
                        }
                      else
                        var t0 = q(n);
                    } else
                      var t0 = q(n);
                    break;
                  case 30:
                    var t0 = 41;
                    break;
                  case 31:
                    B0(n, 87);
                    var t0 = Hi(j(n)) === 0 ? 74 : q(n);
                    break;
                  case 32:
                    var t0 = 8;
                    break;
                  case 33:
                    var t0 = 36;
                    break;
                  case 34:
                    B0(n, 85);
                    var _ = j(n), k = 60 < _ ? X2 < _ ? -1 : Vr(LRr, _ + TS | 0) - 1 | 0 : -1, t0 = k === 0 ? 73 : k === 1 ? (B0(n, 52), Hi(j(n)) === 0 ? 77 : q(n)) : q(n);
                    break;
                  case 35:
                    var t0 = 37;
                    break;
                  default:
                    var t0 = 89;
                }
              if (99 < t0 >>> 0)
                return ke(APr);
              var I = t0;
              if (50 <= I)
                switch (I) {
                  case 50:
                    return [0, t4, 85];
                  case 51:
                    return [0, t4, 88];
                  case 52:
                    return [0, t4, 87];
                  case 53:
                    return [0, t4, 94];
                  case 54:
                    return [0, t4, 95];
                  case 55:
                    return [0, t4, 96];
                  case 56:
                    return [0, t4, 97];
                  case 57:
                    return [0, t4, 92];
                  case 58:
                    return [0, t4, 93];
                  case 59:
                    return [0, t4, vf];
                  case 60:
                    return [0, t4, T7];
                  case 61:
                    return [0, t4, 69];
                  case 62:
                    return [0, t4, ti];
                  case 63:
                    return [0, t4, 68];
                  case 64:
                    return [0, t4, 67];
                  case 65:
                    return [0, t4, ji];
                  case 66:
                    return [0, t4, R7];
                  case 67:
                    return [0, t4, 78];
                  case 68:
                    return [0, t4, 77];
                  case 69:
                    return [0, t4, 75];
                  case 70:
                    return [0, t4, 76];
                  case 71:
                    return [0, t4, 73];
                  case 72:
                    return [0, t4, 72];
                  case 73:
                    return [0, t4, 71];
                  case 74:
                    return [0, t4, 70];
                  case 75:
                    return [0, t4, 79];
                  case 76:
                    return [0, t4, 80];
                  case 77:
                    return [0, t4, 81];
                  case 78:
                    return [0, t4, 98];
                  case 79:
                    return [0, t4, 99];
                  case 80:
                    return [0, t4, s7];
                  case 81:
                    return [0, t4, L7];
                  case 82:
                    return [0, t4, Vt];
                  case 83:
                    return [0, t4, Qc];
                  case 84:
                    return [0, t4, fs2];
                  case 85:
                    return [0, t4, 89];
                  case 86:
                    return [0, t4, 91];
                  case 87:
                    return [0, t4, 90];
                  case 88:
                    return [0, t4, Fv];
                  case 89:
                    return [0, t4, Yt];
                  case 90:
                    return [0, t4, 82];
                  case 91:
                    return [0, t4, 11];
                  case 92:
                    return [0, t4, 74];
                  case 93:
                    return [0, t4, j7];
                  case 94:
                    return [0, t4, 13];
                  case 95:
                    return [0, t4, 14];
                  case 96:
                    return [2, Ei(t4, nt(t4, n))];
                  case 97:
                    var U = n[6];
                    Kr0(n);
                    var Y = Hl(t4, U, n[3]);
                    fL(n, U);
                    var y0 = Ll(n), D0 = re0(t4, y0), A0 = D0[2], D = Ee(A0, RPr);
                    if (0 <= D) {
                      if (!(0 < D))
                        return [0, t4, 18];
                      var u0 = Ee(A0, aDr);
                      if (0 <= u0) {
                        if (!(0 < u0))
                          return [0, t4, 51];
                        var Y0 = Ee(A0, kDr);
                        if (0 <= Y0) {
                          if (!(0 < Y0))
                            return [0, t4, 46];
                          if (!n0(A0, ODr))
                            return [0, t4, 24];
                          if (!n0(A0, IDr))
                            return [0, t4, 47];
                          if (!n0(A0, ADr))
                            return [0, t4, 25];
                          if (!n0(A0, NDr))
                            return [0, t4, 26];
                          if (!n0(A0, CDr))
                            return [0, t4, 58];
                        } else {
                          if (!n0(A0, wDr))
                            return [0, t4, 20];
                          if (!n0(A0, EDr))
                            return [0, t4, 21];
                          if (!n0(A0, SDr))
                            return [0, t4, 22];
                          if (!n0(A0, gDr))
                            return [0, t4, 31];
                          if (!n0(A0, FDr))
                            return [0, t4, 23];
                          if (!n0(A0, TDr))
                            return [0, t4, 61];
                        }
                      } else {
                        var J0 = Ee(A0, oDr);
                        if (0 <= J0) {
                          if (!(0 < J0))
                            return [0, t4, 54];
                          if (!n0(A0, mDr))
                            return [0, t4, 55];
                          if (!n0(A0, _Dr))
                            return [0, t4, 56];
                          if (!n0(A0, yDr))
                            return [0, t4, 57];
                          if (!n0(A0, dDr))
                            return [0, t4, 19];
                          if (!n0(A0, hDr))
                            return [0, t4, 42];
                        } else {
                          if (!n0(A0, cDr))
                            return [0, t4, 53];
                          if (!n0(A0, sDr))
                            return [0, t4, 28];
                          if (!n0(A0, vDr))
                            return [0, t4, 44];
                          if (!n0(A0, lDr))
                            return [0, t4, 29];
                          if (!n0(A0, bDr))
                            return [0, t4, 63];
                          if (!n0(A0, pDr))
                            return [0, t4, 62];
                        }
                      }
                    } else {
                      var fr = Ee(A0, jPr);
                      if (0 <= fr) {
                        if (!(0 < fr))
                          return [0, t4, 37];
                        var Q0 = Ee(A0, JPr);
                        if (0 <= Q0) {
                          if (!(0 < Q0))
                            return [0, t4, 39];
                          if (!n0(A0, tDr))
                            return [0, t4, 15];
                          if (!n0(A0, uDr))
                            return [0, t4, 16];
                          if (!n0(A0, iDr))
                            return [0, t4, 52];
                          if (!n0(A0, fDr))
                            return [0, t4, 50];
                          if (!n0(A0, xDr))
                            return [0, t4, 17];
                        } else {
                          if (!n0(A0, $Pr))
                            return [0, t4, 43];
                          if (!n0(A0, ZPr))
                            return [0, t4, 48];
                          if (!n0(A0, QPr))
                            return [0, t4, 49];
                          if (!n0(A0, rDr))
                            return [0, t4, 41];
                          if (!n0(A0, eDr))
                            return [0, t4, 30];
                          if (!n0(A0, nDr))
                            return [0, t4, 38];
                        }
                      } else {
                        var F0 = Ee(A0, GPr);
                        if (0 <= F0) {
                          if (!(0 < F0))
                            return [0, t4, 27];
                          if (!n0(A0, YPr))
                            return [0, t4, 35];
                          if (!n0(A0, VPr))
                            return [0, t4, 59];
                          if (!n0(A0, zPr))
                            return [0, t4, 60];
                          if (!n0(A0, KPr))
                            return [0, t4, 36];
                          if (!n0(A0, WPr))
                            return [0, t4, 45];
                        } else {
                          if (!n0(A0, MPr))
                            return [0, t4, 64];
                          if (!n0(A0, BPr))
                            return [0, t4, 65];
                          if (!n0(A0, qPr))
                            return [0, t4, 32];
                          if (!n0(A0, UPr))
                            return [0, t4, 33];
                          if (!n0(A0, HPr))
                            return [0, t4, 34];
                          if (!n0(A0, XPr))
                            return [0, t4, 40];
                        }
                      }
                    }
                    var gr = [4, Y, A0, xL(y0)];
                    return [0, D0[1], gr];
                  case 98:
                    var mr = t4[4] ? Ru(t4, nt(t4, n), 6) : t4;
                    return [0, mr, Ln];
                  default:
                    var Cr = Ei(t4, nt(t4, n));
                    return [0, Cr, [6, Se(n)]];
                }
              switch (I) {
                case 0:
                  return [2, h7(t4, n)];
                case 1:
                  return [2, t4];
                case 2:
                  var sr = Lu(t4, n), Pr = Qn(Kn), K0 = j1(t4, Pr, n), Ur = K0[1];
                  return [1, Ur, Si(Ur, sr, K0[2], Pr, 1)];
                case 3:
                  var d0 = Se(n);
                  if (t4[5]) {
                    var Kr = t4[4] ? Jr0(t4, nt(t4, n), d0) : t4, re = Zm(1, Kr), xe = $m(n);
                    return Un(jl(n, xe - 1 | 0, 1), NPr) && n0(jl(n, xe - 2 | 0, 1), CPr) ? [0, re, 86] : [2, re];
                  }
                  var je = Lu(t4, n), le = Qn(Kn);
                  dn(le, m7(d0, 2, tn(d0) - 2 | 0));
                  var Ie = j1(t4, le, n), Me = Ie[1];
                  return [1, Me, Si(Me, je, Ie[2], le, 1)];
                case 4:
                  if (t4[4])
                    return [2, Zm(0, t4)];
                  $v(n), Tn(n);
                  var Be = Cr0(j(n)) !== 0 ? 1 : 0, an = Be && q(n);
                  return an === 0 ? [0, t4, Vt] : ke(PPr);
                case 5:
                  var Ke = Lu(t4, n), Ae = Qn(Kn), on = e2(t4, Ae, n), rn = on[1];
                  return [1, rn, Si(rn, Ke, on[2], Ae, 0)];
                case 6:
                  return n[6] === 0 ? [2, e2(t4, Qn(Kn), n)[1]] : [0, t4, DPr];
                case 7:
                  var kn = Se(n), sn = Lu(t4, n), Pe = Qn(Kn), We = Qn(Kn);
                  dn(We, kn);
                  var en = ne0(t4, kn, Pe, We, 0, n), _n = en[1], Dn = [0, _n[1], sn, en[2]], Xn = en[3], On = Bt(We);
                  return [0, _n, [2, [0, Dn, Bt(Pe), On, Xn]]];
                case 8:
                  var bt = Qn(Kn), Ct = Qn(Kn), Tt = Qn(Kn);
                  Gl(n, Tt);
                  var Zt = Lu(t4, n), Ut = te0(t4, bt, Ct, Tt, n), Ot = Ut[1], Pt = d7(Ot, n), yu = [0, Ot[1], Zt, Pt], Ku = Ut[2], pt = Bt(Tt), xu = Bt(Ct);
                  return [0, Ot, [3, [0, yu, [0, Bt(bt), xu, pt], Ku]]];
                case 9:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && s9(j(R0)) === 0 && Bc(j(R0)) === 0)
                      for (; ; ) {
                        var Re = t9(j(R0));
                        if (2 < Re >>> 0)
                          var _e = q(R0);
                        else
                          switch (Re) {
                            case 0:
                              continue;
                            case 1:
                              r:
                                for (; ; ) {
                                  if (Bc(j(R0)) === 0)
                                    for (; ; ) {
                                      var Xe = t9(j(R0));
                                      if (2 < Xe >>> 0)
                                        var he = q(R0);
                                      else
                                        switch (Xe) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            var he = 0;
                                        }
                                      break;
                                    }
                                  else
                                    var he = q(R0);
                                  var _e = he;
                                  break;
                                }
                              break;
                            default:
                              var _e = 0;
                          }
                        break;
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [1, 0, Se(R0)]] : ke(IPr);
                  });
                case 10:
                  return [0, t4, [1, 0, Se(n)]];
                case 11:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && s9(j(R0)) === 0 && Bc(j(R0)) === 0)
                      for (; ; ) {
                        B0(R0, 0);
                        var Re = n9(j(R0));
                        if (Re !== 0) {
                          if (Re === 1)
                            r:
                              for (; ; ) {
                                if (Bc(j(R0)) === 0)
                                  for (; ; ) {
                                    B0(R0, 0);
                                    var Xe = n9(j(R0));
                                    if (Xe !== 0) {
                                      if (Xe === 1)
                                        continue r;
                                      var he = q(R0);
                                      break;
                                    }
                                  }
                                else
                                  var he = q(R0);
                                var _e = he;
                                break;
                              }
                          else
                            var _e = q(R0);
                          break;
                        }
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [0, 0, Se(R0)]] : ke(OPr);
                  });
                case 12:
                  return [0, t4, [0, 0, Se(n)]];
                case 13:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && p9(j(R0)) === 0 && Vu(j(R0)) === 0)
                      for (; ; ) {
                        var Re = c9(j(R0));
                        if (2 < Re >>> 0)
                          var _e = q(R0);
                        else
                          switch (Re) {
                            case 0:
                              continue;
                            case 1:
                              r:
                                for (; ; ) {
                                  if (Vu(j(R0)) === 0)
                                    for (; ; ) {
                                      var Xe = c9(j(R0));
                                      if (2 < Xe >>> 0)
                                        var he = q(R0);
                                      else
                                        switch (Xe) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            var he = 0;
                                        }
                                      break;
                                    }
                                  else
                                    var he = q(R0);
                                  var _e = he;
                                  break;
                                }
                              break;
                            default:
                              var _e = 0;
                          }
                        break;
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [1, 1, Se(R0)]] : ke(TPr);
                  });
                case 14:
                  return [0, t4, [1, 1, Se(n)]];
                case 15:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && p9(j(R0)) === 0 && Vu(j(R0)) === 0)
                      for (; ; ) {
                        B0(R0, 0);
                        var Re = a9(j(R0));
                        if (Re !== 0) {
                          if (Re === 1)
                            r:
                              for (; ; ) {
                                if (Vu(j(R0)) === 0)
                                  for (; ; ) {
                                    B0(R0, 0);
                                    var Xe = a9(j(R0));
                                    if (Xe !== 0) {
                                      if (Xe === 1)
                                        continue r;
                                      var he = q(R0);
                                      break;
                                    }
                                  }
                                else
                                  var he = q(R0);
                                var _e = he;
                                break;
                              }
                          else
                            var _e = q(R0);
                          break;
                        }
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [0, 3, Se(R0)]] : ke(FPr);
                  });
                case 16:
                  return [0, t4, [0, 3, Se(n)]];
                case 17:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0)
                      for (; ; ) {
                        var Re = j(R0), Xe = 47 < Re ? 57 < Re ? -1 : Vr(wRr, Re + Wt | 0) - 1 | 0 : -1;
                        if (Xe !== 0) {
                          if (Xe === 1) {
                            for (; ; )
                              if (B0(R0, 0), pn(j(R0)) !== 0) {
                                var he = q(R0);
                                break;
                              }
                          } else
                            var he = q(R0);
                          break;
                        }
                      }
                    else
                      var he = q(R0);
                    return he === 0 ? [0, U0, [0, 2, Se(R0)]] : ke(gPr);
                  });
                case 18:
                  return [0, t4, [0, 2, Se(n)]];
                case 19:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && Vu(j(R0)) === 0) {
                      for (; ; )
                        if (B0(R0, 0), Vu(j(R0)) !== 0) {
                          var Re = q(R0);
                          break;
                        }
                    } else
                      var Re = q(R0);
                    return Re === 0 ? [0, U0, [0, 1, Se(R0)]] : ke(SPr);
                  });
                case 20:
                  return [0, t4, [0, 1, Se(n)]];
                case 21:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && Qm(j(R0)) === 0 && Pn(j(R0)) === 0)
                      for (; ; ) {
                        var Re = u9(j(R0));
                        if (2 < Re >>> 0)
                          var _e = q(R0);
                        else
                          switch (Re) {
                            case 0:
                              continue;
                            case 1:
                              r:
                                for (; ; ) {
                                  if (Pn(j(R0)) === 0)
                                    for (; ; ) {
                                      var Xe = u9(j(R0));
                                      if (2 < Xe >>> 0)
                                        var he = q(R0);
                                      else
                                        switch (Xe) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            var he = 0;
                                        }
                                      break;
                                    }
                                  else
                                    var he = q(R0);
                                  var _e = he;
                                  break;
                                }
                              break;
                            default:
                              var _e = 0;
                          }
                        break;
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [1, 2, Se(R0)]] : ke(EPr);
                  });
                case 23:
                  return jt(t4, n, function(U0, R0) {
                    if (Tn(R0), Ls(j(R0)) === 0 && Qm(j(R0)) === 0 && Pn(j(R0)) === 0)
                      for (; ; ) {
                        B0(R0, 0);
                        var Re = y9(j(R0));
                        if (Re !== 0) {
                          if (Re === 1)
                            r:
                              for (; ; ) {
                                if (Pn(j(R0)) === 0)
                                  for (; ; ) {
                                    B0(R0, 0);
                                    var Xe = y9(j(R0));
                                    if (Xe !== 0) {
                                      if (Xe === 1)
                                        continue r;
                                      var he = q(R0);
                                      break;
                                    }
                                  }
                                else
                                  var he = q(R0);
                                var _e = he;
                                break;
                              }
                          else
                            var _e = q(R0);
                          break;
                        }
                      }
                    else
                      var _e = q(R0);
                    return _e === 0 ? [0, U0, [0, 4, Se(R0)]] : ke(wPr);
                  });
                case 25:
                  return jt(t4, n, function(U0, R0) {
                    function Re(vn) {
                      for (; ; ) {
                        var ut = wi(j(vn));
                        if (2 < ut >>> 0)
                          return q(vn);
                        switch (ut) {
                          case 0:
                            continue;
                          case 1:
                            r:
                              for (; ; ) {
                                if (pn(j(vn)) === 0)
                                  for (; ; ) {
                                    var It = wi(j(vn));
                                    if (2 < It >>> 0)
                                      return q(vn);
                                    switch (It) {
                                      case 0:
                                        continue;
                                      case 1:
                                        continue r;
                                      default:
                                        return 0;
                                    }
                                  }
                                return q(vn);
                              }
                          default:
                            return 0;
                        }
                      }
                    }
                    function Xe(vn) {
                      for (; ; ) {
                        var ut = r2(j(vn));
                        if (ut !== 0) {
                          var It = ut !== 1 ? 1 : 0;
                          return It && q(vn);
                        }
                      }
                    }
                    function he(vn) {
                      var ut = S9(j(vn));
                      if (2 < ut >>> 0)
                        return q(vn);
                      switch (ut) {
                        case 0:
                          var It = P1(j(vn));
                          return It === 0 ? Xe(vn) : It === 1 ? Re(vn) : q(vn);
                        case 1:
                          return Xe(vn);
                        default:
                          return Re(vn);
                      }
                    }
                    function _e(vn) {
                      var ut = m9(j(vn));
                      if (ut === 0)
                        for (; ; ) {
                          var It = i7(j(vn));
                          if (2 < It >>> 0)
                            return q(vn);
                          switch (It) {
                            case 0:
                              continue;
                            case 1:
                              return he(vn);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(vn)) === 0)
                                    for (; ; ) {
                                      var Ti = i7(j(vn));
                                      if (2 < Ti >>> 0)
                                        return q(vn);
                                      switch (Ti) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return he(vn);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(vn);
                                }
                          }
                        }
                      return ut === 1 ? he(vn) : q(vn);
                    }
                    Tn(R0);
                    var rt = r9(j(R0));
                    if (2 < rt >>> 0)
                      var wn = q(R0);
                    else
                      switch (rt) {
                        case 0:
                          if (pn(j(R0)) === 0)
                            for (; ; ) {
                              var ft = i7(j(R0));
                              if (2 < ft >>> 0)
                                var wn = q(R0);
                              else
                                switch (ft) {
                                  case 0:
                                    continue;
                                  case 1:
                                    var wn = he(R0);
                                    break;
                                  default:
                                    r:
                                      for (; ; ) {
                                        if (pn(j(R0)) === 0)
                                          for (; ; ) {
                                            var xt = i7(j(R0));
                                            if (2 < xt >>> 0)
                                              var Gn = q(R0);
                                            else
                                              switch (xt) {
                                                case 0:
                                                  continue;
                                                case 1:
                                                  var Gn = he(R0);
                                                  break;
                                                default:
                                                  continue r;
                                              }
                                            break;
                                          }
                                        else
                                          var Gn = q(R0);
                                        var wn = Gn;
                                        break;
                                      }
                                }
                              break;
                            }
                          else
                            var wn = q(R0);
                          break;
                        case 1:
                          var tt = e9(j(R0)), wn = tt === 0 ? _e(R0) : tt === 1 ? he(R0) : q(R0);
                          break;
                        default:
                          for (; ; ) {
                            var wt = b9(j(R0));
                            if (2 < wt >>> 0)
                              var wn = q(R0);
                            else
                              switch (wt) {
                                case 0:
                                  var wn = _e(R0);
                                  break;
                                case 1:
                                  continue;
                                default:
                                  var wn = he(R0);
                              }
                            break;
                          }
                      }
                    if (wn === 0) {
                      var un = Ru(U0, nt(U0, R0), 23);
                      return [0, un, [1, 2, Se(R0)]];
                    }
                    return ke(kPr);
                  });
                case 26:
                  var Gu = Ru(t4, nt(t4, n), 23);
                  return [0, Gu, [1, 2, Se(n)]];
                case 27:
                  return jt(t4, n, function(U0, R0) {
                    function Re(un) {
                      for (; ; ) {
                        B0(un, 0);
                        var vn = js(j(un));
                        if (vn !== 0) {
                          if (vn === 1)
                            r:
                              for (; ; ) {
                                if (pn(j(un)) === 0)
                                  for (; ; ) {
                                    B0(un, 0);
                                    var ut = js(j(un));
                                    if (ut !== 0) {
                                      if (ut === 1)
                                        continue r;
                                      return q(un);
                                    }
                                  }
                                return q(un);
                              }
                          return q(un);
                        }
                      }
                    }
                    function Xe(un) {
                      for (; ; )
                        if (B0(un, 0), pn(j(un)) !== 0)
                          return q(un);
                    }
                    function he(un) {
                      var vn = S9(j(un));
                      if (2 < vn >>> 0)
                        return q(un);
                      switch (vn) {
                        case 0:
                          var ut = P1(j(un));
                          return ut === 0 ? Xe(un) : ut === 1 ? Re(un) : q(un);
                        case 1:
                          return Xe(un);
                        default:
                          return Re(un);
                      }
                    }
                    function _e(un) {
                      var vn = m9(j(un));
                      if (vn === 0)
                        for (; ; ) {
                          var ut = i7(j(un));
                          if (2 < ut >>> 0)
                            return q(un);
                          switch (ut) {
                            case 0:
                              continue;
                            case 1:
                              return he(un);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(un)) === 0)
                                    for (; ; ) {
                                      var It = i7(j(un));
                                      if (2 < It >>> 0)
                                        return q(un);
                                      switch (It) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return he(un);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(un);
                                }
                          }
                        }
                      return vn === 1 ? he(un) : q(un);
                    }
                    Tn(R0);
                    var rt = r9(j(R0));
                    if (2 < rt >>> 0)
                      var wn = q(R0);
                    else
                      switch (rt) {
                        case 0:
                          if (pn(j(R0)) === 0)
                            for (; ; ) {
                              var ft = i7(j(R0));
                              if (2 < ft >>> 0)
                                var wn = q(R0);
                              else
                                switch (ft) {
                                  case 0:
                                    continue;
                                  case 1:
                                    var wn = he(R0);
                                    break;
                                  default:
                                    r:
                                      for (; ; ) {
                                        if (pn(j(R0)) === 0)
                                          for (; ; ) {
                                            var xt = i7(j(R0));
                                            if (2 < xt >>> 0)
                                              var Gn = q(R0);
                                            else
                                              switch (xt) {
                                                case 0:
                                                  continue;
                                                case 1:
                                                  var Gn = he(R0);
                                                  break;
                                                default:
                                                  continue r;
                                              }
                                            break;
                                          }
                                        else
                                          var Gn = q(R0);
                                        var wn = Gn;
                                        break;
                                      }
                                }
                              break;
                            }
                          else
                            var wn = q(R0);
                          break;
                        case 1:
                          var tt = e9(j(R0)), wn = tt === 0 ? _e(R0) : tt === 1 ? he(R0) : q(R0);
                          break;
                        default:
                          for (; ; ) {
                            var wt = b9(j(R0));
                            if (2 < wt >>> 0)
                              var wn = q(R0);
                            else
                              switch (wt) {
                                case 0:
                                  var wn = _e(R0);
                                  break;
                                case 1:
                                  continue;
                                default:
                                  var wn = he(R0);
                              }
                            break;
                          }
                      }
                    return wn === 0 ? [0, U0, [0, 4, Se(R0)]] : ke(hPr);
                  });
                case 29:
                  return jt(t4, n, function(U0, R0) {
                    function Re(tt) {
                      for (; ; ) {
                        var wt = wi(j(tt));
                        if (2 < wt >>> 0)
                          return q(tt);
                        switch (wt) {
                          case 0:
                            continue;
                          case 1:
                            r:
                              for (; ; ) {
                                if (pn(j(tt)) === 0)
                                  for (; ; ) {
                                    var un = wi(j(tt));
                                    if (2 < un >>> 0)
                                      return q(tt);
                                    switch (un) {
                                      case 0:
                                        continue;
                                      case 1:
                                        continue r;
                                      default:
                                        return 0;
                                    }
                                  }
                                return q(tt);
                              }
                          default:
                            return 0;
                        }
                      }
                    }
                    function Xe(tt) {
                      var wt = r2(j(tt));
                      if (wt === 0)
                        return Re(tt);
                      var un = wt !== 1 ? 1 : 0;
                      return un && q(tt);
                    }
                    Tn(R0);
                    var he = r9(j(R0));
                    if (2 < he >>> 0)
                      var _e = q(R0);
                    else
                      switch (he) {
                        case 0:
                          var _e = pn(j(R0)) === 0 ? Re(R0) : q(R0);
                          break;
                        case 1:
                          for (; ; ) {
                            var rt = L1(j(R0));
                            if (rt === 0)
                              var _e = Xe(R0);
                            else {
                              if (rt === 1)
                                continue;
                              var _e = q(R0);
                            }
                            break;
                          }
                          break;
                        default:
                          for (; ; ) {
                            var wn = Uc(j(R0));
                            if (2 < wn >>> 0)
                              var _e = q(R0);
                            else
                              switch (wn) {
                                case 0:
                                  var _e = Xe(R0);
                                  break;
                                case 1:
                                  continue;
                                default:
                                  r:
                                    for (; ; ) {
                                      if (pn(j(R0)) === 0)
                                        for (; ; ) {
                                          var ft = Uc(j(R0));
                                          if (2 < ft >>> 0)
                                            var xt = q(R0);
                                          else
                                            switch (ft) {
                                              case 0:
                                                var xt = Xe(R0);
                                                break;
                                              case 1:
                                                continue;
                                              default:
                                                continue r;
                                            }
                                          break;
                                        }
                                      else
                                        var xt = q(R0);
                                      var _e = xt;
                                      break;
                                    }
                              }
                            break;
                          }
                      }
                    if (_e === 0) {
                      var Gn = Ru(U0, nt(U0, R0), 22);
                      return [0, Gn, [1, 2, Se(R0)]];
                    }
                    return ke(dPr);
                  });
                case 30:
                  return jt(t4, n, function(U0, R0) {
                    Tn(R0);
                    var Re = P1(j(R0));
                    if (Re === 0)
                      for (; ; ) {
                        var Xe = r2(j(R0));
                        if (Xe !== 0) {
                          var he = Xe !== 1 ? 1 : 0, ft = he && q(R0);
                          break;
                        }
                      }
                    else if (Re === 1)
                      for (; ; ) {
                        var _e = wi(j(R0));
                        if (2 < _e >>> 0)
                          var ft = q(R0);
                        else
                          switch (_e) {
                            case 0:
                              continue;
                            case 1:
                              r:
                                for (; ; ) {
                                  if (pn(j(R0)) === 0)
                                    for (; ; ) {
                                      var rt = wi(j(R0));
                                      if (2 < rt >>> 0)
                                        var wn = q(R0);
                                      else
                                        switch (rt) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            var wn = 0;
                                        }
                                      break;
                                    }
                                  else
                                    var wn = q(R0);
                                  var ft = wn;
                                  break;
                                }
                              break;
                            default:
                              var ft = 0;
                          }
                        break;
                      }
                    else
                      var ft = q(R0);
                    return ft === 0 ? [0, U0, [1, 2, Se(R0)]] : ke(yPr);
                  });
                case 31:
                  var K7 = Ru(t4, nt(t4, n), 22);
                  return [0, K7, [1, 2, Se(n)]];
                case 33:
                  return jt(t4, n, function(U0, R0) {
                    function Re(Gn) {
                      for (; ; ) {
                        B0(Gn, 0);
                        var tt = js(j(Gn));
                        if (tt !== 0) {
                          if (tt === 1)
                            r:
                              for (; ; ) {
                                if (pn(j(Gn)) === 0)
                                  for (; ; ) {
                                    B0(Gn, 0);
                                    var wt = js(j(Gn));
                                    if (wt !== 0) {
                                      if (wt === 1)
                                        continue r;
                                      return q(Gn);
                                    }
                                  }
                                return q(Gn);
                              }
                          return q(Gn);
                        }
                      }
                    }
                    function Xe(Gn) {
                      return B0(Gn, 0), pn(j(Gn)) === 0 ? Re(Gn) : q(Gn);
                    }
                    Tn(R0);
                    var he = r9(j(R0));
                    if (2 < he >>> 0)
                      var _e = q(R0);
                    else
                      switch (he) {
                        case 0:
                          var _e = pn(j(R0)) === 0 ? Re(R0) : q(R0);
                          break;
                        case 1:
                          for (; ; ) {
                            B0(R0, 0);
                            var rt = L1(j(R0));
                            if (rt === 0)
                              var _e = Xe(R0);
                            else {
                              if (rt === 1)
                                continue;
                              var _e = q(R0);
                            }
                            break;
                          }
                          break;
                        default:
                          for (; ; ) {
                            B0(R0, 0);
                            var wn = Uc(j(R0));
                            if (2 < wn >>> 0)
                              var _e = q(R0);
                            else
                              switch (wn) {
                                case 0:
                                  var _e = Xe(R0);
                                  break;
                                case 1:
                                  continue;
                                default:
                                  r:
                                    for (; ; ) {
                                      if (pn(j(R0)) === 0)
                                        for (; ; ) {
                                          B0(R0, 0);
                                          var ft = Uc(j(R0));
                                          if (2 < ft >>> 0)
                                            var xt = q(R0);
                                          else
                                            switch (ft) {
                                              case 0:
                                                var xt = Xe(R0);
                                                break;
                                              case 1:
                                                continue;
                                              default:
                                                continue r;
                                            }
                                          break;
                                        }
                                      else
                                        var xt = q(R0);
                                      var _e = xt;
                                      break;
                                    }
                              }
                            break;
                          }
                      }
                    return _e === 0 ? [0, U0, [0, 4, Se(R0)]] : ke(_Pr);
                  });
                case 35:
                  var Vi = nt(t4, n), a7 = Se(n);
                  return [0, t4, [4, Vi, a7, a7]];
                case 36:
                  return [0, t4, 0];
                case 37:
                  return [0, t4, 1];
                case 38:
                  return [0, t4, 4];
                case 39:
                  return [0, t4, 5];
                case 40:
                  return [0, t4, 6];
                case 41:
                  return [0, t4, 7];
                case 42:
                  return [0, t4, 12];
                case 43:
                  return [0, t4, 10];
                case 44:
                  return [0, t4, 8];
                case 45:
                  return [0, t4, 9];
                case 46:
                  return [0, t4, 86];
                case 47:
                  $v(n), Tn(n);
                  var Yc = j(n), W7 = 62 < Yc ? 63 < Yc ? -1 : 0 : -1, Ht = W7 !== 0 ? 1 : 0, mt = Ht && q(n);
                  return mt === 0 ? [0, t4, 85] : ke(LPr);
                case 48:
                  return [0, t4, 83];
                case 49:
                  return [0, t4, 84];
                case 22:
                case 32:
                  return [0, t4, [1, 2, Se(n)]];
                default:
                  return [0, t4, [0, 4, Se(n)]];
              }
            }
            function Zee(t4, n) {
              Tn(n);
              var e = j(n), i = tf < e ? Sa < e ? qo < e ? La < e ? 1 : 2 : ea < e ? 1 : 2 : ya < e ? oc < e ? cx < e ? 1 : 2 : aa < e ? 1 : 2 : Ju < e ? Uu < e ? 1 : 3 : Pa < e ? 1 : 2 : Vr(KLr, e + 1 | 0) - 1 | 0;
              if (5 < i >>> 0)
                var x = q(n);
              else
                switch (i) {
                  case 0:
                    var x = 0;
                    break;
                  case 1:
                    var x = 6;
                    break;
                  case 2:
                    if (B0(n, 2), Mc(j(n)) === 0) {
                      for (; ; )
                        if (B0(n, 2), Mc(j(n)) !== 0) {
                          var x = q(n);
                          break;
                        }
                    } else
                      var x = q(n);
                    break;
                  case 3:
                    var x = 1;
                    break;
                  case 4:
                    B0(n, 1);
                    var x = xi(j(n)) === 0 ? 1 : q(n);
                    break;
                  default:
                    B0(n, 5);
                    var c = k9(j(n)), x = c === 0 ? 4 : c === 1 ? 3 : q(n);
                }
              if (6 < x >>> 0)
                return ke(mPr);
              switch (x) {
                case 0:
                  return [0, t4, Ln];
                case 1:
                  return [2, h7(t4, n)];
                case 2:
                  return [2, t4];
                case 3:
                  var s = Lu(t4, n), p = Qn(Kn), y = e2(t4, p, n), T = y[1];
                  return [1, T, Si(T, s, y[2], p, 0)];
                case 4:
                  var E = Lu(t4, n), h = Qn(Kn), w = j1(t4, h, n), G = w[1];
                  return [1, G, Si(G, E, w[2], h, 1)];
                case 5:
                  var A = Lu(t4, n), S = Qn(Kn), M = t4;
                  r:
                    for (; ; ) {
                      Tn(n);
                      var K = j(n), V = 92 < K ? Uu < K ? 1 : Ju < K ? 2 : 1 : Vr(nRr, K + 1 | 0) - 1 | 0;
                      if (6 < V >>> 0)
                        var f0 = q(n);
                      else
                        switch (V) {
                          case 0:
                            var f0 = 0;
                            break;
                          case 1:
                            for (; ; ) {
                              B0(n, 7);
                              var m0 = j(n);
                              if (-1 < m0)
                                if (90 < m0)
                                  if (92 < m0)
                                    if (Ju < m0)
                                      var k0 = m0 <= Uu ? 1 : 0, g0 = k0 && -1;
                                    else
                                      var g0 = 0;
                                  else
                                    var g0 = -1;
                                else
                                  var g0 = Vr(ORr, m0) - 1 | 0;
                              else
                                var g0 = -1;
                              if (g0 !== 0) {
                                var f0 = q(n);
                                break;
                              }
                            }
                            break;
                          case 2:
                            var f0 = 6;
                            break;
                          case 3:
                            B0(n, 6);
                            var f0 = xi(j(n)) === 0 ? 6 : q(n);
                            break;
                          case 4:
                            if (B0(n, 4), Ir0(j(n)) === 0) {
                              for (; ; )
                                if (B0(n, 3), Ir0(j(n)) !== 0) {
                                  var f0 = q(n);
                                  break;
                                }
                            } else
                              var f0 = q(n);
                            break;
                          case 5:
                            var f0 = 5;
                            break;
                          default:
                            B0(n, 7);
                            var e0 = j(n);
                            if (-1 < e0)
                              if (13 < e0)
                                var x0 = e0 <= Uu ? 1 : 0, l = x0 && (Ju < e0 ? 1 : 0);
                              else
                                var l = Vr(gLr, e0) - 1 | 0;
                            else
                              var l = -1;
                            if (2 < l >>> 0)
                              var f0 = q(n);
                            else
                              switch (l) {
                                case 0:
                                  var f0 = 2;
                                  break;
                                case 1:
                                  var f0 = 1;
                                  break;
                                default:
                                  B0(n, 1);
                                  var f0 = xi(j(n)) === 0 ? 1 : q(n);
                              }
                        }
                      if (7 < f0 >>> 0)
                        var c0 = ke(Xwr);
                      else
                        switch (f0) {
                          case 0:
                            var c0 = [0, Ru(M, nt(M, n), 25), Ywr];
                            break;
                          case 1:
                            var c0 = [0, h7(Ru(M, nt(M, n), 25), n), Vwr];
                            break;
                          case 3:
                            var t0 = Se(n), c0 = [0, M, m7(t0, 1, tn(t0) - 1 | 0)];
                            break;
                          case 4:
                            var c0 = [0, M, zwr];
                            break;
                          case 5:
                            for (Ui(S, 91); ; ) {
                              Tn(n);
                              var a0 = j(n), w0 = 93 < a0 ? 1 : Vr(FLr, a0 + 1 | 0) - 1 | 0;
                              if (3 < w0 >>> 0)
                                var _0 = q(n);
                              else
                                switch (w0) {
                                  case 0:
                                    var _0 = 0;
                                    break;
                                  case 1:
                                    for (; ; ) {
                                      B0(n, 4);
                                      var E0 = j(n);
                                      if (-1 < E0)
                                        if (91 < E0)
                                          var X0 = E0 <= 93 ? 1 : 0, b = X0 && -1;
                                        else
                                          var b = 0;
                                      else
                                        var b = -1;
                                      if (b !== 0) {
                                        var _0 = q(n);
                                        break;
                                      }
                                    }
                                    break;
                                  case 2:
                                    B0(n, 4);
                                    var G0 = j(n), X = 91 < G0 ? 93 < G0 ? -1 : Vr(tN, G0 - 92 | 0) - 1 | 0 : -1, _0 = X === 0 ? 1 : X === 1 ? 2 : q(n);
                                    break;
                                  default:
                                    var _0 = 3;
                                }
                              if (4 < _0 >>> 0)
                                var s0 = ke(Uwr);
                              else
                                switch (_0) {
                                  case 0:
                                    var s0 = M;
                                    break;
                                  case 1:
                                    dn(S, Hwr);
                                    continue;
                                  case 2:
                                    Ui(S, 92), Ui(S, 93);
                                    continue;
                                  case 3:
                                    Ui(S, 93);
                                    var s0 = M;
                                    break;
                                  default:
                                    dn(S, Se(n));
                                    continue;
                                }
                              var M = s0;
                              continue r;
                            }
                          case 6:
                            var c0 = [0, h7(Ru(M, nt(M, n), 25), n), Kwr];
                            break;
                          default:
                            dn(S, Se(n));
                            continue;
                        }
                      var dr = c0[1], Ar = d7(dr, n), ar = [0, dr[1], A, Ar], W0 = c0[2];
                      return [0, dr, [5, ar, Bt(S), W0]];
                    }
                default:
                  var Lr = Ei(t4, nt(t4, n));
                  return [0, Lr, [6, Se(n)]];
              }
            }
            function yL(t4, n, e, i, x) {
              for (var c = t4; ; ) {
                var s = function(Dn) {
                  for (; ; )
                    if (B0(Dn, 6), Nr0(j(Dn)) !== 0)
                      return q(Dn);
                };
                Tn(x);
                var p = j(x), y = br < p ? Uu < p ? 1 : Ju < p ? 2 : 1 : Vr(_Lr, p + 1 | 0) - 1 | 0;
                if (6 < y >>> 0)
                  var T = q(x);
                else
                  switch (y) {
                    case 0:
                      var T = 1;
                      break;
                    case 1:
                      var T = s(x);
                      break;
                    case 2:
                      var T = 2;
                      break;
                    case 3:
                      B0(x, 2);
                      var T = xi(j(x)) === 0 ? 2 : q(x);
                      break;
                    case 4:
                      var T = 0;
                      break;
                    case 5:
                      B0(x, 6);
                      var E = j(x), h = 34 < E ? Nn < E ? -1 : Vr(lRr, E - 35 | 0) - 1 | 0 : -1;
                      if (h === 0) {
                        var w = j(x), G = 47 < w ? fc < w ? -1 : Vr(ERr, w + Wt | 0) - 1 | 0 : -1;
                        if (G === 0)
                          for (; ; ) {
                            var A = j(x), S = 47 < A ? 59 < A ? -1 : Vr(ELr, A + Wt | 0) - 1 | 0 : -1;
                            if (S !== 0) {
                              var T = S === 1 ? 4 : q(x);
                              break;
                            }
                          }
                        else if (G === 1 && Pn(j(x)) === 0)
                          for (; ; ) {
                            var M = j(x), K = 47 < M ? ji < M ? -1 : Vr(yRr, M + Wt | 0) - 1 | 0 : -1;
                            if (K !== 0) {
                              var T = K === 1 ? 3 : q(x);
                              break;
                            }
                          }
                        else
                          var T = q(x);
                      } else if (h === 1 && hn(j(x)) === 0) {
                        var V = Zv(j(x));
                        if (V === 0) {
                          var f0 = Zv(j(x));
                          if (f0 === 0) {
                            var m0 = Zv(j(x));
                            if (m0 === 0) {
                              var k0 = Zv(j(x));
                              if (k0 === 0) {
                                var g0 = Zv(j(x));
                                if (g0 === 0) {
                                  var e0 = Zv(j(x));
                                  if (e0 === 0)
                                    var x0 = j(x), l = 58 < x0 ? 59 < x0 ? -1 : 0 : -1, T = l === 0 ? 5 : q(x);
                                  else
                                    var T = e0 === 1 ? 5 : q(x);
                                } else
                                  var T = g0 === 1 ? 5 : q(x);
                              } else
                                var T = k0 === 1 ? 5 : q(x);
                            } else
                              var T = m0 === 1 ? 5 : q(x);
                          } else
                            var T = f0 === 1 ? 5 : q(x);
                        } else
                          var T = V === 1 ? 5 : q(x);
                      } else
                        var T = q(x);
                      break;
                    default:
                      B0(x, 0);
                      var T = Nr0(j(x)) === 0 ? s(x) : q(x);
                  }
                if (6 < T >>> 0)
                  return ke(Wwr);
                switch (T) {
                  case 0:
                    var c0 = Se(x), t0 = 0;
                    switch (n) {
                      case 0:
                        n0(c0, Jwr) || (t0 = 1);
                        break;
                      case 1:
                        n0(c0, $wr) || (t0 = 1);
                        break;
                      default:
                        var a0 = 0;
                        if (n0(c0, Zwr)) {
                          if (!n0(c0, Qwr))
                            return _L(c, nt(c, x), iEr, uEr);
                          if (n0(c0, rEr)) {
                            if (!n0(c0, eEr))
                              return _L(c, nt(c, x), tEr, nEr);
                            a0 = 1;
                          }
                        }
                        if (!a0)
                          return $v(x), c;
                    }
                    if (t0)
                      return c;
                    dn(i, c0), dn(e, c0);
                    continue;
                  case 1:
                    return Ei(c, nt(c, x));
                  case 2:
                    var w0 = Se(x);
                    dn(i, w0), dn(e, w0);
                    var c = h7(c, x);
                    continue;
                  case 3:
                    var _0 = Se(x), E0 = m7(_0, 3, tn(_0) - 4 | 0);
                    dn(i, _0), g1(e, qi(Te(fEr, E0)));
                    continue;
                  case 4:
                    var X0 = Se(x), b = m7(X0, 2, tn(X0) - 3 | 0);
                    dn(i, X0), g1(e, qi(b));
                    continue;
                  case 5:
                    var G0 = Se(x), X = m7(G0, 1, tn(G0) - 2 | 0);
                    dn(i, G0);
                    var s0 = Ee(X, xEr), dr = 0;
                    if (0 <= s0)
                      if (0 < s0) {
                        var Ar = Ee(X, XTr), ar = 0;
                        if (0 <= Ar)
                          if (0 < Ar) {
                            var W0 = Ee(X, oAr), Lr = 0;
                            if (0 <= W0)
                              if (0 < W0) {
                                var Tr = Ee(X, yNr), Hr = 0;
                                if (0 <= Tr)
                                  if (0 < Tr) {
                                    var Or = Ee(X, WNr), xr = 0;
                                    if (0 <= Or)
                                      if (0 < Or)
                                        if (n0(X, cCr))
                                          if (n0(X, sCr))
                                            if (n0(X, vCr))
                                              if (n0(X, lCr))
                                                if (n0(X, bCr))
                                                  if (n0(X, pCr))
                                                    ar = 1, Lr = 1, Hr = 1, xr = 1;
                                                  else
                                                    var Rr = mCr;
                                                else
                                                  var Rr = _Cr;
                                              else
                                                var Rr = yCr;
                                            else
                                              var Rr = dCr;
                                          else
                                            var Rr = hCr;
                                        else
                                          var Rr = kCr;
                                      else
                                        var Rr = wCr;
                                    else if (n0(X, JNr))
                                      if (n0(X, $Nr))
                                        if (n0(X, ZNr))
                                          if (n0(X, QNr))
                                            if (n0(X, rCr))
                                              if (n0(X, eCr))
                                                if (n0(X, nCr))
                                                  ar = 1, Lr = 1, Hr = 1, xr = 1;
                                                else
                                                  var Rr = tCr;
                                              else
                                                var Rr = uCr;
                                            else
                                              var Rr = iCr;
                                          else
                                            var Rr = fCr;
                                        else
                                          var Rr = xCr;
                                      else
                                        var Rr = aCr;
                                    else
                                      var Rr = oCr;
                                    if (!xr)
                                      var Wr = Rr;
                                  } else
                                    var Wr = ECr;
                                else {
                                  var Jr = Ee(X, dNr), or = 0;
                                  if (0 <= Jr)
                                    if (0 < Jr)
                                      if (n0(X, DNr))
                                        if (n0(X, LNr))
                                          if (n0(X, RNr))
                                            if (n0(X, jNr))
                                              if (n0(X, GNr))
                                                if (n0(X, MNr))
                                                  if (n0(X, BNr))
                                                    ar = 1, Lr = 1, Hr = 1, or = 1;
                                                  else
                                                    var _r = qNr;
                                                else
                                                  var _r = UNr;
                                              else
                                                var _r = HNr;
                                            else
                                              var _r = XNr;
                                          else
                                            var _r = YNr;
                                        else
                                          var _r = VNr;
                                      else
                                        var _r = zNr;
                                    else
                                      var _r = KNr;
                                  else if (n0(X, hNr))
                                    if (n0(X, kNr))
                                      if (n0(X, wNr))
                                        if (n0(X, ENr))
                                          if (n0(X, SNr))
                                            if (n0(X, gNr))
                                              if (n0(X, FNr))
                                                ar = 1, Lr = 1, Hr = 1, or = 1;
                                              else
                                                var _r = TNr;
                                            else
                                              var _r = ONr;
                                          else
                                            var _r = INr;
                                        else
                                          var _r = ANr;
                                      else
                                        var _r = NNr;
                                    else
                                      var _r = CNr;
                                  else
                                    var _r = PNr;
                                  if (!or)
                                    var Wr = _r;
                                }
                                if (!Hr)
                                  var Ir = Wr;
                              } else
                                var Ir = SCr;
                            else {
                              var fe = Ee(X, cAr), v0 = 0;
                              if (0 <= fe)
                                if (0 < fe) {
                                  var P = Ee(X, qAr), L = 0;
                                  if (0 <= P)
                                    if (0 < P)
                                      if (n0(X, nNr))
                                        if (n0(X, tNr))
                                          if (n0(X, uNr))
                                            if (n0(X, iNr))
                                              if (n0(X, fNr))
                                                if (n0(X, xNr))
                                                  if (n0(X, aNr))
                                                    ar = 1, Lr = 1, v0 = 1, L = 1;
                                                  else
                                                    var Q = oNr;
                                                else
                                                  var Q = cNr;
                                              else
                                                var Q = sNr;
                                            else
                                              var Q = vNr;
                                          else
                                            var Q = lNr;
                                        else
                                          var Q = bNr;
                                      else
                                        var Q = pNr;
                                    else
                                      var Q = mNr;
                                  else if (n0(X, UAr))
                                    if (n0(X, HAr))
                                      if (n0(X, XAr))
                                        if (n0(X, YAr))
                                          if (n0(X, VAr))
                                            if (n0(X, zAr))
                                              if (n0(X, KAr))
                                                ar = 1, Lr = 1, v0 = 1, L = 1;
                                              else
                                                var Q = WAr;
                                            else
                                              var Q = JAr;
                                          else
                                            var Q = $Ar;
                                        else
                                          var Q = ZAr;
                                      else
                                        var Q = QAr;
                                    else
                                      var Q = rNr;
                                  else
                                    var Q = eNr;
                                  if (!L)
                                    var i0 = Q;
                                } else
                                  var i0 = _Nr;
                              else {
                                var l0 = Ee(X, sAr), S0 = 0;
                                if (0 <= l0)
                                  if (0 < l0)
                                    if (n0(X, FAr))
                                      if (n0(X, TAr))
                                        if (n0(X, OAr))
                                          if (n0(X, IAr))
                                            if (n0(X, AAr))
                                              if (n0(X, NAr))
                                                if (n0(X, CAr))
                                                  ar = 1, Lr = 1, v0 = 1, S0 = 1;
                                                else
                                                  var T0 = PAr;
                                              else
                                                var T0 = DAr;
                                            else
                                              var T0 = LAr;
                                          else
                                            var T0 = RAr;
                                        else
                                          var T0 = jAr;
                                      else
                                        var T0 = GAr;
                                    else
                                      var T0 = MAr;
                                  else
                                    var T0 = BAr;
                                else if (n0(X, vAr))
                                  if (n0(X, lAr))
                                    if (n0(X, bAr))
                                      if (n0(X, pAr))
                                        if (n0(X, mAr))
                                          if (n0(X, _Ar))
                                            if (n0(X, yAr))
                                              ar = 1, Lr = 1, v0 = 1, S0 = 1;
                                            else
                                              var T0 = dAr;
                                          else
                                            var T0 = hAr;
                                        else
                                          var T0 = kAr;
                                      else
                                        var T0 = wAr;
                                    else
                                      var T0 = EAr;
                                  else
                                    var T0 = SAr;
                                else
                                  var T0 = gAr;
                                if (!S0)
                                  var i0 = T0;
                              }
                              if (!v0)
                                var Ir = i0;
                            }
                            if (!Lr)
                              var er = Ir;
                          } else
                            var er = gCr;
                        else {
                          var j0 = Ee(X, YTr), B = 0;
                          if (0 <= j0)
                            if (0 < j0) {
                              var Z = Ee(X, rIr), p0 = 0;
                              if (0 <= Z)
                                if (0 < Z) {
                                  var b0 = Ee(X, NIr), O0 = 0;
                                  if (0 <= b0)
                                    if (0 < b0)
                                      if (n0(X, VIr))
                                        if (n0(X, zIr))
                                          if (n0(X, KIr))
                                            if (n0(X, WIr))
                                              if (n0(X, JIr))
                                                if (n0(X, $Ir))
                                                  if (n0(X, ZIr))
                                                    ar = 1, B = 1, p0 = 1, O0 = 1;
                                                  else
                                                    var q0 = QIr;
                                                else
                                                  var q0 = rAr;
                                              else
                                                var q0 = eAr;
                                            else
                                              var q0 = nAr;
                                          else
                                            var q0 = tAr;
                                        else
                                          var q0 = uAr;
                                      else
                                        var q0 = iAr;
                                    else
                                      var q0 = fAr;
                                  else if (n0(X, CIr))
                                    if (n0(X, PIr))
                                      if (n0(X, DIr))
                                        if (n0(X, LIr))
                                          if (n0(X, RIr))
                                            if (n0(X, jIr))
                                              if (n0(X, GIr))
                                                ar = 1, B = 1, p0 = 1, O0 = 1;
                                              else
                                                var q0 = MIr;
                                            else
                                              var q0 = BIr;
                                          else
                                            var q0 = qIr;
                                        else
                                          var q0 = UIr;
                                      else
                                        var q0 = HIr;
                                    else
                                      var q0 = XIr;
                                  else
                                    var q0 = YIr;
                                  if (!O0)
                                    var nr = q0;
                                } else
                                  var nr = xAr;
                              else {
                                var yr = Ee(X, eIr), vr = 0;
                                if (0 <= yr)
                                  if (0 < yr)
                                    if (n0(X, mIr))
                                      if (n0(X, _Ir))
                                        if (n0(X, yIr))
                                          if (n0(X, dIr))
                                            if (n0(X, hIr))
                                              if (n0(X, kIr))
                                                if (n0(X, wIr))
                                                  ar = 1, B = 1, p0 = 1, vr = 1;
                                                else
                                                  var $0 = EIr;
                                              else
                                                var $0 = SIr;
                                            else
                                              var $0 = gIr;
                                          else
                                            var $0 = FIr;
                                        else
                                          var $0 = TIr;
                                      else
                                        var $0 = OIr;
                                    else
                                      var $0 = IIr;
                                  else
                                    var $0 = AIr;
                                else if (n0(X, nIr))
                                  if (n0(X, tIr))
                                    if (n0(X, uIr))
                                      if (n0(X, iIr))
                                        if (n0(X, fIr))
                                          if (n0(X, xIr))
                                            if (n0(X, aIr))
                                              ar = 1, B = 1, p0 = 1, vr = 1;
                                            else
                                              var $0 = oIr;
                                          else
                                            var $0 = cIr;
                                        else
                                          var $0 = sIr;
                                      else
                                        var $0 = vIr;
                                    else
                                      var $0 = lIr;
                                  else
                                    var $0 = bIr;
                                else
                                  var $0 = pIr;
                                if (!vr)
                                  var nr = $0;
                              }
                              if (!p0)
                                var Sr = nr;
                            } else
                              var Sr = aAr;
                          else {
                            var Mr = Ee(X, VTr), Br = 0;
                            if (0 <= Mr)
                              if (0 < Mr) {
                                var qr = Ee(X, EOr), jr = 0;
                                if (0 <= qr)
                                  if (0 < qr)
                                    if (n0(X, GOr))
                                      if (n0(X, MOr))
                                        if (n0(X, BOr))
                                          if (n0(X, qOr))
                                            if (n0(X, UOr))
                                              if (n0(X, HOr))
                                                if (n0(X, XOr))
                                                  ar = 1, B = 1, Br = 1, jr = 1;
                                                else
                                                  var $r = YOr;
                                              else
                                                var $r = VOr;
                                            else
                                              var $r = zOr;
                                          else
                                            var $r = KOr;
                                        else
                                          var $r = WOr;
                                      else
                                        var $r = JOr;
                                    else
                                      var $r = $Or;
                                  else
                                    var $r = ZOr;
                                else if (n0(X, SOr))
                                  if (n0(X, gOr))
                                    if (n0(X, FOr))
                                      if (n0(X, TOr))
                                        if (n0(X, OOr))
                                          if (n0(X, IOr))
                                            if (n0(X, AOr))
                                              ar = 1, B = 1, Br = 1, jr = 1;
                                            else
                                              var $r = NOr;
                                          else
                                            var $r = COr;
                                        else
                                          var $r = POr;
                                      else
                                        var $r = DOr;
                                    else
                                      var $r = LOr;
                                  else
                                    var $r = ROr;
                                else
                                  var $r = jOr;
                                if (!jr)
                                  var ne = $r;
                              } else
                                var ne = QOr;
                            else {
                              var Qr = Ee(X, zTr), pe = 0;
                              if (0 <= Qr)
                                if (0 < Qr)
                                  if (n0(X, aOr))
                                    if (n0(X, oOr))
                                      if (n0(X, cOr))
                                        if (n0(X, sOr))
                                          if (n0(X, vOr))
                                            if (n0(X, lOr))
                                              if (n0(X, bOr))
                                                ar = 1, B = 1, Br = 1, pe = 1;
                                              else
                                                var oe = pOr;
                                            else
                                              var oe = mOr;
                                          else
                                            var oe = _Or;
                                        else
                                          var oe = yOr;
                                      else
                                        var oe = dOr;
                                    else
                                      var oe = hOr;
                                  else
                                    var oe = kOr;
                                else
                                  var oe = wOr;
                              else if (n0(X, KTr))
                                if (n0(X, WTr))
                                  if (n0(X, JTr))
                                    if (n0(X, $Tr))
                                      if (n0(X, ZTr))
                                        if (n0(X, QTr))
                                          if (n0(X, rOr))
                                            ar = 1, B = 1, Br = 1, pe = 1;
                                          else
                                            var oe = eOr;
                                        else
                                          var oe = nOr;
                                      else
                                        var oe = tOr;
                                    else
                                      var oe = uOr;
                                  else
                                    var oe = iOr;
                                else
                                  var oe = fOr;
                              else
                                var oe = xOr;
                              if (!pe)
                                var ne = oe;
                            }
                            if (!Br)
                              var Sr = ne;
                          }
                          if (!B)
                            var er = Sr;
                        }
                        if (!ar) {
                          var me = er;
                          dr = 1;
                        }
                      } else {
                        var me = FCr;
                        dr = 1;
                      }
                    else {
                      var ae = Ee(X, aEr), ce = 0;
                      if (0 <= ae)
                        if (0 < ae) {
                          var ge = Ee(X, Tgr), H0 = 0;
                          if (0 <= ge)
                            if (0 < ge) {
                              var Fr = Ee(X, RFr), _ = 0;
                              if (0 <= Fr)
                                if (0 < Fr) {
                                  var k = Ee(X, lTr), I = 0;
                                  if (0 <= k)
                                    if (0 < k)
                                      if (n0(X, OTr))
                                        if (n0(X, ITr))
                                          if (n0(X, ATr))
                                            if (n0(X, NTr))
                                              if (n0(X, CTr))
                                                if (n0(X, PTr))
                                                  ce = 1, H0 = 1, _ = 1, I = 1;
                                                else
                                                  var U = DTr;
                                              else
                                                var U = LTr;
                                            else
                                              var U = RTr;
                                          else
                                            var U = jTr;
                                        else
                                          var U = GTr;
                                      else
                                        var U = MTr;
                                    else
                                      var U = BTr;
                                  else if (n0(X, bTr))
                                    if (n0(X, pTr))
                                      if (n0(X, mTr))
                                        if (n0(X, _Tr))
                                          if (n0(X, yTr))
                                            if (n0(X, dTr))
                                              if (n0(X, hTr))
                                                ce = 1, H0 = 1, _ = 1, I = 1;
                                              else
                                                var U = kTr;
                                            else
                                              var U = wTr;
                                          else
                                            var U = ETr;
                                        else
                                          var U = STr;
                                      else
                                        var U = gTr;
                                    else
                                      var U = FTr;
                                  else
                                    var U = TTr;
                                  if (!I)
                                    var Y = U;
                                } else
                                  var Y = qTr;
                              else {
                                var y0 = Ee(X, jFr), D0 = 0;
                                if (0 <= y0)
                                  if (0 < y0)
                                    if (n0(X, ZFr))
                                      if (n0(X, QFr))
                                        if (n0(X, rTr))
                                          if (n0(X, eTr))
                                            if (n0(X, nTr))
                                              if (n0(X, tTr))
                                                if (n0(X, uTr))
                                                  ce = 1, H0 = 1, _ = 1, D0 = 1;
                                                else
                                                  var A0 = iTr;
                                              else
                                                var A0 = fTr;
                                            else
                                              var A0 = xTr;
                                          else
                                            var A0 = aTr;
                                        else
                                          var A0 = oTr;
                                      else
                                        var A0 = cTr;
                                    else
                                      var A0 = sTr;
                                  else
                                    var A0 = vTr;
                                else if (n0(X, GFr))
                                  if (n0(X, MFr))
                                    if (n0(X, BFr))
                                      if (n0(X, qFr))
                                        if (n0(X, UFr))
                                          if (n0(X, HFr))
                                            if (n0(X, XFr))
                                              ce = 1, H0 = 1, _ = 1, D0 = 1;
                                            else
                                              var A0 = YFr;
                                          else
                                            var A0 = VFr;
                                        else
                                          var A0 = zFr;
                                      else
                                        var A0 = KFr;
                                    else
                                      var A0 = WFr;
                                  else
                                    var A0 = JFr;
                                else
                                  var A0 = $Fr;
                                if (!D0)
                                  var Y = A0;
                              }
                              if (!_)
                                var D = Y;
                            } else
                              var D = UTr;
                          else {
                            var u0 = Ee(X, Ogr), Y0 = 0;
                            if (0 <= u0)
                              if (0 < u0) {
                                var J0 = Ee(X, iFr), fr = 0;
                                if (0 <= J0)
                                  if (0 < J0)
                                    if (n0(X, hFr))
                                      if (n0(X, kFr))
                                        if (n0(X, wFr))
                                          if (n0(X, EFr))
                                            if (n0(X, SFr))
                                              if (n0(X, gFr))
                                                if (n0(X, FFr))
                                                  ce = 1, H0 = 1, Y0 = 1, fr = 1;
                                                else
                                                  var Q0 = TFr;
                                              else
                                                var Q0 = OFr;
                                            else
                                              var Q0 = IFr;
                                          else
                                            var Q0 = AFr;
                                        else
                                          var Q0 = NFr;
                                      else
                                        var Q0 = CFr;
                                    else
                                      var Q0 = PFr;
                                  else
                                    var Q0 = DFr;
                                else if (n0(X, fFr))
                                  if (n0(X, xFr))
                                    if (n0(X, aFr))
                                      if (n0(X, oFr))
                                        if (n0(X, cFr))
                                          if (n0(X, sFr))
                                            if (n0(X, vFr))
                                              ce = 1, H0 = 1, Y0 = 1, fr = 1;
                                            else
                                              var Q0 = lFr;
                                          else
                                            var Q0 = bFr;
                                        else
                                          var Q0 = pFr;
                                      else
                                        var Q0 = mFr;
                                    else
                                      var Q0 = _Fr;
                                  else
                                    var Q0 = yFr;
                                else
                                  var Q0 = dFr;
                                if (!fr)
                                  var F0 = Q0;
                              } else
                                var F0 = LFr;
                            else {
                              var gr = Ee(X, Igr), mr = 0;
                              if (0 <= gr)
                                if (0 < gr)
                                  if (n0(X, Xgr))
                                    if (n0(X, Ygr))
                                      if (n0(X, Vgr))
                                        if (n0(X, zgr))
                                          if (n0(X, Kgr))
                                            if (n0(X, Wgr))
                                              if (n0(X, Jgr))
                                                ce = 1, H0 = 1, Y0 = 1, mr = 1;
                                              else
                                                var Cr = $gr;
                                            else
                                              var Cr = Zgr;
                                          else
                                            var Cr = Qgr;
                                        else
                                          var Cr = rFr;
                                      else
                                        var Cr = eFr;
                                    else
                                      var Cr = nFr;
                                  else
                                    var Cr = tFr;
                                else
                                  var Cr = uFr;
                              else if (n0(X, Agr))
                                if (n0(X, Ngr))
                                  if (n0(X, Cgr))
                                    if (n0(X, Pgr))
                                      if (n0(X, Dgr))
                                        if (n0(X, Lgr))
                                          if (n0(X, Rgr))
                                            ce = 1, H0 = 1, Y0 = 1, mr = 1;
                                          else
                                            var Cr = jgr;
                                        else
                                          var Cr = Ggr;
                                      else
                                        var Cr = Mgr;
                                    else
                                      var Cr = Bgr;
                                  else
                                    var Cr = qgr;
                                else
                                  var Cr = Ugr;
                              else
                                var Cr = Hgr;
                              if (!mr)
                                var F0 = Cr;
                            }
                            if (!Y0)
                              var D = F0;
                          }
                          if (!H0)
                            var sr = D;
                        } else
                          var sr = HTr;
                      else {
                        var Pr = Ee(X, oEr), K0 = 0;
                        if (0 <= Pr)
                          if (0 < Pr) {
                            var Ur = Ee(X, ySr), d0 = 0;
                            if (0 <= Ur)
                              if (0 < Ur) {
                                var Kr = Ee(X, WSr), re = 0;
                                if (0 <= Kr)
                                  if (0 < Kr)
                                    if (n0(X, cgr))
                                      if (n0(X, sgr))
                                        if (n0(X, vgr))
                                          if (n0(X, lgr))
                                            if (n0(X, bgr))
                                              if (n0(X, pgr))
                                                if (n0(X, mgr))
                                                  ce = 1, K0 = 1, d0 = 1, re = 1;
                                                else
                                                  var xe = _gr;
                                              else
                                                var xe = ygr;
                                            else
                                              var xe = dgr;
                                          else
                                            var xe = hgr;
                                        else
                                          var xe = kgr;
                                      else
                                        var xe = wgr;
                                    else
                                      var xe = Egr;
                                  else
                                    var xe = Sgr;
                                else if (n0(X, JSr))
                                  if (n0(X, $Sr))
                                    if (n0(X, ZSr))
                                      if (n0(X, QSr))
                                        if (n0(X, rgr))
                                          if (n0(X, egr))
                                            if (n0(X, ngr))
                                              ce = 1, K0 = 1, d0 = 1, re = 1;
                                            else
                                              var xe = tgr;
                                          else
                                            var xe = ugr;
                                        else
                                          var xe = igr;
                                      else
                                        var xe = fgr;
                                    else
                                      var xe = xgr;
                                  else
                                    var xe = agr;
                                else
                                  var xe = ogr;
                                if (!re)
                                  var je = xe;
                              } else
                                var je = ggr;
                            else {
                              var le = Ee(X, dSr), Ie = 0;
                              if (0 <= le)
                                if (0 < le)
                                  if (n0(X, DSr))
                                    if (n0(X, LSr))
                                      if (n0(X, RSr))
                                        if (n0(X, jSr))
                                          if (n0(X, GSr))
                                            if (n0(X, MSr))
                                              if (n0(X, BSr))
                                                ce = 1, K0 = 1, d0 = 1, Ie = 1;
                                              else
                                                var Me = qSr;
                                            else
                                              var Me = USr;
                                          else
                                            var Me = HSr;
                                        else
                                          var Me = XSr;
                                      else
                                        var Me = YSr;
                                    else
                                      var Me = VSr;
                                  else
                                    var Me = zSr;
                                else
                                  var Me = KSr;
                              else if (n0(X, hSr))
                                if (n0(X, kSr))
                                  if (n0(X, wSr))
                                    if (n0(X, ESr))
                                      if (n0(X, SSr))
                                        if (n0(X, gSr))
                                          if (n0(X, FSr))
                                            ce = 1, K0 = 1, d0 = 1, Ie = 1;
                                          else
                                            var Me = TSr;
                                        else
                                          var Me = OSr;
                                      else
                                        var Me = ISr;
                                    else
                                      var Me = ASr;
                                  else
                                    var Me = NSr;
                                else
                                  var Me = CSr;
                              else
                                var Me = PSr;
                              if (!Ie)
                                var je = Me;
                            }
                            if (!d0)
                              var Be = je;
                          } else
                            var Be = Fgr;
                        else {
                          var an = Ee(X, cEr), Ke = 0;
                          if (0 <= an)
                            if (0 < an) {
                              var Ae = Ee(X, qEr), on = 0;
                              if (0 <= Ae)
                                if (0 < Ae)
                                  if (n0(X, nSr))
                                    if (n0(X, tSr))
                                      if (n0(X, uSr))
                                        if (n0(X, iSr))
                                          if (n0(X, fSr))
                                            if (n0(X, xSr))
                                              if (n0(X, aSr))
                                                ce = 1, K0 = 1, Ke = 1, on = 1;
                                              else
                                                var rn = oSr;
                                            else
                                              var rn = cSr;
                                          else
                                            var rn = sSr;
                                        else
                                          var rn = vSr;
                                      else
                                        var rn = lSr;
                                    else
                                      var rn = bSr;
                                  else
                                    var rn = pSr;
                                else
                                  var rn = mSr;
                              else if (n0(X, UEr))
                                if (n0(X, HEr))
                                  if (n0(X, XEr))
                                    if (n0(X, YEr))
                                      if (n0(X, VEr))
                                        if (n0(X, zEr))
                                          if (n0(X, KEr))
                                            ce = 1, K0 = 1, Ke = 1, on = 1;
                                          else
                                            var rn = WEr;
                                        else
                                          var rn = JEr;
                                      else
                                        var rn = $Er;
                                    else
                                      var rn = ZEr;
                                  else
                                    var rn = QEr;
                                else
                                  var rn = rSr;
                              else
                                var rn = eSr;
                              if (!on)
                                var kn = rn;
                            } else
                              var kn = _Sr;
                          else {
                            var sn = Ee(X, sEr), Pe = 0;
                            if (0 <= sn)
                              if (0 < sn)
                                if (n0(X, FEr))
                                  if (n0(X, TEr))
                                    if (n0(X, OEr))
                                      if (n0(X, IEr))
                                        if (n0(X, AEr))
                                          if (n0(X, NEr))
                                            if (n0(X, CEr))
                                              ce = 1, K0 = 1, Ke = 1, Pe = 1;
                                            else
                                              var We = PEr;
                                          else
                                            var We = DEr;
                                        else
                                          var We = LEr;
                                      else
                                        var We = REr;
                                    else
                                      var We = jEr;
                                  else
                                    var We = GEr;
                                else
                                  var We = MEr;
                              else
                                var We = BEr;
                            else if (n0(X, vEr))
                              if (n0(X, lEr))
                                if (n0(X, bEr))
                                  if (n0(X, pEr))
                                    if (n0(X, mEr))
                                      if (n0(X, _Er))
                                        if (n0(X, yEr))
                                          ce = 1, K0 = 1, Ke = 1, Pe = 1;
                                        else
                                          var We = dEr;
                                      else
                                        var We = hEr;
                                    else
                                      var We = kEr;
                                  else
                                    var We = wEr;
                                else
                                  var We = EEr;
                              else
                                var We = SEr;
                            else
                              var We = gEr;
                            if (!Pe)
                              var kn = We;
                          }
                          if (!Ke)
                            var Be = kn;
                        }
                        if (!K0)
                          var sr = Be;
                      }
                      if (!ce) {
                        var me = sr;
                        dr = 1;
                      }
                    }
                    var en = dr ? me : 0;
                    en ? g1(e, en[1]) : dn(e, Te(OCr, Te(X, TCr)));
                    continue;
                  default:
                    var _n = Se(x);
                    dn(i, _n), dn(e, _n);
                    continue;
                }
              }
            }
            function Qee(t4, n) {
              Tn(n);
              var e = j(n), i = tf < e ? pw < e ? -1 : Yk < e ? P3 < e ? Hw < e ? FE < e ? Zy < e ? 1 : 6 : Qh < e ? mE < e ? xF < e ? 1 : 6 : eO < e ? 1 : 6 : ZF < e ? _A < e ? 1 : 6 : bI < e ? 1 : 6 : P6 < e ? S4 < e ? a6 < e ? z8 < e ? G3 < e ? e3 < e ? LO < e ? 1 : 6 : GI < e ? 1 : 6 : Cy < e ? wg < e ? 1 : 6 : Uw < e ? 1 : 6 : R3 < e ? E8 < e ? Bg < e ? 1 : 6 : Z4 < e ? 1 : 6 : J8 < e ? JT < e ? 1 : 6 : Sk < e ? 1 : 6 : I4 < e ? KO < e ? b3 < e ? nw < e ? 1 : 6 : ok < e ? 1 : 6 : ap < e ? z6 < e ? 1 : 6 : Ah < e ? 1 : 6 : M8 < e ? v4 < e ? u6 < e ? 1 : 6 : U6 < e ? 1 : 6 : q6 < e ? g4 < e ? 1 : 6 : Ze < e ? 1 : 6 : GE < e ? B4 < e ? F6 < e ? TF < e ? f8 < e ? 1 : 6 : k8 < e ? 1 : 6 : T4 < e ? QF < e ? 1 : 6 : dd < e ? 1 : 6 : H6 < e ? t8 < e ? v3 < e ? 1 : 6 : g8 < e ? 1 : 6 : HS < e ? R8 < e ? 1 : 6 : W3 < e ? 1 : 6 : _8 < e ? x8 < e ? a8 < e ? E3 < e ? 1 : 6 : y6 < e ? 1 : 6 : v6 < e ? sF < e ? 1 : 6 : eI < e ? 1 : 6 : c3 < e ? jS < e ? n8 < e ? 1 : 6 : F8 < e ? 1 : 6 : $3 < e ? bF < e ? 1 : 6 : ag < e ? 1 : 6 : aw < e ? Fk < e ? gk < e ? Xk < e ? IT < e ? Wk < e ? 1 : 6 : xA < e ? 1 : 6 : Ey < e ? WS < e ? 1 : 6 : hh < e ? 1 : 6 : Ad < e ? yF < e ? IE < e ? 1 : 6 : eE < e ? 1 : 6 : Ty < e ? G_ < e ? 1 : 6 : LE < e ? 1 : 6 : GF < e ? Ww < e ? Uy < e ? tw < e ? 1 : 6 : zI < e ? 1 : 6 : BO < e ? cp < e ? 1 : 6 : BT < e ? 1 : 6 : ot < e ? NA < e ? OA < e ? 1 : 6 : 1 : 6 : s6 < e ? E6 < e ? b6 < e ? w3 < e ? WE < e ? 1 : 6 : Xw < e ? 1 : 6 : l4 < e ? iE < e ? 1 : 6 : Ay < e ? 1 : 6 : s3 < e ? z4 < e ? ug < e ? 1 : 6 : XF < e ? 1 : 6 : Y4 < e ? hT < e ? 1 : 6 : Ny < e ? 1 : 6 : L6 < e ? L4 < e ? z3 < e ? US < e ? 1 : 6 : Zw < e ? 1 : 6 : ly < e ? By < e ? 1 : 6 : WT < e ? 1 : 6 : q4 < e ? _d < e ? QT < e ? 1 : 6 : M3 < e ? 1 : 6 : e6 < e ? bO < e ? 1 : 6 : eS < e ? 1 : 6 : xT < e ? Q4 < e ? Kh < e ? rp < e ? R4 < e ? C6 < e ? lp < e ? j_ < e ? 1 : 6 : Rh < e ? 1 : 6 : yh < e ? Mg < e ? 1 : 6 : NS < e ? 1 : 6 : M6 < e ? A3 < e ? xk < e ? 1 : 6 : lE < e ? 1 : 6 : b8 < e ? b4 < e ? 1 : 6 : td < e ? 1 : 6 : B3 < e ? IS < e ? DE < e ? vT < e ? 1 : 6 : ST < e ? 1 : 6 : xS < e ? k3 < e ? 1 : 6 : Jh < e ? 1 : 6 : my < e ? O6 < e ? Rg < e ? 1 : 6 : py < e ? 1 : 6 : GO < e ? kF < e ? 1 : 6 : KF < e ? 1 : 6 : jI < e ? Mu < e ? BF < e ? Pd < e ? PO < e ? 1 : 6 : Lh < e ? 1 : 6 : Xd < e ? PS < e ? 1 : 6 : mA < e ? 1 : 6 : lO < e ? PI < e ? cI < e ? 1 : 6 : H_ < e ? 1 : 6 : wS < e ? oT < e ? 1 : 6 : dg < e ? 1 : 6 : DO < e ? Dw < e ? Kd < e ? mw < e ? 1 : 6 : nF < e ? 1 : 6 : Wg < e ? Gk < e ? 1 : 6 : XO < e ? 1 : 6 : aS < e ? p6 < e ? h6 < e ? 1 : 6 : rT < e ? 1 : 6 : yd < e ? tT < e ? 1 : 6 : VS < e ? 1 : 6 : JO < e ? Lk < e ? kS < e ? Cw < e ? LI < e ? $g < e ? 1 : 6 : WO < e ? 1 : 6 : Uk < e ? Ss < e ? 1 : 6 : RF < e ? 1 : 6 : Sh < e ? AS < e ? gI < e ? 1 : 6 : cg < e ? 1 : 6 : Mh < e ? Ed < e ? 1 : 6 : sI < e ? 1 : 6 : sT < e ? mg < e ? fF < e ? $I < e ? 1 : 6 : yk < e ? 1 : 6 : q_ < e ? Sw < e ? 1 : 6 : nT < e ? 1 : 6 : Bk < e ? IO < e ? dA < e ? 1 : 6 : hg < e ? 1 : 6 : ZE < e ? mF < e ? 1 : 6 : UF < e ? 1 : 6 : h4 < e ? h3 < e ? pT < e ? BI < e ? dS < e ? 1 : 6 : lA < e ? 1 : 6 : jE < e ? Jk < e ? 1 : 6 : Gg < e ? 1 : 6 : PT < e ? j6 < e ? _k < e ? 1 : 6 : aT < e ? 1 : 6 : YS < e ? HT < e ? 1 : 6 : pE < e ? 1 : 6 : Jc < e ? Tk < e ? L3 < e ? zg < e ? 1 : 6 : oh < e ? 1 : 6 : CF < e ? mh < e ? 1 : 6 : iA < e ? 1 : 6 : HE < e ? J3 < e ? by < e ? 1 : 6 : SI < e ? 1 : 6 : WF < e ? oS < e ? 1 : 6 : D4 < e ? 1 : 6 : pS < e ? Bw < e ? ak < e ? wO < e ? aI < e ? _g < e ? Dh < e ? 1 : 6 : i3 < e ? 1 : 6 : bE < e ? Gh < e ? 1 : 6 : zk < e ? 1 : 6 : ip < e ? wd < e ? B8 < e ? 1 : 6 : m3 < e ? 1 : 6 : Fw < e ? yE < e ? 1 : 6 : Hg < e ? 1 : 6 : _y < e ? ew < e ? rO < e ? JF < e ? 1 : 6 : Hh < e ? 1 : 6 : rw < e ? AI < e ? 1 : 6 : yO < e ? 1 : 6 : bS < e ? MO < e ? SA < e ? 1 : 6 : gA < e ? 1 : 6 : og < e ? XI < e ? 1 : 6 : ES < e ? 1 : 6 : wI < e ? DI < e ? iS < e ? zy < e ? Q_ < e ? 1 : 6 : _T < e ? 1 : 6 : rI < e ? Fg < e ? 1 : 6 : sA < e ? 1 : 6 : xE < e ? FT < e ? Eg < e ? 1 : 6 : AT < e ? 1 : 6 : Py < e ? i8 < e ? 1 : 6 : eg < e ? 1 : 6 : qd < e ? U_ < e ? TO < e ? md < e ? 1 : 6 : zE < e ? 1 : 6 : r6 < e ? Q6 < e ? 1 : 6 : Nh < e ? 1 : 6 : J6 < e ? MF < e ? Xy < e ? 1 : 6 : Dk < e ? 1 : 6 : RE < e ? Ag < e ? 1 : 6 : NI < e ? 1 : 6 : N8 < e ? R_ < e ? P4 < e ? rF < e ? Yd < e ? ZS < e ? 1 : 6 : G6 < e ? 1 : 6 : hE < e ? oI < e ? 1 : 6 : Rw < e ? 1 : 6 : x3 < e ? c8 < e ? YF < e ? 1 : 6 : Gw < e ? 1 : 6 : dk < e ? vI < e ? 1 : 6 : ky < e ? 1 : 6 : I8 < e ? xI < e ? i6 < e ? Sy < e ? 1 : 6 : qI < e ? 1 : 6 : s8 < e ? Nw < e ? 1 : 6 : _E < e ? 1 : 6 : d3 < e ? xp < e ? uE < e ? 1 : 6 : A8 < e ? 1 : 6 : lw < e ? $F < e ? 1 : 6 : WI < e ? 1 : 6 : Jd < e ? nI < e ? h8 < e ? wy < e ? uw < e ? 1 : 6 : f3 < e ? 1 : 6 : yI < e ? EA < e ? 1 : 6 : Xh < e ? 1 : 6 : Sg < e ? aE < e ? AO < e ? 1 : 6 : Y6 < e ? 1 : 6 : Mw < e ? vw < e ? 1 : 6 : T3 < e ? 1 : 6 : Ck < e ? NF < e ? Gy < e ? _4 < e ? 1 : 6 : lh < e ? 1 : 6 : Jg < e ? Qk < e ? 1 : 6 : vS < e ? 1 : 6 : q3 < e ? CO < e ? ww < e ? 1 : 6 : dE < e ? 1 : 6 : rg < e ? nA < e ? 1 : 6 : IA < e ? 1 : 6 : sh < e ? $E < e ? Mk < e ? $6 < e ? Uh < e ? cF < e ? eF < e ? bd < e ? uT < e ? 1 : 6 : KI < e ? 1 : 6 : ME < e ? NT < e ? 1 : 6 : $8 < e ? 1 : 6 : CA < e ? EE < e ? XT < e ? 1 : 6 : wh < e ? 1 : 6 : Ch < e ? Ud < e ? 1 : 6 : hS < e ? 1 : 6 : FA < e ? RO < e ? Vg < e ? bg < e ? 1 : 6 : Yg < e ? 1 : 6 : zw < e ? fh < e ? 1 : 6 : jg < e ? 1 : 6 : Pg < e ? _S < e ? Zh < e ? 1 : 6 : Ig < e ? 1 : 6 : fA < e ? gT < e ? 1 : 6 : jk < e ? 1 : 6 : tS < e ? Q8 < e ? QI < e ? PE < e ? UE < e ? 1 : 6 : yA < e ? 1 : 6 : FO < e ? qy < e ? 1 : 6 : oA < e ? 1 : 6 : cA < e ? p4 < e ? hk < e ? 1 : 6 : sO < e ? 1 : 6 : gh < e ? S7 < e ? 1 : 6 : rk < e ? 1 : 6 : Y8 < e ? J_ < e ? Ih < e ? Rd < e ? 1 : 6 : ET < e ? 1 : 6 : jh < e ? Nk < e ? 1 : 6 : vd < e ? 1 : 6 : id < e ? vg < e ? rE < e ? 1 : 6 : ZT < e ? 1 : 6 : ng < e ? Iw < e ? 1 : 6 : GT < e ? 1 : 6 : Cd < e ? pk < e ? fn < e ? m8 < e ? OT < e ? B6 < e ? 1 : 6 : Od < e ? 1 : 6 : $4 < e ? ny < e ? 1 : 6 : op < e ? 1 : 6 : pO < e ? qE < e ? ld < e ? 1 : 6 : X_ < e ? 1 : 6 : FS < e ? YT < e ? 1 : 6 : BS < e ? 1 : 6 : Yw < e ? fy < e ? bA < e ? Wd < e ? 1 : 6 : bT < e ? 1 : 6 : aF < e ? ek < e ? 1 : 6 : II < e ? 1 : 6 : cO < e ? fd < e ? ig < e ? 1 : 6 : _h < e ? 1 : 6 : aO < e ? hO < e ? 1 : 6 : uO < e ? 1 : 6 : CS < e ? JE < e ? oO < e ? lk < e ? cd < e ? 1 : 6 : xh < e ? 1 : 6 : QS < e ? hw < e ? 1 : 6 : Iy < e ? 1 : 6 : pA < e ? rS < e ? $T < e ? 1 : 6 : tI < e ? 1 : 6 : xy < e ? Aw < e ? 1 : 6 : 1 : iT < e ? Q3 < e ? uk < e ? 6 : rd < e ? 1 : 6 : qF < e ? nE < e ? 1 : 6 : bk < e ? 1 : 6 : pg < e ? iO < e ? fI < e ? 1 : 6 : qO < e ? 1 : 6 : My < e ? 1 : 6 : L8 < e ? Fh < e ? cw < e ? Nd < e ? tA < e ? 6 : rh < e ? fT < e ? 1 : 6 : pF < e ? 1 : 6 : nd < e ? JI < e ? ty < e ? 1 : 6 : kd < e ? 1 : 6 : VE < e ? Qd < e ? 1 : 6 : wF < e ? 1 : 6 : ep < e ? K4 < e ? g6 < e ? yy < e ? 1 : 6 : tg < e ? 1 : 6 : Z8 < e ? kO < e ? 1 : 6 : Hk < e ? 1 : 6 : Ok < e ? H8 < e ? FF < e ? 1 : 6 : gy < e ? 1 : 6 : sg < e ? Ak < e ? 1 : 6 : gE < e ? 1 : 6 : qw < e ? ry < e ? uy < e ? yS < e ? sE < e ? 1 : 6 : 1 : 6 : Ew < e ? 6 : r8 < e ? CT < e ? 1 : 6 : kg < e ? 1 : 6 : uI < e ? u3 < e ? qo < e ? La < e ? 1 : 2 : HI < e ? 1 : 6 : sw < e ? UT < e ? 1 : 6 : KS < e ? 1 : 6 : kI < e ? fS < e ? eh < e ? 1 : 6 : LT < e ? 1 : 6 : qT < e ? $w < e ? 1 : 6 : TI < e ? 1 : 6 : YI < e ? fk < e ? Jn < e ? j4 < e ? U3 < e ? ah < e ? 1 : 6 : hF < e ? 1 : 6 : K3 < e ? R6 < e ? 1 : 6 : od < e ? 1 : 6 : RT < e ? fp < e ? xw < e ? 1 : 6 : uS < e ? 1 : 6 : fO < e ? n3 < e ? 1 : 6 : sd < e ? 1 : 6 : Ek < e ? JS < e ? nh < e ? xg < e ? 1 : 6 : ay < e ? 1 : 6 : Zk < e ? $h < e ? 1 : 6 : AE < e ? 1 : 6 : Eh < e ? dy < e ? lF < e ? 1 : 6 : hA < e ? 1 : 6 : Dy < e ? 1 : 6 : zh < e ? X3 < e ? o3 < e ? Qw < e ? 1 : 6 : ov < e ? 6 : MT < e ? 1 : 6 : OF < e ? w6 < e ? DF < e ? 1 : 6 : Zd < e ? 1 : 6 : qk < e ? jd < e ? 1 : 6 : eA < e ? 1 : 6 : Wh < e ? lS < e ? mT < e ? lI < e ? 1 : 6 : 1 : jy < e ? 6 : Qy < e ? 1 : 6 : IF < e ? bh < e ? 1 : 6 : zT < e ? NO < e ? 1 : 6 : vO < e ? 1 : 6 : gd < e ? T8 < e ? Z_ < e ? xd < e ? SO < e ? uh < e ? FI < e ? Pw < e ? 1 : 6 : kA < e ? 1 : 6 : Hd < e ? oy < e ? 1 : 6 : vk < e ? 1 : 6 : LF < e ? AA < e ? bp < e ? 1 : 6 : 1 : 6 : kT < e ? Vh < e ? SS < e ? Jy < e ? 1 : 6 : gS < e ? 1 : 6 : l6 < e ? Vk < e ? 1 : 6 : SE < e ? 1 : 6 : Tw < e ? yw < e ? 1 : 6 : hd < e ? ZO < e ? 1 : 6 : w8 < e ? 1 : 6 : SF < e ? jO < e ? zF < e ? Oy < e ? Th < e ? 1 : 6 : uA < e ? 1 : 6 : ey < e ? QE < e ? 1 : 6 : vy < e ? 1 : 6 : $y < e ? y8 < e ? Yy < e ? 1 : 6 : t3 < e ? 1 : 6 : tE < e ? sy < e ? 1 : 6 : lg < e ? 1 : 6 : Ky < e ? TA < e ? cS < e ? tF < e ? 1 : 6 : zd < e ? 1 : 6 : dI < e ? mk < e ? 1 : 6 : xO < e ? 1 : 6 : RS < e && vA < e ? 1 : 6 : kk < e ? Md < e ? fg < e ? ik < e ? 6 : ed < e ? _I < e ? 1 : 6 : Ld < e ? 1 : 6 : cE < e ? sk < e ? W_ < e ? 1 : 6 : 1 : 6 : Ng < e ? YO < e && sS < e ? 1 : 6 : _w < e ? tO < e ? Gd < e ? 1 : 6 : 1 : EF < e ? 6 : 1 : Fd < e ? OE < e ? H3 < e ? 6 : fw < e ? 1 : 6 : EI < e ? nk < e ? gO < e ? 1 : 6 : M_ < e ? 1 : 6 : Td < e ? 1 : 6 : HF < e ? Og < e ? Ph < e ? 1 : 6 : zS < e ? 1 : 6 : $k < e ? KE < e ? 6 : ad < e ? 1 : 6 : Y_ < e ? kE < e ? 1 : 6 : Xt < e ? 1 : 6 : qS < e ? BE < e ? EO < e ? U4 < e ? Fy < e ? S8 < e ? MI < e ? 1 : 6 : iF < e ? 1 : 6 : VF < e ? 1 : 6 : gw < e ? S3 < e ? se < e ? 1 : 6 : 1 : 6 : Cg < e ? qh < e ? z_ < e ? V_ < e ? 1 : 6 : 1 : 6 : Vw < e ? O3 < e ? ph < e ? 1 : 6 : oF < e ? 1 : 6 : gg < e ? 1 : 6 : K8 < e ? G8 < e ? Sa < e ? RI < e ? 6 : ea < e ? 1 : 2 : T6 < e ? Hy < e ? 1 : 6 : CE < e ? 1 : 6 : W8 < e ? K6 < e ? Lg < e ? 1 : 6 : lT < e ? 1 : 6 : o8 < e ? it2 < e ? 1 : 6 : Pk < e ? 1 : 6 : DS < e ? fE < e ? G4 < e ? Dg < e ? 1 : 6 : rA < e ? 1 : 6 : D6 < e ? AF < e ? 1 : 6 : m4 < e ? 1 : 6 : hI < e ? oE < e ? OI < e ? 1 : 6 : C3 < e ? 1 : 6 : M4 < e ? q8 < e ? 1 : 6 : Tg < e ? 1 : 6 : C8 < e ? nS < e ? vE < e ? Kk < e ? yT < e ? $_ < e ? 1 : 6 : gF < e ? 1 : 6 : YE < e ? 1 : 6 : th < e ? pI < e ? 6 : 1 : 6 : UO < e ? dw < e ? KT < e ? v8 < e ? 1 : 6 : PA < e ? 1 : 6 : Kw < e ? K_ < e ? 1 : 6 : 1 : 6 : qg < e ? QO < e ? Z3 < e ? vp < e ? D8 < e ? 1 : 6 : r3 < e ? 1 : 6 : hr < e ? u8 < e ? 1 : 6 : 1 : F4 < e ? $S < e ? 6 : _6 < e ? 1 : 6 : dF < e ? Ly < e ? 1 : 6 : j3 < e ? 1 : 6 : Rk < e ? VI < e ? nO < e ? a3 < e ? 1 : 6 : dO < e ? 1 : 6 : Ry < e ? I3 < e ? 1 : 6 : np < e ? 1 : 6 : ya < e ? oc < e ? cx < e ? 1 : 2 : aa < e ? 1 : 2 : Ju < e ? Uu < e ? 1 : 3 : Pa < e ? 1 : 2 : Vr(ZLr, e + 1 | 0) - 1 | 0;
              if (14 < i >>> 0)
                var x = q(n);
              else
                switch (i) {
                  case 0:
                    var x = 0;
                    break;
                  case 1:
                    var x = 14;
                    break;
                  case 2:
                    if (B0(n, 2), Mc(j(n)) === 0) {
                      for (; ; )
                        if (B0(n, 2), Mc(j(n)) !== 0) {
                          var x = q(n);
                          break;
                        }
                    } else
                      var x = q(n);
                    break;
                  case 3:
                    var x = 1;
                    break;
                  case 4:
                    B0(n, 1);
                    var x = xi(j(n)) === 0 ? 1 : q(n);
                    break;
                  case 5:
                    var x = 12;
                    break;
                  case 6:
                    var x = 13;
                    break;
                  case 7:
                    var x = 10;
                    break;
                  case 8:
                    B0(n, 6);
                    var c = k9(j(n)), x = c === 0 ? 4 : c === 1 ? 3 : q(n);
                    break;
                  case 9:
                    var x = 9;
                    break;
                  case 10:
                    var x = 5;
                    break;
                  case 11:
                    var x = 11;
                    break;
                  case 12:
                    var x = 7;
                    break;
                  case 13:
                    if (B0(n, 14), Gs(j(n)) === 0) {
                      var s = R1(j(n));
                      if (s === 0)
                        var x = Pn(j(n)) === 0 && Pn(j(n)) === 0 && Pn(j(n)) === 0 ? 13 : q(n);
                      else if (s === 1 && Pn(j(n)) === 0)
                        for (; ; ) {
                          var p = N1(j(n));
                          if (p !== 0) {
                            var x = p === 1 ? 13 : q(n);
                            break;
                          }
                        }
                      else
                        var x = q(n);
                    } else
                      var x = q(n);
                    break;
                  default:
                    var x = 8;
                }
              if (14 < x >>> 0)
                return ke(bPr);
              switch (x) {
                case 0:
                  return [0, t4, Ln];
                case 1:
                  return [2, h7(t4, n)];
                case 2:
                  return [2, t4];
                case 3:
                  var y = Lu(t4, n), T = Qn(Kn), E = e2(t4, T, n), h = E[1];
                  return [1, h, Si(h, y, E[2], T, 0)];
                case 4:
                  var w = Lu(t4, n), G = Qn(Kn), A = j1(t4, G, n), S = A[1];
                  return [1, S, Si(S, w, A[2], G, 1)];
                case 5:
                  return [0, t4, 98];
                case 6:
                  return [0, t4, j7];
                case 7:
                  return [0, t4, 99];
                case 8:
                  return [0, t4, 0];
                case 9:
                  return [0, t4, 86];
                case 10:
                  return [0, t4, 10];
                case 11:
                  return [0, t4, 82];
                case 12:
                  var M = Se(n), K = Lu(t4, n), V = Qn(Kn), f0 = Qn(Kn);
                  dn(f0, M);
                  var m0 = Un(M, pPr) ? 0 : 1, k0 = yL(t4, m0, V, f0, n), g0 = d7(k0, n);
                  dn(f0, M);
                  var e0 = Bt(V), x0 = Bt(f0);
                  return [0, k0, [8, [0, k0[1], K, g0], e0, x0]];
                case 13:
                  for (var l = n[6]; ; ) {
                    Tn(n);
                    var c0 = j(n), t0 = Nn < c0 ? 1 : Vr(FRr, c0 + 1 | 0) - 1 | 0;
                    if (3 < t0 >>> 0)
                      var a0 = q(n);
                    else
                      switch (t0) {
                        case 0:
                          var a0 = 1;
                          break;
                        case 1:
                          var a0 = 2;
                          break;
                        case 2:
                          var a0 = 0;
                          break;
                        default:
                          if (B0(n, 2), Gs(j(n)) === 0) {
                            var w0 = R1(j(n));
                            if (w0 === 0)
                              if (Pn(j(n)) === 0 && Pn(j(n)) === 0)
                                var _0 = Pn(j(n)) !== 0 ? 1 : 0, a0 = _0 && q(n);
                              else
                                var a0 = q(n);
                            else if (w0 === 1 && Pn(j(n)) === 0)
                              for (; ; ) {
                                var E0 = N1(j(n));
                                if (E0 !== 0) {
                                  var X0 = E0 !== 1 ? 1 : 0, a0 = X0 && q(n);
                                  break;
                                }
                              }
                            else
                              var a0 = q(n);
                          } else
                            var a0 = q(n);
                      }
                    if (2 < a0 >>> 0)
                      throw [0, Fn, Awr];
                    switch (a0) {
                      case 0:
                        continue;
                      case 1:
                        break;
                      default:
                        if (iL(dr0(n)))
                          continue;
                        kr0(n, 1);
                    }
                    var b = n[3];
                    fL(n, l);
                    var G0 = Ll(n), X = Hl(t4, l, b);
                    return [0, t4, [7, xL(G0), X]];
                  }
                default:
                  return [0, t4, [6, Se(n)]];
              }
            }
            function rne(t4, n) {
              Tn(n);
              var e = j(n);
              if (-1 < e)
                if (tf < e)
                  if (Sa < e)
                    if (qo < e)
                      var i = e <= La ? 1 : 0, T = i && 1;
                    else
                      var x = e <= ea ? 1 : 0, T = x && 1;
                  else if (ya < e)
                    if (oc < e)
                      var c = e <= cx ? 1 : 0, T = c && 1;
                    else
                      var s = e <= aa ? 1 : 0, T = s && 1;
                  else if (Ju < e)
                    var p = e <= Uu ? 1 : 0, T = p && 2;
                  else
                    var y = e <= Pa ? 1 : 0, T = y && 1;
                else
                  var T = Vr(kLr, e) - 1 | 0;
              else
                var T = -1;
              if (5 < T >>> 0)
                var E = q(n);
              else
                switch (T) {
                  case 0:
                    var E = 5;
                    break;
                  case 1:
                    if (B0(n, 1), Mc(j(n)) === 0) {
                      for (; ; )
                        if (B0(n, 1), Mc(j(n)) !== 0) {
                          var E = q(n);
                          break;
                        }
                    } else
                      var E = q(n);
                    break;
                  case 2:
                    var E = 0;
                    break;
                  case 3:
                    B0(n, 0);
                    var h = xi(j(n)) !== 0 ? 1 : 0, E = h && q(n);
                    break;
                  case 4:
                    B0(n, 5);
                    var w = k9(j(n)), E = w === 0 ? 3 : w === 1 ? 2 : q(n);
                    break;
                  default:
                    var E = 4;
                }
              if (5 < E >>> 0)
                return ke(sPr);
              switch (E) {
                case 0:
                  return [2, h7(t4, n)];
                case 1:
                  return [2, t4];
                case 2:
                  var G = Lu(t4, n), A = Qn(Kn), S = e2(t4, A, n), M = S[1];
                  return [1, M, Si(M, G, S[2], A, 0)];
                case 3:
                  var K = Lu(t4, n), V = Qn(Kn), f0 = j1(t4, V, n), m0 = f0[1];
                  return [1, m0, Si(m0, K, f0[2], V, 1)];
                case 4:
                  var k0 = Lu(t4, n), g0 = Qn(Kn), e0 = Qn(Kn), x0 = Qn(Kn);
                  dn(x0, vPr);
                  var l = te0(t4, g0, e0, x0, n), c0 = l[1], t0 = d7(c0, n), a0 = [0, c0[1], k0, t0], w0 = l[2], _0 = Bt(x0), E0 = Bt(e0);
                  return [0, c0, [3, [0, a0, [0, Bt(g0), E0, _0], w0]]];
                default:
                  var X0 = Ei(t4, nt(t4, n));
                  return [0, X0, [3, [0, nt(X0, n), lPr, 1]]];
              }
            }
            function ene(t4, n) {
              function e(D) {
                for (; ; )
                  if (B0(D, 29), hn(j(D)) !== 0)
                    return q(D);
              }
              function i(D) {
                B0(D, 27);
                var u0 = qt(j(D));
                if (u0 === 0) {
                  for (; ; )
                    if (B0(D, 25), hn(j(D)) !== 0)
                      return q(D);
                }
                return u0 === 1 ? e(D) : q(D);
              }
              function x(D) {
                for (; ; )
                  if (B0(D, 23), hn(j(D)) !== 0)
                    return q(D);
              }
              function c(D) {
                B0(D, 22);
                var u0 = qt(j(D));
                if (u0 === 0) {
                  for (; ; )
                    if (B0(D, 21), hn(j(D)) !== 0)
                      return q(D);
                }
                return u0 === 1 ? x(D) : q(D);
              }
              function s(D) {
                for (; ; )
                  if (B0(D, 23), hn(j(D)) !== 0)
                    return q(D);
              }
              function p(D) {
                B0(D, 22);
                var u0 = qt(j(D));
                if (u0 === 0) {
                  for (; ; )
                    if (B0(D, 21), hn(j(D)) !== 0)
                      return q(D);
                }
                return u0 === 1 ? s(D) : q(D);
              }
              function y(D) {
                r:
                  for (; ; ) {
                    if (pn(j(D)) === 0)
                      for (; ; ) {
                        B0(D, 24);
                        var u0 = qc(j(D));
                        if (3 < u0 >>> 0)
                          return q(D);
                        switch (u0) {
                          case 0:
                            return s(D);
                          case 1:
                            continue;
                          case 2:
                            continue r;
                          default:
                            return p(D);
                        }
                      }
                    return q(D);
                  }
              }
              function T(D) {
                B0(D, 29);
                var u0 = Hr0(j(D));
                if (3 < u0 >>> 0)
                  return q(D);
                switch (u0) {
                  case 0:
                    return e(D);
                  case 1:
                    var Y0 = P1(j(D));
                    if (Y0 === 0)
                      for (; ; ) {
                        B0(D, 24);
                        var J0 = Qv(j(D));
                        if (2 < J0 >>> 0)
                          return q(D);
                        switch (J0) {
                          case 0:
                            return s(D);
                          case 1:
                            continue;
                          default:
                            return p(D);
                        }
                      }
                    if (Y0 === 1)
                      for (; ; ) {
                        B0(D, 24);
                        var fr = qc(j(D));
                        if (3 < fr >>> 0)
                          return q(D);
                        switch (fr) {
                          case 0:
                            return s(D);
                          case 1:
                            continue;
                          case 2:
                            return y(D);
                          default:
                            return p(D);
                        }
                      }
                    return q(D);
                  case 2:
                    for (; ; ) {
                      B0(D, 24);
                      var Q0 = Qv(j(D));
                      if (2 < Q0 >>> 0)
                        return q(D);
                      switch (Q0) {
                        case 0:
                          return x(D);
                        case 1:
                          continue;
                        default:
                          return c(D);
                      }
                    }
                  default:
                    for (; ; ) {
                      B0(D, 24);
                      var F0 = qc(j(D));
                      if (3 < F0 >>> 0)
                        return q(D);
                      switch (F0) {
                        case 0:
                          return x(D);
                        case 1:
                          continue;
                        case 2:
                          return y(D);
                        default:
                          return c(D);
                      }
                    }
                }
              }
              function E(D) {
                for (; ; ) {
                  B0(D, 30);
                  var u0 = Rs(j(D));
                  if (4 < u0 >>> 0)
                    return q(D);
                  switch (u0) {
                    case 0:
                      return e(D);
                    case 1:
                      continue;
                    case 2:
                      return T(D);
                    case 3:
                      r:
                        for (; ; ) {
                          if (pn(j(D)) === 0)
                            for (; ; ) {
                              B0(D, 30);
                              var Y0 = Rs(j(D));
                              if (4 < Y0 >>> 0)
                                return q(D);
                              switch (Y0) {
                                case 0:
                                  return e(D);
                                case 1:
                                  continue;
                                case 2:
                                  return T(D);
                                case 3:
                                  continue r;
                                default:
                                  return i(D);
                              }
                            }
                          return q(D);
                        }
                    default:
                      return i(D);
                  }
                }
              }
              function h(D) {
                return pn(j(D)) === 0 ? E(D) : q(D);
              }
              function w(D) {
                for (; ; )
                  if (B0(D, 19), hn(j(D)) !== 0)
                    return q(D);
              }
              function G(D) {
                for (; ; )
                  if (B0(D, 19), hn(j(D)) !== 0)
                    return q(D);
              }
              function A(D) {
                B0(D, 29);
                var u0 = Or0(j(D));
                if (u0 === 0)
                  return e(D);
                if (u0 === 1)
                  for (; ; ) {
                    B0(D, 20);
                    var Y0 = E9(j(D));
                    if (3 < Y0 >>> 0)
                      return q(D);
                    switch (Y0) {
                      case 0:
                        return G(D);
                      case 1:
                        continue;
                      case 2:
                        r:
                          for (; ; ) {
                            if (Pn(j(D)) === 0)
                              for (; ; ) {
                                B0(D, 20);
                                var J0 = E9(j(D));
                                if (3 < J0 >>> 0)
                                  return q(D);
                                switch (J0) {
                                  case 0:
                                    return w(D);
                                  case 1:
                                    continue;
                                  case 2:
                                    continue r;
                                  default:
                                    B0(D, 18);
                                    var fr = qt(j(D));
                                    if (fr === 0) {
                                      for (; ; )
                                        if (B0(D, 17), hn(j(D)) !== 0)
                                          return q(D);
                                    }
                                    return fr === 1 ? w(D) : q(D);
                                }
                              }
                            return q(D);
                          }
                      default:
                        B0(D, 18);
                        var Q0 = qt(j(D));
                        if (Q0 === 0) {
                          for (; ; )
                            if (B0(D, 17), hn(j(D)) !== 0)
                              return q(D);
                        }
                        return Q0 === 1 ? G(D) : q(D);
                    }
                  }
                return q(D);
              }
              function S(D) {
                for (; ; )
                  if (B0(D, 13), hn(j(D)) !== 0)
                    return q(D);
              }
              function M(D) {
                for (; ; )
                  if (B0(D, 13), hn(j(D)) !== 0)
                    return q(D);
              }
              function K(D) {
                B0(D, 29);
                var u0 = Mr0(j(D));
                if (u0 === 0)
                  return e(D);
                if (u0 === 1)
                  for (; ; ) {
                    B0(D, 14);
                    var Y0 = h9(j(D));
                    if (3 < Y0 >>> 0)
                      return q(D);
                    switch (Y0) {
                      case 0:
                        return M(D);
                      case 1:
                        continue;
                      case 2:
                        r:
                          for (; ; ) {
                            if (Vu(j(D)) === 0)
                              for (; ; ) {
                                B0(D, 14);
                                var J0 = h9(j(D));
                                if (3 < J0 >>> 0)
                                  return q(D);
                                switch (J0) {
                                  case 0:
                                    return S(D);
                                  case 1:
                                    continue;
                                  case 2:
                                    continue r;
                                  default:
                                    B0(D, 12);
                                    var fr = qt(j(D));
                                    if (fr === 0) {
                                      for (; ; )
                                        if (B0(D, 11), hn(j(D)) !== 0)
                                          return q(D);
                                    }
                                    return fr === 1 ? S(D) : q(D);
                                }
                              }
                            return q(D);
                          }
                      default:
                        B0(D, 12);
                        var Q0 = qt(j(D));
                        if (Q0 === 0) {
                          for (; ; )
                            if (B0(D, 11), hn(j(D)) !== 0)
                              return q(D);
                        }
                        return Q0 === 1 ? M(D) : q(D);
                    }
                  }
                return q(D);
              }
              function V(D) {
                for (; ; )
                  if (B0(D, 9), hn(j(D)) !== 0)
                    return q(D);
              }
              function f0(D) {
                for (; ; )
                  if (B0(D, 9), hn(j(D)) !== 0)
                    return q(D);
              }
              function m0(D) {
                B0(D, 29);
                var u0 = Gr0(j(D));
                if (u0 === 0)
                  return e(D);
                if (u0 === 1)
                  for (; ; ) {
                    B0(D, 10);
                    var Y0 = w9(j(D));
                    if (3 < Y0 >>> 0)
                      return q(D);
                    switch (Y0) {
                      case 0:
                        return f0(D);
                      case 1:
                        continue;
                      case 2:
                        r:
                          for (; ; ) {
                            if (Bc(j(D)) === 0)
                              for (; ; ) {
                                B0(D, 10);
                                var J0 = w9(j(D));
                                if (3 < J0 >>> 0)
                                  return q(D);
                                switch (J0) {
                                  case 0:
                                    return V(D);
                                  case 1:
                                    continue;
                                  case 2:
                                    continue r;
                                  default:
                                    B0(D, 8);
                                    var fr = qt(j(D));
                                    if (fr === 0) {
                                      for (; ; )
                                        if (B0(D, 7), hn(j(D)) !== 0)
                                          return q(D);
                                    }
                                    return fr === 1 ? V(D) : q(D);
                                }
                              }
                            return q(D);
                          }
                      default:
                        B0(D, 8);
                        var Q0 = qt(j(D));
                        if (Q0 === 0) {
                          for (; ; )
                            if (B0(D, 7), hn(j(D)) !== 0)
                              return q(D);
                        }
                        return Q0 === 1 ? f0(D) : q(D);
                    }
                  }
                return q(D);
              }
              function k0(D) {
                B0(D, 28);
                var u0 = qt(j(D));
                if (u0 === 0) {
                  for (; ; )
                    if (B0(D, 26), hn(j(D)) !== 0)
                      return q(D);
                }
                return u0 === 1 ? e(D) : q(D);
              }
              function g0(D) {
                B0(D, 30);
                var u0 = Qv(j(D));
                if (2 < u0 >>> 0)
                  return q(D);
                switch (u0) {
                  case 0:
                    return e(D);
                  case 1:
                    for (; ; ) {
                      B0(D, 30);
                      var Y0 = qc(j(D));
                      if (3 < Y0 >>> 0)
                        return q(D);
                      switch (Y0) {
                        case 0:
                          return e(D);
                        case 1:
                          continue;
                        case 2:
                          r:
                            for (; ; ) {
                              if (pn(j(D)) === 0)
                                for (; ; ) {
                                  B0(D, 30);
                                  var J0 = qc(j(D));
                                  if (3 < J0 >>> 0)
                                    return q(D);
                                  switch (J0) {
                                    case 0:
                                      return e(D);
                                    case 1:
                                      continue;
                                    case 2:
                                      continue r;
                                    default:
                                      return i(D);
                                  }
                                }
                              return q(D);
                            }
                        default:
                          return i(D);
                      }
                    }
                  default:
                    return i(D);
                }
              }
              function e0(D) {
                for (; ; ) {
                  B0(D, 30);
                  var u0 = i9(j(D));
                  if (3 < u0 >>> 0)
                    return q(D);
                  switch (u0) {
                    case 0:
                      return e(D);
                    case 1:
                      return g0(D);
                    case 2:
                      continue;
                    default:
                      return k0(D);
                  }
                }
              }
              function x0(D) {
                for (; ; )
                  if (B0(D, 15), hn(j(D)) !== 0)
                    return q(D);
              }
              function l(D) {
                B0(D, 15);
                var u0 = qt(j(D));
                if (u0 === 0) {
                  for (; ; )
                    if (B0(D, 15), hn(j(D)) !== 0)
                      return q(D);
                }
                return u0 === 1 ? x0(D) : q(D);
              }
              function c0(D) {
                for (; ; ) {
                  B0(D, 16);
                  var u0 = Xr0(j(D));
                  if (4 < u0 >>> 0)
                    return q(D);
                  switch (u0) {
                    case 0:
                      return x0(D);
                    case 1:
                      return g0(D);
                    case 2:
                      continue;
                    case 3:
                      for (; ; ) {
                        B0(D, 15);
                        var Y0 = i9(j(D));
                        if (3 < Y0 >>> 0)
                          return q(D);
                        switch (Y0) {
                          case 0:
                            return x0(D);
                          case 1:
                            return g0(D);
                          case 2:
                            continue;
                          default:
                            return l(D);
                        }
                      }
                    default:
                      return l(D);
                  }
                }
              }
              function t0(D) {
                B0(D, 30);
                var u0 = Pr0(j(D));
                if (3 < u0 >>> 0)
                  return q(D);
                switch (u0) {
                  case 0:
                    return e(D);
                  case 1:
                    for (; ; ) {
                      B0(D, 30);
                      var Y0 = Rs(j(D));
                      if (4 < Y0 >>> 0)
                        return q(D);
                      switch (Y0) {
                        case 0:
                          return e(D);
                        case 1:
                          continue;
                        case 2:
                          return T(D);
                        case 3:
                          r:
                            for (; ; ) {
                              if (pn(j(D)) === 0)
                                for (; ; ) {
                                  B0(D, 30);
                                  var J0 = Rs(j(D));
                                  if (4 < J0 >>> 0)
                                    return q(D);
                                  switch (J0) {
                                    case 0:
                                      return e(D);
                                    case 1:
                                      continue;
                                    case 2:
                                      return T(D);
                                    case 3:
                                      continue r;
                                    default:
                                      return i(D);
                                  }
                                }
                              return q(D);
                            }
                        default:
                          return i(D);
                      }
                    }
                  case 2:
                    return T(D);
                  default:
                    return i(D);
                }
              }
              function a0(D) {
                B0(D, 30);
                var u0 = mL(j(D));
                if (8 < u0 >>> 0)
                  return q(D);
                switch (u0) {
                  case 0:
                    return e(D);
                  case 1:
                    return t0(D);
                  case 2:
                    return c0(D);
                  case 3:
                    return e0(D);
                  case 4:
                    return m0(D);
                  case 5:
                    return T(D);
                  case 6:
                    return K(D);
                  case 7:
                    return A(D);
                  default:
                    return k0(D);
                }
              }
              function w0(D) {
                r:
                  for (; ; ) {
                    if (pn(j(D)) === 0)
                      for (; ; ) {
                        B0(D, 30);
                        var u0 = qr0(j(D));
                        if (4 < u0 >>> 0)
                          return q(D);
                        switch (u0) {
                          case 0:
                            return e(D);
                          case 1:
                            return g0(D);
                          case 2:
                            continue;
                          case 3:
                            continue r;
                          default:
                            return k0(D);
                        }
                      }
                    return q(D);
                  }
              }
              function _0(D) {
                for (; ; ) {
                  B0(D, 30);
                  var u0 = o9(j(D));
                  if (5 < u0 >>> 0)
                    return q(D);
                  switch (u0) {
                    case 0:
                      return e(D);
                    case 1:
                      return t0(D);
                    case 2:
                      continue;
                    case 3:
                      return T(D);
                    case 4:
                      return w0(D);
                    default:
                      return k0(D);
                  }
                }
              }
              function E0(D) {
                return B0(D, 3), zr0(j(D)) === 0 ? 3 : q(D);
              }
              function X0(D) {
                return _9(j(D)) === 0 && l9(j(D)) === 0 && Yr0(j(D)) === 0 && Lr0(j(D)) === 0 && Rr0(j(D)) === 0 && pL(j(D)) === 0 && Bl(j(D)) === 0 && _9(j(D)) === 0 && Gs(j(D)) === 0 && jr0(j(D)) === 0 && Ul(j(D)) === 0 ? 3 : q(D);
              }
              Tn(n);
              var b = j(n), G0 = tf < b ? pw < b ? -1 : Yk < b ? P3 < b ? Hw < b ? FE < b ? Zy < b ? 1 : 6 : Qh < b ? mE < b ? xF < b ? 1 : 6 : eO < b ? 1 : 6 : ZF < b ? _A < b ? 1 : 6 : bI < b ? 1 : 6 : P6 < b ? S4 < b ? a6 < b ? z8 < b ? G3 < b ? e3 < b ? LO < b ? 1 : 6 : GI < b ? 1 : 6 : Cy < b ? wg < b ? 1 : 6 : Uw < b ? 1 : 6 : R3 < b ? E8 < b ? Bg < b ? 1 : 6 : Z4 < b ? 1 : 6 : J8 < b ? JT < b ? 1 : 6 : Sk < b ? 1 : 6 : I4 < b ? KO < b ? b3 < b ? nw < b ? 1 : 6 : ok < b ? 1 : 6 : ap < b ? z6 < b ? 1 : 6 : Ah < b ? 1 : 6 : M8 < b ? v4 < b ? u6 < b ? 1 : 6 : U6 < b ? 1 : 6 : q6 < b ? g4 < b ? 1 : 6 : Ze < b ? 1 : 6 : GE < b ? B4 < b ? F6 < b ? TF < b ? f8 < b ? 1 : 6 : k8 < b ? 1 : 6 : T4 < b ? QF < b ? 1 : 6 : dd < b ? 1 : 6 : H6 < b ? t8 < b ? v3 < b ? 1 : 6 : g8 < b ? 1 : 6 : HS < b ? R8 < b ? 1 : 6 : W3 < b ? 1 : 6 : _8 < b ? x8 < b ? a8 < b ? E3 < b ? 1 : 6 : y6 < b ? 1 : 6 : v6 < b ? sF < b ? 1 : 6 : eI < b ? 1 : 6 : c3 < b ? jS < b ? n8 < b ? 1 : 6 : F8 < b ? 1 : 6 : $3 < b ? bF < b ? 1 : 6 : ag < b ? 1 : 6 : aw < b ? Fk < b ? gk < b ? Xk < b ? IT < b ? Wk < b ? 1 : 6 : xA < b ? 1 : 6 : Ey < b ? WS < b ? 1 : 6 : hh < b ? 1 : 6 : Ad < b ? yF < b ? IE < b ? 1 : 6 : eE < b ? 1 : 6 : Ty < b ? G_ < b ? 1 : 6 : LE < b ? 1 : 6 : GF < b ? Ww < b ? Uy < b ? tw < b ? 1 : 6 : zI < b ? 1 : 6 : BO < b ? cp < b ? 1 : 6 : BT < b ? 1 : 6 : ot < b ? NA < b ? OA < b ? 1 : 6 : 1 : 6 : s6 < b ? E6 < b ? b6 < b ? w3 < b ? WE < b ? 1 : 6 : Xw < b ? 1 : 6 : l4 < b ? iE < b ? 1 : 6 : Ay < b ? 1 : 6 : s3 < b ? z4 < b ? ug < b ? 1 : 6 : XF < b ? 1 : 6 : Y4 < b ? hT < b ? 1 : 6 : Ny < b ? 1 : 6 : L6 < b ? L4 < b ? z3 < b ? US < b ? 1 : 6 : Zw < b ? 1 : 6 : ly < b ? By < b ? 1 : 6 : WT < b ? 1 : 6 : q4 < b ? _d < b ? QT < b ? 1 : 6 : M3 < b ? 1 : 6 : e6 < b ? bO < b ? 1 : 6 : eS < b ? 1 : 6 : xT < b ? Q4 < b ? Kh < b ? rp < b ? R4 < b ? C6 < b ? lp < b ? j_ < b ? 1 : 6 : Rh < b ? 1 : 6 : yh < b ? Mg < b ? 1 : 6 : NS < b ? 1 : 6 : M6 < b ? A3 < b ? xk < b ? 1 : 6 : lE < b ? 1 : 6 : b8 < b ? b4 < b ? 1 : 6 : td < b ? 1 : 6 : B3 < b ? IS < b ? DE < b ? vT < b ? 1 : 6 : ST < b ? 1 : 6 : xS < b ? k3 < b ? 1 : 6 : Jh < b ? 1 : 6 : my < b ? O6 < b ? Rg < b ? 1 : 6 : py < b ? 1 : 6 : GO < b ? kF < b ? 1 : 6 : KF < b ? 1 : 6 : jI < b ? Mu < b ? BF < b ? Pd < b ? PO < b ? 1 : 6 : Lh < b ? 1 : 6 : Xd < b ? PS < b ? 1 : 6 : mA < b ? 1 : 6 : lO < b ? PI < b ? cI < b ? 1 : 6 : H_ < b ? 1 : 6 : wS < b ? oT < b ? 1 : 6 : dg < b ? 1 : 6 : DO < b ? Dw < b ? Kd < b ? mw < b ? 1 : 6 : nF < b ? 1 : 6 : Wg < b ? Gk < b ? 1 : 6 : XO < b ? 1 : 6 : aS < b ? p6 < b ? h6 < b ? 1 : 6 : rT < b ? 1 : 6 : yd < b ? tT < b ? 1 : 6 : VS < b ? 1 : 6 : JO < b ? Lk < b ? kS < b ? Cw < b ? LI < b ? $g < b ? 1 : 6 : WO < b ? 1 : 6 : Uk < b ? Ss < b ? 1 : 6 : RF < b ? 1 : 6 : Sh < b ? AS < b ? gI < b ? 1 : 6 : cg < b ? 1 : 6 : Mh < b ? Ed < b ? 1 : 6 : sI < b ? 1 : 6 : sT < b ? mg < b ? fF < b ? $I < b ? 1 : 6 : yk < b ? 1 : 6 : q_ < b ? Sw < b ? 1 : 6 : nT < b ? 1 : 6 : Bk < b ? IO < b ? dA < b ? 1 : 6 : hg < b ? 1 : 6 : ZE < b ? mF < b ? 1 : 6 : UF < b ? 1 : 6 : h4 < b ? h3 < b ? pT < b ? BI < b ? dS < b ? 1 : 6 : lA < b ? 1 : 6 : jE < b ? Jk < b ? 1 : 6 : Gg < b ? 1 : 6 : PT < b ? j6 < b ? _k < b ? 1 : 6 : aT < b ? 1 : 6 : YS < b ? HT < b ? 1 : 6 : pE < b ? 1 : 6 : Jc < b ? Tk < b ? L3 < b ? zg < b ? 1 : 6 : oh < b ? 1 : 6 : CF < b ? mh < b ? 1 : 6 : iA < b ? 1 : 6 : HE < b ? J3 < b ? by < b ? 1 : 6 : SI < b ? 1 : 6 : WF < b ? oS < b ? 1 : 6 : D4 < b ? 1 : 6 : pS < b ? Bw < b ? ak < b ? wO < b ? aI < b ? _g < b ? Dh < b ? 1 : 6 : i3 < b ? 1 : 6 : bE < b ? Gh < b ? 1 : 6 : zk < b ? 1 : 6 : ip < b ? wd < b ? B8 < b ? 1 : 6 : m3 < b ? 1 : 6 : Fw < b ? yE < b ? 1 : 6 : Hg < b ? 1 : 6 : _y < b ? ew < b ? rO < b ? JF < b ? 1 : 6 : Hh < b ? 1 : 6 : rw < b ? AI < b ? 1 : 6 : yO < b ? 1 : 6 : bS < b ? MO < b ? SA < b ? 1 : 6 : gA < b ? 1 : 6 : og < b ? XI < b ? 1 : 6 : ES < b ? 1 : 6 : wI < b ? DI < b ? iS < b ? zy < b ? Q_ < b ? 1 : 6 : _T < b ? 1 : 6 : rI < b ? Fg < b ? 1 : 6 : sA < b ? 1 : 6 : xE < b ? FT < b ? Eg < b ? 1 : 6 : AT < b ? 1 : 6 : Py < b ? i8 < b ? 1 : 6 : eg < b ? 1 : 6 : qd < b ? U_ < b ? TO < b ? md < b ? 1 : 6 : zE < b ? 1 : 6 : r6 < b ? Q6 < b ? 1 : 6 : Nh < b ? 1 : 6 : J6 < b ? MF < b ? Xy < b ? 1 : 6 : Dk < b ? 1 : 6 : RE < b ? Ag < b ? 1 : 6 : NI < b ? 1 : 6 : N8 < b ? R_ < b ? P4 < b ? rF < b ? Yd < b ? ZS < b ? 1 : 6 : G6 < b ? 1 : 6 : hE < b ? oI < b ? 1 : 6 : Rw < b ? 1 : 6 : x3 < b ? c8 < b ? YF < b ? 1 : 6 : Gw < b ? 1 : 6 : dk < b ? vI < b ? 1 : 6 : ky < b ? 1 : 6 : I8 < b ? xI < b ? i6 < b ? Sy < b ? 1 : 6 : qI < b ? 1 : 6 : s8 < b ? Nw < b ? 1 : 6 : _E < b ? 1 : 6 : d3 < b ? xp < b ? uE < b ? 1 : 6 : A8 < b ? 1 : 6 : lw < b ? $F < b ? 1 : 6 : WI < b ? 1 : 6 : Jd < b ? nI < b ? h8 < b ? wy < b ? uw < b ? 1 : 6 : f3 < b ? 1 : 6 : yI < b ? EA < b ? 1 : 6 : Xh < b ? 1 : 6 : Sg < b ? aE < b ? AO < b ? 1 : 6 : Y6 < b ? 1 : 6 : Mw < b ? vw < b ? 1 : 6 : T3 < b ? 1 : 6 : Ck < b ? NF < b ? Gy < b ? _4 < b ? 1 : 6 : lh < b ? 1 : 6 : Jg < b ? Qk < b ? 1 : 6 : vS < b ? 1 : 6 : q3 < b ? CO < b ? ww < b ? 1 : 6 : dE < b ? 1 : 6 : rg < b ? nA < b ? 1 : 6 : IA < b ? 1 : 6 : sh < b ? $E < b ? Mk < b ? $6 < b ? Uh < b ? cF < b ? eF < b ? bd < b ? uT < b ? 1 : 6 : KI < b ? 1 : 6 : ME < b ? NT < b ? 1 : 6 : $8 < b ? 1 : 6 : CA < b ? EE < b ? XT < b ? 1 : 6 : wh < b ? 1 : 6 : Ch < b ? Ud < b ? 1 : 6 : hS < b ? 1 : 6 : FA < b ? RO < b ? Vg < b ? bg < b ? 1 : 6 : Yg < b ? 1 : 6 : zw < b ? fh < b ? 1 : 6 : jg < b ? 1 : 6 : Pg < b ? _S < b ? Zh < b ? 1 : 6 : Ig < b ? 1 : 6 : fA < b ? gT < b ? 1 : 6 : jk < b ? 1 : 6 : tS < b ? Q8 < b ? QI < b ? PE < b ? UE < b ? 1 : 6 : yA < b ? 1 : 6 : FO < b ? qy < b ? 1 : 6 : oA < b ? 1 : 6 : cA < b ? p4 < b ? hk < b ? 1 : 6 : sO < b ? 1 : 6 : gh < b ? S7 < b ? 1 : 6 : rk < b ? 1 : 6 : Y8 < b ? J_ < b ? Ih < b ? Rd < b ? 1 : 6 : ET < b ? 1 : 6 : jh < b ? Nk < b ? 1 : 6 : vd < b ? 1 : 6 : id < b ? vg < b ? rE < b ? 1 : 6 : ZT < b ? 1 : 6 : ng < b ? Iw < b ? 1 : 6 : GT < b ? 1 : 6 : Cd < b ? pk < b ? fn < b ? m8 < b ? OT < b ? B6 < b ? 1 : 6 : Od < b ? 1 : 6 : $4 < b ? ny < b ? 1 : 6 : op < b ? 1 : 6 : pO < b ? qE < b ? ld < b ? 1 : 6 : X_ < b ? 1 : 6 : FS < b ? YT < b ? 1 : 6 : BS < b ? 1 : 6 : Yw < b ? fy < b ? bA < b ? Wd < b ? 1 : 6 : bT < b ? 1 : 6 : aF < b ? ek < b ? 1 : 6 : II < b ? 1 : 6 : cO < b ? fd < b ? ig < b ? 1 : 6 : _h < b ? 1 : 6 : aO < b ? hO < b ? 1 : 6 : uO < b ? 1 : 6 : CS < b ? JE < b ? oO < b ? lk < b ? cd < b ? 1 : 6 : xh < b ? 1 : 6 : QS < b ? hw < b ? 1 : 6 : Iy < b ? 1 : 6 : pA < b ? rS < b ? $T < b ? 1 : 6 : tI < b ? 1 : 6 : xy < b ? Aw < b ? 1 : 6 : 1 : iT < b ? Q3 < b ? uk < b ? 6 : rd < b ? 1 : 6 : qF < b ? nE < b ? 1 : 6 : bk < b ? 1 : 6 : pg < b ? iO < b ? fI < b ? 1 : 6 : qO < b ? 1 : 6 : My < b ? 1 : 6 : L8 < b ? Fh < b ? cw < b ? Nd < b ? tA < b ? 6 : rh < b ? fT < b ? 1 : 6 : pF < b ? 1 : 6 : nd < b ? JI < b ? ty < b ? 1 : 6 : kd < b ? 1 : 6 : VE < b ? Qd < b ? 1 : 6 : wF < b ? 1 : 6 : ep < b ? K4 < b ? g6 < b ? yy < b ? 1 : 6 : tg < b ? 1 : 6 : Z8 < b ? kO < b ? 1 : 6 : Hk < b ? 1 : 6 : Ok < b ? H8 < b ? FF < b ? 1 : 6 : gy < b ? 1 : 6 : sg < b ? Ak < b ? 1 : 6 : gE < b ? 1 : 6 : qw < b ? ry < b ? uy < b ? yS < b ? sE < b ? 1 : 6 : 1 : 6 : Ew < b ? 6 : r8 < b ? CT < b ? 1 : 6 : kg < b ? 1 : 6 : uI < b ? u3 < b ? qo < b ? La < b ? 1 : 2 : HI < b ? 1 : 6 : sw < b ? UT < b ? 1 : 6 : KS < b ? 1 : 6 : kI < b ? fS < b ? eh < b ? 1 : 6 : LT < b ? 1 : 6 : qT < b ? $w < b ? 1 : 6 : TI < b ? 1 : 6 : YI < b ? fk < b ? Jn < b ? j4 < b ? U3 < b ? ah < b ? 1 : 6 : hF < b ? 1 : 6 : K3 < b ? R6 < b ? 1 : 6 : od < b ? 1 : 6 : RT < b ? fp < b ? xw < b ? 1 : 6 : uS < b ? 1 : 6 : fO < b ? n3 < b ? 1 : 6 : sd < b ? 1 : 6 : Ek < b ? JS < b ? nh < b ? xg < b ? 1 : 6 : ay < b ? 1 : 6 : Zk < b ? $h < b ? 1 : 6 : AE < b ? 1 : 6 : Eh < b ? dy < b ? lF < b ? 1 : 6 : hA < b ? 1 : 6 : Dy < b ? 1 : 6 : zh < b ? X3 < b ? o3 < b ? Qw < b ? 1 : 6 : ov < b ? 6 : MT < b ? 1 : 6 : OF < b ? w6 < b ? DF < b ? 1 : 6 : Zd < b ? 1 : 6 : qk < b ? jd < b ? 1 : 6 : eA < b ? 1 : 6 : Wh < b ? lS < b ? mT < b ? lI < b ? 1 : 6 : 1 : jy < b ? 6 : Qy < b ? 1 : 6 : IF < b ? bh < b ? 1 : 6 : zT < b ? NO < b ? 1 : 6 : vO < b ? 1 : 6 : gd < b ? T8 < b ? Z_ < b ? xd < b ? SO < b ? uh < b ? FI < b ? Pw < b ? 1 : 6 : kA < b ? 1 : 6 : Hd < b ? oy < b ? 1 : 6 : vk < b ? 1 : 6 : LF < b ? AA < b ? bp < b ? 1 : 6 : 1 : 6 : kT < b ? Vh < b ? SS < b ? Jy < b ? 1 : 6 : gS < b ? 1 : 6 : l6 < b ? Vk < b ? 1 : 6 : SE < b ? 1 : 6 : Tw < b ? yw < b ? 1 : 6 : hd < b ? ZO < b ? 1 : 6 : w8 < b ? 1 : 6 : SF < b ? jO < b ? zF < b ? Oy < b ? Th < b ? 1 : 6 : uA < b ? 1 : 6 : ey < b ? QE < b ? 1 : 6 : vy < b ? 1 : 6 : $y < b ? y8 < b ? Yy < b ? 1 : 6 : t3 < b ? 1 : 6 : tE < b ? sy < b ? 1 : 6 : lg < b ? 1 : 6 : Ky < b ? TA < b ? cS < b ? tF < b ? 1 : 6 : zd < b ? 1 : 6 : dI < b ? mk < b ? 1 : 6 : xO < b ? 1 : 6 : RS < b && vA < b ? 1 : 6 : kk < b ? Md < b ? fg < b ? ik < b ? 6 : ed < b ? _I < b ? 1 : 6 : Ld < b ? 1 : 6 : cE < b ? sk < b ? W_ < b ? 1 : 6 : 1 : 6 : Ng < b ? YO < b && sS < b ? 1 : 6 : _w < b ? tO < b ? Gd < b ? 1 : 6 : 1 : EF < b ? 6 : 1 : Fd < b ? OE < b ? H3 < b ? 6 : fw < b ? 1 : 6 : EI < b ? nk < b ? gO < b ? 1 : 6 : M_ < b ? 1 : 6 : Td < b ? 1 : 6 : HF < b ? Og < b ? Ph < b ? 1 : 6 : zS < b ? 1 : 6 : $k < b ? KE < b ? 6 : ad < b ? 1 : 6 : Y_ < b ? kE < b ? 1 : 6 : Xt < b ? 1 : 6 : qS < b ? BE < b ? EO < b ? U4 < b ? Fy < b ? S8 < b ? MI < b ? 1 : 6 : iF < b ? 1 : 6 : VF < b ? 1 : 6 : gw < b ? S3 < b ? se < b ? 1 : 6 : 1 : 6 : Cg < b ? qh < b ? z_ < b ? V_ < b ? 1 : 6 : 1 : 6 : Vw < b ? O3 < b ? ph < b ? 1 : 6 : oF < b ? 1 : 6 : gg < b ? 1 : 6 : K8 < b ? G8 < b ? Sa < b ? RI < b ? 6 : ea < b ? 1 : 2 : T6 < b ? Hy < b ? 1 : 6 : CE < b ? 1 : 6 : W8 < b ? K6 < b ? Lg < b ? 1 : 6 : lT < b ? 1 : 6 : o8 < b ? it2 < b ? 1 : 6 : Pk < b ? 1 : 6 : DS < b ? fE < b ? G4 < b ? Dg < b ? 1 : 6 : rA < b ? 1 : 6 : D6 < b ? AF < b ? 1 : 6 : m4 < b ? 1 : 6 : hI < b ? oE < b ? OI < b ? 1 : 6 : C3 < b ? 1 : 6 : M4 < b ? q8 < b ? 1 : 6 : Tg < b ? 1 : 6 : C8 < b ? nS < b ? vE < b ? Kk < b ? yT < b ? $_ < b ? 1 : 6 : gF < b ? 1 : 6 : YE < b ? 1 : 6 : th < b ? pI < b ? 6 : 1 : 6 : UO < b ? dw < b ? KT < b ? v8 < b ? 1 : 6 : PA < b ? 1 : 6 : Kw < b ? K_ < b ? 1 : 6 : 1 : 6 : qg < b ? QO < b ? Z3 < b ? vp < b ? D8 < b ? 1 : 6 : r3 < b ? 1 : 6 : hr < b ? u8 < b ? 1 : 6 : 1 : F4 < b ? $S < b ? 6 : _6 < b ? 1 : 6 : dF < b ? Ly < b ? 1 : 6 : j3 < b ? 1 : 6 : Rk < b ? VI < b ? nO < b ? a3 < b ? 1 : 6 : dO < b ? 1 : 6 : Ry < b ? I3 < b ? 1 : 6 : np < b ? 1 : 6 : ya < b ? oc < b ? cx < b ? 1 : 2 : aa < b ? 1 : 2 : Ju < b ? Uu < b ? 1 : 3 : Pa < b ? 1 : 2 : Vr($Lr, b + 1 | 0) - 1 | 0;
              if (30 < G0 >>> 0)
                var X = q(n);
              else
                switch (G0) {
                  case 0:
                    var X = 62;
                    break;
                  case 1:
                    var X = 63;
                    break;
                  case 2:
                    if (B0(n, 1), Mc(j(n)) === 0) {
                      for (; ; )
                        if (B0(n, 1), Mc(j(n)) !== 0) {
                          var X = q(n);
                          break;
                        }
                    } else
                      var X = q(n);
                    break;
                  case 3:
                    var X = 0;
                    break;
                  case 4:
                    B0(n, 0);
                    var s0 = xi(j(n)) !== 0 ? 1 : 0, X = s0 && q(n);
                    break;
                  case 5:
                    var X = 6;
                    break;
                  case 6:
                    var X = 61;
                    break;
                  case 7:
                    if (B0(n, 63), Bl(j(n)) === 0) {
                      var dr = j(n), Ar = s7 < dr ? L7 < dr ? -1 : 0 : -1;
                      if (Ar === 0 && Ul(j(n)) === 0 && Bl(j(n)) === 0)
                        var ar = j(n), W0 = Vt < ar ? Qc < ar ? -1 : 0 : -1, X = W0 === 0 && Ar0(j(n)) === 0 ? 31 : q(n);
                      else
                        var X = q(n);
                    } else
                      var X = q(n);
                    break;
                  case 8:
                    var X = 56;
                    break;
                  case 9:
                    var X = 38;
                    break;
                  case 10:
                    var X = 39;
                    break;
                  case 11:
                    B0(n, 53);
                    var X = Vr0(j(n)) === 0 ? 4 : q(n);
                    break;
                  case 12:
                    var X = 59;
                    break;
                  case 13:
                    var X = 43;
                    break;
                  case 14:
                    B0(n, 60);
                    var Lr = ql(j(n));
                    if (3 < Lr >>> 0)
                      var X = q(n);
                    else
                      switch (Lr) {
                        case 0:
                          for (; ; ) {
                            var Tr = ql(j(n));
                            if (3 < Tr >>> 0)
                              var X = q(n);
                            else
                              switch (Tr) {
                                case 0:
                                  continue;
                                case 1:
                                  var X = h(n);
                                  break;
                                case 2:
                                  var X = a0(n);
                                  break;
                                default:
                                  var X = _0(n);
                              }
                            break;
                          }
                          break;
                        case 1:
                          var X = h(n);
                          break;
                        case 2:
                          var X = a0(n);
                          break;
                        default:
                          var X = _0(n);
                      }
                    break;
                  case 15:
                    B0(n, 41);
                    var Hr = L1(j(n)), X = Hr === 0 ? lL(j(n)) === 0 ? 40 : q(n) : Hr === 1 ? E(n) : q(n);
                    break;
                  case 16:
                    B0(n, 63);
                    var Or = k9(j(n));
                    if (Or === 0) {
                      B0(n, 2);
                      var xr = f9(j(n));
                      if (2 < xr >>> 0)
                        var X = q(n);
                      else
                        switch (xr) {
                          case 0:
                            for (; ; ) {
                              var Rr = f9(j(n));
                              if (2 < Rr >>> 0)
                                var X = q(n);
                              else
                                switch (Rr) {
                                  case 0:
                                    continue;
                                  case 1:
                                    var X = E0(n);
                                    break;
                                  default:
                                    var X = X0(n);
                                }
                              break;
                            }
                            break;
                          case 1:
                            var X = E0(n);
                            break;
                          default:
                            var X = X0(n);
                        }
                    } else
                      var X = Or === 1 ? 5 : q(n);
                    break;
                  case 17:
                    B0(n, 30);
                    var Wr = mL(j(n));
                    if (8 < Wr >>> 0)
                      var X = q(n);
                    else
                      switch (Wr) {
                        case 0:
                          var X = e(n);
                          break;
                        case 1:
                          var X = t0(n);
                          break;
                        case 2:
                          var X = c0(n);
                          break;
                        case 3:
                          var X = e0(n);
                          break;
                        case 4:
                          var X = m0(n);
                          break;
                        case 5:
                          var X = T(n);
                          break;
                        case 6:
                          var X = K(n);
                          break;
                        case 7:
                          var X = A(n);
                          break;
                        default:
                          var X = k0(n);
                      }
                    break;
                  case 18:
                    B0(n, 30);
                    var Jr = o9(j(n));
                    if (5 < Jr >>> 0)
                      var X = q(n);
                    else
                      switch (Jr) {
                        case 0:
                          var X = e(n);
                          break;
                        case 1:
                          var X = t0(n);
                          break;
                        case 2:
                          var X = _0(n);
                          break;
                        case 3:
                          var X = T(n);
                          break;
                        case 4:
                          var X = w0(n);
                          break;
                        default:
                          var X = k0(n);
                      }
                    break;
                  case 19:
                    var X = 44;
                    break;
                  case 20:
                    var X = 42;
                    break;
                  case 21:
                    var X = 49;
                    break;
                  case 22:
                    B0(n, 51);
                    var or = j(n), _r = 61 < or ? 62 < or ? -1 : 0 : -1, X = _r === 0 ? 57 : q(n);
                    break;
                  case 23:
                    var X = 50;
                    break;
                  case 24:
                    B0(n, 46);
                    var X = lL(j(n)) === 0 ? 45 : q(n);
                    break;
                  case 25:
                    var X = 32;
                    break;
                  case 26:
                    if (B0(n, 63), Gs(j(n)) === 0) {
                      var Ir = R1(j(n));
                      if (Ir === 0)
                        var X = Pn(j(n)) === 0 && Pn(j(n)) === 0 && Pn(j(n)) === 0 ? 61 : q(n);
                      else if (Ir === 1 && Pn(j(n)) === 0)
                        for (; ; ) {
                          var fe = N1(j(n));
                          if (fe !== 0) {
                            var X = fe === 1 ? 61 : q(n);
                            break;
                          }
                        }
                      else
                        var X = q(n);
                    } else
                      var X = q(n);
                    break;
                  case 27:
                    var X = 33;
                    break;
                  case 28:
                    B0(n, 34);
                    var v0 = j(n), P = us < v0 ? X2 < v0 ? -1 : 0 : -1, X = P === 0 ? 36 : q(n);
                    break;
                  case 29:
                    B0(n, 55);
                    var L = j(n), Q = X2 < L ? br < L ? -1 : 0 : -1, X = Q === 0 ? 37 : q(n);
                    break;
                  default:
                    var X = 35;
                }
              if (63 < X >>> 0)
                return ke(UCr);
              var i0 = X;
              if (32 <= i0)
                switch (i0) {
                  case 34:
                    return [0, t4, 0];
                  case 35:
                    return [0, t4, 1];
                  case 36:
                    return [0, t4, 2];
                  case 37:
                    return [0, t4, 3];
                  case 38:
                    return [0, t4, 4];
                  case 39:
                    return [0, t4, 5];
                  case 40:
                    return [0, t4, 12];
                  case 41:
                    return [0, t4, 10];
                  case 42:
                    return [0, t4, 8];
                  case 43:
                    return [0, t4, 9];
                  case 45:
                    return [0, t4, 83];
                  case 49:
                    return [0, t4, 98];
                  case 50:
                    return [0, t4, 99];
                  case 53:
                    return [0, t4, Vt];
                  case 55:
                    return [0, t4, 89];
                  case 56:
                    return [0, t4, 91];
                  case 57:
                    return [0, t4, 11];
                  case 59:
                    return [0, t4, s7];
                  case 60:
                    return [0, t4, L7];
                  case 61:
                    var l0 = n[6];
                    Kr0(n);
                    var S0 = Hl(t4, l0, n[3]);
                    fL(n, l0);
                    var T0 = Ll(n), er = re0(t4, T0), j0 = er[2], B = er[1], Z = Ee(j0, VCr);
                    if (0 <= Z) {
                      if (!(0 < Z))
                        return [0, B, Av];
                      if (!n0(j0, tPr))
                        return [0, B, 29];
                      if (!n0(j0, uPr))
                        return [0, B, A2];
                      if (!n0(j0, iPr))
                        return [0, B, 42];
                      if (!n0(j0, fPr))
                        return [0, B, Sv];
                      if (!n0(j0, xPr))
                        return [0, B, tl];
                      if (!n0(j0, aPr))
                        return [0, B, 31];
                      if (!n0(j0, oPr))
                        return [0, B, 46];
                      if (!n0(j0, cPr))
                        return [0, B, fc];
                    } else {
                      if (!n0(j0, zCr))
                        return [0, B, u1];
                      if (!n0(j0, KCr))
                        return [0, B, z2];
                      if (!n0(j0, WCr))
                        return [0, B, nPr];
                      if (!n0(j0, JCr))
                        return [0, B, ePr];
                      if (!n0(j0, $Cr))
                        return [0, B, x1];
                      if (!n0(j0, ZCr))
                        return [0, B, 41];
                      if (!n0(j0, QCr))
                        return [0, B, 30];
                      if (!n0(j0, rPr))
                        return [0, B, 53];
                    }
                    return [0, B, [4, S0, j0, xL(T0)]];
                  case 62:
                    var p0 = t4[4] ? Ru(t4, nt(t4, n), 6) : t4;
                    return [0, p0, Ln];
                  case 63:
                    return [0, t4, [6, Se(n)]];
                  case 32:
                  case 47:
                    return [0, t4, 6];
                  case 33:
                  case 48:
                    return [0, t4, 7];
                  case 44:
                  case 54:
                    return [0, t4, 86];
                  case 46:
                  case 52:
                    return [0, t4, 85];
                  default:
                    return [0, t4, 82];
                }
              switch (i0) {
                case 0:
                  return [2, h7(t4, n)];
                case 1:
                  return [2, t4];
                case 2:
                  var b0 = Lu(t4, n), O0 = Qn(Kn), q0 = j1(t4, O0, n), nr = q0[1];
                  return [1, nr, Si(nr, b0, q0[2], O0, 1)];
                case 3:
                  var yr = Se(n);
                  if (t4[5]) {
                    var vr = t4[4] ? Jr0(t4, nt(t4, n), yr) : t4, $0 = Zm(1, vr), Sr = $m(n);
                    return Un(jl(n, Sr - 1 | 0, 1), HCr) && n0(jl(n, Sr - 2 | 0, 1), XCr) ? [0, $0, 86] : [2, $0];
                  }
                  var Mr = Lu(t4, n), Br = Qn(Kn);
                  dn(Br, yr);
                  var qr = j1(t4, Br, n), jr = qr[1];
                  return [1, jr, Si(jr, Mr, qr[2], Br, 1)];
                case 4:
                  if (t4[4])
                    return [2, Zm(0, t4)];
                  $v(n), Tn(n);
                  var $r = Cr0(j(n)) !== 0 ? 1 : 0, ne = $r && q(n);
                  return ne === 0 ? [0, t4, Vt] : ke(YCr);
                case 5:
                  var Qr = Lu(t4, n), pe = Qn(Kn), oe = e2(t4, pe, n), me = oe[1];
                  return [1, me, Si(me, Qr, oe[2], pe, 0)];
                case 6:
                  var ae = Se(n), ce = Lu(t4, n), ge = Qn(Kn), H0 = Qn(Kn);
                  dn(H0, ae);
                  var Fr = ne0(t4, ae, ge, H0, 0, n), _ = Fr[1], k = [0, _[1], ce, Fr[2]], I = Fr[3], U = Bt(H0);
                  return [0, _, [2, [0, k, Bt(ge), U, I]]];
                case 7:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (s9(j(F0)) === 0) {
                        if (Bc(j(F0)) === 0)
                          for (; ; ) {
                            var gr = t9(j(F0));
                            if (2 < gr >>> 0)
                              return q(F0);
                            switch (gr) {
                              case 0:
                                continue;
                              case 1:
                                r:
                                  for (; ; ) {
                                    if (Bc(j(F0)) === 0)
                                      for (; ; ) {
                                        var mr = t9(j(F0));
                                        if (2 < mr >>> 0)
                                          return q(F0);
                                        switch (mr) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            return 0;
                                        }
                                      }
                                    return q(F0);
                                  }
                              default:
                                return 0;
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Xi(0, Se(u0))] : ke(qCr);
                  });
                case 8:
                  return [0, t4, Xi(0, Se(n))];
                case 9:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (s9(j(F0)) === 0) {
                        if (Bc(j(F0)) === 0)
                          for (; ; ) {
                            B0(F0, 0);
                            var gr = n9(j(F0));
                            if (gr !== 0) {
                              if (gr === 1)
                                r:
                                  for (; ; ) {
                                    if (Bc(j(F0)) === 0)
                                      for (; ; ) {
                                        B0(F0, 0);
                                        var mr = n9(j(F0));
                                        if (mr !== 0) {
                                          if (mr === 1)
                                            continue r;
                                          return q(F0);
                                        }
                                      }
                                    return q(F0);
                                  }
                              return q(F0);
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Hc(0, Se(u0))] : ke(BCr);
                  });
                case 10:
                  return [0, t4, Hc(0, Se(n))];
                case 11:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (p9(j(F0)) === 0) {
                        if (Vu(j(F0)) === 0)
                          for (; ; ) {
                            var gr = c9(j(F0));
                            if (2 < gr >>> 0)
                              return q(F0);
                            switch (gr) {
                              case 0:
                                continue;
                              case 1:
                                r:
                                  for (; ; ) {
                                    if (Vu(j(F0)) === 0)
                                      for (; ; ) {
                                        var mr = c9(j(F0));
                                        if (2 < mr >>> 0)
                                          return q(F0);
                                        switch (mr) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            return 0;
                                        }
                                      }
                                    return q(F0);
                                  }
                              default:
                                return 0;
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Xi(1, Se(u0))] : ke(MCr);
                  });
                case 12:
                  return [0, t4, Xi(1, Se(n))];
                case 13:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (p9(j(F0)) === 0) {
                        if (Vu(j(F0)) === 0)
                          for (; ; ) {
                            B0(F0, 0);
                            var gr = a9(j(F0));
                            if (gr !== 0) {
                              if (gr === 1)
                                r:
                                  for (; ; ) {
                                    if (Vu(j(F0)) === 0)
                                      for (; ; ) {
                                        B0(F0, 0);
                                        var mr = a9(j(F0));
                                        if (mr !== 0) {
                                          if (mr === 1)
                                            continue r;
                                          return q(F0);
                                        }
                                      }
                                    return q(F0);
                                  }
                              return q(F0);
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Hc(3, Se(u0))] : ke(GCr);
                  });
                case 14:
                  return [0, t4, Hc(3, Se(n))];
                case 15:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (Vu(j(F0)) === 0) {
                        for (; ; )
                          if (B0(F0, 0), Vu(j(F0)) !== 0)
                            return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Hc(1, Se(u0))] : ke(jCr);
                  });
                case 16:
                  return [0, t4, Hc(1, Se(n))];
                case 17:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (Qm(j(F0)) === 0) {
                        if (Pn(j(F0)) === 0)
                          for (; ; ) {
                            var gr = u9(j(F0));
                            if (2 < gr >>> 0)
                              return q(F0);
                            switch (gr) {
                              case 0:
                                continue;
                              case 1:
                                r:
                                  for (; ; ) {
                                    if (Pn(j(F0)) === 0)
                                      for (; ; ) {
                                        var mr = u9(j(F0));
                                        if (2 < mr >>> 0)
                                          return q(F0);
                                        switch (mr) {
                                          case 0:
                                            continue;
                                          case 1:
                                            continue r;
                                          default:
                                            return 0;
                                        }
                                      }
                                    return q(F0);
                                  }
                              default:
                                return 0;
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Xi(2, Se(u0))] : ke(RCr);
                  });
                case 19:
                  return jt(t4, n, function(D, u0) {
                    function Y0(F0) {
                      if (Qm(j(F0)) === 0) {
                        if (Pn(j(F0)) === 0)
                          for (; ; ) {
                            B0(F0, 0);
                            var gr = y9(j(F0));
                            if (gr !== 0) {
                              if (gr === 1)
                                r:
                                  for (; ; ) {
                                    if (Pn(j(F0)) === 0)
                                      for (; ; ) {
                                        B0(F0, 0);
                                        var mr = y9(j(F0));
                                        if (mr !== 0) {
                                          if (mr === 1)
                                            continue r;
                                          return q(F0);
                                        }
                                      }
                                    return q(F0);
                                  }
                              return q(F0);
                            }
                          }
                        return q(F0);
                      }
                      return q(F0);
                    }
                    Tn(u0);
                    var J0 = D1(j(u0));
                    if (J0 === 0)
                      for (; ; ) {
                        var fr = C1(j(u0));
                        if (fr !== 0) {
                          var Q0 = fr === 1 ? Y0(u0) : q(u0);
                          break;
                        }
                      }
                    else
                      var Q0 = J0 === 1 ? Y0(u0) : q(u0);
                    return Q0 === 0 ? [0, D, Hc(4, Se(u0))] : ke(LCr);
                  });
                case 21:
                  return jt(t4, n, function(D, u0) {
                    function Y0(d0) {
                      for (; ; ) {
                        var Kr = wi(j(d0));
                        if (2 < Kr >>> 0)
                          return q(d0);
                        switch (Kr) {
                          case 0:
                            continue;
                          case 1:
                            r:
                              for (; ; ) {
                                if (pn(j(d0)) === 0)
                                  for (; ; ) {
                                    var re = wi(j(d0));
                                    if (2 < re >>> 0)
                                      return q(d0);
                                    switch (re) {
                                      case 0:
                                        continue;
                                      case 1:
                                        continue r;
                                      default:
                                        return 0;
                                    }
                                  }
                                return q(d0);
                              }
                          default:
                            return 0;
                        }
                      }
                    }
                    function J0(d0) {
                      for (; ; ) {
                        var Kr = r2(j(d0));
                        if (Kr !== 0) {
                          var re = Kr !== 1 ? 1 : 0;
                          return re && q(d0);
                        }
                      }
                    }
                    function fr(d0) {
                      var Kr = S9(j(d0));
                      if (2 < Kr >>> 0)
                        return q(d0);
                      switch (Kr) {
                        case 0:
                          var re = P1(j(d0));
                          return re === 0 ? J0(d0) : re === 1 ? Y0(d0) : q(d0);
                        case 1:
                          return J0(d0);
                        default:
                          return Y0(d0);
                      }
                    }
                    function Q0(d0) {
                      if (pn(j(d0)) === 0)
                        for (; ; ) {
                          var Kr = i7(j(d0));
                          if (2 < Kr >>> 0)
                            return q(d0);
                          switch (Kr) {
                            case 0:
                              continue;
                            case 1:
                              return fr(d0);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(d0)) === 0)
                                    for (; ; ) {
                                      var re = i7(j(d0));
                                      if (2 < re >>> 0)
                                        return q(d0);
                                      switch (re) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return fr(d0);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(d0);
                                }
                          }
                        }
                      return q(d0);
                    }
                    function F0(d0) {
                      var Kr = m9(j(d0));
                      if (Kr === 0)
                        for (; ; ) {
                          var re = i7(j(d0));
                          if (2 < re >>> 0)
                            return q(d0);
                          switch (re) {
                            case 0:
                              continue;
                            case 1:
                              return fr(d0);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(d0)) === 0)
                                    for (; ; ) {
                                      var xe = i7(j(d0));
                                      if (2 < xe >>> 0)
                                        return q(d0);
                                      switch (xe) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return fr(d0);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(d0);
                                }
                          }
                        }
                      return Kr === 1 ? fr(d0) : q(d0);
                    }
                    function gr(d0) {
                      var Kr = e9(j(d0));
                      return Kr === 0 ? F0(d0) : Kr === 1 ? fr(d0) : q(d0);
                    }
                    function mr(d0) {
                      for (; ; ) {
                        var Kr = b9(j(d0));
                        if (2 < Kr >>> 0)
                          return q(d0);
                        switch (Kr) {
                          case 0:
                            return F0(d0);
                          case 1:
                            continue;
                          default:
                            return fr(d0);
                        }
                      }
                    }
                    Tn(u0);
                    var Cr = x9(j(u0));
                    if (3 < Cr >>> 0)
                      var sr = q(u0);
                    else
                      switch (Cr) {
                        case 0:
                          for (; ; ) {
                            var Pr = ql(j(u0));
                            if (3 < Pr >>> 0)
                              var sr = q(u0);
                            else
                              switch (Pr) {
                                case 0:
                                  continue;
                                case 1:
                                  var sr = Q0(u0);
                                  break;
                                case 2:
                                  var sr = gr(u0);
                                  break;
                                default:
                                  var sr = mr(u0);
                              }
                            break;
                          }
                          break;
                        case 1:
                          var sr = Q0(u0);
                          break;
                        case 2:
                          var sr = gr(u0);
                          break;
                        default:
                          var sr = mr(u0);
                      }
                    if (sr === 0) {
                      var K0 = Se(u0), Ur = Ru(D, nt(D, u0), 23);
                      return [0, Ur, Xi(2, K0)];
                    }
                    return ke(DCr);
                  });
                case 22:
                  var Y = Se(n), y0 = Ru(t4, nt(t4, n), 23);
                  return [0, y0, Xi(2, Y)];
                case 23:
                  return jt(t4, n, function(D, u0) {
                    function Y0(K0) {
                      for (; ; ) {
                        B0(K0, 0);
                        var Ur = js(j(K0));
                        if (Ur !== 0) {
                          if (Ur === 1)
                            r:
                              for (; ; ) {
                                if (pn(j(K0)) === 0)
                                  for (; ; ) {
                                    B0(K0, 0);
                                    var d0 = js(j(K0));
                                    if (d0 !== 0) {
                                      if (d0 === 1)
                                        continue r;
                                      return q(K0);
                                    }
                                  }
                                return q(K0);
                              }
                          return q(K0);
                        }
                      }
                    }
                    function J0(K0) {
                      for (; ; )
                        if (B0(K0, 0), pn(j(K0)) !== 0)
                          return q(K0);
                    }
                    function fr(K0) {
                      var Ur = S9(j(K0));
                      if (2 < Ur >>> 0)
                        return q(K0);
                      switch (Ur) {
                        case 0:
                          var d0 = P1(j(K0));
                          return d0 === 0 ? J0(K0) : d0 === 1 ? Y0(K0) : q(K0);
                        case 1:
                          return J0(K0);
                        default:
                          return Y0(K0);
                      }
                    }
                    function Q0(K0) {
                      if (pn(j(K0)) === 0)
                        for (; ; ) {
                          var Ur = i7(j(K0));
                          if (2 < Ur >>> 0)
                            return q(K0);
                          switch (Ur) {
                            case 0:
                              continue;
                            case 1:
                              return fr(K0);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(K0)) === 0)
                                    for (; ; ) {
                                      var d0 = i7(j(K0));
                                      if (2 < d0 >>> 0)
                                        return q(K0);
                                      switch (d0) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return fr(K0);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(K0);
                                }
                          }
                        }
                      return q(K0);
                    }
                    function F0(K0) {
                      var Ur = m9(j(K0));
                      if (Ur === 0)
                        for (; ; ) {
                          var d0 = i7(j(K0));
                          if (2 < d0 >>> 0)
                            return q(K0);
                          switch (d0) {
                            case 0:
                              continue;
                            case 1:
                              return fr(K0);
                            default:
                              r:
                                for (; ; ) {
                                  if (pn(j(K0)) === 0)
                                    for (; ; ) {
                                      var Kr = i7(j(K0));
                                      if (2 < Kr >>> 0)
                                        return q(K0);
                                      switch (Kr) {
                                        case 0:
                                          continue;
                                        case 1:
                                          return fr(K0);
                                        default:
                                          continue r;
                                      }
                                    }
                                  return q(K0);
                                }
                          }
                        }
                      return Ur === 1 ? fr(K0) : q(K0);
                    }
                    function gr(K0) {
                      var Ur = e9(j(K0));
                      return Ur === 0 ? F0(K0) : Ur === 1 ? fr(K0) : q(K0);
                    }
                    function mr(K0) {
                      for (; ; ) {
                        var Ur = b9(j(K0));
                        if (2 < Ur >>> 0)
                          return q(K0);
                        switch (Ur) {
                          case 0:
                            return F0(K0);
                          case 1:
                            continue;
                          default:
                            return fr(K0);
                        }
                      }
                    }
                    Tn(u0);
                    var Cr = x9(j(u0));
                    if (3 < Cr >>> 0)
                      var sr = q(u0);
                    else
                      switch (Cr) {
                        case 0:
                          for (; ; ) {
                            var Pr = ql(j(u0));
                            if (3 < Pr >>> 0)
                              var sr = q(u0);
                            else
                              switch (Pr) {
                                case 0:
                                  continue;
                                case 1:
                                  var sr = Q0(u0);
                                  break;
                                case 2:
                                  var sr = gr(u0);
                                  break;
                                default:
                                  var sr = mr(u0);
                              }
                            break;
                          }
                          break;
                        case 1:
                          var sr = Q0(u0);
                          break;
                        case 2:
                          var sr = gr(u0);
                          break;
                        default:
                          var sr = mr(u0);
                      }
                    return sr === 0 ? [0, D, Hc(4, Se(u0))] : ke(PCr);
                  });
                case 25:
                  return jt(t4, n, function(D, u0) {
                    function Y0(K0) {
                      for (; ; ) {
                        var Ur = wi(j(K0));
                        if (2 < Ur >>> 0)
                          return q(K0);
                        switch (Ur) {
                          case 0:
                            continue;
                          case 1:
                            r:
                              for (; ; ) {
                                if (pn(j(K0)) === 0)
                                  for (; ; ) {
                                    var d0 = wi(j(K0));
                                    if (2 < d0 >>> 0)
                                      return q(K0);
                                    switch (d0) {
                                      case 0:
                                        continue;
                                      case 1:
                                        continue r;
                                      default:
                                        return 0;
                                    }
                                  }
                                return q(K0);
                              }
                          default:
                            return 0;
                        }
                      }
                    }
                    function J0(K0) {
                      return pn(j(K0)) === 0 ? Y0(K0) : q(K0);
                    }
                    function fr(K0) {
                      var Ur = r2(j(K0));
                      if (Ur === 0)
                        return Y0(K0);
                      var d0 = Ur !== 1 ? 1 : 0;
                      return d0 && q(K0);
                    }
                    function Q0(K0) {
                      for (; ; ) {
                        var Ur = L1(j(K0));
                        if (Ur === 0)
                          return fr(K0);
                        if (Ur !== 1)
                          return q(K0);
                      }
                    }
                    function F0(K0) {
                      for (; ; ) {
                        var Ur = Uc(j(K0));
                        if (2 < Ur >>> 0)
                          return q(K0);
                        switch (Ur) {
                          case 0:
                            return fr(K0);
                          case 1:
                            continue;
                          default:
                            r:
                              for (; ; ) {
                                if (pn(j(K0)) === 0)
                                  for (; ; ) {
                                    var d0 = Uc(j(K0));
                                    if (2 < d0 >>> 0)
                                      return q(K0);
                                    switch (d0) {
                                      case 0:
                                        return fr(K0);
                                      case 1:
                                        continue;
                                      default:
                                        continue r;
                                    }
                                  }
                                return q(K0);
                              }
                        }
                      }
                    }
                    Tn(u0);
                    var gr = x9(j(u0));
                    if (3 < gr >>> 0)
                      var mr = q(u0);
                    else
                      switch (gr) {
                        case 0:
                          for (; ; ) {
                            var Cr = ql(j(u0));
                            if (3 < Cr >>> 0)
                              var mr = q(u0);
                            else
                              switch (Cr) {
                                case 0:
                                  continue;
                                case 1:
                                  var mr = J0(u0);
                                  break;
                                case 2:
                                  var mr = Q0(u0);
                                  break;
                                default:
                                  var mr = F0(u0);
                              }
                            break;
                          }
                          break;
                        case 1:
                          var mr = J0(u0);
                          break;
                        case 2:
                          var mr = Q0(u0);
                          break;
                        default:
                          var mr = F0(u0);
                      }
                    if (mr === 0) {
                      var sr = Se(u0), Pr = Ru(D, nt(D, u0), 22);
                      return [0, Pr, Xi(2, sr)];
                    }
                    return ke(CCr);
                  });
                case 26:
                  return jt(t4, n, function(D, u0) {
                    function Y0(mr) {
                      for (; ; ) {
                        var Cr = r2(j(mr));
                        if (Cr !== 0) {
                          var sr = Cr !== 1 ? 1 : 0;
                          return sr && q(mr);
                        }
                      }
                    }
                    function J0(mr) {
                      for (; ; ) {
                        var Cr = wi(j(mr));
                        if (2 < Cr >>> 0)
                          return q(mr);
                        switch (Cr) {
                          case 0:
                            continue;
                          case 1:
                            r:
                              for (; ; ) {
                                if (pn(j(mr)) === 0)
                                  for (; ; ) {
                                    var sr = wi(j(mr));
                                    if (2 < sr >>> 0)
                                      return q(mr);
                                    switch (sr) {
                                      case 0:
                                        continue;
                                      case 1:
                                        continue r;
                                      default:
                                        return 0;
                                    }
                                  }
                                return q(mr);
                              }
                          default:
                            return 0;
                        }
                      }
                    }
                    Tn(u0);
                    var fr = j(u0), Q0 = 44 < fr ? 57 < fr ? -1 : Vr(aLr, fr + mv | 0) - 1 | 0 : -1;
                    if (2 < Q0 >>> 0)
                      var F0 = q(u0);
                    else
                      switch (Q0) {
                        case 0:
                          for (; ; ) {
                            var gr = Ur0(j(u0));
                            if (2 < gr >>> 0)
                              var F0 = q(u0);
                            else
                              switch (gr) {
                                case 0:
                                  continue;
                                case 1:
                                  var F0 = Y0(u0);
                                  break;
                                default:
                                  var F0 = J0(u0);
                              }
                            break;
                          }
                          break;
                        case 1:
                          var F0 = Y0(u0);
                          break;
                        default:
                          var F0 = J0(u0);
                      }
                    return F0 === 0 ? [0, D, Xi(2, Se(u0))] : ke(NCr);
                  });
                case 27:
                  var D0 = Se(n), A0 = Ru(t4, nt(t4, n), 22);
                  return [0, A0, Xi(2, D0)];
                case 29:
                  return jt(t4, n, function(D, u0) {
                    function Y0(re) {
                      for (; ; ) {
                        B0(re, 0);
                        var xe = js(j(re));
                        if (xe !== 0) {
                          if (xe === 1)
                            r:
                              for (; ; ) {
                                if (pn(j(re)) === 0)
                                  for (; ; ) {
                                    B0(re, 0);
                                    var je = js(j(re));
                                    if (je !== 0) {
                                      if (je === 1)
                                        continue r;
                                      return q(re);
                                    }
                                  }
                                return q(re);
                              }
                          return q(re);
                        }
                      }
                    }
                    function J0(re) {
                      return B0(re, 0), pn(j(re)) === 0 ? Y0(re) : q(re);
                    }
                    Tn(u0);
                    var fr = x9(j(u0));
                    if (3 < fr >>> 0)
                      var Q0 = q(u0);
                    else
                      switch (fr) {
                        case 0:
                          for (; ; ) {
                            var F0 = Ur0(j(u0));
                            if (2 < F0 >>> 0)
                              var Q0 = q(u0);
                            else
                              switch (F0) {
                                case 0:
                                  continue;
                                case 1:
                                  for (; ; ) {
                                    B0(u0, 0);
                                    var gr = L1(j(u0)), mr = gr !== 0 ? 1 : 0;
                                    if (mr) {
                                      if (gr === 1)
                                        continue;
                                      var Q0 = q(u0);
                                    } else
                                      var Q0 = mr;
                                    break;
                                  }
                                  break;
                                default:
                                  for (; ; ) {
                                    B0(u0, 0);
                                    var Cr = Uc(j(u0));
                                    if (2 < Cr >>> 0)
                                      var Q0 = q(u0);
                                    else
                                      switch (Cr) {
                                        case 0:
                                          var Q0 = 0;
                                          break;
                                        case 1:
                                          continue;
                                        default:
                                          r:
                                            for (; ; ) {
                                              if (pn(j(u0)) === 0)
                                                for (; ; ) {
                                                  B0(u0, 0);
                                                  var sr = Uc(j(u0));
                                                  if (2 < sr >>> 0)
                                                    var Pr = q(u0);
                                                  else
                                                    switch (sr) {
                                                      case 0:
                                                        var Pr = 0;
                                                        break;
                                                      case 1:
                                                        continue;
                                                      default:
                                                        continue r;
                                                    }
                                                  break;
                                                }
                                              else
                                                var Pr = q(u0);
                                              var Q0 = Pr;
                                              break;
                                            }
                                      }
                                    break;
                                  }
                              }
                            break;
                          }
                          break;
                        case 1:
                          var Q0 = pn(j(u0)) === 0 ? Y0(u0) : q(u0);
                          break;
                        case 2:
                          for (; ; ) {
                            B0(u0, 0);
                            var K0 = L1(j(u0));
                            if (K0 === 0)
                              var Q0 = J0(u0);
                            else {
                              if (K0 === 1)
                                continue;
                              var Q0 = q(u0);
                            }
                            break;
                          }
                          break;
                        default:
                          for (; ; ) {
                            B0(u0, 0);
                            var Ur = Uc(j(u0));
                            if (2 < Ur >>> 0)
                              var Q0 = q(u0);
                            else
                              switch (Ur) {
                                case 0:
                                  var Q0 = J0(u0);
                                  break;
                                case 1:
                                  continue;
                                default:
                                  r:
                                    for (; ; ) {
                                      if (pn(j(u0)) === 0)
                                        for (; ; ) {
                                          B0(u0, 0);
                                          var d0 = Uc(j(u0));
                                          if (2 < d0 >>> 0)
                                            var Kr = q(u0);
                                          else
                                            switch (d0) {
                                              case 0:
                                                var Kr = J0(u0);
                                                break;
                                              case 1:
                                                continue;
                                              default:
                                                continue r;
                                            }
                                          break;
                                        }
                                      else
                                        var Kr = q(u0);
                                      var Q0 = Kr;
                                      break;
                                    }
                              }
                            break;
                          }
                      }
                    return Q0 === 0 ? [0, D, Hc(4, Se(u0))] : ke(ACr);
                  });
                case 31:
                  return [0, t4, 66];
                case 18:
                case 28:
                  return [0, t4, Xi(2, Se(n))];
                default:
                  return [0, t4, Hc(4, Se(n))];
              }
            }
            function Xl(t4) {
              return function(n) {
                for (var e = 0, i = n; ; ) {
                  var x = a(t4, i, i[2]);
                  switch (x[0]) {
                    case 0:
                      var c = x[2], s = x[1], p = Wr0(s, c), y = e === 0 ? 0 : de(e), T = s[6];
                      if (T === 0)
                        return [0, [0, s[1], s[2], s[3], s[4], s[5], s[6], p], [0, c, p, 0, y]];
                      var E = [0, c, p, de(T), y];
                      return [0, [0, s[1], s[2], s[3], s[4], s[5], wr0, p], E];
                    case 1:
                      var h = x[2], w = x[1], e = [0, h, e], i = [0, w[1], w[2], w[3], w[4], w[5], w[6], h[1]];
                      continue;
                    default:
                      var i = x[1];
                      continue;
                  }
                }
              };
            }
            var nne = Xl(Zee), tne = Xl(Qee), une = Xl(rne), ine = Xl(ene), fne = Xl($ee), ju = uL([0, dz]);
            function Yl(t4, n) {
              return [0, 0, 0, n, Er0(t4)];
            }
            function F9(t4) {
              var n = t4[4];
              switch (t4[3]) {
                case 0:
                  var c0 = u(fne, n);
                  break;
                case 1:
                  var c0 = u(ine, n);
                  break;
                case 2:
                  var c0 = u(tne, n);
                  break;
                case 3:
                  var e = d7(n, n[2]), i = Qn(Kn), x = Qn(Kn), c = n[2];
                  Tn(c);
                  var s = j(c), p = us < s ? Uu < s ? 1 : Ju < s ? 2 : 1 : Vr(SRr, s + 1 | 0) - 1 | 0;
                  if (5 < p >>> 0)
                    var y = q(c);
                  else
                    switch (p) {
                      case 0:
                        var y = 1;
                        break;
                      case 1:
                        var y = 4;
                        break;
                      case 2:
                        var y = 0;
                        break;
                      case 3:
                        B0(c, 0);
                        var T = xi(j(c)) !== 0 ? 1 : 0, y = T && q(c);
                        break;
                      case 4:
                        var y = 2;
                        break;
                      default:
                        var y = 3;
                    }
                  if (4 < y >>> 0)
                    var E = ke(ICr);
                  else
                    switch (y) {
                      case 0:
                        var h = Se(c);
                        dn(x, h), dn(i, h);
                        var w = yL(h7(n, c), 2, i, x, c), G = d7(w, c), A = Bt(i), S = Bt(x), E = [0, w, [8, [0, w[1], e, G], A, S]];
                        break;
                      case 1:
                        var E = [0, n, Ln];
                        break;
                      case 2:
                        var E = [0, n, 98];
                        break;
                      case 3:
                        var E = [0, n, 0];
                        break;
                      default:
                        $v(c);
                        var M = yL(n, 2, i, x, c), K = d7(M, c), V = Bt(i), f0 = Bt(x), E = [0, M, [8, [0, M[1], e, K], V, f0]];
                    }
                  var m0 = E[2], k0 = E[1], g0 = Wr0(k0, m0), e0 = k0[6];
                  if (e0 === 0)
                    var l = [0, k0, [0, m0, g0, 0, 0]];
                  else
                    var x0 = [0, m0, g0, de(e0), 0], l = [0, [0, k0[1], k0[2], k0[3], k0[4], k0[5], 0, k0[7]], x0];
                  var c0 = l;
                  break;
                case 4:
                  var c0 = u(une, n);
                  break;
                default:
                  var c0 = u(nne, n);
              }
              var t0 = c0[1], a0 = Er0(t0), w0 = [0, a0, c0[2]];
              return t4[4] = t0, t4[1] ? t4[2] = [0, w0] : t4[1] = [0, w0], w0;
            }
            function ue0(t4) {
              var n = t4[1];
              return n ? n[1][2] : F9(t4)[2];
            }
            function xne(t4, n, e, i) {
              var x = t4 && t4[1], c = n && n[1];
              try {
                var s = 0, p = hr0(i), y = s, T = p;
              } catch (A) {
                if (A = gt(A), A !== A1)
                  throw A;
                var E = [0, [0, [0, e, fz[2], fz[3]], 86], 0], y = E, T = hr0(aGr);
              }
              var h = c ? c[1] : Bv, w = Jee(e, T, h[4]), G = [0, Yl(w, 0)];
              return [0, [0, y], [0, 0], ju[1], [0, 0], h[5], 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, [0, cGr], [0, w], G, [0, x], h, e, [0, 0], [0, oGr]];
            }
            function n2(t4) {
              return bl(t4[23][1]);
            }
            function iu(t4) {
              return t4[27][4];
            }
            function ue(t4, n) {
              var e = n[2];
              t4[1][1] = [0, [0, n[1], e], t4[1][1]];
              var i = t4[22];
              return i && a(i[1], t4, e);
            }
            function Vl(t4, n) {
              return t4[30][1] = n, 0;
            }
            function Ms(t4, n) {
              if (t4 === 0)
                return ue0(n[25][1]);
              if (t4 === 1) {
                var e = n[25][1];
                e[1] || F9(e);
                var i = e[2];
                return i ? i[1][2] : F9(e)[2];
              }
              throw [0, Fn, iGr];
            }
            function ys(t4, n) {
              return t4 === n[5] ? n : [0, n[1], n[2], n[3], n[4], t4, n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function dL(t4, n) {
              return t4 === n[17] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], t4, n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function ie0(t4, n) {
              return t4 === n[18] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], t4, n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function fe0(t4, n) {
              return t4 === n[19] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], t4, n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function t22(t4, n) {
              return t4 === n[21] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], t4, n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function T9(t4, n) {
              return t4 === n[14] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], t4, n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function zl(t4, n) {
              return t4 === n[8] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], t4, n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function Kl(t4, n) {
              return t4 === n[12] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], t4, n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function u2(t4, n) {
              return t4 === n[15] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], t4, n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function xe0(t4, n) {
              return t4 === n[6] ? n : [0, n[1], n[2], n[3], n[4], n[5], t4, n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function ae0(t4, n) {
              return t4 === n[7] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], t4, n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function hL(t4, n) {
              return t4 === n[13] ? n : [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], t4, n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], n[22], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function O9(t4, n) {
              return [0, n[1], n[2], n[3], n[4], n[5], n[6], n[7], n[8], n[9], n[10], n[11], n[12], n[13], n[14], n[15], n[16], n[17], n[18], n[19], n[20], n[21], [0, t4], n[23], n[24], n[25], n[26], n[27], n[28], n[29], n[30]];
            }
            function kL(t4) {
              function n(e) {
                return ue(t4, e);
              }
              return function(e) {
                return Cu(n, e);
              };
            }
            function i2(t4) {
              var n = t4[4][1], e = n && [0, n[1][2]];
              return e;
            }
            function oe0(t4) {
              var n = t4[4][1], e = n && [0, n[1][1]];
              return e;
            }
            function ce0(t4) {
              return [0, t4[1], t4[2], t4[3], t4[4], t4[5], t4[6], t4[7], t4[8], t4[9], t4[10], t4[11], t4[12], t4[13], t4[14], t4[15], t4[16], t4[17], t4[18], t4[19], t4[20], t4[21], 0, t4[23], t4[24], t4[25], t4[26], t4[27], t4[28], t4[29], t4[30]];
            }
            function se0(t4, n, e, i) {
              return [0, t4[1], t4[2], ju[1], t4[4], t4[5], 0, 0, 0, 0, 0, 1, t4[12], t4[13], t4[14], t4[15], t4[16], e, n, t4[19], i, t4[21], t4[22], t4[23], t4[24], t4[25], t4[26], t4[27], t4[28], t4[29], t4[30]];
            }
            function ve0(t4) {
              var n = Ee(t4, gjr), e = 0;
              if (0 <= n) {
                if (0 < n) {
                  var i = Ee(t4, Hjr);
                  0 <= i ? 0 < i && n0(t4, Zjr) && n0(t4, Qjr) && n0(t4, rGr) && n0(t4, eGr) && n0(t4, nGr) && n0(t4, tGr) && n0(t4, uGr) && (e = 1) : n0(t4, Xjr) && n0(t4, Yjr) && n0(t4, Vjr) && n0(t4, zjr) && n0(t4, Kjr) && n0(t4, Wjr) && n0(t4, Jjr) && n0(t4, $jr) && (e = 1);
                }
              } else {
                var x = Ee(t4, Fjr);
                0 <= x ? 0 < x && n0(t4, Ljr) && n0(t4, Rjr) && n0(t4, jjr) && n0(t4, Gjr) && n0(t4, Mjr) && n0(t4, Bjr) && n0(t4, qjr) && n0(t4, Ujr) && (e = 1) : n0(t4, Tjr) && n0(t4, Ojr) && n0(t4, Ijr) && n0(t4, Ajr) && n0(t4, Njr) && n0(t4, Cjr) && n0(t4, Pjr) && n0(t4, Djr) && (e = 1);
              }
              return e ? 0 : 1;
            }
            function I9(t4) {
              return n0(t4, Sjr) ? 0 : 1;
            }
            function wL(t4) {
              if (typeof t4 == "number") {
                if (t4 === 48)
                  return 1;
              } else if (t4[0] === 4 && I9(t4[3]))
                return 1;
              return 0;
            }
            function f2(t4) {
              return n0(t4, mjr) && n0(t4, _jr) && n0(t4, yjr) && n0(t4, djr) && n0(t4, hjr) && n0(t4, kjr) && n0(t4, wjr) && n0(t4, Ejr) ? 0 : 1;
            }
            function EL(t4) {
              if (typeof t4 == "number")
                switch (t4) {
                  case 42:
                  case 52:
                  case 53:
                  case 54:
                  case 55:
                  case 56:
                  case 57:
                  case 58:
                    return 1;
                }
              else if (t4[0] === 4 && f2(t4[3]))
                return 1;
              return 0;
            }
            function Bs(t4) {
              return n0(t4, bjr) && n0(t4, pjr) ? 0 : 1;
            }
            function le0(t4) {
              return typeof t4 != "number" && t4[0] === 4 && Bs(t4[3]) ? 1 : 0;
            }
            function SL(t4) {
              var n = ve0(t4);
              if (n)
                var e = n;
              else {
                var i = I9(t4);
                if (i)
                  var e = i;
                else {
                  if (n0(t4, sjr) && n0(t4, vjr) && n0(t4, ljr))
                    return 0;
                  var e = 1;
                }
              }
              return e;
            }
            function be0(t4) {
              var n = Ee(t4, YRr), e = 0;
              return 0 <= n ? 0 < n && n0(t4, rjr) && n0(t4, ejr) && n0(t4, njr) && n0(t4, tjr) && n0(t4, ujr) && n0(t4, ijr) && n0(t4, fjr) && n0(t4, xjr) && (e = 1) : n0(t4, VRr) && n0(t4, zRr) && n0(t4, KRr) && n0(t4, WRr) && n0(t4, JRr) && n0(t4, $Rr) && n0(t4, ZRr) && n0(t4, QRr) && (e = 1), e ? 0 : 1;
            }
            function Vn(t4, n) {
              return Ms(t4, n)[1];
            }
            function Wl(t4, n) {
              return Ms(t4, n)[2];
            }
            function N0(t4) {
              return Vn(0, t4);
            }
            function Le(t4) {
              return Wl(0, t4);
            }
            function G1(t4) {
              var n = i2(t4), e = n ? n[1] : ke(XRr);
              return [0, e[1], e[3], e[3]];
            }
            function gL(t4) {
              return Ms(0, t4)[3];
            }
            function pr(t4) {
              var n = Ms(0, t4)[4];
              return n && u(ml(function(e) {
                return ms(t4[30][1], e[1][2]) <= 0 ? 1 : 0;
              }), n);
            }
            function pe0(t4) {
              for (var n = Ms(0, t4)[4]; ; ) {
                if (n) {
                  var e = n[2], i = ms(n[1][1][2], t4[30][1]) < 0 ? 1 : 0;
                  if (i)
                    return i;
                  var n = e;
                  continue;
                }
                return 0;
              }
            }
            function Jl(t4, n) {
              var e = 0 < t4 ? [0, Wl(t4 - 1 | 0, n)] : i2(n);
              if (e)
                var i = e[1][2][1], x = i < Wl(t4, n)[2][1] ? 1 : 0;
              else
                var x = e;
              return x;
            }
            function f7(t4) {
              return Jl(0, t4);
            }
            function me0(t4, n) {
              var e = Vn(t4, n);
              if (typeof e == "number") {
                var i = e - 2 | 0;
                if (Yt < i >>> 0) {
                  if (!(T7 < (i + 1 | 0) >>> 0))
                    return 1;
                } else {
                  var x = i !== 6 ? 1 : 0;
                  if (!x)
                    return x;
                }
              }
              return Jl(t4, n);
            }
            function x2(t4) {
              return me0(0, t4);
            }
            function A9(t4, n) {
              var e = Vn(t4, n);
              if (EL(e) || wL(e) || le0(e))
                return 1;
              var i = 0;
              if (typeof e == "number")
                switch (e) {
                  case 14:
                  case 28:
                  case 60:
                  case 61:
                  case 62:
                  case 63:
                  case 64:
                  case 65:
                    i = 1;
                    break;
                }
              else
                e[0] === 4 && (i = 1);
              return i ? 1 : 0;
            }
            function _e0(t4, n) {
              var e = n2(n);
              if (e === 1) {
                var i = Vn(t4, n);
                return typeof i != "number" && i[0] === 4 ? 1 : 0;
              }
              if (e)
                return 0;
              var x = Vn(t4, n);
              if (typeof x == "number")
                switch (x) {
                  case 42:
                  case 46:
                  case 47:
                    return 0;
                  case 15:
                  case 16:
                  case 17:
                  case 18:
                  case 19:
                  case 20:
                  case 21:
                  case 22:
                  case 23:
                  case 24:
                  case 25:
                  case 26:
                  case 27:
                  case 28:
                  case 29:
                  case 30:
                  case 31:
                  case 32:
                  case 33:
                  case 34:
                  case 35:
                  case 36:
                  case 37:
                  case 38:
                  case 39:
                  case 40:
                  case 41:
                  case 43:
                  case 44:
                  case 45:
                  case 48:
                  case 49:
                  case 50:
                  case 51:
                  case 52:
                  case 53:
                  case 54:
                  case 55:
                  case 56:
                  case 57:
                  case 58:
                  case 59:
                  case 60:
                  case 61:
                  case 62:
                  case 63:
                  case 64:
                  case 65:
                  case 114:
                  case 115:
                  case 116:
                  case 117:
                  case 118:
                  case 119:
                  case 120:
                  case 121:
                    break;
                  default:
                    return 0;
                }
              else
                switch (x[0]) {
                  case 4:
                    if (be0(x[3]))
                      return 0;
                    break;
                  case 9:
                  case 10:
                  case 11:
                    break;
                  default:
                    return 0;
                }
              return 1;
            }
            function M1(t4) {
              return A9(0, t4);
            }
            function qs(t4) {
              var n = N0(t4) === 15 ? 1 : 0;
              if (n)
                var e = n;
              else {
                var i = N0(t4) === 64 ? 1 : 0;
                if (i) {
                  var x = Vn(1, t4) === 15 ? 1 : 0;
                  if (x)
                    var c = Wl(1, t4)[2][1], e = Le(t4)[3][1] === c ? 1 : 0;
                  else
                    var e = x;
                } else
                  var e = i;
              }
              return e;
            }
            function $l(t4) {
              var n = N0(t4);
              if (typeof n == "number") {
                var e = 0;
                if ((n === 13 || n === 40) && (e = 1), e)
                  return 1;
              }
              return 0;
            }
            function Ge(t4, n) {
              return ue(t4, [0, Le(t4), n]);
            }
            function ye0(t4, n) {
              if (wL(n))
                return 2;
              if (EL(n))
                return 55;
              var e = vL(0, n);
              return t4 ? [11, e, t4[1]] : [10, e];
            }
            function Ft(t4, n) {
              var e = gL(n);
              return u(kL(n), e), Ge(n, ye0(t4, N0(n)));
            }
            function N9(t4) {
              function n(e) {
                return ue(t4, [0, e[1], 76]);
              }
              return function(e) {
                return Cu(n, e);
              };
            }
            function de0(t4, n) {
              var e = t4[6] ? ir(et(URr), n, n, n) : HRr;
              return Ft([0, e], t4);
            }
            function gi(t4, n) {
              var e = t4[5];
              return e && Ge(t4, n);
            }
            function V7(t4, n) {
              var e = t4[5];
              return e && ue(t4, [0, n[1], n[2]]);
            }
            function B1(t4, n) {
              return ue(t4, [0, n, [18, t4[5]]]);
            }
            function ie(t4) {
              var n = t4[26][1];
              if (n) {
                var e = n2(t4), i = N0(t4), x = [0, Le(t4), i, e];
                u(n[1], x);
              }
              var c = t4[25][1], s = c[1], p = s ? s[1][1] : F9(c)[1];
              t4[24][1] = p;
              var y = gL(t4);
              u(kL(t4), y);
              var T = t4[2][1], E = jc(Ms(0, t4)[4], T);
              t4[2][1] = E;
              var h = [0, Ms(0, t4)];
              t4[4][1] = h;
              var w = t4[25][1];
              return w[2] ? (w[1] = w[2], w[2] = 0, 0) : (ue0(w), w[1] = 0, 0);
            }
            function fu(t4, n) {
              var e = a(aL, N0(t4), n);
              return e && ie(t4), e;
            }
            function zu(t4, n) {
              t4[23][1] = [0, n, t4[23][1]];
              var e = n2(t4), i = Yl(t4[24][1], e);
              return t4[25][1] = i, 0;
            }
            function k7(t4) {
              var n = t4[23][1], e = n ? n[2] : ke(qRr);
              t4[23][1] = e;
              var i = n2(t4), x = Yl(t4[24][1], i);
              return t4[25][1] = x, 0;
            }
            function we(t4) {
              var n = Le(t4);
              if (N0(t4) === 9 && Jl(1, t4)) {
                var e = pr(t4), i = Ms(1, t4)[4], x = xn(e, u(ml(function(s) {
                  return s[1][2][1] <= n[3][1] ? 1 : 0;
                }), i));
                return Vl(t4, [0, n[3][1] + 1 | 0, 0]), x;
              }
              var c = pr(t4);
              return Vl(t4, n[3]), c;
            }
            function Us(t4) {
              var n = t4[4][1];
              if (n) {
                var e = n[1][2], i = pr(t4), x = u(ml(function(p) {
                  return p[1][2][1] <= e[3][1] ? 1 : 0;
                }), i);
                Vl(t4, [0, e[3][1] + 1 | 0, 0]);
                var c = x;
              } else
                var c = n;
              return c;
            }
            function q1(t4, n) {
              return Ft([0, vL(jRr, n)], t4);
            }
            function V0(t4, n) {
              return 1 - a(aL, N0(t4), n) && q1(t4, n), ie(t4);
            }
            function he0(t4, n) {
              var e = fu(t4, n);
              return 1 - e && q1(t4, n), e;
            }
            function Zl(t4, n) {
              var e = N0(t4), i = 0;
              return typeof e != "number" && e[0] === 4 && Un(e[3], n) && (i = 1), i || Ft([0, u(et(RRr), n)], t4), ie(t4);
            }
            var Hs = [St, sGr, M7(0)];
            function ane(t4) {
              var n = t4[26][1];
              if (n) {
                var e = kz(0), i = [0, function(s) {
                  return vN(s, e);
                }];
                t4[26][1] = i;
                var x = [0, [0, n[1], e]];
              } else
                var x = n;
              return [0, t4[1][1], t4[2][1], t4[4][1], t4[23][1], t4[24][1], t4[30][1], x];
            }
            function ke0(t4, n, e) {
              if (e) {
                var i = e[1], x = i[1];
                if (n[26][1] = [0, x], t4)
                  for (var c = i[2][2]; ; ) {
                    if (c) {
                      var s = c[2];
                      u(x, c[1]);
                      var c = s;
                      continue;
                    }
                    return 0;
                  }
                var p = t4;
              } else
                var p = e;
              return p;
            }
            function one(t4, n) {
              ke0(0, t4, n[7]), t4[1][1] = n[1], t4[2][1] = n[2], t4[4][1] = n[3], t4[23][1] = n[4], t4[24][1] = n[5], t4[30][1] = n[6];
              var e = n2(t4), i = Yl(t4[24][1], e);
              return t4[25][1] = i, 0;
            }
            function cne(t4, n, e) {
              return ke0(1, t4, n[7]), [0, e];
            }
            function FL(t4, n) {
              var e = ane(t4);
              try {
                var i = cne(t4, e, u(n, t4));
                return i;
              } catch (x) {
                if (x = gt(x), x === Hs)
                  return one(t4, e);
                throw x;
              }
            }
            function we0(t4, n, e) {
              var i = FL(t4, e);
              return i ? i[1] : n;
            }
            function Ql(t4, n) {
              var e = de(n);
              if (e) {
                var i = e[1], x = u(t4, i);
                return i === x ? n : de([0, x, e[2]]);
              }
              return n;
            }
            var Ee0 = jp(mGr, function(t4) {
              var n = RN(t4, lGr), e = DN(t4, pGr), i = e[22], x = e[26], c = e[35], s = e[77], p = e[cV], y = e[OO], T = e[sp], E = e[HO], h = e[Bd], w = e[eT], G = e[6], A = e[7], S = e[10], M = e[17], K = e[21], V = e[27], f0 = e[33], m0 = e[36], k0 = e[46], g0 = e[51], e0 = e[89], x0 = e[92], l = e[97], c0 = e[99], t0 = e[ti], a0 = e[Ln], w0 = e[Sv], _0 = e[Jw], E0 = e[Qg], X0 = e[gH], b = e[MX], G0 = e[fH], X = e[NH], s0 = e[Sd], dr = e[PF], Ar = e[Zg], ar = e[N6], W0 = e[Lw], Lr = e[aA], Tr = e[tk], Hr = e[wT], Or = e[mO], xr = e[f6], Rr = e[TT], Wr = e[l8], Jr = e[$2], or = GN(t4, 0, 0, xz, $D, 1)[1];
              function _r(H0, Fr, _) {
                var k = _[2], I = k[2], U = k[1], Y = _[1];
                if (I) {
                  var y0 = function(D) {
                    return [0, Y, [0, U, [0, D]]];
                  }, D0 = I[1];
                  return ee(u(H0[1][1 + y], H0), D0, _, y0);
                }
                function A0(D) {
                  return [0, Y, [0, D, I]];
                }
                return ee(a(H0[1][1 + G], H0, Fr), U, _, A0);
              }
              function Ir(H0, Fr, _) {
                var k = _[2], I = _[1], U = I[3], Y = I[2];
                if (U)
                  var y0 = Ql(u(H0[1][1 + x], H0), U), D0 = Y;
                else
                  var y0 = 0, D0 = a(H0[1][1 + x], H0, Y);
                var A0 = a(H0[1][1 + c], H0, k);
                return Y === D0 && U === y0 && k === A0 ? _ : [0, [0, I[1], D0, y0], A0];
              }
              function fe(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function v0(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], _[2], U];
                }
                var I = _[3];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function P(H0, Fr) {
                function _(I) {
                  return [0, Fr[1], I];
                }
                var k = Fr[2];
                return ee(u(H0[1][1 + c], H0), k, Fr, _);
              }
              function L(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], _[2], U];
                }
                var I = _[3];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function Q(H0, Fr, _) {
                var k = _[2], I = _[1], U = Ql(u(H0[1][1 + y], H0), I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, U, Y];
              }
              function i0(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function l0(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], _[2], _[3], U];
                }
                var I = _[4];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function S0(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], U];
                }
                var I = _[2];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function T0(H0, Fr, _) {
                var k = _[3], I = _[2], U = a(H0[1][1 + l], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], U, Y];
              }
              function er(H0, Fr, _) {
                var k = _[4], I = _[3], U = _[2], Y = _[1], y0 = a(H0[1][1 + c], H0, k);
                if (I) {
                  var D0 = ze(u(H0[1][1 + w], H0), I);
                  return I === D0 && k === y0 ? _ : [0, _[1], _[2], D0, y0];
                }
                if (U) {
                  var A0 = ze(u(H0[1][1 + h], H0), U);
                  return U === A0 && k === y0 ? _ : [0, _[1], A0, _[3], y0];
                }
                var D = a(H0[1][1 + y], H0, Y);
                return Y === D && k === y0 ? _ : [0, D, _[2], _[3], y0];
              }
              function j0(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + y], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function B(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], _[2], _[3], U];
                }
                var I = _[4];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function Z(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], _[2], _[3], U];
                }
                var I = _[4];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function p0(H0, Fr, _) {
                var k = _[2], I = _[1], U = I[3], Y = I[2];
                if (U)
                  var y0 = Ql(u(H0[1][1 + x], H0), U), D0 = Y;
                else
                  var y0 = 0, D0 = a(H0[1][1 + x], H0, Y);
                var A0 = a(H0[1][1 + c], H0, k);
                return Y === D0 && U === y0 && k === A0 ? _ : [0, [0, I[1], D0, y0], A0];
              }
              function b0(H0, Fr, _) {
                var k = _[3], I = _[1], U = pu(u(H0[1][1 + s], H0), I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, U, _[2], Y];
              }
              function O0(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], U];
                }
                var I = _[2];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function q0(H0, Fr) {
                if (Fr[0] === 0) {
                  var _ = function(D0) {
                    return [0, D0];
                  }, k = Fr[1];
                  return ee(u(H0[1][1 + p], H0), k, Fr, _);
                }
                var I = Fr[1], U = I[2], Y = U[2], y0 = a(H0[1][1 + p], H0, Y);
                return Y === y0 ? Fr : [1, [0, I[1], [0, U[1], y0]]];
              }
              function nr(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + x], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function yr(H0, Fr) {
                var _ = Fr[2], k = Fr[1];
                function I(Y) {
                  return [0, k, [0, _[1], _[2], _[3], Y]];
                }
                var U = _[4];
                return ee(u(H0[1][1 + c], H0), U, [0, k, _], I);
              }
              function vr(H0, Fr, _) {
                var k = _[9], I = _[3], U = a(H0[1][1 + s0], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, _[4], _[5], _[6], _[7], _[8], Y, _[10]];
              }
              function $0(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + y], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function Sr(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function Mr(H0, Fr) {
                var _ = Fr[2], k = _[2], I = _[1], U = Fr[1];
                if (k === 0) {
                  var Y = function(A0) {
                    return [0, U, [0, A0, k]];
                  };
                  return ee(u(H0[1][1 + p], H0), I, Fr, Y);
                }
                function y0(A0) {
                  return [0, U, [0, I, A0]];
                }
                var D0 = u(H0[1][1 + i], H0);
                return ee(function(A0) {
                  return ze(D0, A0);
                }, k, Fr, y0);
              }
              function Br(H0, Fr) {
                var _ = Fr[2], k = _[2], I = Fr[1];
                function U(D0) {
                  return [0, I, [0, D0, k]];
                }
                var Y = _[1], y0 = u(H0[1][1 + T], H0);
                return ee(function(D0) {
                  return Ql(y0, D0);
                }, Y, Fr, U);
              }
              function qr(H0, Fr, _) {
                var k = _[2];
                if (k === 0) {
                  var I = function(D0) {
                    return [0, D0, _[2], _[3]];
                  }, U = _[1];
                  return ee(u(H0[1][1 + y], H0), U, _, I);
                }
                function Y(D0) {
                  return [0, _[1], D0, _[3]];
                }
                var y0 = u(H0[1][1 + i], H0);
                return ee(function(D0) {
                  return ze(y0, D0);
                }, k, _, Y);
              }
              function jr(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function $r(H0, Fr, _) {
                var k = _[7], I = _[2], U = a(H0[1][1 + E], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], U, _[3], _[4], _[5], _[6], Y];
              }
              function ne(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function Qr(H0, Fr) {
                var _ = Fr[2], k = _[1], I = Fr[1];
                function U(y0) {
                  return [0, I, [0, k, y0]];
                }
                var Y = _[2];
                return ee(u(H0[1][1 + c], H0), Y, Fr, U);
              }
              function pe(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + w], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function oe(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], U];
                }
                var I = _[2];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              function me(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + y], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function ae(H0, Fr, _) {
                var k = _[4], I = _[3], U = a(H0[1][1 + y], H0, I), Y = a(H0[1][1 + c], H0, k);
                return I === U && k === Y ? _ : [0, _[1], _[2], U, Y];
              }
              function ce(H0, Fr) {
                function _(I) {
                  return [0, Fr[1], I];
                }
                var k = Fr[2];
                return ee(u(H0[1][1 + c], H0), k, Fr, _);
              }
              function ge(H0, Fr, _) {
                function k(U) {
                  return [0, _[1], U];
                }
                var I = _[2];
                return ee(u(H0[1][1 + c], H0), I, _, k);
              }
              return BN(t4, [0, m0, function(H0, Fr) {
                var _ = Fr[2], k = u(ml(function(U) {
                  return ms(U[1][2], H0[1 + n]) < 0 ? 1 : 0;
                }), _), I = Rc(k);
                return Rc(_) === I ? Fr : [0, Fr[1], k, Fr[3]];
              }, Jr, ge, Wr, ce, Rr, ae, xr, me, Or, oe, Hr, pe, w, Qr, h, ne, Tr, $r, E, jr, Lr, qr, W0, Br, T, Mr, ar, Sr, Ar, $0, dr, vr, X, yr, G0, nr, b, q0, X0, O0, E0, b0, _0, p0, w0, Z, a0, B, t0, j0, x0, er, c0, T0, e0, S0, s, l0, g0, i0, k0, Q, f0, L, V, P, K, v0, M, fe, S, Ir, A, _r]), function(H0, Fr, _) {
                var k = Gp(Fr, t4);
                return k[1 + n] = _, u(or, k), MN(Fr, k, t4);
              };
            });
            function C9(t4) {
              var n = i2(t4);
              if (n)
                var e = n[1], i = pe0(t4) ? (Vl(t4, e[3]), [0, a(Ee0[1], 0, e[3])]) : 0, x = i;
              else
                var x = n;
              return [0, 0, function(c, s) {
                return x ? a(s, x[1], c) : c;
              }];
            }
            function rb(t4) {
              var n = i2(t4);
              if (n) {
                var e = n[1];
                if (pe0(t4)) {
                  Vl(t4, e[3]);
                  var i = Us(t4), x = [0, a(Ee0[1], 0, [0, e[3][1] + 1 | 0, 0])], c = i;
                } else
                  var x = 0, c = Us(t4);
              } else
                var x = 0, c = 0;
              return [0, c, function(s, p) {
                return x ? a(p, x[1], s) : s;
              }];
            }
            function $t(t4) {
              return f7(t4) ? rb(t4) : C9(t4);
            }
            function ds(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                return a(Qe(x, Nv, 27), x, c);
              }
              return a(e[2], n, i);
            }
            function ai(t4, n) {
              if (n)
                var e = $t(t4), i = function(c, s) {
                  return a(Qe(c, _F, 30), c, s);
                }, x = [0, a(e[2], n[1], i)];
              else
                var x = n;
              return x;
            }
            function a2(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                return a(Qe(x, -983660142, 32), x, c);
              }
              return a(e[2], n, i);
            }
            function eb(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                return a(Qe(x, -455772979, 33), x, c);
              }
              return a(e[2], n, i);
            }
            function Se0(t4, n) {
              if (n)
                var e = $t(t4), i = function(c, s) {
                  return a(Qe(c, FH, 34), c, s);
                }, x = [0, a(e[2], n[1], i)];
              else
                var x = n;
              return x;
            }
            function Yi(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                return a(Qe(x, VY, 35), x, c);
              }
              return a(e[2], n, i);
            }
            function ge0(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                var s = u(Qe(x, tH, 37), x);
                return Ql(function(p) {
                  return pu(s, p);
                }, c);
              }
              return a(e[2], n, i);
            }
            function Fe0(t4, n) {
              var e = $t(t4);
              function i(x, c) {
                return a(Qe(x, -21476009, 38), x, c);
              }
              return a(e[2], n, i);
            }
            jp(_Gr, function(t4) {
              var n = RN(t4, vGr), e = jN(bGr), i = e.length - 1, x = az.length - 1, c = Gv(i + x | 0, 0), s = i - 1 | 0, p = 0;
              if (!(s < 0))
                for (var y = p; ; ) {
                  var T = Fl(t4, nu(e, y)[1 + y]);
                  nu(c, y)[1 + y] = T;
                  var E = y + 1 | 0;
                  if (s !== y) {
                    var y = E;
                    continue;
                  }
                  break;
                }
              var h = x - 1 | 0, w = 0;
              if (!(h < 0))
                for (var G = w; ; ) {
                  var A = G + i | 0, S = RN(t4, nu(az, G)[1 + G]);
                  nu(c, A)[1 + A] = S;
                  var M = G + 1 | 0;
                  if (h !== G) {
                    var G = M;
                    continue;
                  }
                  break;
                }
              var K = c[4], V = c[5], f0 = c[d6], m0 = c[sp], k0 = c[ih], g0 = c[gv], e0 = c[38], x0 = c[dT], l = c[Wy], c0 = GN(t4, 0, 0, xz, $D, 1)[1];
              function t0(b, G0, X) {
                return a(b[1][1 + f0], b, X[2]), X;
              }
              function a0(b, G0) {
                return a(b[1][1 + m0], b, G0), G0;
              }
              function w0(b, G0) {
                var X = G0[1], s0 = b[1 + g0];
                if (s0) {
                  var dr = ms(s0[1][1][2], X[2]) < 0 ? 1 : 0, Ar = dr && (b[1 + g0] = [0, G0], 0);
                  return Ar;
                }
                var ar = 0 <= ms(X[2], b[1 + n][3]) ? 1 : 0, W0 = ar && (b[1 + g0] = [0, G0], 0);
                return W0;
              }
              function _0(b, G0) {
                var X = G0[1], s0 = b[1 + k0];
                if (s0) {
                  var dr = ms(X[2], s0[1][1][2]) < 0 ? 1 : 0, Ar = dr && (b[1 + k0] = [0, G0], 0);
                  return Ar;
                }
                var ar = ms(X[2], b[1 + n][2]) < 0 ? 1 : 0, W0 = ar && (b[1 + k0] = [0, G0], 0);
                return W0;
              }
              function E0(b, G0) {
                return G0 && a(b[1][1 + m0], b, G0[1]);
              }
              function X0(b, G0) {
                var X = G0[1];
                Cu(u(b[1][1 + V], b), X);
                var s0 = G0[2];
                return Cu(u(b[1][1 + K], b), s0);
              }
              return BN(t4, [0, x0, function(b) {
                return [0, b[1 + k0], b[1 + g0]];
              }, m0, X0, f0, E0, V, _0, K, w0, e0, a0, l, t0]), function(b, G0, X) {
                var s0 = Gp(G0, t4);
                return s0[1 + n] = X, u(c0, s0), s0[1 + k0] = 0, s0[1 + g0] = 0, MN(G0, s0, t4);
              };
            });
            function Te0(t4) {
              return t4 === 3 ? 2 : (4 <= t4, 1);
            }
            function TL(t4, n, e) {
              if (e) {
                var i = e[1], x = 0;
                if (i === 8232 || Uu === i)
                  x = 1;
                else if (i === 10)
                  var s = 6;
                else if (i === 13)
                  var s = 5;
                else if (ow <= i)
                  var s = 3;
                else if (Vd <= i)
                  var s = 2;
                else
                  var c = Gt <= i ? 1 : 0, s = c && 1;
                if (x)
                  var s = 7;
                var p = s;
              } else
                var p = 4;
              return [0, p, t4];
            }
            var sne = [St, wGr, M7(0)];
            function Oe0(t4, n, e, i) {
              try {
                var x = nu(t4, n)[1 + n];
                return x;
              } catch (c) {
                throw c = gt(c), c[1] === eN ? [0, sne, e, ir(et(hGr), i, n, t4.length - 1)] : c;
              }
            }
            function P9(t4, n) {
              if (n[1] === 0 && n[2] === 0)
                return 0;
              var e = Oe0(t4, n[1] - 1 | 0, n, yGr);
              return Oe0(e, n[2], n, dGr);
            }
            var vne = Ee;
            function lne(t4, n) {
              return a(f(t4), WWr, n);
            }
            u(uL([0, vne])[33], lne);
            function Ie0(t4) {
              var n = N0(t4), e = 0;
              if (typeof n == "number")
                switch (n) {
                  case 15:
                    var i = JWr;
                    break;
                  case 16:
                    var i = $Wr;
                    break;
                  case 17:
                    var i = ZWr;
                    break;
                  case 18:
                    var i = QWr;
                    break;
                  case 19:
                    var i = rJr;
                    break;
                  case 20:
                    var i = eJr;
                    break;
                  case 21:
                    var i = nJr;
                    break;
                  case 22:
                    var i = tJr;
                    break;
                  case 23:
                    var i = uJr;
                    break;
                  case 24:
                    var i = iJr;
                    break;
                  case 25:
                    var i = fJr;
                    break;
                  case 26:
                    var i = xJr;
                    break;
                  case 27:
                    var i = aJr;
                    break;
                  case 28:
                    var i = oJr;
                    break;
                  case 29:
                    var i = cJr;
                    break;
                  case 30:
                    var i = sJr;
                    break;
                  case 31:
                    var i = vJr;
                    break;
                  case 32:
                    var i = lJr;
                    break;
                  case 33:
                    var i = bJr;
                    break;
                  case 34:
                    var i = pJr;
                    break;
                  case 35:
                    var i = mJr;
                    break;
                  case 36:
                    var i = _Jr;
                    break;
                  case 37:
                    var i = yJr;
                    break;
                  case 38:
                    var i = dJr;
                    break;
                  case 39:
                    var i = hJr;
                    break;
                  case 40:
                    var i = kJr;
                    break;
                  case 41:
                    var i = wJr;
                    break;
                  case 42:
                    var i = EJr;
                    break;
                  case 43:
                    var i = SJr;
                    break;
                  case 44:
                    var i = gJr;
                    break;
                  case 45:
                    var i = FJr;
                    break;
                  case 46:
                    var i = TJr;
                    break;
                  case 47:
                    var i = OJr;
                    break;
                  case 48:
                    var i = IJr;
                    break;
                  case 49:
                    var i = AJr;
                    break;
                  case 50:
                    var i = NJr;
                    break;
                  case 51:
                    var i = CJr;
                    break;
                  case 52:
                    var i = PJr;
                    break;
                  case 53:
                    var i = DJr;
                    break;
                  case 54:
                    var i = LJr;
                    break;
                  case 55:
                    var i = RJr;
                    break;
                  case 56:
                    var i = jJr;
                    break;
                  case 57:
                    var i = GJr;
                    break;
                  case 58:
                    var i = MJr;
                    break;
                  case 59:
                    var i = BJr;
                    break;
                  case 60:
                    var i = qJr;
                    break;
                  case 61:
                    var i = UJr;
                    break;
                  case 62:
                    var i = HJr;
                    break;
                  case 63:
                    var i = XJr;
                    break;
                  case 64:
                    var i = YJr;
                    break;
                  case 65:
                    var i = VJr;
                    break;
                  case 114:
                    var i = zJr;
                    break;
                  case 115:
                    var i = KJr;
                    break;
                  case 116:
                    var i = WJr;
                    break;
                  case 117:
                    var i = JJr;
                    break;
                  case 118:
                    var i = $Jr;
                    break;
                  case 119:
                    var i = ZJr;
                    break;
                  case 120:
                    var i = QJr;
                    break;
                  case 121:
                    var i = r$r;
                    break;
                  default:
                    e = 1;
                }
              else
                switch (n[0]) {
                  case 4:
                    var i = n[2];
                    break;
                  case 9:
                    var i = n[1] ? e$r : n$r;
                    break;
                  default:
                    e = 1;
                }
              if (e) {
                Ft(t$r, t4);
                var i = u$r;
              }
              return ie(t4), i;
            }
            function z7(t4) {
              var n = Le(t4), e = pr(t4), i = Ie0(t4);
              return [0, n, [0, i, lr([0, e], [0, we(t4)], 0)]];
            }
            function Ae0(t4) {
              var n = Le(t4), e = pr(t4);
              V0(t4, 14);
              var i = Le(t4), x = Ie0(t4), c = lr([0, e], [0, we(t4)], 0), s = ht(n, i), p = i[2], y = n[3], T = y[1] === p[1] ? 1 : 0, E = T && (y[2] === p[2] ? 1 : 0);
              return 1 - E && ue(t4, [0, s, R7]), [0, s, [0, x, c]];
            }
            function U1(t4) {
              var n = t4[2], e = n[3] === 0 ? 1 : 0;
              if (e)
                for (var i = n[2]; ; ) {
                  if (i) {
                    var x = i[1][2], c = 0, s = i[2];
                    if (x[1][2][0] === 2 && !x[2]) {
                      var p = 1;
                      c = 1;
                    }
                    if (!c)
                      var p = 0;
                    if (p) {
                      var i = s;
                      continue;
                    }
                    return p;
                  }
                  return 1;
                }
              return e;
            }
            function nb(t4) {
              for (var n = t4; ; ) {
                var e = n[2];
                if (e[0] === 27) {
                  var i = e[1][2];
                  if (i[2][0] === 23)
                    return 1;
                  var n = i;
                  continue;
                }
                return 0;
              }
            }
            function cr(t4, n, e) {
              var i = t4 ? t4[1] : Le(e), x = u(n, e), c = i2(e), s = c ? ht(i, c[1]) : i;
              return [0, s, x];
            }
            function OL(t4, n, e) {
              var i = cr(t4, n, e), x = i[2];
              return [0, [0, i[1], x[1]], x[2]];
            }
            function bne(t4) {
              function n(B) {
                var Z = Le(B), p0 = N0(B);
                if (typeof p0 == "number") {
                  if (s7 === p0) {
                    var b0 = pr(B);
                    return ie(B), [0, [0, Z, [0, 0, lr([0, b0], 0, 0)]]];
                  }
                  if (L7 === p0) {
                    var O0 = pr(B);
                    return ie(B), [0, [0, Z, [0, 1, lr([0, O0], 0, 0)]]];
                  }
                }
                return 0;
              }
              var e = function B(Z) {
                return B.fun(Z);
              }, i = function B(Z) {
                return B.fun(Z);
              }, x = function B(Z) {
                return B.fun(Z);
              }, c = function B(Z, p0, b0) {
                return B.fun(Z, p0, b0);
              }, s = function B(Z) {
                return B.fun(Z);
              }, p = function B(Z, p0, b0) {
                return B.fun(Z, p0, b0);
              }, y = function B(Z) {
                return B.fun(Z);
              }, T = function B(Z, p0) {
                return B.fun(Z, p0);
              }, E = function B(Z) {
                return B.fun(Z);
              }, h = function B(Z) {
                return B.fun(Z);
              }, w = function B(Z, p0, b0) {
                return B.fun(Z, p0, b0);
              }, G = function B(Z, p0, b0, O0) {
                return B.fun(Z, p0, b0, O0);
              }, A = function B(Z) {
                return B.fun(Z);
              }, S = function B(Z, p0) {
                return B.fun(Z, p0);
              }, M = function B(Z) {
                return B.fun(Z);
              }, K = function B(Z) {
                return B.fun(Z);
              }, V = function B(Z) {
                return B.fun(Z);
              }, f0 = function B(Z) {
                return B.fun(Z);
              }, m0 = function B(Z) {
                return B.fun(Z);
              }, k0 = function B(Z) {
                return B.fun(Z);
              }, g0 = function B(Z, p0) {
                return B.fun(Z, p0);
              }, e0 = function B(Z) {
                return B.fun(Z);
              }, x0 = function B(Z) {
                return B.fun(Z);
              }, l = function B(Z) {
                return B.fun(Z);
              }, c0 = function B(Z) {
                return B.fun(Z);
              }, t0 = function B(Z) {
                return B.fun(Z);
              }, a0 = function B(Z) {
                return B.fun(Z);
              }, w0 = function B(Z) {
                return B.fun(Z);
              }, _0 = function B(Z, p0, b0, O0) {
                return B.fun(Z, p0, b0, O0);
              }, E0 = function B(Z, p0, b0, O0) {
                return B.fun(Z, p0, b0, O0);
              }, X0 = function B(Z) {
                return B.fun(Z);
              }, b = function B(Z) {
                return B.fun(Z);
              }, G0 = function B(Z) {
                return B.fun(Z);
              }, X = function B(Z) {
                return B.fun(Z);
              }, s0 = function B(Z) {
                return B.fun(Z);
              }, dr = function B(Z) {
                return B.fun(Z);
              }, Ar = function B(Z, p0) {
                return B.fun(Z, p0);
              }, ar = function B(Z, p0) {
                return B.fun(Z, p0);
              }, W0 = function B(Z) {
                return B.fun(Z);
              }, Lr = function B(Z, p0, b0) {
                return B.fun(Z, p0, b0);
              };
              N(e, function(B) {
                return u(x, B);
              }), N(i, function(B) {
                return 1 - iu(B) && Ge(B, 12), cr(0, function(Z) {
                  return V0(Z, 86), u(e, Z);
                }, B);
              }), N(x, function(B) {
                var Z = N0(B) === 89 ? 1 : 0;
                if (Z) {
                  var p0 = pr(B);
                  ie(B);
                  var b0 = p0;
                } else
                  var b0 = Z;
                return ir(c, B, [0, b0], u(s, B));
              }), N(c, function(B, Z, p0) {
                var b0 = Z && Z[1];
                if (N0(B) === 89) {
                  var O0 = [0, p0, 0], q0 = function(nr) {
                    for (var yr = O0; ; ) {
                      var vr = N0(nr);
                      if (typeof vr == "number" && vr === 89) {
                        V0(nr, 89);
                        var yr = [0, u(s, nr), yr];
                        continue;
                      }
                      var $0 = de(yr);
                      if ($0) {
                        var Sr = $0[2];
                        if (Sr) {
                          var Mr = lr([0, b0], 0, 0);
                          return [19, [0, [0, $0[1], Sr[1], Sr[2]], Mr]];
                        }
                      }
                      throw [0, Fn, R$r];
                    }
                  };
                  return cr([0, p0[1]], q0, B);
                }
                return p0;
              }), N(s, function(B) {
                var Z = N0(B) === 91 ? 1 : 0;
                if (Z) {
                  var p0 = pr(B);
                  ie(B);
                  var b0 = p0;
                } else
                  var b0 = Z;
                return ir(p, B, [0, b0], u(y, B));
              }), N(p, function(B, Z, p0) {
                var b0 = Z && Z[1];
                if (N0(B) === 91) {
                  var O0 = [0, p0, 0], q0 = function(nr) {
                    for (var yr = O0; ; ) {
                      var vr = N0(nr);
                      if (typeof vr == "number" && vr === 91) {
                        V0(nr, 91);
                        var yr = [0, u(y, nr), yr];
                        continue;
                      }
                      var $0 = de(yr);
                      if ($0) {
                        var Sr = $0[2];
                        if (Sr) {
                          var Mr = lr([0, b0], 0, 0);
                          return [20, [0, [0, $0[1], Sr[1], Sr[2]], Mr]];
                        }
                      }
                      throw [0, Fn, L$r];
                    }
                  };
                  return cr([0, p0[1]], q0, B);
                }
                return p0;
              }), N(y, function(B) {
                return a(T, B, u(E, B));
              }), N(T, function(B, Z) {
                var p0 = N0(B);
                if (typeof p0 == "number" && p0 === 11 && !B[15]) {
                  var b0 = a(g0, B, Z);
                  return R(_0, B, b0[1], 0, [0, b0[1], [0, 0, [0, b0, 0], 0, 0]]);
                }
                return Z;
              }), N(E, function(B) {
                var Z = N0(B);
                return typeof Z == "number" && Z === 85 ? cr(0, function(p0) {
                  var b0 = pr(p0);
                  V0(p0, 85);
                  var O0 = lr([0, b0], 0, 0);
                  return [11, [0, u(E, p0), O0]];
                }, B) : u(h, B);
              }), N(h, function(B) {
                return ir(w, 0, B, u(V, B));
              }), N(w, function(B, Z, p0) {
                var b0 = B && B[1];
                if (f7(Z))
                  return p0;
                var O0 = N0(Z);
                if (typeof O0 == "number") {
                  if (O0 === 6)
                    return ie(Z), R(G, b0, 0, Z, p0);
                  if (O0 === 10) {
                    var q0 = Vn(1, Z);
                    return typeof q0 == "number" && q0 === 6 ? (Ge(Z, P$r), V0(Z, 10), V0(Z, 6), R(G, b0, 0, Z, p0)) : (Ge(Z, D$r), p0);
                  }
                  if (O0 === 83)
                    return ie(Z), N0(Z) !== 6 && Ge(Z, 30), V0(Z, 6), R(G, 1, 1, Z, p0);
                }
                return p0;
              }), N(G, function(B, Z, p0, b0) {
                function O0(q0) {
                  if (!Z && fu(q0, 7))
                    return [15, [0, b0, lr(0, [0, we(q0)], 0)]];
                  var nr = u(e, q0);
                  V0(q0, 7);
                  var yr = [0, b0, nr, lr(0, [0, we(q0)], 0)];
                  return B ? [18, [0, yr, Z]] : [17, yr];
                }
                return ir(w, [0, B], p0, cr([0, b0[1]], O0, p0));
              }), N(A, function(B) {
                return a(S, B, a(t4[13], 0, B));
              }), N(S, function(B, Z) {
                for (var p0 = [0, Z[1], [0, Z]]; ; ) {
                  var b0 = p0[2];
                  if (N0(B) === 10 && A9(1, B)) {
                    var O0 = function(vr) {
                      return function($0) {
                        return V0($0, 10), [0, vr, z7($0)];
                      };
                    }(b0), q0 = cr([0, p0[1]], O0, B), nr = q0[1], p0 = [0, nr, [1, [0, nr, q0[2]]]];
                    continue;
                  }
                  return b0;
                }
              }), N(M, function(B) {
                var Z = N0(B);
                if (typeof Z == "number") {
                  if (Z === 4) {
                    ie(B);
                    var p0 = u(M, B);
                    return V0(B, 5), p0;
                  }
                } else if (Z[0] === 4)
                  return [0, u(A, B)];
                return Ge(B, 51), 0;
              }), N(K, function(B) {
                return cr(0, function(Z) {
                  var p0 = pr(Z);
                  V0(Z, 46);
                  var b0 = u(M, Z);
                  if (b0) {
                    var O0 = lr([0, p0], 0, 0);
                    return [21, [0, b0[1], O0]];
                  }
                  return C$r;
                }, B);
              }), N(V, function(B) {
                var Z = Le(B), p0 = N0(B), b0 = 0;
                if (typeof p0 == "number")
                  switch (p0) {
                    case 4:
                      return u(a0, B);
                    case 6:
                      return u(k0, B);
                    case 46:
                      return u(K, B);
                    case 53:
                      return cr(0, function(ge) {
                        var H0 = pr(ge);
                        V0(ge, 53);
                        var Fr = u(X0, ge), _ = lr([0, H0], 0, 0);
                        return [14, [0, Fr[2], Fr[1], _]];
                      }, B);
                    case 98:
                      return u(w0, B);
                    case 106:
                      var O0 = pr(B);
                      return V0(B, Vt), [0, Z, [10, lr([0, O0], [0, we(B)], 0)]];
                    case 42:
                      b0 = 1;
                      break;
                    case 0:
                    case 2:
                      var q0 = R(E0, 0, 1, 1, B);
                      return [0, q0[1], [13, q0[2]]];
                    case 30:
                    case 31:
                      var nr = pr(B);
                      return V0(B, p0), [0, Z, [26, [0, p0 === 31 ? 1 : 0, lr([0, nr], [0, we(B)], 0)]]];
                  }
                else
                  switch (p0[0]) {
                    case 2:
                      var yr = p0[1], vr = yr[4], $0 = yr[3], Sr = yr[2], Mr = yr[1];
                      vr && gi(B, 45);
                      var Br = pr(B);
                      return V0(B, [2, [0, Mr, Sr, $0, vr]]), [0, Mr, [23, [0, Sr, $0, lr([0, Br], [0, we(B)], 0)]]];
                    case 10:
                      var qr = p0[3], jr = p0[2], $r = p0[1], ne = pr(B);
                      V0(B, [10, $r, jr, qr]);
                      var Qr = we(B);
                      return $r === 1 && gi(B, 45), [0, Z, [24, [0, jr, qr, lr([0, ne], [0, Qr], 0)]]];
                    case 11:
                      var pe = p0[3], oe = p0[2], me = pr(B);
                      return V0(B, [11, p0[1], oe, pe]), [0, Z, [25, [0, oe, pe, lr([0, me], [0, we(B)], 0)]]];
                    case 4:
                      b0 = 1;
                      break;
                  }
                if (b0) {
                  var ae = u(dr, B);
                  return [0, ae[1], [16, ae[2]]];
                }
                var ce = u(m0, B);
                return ce ? [0, Z, ce[1]] : (Ft(A$r, B), [0, Z, N$r]);
              }), N(f0, function(B) {
                var Z = 0;
                if (typeof B == "number")
                  switch (B) {
                    case 29:
                    case 114:
                    case 115:
                    case 116:
                    case 117:
                    case 118:
                    case 119:
                    case 120:
                    case 121:
                      Z = 1;
                      break;
                  }
                else
                  B[0] === 9 && (Z = 1);
                return Z ? 1 : 0;
              }), N(m0, function(B) {
                var Z = pr(B), p0 = N0(B);
                if (typeof p0 == "number")
                  switch (p0) {
                    case 29:
                      return ie(B), [0, [4, lr([0, Z], [0, we(B)], 0)]];
                    case 114:
                      return ie(B), [0, [0, lr([0, Z], [0, we(B)], 0)]];
                    case 115:
                      return ie(B), [0, [1, lr([0, Z], [0, we(B)], 0)]];
                    case 116:
                      return ie(B), [0, [2, lr([0, Z], [0, we(B)], 0)]];
                    case 117:
                      return ie(B), [0, [5, lr([0, Z], [0, we(B)], 0)]];
                    case 118:
                      return ie(B), [0, [6, lr([0, Z], [0, we(B)], 0)]];
                    case 119:
                      return ie(B), [0, [7, lr([0, Z], [0, we(B)], 0)]];
                    case 120:
                      return ie(B), [0, [3, lr([0, Z], [0, we(B)], 0)]];
                    case 121:
                      return ie(B), [0, [9, lr([0, Z], [0, we(B)], 0)]];
                  }
                else if (p0[0] === 9)
                  return ie(B), [0, [8, lr([0, Z], [0, we(B)], 0)]];
                return 0;
              }), N(k0, function(B) {
                return cr(0, function(Z) {
                  var p0 = pr(Z);
                  V0(Z, 6);
                  for (var b0 = u2(0, Z), O0 = 0; ; ) {
                    var q0 = N0(b0);
                    if (typeof q0 == "number") {
                      var nr = 0;
                      if ((q0 === 7 || Ln === q0) && (nr = 1), nr) {
                        var yr = de(O0);
                        return V0(Z, 7), [22, [0, yr, lr([0, p0], [0, we(Z)], 0)]];
                      }
                    }
                    var vr = [0, u(e, b0), O0];
                    N0(b0) !== 7 && V0(b0, 9);
                    var O0 = vr;
                  }
                }, B);
              }), N(g0, function(B, Z) {
                return [0, Z[1], [0, 0, Z, 0]];
              }), N(e0, function(B) {
                return cr(0, function(Z) {
                  zu(Z, 0);
                  var p0 = a(t4[13], 0, Z);
                  k7(Z), 1 - iu(Z) && Ge(Z, 12);
                  var b0 = fu(Z, 85);
                  return V0(Z, 86), [0, [0, p0], u(e, Z), b0];
                }, B);
              });
              function Tr(B) {
                var Z = Vn(1, B);
                return typeof Z == "number" && !(1 < (Z + W2 | 0) >>> 0) ? u(e0, B) : a(g0, B, u(e, B));
              }
              N(x0, function(B) {
                var Z = 0;
                return function(p0) {
                  for (var b0 = Z, O0 = p0; ; ) {
                    var q0 = N0(B);
                    if (typeof q0 == "number")
                      switch (q0) {
                        case 5:
                        case 12:
                        case 113:
                          var nr = q0 === 12 ? 1 : 0, yr = nr && [0, cr(0, function(jr) {
                            var $r = pr(jr);
                            V0(jr, 12);
                            var ne = lr([0, $r], 0, 0);
                            return [0, Tr(jr), ne];
                          }, B)];
                          return [0, b0, de(O0), yr, 0];
                      }
                    else if (q0[0] === 4 && !n0(q0[3], I$r)) {
                      var vr = 0;
                      if ((Vn(1, B) === 86 || Vn(1, B) === 85) && (vr = 1), vr) {
                        var $0 = b0 !== 0 ? 1 : 0, Sr = $0 || (O0 !== 0 ? 1 : 0);
                        Sr && Ge(B, s7);
                        var Mr = cr(0, function($r) {
                          var ne = pr($r);
                          ie($r), N0($r) === 85 && Ge($r, L7);
                          var Qr = lr([0, ne], 0, 0);
                          return [0, u(i, $r), Qr];
                        }, B);
                        N0(B) !== 5 && V0(B, 9);
                        var b0 = [0, Mr];
                        continue;
                      }
                    }
                    var Br = [0, Tr(B), O0];
                    N0(B) !== 5 && V0(B, 9);
                    var O0 = Br;
                  }
                };
              }), N(l, function(B) {
                return cr(0, function(Z) {
                  var p0 = pr(Z);
                  V0(Z, 4);
                  var b0 = a(x0, Z, 0), O0 = pr(Z);
                  V0(Z, 5);
                  var q0 = mu([0, p0], [0, we(Z)], O0, 0);
                  return [0, b0[1], b0[2], b0[3], q0];
                }, B);
              }), N(c0, function(B) {
                var Z = pr(B);
                V0(B, 4);
                var p0 = u2(0, B), b0 = N0(p0), O0 = 0;
                if (typeof b0 == "number")
                  switch (b0) {
                    case 5:
                      var q0 = O$r;
                      break;
                    case 42:
                      O0 = 2;
                      break;
                    case 12:
                    case 113:
                      var q0 = [0, a(x0, p0, 0)];
                      break;
                    default:
                      O0 = 1;
                  }
                else
                  b0[0] === 4 ? O0 = 2 : O0 = 1;
                switch (O0) {
                  case 1:
                    if (u(f0, b0)) {
                      var nr = Vn(1, p0), yr = 0;
                      if (typeof nr == "number" && !(1 < (nr + W2 | 0) >>> 0)) {
                        var vr = [0, a(x0, p0, 0)];
                        yr = 1;
                      }
                      if (!yr)
                        var vr = [1, u(e, p0)];
                      var q0 = vr;
                    } else
                      var q0 = [1, u(e, p0)];
                    break;
                  case 2:
                    var q0 = u(t0, p0);
                    break;
                }
                if (q0[0] === 0)
                  var $0 = q0;
                else {
                  var Sr = q0[1];
                  if (B[15])
                    var Mr = q0;
                  else {
                    var Br = N0(B), qr = 0;
                    if (typeof Br == "number")
                      if (Br === 5)
                        var jr = Vn(1, B) === 11 ? [0, a(x0, B, [0, a(g0, B, Sr), 0])] : [1, Sr];
                      else if (Br === 9) {
                        V0(B, 9);
                        var jr = [0, a(x0, B, [0, a(g0, B, Sr), 0])];
                      } else
                        qr = 1;
                    else
                      qr = 1;
                    if (qr)
                      var jr = q0;
                    var Mr = jr;
                  }
                  var $0 = Mr;
                }
                var $r = pr(B);
                V0(B, 5);
                var ne = we(B);
                if ($0[0] === 0) {
                  var Qr = $0[1], pe = mu([0, Z], [0, ne], $r, 0);
                  return [0, [0, Qr[1], Qr[2], Qr[3], pe]];
                }
                return [1, ir(Lr, $0[1], Z, ne)];
              }), N(t0, function(B) {
                var Z = Vn(1, B);
                return typeof Z == "number" && !(1 < (Z + W2 | 0) >>> 0) ? [0, a(x0, B, 0)] : [1, ir(c, B, 0, ir(p, B, 0, a(T, B, ir(w, 0, B, a(ar, B, u(b, B))))))];
              }), N(a0, function(B) {
                var Z = Le(B), p0 = cr(0, c0, B), b0 = p0[2];
                return b0[0] === 0 ? R(_0, B, Z, 0, [0, p0[1], b0[1]]) : b0[1];
              }), N(w0, function(B) {
                var Z = Le(B), p0 = ai(B, u(X, B));
                return R(_0, B, Z, p0, u(l, B));
              }), N(_0, function(B, Z, p0, b0) {
                return cr([0, Z], function(O0) {
                  return V0(O0, 11), [12, [0, p0, b0, u(e, O0), 0]];
                }, B);
              });
              function Hr(B, Z, p0) {
                return cr([0, Z], function(b0) {
                  var O0 = u(l, b0);
                  return V0(b0, 86), [0, p0, O0, u(e, b0), 0];
                }, B);
              }
              function Or(B, Z) {
                var p0 = N0(Z);
                if (typeof p0 == "number" && !(10 <= p0))
                  switch (p0) {
                    case 1:
                      if (!B)
                        return 0;
                      break;
                    case 3:
                      if (B)
                        return 0;
                      break;
                    case 8:
                    case 9:
                      return ie(Z);
                  }
                return q1(Z, 9);
              }
              function xr(B, Z) {
                return Z && ue(B, [0, Z[1][1], 7]);
              }
              function Rr(B, Z) {
                return Z && ue(B, [0, Z[1], 9]);
              }
              N(E0, function(B, Z, p0, b0) {
                var O0 = Z && (N0(b0) === 2 ? 1 : 0), q0 = Z && 1 - O0;
                return cr(0, function(nr) {
                  var yr = pr(nr), vr = O0 && 2;
                  V0(nr, vr);
                  var $0 = u2(0, nr), Sr = T$r;
                  r:
                    for (; ; ) {
                      var Mr = Sr[3], Br = Sr[2], qr = Sr[1];
                      if (B && p0)
                        throw [0, Fn, l$r];
                      if (q0 && !p0)
                        throw [0, Fn, b$r];
                      var jr = Le($0), $r = N0($0);
                      if (typeof $r == "number") {
                        var ne = 0;
                        if (13 <= $r) {
                          if (Ln === $r) {
                            var Qr = [0, de(qr), Br, Mr];
                            ne = 1;
                          }
                        } else if ($r)
                          switch ($r - 1 | 0) {
                            case 0:
                              if (!O0) {
                                var Qr = [0, de(qr), Br, Mr];
                                ne = 1;
                              }
                              break;
                            case 2:
                              if (O0) {
                                var Qr = [0, de(qr), Br, Mr];
                                ne = 1;
                              }
                              break;
                            case 11:
                              if (!p0) {
                                ie($0);
                                var pe = N0($0);
                                if (typeof pe == "number" && !(10 <= pe))
                                  switch (pe) {
                                    case 1:
                                    case 3:
                                    case 8:
                                    case 9:
                                      ue($0, [0, jr, 20]), Or(O0, $0);
                                      continue;
                                  }
                                var oe = gL($0);
                                u(kL($0), oe), ue($0, [0, jr, 17]), ie($0), Or(O0, $0);
                                continue;
                              }
                              var me = pr($0);
                              ie($0);
                              var ae = N0($0), ce = 0;
                              if (typeof ae == "number" && !(10 <= ae))
                                switch (ae) {
                                  case 1:
                                  case 3:
                                  case 8:
                                  case 9:
                                    Or(O0, $0);
                                    var ge = N0($0), H0 = 0;
                                    if (typeof ge == "number") {
                                      var Fr = ge - 1 | 0;
                                      if (!(2 < Fr >>> 0))
                                        switch (Fr) {
                                          case 0:
                                            if (q0) {
                                              var Qr = [0, de(qr), 1, me];
                                              ne = 1, ce = 1, H0 = 1;
                                            }
                                            break;
                                          case 1:
                                            break;
                                          default:
                                            ue($0, [0, jr, 19]);
                                            var Qr = [0, de(qr), Br, Mr];
                                            ne = 1, ce = 1, H0 = 1;
                                        }
                                    }
                                    if (!H0) {
                                      ue($0, [0, jr, 18]);
                                      continue;
                                    }
                                    break;
                                }
                              if (!ce) {
                                var _ = [1, cr([0, jr], function(W7) {
                                  return function(Ht) {
                                    var mt = lr([0, W7], 0, 0);
                                    return [0, u(e, Ht), mt];
                                  };
                                }(me), $0)];
                                Or(O0, $0);
                                var Sr = [0, [0, _, qr], Br, Mr];
                                continue;
                              }
                              break;
                          }
                        if (ne) {
                          var k = pr(nr), I = xn(Qr[3], k), U = O0 ? 3 : 1;
                          V0(nr, U);
                          var Y = mu([0, yr], [0, we(nr)], I, 0);
                          return [0, O0, Qr[2], Qr[1], Y];
                        }
                      }
                      for (var y0 = B, D0 = B, A0 = 0, D = 0, u0 = 0, Y0 = 0; ; ) {
                        var J0 = N0($0), fr = 0;
                        if (typeof J0 == "number")
                          switch (J0) {
                            case 6:
                              Rr($0, u0);
                              var Q0 = Vn(1, $0), F0 = 0;
                              if (typeof Q0 == "number" && Q0 === 6) {
                                xr($0, A0);
                                var Cr = [4, cr([0, jr], function(Ht, mt, U0) {
                                  return function(R0) {
                                    var Re = xn(mt, pr(R0));
                                    V0(R0, 6), V0(R0, 6);
                                    var Xe = z7(R0);
                                    V0(R0, 7), V0(R0, 7);
                                    var he = N0(R0), _e = 0;
                                    if (typeof he == "number") {
                                      var rt = 0;
                                      if (he !== 4 && he !== 98 && (rt = 1), !rt) {
                                        var wn = Hr(R0, Ht, ai(R0, u(X, R0))), ft = 0, xt = [0, wn[1], [12, wn[2]]], Gn = 1, tt = 0;
                                        _e = 1;
                                      }
                                    }
                                    if (!_e) {
                                      var wt = fu(R0, 85), un = we(R0);
                                      V0(R0, 86);
                                      var ft = un, xt = u(e, R0), Gn = 0, tt = wt;
                                    }
                                    return [0, Xe, xt, tt, U0 !== 0 ? 1 : 0, Gn, lr([0, Re], [0, ft], 0)];
                                  };
                                }(jr, Y0, D), $0)];
                                F0 = 1;
                              }
                              if (!F0)
                                var Cr = [2, cr([0, jr], function(W7, Ht, mt) {
                                  return function(U0) {
                                    var R0 = xn(W7, pr(U0));
                                    V0(U0, 6);
                                    var Re = Vn(1, U0) === 86 ? 1 : 0;
                                    if (Re) {
                                      var Xe = z7(U0);
                                      V0(U0, 86);
                                      var he = [0, Xe];
                                    } else
                                      var he = Re;
                                    var _e = u(e, U0);
                                    V0(U0, 7);
                                    var rt = we(U0);
                                    V0(U0, 86);
                                    var wn = u(e, U0);
                                    return [0, he, _e, wn, Ht !== 0 ? 1 : 0, mt, lr([0, R0], [0, rt], 0)];
                                  };
                                }(Y0, D, A0), $0)];
                              break;
                            case 42:
                              if (y0) {
                                if (A0 === 0) {
                                  var gr = [0, Le($0)], mr = xn(Y0, pr($0));
                                  ie($0);
                                  var y0 = 0, D0 = 0, D = gr, Y0 = mr;
                                  continue;
                                }
                                throw [0, Fn, m$r];
                              }
                              fr = 1;
                              break;
                            case 103:
                            case 104:
                              if (A0 === 0) {
                                var y0 = 0, D0 = 0, A0 = n($0);
                                continue;
                              }
                              fr = 1;
                              break;
                            case 4:
                            case 98:
                              Rr($0, u0), xr($0, A0);
                              var Cr = [3, cr([0, jr], function(W7, Ht) {
                                return function(mt) {
                                  var U0 = Le(mt), R0 = Hr(mt, U0, ai(mt, u(X, mt)));
                                  return [0, R0, Ht !== 0 ? 1 : 0, lr([0, W7], 0, 0)];
                                };
                              }(Y0, D), $0)];
                              break;
                            default:
                              fr = 1;
                          }
                        else if (J0[0] === 4 && !n0(J0[3], _$r)) {
                          if (D0) {
                            if (A0 === 0) {
                              var sr = [0, Le($0)], Pr = xn(Y0, pr($0));
                              ie($0);
                              var y0 = 0, D0 = 0, u0 = sr, Y0 = Pr;
                              continue;
                            }
                            throw [0, Fn, y$r];
                          }
                          fr = 1;
                        } else
                          fr = 1;
                        if (fr) {
                          var K0 = 0;
                          if (D) {
                            var Ur = D[1];
                            if (u0) {
                              var Cr = ke(d$r);
                              K0 = 1;
                            } else if (typeof J0 == "number" && !(1 < (J0 + W2 | 0) >>> 0)) {
                              var d0 = [0, Ur, [1, Gc(lr([0, Y0], 0, 0), [0, Ur, h$r])]], Kr = 0, re = u0, xe = 0;
                              K0 = 2;
                            }
                          } else if (u0) {
                            var je = u0[1];
                            if (typeof J0 == "number" && !(1 < (J0 + W2 | 0) >>> 0)) {
                              var d0 = [0, je, [1, Gc(lr([0, Y0], 0, 0), [0, je, k$r])]], Kr = 0, re = 0, xe = D;
                              K0 = 2;
                            }
                          }
                          var le = 0;
                          switch (K0) {
                            case 0:
                              var Ie = function(Ht) {
                                zu(Ht, 0);
                                var mt = a(t4[20], 0, Ht);
                                return k7(Ht), mt;
                              }, Me = pr($0), Be = Ie($0), an = Be[1], Ke = Be[2], Ae = 0;
                              if (Ke[0] === 1) {
                                var on = Ke[1][2][1], rn = 0;
                                if (n0(on, w$r) && n0(on, E$r) && (rn = 1), !rn) {
                                  var kn = N0($0), sn = 0;
                                  if (typeof kn == "number") {
                                    var Pe = kn - 5 | 0;
                                    if (92 < Pe >>> 0) {
                                      if (!(94 < (Pe + 1 | 0) >>> 0)) {
                                        Rr($0, u0), xr($0, A0);
                                        var We = Ke;
                                        Ae = 1, sn = 1;
                                      }
                                    } else if (!(1 < (Pe + fX | 0) >>> 0)) {
                                      var d0 = [0, an, Ke], Kr = Y0, re = u0, xe = D;
                                      le = 1, Ae = 2, sn = 1;
                                    }
                                  }
                                  if (!sn) {
                                    Yi($0, Ke);
                                    var en = Ie($0), _n = Un(on, S$r), Dn = xn(Y0, Me);
                                    Rr($0, u0), xr($0, A0);
                                    var Cr = [0, cr([0, jr], function(mt, U0, R0, Re, Xe) {
                                      return function(he) {
                                        var _e = R0[1], rt = Yi(he, R0[2]), wn = Hr(he, mt, 0), ft = wn[2][2];
                                        if (Re) {
                                          var xt = ft[2], Gn = 0;
                                          if (xt[1])
                                            ue(he, [0, _e, j7]), Gn = 1;
                                          else {
                                            var tt = 0;
                                            !xt[2] && !xt[3] && (Gn = 1, tt = 1), tt || ue(he, [0, _e, 80]);
                                          }
                                        } else {
                                          var wt = ft[2], un = 0;
                                          if (wt[1])
                                            ue(he, [0, _e, Vt]), un = 1;
                                          else {
                                            var vn = wt[2], ut = 0;
                                            if (wt[3])
                                              ue(he, [0, _e, 81]);
                                            else {
                                              var It = 0;
                                              vn && !vn[2] && (It = 1), It || (ue(he, [0, _e, 81]), ut = 1);
                                            }
                                            ut || (un = 1);
                                          }
                                        }
                                        var Ti = lr([0, Xe], 0, 0), hs = 0, Ou = 0, Vs = 0, zi = U0 !== 0 ? 1 : 0, zs = 0, Ks = Re ? [1, wn] : [2, wn];
                                        return [0, rt, Ks, zs, zi, Vs, Ou, hs, Ti];
                                      };
                                    }(jr, D, en, _n, Dn), $0)];
                                    Ae = 2;
                                  }
                                }
                              }
                              var Xn = 0;
                              switch (Ae) {
                                case 2:
                                  Xn = 1;
                                  break;
                                case 0:
                                  var On = Be[2], bt = N0($0), Ct = 0;
                                  if (typeof bt == "number") {
                                    var Tt = 0;
                                    if (bt !== 4 && bt !== 98 && (Tt = 1), !Tt) {
                                      Rr($0, u0), xr($0, A0);
                                      var We = On;
                                      Ct = 1;
                                    }
                                  }
                                  if (!Ct) {
                                    var Zt = D !== 0 ? 1 : 0, Ut = 0;
                                    if (On[0] === 1) {
                                      var Ot = On[1], Pt = Ot[2][1], yu = 0;
                                      if (B) {
                                        var Ku = 0;
                                        !Un(g$r, Pt) && (!Zt || !Un(F$r, Pt)) && (Ku = 1), Ku || (ue($0, [0, Ot[1], [21, Pt, Zt, 0, 0]]), Ut = 1, yu = 1);
                                      }
                                    }
                                    var d0 = [0, an, On], Kr = Y0, re = u0, xe = D;
                                    le = 1, Xn = 1;
                                  }
                                  break;
                              }
                              if (!Xn)
                                var pt = Yi($0, We), xu = Hr($0, jr, ai($0, u(X, $0))), Gu = [0, xu[1], [12, xu[2]]], K7 = [0, pt, [0, Gu], 0, D !== 0 ? 1 : 0, 0, 1, 0, lr([0, Y0], 0, 0)], Cr = [0, [0, Gu[1], K7]];
                              break;
                            case 2:
                              le = 1;
                              break;
                          }
                          if (le) {
                            var Vi = d0[2], a7 = d0[1];
                            1 - iu($0) && Ge($0, 12);
                            var Cr = [0, cr([0, jr], function(Ht, mt, U0, R0, Re, Xe) {
                              return function(he) {
                                var _e = fu(he, 85), rt = he0(he, 86) ? u(e, he) : [0, Xe, p$r];
                                return [0, Re, [0, rt], _e, mt !== 0 ? 1 : 0, U0 !== 0 ? 1 : 0, 0, Ht, lr([0, R0], 0, 0)];
                              };
                            }(A0, xe, re, Kr, Vi, a7), $0)];
                          }
                        }
                        Or(O0, $0);
                        var Sr = [0, [0, Cr, qr], Br, Mr];
                        continue r;
                      }
                    }
                }, b0);
              }), N(X0, function(B) {
                var Z = N0(B) === 41 ? 1 : 0;
                if (Z) {
                  V0(B, 41);
                  for (var p0 = 0; ; ) {
                    var b0 = [0, u(dr, B), p0], O0 = N0(B);
                    if (typeof O0 == "number" && O0 === 9) {
                      V0(B, 9);
                      var p0 = b0;
                      continue;
                    }
                    var q0 = ge0(B, de(b0));
                    break;
                  }
                } else
                  var q0 = Z;
                return [0, q0, R(E0, 0, 0, 0, B)];
              }), N(b, function(B) {
                var Z = z7(B), p0 = Z[2], b0 = p0[1], O0 = Z[1];
                return be0(b0) && ue(B, [0, O0, 3]), [0, O0, [0, b0, p0[2]]];
              }), N(G0, function(B) {
                return cr(0, function(Z) {
                  var p0 = u(b, Z), b0 = N0(Z) === 86 ? [1, u(i, Z)] : [0, G1(Z)];
                  return [0, p0, b0];
                }, B);
              }), N(X, function(B) {
                var Z = N0(B) === 98 ? 1 : 0;
                if (Z) {
                  1 - iu(B) && Ge(B, 12);
                  var p0 = [0, cr(0, function(O0) {
                    var q0 = pr(O0);
                    V0(O0, 98);
                    for (var nr = 0, yr = 0; ; ) {
                      var vr = cr(0, function(ne) {
                        return function(Qr) {
                          var pe = n(Qr), oe = u(G0, Qr), me = oe[2], ae = N0(Qr), ce = 0;
                          if (typeof ae == "number" && ae === 82) {
                            ie(Qr);
                            var ge = 1, H0 = [0, u(e, Qr)];
                            ce = 1;
                          }
                          if (!ce) {
                            ne && ue(Qr, [0, oe[1], 77]);
                            var ge = ne, H0 = 0;
                          }
                          return [0, pe, me[1], me[2], H0, ge];
                        };
                      }(nr), O0), $0 = vr[2], Sr = [0, [0, vr[1], [0, $0[2], $0[3], $0[1], $0[4]]], yr], Mr = N0(O0), Br = 0;
                      if (typeof Mr == "number") {
                        var qr = 0;
                        if (Mr !== 99 && Ln !== Mr && (qr = 1), !qr) {
                          var jr = de(Sr);
                          Br = 1;
                        }
                      }
                      if (!Br) {
                        if (V0(O0, 9), N0(O0) !== 99) {
                          var nr = $0[5], yr = Sr;
                          continue;
                        }
                        var jr = de(Sr);
                      }
                      var $r = pr(O0);
                      return V0(O0, 99), [0, jr, mu([0, q0], [0, we(O0)], $r, 0)];
                    }
                  }, B)];
                } else
                  var p0 = Z;
                return p0;
              }), N(s0, function(B) {
                var Z = N0(B) === 98 ? 1 : 0, p0 = Z && [0, cr(0, function(b0) {
                  var O0 = pr(b0);
                  V0(b0, 98);
                  for (var q0 = u2(0, b0), nr = 0; ; ) {
                    var yr = N0(q0);
                    if (typeof yr == "number") {
                      var vr = 0;
                      if ((yr === 99 || Ln === yr) && (vr = 1), vr) {
                        var $0 = de(nr), Sr = pr(q0);
                        return V0(q0, 99), [0, $0, mu([0, O0], [0, we(q0)], Sr, 0)];
                      }
                    }
                    var Mr = [0, u(e, q0), nr];
                    N0(q0) !== 99 && V0(q0, 9);
                    var nr = Mr;
                  }
                }, B)];
                return p0;
              }), N(dr, function(B) {
                return a(Ar, B, u(b, B));
              }), N(Ar, function(B, Z) {
                function p0(b0) {
                  for (var O0 = [0, Z[1], [0, Z]]; ; ) {
                    var q0 = O0[2], nr = O0[1];
                    if (N0(b0) === 10 && _e0(1, b0)) {
                      var yr = cr([0, nr], function(qr) {
                        return function(jr) {
                          return V0(jr, 10), [0, qr, u(b, jr)];
                        };
                      }(q0), b0), vr = yr[1], O0 = [0, vr, [1, [0, vr, yr[2]]]];
                      continue;
                    }
                    if (N0(b0) === 98)
                      var $0 = $t(b0), Sr = function(Br, qr) {
                        return a(Qe(Br, -860373976, 77), Br, qr);
                      }, Mr = a($0[2], q0, Sr);
                    else
                      var Mr = q0;
                    return [0, Mr, u(s0, b0), 0];
                  }
                }
                return cr([0, Z[1]], p0, B);
              }), N(ar, function(B, Z) {
                var p0 = a(Ar, B, Z);
                return [0, p0[1], [16, p0[2]]];
              }), N(W0, function(B) {
                var Z = N0(B);
                return typeof Z == "number" && Z === 86 ? [1, u(i, B)] : [0, G1(B)];
              }), N(Lr, function(B, Z, p0) {
                var b0 = B[2];
                function O0(gr) {
                  return y7(gr, lr([0, Z], [0, p0], 0));
                }
                switch (b0[0]) {
                  case 0:
                    var F0 = [0, O0(b0[1])];
                    break;
                  case 1:
                    var F0 = [1, O0(b0[1])];
                    break;
                  case 2:
                    var F0 = [2, O0(b0[1])];
                    break;
                  case 3:
                    var F0 = [3, O0(b0[1])];
                    break;
                  case 4:
                    var F0 = [4, O0(b0[1])];
                    break;
                  case 5:
                    var F0 = [5, O0(b0[1])];
                    break;
                  case 6:
                    var F0 = [6, O0(b0[1])];
                    break;
                  case 7:
                    var F0 = [7, O0(b0[1])];
                    break;
                  case 8:
                    var F0 = [8, O0(b0[1])];
                    break;
                  case 9:
                    var F0 = [9, O0(b0[1])];
                    break;
                  case 10:
                    var F0 = [10, O0(b0[1])];
                    break;
                  case 11:
                    var q0 = b0[1], nr = O0(q0[2]), F0 = [11, [0, q0[1], nr]];
                    break;
                  case 12:
                    var yr = b0[1], vr = O0(yr[4]), F0 = [12, [0, yr[1], yr[2], yr[3], vr]];
                    break;
                  case 13:
                    var $0 = b0[1], Sr = lr([0, Z], [0, p0], 0), Mr = QD($0[4], Sr), F0 = [13, [0, $0[1], $0[2], $0[3], Mr]];
                    break;
                  case 14:
                    var Br = b0[1], qr = O0(Br[3]), F0 = [14, [0, Br[1], Br[2], qr]];
                    break;
                  case 15:
                    var jr = b0[1], $r = O0(jr[2]), F0 = [15, [0, jr[1], $r]];
                    break;
                  case 16:
                    var ne = b0[1], Qr = O0(ne[3]), F0 = [16, [0, ne[1], ne[2], Qr]];
                    break;
                  case 17:
                    var pe = b0[1], oe = O0(pe[3]), F0 = [17, [0, pe[1], pe[2], oe]];
                    break;
                  case 18:
                    var me = b0[1], ae = me[1], ce = me[2], ge = O0(ae[3]), F0 = [18, [0, [0, ae[1], ae[2], ge], ce]];
                    break;
                  case 19:
                    var H0 = b0[1], Fr = O0(H0[2]), F0 = [19, [0, H0[1], Fr]];
                    break;
                  case 20:
                    var _ = b0[1], k = O0(_[2]), F0 = [20, [0, _[1], k]];
                    break;
                  case 21:
                    var I = b0[1], U = O0(I[2]), F0 = [21, [0, I[1], U]];
                    break;
                  case 22:
                    var Y = b0[1], y0 = O0(Y[2]), F0 = [22, [0, Y[1], y0]];
                    break;
                  case 23:
                    var D0 = b0[1], A0 = O0(D0[3]), F0 = [23, [0, D0[1], D0[2], A0]];
                    break;
                  case 24:
                    var D = b0[1], u0 = O0(D[3]), F0 = [24, [0, D[1], D[2], u0]];
                    break;
                  case 25:
                    var Y0 = b0[1], J0 = O0(Y0[3]), F0 = [25, [0, Y0[1], Y0[2], J0]];
                    break;
                  default:
                    var fr = b0[1], Q0 = O0(fr[2]), F0 = [26, [0, fr[1], Q0]];
                }
                return [0, B[1], F0];
              });
              function Wr(B) {
                var Z = pr(B);
                if (V0(B, 66), N0(B) === 4) {
                  var p0 = xn(Z, pr(B));
                  V0(B, 4), zu(B, 0);
                  var b0 = u(t4[9], B);
                  return k7(B), V0(B, 5), [0, [0, b0], lr([0, p0], [0, we(B)], 0)];
                }
                return [0, 0, lr([0, Z], [0, we(B)], 0)];
              }
              var Jr = 0;
              function or(B) {
                var Z = u2(0, B), p0 = N0(Z);
                return typeof p0 == "number" && p0 === 66 ? [0, cr(Jr, Wr, Z)] : 0;
              }
              function _r(B) {
                var Z = N0(B), p0 = Vn(1, B);
                if (typeof Z == "number" && Z === 86) {
                  if (typeof p0 == "number" && p0 === 66) {
                    V0(B, 86);
                    var b0 = or(B);
                    return [0, [0, G1(B)], b0];
                  }
                  var O0 = u(W0, B), q0 = N0(B) === 66 ? a2(B, O0) : O0;
                  return [0, q0, or(B)];
                }
                return [0, [0, G1(B)], 0];
              }
              function Ir(B, Z) {
                var p0 = ys(1, Z);
                zu(p0, 1);
                var b0 = u(B, p0);
                return k7(p0), b0;
              }
              function fe(B) {
                return Ir(e, B);
              }
              function v0(B) {
                return Ir(b, B);
              }
              function P(B) {
                return Ir(X, B);
              }
              function L(B) {
                return Ir(s0, B);
              }
              function Q(B, Z) {
                return Ir(ir(E0, B, 0, 0), Z);
              }
              function i0(B) {
                return Ir(X0, B);
              }
              function l0(B) {
                return Ir(l, B);
              }
              function S0(B) {
                return Ir(i, B);
              }
              function T0(B) {
                return Ir(W0, B);
              }
              function er(B) {
                return Ir(or, B);
              }
              function j0(B) {
                return Ir(_r, B);
              }
              return [0, fe, v0, P, L, function(B) {
                return Ir(dr, B);
              }, Q, i0, l0, S0, T0, er, j0];
            }
            function pne(t4) {
              function n(c, s) {
                if (s[0] === 0)
                  return s[1];
                var p = s[2][1];
                return Cu(function(y) {
                  return ue(c, y);
                }, p), s[1];
              }
              function e(c, s, p) {
                var y = c ? c[1] : 26;
                if (p[0] === 0)
                  var T = p[1];
                else {
                  var E = p[2][2];
                  Cu(function(A) {
                    return ue(s, A);
                  }, E);
                  var T = p[1];
                }
                1 - u(t4[23], T) && ue(s, [0, T[1], y]);
                var h = T[2], w = 0;
                return h[0] === 10 && Bs(h[1][2][1]) && (V7(s, [0, T[1], 52]), w = 1), a(t4[19], s, T);
              }
              function i(c, s) {
                return [0, [0, c, s[1]], [0, c, s[2]]];
              }
              function x(c, s) {
                var p = jc(c[2], s[2]);
                return [0, jc(c[1], s[1]), p];
              }
              return [0, n, e, H$r, i, x, function(c) {
                var s = de(c[2]);
                return [0, de(c[1]), s];
              }];
            }
            function mne(t4) {
              function n(S) {
                var M = N0(S);
                if (typeof M == "number") {
                  var K = M - 99 | 0, V = 0;
                  if (6 < K >>> 0 ? K === 14 && (V = 1) : 4 < (K - 1 | 0) >>> 0 && (V = 1), V)
                    return we(S);
                }
                var f0 = f7(S);
                return f0 && Us(S);
              }
              function e(S) {
                var M = pr(S);
                zu(S, 0);
                var K = cr(0, function(f0) {
                  V0(f0, 0), V0(f0, 12);
                  var m0 = u(t4[10], f0);
                  return V0(f0, 1), m0;
                }, S);
                k7(S);
                var V = lr([0, M], [0, n(S)], 0);
                return [0, K[1], [0, K[2], V]];
              }
              function i(S) {
                return N0(S) === 1 ? 0 : [0, u(t4[7], S)];
              }
              function x(S) {
                var M = pr(S);
                zu(S, 0);
                var K = cr(0, function(f0) {
                  V0(f0, 0);
                  var m0 = i(f0);
                  return V0(f0, 1), m0;
                }, S);
                k7(S);
                var V = mu([0, M], [0, n(S)], 0, 0);
                return [0, K[1], [0, K[2], V]];
              }
              function c(S) {
                zu(S, 0);
                var M = cr(0, function(K) {
                  V0(K, 0);
                  var V = N0(K), f0 = 0;
                  if (typeof V == "number" && V === 12) {
                    var m0 = pr(K);
                    V0(K, 12);
                    var k0 = u(t4[10], K), x0 = [3, [0, k0, lr([0, m0], 0, 0)]];
                    f0 = 1;
                  }
                  if (!f0)
                    var g0 = i(K), e0 = g0 ? 0 : pr(K), x0 = [2, [0, g0, mu(0, 0, e0, 0)]];
                  return V0(K, 1), x0;
                }, S);
                return k7(S), [0, M[1], M[2]];
              }
              function s(S) {
                var M = Le(S), K = N0(S), V = 0;
                if (typeof K != "number" && K[0] === 7) {
                  var f0 = K[1];
                  V = 1;
                }
                if (!V) {
                  Ft(XQr, S);
                  var f0 = YQr;
                }
                var m0 = pr(S);
                ie(S);
                var k0 = N0(S), g0 = 0;
                if (typeof k0 == "number") {
                  var e0 = k0 + jX | 0, x0 = 0;
                  if (72 < e0 >>> 0 ? e0 !== 76 && (x0 = 1) : 70 < (e0 - 1 | 0) >>> 0 || (x0 = 1), !x0) {
                    var l = we(S);
                    g0 = 1;
                  }
                }
                if (!g0)
                  var l = n(S);
                return [0, M, [0, f0, lr([0, m0], [0, l], 0)]];
              }
              function p(S) {
                var M = Vn(1, S);
                if (typeof M == "number") {
                  if (M === 10)
                    for (var K = cr(0, function(m0) {
                      var k0 = [0, s(m0)];
                      return V0(m0, 10), [0, k0, s(m0)];
                    }, S); ; ) {
                      var V = N0(S);
                      if (typeof V == "number" && V === 10) {
                        var f0 = function(k0) {
                          return function(g0) {
                            return V0(g0, 10), [0, [1, k0], s(g0)];
                          };
                        }(K), K = cr([0, K[1]], f0, S);
                        continue;
                      }
                      return [2, K];
                    }
                  if (M === 86)
                    return [1, cr(0, function(m0) {
                      var k0 = s(m0);
                      return V0(m0, 86), [0, k0, s(m0)];
                    }, S)];
                }
                return [0, s(S)];
              }
              function y(S) {
                return cr(0, function(M) {
                  var K = Vn(1, M), V = 0;
                  if (typeof K == "number" && K === 86) {
                    var f0 = [1, cr(0, function(b) {
                      var G0 = s(b);
                      return V0(b, 86), [0, G0, s(b)];
                    }, M)];
                    V = 1;
                  }
                  if (!V)
                    var f0 = [0, s(M)];
                  var m0 = N0(M), k0 = 0;
                  if (typeof m0 == "number" && m0 === 82) {
                    V0(M, 82);
                    var g0 = pr(M), e0 = N0(M), x0 = 0;
                    if (typeof e0 == "number")
                      if (e0 === 0) {
                        var l = x(M), c0 = l[2], t0 = l[1];
                        c0[1] || ue(M, [0, t0, 56]);
                        var a0 = [0, [1, t0, c0]];
                      } else
                        x0 = 1;
                    else if (e0[0] === 8) {
                      V0(M, e0);
                      var w0 = [0, e0[2]], _0 = lr([0, g0], [0, n(M)], 0), a0 = [0, [0, e0[1], [0, w0, e0[3], _0]]];
                    } else
                      x0 = 1;
                    if (x0) {
                      Ge(M, 57);
                      var a0 = [0, [0, Le(M), [0, HQr, UQr, 0]]];
                    }
                    var E0 = a0;
                    k0 = 1;
                  }
                  if (!k0)
                    var E0 = 0;
                  return [0, f0, E0];
                }, S);
              }
              function T(S) {
                return cr(0, function(M) {
                  V0(M, 98);
                  var K = N0(M);
                  if (typeof K == "number") {
                    if (K === 99)
                      return ie(M), BQr;
                  } else if (K[0] === 7)
                    for (var V = 0, f0 = p(M); ; ) {
                      var m0 = N0(M);
                      if (typeof m0 == "number") {
                        if (m0 === 0) {
                          var V = [0, [1, e(M)], V];
                          continue;
                        }
                      } else if (m0[0] === 7) {
                        var V = [0, [0, y(M)], V];
                        continue;
                      }
                      var k0 = de(V), g0 = [0, s1, [0, f0, fu(M, j7), k0]];
                      return fu(M, 99) ? [0, g0] : (q1(M, 99), [1, g0]);
                    }
                  return q1(M, 99), qQr;
                }, S);
              }
              function E(S) {
                return cr(0, function(M) {
                  V0(M, 98), V0(M, j7);
                  var K = N0(M);
                  if (typeof K == "number") {
                    if (K === 99)
                      return ie(M), Ci;
                  } else if (K[0] === 7) {
                    var V = p(M);
                    return he0(M, 99), [0, s1, [0, V]];
                  }
                  return q1(M, 99), Ci;
                }, S);
              }
              var h = function S(M) {
                return S.fun(M);
              }, w = function S(M) {
                return S.fun(M);
              }, G = function S(M) {
                return S.fun(M);
              };
              N(h, function(S) {
                var M = N0(S);
                if (typeof M == "number") {
                  if (M === 0)
                    return c(S);
                } else if (M[0] === 8)
                  return V0(S, M), [0, M[1], [4, [0, M[2], M[3]]]];
                var K = u(G, S), V = K[2], f0 = K[1];
                return Ci <= V[1] ? [0, f0, [1, V[2]]] : [0, f0, [0, V[2]]];
              });
              function A(S) {
                switch (S[0]) {
                  case 0:
                    return S[1][2][1];
                  case 1:
                    var M = S[1][2], K = Te(jQr, M[2][2][1]);
                    return Te(M[1][2][1], K);
                  default:
                    var V = S[1][2], f0 = V[1], m0 = f0[0] === 0 ? f0[1][2][1] : A([2, f0[1]]);
                    return Te(m0, Te(GQr, V[2][2][1]));
                }
              }
              return N(w, function(S) {
                var M = pr(S), K = T(S);
                k7(S);
                var V = K[2];
                if (V[0] === 0)
                  var f0 = V[1], m0 = typeof f0 == "number" ? 0 : f0[2][2], k0 = m0;
                else
                  var k0 = 1;
                if (k0)
                  var g0 = IU, e0 = g0, x0 = cr(0, function(qr) {
                    return 0;
                  }, S);
                else {
                  zu(S, 3);
                  for (var l = Le(S), c0 = 0; ; ) {
                    var t0 = i2(S), a0 = N0(S), w0 = 0;
                    if (typeof a0 == "number") {
                      var _0 = 0;
                      if (a0 === 98) {
                        zu(S, 2);
                        var E0 = N0(S), X0 = Vn(1, S), b = 0;
                        if (typeof E0 == "number" && E0 === 98 && typeof X0 == "number") {
                          var G0 = 0;
                          if (j7 !== X0 && Ln !== X0 && (G0 = 1), !G0) {
                            var X = E(S), s0 = X[2], dr = X[1], Ar = typeof s0 == "number" ? [0, Ci, dr] : [0, s1, [0, dr, s0[2]]], ar = S[23][1], W0 = 0;
                            if (ar) {
                              var Lr = ar[2];
                              if (Lr) {
                                var Tr = Lr[2];
                                W0 = 1;
                              }
                            }
                            if (!W0)
                              var Tr = ke(BRr);
                            S[23][1] = Tr;
                            var Hr = n2(S), Or = Yl(S[24][1], Hr);
                            S[25][1] = Or;
                            var xr = [0, de(c0), t0, Ar];
                            b = 1;
                          }
                        }
                        if (!b) {
                          var Rr = u(w, S), Wr = Rr[2], Jr = Rr[1], or = Ci <= Wr[1] ? [0, Jr, [1, Wr[2]]] : [0, Jr, [0, Wr[2]]], c0 = [0, or, c0];
                          continue;
                        }
                      } else if (Ln === a0) {
                        Ft(0, S);
                        var xr = [0, de(c0), t0, IU];
                      } else
                        w0 = 1, _0 = 1;
                      if (!_0)
                        var _r = t0 ? t0[1] : l, Ir = ht(l, _r), e0 = xr[3], x0 = [0, Ir, xr[1]];
                    } else
                      w0 = 1;
                    if (w0) {
                      var c0 = [0, u(h, S), c0];
                      continue;
                    }
                    break;
                  }
                }
                var fe = we(S), v0 = 0;
                if (typeof e0 != "number") {
                  var P = e0[1], L = 0;
                  if (s1 === P) {
                    var Q = e0[2], i0 = K[2];
                    if (i0[0] === 0) {
                      var l0 = i0[1];
                      if (typeof l0 == "number")
                        Ge(S, MQr);
                      else {
                        var S0 = A(l0[2][1]);
                        n0(A(Q[2][1]), S0) && Ge(S, [17, S0]);
                      }
                    }
                    var T0 = Q[1];
                  } else if (Ci === P) {
                    var er = K[2];
                    if (er[0] === 0) {
                      var j0 = er[1];
                      typeof j0 != "number" && Ge(S, [17, A(j0[2][1])]);
                    }
                    var T0 = e0[2];
                  } else
                    L = 1;
                  if (!L) {
                    var B = T0;
                    v0 = 1;
                  }
                }
                if (!v0)
                  var B = K[1];
                var Z = K[2][1], p0 = K[1];
                if (typeof Z == "number") {
                  var b0 = 0, O0 = lr([0, M], [0, fe], 0);
                  if (typeof e0 != "number") {
                    var q0 = e0[1], nr = 0;
                    if (s1 === q0)
                      var yr = e0[2][1];
                    else if (Ci === q0)
                      var yr = e0[2];
                    else
                      nr = 1;
                    if (!nr) {
                      var vr = yr;
                      b0 = 1;
                    }
                  }
                  if (!b0)
                    var vr = B;
                  var $0 = [0, Ci, [0, p0, vr, x0, O0]];
                } else {
                  var Sr = 0, Mr = lr([0, M], [0, fe], 0);
                  if (typeof e0 != "number" && s1 === e0[1]) {
                    var Br = [0, e0[2]];
                    Sr = 1;
                  }
                  if (!Sr)
                    var Br = 0;
                  var $0 = [0, s1, [0, [0, p0, Z[2]], Br, x0, Mr]];
                }
                return [0, ht(K[1], B), $0];
              }), N(G, function(S) {
                return zu(S, 2), u(w, S);
              }), [0, n, e, i, x, c, s, p, y, T, E, h, w, G];
            }
            function Fi(t4) {
              return typeof t4 == "number" ? 0 : t4[0] === 0 ? 1 : t4[1];
            }
            function _ne(t4, n) {
              return [0, t4, n];
            }
            function tb(t4, n, e) {
              return [1, 2, n, e, t4, 0];
            }
            function ub(t4, n, e) {
              return [1, 2, t4, n, 0, e];
            }
            function Xc(t4, n, e, i) {
              var x = Fi(t4), c = Fi(i), s = c <= x ? x + 1 | 0 : c + 1 | 0;
              return s === 1 ? [0, n, e] : [1, s, n, e, t4, i];
            }
            function IL(t4, n) {
              var e = n !== 0 ? 1 : 0;
              if (e) {
                if (n !== 1) {
                  var i = n >>> 1 | 0, x = IL(t4, i), c = u(t4, 0), s = IL(t4, (n - i | 0) - 1 | 0), p = c[2], y = c[1];
                  return [1, Fi(x) + 1 | 0, y, p, x, s];
                }
                var T = u(t4, 0), E = [0, T[1], T[2]];
              } else
                var E = e;
              return E;
            }
            function D9(t4, n, e, i) {
              var x = Fi(t4), c = Fi(i), s = c <= x ? x + 1 | 0 : c + 1 | 0;
              return [1, s, n, e, t4, i];
            }
            function Tu(t4, n, e, i) {
              var x = Fi(t4), c = Fi(i);
              if ((c + 2 | 0) < x) {
                var s = t4[5], p = t4[4], y = t4[3], T = t4[2], E = Fi(s);
                if (E <= Fi(p))
                  return D9(p, T, y, Xc(s, n, e, i));
                var h = Xc(s[5], n, e, i), w = s[3], G = s[2];
                return D9(Xc(p, T, y, s[4]), G, w, h);
              }
              if ((x + 2 | 0) < c) {
                var A = i[5], S = i[4], M = i[3], K = i[2], V = Fi(S);
                if (V <= Fi(A))
                  return D9(Xc(t4, n, e, S), K, M, A);
                var f0 = Xc(S[5], K, M, A), m0 = S[3], k0 = S[2];
                return D9(Xc(t4, n, e, S[4]), k0, m0, f0);
              }
              return Xc(t4, n, e, i);
            }
            var x7 = 0;
            function yne(t4) {
              var n = typeof t4 == "number" ? 1 : 0, e = n && 1;
              return e;
            }
            function Xs(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (typeof e == "number")
                  return i;
                if (e[0] === 0)
                  return [0, e[1], e[2], x7, i];
                var x = [0, e[2], e[3], e[5], i], e = e[4], i = x;
              }
            }
            function Ne0(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  throw Jt;
                if (n[0] === 0)
                  return n;
                if (typeof n[4] == "number")
                  return [0, n[2], n[3]];
                var n = n[4];
              }
            }
            function Ce0(t4) {
              for (var n = t4; ; ) {
                var e = n[4];
                if (typeof e == "number")
                  return [0, n[2], n[3]];
                if (e[0] === 0)
                  return e;
                var n = e;
              }
            }
            function Pe0(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  return 0;
                if (n[0] === 0)
                  return [0, [0, n[1], n[2]]];
                if (typeof n[4] == "number")
                  return [0, [0, n[2], n[3]]];
                var n = n[4];
              }
            }
            function dne(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  throw Jt;
                if (n[0] === 0)
                  return n;
                if (typeof n[5] == "number")
                  return [0, n[2], n[3]];
                var n = n[5];
              }
            }
            function hne(t4) {
              for (var n = t4; ; ) {
                if (typeof n == "number")
                  return 0;
                if (n[0] === 0)
                  return [0, [0, n[1], n[2]]];
                if (typeof n[5] == "number")
                  return [0, [0, n[2], n[3]]];
                var n = n[5];
              }
            }
            function AL(t4) {
              var n = t4[5], e = t4[4], i = t4[3], x = t4[2];
              return typeof e == "number" ? n : e[0] === 0 ? Tu(0, x, i, n) : Tu(AL(e), x, i, n);
            }
            function NL(t4, n) {
              if (typeof n == "number")
                return t4;
              if (n[0] === 0)
                return tb(t4, n[1], n[2]);
              var e = n[5], i = n[3], x = n[2];
              return Tu(NL(t4, n[4]), x, i, e);
            }
            function De0(t4, n, e) {
              if (typeof e == "number")
                return [0, t4, n];
              if (e[0] === 0)
                return ub(t4, n, e);
              var i = e[5], x = e[3], c = e[2];
              return Tu(De0(t4, n, e[4]), c, x, i);
            }
            function CL(t4, n) {
              if (typeof n == "number")
                return t4;
              if (n[0] === 0)
                return ub(n[1], n[2], t4);
              var e = CL(t4, n[5]);
              return Tu(n[4], n[2], n[3], e);
            }
            function Le0(t4, n, e) {
              if (typeof e == "number")
                return [0, t4, n];
              if (e[0] === 0)
                return tb(e, t4, n);
              var i = Le0(t4, n, e[5]);
              return Tu(e[4], e[2], e[3], i);
            }
            function Re0(t4, n) {
              if (typeof t4 == "number")
                return n;
              if (t4[0] === 1 && typeof n != "number") {
                if (n[0] === 0)
                  return CL(n, t4);
                var e = Ce0(n), i = AL(n);
                return Tu(t4, e[1], e[2], i);
              }
              return typeof n == "number" ? t4 : NL(t4, n);
            }
            function oi(t4, n, e, i) {
              if (typeof t4 == "number")
                return De0(n, e, i);
              if (t4[0] === 0) {
                if (typeof i != "number") {
                  if (i[0] === 0)
                    return [1, 2, n, e, t4, i];
                  if (3 < i[1]) {
                    var x = i[5], c = i[3], s = i[2];
                    return Tu(oi(t4, n, e, i[4]), s, c, x);
                  }
                  return Xc(t4, n, e, i);
                }
              } else {
                var p = t4[5], y = t4[4], T = t4[3], E = t4[2], h = t4[1];
                if (typeof i != "number") {
                  if (i[0] === 0)
                    return 3 < h ? Tu(y, E, T, oi(p, n, e, i)) : Xc(t4, n, e, i);
                  var w = i[1];
                  if ((w + 2 | 0) < h)
                    return Tu(y, E, T, oi(p, n, e, i));
                  if ((h + 2 | 0) < w) {
                    var G = i[5], A = i[3], S = i[2];
                    return Tu(oi(t4, n, e, i[4]), S, A, G);
                  }
                  return Xc(t4, n, e, i);
                }
              }
              return Le0(n, e, t4);
            }
            function L9(t4, n) {
              if (typeof t4 == "number")
                return n;
              if (t4[0] === 1 && typeof n != "number") {
                if (n[0] === 0)
                  return CL(n, t4);
                var e = Ce0(n), i = AL(n);
                return oi(t4, e[1], e[2], i);
              }
              return typeof n == "number" ? t4 : NL(t4, n);
            }
            function ib(t4, n, e, i) {
              return e ? oi(t4, n, e[1], i) : L9(t4, i);
            }
            function je0(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 0;
                if (e[0] === 0)
                  return a(t4, e[1], e[2]);
                je0(t4, e[4]), a(t4, e[2], e[3]);
                var e = e[5];
              }
            }
            function PL(t4, n) {
              if (typeof n == "number")
                return 0;
              if (n[0] === 0) {
                var e = u(t4, n[2]);
                return [0, n[1], e];
              }
              var i = PL(t4, n[4]), x = u(t4, n[3]), c = PL(t4, n[5]);
              return [1, n[1], n[2], x, i, c];
            }
            function DL(t4, n) {
              if (typeof n == "number")
                return 0;
              if (n[0] === 0) {
                var e = n[1];
                return [0, e, a(t4, e, n[2])];
              }
              var i = n[2], x = DL(t4, n[4]), c = a(t4, i, n[3]), s = DL(t4, n[5]);
              return [1, n[1], i, c, x, s];
            }
            function LL(t4, n, e) {
              for (var i = n, x = e; ; ) {
                if (typeof i == "number")
                  return x;
                if (i[0] === 0)
                  return ir(t4, i[1], i[2], x);
                var c = LL(t4, i[4], x), s = ir(t4, i[2], i[3], c), i = i[5], x = s;
              }
            }
            function Ge0(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (typeof i == "number")
                  return e;
                if (i[0] === 0)
                  return [0, i[1], e];
                var x = i[4], c = Ge0(e, i[5]), e = [0, i[2], c], i = x;
              }
            }
            function Me0(t4) {
              return Ge0(0, t4);
            }
            function Be0(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 1;
                if (e[0] === 0)
                  return a(t4, e[1], e[2]);
                var i = a(t4, e[2], e[3]);
                if (i) {
                  var x = Be0(t4, e[4]);
                  if (x) {
                    var e = e[5];
                    continue;
                  }
                  var c = x;
                } else
                  var c = i;
                return c;
              }
            }
            function qe0(t4, n) {
              for (var e = n; ; ) {
                if (typeof e == "number")
                  return 0;
                if (e[0] === 0)
                  return a(t4, e[1], e[2]);
                var i = a(t4, e[2], e[3]);
                if (i)
                  var x = i;
                else {
                  var c = qe0(t4, e[4]);
                  if (!c) {
                    var e = e[5];
                    continue;
                  }
                  var x = c;
                }
                return x;
              }
            }
            function RL(t4, n) {
              if (typeof n == "number")
                return 0;
              if (n[0] === 0)
                return a(t4, n[1], n[2]) ? n : x7;
              var e = n[5], i = n[4], x = n[3], c = n[2], s = RL(t4, i), p = a(t4, c, x), y = RL(t4, e);
              return p ? i === s && e === y ? n : oi(s, c, x, y) : L9(s, y);
            }
            function jL(t4) {
              if (typeof t4 == "number")
                return 0;
              if (t4[0] === 0)
                return 1;
              var n = jL(t4[5]);
              return (jL(t4[4]) + 1 | 0) + n | 0;
            }
            function Ue0(t4, n) {
              for (var e = t4, i = n; ; ) {
                if (typeof i == "number")
                  return e;
                if (i[0] === 0)
                  return [0, i, e];
                var x = i[4], c = Ue0(e, i[5]), e = [0, [0, i[2], i[3]], c], i = x;
              }
            }
            function kne(t4) {
              return Ue0(0, t4);
            }
            var R9 = function(t4) {
              function n(A, S, M) {
                if (typeof M == "number")
                  return [0, A, S];
                if (M[0] === 0) {
                  var K = M[1], V = a(t4[1], A, K);
                  return V === 0 ? M[2] === S ? M : [0, K, S] : 0 <= V ? tb(M, A, S) : ub(A, S, M);
                }
                var f0 = M[5], m0 = M[4], k0 = M[3], g0 = M[2], e0 = a(t4[1], A, g0);
                if (e0 === 0)
                  return k0 === S ? M : [1, M[1], A, S, m0, f0];
                if (0 <= e0) {
                  var x0 = n(A, S, f0);
                  return f0 === x0 ? M : Tu(m0, g0, k0, x0);
                }
                var l = n(A, S, m0);
                return m0 === l ? M : Tu(l, g0, k0, f0);
              }
              function e(A, S) {
                for (var M = S; ; ) {
                  if (typeof M == "number")
                    throw Jt;
                  if (M[0] === 0) {
                    if (a(t4[1], A, M[1]) === 0)
                      return M[2];
                    throw Jt;
                  }
                  var K = a(t4[1], A, M[2]);
                  if (K === 0)
                    return M[3];
                  var V = 0 <= K ? M[5] : M[4], M = V;
                }
              }
              function i(A, S) {
                for (var M = S; ; ) {
                  if (typeof M == "number")
                    return 0;
                  if (M[0] === 0) {
                    var K = a(t4[1], A, M[1]) === 0 ? 1 : 0, V = K && [0, M[2]];
                    return V;
                  }
                  var f0 = a(t4[1], A, M[2]);
                  if (f0 === 0)
                    return [0, M[3]];
                  var m0 = 0 <= f0 ? M[5] : M[4], M = m0;
                }
              }
              function x(A, S) {
                for (var M = S; ; ) {
                  if (typeof M == "number")
                    return 0;
                  if (M[0] === 0)
                    return a(t4[1], A, M[1]) === 0 ? 1 : 0;
                  var K = a(t4[1], A, M[2]), V = K === 0 ? 1 : 0;
                  if (V)
                    return V;
                  var f0 = 0 <= K ? M[5] : M[4], M = f0;
                }
              }
              function c(A, S) {
                if (typeof S == "number")
                  return S;
                if (S[0] === 0)
                  return a(t4[1], A, S[1]) === 0 ? x7 : S;
                var M = S[5], K = S[4], V = S[3], f0 = S[2], m0 = a(t4[1], A, f0);
                if (m0 === 0)
                  return Re0(K, M);
                if (0 <= m0) {
                  var k0 = c(A, M);
                  return M === k0 ? S : Tu(K, f0, V, k0);
                }
                var g0 = c(A, K);
                return K === g0 ? S : Tu(g0, f0, V, M);
              }
              function s(A, S, M) {
                if (typeof M == "number")
                  return [0, A, u(S, 0)];
                if (M[0] === 0) {
                  var K = M[2], V = M[1], f0 = a(t4[1], A, V);
                  if (f0 === 0) {
                    var m0 = u(S, [0, K]);
                    return K === m0 ? M : [0, V, m0];
                  }
                  var k0 = u(S, 0);
                  return 0 <= f0 ? tb(M, A, k0) : ub(A, k0, M);
                }
                var g0 = M[5], e0 = M[4], x0 = M[3], l = M[2], c0 = a(t4[1], A, l);
                if (c0 === 0) {
                  var t0 = u(S, [0, x0]);
                  return x0 === t0 ? M : [1, M[1], A, t0, e0, g0];
                }
                if (0 <= c0) {
                  var a0 = s(A, S, g0);
                  return g0 === a0 ? M : Tu(e0, l, x0, a0);
                }
                var w0 = s(A, S, e0);
                return e0 === w0 ? M : Tu(w0, l, x0, g0);
              }
              function p(A, S, M) {
                if (typeof M == "number") {
                  var K = u(S, 0);
                  return K && [0, A, K[1]];
                } else {
                  if (M[0] === 0) {
                    var V = M[2], f0 = M[1], m0 = a(t4[1], A, f0);
                    if (m0 === 0) {
                      var k0 = u(S, [0, V]);
                      if (k0) {
                        var g0 = k0[1];
                        return V === g0 ? M : [0, f0, g0];
                      }
                      return x7;
                    }
                    var e0 = u(S, 0);
                    if (e0) {
                      var x0 = e0[1];
                      return 0 <= m0 ? tb(M, A, x0) : ub(A, x0, M);
                    }
                    return M;
                  }
                  var l = M[5], c0 = M[4], t0 = M[3], a0 = M[2], w0 = a(t4[1], A, a0);
                  if (w0 === 0) {
                    var _0 = u(S, [0, t0]);
                    if (_0) {
                      var E0 = _0[1];
                      return t0 === E0 ? M : [1, M[1], A, E0, c0, l];
                    }
                    return Re0(c0, l);
                  }
                  if (0 <= w0) {
                    var X0 = p(A, S, l);
                    return l === X0 ? M : Tu(c0, a0, t0, X0);
                  }
                  var b = p(A, S, c0);
                  return c0 === b ? M : Tu(b, a0, t0, l);
                }
              }
              function y(A, S) {
                if (typeof S == "number")
                  return VQr;
                if (S[0] === 0) {
                  var M = a(t4[1], A, S[1]);
                  return M === 0 ? [0, x7, [0, S[2]], x7] : 0 <= M ? [0, S, 0, x7] : [0, x7, 0, S];
                }
                var K = S[5], V = S[4], f0 = S[3], m0 = S[2], k0 = a(t4[1], A, m0);
                if (k0 === 0)
                  return [0, V, [0, f0], K];
                if (0 <= k0) {
                  var g0 = y(A, K), e0 = g0[3], x0 = g0[2];
                  return [0, oi(V, m0, f0, g0[1]), x0, e0];
                }
                var l = y(A, V), c0 = oi(l[3], m0, f0, K);
                return [0, l[1], l[2], c0];
              }
              function T(A, S, M) {
                if (typeof S == "number") {
                  if (typeof M == "number")
                    return 0;
                  if (M[0] === 0) {
                    var K = M[1], V = ir(A, K, 0, [0, M[2]]);
                    return V ? [0, K, V[1]] : x7;
                  }
                } else if (S[0] === 0) {
                  var f0 = S[2], m0 = S[1];
                  if (typeof M == "number") {
                    var k0 = ir(A, m0, [0, f0], 0);
                    return k0 ? [0, m0, k0[1]] : x7;
                  } else if (M[0] === 0) {
                    var g0 = y(m0, M), e0 = T(A, x7, g0[3]), x0 = ir(A, m0, [0, f0], g0[2]);
                    return ib(T(A, x7, g0[1]), m0, x0, e0);
                  }
                } else {
                  var l = S[2], c0 = Fi(M);
                  if (c0 <= S[1]) {
                    var t0 = y(l, M), a0 = T(A, S[5], t0[3]), w0 = ir(A, l, [0, S[3]], t0[2]);
                    return ib(T(A, S[4], t0[1]), l, w0, a0);
                  }
                  var _0 = 0;
                  if ((typeof M == "number" || M[0] !== 1) && (_0 = 1), _0)
                    throw [0, Fn, zQr];
                }
                var E0 = M[2], X0 = y(E0, S), b = T(A, X0[3], M[5]), G0 = ir(A, E0, X0[2], [0, M[3]]);
                return ib(T(A, X0[1], M[4]), E0, G0, b);
              }
              function E(A, S, M) {
                var K = 0;
                if (typeof S == "number") {
                  var _0 = M;
                  K = 1;
                } else if (S[0] === 1) {
                  var V = S[3], f0 = S[2];
                  if (typeof M != "number" && M[0] !== 0) {
                    var m0 = M[3], k0 = M[2];
                    if (M[1] <= S[1]) {
                      var g0 = y(f0, M), e0 = g0[2], x0 = E(A, S[4], g0[1]), l = E(A, S[5], g0[3]);
                      return e0 ? ib(x0, f0, ir(A, f0, V, e0[1]), l) : oi(x0, f0, V, l);
                    }
                    var c0 = y(k0, S), t0 = c0[2], a0 = E(A, c0[1], M[4]), w0 = E(A, c0[3], M[5]);
                    return t0 ? ib(a0, k0, ir(A, k0, t0[1], m0), w0) : oi(a0, k0, m0, w0);
                  }
                }
                if (!K)
                  if (typeof M == "number")
                    var _0 = S;
                  else {
                    if (M[0] === 0) {
                      var E0 = M[2], X0 = M[1];
                      return p(X0, function(X) {
                        return X ? ir(A, X0, X[1], E0) : [0, E0];
                      }, S);
                    }
                    var b = S[2], G0 = S[1];
                    return p(G0, function(X) {
                      return X ? ir(A, G0, b, X[1]) : [0, b];
                    }, M);
                  }
                return _0;
              }
              function h(A, S) {
                if (typeof S == "number")
                  return KQr;
                if (S[0] === 0)
                  return a(A, S[1], S[2]) ? [0, S, x7] : [0, x7, S];
                var M = S[3], K = S[2], V = h(A, S[4]), f0 = V[2], m0 = V[1], k0 = a(A, K, M), g0 = h(A, S[5]), e0 = g0[2], x0 = g0[1];
                if (k0) {
                  var l = L9(f0, e0);
                  return [0, oi(m0, K, M, x0), l];
                }
                var c0 = oi(f0, K, M, e0);
                return [0, L9(m0, x0), c0];
              }
              function w(A, S, M) {
                for (var K = Xs(M, 0), V = Xs(S, 0), f0 = K; ; ) {
                  if (V) {
                    if (f0) {
                      var m0 = a(t4[1], V[1], f0[1]);
                      if (m0 === 0) {
                        var k0 = a(A, V[2], f0[2]);
                        if (k0 === 0) {
                          var g0 = Xs(f0[3], f0[4]), V = Xs(V[3], V[4]), f0 = g0;
                          continue;
                        }
                        return k0;
                      }
                      return m0;
                    }
                    return 1;
                  }
                  var e0 = f0 && -1;
                  return e0;
                }
              }
              function G(A, S, M) {
                for (var K = Xs(M, 0), V = Xs(S, 0), f0 = K; ; ) {
                  if (V) {
                    if (f0) {
                      var m0 = a(t4[1], V[1], f0[1]) === 0 ? 1 : 0;
                      if (m0) {
                        var k0 = a(A, V[2], f0[2]);
                        if (k0) {
                          var g0 = Xs(f0[3], f0[4]), V = Xs(V[3], V[4]), f0 = g0;
                          continue;
                        }
                        var e0 = k0;
                      } else
                        var e0 = m0;
                    } else
                      var e0 = f0;
                    return e0;
                  }
                  return f0 ? 0 : 1;
                }
              }
              return [0, x7, yne, x, n, p, s, _ne, c, T, E, w, G, je0, LL, Be0, qe0, RL, h, jL, kne, Ne0, Pe0, dne, hne, Me0, Me0, function(A, S, M) {
                var K = [0, x7, 0], V = LL(function(f0, m0, k0) {
                  var g0 = k0[1], e0 = u(S, f0), x0 = k0[2], l = x0 || (e0 !== f0 ? 1 : 0);
                  if (A)
                    var c0 = A[1], t0 = s(e0, function(a0) {
                      return a0 ? a(c0, a0[1], m0) : m0;
                    }, g0);
                  else
                    var t0 = n(e0, m0, g0);
                  return [0, t0, l];
                }, M, K);
                return V[2] ? V[1] : M;
              }, Ne0, Pe0, y, e, i, PL, DL, IL];
            }([0, dz]);
            function o2(t4) {
              return [0, G1(t4)];
            }
            var GL = uL([0, function(t4, n) {
              var e = Z00(t4[1], n[1]);
              return e === 0 ? a(ar0, t4[2], n[2]) : e;
            }]);
            function fb(t4, n, e) {
              var i = e[2][1];
              return Un(i, Ore) ? n : a(ju[3], i, n) ? (ue(t4, [0, e[1], [19, i]]), n) : a(ju[4], i, n);
            }
            function ML(t4, n) {
              var e = n[2];
              switch (e[0]) {
                case 0:
                  var i = e[1][1];
                  return be(function(c, s) {
                    var p = s[0] === 0 ? s[1][2][2] : s[1][2][1];
                    return ML(c, p);
                  }, t4, i);
                case 1:
                  var x = e[1][1];
                  return be(function(c, s) {
                    return s[0] === 2 ? c : ML(c, s[1][2][1]);
                  }, t4, x);
                case 2:
                  return [0, e[1][1], t4];
                default:
                  return ke(Tre);
              }
            }
            var ve = lu(Are, Ire), mn = bne(ve), zn = function(t4) {
              var n = [0, v$r, ju[1], 0, 0];
              function e(a0) {
                var w0 = N0(a0);
                if (typeof w0 == "number") {
                  var _0 = 0;
                  if (8 <= w0 ? 10 <= w0 || (_0 = 1) : w0 === 1 && (_0 = 1), _0)
                    return 1;
                }
                return 0;
              }
              function i(a0) {
                var w0 = z7(a0), _0 = N0(a0), E0 = 0;
                if (typeof _0 == "number") {
                  var X0 = 0;
                  if (_0 === 82 ? V0(a0, 82) : _0 === 86 ? (Ge(a0, [4, w0[2][1]]), V0(a0, 86)) : X0 = 1, !X0) {
                    var b = Le(a0), G0 = pr(a0), X = N0(a0), s0 = 0;
                    if (typeof X == "number")
                      switch (X) {
                        case 30:
                        case 31:
                          ie(a0);
                          var dr = we(a0), Ar = e(a0) ? [1, b, [0, X === 31 ? 1 : 0, lr([0, G0], [0, dr], 0)]] : [0, b], ar = Ar;
                          break;
                        default:
                          s0 = 1;
                      }
                    else
                      switch (X[0]) {
                        case 0:
                          var W0 = X[2], Lr = ir(ve[24], a0, X[1], W0), Tr = we(a0), Hr = e(a0) ? [2, b, [0, Lr, W0, lr([0, G0], [0, Tr], 0)]] : [0, b], ar = Hr;
                          break;
                        case 2:
                          var Or = X[1], xr = Or[1];
                          Or[4] && gi(a0, 45), ie(a0);
                          var Rr = we(a0);
                          if (e(a0))
                            var Wr = lr([0, G0], [0, Rr], 0), Jr = [3, xr, [0, Or[2], Or[3], Wr]];
                          else
                            var Jr = [0, xr];
                          var ar = Jr;
                          break;
                        default:
                          s0 = 1;
                      }
                    if (s0) {
                      ie(a0);
                      var ar = [0, b];
                    }
                    var or = ar;
                    E0 = 1;
                  }
                }
                if (!E0)
                  var or = 0;
                return [0, w0, or];
              }
              var x = 0;
              function c(a0) {
                var w0 = pr(a0);
                V0(a0, 48);
                var _0 = a(ve[13], 0, a0), E0 = _0[2][1], X0 = _0[1], b = cr(0, function(G0) {
                  var X = fu(G0, 63);
                  if (X) {
                    zu(G0, 1);
                    var s0 = N0(G0), dr = 0;
                    if (typeof s0 == "number")
                      switch (s0) {
                        case 117:
                          var Ar = x$r;
                          break;
                        case 119:
                          var Ar = a$r;
                          break;
                        case 121:
                          var Ar = o$r;
                          break;
                        default:
                          dr = 1;
                      }
                    else
                      switch (s0[0]) {
                        case 4:
                          Ge(G0, [3, E0, [0, s0[2]]]);
                          var Ar = 0;
                          break;
                        case 9:
                          if (s0[1])
                            var Ar = c$r;
                          else
                            dr = 1;
                          break;
                        default:
                          dr = 1;
                      }
                    if (dr) {
                      Ge(G0, [3, E0, 0]);
                      var Ar = 0;
                    }
                    ie(G0), k7(G0);
                    var ar = Ar;
                  } else
                    var ar = X;
                  var W0 = ar !== 0 ? 1 : 0, Lr = W0 && pr(G0);
                  V0(G0, 0);
                  for (var Tr = n; ; ) {
                    var Hr = N0(G0);
                    if (typeof Hr == "number") {
                      var Or = Hr - 2 | 0;
                      if (Yt < Or >>> 0) {
                        if (!(T7 < (Or + 1 | 0) >>> 0)) {
                          var xr = Tr[3], Rr = Tr[4], Wr = de(Tr[1][4]), Jr = de(Tr[1][3]), or = de(Tr[1][2]), _r = de(Tr[1][1]), Ir = xn(Rr, pr(G0));
                          V0(G0, 1);
                          var fe = N0(G0), v0 = 0;
                          if (typeof fe == "number") {
                            var P = 0;
                            if (fe !== 1 && Ln !== fe && (v0 = 1, P = 1), !P)
                              var Q = we(G0);
                          } else
                            v0 = 1;
                          if (v0)
                            var L = f7(G0), Q = L && Us(G0);
                          var i0 = mu([0, Lr], [0, Q], Ir, 0);
                          if (ar)
                            switch (ar[1]) {
                              case 0:
                                return [0, [0, _r, 1, xr, i0]];
                              case 1:
                                return [1, [0, or, 1, xr, i0]];
                              case 2:
                                var l0 = 1;
                                break;
                              default:
                                return [3, [0, Wr, xr, i0]];
                            }
                          else {
                            var S0 = Rc(_r), T0 = Rc(or), er = Rc(Jr), j0 = Rc(Wr), B = 0;
                            if (S0 === 0 && T0 === 0) {
                              var Z = 0;
                              if (er === 0 && j0 === 0 && (B = 1, Z = 1), !Z) {
                                var l0 = 0;
                                B = 2;
                              }
                            }
                            var p0 = 0;
                            switch (B) {
                              case 0:
                                if (T0 === 0 && er === 0 && j0 <= S0)
                                  return Cu(function(K0) {
                                    return ue(G0, [0, K0[1], [0, E0, K0[2][1][2][1]]]);
                                  }, Wr), [0, [0, _r, 0, xr, i0]];
                                if (S0 === 0 && er === 0 && j0 <= T0)
                                  return Cu(function(K0) {
                                    return ue(G0, [0, K0[1], [8, E0, K0[2][1][2][1]]]);
                                  }, Wr), [1, [0, or, 0, xr, i0]];
                                ue(G0, [0, X0, [2, E0]]);
                                break;
                              case 1:
                                break;
                              default:
                                p0 = 1;
                            }
                            if (!p0)
                              return [2, [0, s$r, 0, xr, i0]];
                          }
                          var b0 = Rc(Jr), O0 = Rc(Wr);
                          if (b0 !== 0) {
                            var q0 = 0;
                            if (O0 !== 0 && (b0 < O0 ? (Cu(function(K0) {
                              return ue(G0, [0, K0[1], [9, E0]]);
                            }, Jr), q0 = 1) : Cu(function(K0) {
                              return ue(G0, [0, K0[1], [9, E0]]);
                            }, Wr)), !q0)
                              return [2, [0, [1, Jr], l0, xr, i0]];
                          }
                          return [2, [0, [0, Wr], l0, xr, i0]];
                        }
                      } else if (Or === 10) {
                        var nr = Le(G0), yr = pr(G0);
                        ie(G0);
                        var vr = N0(G0), $0 = 0;
                        if (typeof vr == "number") {
                          var Sr = vr - 2 | 0, Mr = 0;
                          if (Yt < Sr >>> 0)
                            T7 < (Sr + 1 | 0) >>> 0 && (Mr = 1);
                          else if (Sr === 7) {
                            V0(G0, 9);
                            var Br = N0(G0), qr = 0;
                            if (typeof Br == "number") {
                              var jr = 0;
                              if (Br !== 1 && Ln !== Br && (jr = 1), !jr) {
                                var $r = 1;
                                qr = 1;
                              }
                            }
                            if (!qr)
                              var $r = 0;
                            ue(G0, [0, nr, [7, $r]]);
                          } else
                            Mr = 1;
                          Mr || ($0 = 1);
                        }
                        $0 || ue(G0, [0, nr, i$r]);
                        var Tr = [0, Tr[1], Tr[2], 1, yr];
                        continue;
                      }
                    }
                    var ne = Tr[2], Qr = Tr[1], pe = cr(x, i, G0), oe = pe[2], me = oe[1], ae = me[2][1];
                    if (Un(ae, f$r))
                      var ce = Tr;
                    else {
                      var ge = me[1], H0 = oe[2], Fr = pe[1], _ = At(ae, 0), k = 97 <= _ ? 1 : 0, I = k && (_ <= Nn ? 1 : 0);
                      I && ue(G0, [0, ge, [6, E0, ae]]), a(ju[3], ae, ne) && ue(G0, [0, ge, [1, E0, ae]]);
                      var U = Tr[4], Y = Tr[3], y0 = a(ju[4], ae, ne), D0 = [0, Tr[1], y0, Y, U], A0 = function(Ur) {
                        return function(d0, Kr) {
                          return ar && ar[1] !== d0 ? ue(G0, [0, Kr, [5, E0, ar, Ur]]) : 0;
                        };
                      }(ae);
                      if (typeof H0 == "number") {
                        var D = 0;
                        if (ar) {
                          var u0 = ar[1], Y0 = 0;
                          if (u0 === 1 ? ue(G0, [0, Fr, [8, E0, ae]]) : u0 ? (D = 1, Y0 = 1) : ue(G0, [0, Fr, [0, E0, ae]]), !Y0)
                            var J0 = D0;
                        } else
                          D = 1;
                        if (D)
                          var J0 = [0, [0, Qr[1], Qr[2], Qr[3], [0, [0, Fr, [0, me]], Qr[4]]], y0, Y, U];
                      } else
                        switch (H0[0]) {
                          case 0:
                            ue(G0, [0, H0[1], [5, E0, ar, ae]]);
                            var J0 = D0;
                            break;
                          case 1:
                            var fr = H0[1];
                            A0(0, fr);
                            var J0 = [0, [0, [0, [0, Fr, [0, me, [0, fr, H0[2]]]], Qr[1]], Qr[2], Qr[3], Qr[4]], y0, Y, U];
                            break;
                          case 2:
                            var Q0 = H0[1];
                            A0(1, Q0);
                            var J0 = [0, [0, Qr[1], [0, [0, Fr, [0, me, [0, Q0, H0[2]]]], Qr[2]], Qr[3], Qr[4]], y0, Y, U];
                            break;
                          default:
                            var F0 = H0[1];
                            A0(2, F0);
                            var J0 = [0, [0, Qr[1], Qr[2], [0, [0, Fr, [0, me, [0, F0, H0[2]]]], Qr[3]], Qr[4]], y0, Y, U];
                        }
                      var ce = J0;
                    }
                    var gr = N0(G0), mr = 0;
                    if (typeof gr == "number") {
                      var Cr = gr - 2 | 0, sr = 0;
                      Yt < Cr >>> 0 ? T7 < (Cr + 1 | 0) >>> 0 && (sr = 1) : Cr === 6 ? (Ge(G0, 1), V0(G0, 8)) : sr = 1, sr || (mr = 1);
                    }
                    mr || V0(G0, 9);
                    var Tr = ce;
                  }
                }, a0);
                return [16, [0, _0, b, lr([0, w0], 0, 0)]];
              }
              var s = 0;
              function p(a0) {
                return cr(s, c, a0);
              }
              function y(a0, w0) {
                var _0 = w0[2][1], E0 = w0[1], X0 = a0[1];
                Bs(_0) && V7(X0, [0, E0, 41]);
                var b = I9(_0), G0 = b || f2(_0);
                return G0 && V7(X0, [0, E0, 55]), [0, X0, a0[2]];
              }
              function T(a0, w0) {
                var _0 = w0[2];
                switch (_0[0]) {
                  case 0:
                    return be(E, a0, _0[1][1]);
                  case 1:
                    return be(h, a0, _0[1][1]);
                  case 2:
                    var E0 = _0[1][1], X0 = E0[2][1], b = a0[2], G0 = a0[1];
                    a(ju[3], X0, b) && ue(G0, [0, E0[1], 42]);
                    var X = y([0, G0, b], E0), s0 = a(ju[4], X0, X[2]);
                    return [0, X[1], s0];
                  default:
                    return ue(a0[1], [0, w0[1], 31]), a0;
                }
              }
              function E(a0, w0) {
                if (w0[0] === 0) {
                  var _0 = w0[1][2], E0 = _0[1], X0 = E0[0] === 1 ? y(a0, E0[1]) : a0;
                  return T(X0, _0[2]);
                }
                return T(a0, w0[1][2][1]);
              }
              function h(a0, w0) {
                return w0[0] === 2 ? a0 : T(a0, w0[1][2][1]);
              }
              function w(a0, w0, _0, E0) {
                var X0 = a0[5], b = U1(E0), G0 = E0[2], X = G0[3], s0 = ys(X0 ? 0 : w0, a0), dr = w0 || X0 || 1 - b;
                if (dr) {
                  if (_0) {
                    var Ar = _0[1], ar = Ar[2][1], W0 = Ar[1];
                    Bs(ar) && V7(s0, [0, W0, 44]);
                    var Lr = I9(ar), Tr = Lr || f2(ar);
                    Tr && V7(s0, [0, W0, 55]);
                  }
                  var Hr = G0[2], Or = [0, s0, ju[1]], xr = be(function(or, _r) {
                    return T(or, _r[2][1]);
                  }, Or, Hr), Rr = X && (T(xr, X[1][2][1]), 0), Wr = Rr;
                } else
                  var Wr = dr;
                return Wr;
              }
              var G = function a0(w0, _0) {
                return a0.fun(w0, _0);
              };
              function A(a0) {
                N0(a0) === 21 && Ge(a0, s7);
                var w0 = a(ve[18], a0, 41), _0 = N0(a0) === 82 ? 1 : 0, E0 = _0 && (V0(a0, 82), [0, u(ve[10], a0)]);
                return [0, w0, E0];
              }
              var S = 0;
              N(G, function(a0, w0) {
                var _0 = N0(a0);
                if (typeof _0 == "number") {
                  var E0 = _0 - 5 | 0, X0 = 0;
                  if (7 < E0 >>> 0 ? fs2 === E0 && (X0 = 1) : 5 < (E0 - 1 | 0) >>> 0 && (X0 = 1), X0) {
                    var b = _0 === 12 ? 1 : 0;
                    if (b)
                      var G0 = pr(a0), X = cr(0, function(ar) {
                        return V0(ar, 12), a(ve[18], ar, 41);
                      }, a0), s0 = lr([0, G0], 0, 0), dr = [0, [0, X[1], [0, X[2], s0]]];
                    else
                      var dr = b;
                    return N0(a0) !== 5 && Ge(a0, 64), [0, de(w0), dr];
                  }
                }
                var Ar = cr(S, A, a0);
                return N0(a0) !== 5 && V0(a0, 9), a(G, a0, [0, Ar, w0]);
              });
              function M(a0, w0) {
                function _0(X0) {
                  var b = dL(w0, ie0(a0, X0)), G0 = 1, X = b[10] === 1 ? b : [0, b[1], b[2], b[3], b[4], b[5], b[6], b[7], b[8], b[9], G0, b[11], b[12], b[13], b[14], b[15], b[16], b[17], b[18], b[19], b[20], b[21], b[22], b[23], b[24], b[25], b[26], b[27], b[28], b[29], b[30]], s0 = pr(X);
                  V0(X, 4);
                  var dr = iu(X), Ar = dr && (N0(X) === 21 ? 1 : 0);
                  if (Ar) {
                    var ar = pr(X), W0 = cr(0, function(or) {
                      return V0(or, 21), N0(or) === 86 ? [0, u(t4[9], or)] : (Ge(or, ji), 0);
                    }, X), Lr = W0[2];
                    if (Lr) {
                      N0(X) === 9 && ie(X);
                      var Tr = lr([0, ar], 0, 0), Hr = [0, [0, W0[1], [0, Lr[1], Tr]]];
                    } else
                      var Hr = Lr;
                    var Or = Hr;
                  } else
                    var Or = Ar;
                  var xr = a(G, X, 0), Rr = pr(X);
                  V0(X, 5);
                  var Wr = mu([0, s0], [0, we(X)], Rr, 0);
                  return [0, Or, xr[1], xr[2], Wr];
                }
                var E0 = 0;
                return function(X0) {
                  return cr(E0, _0, X0);
                };
              }
              function K(a0, w0, _0, E0, X0) {
                var b = se0(a0, w0, _0, X0), G0 = a(ve[16], E0, b);
                return [0, [0, G0[1]], G0[2]];
              }
              function V(a0, w0, _0) {
                var E0 = Le(a0), X0 = N0(a0), b = 0;
                if (typeof X0 == "number")
                  if (s7 === X0) {
                    var G0 = pr(a0);
                    ie(a0);
                    var s0 = [0, [0, E0, [0, 0, lr([0, G0], 0, 0)]]];
                  } else if (L7 === X0) {
                    var X = pr(a0);
                    ie(a0);
                    var s0 = [0, [0, E0, [0, 1, lr([0, X], 0, 0)]]];
                  } else
                    b = 1;
                else
                  b = 1;
                if (b)
                  var s0 = 0;
                if (s0) {
                  var dr = 0;
                  if (!w0 && !_0 && (dr = 1), !dr)
                    return ue(a0, [0, s0[1][1], 7]), 0;
                }
                return s0;
              }
              function f0(a0) {
                if (Vt === N0(a0)) {
                  var w0 = pr(a0);
                  return ie(a0), [0, 1, w0];
                }
                return U$r;
              }
              function m0(a0) {
                if (N0(a0) === 64 && !Jl(1, a0)) {
                  var w0 = pr(a0);
                  return ie(a0), [0, 1, w0];
                }
                return q$r;
              }
              function k0(a0) {
                var w0 = m0(a0), _0 = w0[1], E0 = w0[2], X0 = cr(0, function(W0) {
                  var Lr = pr(W0);
                  V0(W0, 15);
                  var Tr = f0(W0), Hr = Tr[1], Or = pl([0, E0, [0, Lr, [0, Tr[2], 0]]]), xr = W0[7], Rr = N0(W0), Wr = 0;
                  if (xr && typeof Rr == "number") {
                    if (Rr === 4) {
                      var Ir = 0, fe = 0;
                      Wr = 1;
                    } else if (Rr === 98) {
                      var Jr = ai(W0, u(t4[3], W0)), or = N0(W0) === 4 ? 0 : [0, ds(W0, a(ve[13], j$r, W0))], Ir = or, fe = Jr;
                      Wr = 1;
                    }
                  }
                  if (!Wr)
                    var _r = M1(W0) ? ds(W0, a(ve[13], G$r, W0)) : (de0(W0, M$r), [0, Le(W0), B$r]), Ir = [0, _r], fe = ai(W0, u(t4[3], W0));
                  var v0 = u(M(_0, Hr), W0), P = N0(W0) === 86 ? v0 : eb(W0, v0), L = u(t4[12], W0), Q = L[2], i0 = L[1];
                  if (Q)
                    var l0 = Se0(W0, Q), S0 = i0;
                  else
                    var l0 = Q, S0 = a2(W0, i0);
                  return [0, Hr, fe, Ir, P, S0, l0, Or];
                }, a0), b = X0[2], G0 = b[4], X = b[3], s0 = b[1], dr = K(a0, _0, s0, 0, U1(G0));
                w(a0, dr[2], X, G0);
                var Ar = X0[1], ar = lr([0, b[7]], 0, 0);
                return [23, [0, X, G0, dr[1], _0, s0, b[6], b[5], b[2], ar, Ar]];
              }
              var g0 = 0;
              function e0(a0) {
                return cr(g0, k0, a0);
              }
              function x0(a0, w0) {
                var _0 = pr(w0);
                V0(w0, a0);
                for (var E0 = 0, X0 = 0; ; ) {
                  var b = cr(0, function(ar) {
                    var W0 = a(ve[18], ar, 40);
                    if (fu(ar, 82))
                      var Lr = 0, Tr = [0, u(ve[10], ar)];
                    else if (W0[2][0] === 2)
                      var Lr = 0, Tr = 0;
                    else
                      var Lr = [0, [0, W0[1], 59]], Tr = 0;
                    return [0, [0, W0, Tr], Lr];
                  }, w0), G0 = b[2], X = G0[2], s0 = [0, [0, b[1], G0[1]], E0], dr = X ? [0, X[1], X0] : X0;
                  if (fu(w0, 9)) {
                    var E0 = s0, X0 = dr;
                    continue;
                  }
                  var Ar = de(dr);
                  return [0, de(s0), _0, Ar];
                }
              }
              var l = 24;
              function c0(a0) {
                return x0(l, a0);
              }
              function t0(a0) {
                var w0 = x0(27, T9(1, a0)), _0 = w0[1], E0 = w0[3], X0 = de(be(function(b, G0) {
                  return G0[2][2] ? b : [0, [0, G0[1], 58], b];
                }, E0, _0));
                return [0, _0, w0[2], X0];
              }
              return [0, m0, f0, V, M, K, w, function(a0) {
                return x0(28, T9(1, a0));
              }, t0, c0, e0, p];
            }(mn), j9 = pne(ve), ci = function(t4) {
              function n(P) {
                var L = P[2];
                switch (L[0]) {
                  case 17:
                    var Q = L[1], i0 = Q[1][2][1];
                    if (n0(i0, PQr)) {
                      if (!n0(i0, DQr)) {
                        var l0 = n0(Q[2][2][1], LQr);
                        if (!l0)
                          return l0;
                      }
                    } else {
                      var S0 = n0(Q[2][2][1], RQr);
                      if (!S0)
                        return S0;
                    }
                    break;
                  case 0:
                  case 10:
                  case 16:
                  case 19:
                    break;
                  default:
                    return 0;
                }
                return 1;
              }
              var e = t4[1], i = function P(L) {
                return P.fun(L);
              }, x = function P(L) {
                return P.fun(L);
              }, c = function P(L) {
                return P.fun(L);
              }, s = function P(L) {
                return P.fun(L);
              }, p = function P(L) {
                return P.fun(L);
              }, y = function P(L) {
                return P.fun(L);
              }, T = function P(L) {
                return P.fun(L);
              }, E = function P(L) {
                return P.fun(L);
              }, h = function P(L) {
                return P.fun(L);
              }, w = function P(L) {
                return P.fun(L);
              }, G = function P(L) {
                return P.fun(L);
              }, A = function P(L) {
                return P.fun(L);
              }, S = function P(L) {
                return P.fun(L);
              }, M = function P(L) {
                return P.fun(L);
              }, K = function P(L) {
                return P.fun(L);
              }, V = function P(L) {
                return P.fun(L);
              }, f0 = function P(L) {
                return P.fun(L);
              }, m0 = function P(L, Q, i0, l0, S0) {
                return P.fun(L, Q, i0, l0, S0);
              }, k0 = function P(L, Q, i0, l0) {
                return P.fun(L, Q, i0, l0);
              }, g0 = function P(L) {
                return P.fun(L);
              }, e0 = function P(L) {
                return P.fun(L);
              }, x0 = function P(L) {
                return P.fun(L);
              }, l = function P(L, Q, i0, l0, S0) {
                return P.fun(L, Q, i0, l0, S0);
              }, c0 = function P(L, Q, i0, l0) {
                return P.fun(L, Q, i0, l0);
              }, t0 = function P(L) {
                return P.fun(L);
              }, a0 = function P(L, Q, i0) {
                return P.fun(L, Q, i0);
              }, w0 = function P(L) {
                return P.fun(L);
              }, _0 = function P(L, Q, i0) {
                return P.fun(L, Q, i0);
              }, E0 = function P(L) {
                return P.fun(L);
              }, X0 = function P(L) {
                return P.fun(L);
              }, b = function P(L, Q) {
                return P.fun(L, Q);
              }, G0 = function P(L, Q, i0, l0) {
                return P.fun(L, Q, i0, l0);
              }, X = function P(L) {
                return P.fun(L);
              }, s0 = function P(L, Q, i0) {
                return P.fun(L, Q, i0);
              }, dr = function P(L) {
                return P.fun(L);
              }, Ar = function P(L) {
                return P.fun(L);
              }, ar = function P(L) {
                return P.fun(L);
              }, W0 = function P(L, Q, i0) {
                return P.fun(L, Q, i0);
              }, Lr = t4[2];
              function Tr(P) {
                var L = Le(P), Q = u(y, P), i0 = u(p, P);
                if (i0) {
                  var l0 = i0[1];
                  return [0, cr([0, L], function(S0) {
                    var T0 = ir(Lr, 0, S0, Q);
                    return [2, [0, l0, T0, u(x, S0), 0]];
                  }, P)];
                }
                return Q;
              }
              function Hr(P, L) {
                if (typeof L == "number") {
                  var Q = L !== 55 ? 1 : 0;
                  if (!Q)
                    return Q;
                }
                throw Hs;
              }
              function Or(P) {
                var L = O9(Hr, P), Q = Tr(L), i0 = N0(L);
                if (typeof i0 == "number") {
                  if (i0 === 11)
                    throw Hs;
                  if (i0 === 86) {
                    var l0 = oe0(L), S0 = 0;
                    if (l0) {
                      var T0 = l0[1];
                      if (typeof T0 == "number" && T0 === 5) {
                        var er = 1;
                        S0 = 1;
                      }
                    }
                    if (!S0)
                      var er = 0;
                    if (er)
                      throw Hs;
                  }
                }
                if (M1(L)) {
                  if (Q[0] === 0) {
                    var j0 = Q[1][2];
                    if (j0[0] === 10 && !n0(j0[1][2][1], CQr) && !f7(L))
                      throw Hs;
                  }
                  return Q;
                }
                return Q;
              }
              N(i, function(P) {
                var L = N0(P), Q = 0, i0 = M1(P);
                if (typeof L == "number") {
                  var l0 = 0;
                  if (22 <= L)
                    if (L === 58) {
                      if (P[17])
                        return [0, u(c, P)];
                      l0 = 1;
                    } else
                      L !== 98 && (l0 = 1);
                  else
                    L !== 4 && !(21 <= L) && (l0 = 1);
                  l0 || (Q = 1);
                }
                if (!Q && !i0)
                  return Tr(P);
                var S0 = 0;
                if (L === 64 && iu(P) && Vn(1, P) === 98) {
                  var T0 = Or, er = ar;
                  S0 = 1;
                }
                if (!S0)
                  var T0 = ar, er = Or;
                var j0 = FL(P, er);
                if (j0)
                  return j0[1];
                var B = FL(P, T0);
                return B ? B[1] : Tr(P);
              }), N(x, function(P) {
                return a(e, P, u(i, P));
              }), N(c, function(P) {
                return cr(0, function(L) {
                  L[10] && Ge(L, 91);
                  var Q = pr(L), i0 = Le(L);
                  V0(L, 58);
                  var l0 = Le(L);
                  if (x2(L))
                    var S0 = 0, T0 = 0;
                  else {
                    var er = fu(L, Vt), j0 = N0(L), B = 0;
                    if (typeof j0 == "number") {
                      var Z = 0;
                      if (j0 !== 86)
                        if (10 <= j0)
                          Z = 1;
                        else
                          switch (j0) {
                            case 0:
                            case 2:
                            case 3:
                            case 4:
                            case 6:
                              Z = 1;
                              break;
                          }
                      if (!Z) {
                        var p0 = 0;
                        B = 1;
                      }
                    }
                    if (!B)
                      var p0 = 1;
                    var b0 = er || p0, O0 = b0 && [0, u(x, L)], S0 = er, T0 = O0;
                  }
                  var q0 = T0 ? 0 : we(L), nr = ht(i0, l0);
                  return [30, [0, T0, lr([0, Q], [0, q0], 0), S0, nr]];
                }, P);
              }), N(s, function(P) {
                var L = P[2];
                switch (L[0]) {
                  case 17:
                    var Q = L[1], i0 = Q[1][2][1];
                    if (n0(i0, OQr)) {
                      if (!n0(i0, IQr)) {
                        var l0 = n0(Q[2][2][1], AQr);
                        if (!l0)
                          return l0;
                      }
                    } else {
                      var S0 = n0(Q[2][2][1], NQr);
                      if (!S0)
                        return S0;
                    }
                    break;
                  case 10:
                  case 16:
                    break;
                  default:
                    return 0;
                }
                return 1;
              }), N(p, function(P) {
                var L = N0(P), Q = 0;
                if (typeof L == "number") {
                  var i0 = L - 67 | 0;
                  if (!(15 < i0 >>> 0)) {
                    switch (i0) {
                      case 0:
                        var l0 = vQr;
                        break;
                      case 1:
                        var l0 = lQr;
                        break;
                      case 2:
                        var l0 = bQr;
                        break;
                      case 3:
                        var l0 = pQr;
                        break;
                      case 4:
                        var l0 = mQr;
                        break;
                      case 5:
                        var l0 = _Qr;
                        break;
                      case 6:
                        var l0 = yQr;
                        break;
                      case 7:
                        var l0 = dQr;
                        break;
                      case 8:
                        var l0 = hQr;
                        break;
                      case 9:
                        var l0 = kQr;
                        break;
                      case 10:
                        var l0 = wQr;
                        break;
                      case 11:
                        var l0 = EQr;
                        break;
                      case 12:
                        var l0 = SQr;
                        break;
                      case 13:
                        var l0 = gQr;
                        break;
                      case 14:
                        var l0 = FQr;
                        break;
                      default:
                        var l0 = TQr;
                    }
                    var S0 = l0;
                    Q = 1;
                  }
                }
                if (!Q)
                  var S0 = 0;
                return S0 !== 0 && ie(P), S0;
              }), N(y, function(P) {
                var L = Le(P), Q = u(E, P);
                if (N0(P) === 85) {
                  ie(P);
                  var i0 = u(x, Kl(0, P));
                  V0(P, 86);
                  var l0 = cr(0, x, P), S0 = ht(L, l0[1]), T0 = l0[2];
                  return [0, [0, S0, [7, [0, a(e, P, Q), i0, T0, 0]]]];
                }
                return Q;
              }), N(T, function(P) {
                return a(e, P, u(y, P));
              });
              function xr(P, L, Q, i0, l0) {
                var S0 = a(e, P, L);
                return [0, [0, l0, [15, [0, i0, S0, a(e, P, Q), 0]]]];
              }
              function Rr(P, L, Q, i0) {
                for (var l0 = P, S0 = Q, T0 = i0; ; ) {
                  var er = N0(L);
                  if (typeof er == "number" && er === 84) {
                    1 - l0 && Ge(L, sQr), V0(L, 84);
                    var j0 = cr(0, h, L), B = j0[2], Z = j0[1], p0 = N0(L), b0 = 0;
                    if (typeof p0 == "number" && !(1 < (p0 - 87 | 0) >>> 0)) {
                      Ge(L, [23, sL(p0)]);
                      var O0 = Jr(L, B, Z), q0 = Wr(L, O0[2], O0[1]), nr = q0[2], yr = q0[1];
                      b0 = 1;
                    }
                    if (!b0)
                      var nr = B, yr = Z;
                    var vr = ht(T0, yr), l0 = 1, S0 = xr(L, S0, nr, 2, vr), T0 = vr;
                    continue;
                  }
                  return [0, T0, S0];
                }
              }
              function Wr(P, L, Q) {
                for (var i0 = L, l0 = Q; ; ) {
                  var S0 = N0(P);
                  if (typeof S0 == "number" && S0 === 87) {
                    ie(P);
                    var T0 = cr(0, h, P), er = Jr(P, T0[2], T0[1]), j0 = ht(l0, er[1]), B = Rr(0, P, xr(P, i0, er[2], 0, j0), j0), i0 = B[2], l0 = B[1];
                    continue;
                  }
                  return [0, l0, i0];
                }
              }
              function Jr(P, L, Q) {
                for (var i0 = L, l0 = Q; ; ) {
                  var S0 = N0(P);
                  if (typeof S0 == "number" && S0 === 88) {
                    ie(P);
                    var T0 = cr(0, h, P), er = ht(l0, T0[1]), j0 = Rr(0, P, xr(P, i0, T0[2], 1, er), er), i0 = j0[2], l0 = j0[1];
                    continue;
                  }
                  return [0, l0, i0];
                }
              }
              N(E, function(P) {
                var L = cr(0, h, P), Q = L[2], i0 = L[1], l0 = N0(P), S0 = 0;
                if (typeof l0 == "number" && l0 === 84) {
                  var er = Rr(1, P, Q, i0);
                  S0 = 1;
                }
                if (!S0)
                  var T0 = Jr(P, Q, i0), er = Wr(P, T0[2], T0[1]);
                return er[2];
              });
              function or(P, L, Q, i0) {
                return [0, i0, [3, [0, Q, P, L, 0]]];
              }
              N(h, function(P) {
                var L = 0;
                r:
                  for (; ; ) {
                    var Q = cr(0, function(k) {
                      var I = u(w, k) !== 0 ? 1 : 0;
                      return [0, I, u(G, Kl(0, k))];
                    }, P), i0 = Q[2], l0 = i0[2], S0 = Q[1];
                    if (N0(P) === 98) {
                      var T0 = 0;
                      l0[0] === 0 && l0[1][2][0] === 12 ? Ge(P, 63) : T0 = 1;
                    }
                    var er = N0(P), j0 = 0;
                    if (typeof er == "number") {
                      var B = er - 17 | 0, Z = 0;
                      if (1 < B >>> 0)
                        if (72 <= B)
                          switch (B - 72 | 0) {
                            case 0:
                              var p0 = HZr;
                              break;
                            case 1:
                              var p0 = XZr;
                              break;
                            case 2:
                              var p0 = YZr;
                              break;
                            case 3:
                              var p0 = VZr;
                              break;
                            case 4:
                              var p0 = zZr;
                              break;
                            case 5:
                              var p0 = KZr;
                              break;
                            case 6:
                              var p0 = WZr;
                              break;
                            case 7:
                              var p0 = JZr;
                              break;
                            case 8:
                              var p0 = $Zr;
                              break;
                            case 9:
                              var p0 = ZZr;
                              break;
                            case 10:
                              var p0 = QZr;
                              break;
                            case 11:
                              var p0 = rQr;
                              break;
                            case 12:
                              var p0 = eQr;
                              break;
                            case 13:
                              var p0 = nQr;
                              break;
                            case 14:
                              var p0 = tQr;
                              break;
                            case 15:
                              var p0 = uQr;
                              break;
                            case 16:
                              var p0 = iQr;
                              break;
                            case 17:
                              var p0 = fQr;
                              break;
                            case 18:
                              var p0 = xQr;
                              break;
                            case 19:
                              var p0 = aQr;
                              break;
                            default:
                              Z = 1;
                          }
                        else
                          Z = 1;
                      else
                        var p0 = B ? oQr : P[12] ? 0 : cQr;
                      if (!Z) {
                        var b0 = p0;
                        j0 = 1;
                      }
                    }
                    if (!j0)
                      var b0 = 0;
                    if (b0 !== 0 && ie(P), !L && !b0)
                      return l0;
                    if (b0) {
                      var O0 = b0[1], q0 = O0[1], nr = i0[1], yr = nr && (q0 === 14 ? 1 : 0);
                      yr && ue(P, [0, S0, 27]);
                      for (var vr = a(e, P, l0), $0 = vr, Sr = [0, q0, O0[2]], Mr = S0, Br = L; ; ) {
                        var qr = Sr[2], jr = Sr[1];
                        if (Br) {
                          var $r = Br[1], ne = $r[2], Qr = ne[2], pe = Qr[0] === 0 ? Qr[1] : Qr[1] - 1 | 0;
                          if (qr[1] <= pe) {
                            var oe = ht($r[3], Mr), me = or($r[1], $0, ne[1], oe), $0 = me, Sr = [0, jr, qr], Mr = oe, Br = Br[2];
                            continue;
                          }
                        }
                        var L = [0, [0, $0, [0, jr, qr], Mr], Br];
                        continue r;
                      }
                    }
                    for (var ae = a(e, P, l0), ce = S0, ge = L; ; ) {
                      if (ge) {
                        var H0 = ge[1], Fr = ht(H0[3], ce), _ = ge[2], ae = or(H0[1], ae, H0[2][1], Fr), ce = Fr, ge = _;
                        continue;
                      }
                      return [0, ae];
                    }
                  }
              }), N(w, function(P) {
                var L = N0(P);
                if (typeof L == "number") {
                  if (48 <= L) {
                    if (s7 <= L) {
                      if (!(vf <= L))
                        switch (L - 103 | 0) {
                          case 0:
                            return LZr;
                          case 1:
                            return RZr;
                          case 6:
                            return jZr;
                          case 7:
                            return GZr;
                        }
                    } else if (L === 65 && P[18])
                      return MZr;
                  } else if (45 <= L)
                    switch (L + mv | 0) {
                      case 0:
                        return BZr;
                      case 1:
                        return qZr;
                      default:
                        return UZr;
                    }
                }
                return 0;
              }), N(G, function(P) {
                var L = Le(P), Q = pr(P), i0 = u(w, P);
                if (i0) {
                  var l0 = i0[1];
                  ie(P);
                  var S0 = cr(0, A, P), T0 = S0[2], er = ht(L, S0[1]), j0 = 0;
                  if (l0 === 6) {
                    var B = T0[2], Z = 0;
                    switch (B[0]) {
                      case 10:
                        V7(P, [0, er, 47]);
                        break;
                      case 16:
                        B[1][2][0] === 1 && ue(P, [0, er, 88]);
                        break;
                      default:
                        Z = 1;
                    }
                    Z || (j0 = 1);
                  }
                  return [0, [0, er, [28, [0, l0, T0, lr([0, Q], 0, 0)]]]];
                }
                var p0 = N0(P), b0 = 0;
                if (typeof p0 == "number")
                  if (vf === p0)
                    var O0 = DZr;
                  else if (T7 === p0)
                    var O0 = PZr;
                  else
                    b0 = 1;
                else
                  b0 = 1;
                if (b0)
                  var O0 = 0;
                if (O0) {
                  ie(P);
                  var q0 = cr(0, A, P), nr = q0[2];
                  1 - u(s, nr) && ue(P, [0, nr[1], 26]);
                  var yr = nr[2], vr = 0;
                  yr[0] === 10 && Bs(yr[1][2][1]) && (gi(P, 54), vr = 1);
                  var $0 = ht(L, q0[1]), Sr = lr([0, Q], 0, 0);
                  return [0, [0, $0, [29, [0, O0[1], nr, 1, Sr]]]];
                }
                return u(S, P);
              }), N(A, function(P) {
                return a(e, P, u(G, P));
              }), N(S, function(P) {
                var L = u(M, P);
                if (f7(P))
                  return L;
                var Q = N0(P), i0 = 0;
                if (typeof Q == "number")
                  if (vf === Q)
                    var l0 = CZr;
                  else if (T7 === Q)
                    var l0 = NZr;
                  else
                    i0 = 1;
                else
                  i0 = 1;
                if (i0)
                  var l0 = 0;
                if (l0) {
                  var S0 = a(e, P, L);
                  1 - u(s, S0) && ue(P, [0, S0[1], 26]);
                  var T0 = S0[2], er = 0;
                  T0[0] === 10 && Bs(T0[1][2][1]) && (gi(P, 53), er = 1);
                  var j0 = Le(P);
                  ie(P);
                  var B = we(P), Z = ht(S0[1], j0), p0 = lr(0, [0, B], 0);
                  return [0, [0, Z, [29, [0, l0[1], S0, 0, p0]]]];
                }
                return L;
              }), N(M, function(P) {
                var L = Le(P), Q = 1 - P[16], i0 = 0, l0 = P[16] === 0 ? P : [0, P[1], P[2], P[3], P[4], P[5], P[6], P[7], P[8], P[9], P[10], P[11], P[12], P[13], P[14], P[15], i0, P[17], P[18], P[19], P[20], P[21], P[22], P[23], P[24], P[25], P[26], P[27], P[28], P[29], P[30]], S0 = N0(l0), T0 = 0;
                if (typeof S0 == "number") {
                  var er = S0 - 44 | 0;
                  if (!(7 < er >>> 0)) {
                    var j0 = 0;
                    switch (er) {
                      case 0:
                        if (Q)
                          var B = [0, u(g0, l0)];
                        else
                          j0 = 1;
                        break;
                      case 6:
                        var B = [0, u(f0, l0)];
                        break;
                      case 7:
                        var B = [0, u(V, l0)];
                        break;
                      default:
                        j0 = 1;
                    }
                    if (!j0) {
                      var Z = B;
                      T0 = 1;
                    }
                  }
                }
                if (!T0)
                  var Z = qs(l0) ? [0, u(t0, l0)] : u(E0, l0);
                return p7(m0, 0, 0, l0, L, Z);
              }), N(K, function(P) {
                return a(e, P, u(M, P));
              }), N(V, function(P) {
                switch (P[21]) {
                  case 0:
                    var L = 0, Q = 0;
                    break;
                  case 1:
                    var L = 0, Q = 1;
                    break;
                  default:
                    var L = 1, Q = 1;
                }
                var i0 = Le(P), l0 = pr(P);
                V0(P, 51);
                var S0 = [0, i0, [23, [0, lr([0, l0], [0, we(P)], 0)]]], T0 = N0(P);
                if (typeof T0 == "number" && !(11 <= T0))
                  switch (T0) {
                    case 4:
                      var er = L ? S0 : (ue(P, [0, i0, 5]), [0, i0, [10, Gc(0, [0, i0, FZr])]]);
                      return R(k0, TZr, P, i0, er);
                    case 6:
                    case 10:
                      var j0 = Q ? S0 : (ue(P, [0, i0, 4]), [0, i0, [10, Gc(0, [0, i0, IZr])]]);
                      return R(k0, AZr, P, i0, j0);
                  }
                return Q ? Ft(OZr, P) : ue(P, [0, i0, 4]), S0;
              }), N(f0, function(P) {
                return cr(0, function(L) {
                  var Q = pr(L), i0 = Le(L);
                  if (V0(L, 50), fu(L, 10)) {
                    var l0 = Gc(0, [0, i0, EZr]), S0 = Le(L);
                    Zl(L, SZr);
                    var T0 = Gc(0, [0, S0, gZr]);
                    return [17, [0, l0, T0, lr([0, Q], [0, we(L)], 0)]];
                  }
                  var er = pr(L);
                  V0(L, 4);
                  var j0 = ir(s0, [0, er], 0, u(x, Kl(0, L)));
                  return V0(L, 5), [11, [0, j0, lr([0, Q], [0, we(L)], 0)]];
                }, P);
              }), N(m0, function(P, L, Q, i0, l0) {
                var S0 = P ? P[1] : 1, T0 = L && L[1], er = p7(l, [0, S0], [0, T0], Q, i0, l0), j0 = oe0(Q), B = 0;
                if (j0) {
                  var Z = j0[1];
                  if (typeof Z == "number" && Z === 83) {
                    var p0 = 1;
                    B = 1;
                  }
                }
                if (!B)
                  var p0 = 0;
                function b0(vr) {
                  var $0 = $t(vr);
                  function Sr(Br, qr) {
                    return a(Qe(Br, Li, 78), Br, qr);
                  }
                  var Mr = a(e, vr, er);
                  return a($0[2], Mr, Sr);
                }
                function O0(vr, $0, Sr) {
                  var Mr = u(x0, $0), Br = Mr[1], qr = ht(i0, Br), jr = [0, Sr, vr, [0, Br, Mr[2]], 0], $r = 0;
                  if (!p0 && !T0) {
                    var ne = [4, jr];
                    $r = 1;
                  }
                  if (!$r)
                    var ne = [20, [0, jr, qr, p0]];
                  var Qr = T0 || p0;
                  return p7(m0, [0, S0], [0, Qr], $0, i0, [0, [0, qr, ne]]);
                }
                if (Q[13])
                  return er;
                var q0 = N0(Q);
                if (typeof q0 == "number") {
                  var nr = q0 - 98 | 0;
                  if (2 < nr >>> 0) {
                    if (nr === -94)
                      return O0(0, Q, b0(Q));
                  } else if (nr !== 1 && iu(Q)) {
                    var yr = O9(function(vr, $0) {
                      throw Hs;
                    }, Q);
                    return we0(yr, er, function(vr) {
                      var $0 = b0(vr);
                      return O0(u(e0, vr), vr, $0);
                    });
                  }
                }
                return er;
              }), N(k0, function(P, L, Q, i0) {
                var l0 = P ? P[1] : 1;
                return a(e, L, p7(m0, [0, l0], 0, L, Q, [0, i0]));
              }), N(g0, function(P) {
                return cr(0, function(L) {
                  var Q = Le(L), i0 = pr(L);
                  if (V0(L, 44), L[11] && N0(L) === 10) {
                    var l0 = we(L);
                    ie(L);
                    var S0 = Gc(lr([0, i0], [0, l0], 0), [0, Q, dZr]), T0 = N0(L);
                    return typeof T0 != "number" && T0[0] === 4 && !n0(T0[3], hZr) ? [17, [0, S0, a(ve[13], 0, L), 0]] : (Ft(kZr, L), ie(L), [10, S0]);
                  }
                  var er = Le(L), j0 = N0(L), B = 0;
                  if (typeof j0 == "number")
                    if (j0 === 44)
                      var Z = u(g0, L);
                    else if (j0 === 51)
                      var Z = u(V, hL(1, L));
                    else
                      B = 1;
                  else
                    B = 1;
                  if (B)
                    var Z = qs(L) ? u(t0, L) : u(X0, L);
                  var p0 = R(c0, wZr, hL(1, L), er, Z), b0 = N0(L), O0 = 0;
                  if (typeof b0 != "number" && b0[0] === 3) {
                    var q0 = R(G0, L, er, p0, b0[1]);
                    O0 = 1;
                  }
                  if (!O0)
                    var q0 = p0;
                  var nr = 0;
                  if (N0(L) !== 4) {
                    var yr = 0;
                    if (iu(L) && N0(L) === 98 && (yr = 1), !yr) {
                      var Sr = q0;
                      nr = 1;
                    }
                  }
                  if (!nr)
                    var vr = $t(L), $0 = function(ne, Qr) {
                      return a(Qe(ne, Li, 79), ne, Qr);
                    }, Sr = a(vr[2], q0, $0);
                  var Mr = iu(L), Br = Mr && we0(O9(function(ne, Qr) {
                    throw Hs;
                  }, L), 0, e0), qr = N0(L), jr = 0;
                  if (typeof qr == "number" && qr === 4) {
                    var $r = [0, u(x0, L)];
                    jr = 1;
                  }
                  if (!jr)
                    var $r = 0;
                  return [18, [0, Sr, Br, $r, lr([0, i0], 0, 0)]];
                }, P);
              });
              function _r(P) {
                var L = pr(P);
                V0(P, 98);
                for (var Q = 0; ; ) {
                  var i0 = N0(P);
                  if (typeof i0 == "number") {
                    var l0 = 0;
                    if ((i0 === 99 || Ln === i0) && (l0 = 1), l0) {
                      var S0 = de(Q), T0 = pr(P);
                      V0(P, 99);
                      var er = N0(P) === 4 ? $t(P)[1] : we(P);
                      return [0, S0, mu([0, L], [0, er], T0, 0)];
                    }
                  }
                  var j0 = N0(P), B = 0;
                  if (typeof j0 != "number" && j0[0] === 4 && !n0(j0[2], _Zr)) {
                    var Z = Le(P), p0 = pr(P);
                    Zl(P, yZr);
                    var b0 = [1, [0, Z, [0, lr([0, p0], [0, we(P)], 0)]]];
                    B = 1;
                  }
                  if (!B)
                    var b0 = [0, u(mn[1], P)];
                  var O0 = [0, b0, Q];
                  N0(P) !== 99 && V0(P, 9);
                  var Q = O0;
                }
              }
              N(e0, function(P) {
                zu(P, 1);
                var L = N0(P) === 98 ? 1 : 0, Q = L && [0, cr(0, _r, P)];
                return k7(P), Q;
              });
              function Ir(P) {
                var L = pr(P);
                V0(P, 12);
                var Q = u(x, P);
                return [0, Q, lr([0, L], 0, 0)];
              }
              N(x0, function(P) {
                return cr(0, function(L) {
                  var Q = pr(L);
                  V0(L, 4);
                  for (var i0 = 0; ; ) {
                    var l0 = N0(L);
                    if (typeof l0 == "number") {
                      var S0 = 0;
                      if ((l0 === 5 || Ln === l0) && (S0 = 1), S0) {
                        var T0 = de(i0), er = pr(L);
                        return V0(L, 5), [0, T0, mu([0, Q], [0, we(L)], er, 0)];
                      }
                    }
                    var j0 = N0(L), B = 0;
                    if (typeof j0 == "number" && j0 === 12) {
                      var Z = [1, cr(0, Ir, L)];
                      B = 1;
                    }
                    if (!B)
                      var Z = [0, u(x, L)];
                    var p0 = [0, Z, i0];
                    N0(L) !== 5 && V0(L, 9);
                    var i0 = p0;
                  }
                }, P);
              }), N(l, function(P, L, Q, i0, l0) {
                var S0 = P ? P[1] : 1, T0 = L && L[1], er = N0(Q), j0 = 0;
                if (typeof er == "number")
                  switch (er) {
                    case 6:
                      ie(Q);
                      var B = 0, Z = [0, T0], p0 = [0, S0];
                      j0 = 2;
                      break;
                    case 10:
                      ie(Q);
                      var b0 = 0, O0 = [0, T0], q0 = [0, S0];
                      j0 = 1;
                      break;
                    case 83:
                      1 - S0 && Ge(Q, 99), V0(Q, 83);
                      var nr = 0, yr = N0(Q);
                      if (typeof yr == "number")
                        switch (yr) {
                          case 4:
                            return l0;
                          case 6:
                            ie(Q);
                            var B = vZr, Z = lZr, p0 = [0, S0];
                            j0 = 2, nr = 1;
                            break;
                          case 98:
                            if (iu(Q))
                              return l0;
                            break;
                        }
                      else if (yr[0] === 3)
                        return Ge(Q, ti), l0;
                      if (!nr) {
                        var b0 = bZr, O0 = pZr, q0 = [0, S0];
                        j0 = 1;
                      }
                      break;
                  }
                else if (er[0] === 3) {
                  T0 && Ge(Q, ti);
                  var vr = er[1];
                  return p7(m0, mZr, 0, Q, i0, [0, R(G0, Q, i0, a(e, Q, l0), vr)]);
                }
                switch (j0) {
                  case 0:
                    return l0;
                  case 1:
                    var $0 = q0 ? S0 : 1, Sr = O0 && O0[1], Mr = b0 && b0[1], Br = N0(Q), qr = 0;
                    if (typeof Br == "number" && Br === 14) {
                      var jr = Ae0(Q), $r = jr[1], ne = Q[29][1], Qr = jr[2][1];
                      if (ne) {
                        var pe = ne[1];
                        Q[29][1] = [0, [0, pe[1], [0, [0, Qr, $r], pe[2]]], ne[2]];
                      } else
                        ue(Q, [0, $r, 89]);
                      var me = [1, jr], ae = $r;
                      qr = 1;
                    }
                    if (!qr)
                      var oe = z7(Q), me = [0, oe], ae = oe[1];
                    var ce = ht(i0, ae), ge = 0;
                    l0[0] === 0 && l0[1][2][0] === 23 && me[0] === 1 && (ue(Q, [0, ce, 90]), ge = 1);
                    var H0 = [0, a(e, Q, l0), me, 0], Fr = Sr ? [21, [0, H0, ce, Mr]] : [16, H0];
                    return p7(m0, [0, $0], [0, Sr], Q, i0, [0, [0, ce, Fr]]);
                  default:
                    var _ = p0 ? S0 : 1, k = Z && Z[1], I = B && B[1], U = hL(0, Q), Y = u(ve[7], U), y0 = Le(Q);
                    V0(Q, 7);
                    var D0 = we(Q), A0 = ht(i0, y0), D = lr(0, [0, D0], 0), u0 = [0, a(e, Q, l0), [2, Y], D], Y0 = k ? [21, [0, u0, A0, I]] : [16, u0];
                    return p7(m0, [0, _], [0, k], Q, i0, [0, [0, A0, Y0]]);
                }
              }), N(c0, function(P, L, Q, i0) {
                var l0 = P ? P[1] : 1;
                return a(e, L, p7(l, [0, l0], 0, L, Q, [0, i0]));
              }), N(t0, function(P) {
                return cr(0, function(L) {
                  var Q = u(zn[1], L), i0 = Q[1], l0 = Q[2], S0 = cr(0, function(q0) {
                    var nr = pr(q0);
                    V0(q0, 15);
                    var yr = u(zn[2], q0), vr = yr[1], $0 = pl([0, l0, [0, nr, [0, yr[2], 0]]]);
                    if (N0(q0) === 4)
                      var Sr = 0, Mr = 0;
                    else {
                      var Br = N0(q0), qr = 0;
                      if (typeof Br == "number") {
                        var jr = Br !== 98 ? 1 : 0;
                        if (!jr) {
                          var ne = jr;
                          qr = 1;
                        }
                      }
                      if (!qr)
                        var $r = dL(vr, ie0(i0, q0)), ne = [0, ds($r, a(ve[13], sZr, $r))];
                      var Sr = ai(q0, u(mn[3], q0)), Mr = ne;
                    }
                    var Qr = t22(0, q0), pe = ir(zn[4], i0, vr, Qr), oe = N0(Qr) === 86 ? pe : eb(Qr, pe), me = u(mn[12], Qr), ae = me[2], ce = me[1];
                    if (ae)
                      var ge = Se0(Qr, ae), H0 = ce;
                    else
                      var ge = ae, H0 = a2(Qr, ce);
                    return [0, Mr, oe, vr, ge, H0, Sr, $0];
                  }, L), T0 = S0[2], er = T0[3], j0 = T0[2], B = T0[1], Z = U1(j0), p0 = p7(zn[5], L, i0, er, 1, Z);
                  R(zn[6], L, p0[2], B, j0);
                  var b0 = S0[1], O0 = lr([0, T0[7]], 0, 0);
                  return [8, [0, B, j0, p0[1], i0, er, T0[4], T0[5], T0[6], O0, b0]];
                }, P);
              }), N(a0, function(P, L, Q) {
                switch (L) {
                  case 1:
                    gi(P, 45);
                    try {
                      var i0 = jv(Rv(Te(fZr, Q))), l0 = i0;
                    } catch (j0) {
                      if (j0 = gt(j0), j0[1] !== q7)
                        throw j0;
                      var l0 = ke(Te(xZr, Q));
                    }
                    break;
                  case 2:
                    gi(P, 46);
                    try {
                      var S0 = al(Q), l0 = S0;
                    } catch (j0) {
                      if (j0 = gt(j0), j0[1] !== q7)
                        throw j0;
                      var l0 = ke(Te(aZr, Q));
                    }
                    break;
                  case 4:
                    try {
                      var T0 = al(Q), l0 = T0;
                    } catch (j0) {
                      if (j0 = gt(j0), j0[1] !== q7)
                        throw j0;
                      var l0 = ke(Te(oZr, Q));
                    }
                    break;
                  default:
                    try {
                      var er = jv(Rv(Q)), l0 = er;
                    } catch (j0) {
                      if (j0 = gt(j0), j0[1] !== q7)
                        throw j0;
                      var l0 = ke(Te(cZr, Q));
                    }
                }
                return V0(P, [0, L, Q]), l0;
              }), N(w0, function(P) {
                var L = tn(P);
                return L !== 0 && Yt === At(P, L - 1 | 0) ? m7(P, 0, L - 1 | 0) : P;
              }), N(_0, function(P, L, Q) {
                if (2 <= L) {
                  var i0 = u(w0, Q);
                  try {
                    var l0 = al(i0), S0 = l0;
                  } catch (Z) {
                    if (Z = gt(Z), Z[1] !== q7)
                      throw Z;
                    var S0 = ke(Te(uZr, i0));
                  }
                  var T0 = S0;
                } else {
                  var er = u(w0, Q);
                  try {
                    var j0 = jv(Rv(er)), B = j0;
                  } catch (p0) {
                    if (p0 = gt(p0), p0[1] !== q7)
                      throw p0;
                    var B = ke(Te(iZr, er));
                  }
                  var T0 = B;
                }
                return V0(P, [1, L, Q]), T0;
              }), N(E0, function(P) {
                var L = Le(P), Q = pr(P), i0 = N0(P);
                if (typeof i0 == "number")
                  switch (i0) {
                    case 0:
                      var l0 = u(ve[12], P);
                      return [1, [0, l0[1], [19, l0[2]]], l0[3]];
                    case 4:
                      return [0, u(X, P)];
                    case 6:
                      var S0 = cr(0, dr, P), T0 = S0[2];
                      return [1, [0, S0[1], [0, T0[1]]], T0[2]];
                    case 21:
                      return ie(P), [0, [0, L, [26, [0, lr([0, Q], [0, we(P)], 0)]]]];
                    case 29:
                      return ie(P), [0, [0, L, [14, [0, 0, rZr, lr([0, Q], [0, we(P)], 0)]]]];
                    case 40:
                      return [0, u(ve[22], P)];
                    case 98:
                      var er = u(ve[17], P), j0 = er[2], B = er[1], Z = Ci <= j0[1] ? [13, j0[2]] : [12, j0[2]];
                      return [0, [0, B, Z]];
                    case 30:
                    case 31:
                      ie(P);
                      var p0 = i0 === 31 ? 1 : 0, b0 = p0 ? nZr : tZr;
                      return [0, [0, L, [14, [0, [1, p0], b0, lr([0, Q], [0, we(P)], 0)]]]];
                    case 74:
                    case 105:
                      return [0, u(Ar, P)];
                  }
                else
                  switch (i0[0]) {
                    case 0:
                      var O0 = i0[2], q0 = [2, ir(a0, P, i0[1], O0)];
                      return [0, [0, L, [14, [0, q0, O0, lr([0, Q], [0, we(P)], 0)]]]];
                    case 1:
                      var nr = i0[2], yr = [3, ir(_0, P, i0[1], nr)];
                      return [0, [0, L, [14, [0, yr, nr, lr([0, Q], [0, we(P)], 0)]]]];
                    case 2:
                      var vr = i0[1];
                      vr[4] && gi(P, 45), ie(P);
                      var $0 = [0, vr[2]], Sr = lr([0, Q], [0, we(P)], 0);
                      return [0, [0, vr[1], [14, [0, $0, vr[3], Sr]]]];
                    case 3:
                      var Mr = a(b, P, i0[1]);
                      return [0, [0, Mr[1], [25, Mr[2]]]];
                  }
                if (M1(P)) {
                  var Br = a(ve[13], 0, P);
                  return [0, [0, Br[1], [10, Br]]];
                }
                Ft(0, P);
                var qr = 0;
                return typeof i0 != "number" && i0[0] === 6 && (ie(P), qr = 1), [0, [0, L, [14, [0, 0, eZr, lr([0, Q], [0, 0], 0)]]]];
              }), N(X0, function(P) {
                return a(e, P, u(E0, P));
              }), N(b, function(P, L) {
                var Q = L[3], i0 = L[2], l0 = L[1], S0 = pr(P);
                V0(P, [3, L]);
                var T0 = [0, l0, [0, [0, i0[2], i0[1]], Q]];
                if (Q)
                  var er = 0, j0 = [0, T0, 0], B = l0;
                else
                  for (var Z = [0, T0, 0], p0 = 0; ; ) {
                    var b0 = u(ve[7], P), O0 = [0, b0, p0], q0 = N0(P), nr = 0;
                    if (typeof q0 == "number" && q0 === 1) {
                      zu(P, 4);
                      var yr = N0(P), vr = 0;
                      if (typeof yr != "number" && yr[0] === 3) {
                        var $0 = yr[1], Sr = $0[3], Mr = $0[2], Br = $0[1];
                        ie(P);
                        var qr = [0, [0, Mr[2], Mr[1]], Sr];
                        k7(P);
                        var jr = [0, [0, Br, qr], Z];
                        if (!Sr) {
                          var Z = jr, p0 = O0;
                          continue;
                        }
                        var $r = de(O0), ne = [0, Br, de(jr), $r];
                        nr = 1, vr = 1;
                      }
                      if (!vr)
                        throw [0, Fn, $$r];
                    }
                    if (!nr) {
                      Ft(Z$r, P);
                      var Qr = [0, b0[1], Q$r], pe = de(O0), oe = de([0, Qr, Z]), ne = [0, b0[1], oe, pe];
                    }
                    var er = ne[3], j0 = ne[2], B = ne[1];
                    break;
                  }
                var me = we(P), ae = ht(l0, B);
                return [0, ae, [0, j0, er, lr([0, S0], [0, me], 0)]];
              }), N(G0, function(P, L, Q, i0) {
                var l0 = $t(P);
                function S0(j0, B) {
                  return a(Qe(j0, Li, 28), j0, B);
                }
                var T0 = a(l0[2], Q, S0), er = a(b, P, i0);
                return [0, ht(L, er[1]), [24, [0, T0, er, 0]]];
              }), N(X, function(P) {
                var L = pr(P), Q = cr(0, function(T0) {
                  V0(T0, 4);
                  var er = Le(T0), j0 = u(x, T0), B = N0(T0), Z = 0;
                  if (typeof B == "number")
                    if (B === 9)
                      var p0 = [0, ir(W0, T0, er, [0, j0, 0])];
                    else if (B === 86)
                      var p0 = [1, [0, j0, u(mn[9], T0), 0]];
                    else
                      Z = 1;
                  else
                    Z = 1;
                  if (Z)
                    var p0 = [0, j0];
                  return V0(T0, 5), p0;
                }, P), i0 = Q[2], l0 = we(P), S0 = i0[0] === 0 ? i0[1] : [0, Q[1], [27, i0[1]]];
                return ir(s0, [0, L], [0, l0], S0);
              }), N(s0, function(P, L, Q) {
                var i0 = Q[2], l0 = P && P[1], S0 = L && L[1];
                function T0(We) {
                  return y7(We, lr([0, l0], [0, S0], 0));
                }
                function er(We) {
                  return QD(We, lr([0, l0], [0, S0], 0));
                }
                switch (i0[0]) {
                  case 0:
                    var j0 = i0[1], B = er(j0[2]), Pe = [0, [0, j0[1], B]];
                    break;
                  case 1:
                    var Z = i0[1], p0 = Z[10], b0 = T0(Z[9]), Pe = [1, [0, Z[1], Z[2], Z[3], Z[4], Z[5], Z[6], Z[7], Z[8], b0, p0]];
                    break;
                  case 2:
                    var O0 = i0[1], q0 = T0(O0[4]), Pe = [2, [0, O0[1], O0[2], O0[3], q0]];
                    break;
                  case 3:
                    var nr = i0[1], yr = T0(nr[4]), Pe = [3, [0, nr[1], nr[2], nr[3], yr]];
                    break;
                  case 4:
                    var vr = i0[1], $0 = T0(vr[4]), Pe = [4, [0, vr[1], vr[2], vr[3], $0]];
                    break;
                  case 5:
                    var Sr = i0[1], Mr = T0(Sr[7]), Pe = [5, [0, Sr[1], Sr[2], Sr[3], Sr[4], Sr[5], Sr[6], Mr]];
                    break;
                  case 7:
                    var Br = i0[1], qr = T0(Br[4]), Pe = [7, [0, Br[1], Br[2], Br[3], qr]];
                    break;
                  case 8:
                    var jr = i0[1], $r = jr[10], ne = T0(jr[9]), Pe = [8, [0, jr[1], jr[2], jr[3], jr[4], jr[5], jr[6], jr[7], jr[8], ne, $r]];
                    break;
                  case 10:
                    var Qr = i0[1], pe = Qr[2], oe = T0(pe[2]), Pe = [10, [0, Qr[1], [0, pe[1], oe]]];
                    break;
                  case 11:
                    var me = i0[1], ae = T0(me[2]), Pe = [11, [0, me[1], ae]];
                    break;
                  case 12:
                    var ce = i0[1], ge = T0(ce[4]), Pe = [12, [0, ce[1], ce[2], ce[3], ge]];
                    break;
                  case 13:
                    var H0 = i0[1], Fr = T0(H0[4]), Pe = [13, [0, H0[1], H0[2], H0[3], Fr]];
                    break;
                  case 14:
                    var _ = i0[1], k = T0(_[3]), Pe = [14, [0, _[1], _[2], k]];
                    break;
                  case 15:
                    var I = i0[1], U = T0(I[4]), Pe = [15, [0, I[1], I[2], I[3], U]];
                    break;
                  case 16:
                    var Y = i0[1], y0 = T0(Y[3]), Pe = [16, [0, Y[1], Y[2], y0]];
                    break;
                  case 17:
                    var D0 = i0[1], A0 = T0(D0[3]), Pe = [17, [0, D0[1], D0[2], A0]];
                    break;
                  case 18:
                    var D = i0[1], u0 = T0(D[4]), Pe = [18, [0, D[1], D[2], D[3], u0]];
                    break;
                  case 19:
                    var Y0 = i0[1], J0 = er(Y0[2]), Pe = [19, [0, Y0[1], J0]];
                    break;
                  case 20:
                    var fr = i0[1], Q0 = fr[1], F0 = fr[3], gr = fr[2], mr = T0(Q0[4]), Pe = [20, [0, [0, Q0[1], Q0[2], Q0[3], mr], gr, F0]];
                    break;
                  case 21:
                    var Cr = i0[1], sr = Cr[1], Pr = Cr[3], K0 = Cr[2], Ur = T0(sr[3]), Pe = [21, [0, [0, sr[1], sr[2], Ur], K0, Pr]];
                    break;
                  case 22:
                    var d0 = i0[1], Kr = T0(d0[2]), Pe = [22, [0, d0[1], Kr]];
                    break;
                  case 23:
                    var Pe = [23, [0, T0(i0[1][1])]];
                    break;
                  case 24:
                    var re = i0[1], xe = T0(re[3]), Pe = [24, [0, re[1], re[2], xe]];
                    break;
                  case 25:
                    var je = i0[1], le = T0(je[3]), Pe = [25, [0, je[1], je[2], le]];
                    break;
                  case 26:
                    var Pe = [26, [0, T0(i0[1][1])]];
                    break;
                  case 27:
                    var Ie = i0[1], Me = T0(Ie[3]), Pe = [27, [0, Ie[1], Ie[2], Me]];
                    break;
                  case 28:
                    var Be = i0[1], an = T0(Be[3]), Pe = [28, [0, Be[1], Be[2], an]];
                    break;
                  case 29:
                    var Ke = i0[1], Ae = T0(Ke[4]), Pe = [29, [0, Ke[1], Ke[2], Ke[3], Ae]];
                    break;
                  case 30:
                    var on = i0[1], rn = on[4], kn = on[3], sn = T0(on[2]), Pe = [30, [0, on[1], sn, kn, rn]];
                    break;
                  default:
                    var Pe = i0;
                }
                return [0, Q[1], Pe];
              }), N(dr, function(P) {
                var L = pr(P);
                V0(P, 6);
                for (var Q = [0, 0, t4[3]]; ; ) {
                  var i0 = Q[2], l0 = Q[1], S0 = N0(P);
                  if (typeof S0 == "number") {
                    var T0 = 0;
                    if (13 <= S0)
                      Ln === S0 && (T0 = 1);
                    else if (7 <= S0)
                      switch (S0 - 7 | 0) {
                        case 2:
                          var er = Le(P);
                          ie(P);
                          var Q = [0, [0, [2, er], l0], i0];
                          continue;
                        case 5:
                          var j0 = pr(P), B = cr(0, function(Qr) {
                            ie(Qr);
                            var pe = u(i, Qr);
                            return pe[0] === 0 ? [0, pe[1], t4[3]] : [0, pe[1], pe[2]];
                          }, P), Z = B[2], p0 = Z[2], b0 = B[1], O0 = lr([0, j0], 0, 0), q0 = [1, [0, b0, [0, Z[1], O0]]], nr = N0(P) === 7 ? 1 : 0, yr = 0;
                          if (!nr && Vn(1, P) === 7) {
                            var vr = [0, p0[1], [0, [0, b0, 65], p0[2]]];
                            yr = 1;
                          }
                          if (!yr)
                            var vr = p0;
                          1 - nr && V0(P, 9);
                          var Q = [0, [0, q0, l0], a(t4[5], vr, i0)];
                          continue;
                        case 0:
                          T0 = 1;
                          break;
                      }
                    if (T0) {
                      var $0 = u(t4[6], i0), Sr = de(l0), Mr = pr(P);
                      return V0(P, 7), [0, [0, Sr, mu([0, L], [0, we(P)], Mr, 0)], $0];
                    }
                  }
                  var Br = u(i, P);
                  if (Br[0] === 0)
                    var qr = t4[3], jr = Br[1];
                  else
                    var qr = Br[2], jr = Br[1];
                  N0(P) !== 7 && V0(P, 9);
                  var Q = [0, [0, [0, jr], l0], a(t4[5], qr, i0)];
                }
              }), N(Ar, function(P) {
                zu(P, 5);
                var L = Le(P), Q = pr(P), i0 = N0(P), l0 = 0;
                if (typeof i0 != "number" && i0[0] === 5) {
                  var S0 = i0[3], T0 = i0[2];
                  ie(P);
                  var er = we(P), j0 = er, B = S0, Z = T0, p0 = Te(V$r, Te(T0, Te(Y$r, S0)));
                  l0 = 1;
                }
                if (!l0) {
                  Ft(z$r, P);
                  var j0 = 0, B = K$r, Z = W$r, p0 = J$r;
                }
                k7(P);
                var b0 = Qn(tn(B)), O0 = tn(B) - 1 | 0, q0 = 0;
                if (!(O0 < 0))
                  for (var nr = q0; ; ) {
                    var yr = Vr(B, nr), vr = yr - 100 | 0, $0 = 0;
                    if (!(21 < vr >>> 0))
                      switch (vr) {
                        case 0:
                        case 3:
                        case 5:
                        case 9:
                        case 15:
                        case 17:
                        case 21:
                          Ui(b0, yr), $0 = 1;
                          break;
                      }
                    var Sr = nr + 1 | 0;
                    if (O0 !== nr) {
                      var nr = Sr;
                      continue;
                    }
                    break;
                  }
                var Mr = Bt(b0);
                return n0(Mr, B) && Ge(P, [13, B]), [0, L, [14, [0, [4, [0, Z, Mr]], p0, lr([0, Q], [0, j0], 0)]]];
              });
              function fe(P, L) {
                if (typeof L == "number") {
                  var Q = 0;
                  if (61 <= L) {
                    var i0 = L - 64 | 0;
                    27 < i0 >>> 0 ? i0 === 43 && (Q = 1) : 25 < (i0 - 1 | 0) >>> 0 && (Q = 1);
                  } else {
                    var l0 = L + hy | 0;
                    17 < l0 >>> 0 ? -1 <= l0 && (Q = 1) : l0 === 13 && (Q = 1);
                  }
                  if (Q)
                    return 0;
                }
                throw Hs;
              }
              function v0(P) {
                var L = N0(P);
                if (typeof L == "number" && !L) {
                  var Q = a(ve[16], 1, P);
                  return [0, [0, Q[1]], Q[2]];
                }
                return [0, [1, u(ve[10], P)], 0];
              }
              return N(ar, function(P) {
                var L = O9(fe, P), Q = Le(L);
                if (Vn(1, L) === 11)
                  var l0 = 0, S0 = 0;
                else
                  var i0 = u(zn[1], L), l0 = i0[2], S0 = i0[1];
                var T0 = cr(0, function(ne) {
                  var Qr = ai(ne, u(mn[3], ne));
                  if (M1(ne) && Qr === 0) {
                    var pe = a(ve[13], X$r, ne), oe = pe[1], me = [0, oe, [0, [0, oe, [2, [0, pe, [0, G1(ne)], 0]]], 0]];
                    return [0, Qr, [0, oe, [0, 0, [0, me, 0], 0, 0]], [0, [0, oe[1], oe[3], oe[3]]], 0];
                  }
                  var ae = ir(zn[4], ne[18], ne[17], ne), ce = u2(1, ne), ge = u(mn[12], ce);
                  return [0, Qr, ae, ge[1], ge[2]];
                }, L), er = T0[2], j0 = er[2], B = j0[2], Z = 0;
                if (!B[1]) {
                  var p0 = 0;
                  if (!B[3] && B[2] && (p0 = 1), !p0) {
                    var b0 = ce0(L);
                    Z = 1;
                  }
                }
                if (!Z)
                  var b0 = L;
                var O0 = j0[2], q0 = O0[1], nr = q0 ? (ue(b0, [0, q0[1][1], Qc]), [0, j0[1], [0, 0, O0[2], O0[3], O0[4]]]) : j0, yr = U1(nr), vr = f7(b0), $0 = vr && (N0(b0) === 11 ? 1 : 0);
                $0 && Ge(b0, 60), V0(b0, 11);
                var Sr = se0(ce0(b0), S0, 0, yr), Mr = cr(0, v0, Sr), Br = Mr[2];
                R(zn[6], Sr, Br[2], 0, nr);
                var qr = ht(Q, Mr[1]), jr = T0[1], $r = lr([0, l0], 0, 0);
                return [0, [0, qr, [1, [0, 0, nr, Br[1], S0, 0, er[4], er[3], er[1], $r, jr]]]];
              }), N(W0, function(P, L, Q) {
                return cr([0, L], function(i0) {
                  for (var l0 = Q; ; ) {
                    var S0 = N0(i0);
                    if (typeof S0 == "number" && S0 === 9) {
                      ie(i0);
                      var l0 = [0, u(x, i0), l0];
                      continue;
                    }
                    return [22, [0, de(l0), 0]];
                  }
                }, P);
              }), [0, x, i, T, n, K, a0, W0];
            }(j9), Ys = function(t4) {
              function n(e0) {
                var x0 = pr(e0);
                ie(e0);
                var l = lr([0, x0], 0, 0), c0 = u(ci[5], e0), t0 = f7(e0) ? rb(e0) : C9(e0);
                function a0(w0, _0) {
                  return a(Qe(w0, Li, 80), w0, _0);
                }
                return [0, a(t0[2], c0, a0), l];
              }
              function e(e0) {
                var x0 = e0[27][2];
                if (x0)
                  for (var l = 0; ; ) {
                    var c0 = N0(e0);
                    if (typeof c0 == "number" && c0 === 13) {
                      var l = [0, cr(0, n, e0), l];
                      continue;
                    }
                    return de(l);
                  }
                return x0;
              }
              function i(e0, x0) {
                var l = e0 && e0[1], c0 = pr(x0), t0 = N0(x0);
                if (typeof t0 == "number")
                  switch (t0) {
                    case 6:
                      var a0 = cr(0, function(Jr) {
                        var or = pr(Jr);
                        V0(Jr, 6);
                        var _r = Kl(0, Jr), Ir = u(ve[10], _r);
                        return V0(Jr, 7), [0, Ir, lr([0, or], [0, we(Jr)], 0)];
                      }, x0), w0 = a0[1];
                      return [0, w0, [3, [0, w0, a0[2]]]];
                    case 14:
                      if (l) {
                        var _0 = Ae0(x0), E0 = x0[29][1], X0 = _0[2][1];
                        if (E0) {
                          var b = E0[1], G0 = E0[2], X = b[2], s0 = [0, [0, a(ju[4], X0, b[1]), X], G0];
                          x0[29][1] = s0;
                        } else
                          ke(fGr);
                        return [0, _0[1], [2, _0]];
                      }
                      var dr = cr(0, function(Jr) {
                        return ie(Jr), [1, z7(Jr)];
                      }, x0), Ar = dr[1];
                      return ue(x0, [0, Ar, 89]), [0, Ar, dr[2]];
                  }
                else
                  switch (t0[0]) {
                    case 0:
                      var ar = t0[2], W0 = Le(x0), Lr = [2, ir(ci[6], x0, t0[1], ar)];
                      return [0, W0, [0, [0, W0, [0, Lr, ar, lr([0, c0], [0, we(x0)], 0)]]]];
                    case 2:
                      var Tr = t0[1], Hr = Tr[4], Or = Tr[3], xr = Tr[2], Rr = Tr[1];
                      return Hr && gi(x0, 45), V0(x0, [2, [0, Rr, xr, Or, Hr]]), [0, Rr, [0, [0, Rr, [0, [0, xr], Or, lr([0, c0], [0, we(x0)], 0)]]]];
                  }
                var Wr = z7(x0);
                return [0, Wr[1], [1, Wr]];
              }
              function x(e0, x0, l) {
                var c0 = u(zn[2], e0), t0 = c0[1], a0 = c0[2], w0 = i([0, x0], e0), _0 = w0[1], E0 = 0, X0 = Yi(e0, w0[2]);
                return [0, X0, cr(0, function(b) {
                  var G0 = t22(1, b), X = cr(0, function(Tr) {
                    var Hr = ir(zn[4], 0, 0, Tr), Or = 0, xr = N0(Tr) === 86 ? Hr : eb(Tr, Hr);
                    if (l) {
                      var Rr = xr[2], Wr = 0;
                      if (Rr[1])
                        ue(Tr, [0, _0, j7]), Wr = 1;
                      else {
                        var Jr = 0;
                        !Rr[2] && !Rr[3] && (Wr = 1, Jr = 1), Jr || ue(Tr, [0, _0, 80]);
                      }
                    } else {
                      var or = xr[2];
                      if (or[1])
                        ue(Tr, [0, _0, Vt]);
                      else {
                        var _r = or[2], Ir = 0;
                        (!_r || _r[2] || or[3]) && (Ir = 1), Ir && (or[3] ? ue(Tr, [0, _0, 81]) : ue(Tr, [0, _0, 81]));
                      }
                    }
                    return [0, Or, xr, a2(Tr, u(mn[10], Tr))];
                  }, G0), s0 = X[2], dr = s0[2], Ar = U1(dr), ar = p7(zn[5], G0, E0, t0, 0, Ar);
                  R(zn[6], G0, ar[2], 0, dr);
                  var W0 = X[1], Lr = lr([0, a0], 0, 0);
                  return [0, 0, dr, ar[1], E0, t0, 0, s0[3], s0[1], Lr, W0];
                }, e0)];
              }
              function c(e0) {
                var x0 = u(ci[2], e0);
                return x0[0] === 0 ? [0, x0[1], t4[3]] : [0, x0[1], x0[2]];
              }
              function s(e0, x0) {
                switch (x0[0]) {
                  case 0:
                    var l = x0[1], c0 = l[1];
                    return ue(e0, [0, c0, 95]), [0, c0, [14, l[2]]];
                  case 1:
                    var t0 = x0[1], a0 = t0[2][1], w0 = t0[1], _0 = 0;
                    return SL(a0) && n0(a0, v0e) && n0(a0, l0e) && (ue(e0, [0, w0, 2]), _0 = 1), !_0 && f2(a0) && V7(e0, [0, w0, 55]), [0, w0, [10, t0]];
                  case 2:
                    return ke(b0e);
                  default:
                    var E0 = x0[1][2][1];
                    return ue(e0, [0, E0[1], 96]), E0;
                }
              }
              function p(e0, x0, l) {
                function c0(a0) {
                  var w0 = t22(1, a0), _0 = cr(0, function(dr) {
                    var Ar = ai(dr, u(mn[3], dr));
                    if (e0)
                      if (x0)
                        var ar = 1, W0 = 1;
                      else
                        var ar = dr[18], W0 = 0;
                    else if (x0)
                      var ar = 0, W0 = 1;
                    else
                      var ar = 0, W0 = 0;
                    var Lr = ir(zn[4], ar, W0, dr), Tr = N0(dr) === 86 ? Lr : eb(dr, Lr);
                    return [0, Ar, Tr, a2(dr, u(mn[10], dr))];
                  }, w0), E0 = _0[2], X0 = E0[2], b = U1(X0), G0 = p7(zn[5], w0, e0, x0, 0, b);
                  R(zn[6], w0, G0[2], 0, X0);
                  var X = _0[1], s0 = lr([0, l], 0, 0);
                  return [0, 0, X0, G0[1], e0, x0, 0, E0[3], E0[1], s0, X];
                }
                var t0 = 0;
                return function(a0) {
                  return cr(t0, c0, a0);
                };
              }
              function y(e0) {
                return V0(e0, 86), c(e0);
              }
              function T(e0, x0, l, c0, t0, a0) {
                var w0 = cr([0, x0], function(E0) {
                  if (!c0 && !t0) {
                    var X0 = N0(E0);
                    if (typeof X0 == "number") {
                      var b = 0;
                      if (86 <= X0) {
                        if (X0 === 98)
                          b = 1;
                        else if (!(87 <= X0)) {
                          var G0 = y(E0);
                          return [0, [0, l, G0[1], 0], G0[2]];
                        }
                      } else {
                        if (X0 === 82) {
                          if (l[0] === 1)
                            var X = l[1], s0 = Le(E0), dr = function(Rr) {
                              var Wr = pr(Rr);
                              V0(Rr, 82);
                              var Jr = we(Rr), or = a(ve[19], Rr, [0, X[1], [10, X]]), _r = u(ve[10], Rr);
                              return [2, [0, 0, or, _r, lr([0, Wr], [0, Jr], 0)]];
                            }, Ar = cr([0, X[1]], dr, E0), ar = [0, Ar, [0, [0, [0, s0, [10, Ml(s0e)]], 0], 0]];
                          else
                            var ar = y(E0);
                          return [0, [0, l, ar[1], 1], ar[2]];
                        }
                        if (!(10 <= X0))
                          switch (X0) {
                            case 4:
                              b = 1;
                              break;
                            case 1:
                            case 9:
                              var W0 = [0, l, s(E0, l), 1];
                              return [0, W0, t4[3]];
                          }
                      }
                      if (b) {
                        var Lr = Yi(E0, l), Tr = [1, Lr, u(p(c0, t0, a0), E0)];
                        return [0, Tr, t4[3]];
                      }
                    }
                    var Hr = [0, l, s(E0, l), 1];
                    return [0, Hr, t4[3]];
                  }
                  var Or = Yi(E0, l), xr = [1, Or, u(p(c0, t0, a0), E0)];
                  return [0, xr, t4[3]];
                }, e0), _0 = w0[2];
                return [0, [0, [0, w0[1], _0[1]]], _0[2]];
              }
              function E(e0) {
                var x0 = cr(0, function(c0) {
                  var t0 = pr(c0);
                  V0(c0, 0);
                  for (var a0 = 0, w0 = [0, 0, t4[3]]; ; ) {
                    var _0 = w0[2], E0 = w0[1], X0 = N0(c0);
                    if (typeof X0 == "number") {
                      var b = 0;
                      if ((X0 === 1 || Ln === X0) && (b = 1), b) {
                        var G0 = a0 ? [0, _0[1], [0, [0, a0[1], 98], _0[2]]] : _0, X = u(t4[6], G0), s0 = de(E0), dr = pr(c0);
                        return V0(c0, 1), [0, [0, s0, mu([0, t0], [0, we(c0)], dr, 0)], X];
                      }
                    }
                    if (N0(c0) === 12)
                      var Ar = pr(c0), ar = cr(0, function(y0) {
                        return V0(y0, 12), c(y0);
                      }, c0), W0 = ar[2], Lr = W0[2], Tr = lr([0, Ar], 0, 0), Hr = [0, [1, [0, ar[1], [0, W0[1], Tr]]], Lr];
                    else {
                      var Or = Le(c0), xr = Vn(1, c0), Rr = 0;
                      if (typeof xr == "number") {
                        var Wr = 0;
                        if (86 <= xr)
                          xr !== 98 && 87 <= xr && (Wr = 1);
                        else if (xr !== 82)
                          if (10 <= xr)
                            Wr = 1;
                          else
                            switch (xr) {
                              case 1:
                              case 4:
                              case 9:
                                break;
                              default:
                                Wr = 1;
                            }
                        if (!Wr) {
                          var or = 0, _r = 0;
                          Rr = 1;
                        }
                      }
                      if (!Rr)
                        var Jr = u(zn[1], c0), or = Jr[2], _r = Jr[1];
                      var Ir = u(zn[2], c0), fe = Ir[1], v0 = xn(or, Ir[2]), P = N0(c0), L = 0;
                      if (!_r && !fe && typeof P != "number" && P[0] === 4) {
                        var Q = P[3], i0 = 0;
                        if (n0(Q, o0e))
                          if (n0(Q, c0e))
                            i0 = 1;
                          else {
                            var l0 = pr(c0), S0 = i(0, c0)[2], T0 = N0(c0), er = 0;
                            if (typeof T0 == "number") {
                              var j0 = 0;
                              if (86 <= T0)
                                T0 !== 98 && 87 <= T0 && (j0 = 1);
                              else if (T0 !== 82)
                                if (10 <= T0)
                                  j0 = 1;
                                else
                                  switch (T0) {
                                    case 1:
                                    case 4:
                                    case 9:
                                      break;
                                    default:
                                      j0 = 1;
                                  }
                              if (!j0) {
                                var B = T(c0, Or, S0, 0, 0, 0);
                                er = 1;
                              }
                            }
                            if (!er) {
                              Yi(c0, S0);
                              var Z = t4[3], p0 = cr([0, Or], function(A0) {
                                return x(A0, 0, 0);
                              }, c0), b0 = p0[2], O0 = lr([0, l0], 0, 0), B = [0, [0, [0, p0[1], [3, b0[1], b0[2], O0]]], Z];
                            }
                            var q0 = B;
                          }
                        else {
                          var nr = pr(c0), yr = i(0, c0)[2], vr = N0(c0), $0 = 0;
                          if (typeof vr == "number") {
                            var Sr = 0;
                            if (86 <= vr)
                              vr !== 98 && 87 <= vr && (Sr = 1);
                            else if (vr !== 82)
                              if (10 <= vr)
                                Sr = 1;
                              else
                                switch (vr) {
                                  case 1:
                                  case 4:
                                  case 9:
                                    break;
                                  default:
                                    Sr = 1;
                                }
                            if (!Sr) {
                              var Mr = T(c0, Or, yr, 0, 0, 0);
                              $0 = 1;
                            }
                          }
                          if (!$0) {
                            Yi(c0, yr);
                            var Br = t4[3], qr = cr([0, Or], function(D) {
                              return x(D, 0, 1);
                            }, c0), jr = qr[2], $r = lr([0, nr], 0, 0), Mr = [0, [0, [0, qr[1], [2, jr[1], jr[2], $r]]], Br];
                          }
                          var q0 = Mr;
                        }
                        if (!i0) {
                          var ne = q0;
                          L = 1;
                        }
                      }
                      if (!L)
                        var ne = T(c0, Or, i(0, c0)[2], _r, fe, v0);
                      var Hr = ne;
                    }
                    var Qr = Hr[1], pe = 0;
                    if (Qr[0] === 1 && N0(c0) === 9) {
                      var oe = [0, Le(c0)];
                      pe = 1;
                    }
                    if (!pe)
                      var oe = 0;
                    var me = a(t4[5], Hr[2], _0), ae = N0(c0), ce = 0;
                    if (typeof ae == "number") {
                      var ge = ae - 2 | 0, H0 = 0;
                      if (Yt < ge >>> 0 ? T7 < (ge + 1 | 0) >>> 0 && (H0 = 1) : ge === 7 ? ie(c0) : H0 = 1, !H0) {
                        var Fr = me;
                        ce = 1;
                      }
                    }
                    if (!ce) {
                      var _ = vL(GRr, 9), k = ye0([0, _], N0(c0)), I = [0, Le(c0), k];
                      fu(c0, 8);
                      var Fr = a(t4[4], I, me);
                    }
                    var a0 = oe, w0 = [0, [0, Qr, E0], Fr];
                  }
                }, e0), l = x0[2];
                return [0, x0[1], l[1], l[2]];
              }
              function h(e0, x0, l, c0) {
                var t0 = l[2][1], a0 = l[1];
                if (Un(t0, a0e))
                  return ue(e0, [0, a0, [21, t0, 0, uV === c0 ? 1 : 0, 1]]), x0;
                var w0 = a(R9[32], t0, x0);
                if (w0) {
                  var _0 = w0[1], E0 = 0;
                  return TE === c0 ? Id === _0 && (E0 = 1) : Id === c0 && TE === _0 && (E0 = 1), E0 || ue(e0, [0, a0, [20, t0]]), ir(R9[4], t0, QX, x0);
                }
                return ir(R9[4], t0, c0, x0);
              }
              function w(e0, x0) {
                return cr(0, function(l) {
                  var c0 = x0 && pr(l);
                  V0(l, 52);
                  for (var t0 = 0; ; ) {
                    var a0 = [0, cr(0, function(E0) {
                      var X0 = u(mn[2], E0);
                      if (N0(E0) === 98)
                        var b = $t(E0), G0 = function(s0, dr) {
                          return a(Qe(s0, Nv, 81), s0, dr);
                        }, X = a(b[2], X0, G0);
                      else
                        var X = X0;
                      return [0, X, u(mn[4], E0)];
                    }, l), t0], w0 = N0(l);
                    if (typeof w0 == "number" && w0 === 9) {
                      V0(l, 9);
                      var t0 = a0;
                      continue;
                    }
                    var _0 = de(a0);
                    return [0, _0, lr([0, c0], 0, 0)];
                  }
                }, e0);
              }
              function G(e0, x0) {
                return x0 && ue(e0, [0, x0[1][1], 7]);
              }
              function A(e0, x0) {
                return x0 && ue(e0, [0, x0[1], 68]);
              }
              function S(e0, x0, l, c0, t0, a0, w0, _0, E0, X0) {
                for (; ; ) {
                  var b = N0(e0), G0 = 0;
                  if (typeof b == "number") {
                    var X = b - 1 | 0, s0 = 0;
                    if (7 < X >>> 0) {
                      var dr = X - 81 | 0;
                      if (4 < dr >>> 0)
                        s0 = 1;
                      else
                        switch (dr) {
                          case 3:
                            Ft(0, e0), ie(e0);
                            continue;
                          case 0:
                          case 4:
                            break;
                          default:
                            s0 = 1;
                        }
                    } else
                      5 < (X - 1 | 0) >>> 0 || (s0 = 1);
                    !s0 && !t0 && !a0 && (G0 = 1);
                  }
                  if (!G0) {
                    var Ar = N0(e0), ar = 0;
                    if (typeof Ar == "number") {
                      var W0 = 0;
                      if (Ar !== 4 && Ar !== 98 && (ar = 1, W0 = 1), !W0)
                        var Tr = 0;
                    } else
                      ar = 1;
                    if (ar)
                      var Lr = x2(e0), Tr = Lr && 1;
                    if (!Tr) {
                      A(e0, _0), G(e0, E0);
                      var Hr = 0;
                      if (!w0) {
                        var Or = 0;
                        switch (c0[0]) {
                          case 0:
                            var xr = c0[1][2][1], Rr = 0;
                            typeof xr != "number" && xr[0] === 0 && (n0(xr[1], e0e) && (Or = 1), Rr = 1), Rr || (Or = 1);
                            break;
                          case 1:
                            n0(c0[1][2][1], n0e) && (Or = 1);
                            break;
                          default:
                            Or = 1;
                        }
                        if (!Or) {
                          var Wr = t22(2, e0), Jr = 0;
                          Hr = 1;
                        }
                      }
                      if (!Hr)
                        var Wr = t22(1, e0), Jr = 1;
                      var or = Yi(Wr, c0), _r = cr(0, function(S0) {
                        var T0 = cr(0, function(p0) {
                          var b0 = ai(p0, u(mn[3], p0));
                          if (t0)
                            if (a0)
                              var O0 = 1, q0 = 1;
                            else
                              var O0 = p0[18], q0 = 0;
                          else if (a0)
                            var O0 = 0, q0 = 1;
                          else
                            var O0 = 0, q0 = 0;
                          var nr = ir(zn[4], O0, q0, p0), yr = N0(p0) === 86 ? nr : eb(p0, nr), vr = yr[2], $0 = vr[1], Sr = 0;
                          if ($0 && Jr === 0) {
                            ue(p0, [0, $0[1][1], fs2]);
                            var Mr = [0, yr[1], [0, 0, vr[2], vr[3], vr[4]]];
                            Sr = 1;
                          }
                          if (!Sr)
                            var Mr = yr;
                          return [0, b0, Mr, a2(p0, u(mn[10], p0))];
                        }, S0), er = T0[2], j0 = er[2], B = U1(j0), Z = p7(zn[5], S0, t0, a0, 0, B);
                        return R(zn[6], S0, Z[2], 0, j0), [0, 0, j0, Z[1], t0, a0, 0, er[3], er[1], 0, T0[1]];
                      }, Wr), Ir = [0, Jr, or, _r, w0, l, lr([0, X0], 0, 0)];
                      return [0, [0, ht(x0, _r[1]), Ir]];
                    }
                  }
                  var fe = cr([0, x0], function(S0) {
                    var T0 = u(mn[10], S0), er = N0(S0);
                    if (_0) {
                      var j0 = 0;
                      if (typeof er == "number" && er === 82) {
                        Ge(S0, 69), ie(S0);
                        var B = 0;
                      } else
                        j0 = 1;
                      if (j0)
                        var B = 0;
                    } else {
                      var Z = 0;
                      if (typeof er == "number" && er === 82) {
                        ie(S0);
                        var p0 = t22(1, S0), B = [0, u(ve[7], p0)];
                      } else
                        Z = 1;
                      if (Z)
                        var B = 1;
                    }
                    var b0 = N0(S0), O0 = 0;
                    if (typeof b0 == "number" && !(9 <= b0))
                      switch (b0) {
                        case 8:
                          ie(S0);
                          var q0 = N0(S0), nr = 0;
                          if (typeof q0 == "number") {
                            var yr = 0;
                            if (q0 !== 1 && Ln !== q0 && (nr = 1, yr = 1), !yr)
                              var $0 = we(S0);
                          } else
                            nr = 1;
                          if (nr)
                            var vr = f7(S0), $0 = vr && Us(S0);
                          var Sr = [0, c0, T0, B, $0];
                          O0 = 1;
                          break;
                        case 4:
                        case 6:
                          Ft(0, S0);
                          var Sr = [0, c0, T0, B, 0];
                          O0 = 1;
                          break;
                      }
                    if (!O0) {
                      var Mr = N0(S0), Br = 0;
                      if (typeof Mr == "number") {
                        var qr = 0;
                        if (Mr !== 1 && Ln !== Mr && (Br = 1, qr = 1), !qr)
                          var jr = [0, 0, function(H0, Fr) {
                            return H0;
                          }];
                      } else
                        Br = 1;
                      if (Br)
                        var jr = f7(S0) ? rb(S0) : C9(S0);
                      if (typeof B == "number")
                        if (T0[0] === 0)
                          var $r = function(_, k) {
                            return a(Qe(_, VY, 83), _, k);
                          }, pe = B, oe = T0, me = a(jr[2], c0, $r);
                        else
                          var ne = function(_, k) {
                            return a(Qe(_, NE, 84), _, k);
                          }, pe = B, oe = [1, a(jr[2], T0[1], ne)], me = c0;
                      else
                        var Qr = function(ge, H0) {
                          return a(Qe(ge, Li, 85), ge, H0);
                        }, pe = [0, a(jr[2], B[1], Qr)], oe = T0, me = c0;
                      var Sr = [0, me, oe, pe, 0];
                    }
                    var ae = lr([0, X0], [0, Sr[4]], 0);
                    return [0, Sr[1], Sr[2], Sr[3], ae];
                  }, e0), v0 = fe[2], P = v0[4], L = v0[3], Q = v0[2], i0 = v0[1], l0 = fe[1];
                  return i0[0] === 2 ? [2, [0, l0, [0, i0[1], L, Q, w0, E0, P]]] : [1, [0, l0, [0, i0, L, Q, w0, E0, P]]];
                }
              }
              function M(e0, x0) {
                var l = Vn(e0, x0);
                if (typeof l == "number") {
                  var c0 = 0;
                  if (86 <= l)
                    (l === 98 || !(87 <= l)) && (c0 = 1);
                  else if (l === 82)
                    c0 = 1;
                  else if (!(9 <= l))
                    switch (l) {
                      case 1:
                      case 4:
                      case 8:
                        c0 = 1;
                        break;
                    }
                  if (c0)
                    return 1;
                }
                return 0;
              }
              var K = 0;
              function V(e0) {
                return M(K, e0);
              }
              function f0(e0, x0, l, c0) {
                var t0 = e0 && e0[1], a0 = ys(1, x0), w0 = xn(t0, e(a0)), _0 = pr(a0);
                V0(a0, 40);
                var E0 = T9(1, a0), X0 = N0(E0), b = 0;
                if (l && typeof X0 == "number") {
                  var G0 = 0;
                  if (52 <= X0 ? X0 !== 98 && 53 <= X0 && (G0 = 1) : X0 !== 41 && X0 && (G0 = 1), !G0) {
                    var Ar = 0;
                    b = 1;
                  }
                }
                if (!b)
                  if (M1(a0))
                    var X = a(ve[13], 0, E0), s0 = $t(a0), dr = function(v0, P) {
                      return a(Qe(v0, Nv, 88), v0, P);
                    }, Ar = [0, a(s0[2], X, dr)];
                  else {
                    de0(a0, WQr);
                    var Ar = [0, [0, Le(a0), JQr]];
                  }
                var ar = u(mn[3], a0);
                if (ar)
                  var W0 = $t(a0), Lr = function(v0, P) {
                    return a(Qe(v0, _F, 86), v0, P);
                  }, Tr = [0, a(W0[2], ar[1], Lr)];
                else
                  var Tr = ar;
                var Hr = pr(a0), Or = fu(a0, 41);
                if (Or)
                  var xr = cr(0, function(v0) {
                    var P = dL(0, v0), L = u(ci[5], P);
                    if (N0(v0) === 98)
                      var Q = $t(v0), i0 = function(T0, er) {
                        return a(Qe(T0, Li, 82), T0, er);
                      }, l0 = a(Q[2], L, i0);
                    else
                      var l0 = L;
                    var S0 = u(mn[4], v0);
                    return [0, l0, S0, lr([0, Hr], 0, 0)];
                  }, a0), Rr = xr[1], Wr = $t(a0), Jr = function(v0, P) {
                    return ir(Qe(v0, -663447790, 87), v0, Rr, P);
                  }, or = [0, [0, Rr, a(Wr[2], xr[2], Jr)]];
                else
                  var or = Or;
                var _r = N0(a0) === 52 ? 1 : 0;
                if (_r) {
                  1 - iu(a0) && Ge(a0, 16);
                  var Ir = [0, Fe0(a0, w(a0, 1))];
                } else
                  var Ir = _r;
                var fe = cr(0, function(v0) {
                  var P = pr(v0);
                  if (fu(v0, 0)) {
                    v0[29][1] = [0, [0, ju[1], 0], v0[29][1]];
                    for (var L = 0, Q = R9[1], i0 = 0; ; ) {
                      var l0 = N0(v0);
                      if (typeof l0 == "number") {
                        var S0 = l0 - 2 | 0;
                        if (Yt < S0 >>> 0) {
                          if (!(T7 < (S0 + 1 | 0) >>> 0)) {
                            var T0 = de(i0), er = function(xu, Gu) {
                              return u(ml(function(K7) {
                                return 1 - a(ju[3], K7[1], xu);
                              }), Gu);
                            }, j0 = v0[29][1];
                            if (j0) {
                              var B = j0[1], Z = B[1];
                              if (j0[2]) {
                                var p0 = j0[2], b0 = er(Z, B[2]), O0 = bl(p0), q0 = bz(p0), nr = xn(O0[2], b0);
                                v0[29][1] = [0, [0, O0[1], nr], q0];
                              } else {
                                var yr = er(Z, B[2]);
                                Cu(function(xu) {
                                  return ue(v0, [0, xu[2], [22, xu[1]]]);
                                }, yr), v0[29][1] = 0;
                              }
                            } else
                              ke(xGr);
                            V0(v0, 1);
                            var vr = N0(v0), $0 = 0;
                            if (!c0) {
                              var Sr = 0;
                              if (typeof vr == "number" && (vr === 1 || Ln === vr) && (Sr = 1), !Sr) {
                                var Mr = f7(v0);
                                if (Mr) {
                                  var Br = Us(v0);
                                  $0 = 1;
                                } else {
                                  var Br = Mr;
                                  $0 = 1;
                                }
                              }
                            }
                            if (!$0)
                              var Br = we(v0);
                            return [0, T0, lr([0, P], [0, Br], 0)];
                          }
                        } else if (S0 === 6) {
                          V0(v0, 8);
                          continue;
                        }
                      }
                      var qr = Le(v0), jr = e(v0), $r = N0(v0), ne = 0;
                      if (typeof $r == "number" && $r === 60 && !M(1, v0)) {
                        var Qr = [0, Le(v0)], pe = pr(v0);
                        ie(v0);
                        var oe = pe, me = Qr;
                        ne = 1;
                      }
                      if (!ne)
                        var oe = 0, me = 0;
                      var ae = Vn(1, v0) !== 4 ? 1 : 0;
                      if (ae)
                        var ce = Vn(1, v0) !== 98 ? 1 : 0, ge = ce && (N0(v0) === 42 ? 1 : 0);
                      else
                        var ge = ae;
                      if (ge) {
                        var H0 = pr(v0);
                        ie(v0);
                        var Fr = H0;
                      } else
                        var Fr = ge;
                      var _ = N0(v0) === 64 ? 1 : 0;
                      if (_)
                        var k = 1 - M(1, v0), I = k && 1 - Jl(1, v0);
                      else
                        var I = _;
                      if (I) {
                        var U = pr(v0);
                        ie(v0);
                        var Y = U;
                      } else
                        var Y = I;
                      var y0 = u(zn[2], v0), D0 = y0[1], A0 = ir(zn[3], v0, I, D0), D = 0;
                      if (!D0 && A0) {
                        var u0 = u(zn[2], v0), Y0 = u0[2], J0 = u0[1];
                        D = 1;
                      }
                      if (!D)
                        var Y0 = y0[2], J0 = D0;
                      var fr = pl([0, oe, [0, Fr, [0, Y, [0, Y0, 0]]]]), Q0 = N0(v0), F0 = 0;
                      if (!I && !J0 && typeof Q0 != "number" && Q0[0] === 4) {
                        var gr = Q0[3];
                        if (n0(gr, t0e)) {
                          if (!n0(gr, u0e)) {
                            var mr = pr(v0), Cr = i(i0e, v0)[2];
                            if (V(v0)) {
                              var Ie = S(v0, qr, jr, Cr, I, J0, ge, me, A0, fr);
                              F0 = 1;
                            } else {
                              A(v0, me), G(v0, A0), Yi(v0, Cr);
                              var sr = xn(fr, mr), Pr = cr([0, qr], function(Gu) {
                                return x(Gu, 1, 0);
                              }, v0), K0 = Pr[2], Ur = lr([0, sr], 0, 0), Ie = [0, [0, Pr[1], [0, 3, K0[1], K0[2], ge, jr, Ur]]];
                              F0 = 1;
                            }
                          }
                        } else {
                          var d0 = pr(v0), Kr = i(f0e, v0)[2];
                          if (V(v0)) {
                            var Ie = S(v0, qr, jr, Kr, I, J0, ge, me, A0, fr);
                            F0 = 1;
                          } else {
                            A(v0, me), G(v0, A0), Yi(v0, Kr);
                            var re = xn(fr, d0), xe = cr([0, qr], function(Gu) {
                              return x(Gu, 1, 1);
                            }, v0), je = xe[2], le = lr([0, re], 0, 0), Ie = [0, [0, xe[1], [0, 2, je[1], je[2], ge, jr, le]]];
                            F0 = 1;
                          }
                        }
                      }
                      if (!F0)
                        var Ie = S(v0, qr, jr, i(x0e, v0)[2], I, J0, ge, me, A0, fr);
                      switch (Ie[0]) {
                        case 0:
                          var Me = Ie[1], Be = Me[2];
                          switch (Be[1]) {
                            case 0:
                              if (Be[4])
                                var Ot = Q, Pt = L;
                              else {
                                L && ue(v0, [0, Me[1], 87]);
                                var Ot = Q, Pt = 1;
                              }
                              break;
                            case 1:
                              var an = Be[2], Ke = an[0] === 2 ? h(v0, Q, an[1], uV) : Q, Ot = Ke, Pt = L;
                              break;
                            case 2:
                              var Ae = Be[2], on = Ae[0] === 2 ? h(v0, Q, Ae[1], TE) : Q, Ot = on, Pt = L;
                              break;
                            default:
                              var rn = Be[2], kn = rn[0] === 2 ? h(v0, Q, rn[1], Id) : Q, Ot = kn, Pt = L;
                          }
                          break;
                        case 1:
                          var sn = Ie[1][2], Pe = sn[4], We = sn[1], en = 0;
                          switch (We[0]) {
                            case 0:
                              var _n = We[1], Dn = _n[2][1], Xn = 0;
                              if (typeof Dn != "number" && Dn[0] === 0) {
                                var bt = Dn[1], Ct = _n[1];
                                en = 1, Xn = 1;
                              }
                              Xn || (en = 2);
                              break;
                            case 1:
                              var On = We[1], bt = On[2][1], Ct = On[1];
                              en = 1;
                              break;
                            case 2:
                              ke($Qr);
                              break;
                            default:
                              en = 2;
                          }
                          switch (en) {
                            case 1:
                              var Tt = Un(bt, ZQr);
                              if (Tt)
                                var Ut = Tt;
                              else
                                var Zt = Un(bt, QQr), Ut = Zt && Pe;
                              Ut && ue(v0, [0, Ct, [21, bt, Pe, 0, 0]]);
                              break;
                            case 2:
                              break;
                          }
                          var Ot = Q, Pt = L;
                          break;
                        default:
                          var Ot = h(v0, Q, Ie[1][2][1], QX), Pt = L;
                      }
                      var L = Pt, Q = Ot, i0 = [0, Ie, i0];
                    }
                  }
                  return q1(v0, 0), r0e;
                }, a0);
                return [0, Ar, fe, Tr, or, Ir, w0, lr([0, _0], 0, 0)];
              }
              function m0(e0, x0) {
                return cr(0, function(l) {
                  return [2, f0([0, x0], l, l[7], 0)];
                }, e0);
              }
              function k0(e0) {
                return [5, f0(0, e0, 1, 1)];
              }
              var g0 = 0;
              return [0, i, E, m0, function(e0) {
                return cr(g0, k0, e0);
              }, w, e];
            }(j9), kt = function(t4) {
              function n(_) {
                var k = u(zn[10], _);
                if (_[5])
                  B1(_, k[1]);
                else {
                  var I = k[2], U = 0;
                  if (I[0] === 23) {
                    var Y = I[1], y0 = k[1], D0 = 0;
                    Y[4] ? ue(_, [0, y0, 61]) : Y[5] ? ue(_, [0, y0, 62]) : (U = 1, D0 = 1);
                  } else
                    U = 1;
                }
                return k;
              }
              function e(_, k, I) {
                var U = I[2][1], Y = I[1];
                if (n0(U, mre)) {
                  if (n0(U, _re))
                    return n0(U, yre) ? f2(U) ? V7(k, [0, Y, 55]) : SL(U) ? ue(k, [0, Y, [10, Ml(U)]]) : _ && Bs(U) ? V7(k, [0, Y, _[1]]) : 0 : k[17] ? ue(k, [0, Y, 2]) : V7(k, [0, Y, 55]);
                  if (k[5])
                    return V7(k, [0, Y, 55]);
                  var y0 = k[14];
                  return y0 && ue(k, [0, Y, [10, Ml(U)]]);
                }
                var D0 = k[18];
                return D0 && ue(k, [0, Y, 2]);
              }
              function i(_, k) {
                var I = k[4], U = k[3], Y = k[2], y0 = k[1];
                I && gi(_, 45);
                var D0 = pr(_);
                return V0(_, [2, [0, y0, Y, U, I]]), [0, y0, [0, Y, U, lr([0, D0], [0, we(_)], 0)]];
              }
              function x(_, k, I) {
                var U = _ ? _[1] : lre, Y = k ? k[1] : 1, y0 = N0(I);
                if (typeof y0 == "number") {
                  var D0 = y0 - 2 | 0;
                  if (Yt < D0 >>> 0) {
                    if (!(T7 < (D0 + 1 | 0) >>> 0)) {
                      var A0 = function(Y0, J0) {
                        return Y0;
                      };
                      return [1, [0, we(I), A0]];
                    }
                  } else if (D0 === 6) {
                    ie(I);
                    var D = N0(I);
                    if (typeof D == "number") {
                      var u0 = 0;
                      if ((D === 1 || Ln === D) && (u0 = 1), u0)
                        return [0, we(I)];
                    }
                    return f7(I) ? [0, Us(I)] : bre;
                  }
                }
                return f7(I) ? [1, rb(I)] : (Y && Ft([0, U], I), pre);
              }
              function c(_) {
                var k = N0(_);
                if (typeof k == "number") {
                  var I = 0;
                  if ((k === 1 || Ln === k) && (I = 1), I) {
                    var U = function(Y, y0) {
                      return Y;
                    };
                    return [0, we(_), U];
                  }
                }
                return f7(_) ? rb(_) : C9(_);
              }
              function s(_, k, I) {
                var U = x(0, 0, k);
                if (U[0] === 0)
                  return [0, U[1], I];
                var Y = de(I);
                if (Y)
                  var y0 = function(D, u0) {
                    return ir(Qe(D, 634872468, 89), D, _, u0);
                  }, D0 = a(U[1][2], Y[1], y0), A0 = de([0, D0, Y[2]]);
                else
                  var A0 = Y;
                return [0, 0, A0];
              }
              var p = function _(k) {
                return _.fun(k);
              }, y = function _(k) {
                return _.fun(k);
              }, T = function _(k) {
                return _.fun(k);
              }, E = function _(k) {
                return _.fun(k);
              }, h = function _(k) {
                return _.fun(k);
              }, w = function _(k, I) {
                return _.fun(k, I);
              }, G = function _(k) {
                return _.fun(k);
              }, A = function _(k) {
                return _.fun(k);
              }, S = function _(k, I, U) {
                return _.fun(k, I, U);
              }, M = function _(k) {
                return _.fun(k);
              }, K = function _(k) {
                return _.fun(k);
              }, V = function _(k, I) {
                return _.fun(k, I);
              }, f0 = function _(k) {
                return _.fun(k);
              }, m0 = function _(k) {
                return _.fun(k);
              }, k0 = function _(k, I) {
                return _.fun(k, I);
              }, g0 = function _(k) {
                return _.fun(k);
              }, e0 = function _(k, I) {
                return _.fun(k, I);
              }, x0 = function _(k) {
                return _.fun(k);
              }, l = function _(k, I) {
                return _.fun(k, I);
              }, c0 = function _(k) {
                return _.fun(k);
              }, t0 = function _(k, I) {
                return _.fun(k, I);
              }, a0 = function _(k, I) {
                return _.fun(k, I);
              }, w0 = function _(k, I) {
                return _.fun(k, I);
              }, _0 = function _(k) {
                return _.fun(k);
              }, E0 = function _(k) {
                return _.fun(k);
              }, X0 = function _(k, I, U) {
                return _.fun(k, I, U);
              }, b = function _(k, I) {
                return _.fun(k, I);
              }, G0 = function _(k, I) {
                return _.fun(k, I);
              }, X = function _(k) {
                return _.fun(k);
              };
              function s0(_) {
                var k = pr(_);
                V0(_, 59);
                var I = N0(_) === 8 ? 1 : 0, U = I && we(_), Y = x(0, 0, _), y0 = Y[0] === 0 ? Y[1] : Y[1][1];
                return [4, [0, lr([0, k], [0, xn(U, y0)], 0)]];
              }
              var dr = 0;
              function Ar(_) {
                return cr(dr, s0, _);
              }
              function ar(_) {
                var k = pr(_);
                V0(_, 37);
                var I = zl(1, _), U = u(ve[2], I), Y = 1 - _[5], y0 = Y && nb(U);
                y0 && B1(_, U[1]);
                var D0 = we(_);
                V0(_, 25);
                var A0 = we(_);
                V0(_, 4);
                var D = u(ve[7], _);
                V0(_, 5);
                var u0 = N0(_) === 8 ? 1 : 0, Y0 = u0 && we(_), J0 = x(0, vre, _), fr = J0[0] === 0 ? xn(Y0, J0[1]) : J0[1][1];
                return [14, [0, U, D, lr([0, k], [0, xn(D0, xn(A0, fr))], 0)]];
              }
              var W0 = 0;
              function Lr(_) {
                return cr(W0, ar, _);
              }
              function Tr(_, k, I) {
                var U = I[2][1];
                if (U && !U[1][2][2]) {
                  var Y = U[2];
                  if (!Y)
                    return Y;
                }
                return ue(_, [0, I[1], k]);
              }
              function Hr(_, k) {
                var I = 1 - _[5], U = I && nb(k);
                return U && B1(_, k[1]);
              }
              function Or(_) {
                var k = pr(_);
                V0(_, 39);
                var I = _[18], U = I && fu(_, 65), Y = xn(k, pr(_));
                V0(_, 4);
                var y0 = lr([0, Y], 0, 0), D0 = Kl(1, _), A0 = N0(D0), D = 0;
                if (typeof A0 == "number")
                  if (24 <= A0)
                    if (29 <= A0)
                      D = 1;
                    else
                      switch (A0 - 24 | 0) {
                        case 0:
                          var u0 = cr(0, zn[9], D0), Y0 = u0[2], J0 = lr([0, Y0[2]], 0, 0), Pr = Y0[3], K0 = [0, [1, [0, u0[1], [0, Y0[1], 0, J0]]]];
                          break;
                        case 3:
                          var fr = cr(0, zn[8], D0), Q0 = fr[2], F0 = lr([0, Q0[2]], 0, 0), Pr = Q0[3], K0 = [0, [1, [0, fr[1], [0, Q0[1], 2, F0]]]];
                          break;
                        case 4:
                          var gr = cr(0, zn[7], D0), mr = gr[2], Cr = lr([0, mr[2]], 0, 0), Pr = mr[3], K0 = [0, [1, [0, gr[1], [0, mr[1], 1, Cr]]]];
                          break;
                        default:
                          D = 1;
                      }
                  else if (A0 === 8)
                    var Pr = 0, K0 = 0;
                  else
                    D = 1;
                else
                  D = 1;
                if (D)
                  var sr = T9(1, D0), Pr = 0, K0 = [0, [0, u(ve[8], sr)]];
                var Ur = N0(_);
                if (typeof Ur == "number") {
                  if (Ur === 17) {
                    if (K0) {
                      var d0 = K0[1];
                      if (d0[0] === 0)
                        var Kr = [1, ir(t4[2], cre, _, d0[1])];
                      else {
                        var re = d0[1];
                        Tr(_, 28, re);
                        var Kr = [0, re];
                      }
                      U ? V0(_, 63) : V0(_, 17);
                      var xe = u(ve[7], _);
                      V0(_, 5);
                      var je = zl(1, _), le = u(ve[2], je);
                      return Hr(_, le), [21, [0, Kr, xe, le, 0, y0]];
                    }
                    throw [0, Fn, sre];
                  }
                  if (Ur === 63) {
                    if (K0) {
                      var Ie = K0[1];
                      if (Ie[0] === 0)
                        var Me = [1, ir(t4[2], are, _, Ie[1])];
                      else {
                        var Be = Ie[1];
                        Tr(_, 29, Be);
                        var Me = [0, Be];
                      }
                      V0(_, 63);
                      var an = u(ve[10], _);
                      V0(_, 5);
                      var Ke = zl(1, _), Ae = u(ve[2], Ke);
                      return Hr(_, Ae), [22, [0, Me, an, Ae, U, y0]];
                    }
                    throw [0, Fn, ore];
                  }
                }
                if (Cu(function(Tt) {
                  return ue(_, Tt);
                }, Pr), U ? V0(_, 63) : V0(_, 8), K0)
                  var on = K0[1], rn = on[0] === 0 ? [0, [1, a(t4[1], _, on[1])]] : [0, [0, on[1]]], kn = rn;
                else
                  var kn = K0;
                var sn = N0(_), Pe = 0;
                if (typeof sn == "number") {
                  var We = sn !== 8 ? 1 : 0;
                  if (!We) {
                    var en = We;
                    Pe = 1;
                  }
                }
                if (!Pe)
                  var en = [0, u(ve[7], _)];
                V0(_, 8);
                var _n = N0(_), Dn = 0;
                if (typeof _n == "number") {
                  var Xn = _n !== 5 ? 1 : 0;
                  if (!Xn) {
                    var On = Xn;
                    Dn = 1;
                  }
                }
                if (!Dn)
                  var On = [0, u(ve[7], _)];
                V0(_, 5);
                var bt = zl(1, _), Ct = u(ve[2], bt);
                return Hr(_, Ct), [20, [0, kn, en, On, Ct, y0]];
              }
              var xr = 0;
              function Rr(_) {
                return cr(xr, Or, _);
              }
              function Wr(_) {
                var k = qs(_) ? n(_) : u(ve[2], _), I = 1 - _[5], U = I && nb(k);
                return U && B1(_, k[1]), k;
              }
              function Jr(_) {
                var k = pr(_);
                V0(_, 43);
                var I = Wr(_);
                return [0, I, lr([0, k], 0, 0)];
              }
              function or(_) {
                var k = pr(_);
                V0(_, 16);
                var I = xn(k, pr(_));
                V0(_, 4);
                var U = u(ve[7], _);
                V0(_, 5);
                var Y = Wr(_), y0 = N0(_) === 43 ? 1 : 0, D0 = y0 && [0, cr(0, Jr, _)];
                return [24, [0, U, Y, D0, lr([0, I], 0, 0)]];
              }
              var _r = 0;
              function Ir(_) {
                return cr(_r, or, _);
              }
              function fe(_) {
                1 - _[11] && Ge(_, 36);
                var k = pr(_), I = Le(_);
                V0(_, 19);
                var U = N0(_) === 8 ? 1 : 0, Y = U && we(_), y0 = 0;
                if (N0(_) !== 8 && !x2(_)) {
                  var D0 = [0, u(ve[7], _)];
                  y0 = 1;
                }
                if (!y0)
                  var D0 = 0;
                var A0 = ht(I, Le(_)), D = x(0, 0, _), u0 = 0;
                if (D[0] === 0)
                  var Y0 = D[1];
                else {
                  var J0 = D[1];
                  if (D0) {
                    var fr = function(sr, Pr) {
                      return a(Qe(sr, Li, 90), sr, Pr);
                    }, Q0 = [0, a(J0[2], D0[1], fr)], F0 = Y;
                    u0 = 1;
                  } else
                    var Y0 = J0[1];
                }
                if (!u0)
                  var Q0 = D0, F0 = xn(Y, Y0);
                return [28, [0, Q0, lr([0, k], [0, F0], 0), A0]];
              }
              var v0 = 0;
              function P(_) {
                return cr(v0, fe, _);
              }
              function L(_) {
                var k = pr(_);
                V0(_, 20), V0(_, 4);
                var I = u(ve[7], _);
                V0(_, 5), V0(_, 0);
                for (var U = xre; ; ) {
                  var Y = U[2], y0 = N0(_);
                  if (typeof y0 == "number") {
                    var D0 = 0;
                    if ((y0 === 1 || Ln === y0) && (D0 = 1), D0) {
                      var A0 = de(Y);
                      V0(_, 1);
                      var D = c(_), u0 = I[1];
                      return [29, [0, I, A0, lr([0, k], [0, D[1]], 0), u0]];
                    }
                  }
                  var Y0 = U[1], J0 = OL(0, function(Q0) {
                    return function(F0) {
                      var gr = pr(F0), mr = N0(F0), Cr = 0;
                      if (typeof mr == "number" && mr === 36) {
                        Q0 && Ge(F0, 32), V0(F0, 36);
                        var sr = we(F0), Pr = 0;
                        Cr = 1;
                      }
                      if (!Cr) {
                        V0(F0, 33);
                        var sr = 0, Pr = [0, u(ve[7], F0)];
                      }
                      var K0 = Q0 || (Pr === 0 ? 1 : 0);
                      V0(F0, 86);
                      var Ur = xn(sr, c(F0)[1]);
                      function d0(je) {
                        if (typeof je == "number") {
                          var le = je - 1 | 0, Ie = 0;
                          if (32 < le >>> 0 ? le === 35 && (Ie = 1) : 30 < (le - 1 | 0) >>> 0 && (Ie = 1), Ie)
                            return 1;
                        }
                        return 0;
                      }
                      var Kr = 1, re = F0[9] === 1 ? F0 : [0, F0[1], F0[2], F0[3], F0[4], F0[5], F0[6], F0[7], F0[8], Kr, F0[10], F0[11], F0[12], F0[13], F0[14], F0[15], F0[16], F0[17], F0[18], F0[19], F0[20], F0[21], F0[22], F0[23], F0[24], F0[25], F0[26], F0[27], F0[28], F0[29], F0[30]], xe = a(ve[4], d0, re);
                      return [0, [0, Pr, xe, lr([0, gr], [0, Ur], 0)], K0];
                    };
                  }(Y0), _), U = [0, J0[2], [0, J0[1], Y]];
                }
              }
              var Q = 0;
              function i0(_) {
                return cr(Q, L, _);
              }
              function l0(_) {
                var k = pr(_), I = Le(_);
                V0(_, 22), f7(_) && ue(_, [0, I, 21]);
                var U = u(ve[7], _), Y = x(0, 0, _);
                if (Y[0] === 0)
                  var D0 = U, A0 = Y[1];
                else
                  var y0 = function(D, u0) {
                    return a(Qe(D, Li, 91), D, u0);
                  }, D0 = a(Y[1][2], U, y0), A0 = 0;
                return [30, [0, D0, lr([0, k], [0, A0], 0)]];
              }
              var S0 = 0;
              function T0(_) {
                return cr(S0, l0, _);
              }
              function er(_) {
                var k = pr(_);
                V0(_, 23);
                var I = u(ve[15], _);
                if (N0(_) === 34)
                  var U = $t(_), Y = function(sr, Pr) {
                    var K0 = Pr[1];
                    return [0, K0, ir(Qe(sr, V8, 29), sr, K0, Pr[2])];
                  }, y0 = a(U[2], I, Y);
                else
                  var y0 = I;
                var D0 = N0(_), A0 = 0;
                if (typeof D0 == "number" && D0 === 34) {
                  var D = [0, cr(0, function(Pr) {
                    var K0 = pr(Pr);
                    V0(Pr, 34);
                    var Ur = we(Pr), d0 = N0(Pr) === 4 ? 1 : 0;
                    if (d0) {
                      V0(Pr, 4);
                      var Kr = [0, a(ve[18], Pr, 39)];
                      V0(Pr, 5);
                      var re = Kr;
                    } else
                      var re = d0;
                    var xe = u(ve[15], Pr);
                    if (N0(Pr) === 38)
                      var Ie = xe;
                    else
                      var je = c(Pr), le = function(Me, Be) {
                        var an = Be[1];
                        return [0, an, ir(Qe(Me, V8, 92), Me, an, Be[2])];
                      }, Ie = a(je[2], xe, le);
                    return [0, re, Ie, lr([0, K0], [0, Ur], 0)];
                  }, _)];
                  A0 = 1;
                }
                if (!A0)
                  var D = 0;
                var u0 = N0(_), Y0 = 0;
                if (typeof u0 == "number" && u0 === 38) {
                  V0(_, 38);
                  var J0 = u(ve[15], _), fr = J0[1], Q0 = c(_), F0 = function(Pr, K0) {
                    return ir(Qe(Pr, V8, 93), Pr, fr, K0);
                  }, gr = [0, [0, fr, a(Q0[2], J0[2], F0)]];
                  Y0 = 1;
                }
                if (!Y0)
                  var gr = 0;
                var mr = D === 0 ? 1 : 0, Cr = mr && (gr === 0 ? 1 : 0);
                return Cr && ue(_, [0, y0[1], 33]), [31, [0, y0, D, gr, lr([0, k], 0, 0)]];
              }
              var j0 = 0;
              function B(_) {
                return cr(j0, er, _);
              }
              function Z(_) {
                var k = u(zn[9], _), I = s(0, _, k[1]), U = 0, Y = k[3];
                Cu(function(D0) {
                  return ue(_, D0);
                }, Y);
                var y0 = lr([0, k[2]], [0, I[1]], 0);
                return [34, [0, I[2], U, y0]];
              }
              var p0 = 0;
              function b0(_) {
                return cr(p0, Z, _);
              }
              function O0(_) {
                var k = u(zn[8], _), I = s(2, _, k[1]), U = 2, Y = k[3];
                Cu(function(D0) {
                  return ue(_, D0);
                }, Y);
                var y0 = lr([0, k[2]], [0, I[1]], 0);
                return [34, [0, I[2], U, y0]];
              }
              var q0 = 0;
              function nr(_) {
                return cr(q0, O0, _);
              }
              function yr(_) {
                var k = u(zn[7], _), I = s(1, _, k[1]), U = 1, Y = k[3];
                Cu(function(D0) {
                  return ue(_, D0);
                }, Y);
                var y0 = lr([0, k[2]], [0, I[1]], 0);
                return [34, [0, I[2], U, y0]];
              }
              var vr = 0;
              function $0(_) {
                return cr(vr, yr, _);
              }
              function Sr(_) {
                var k = pr(_);
                V0(_, 25);
                var I = xn(k, pr(_));
                V0(_, 4);
                var U = u(ve[7], _);
                V0(_, 5);
                var Y = zl(1, _), y0 = u(ve[2], Y), D0 = 1 - _[5], A0 = D0 && nb(y0);
                return A0 && B1(_, y0[1]), [35, [0, U, y0, lr([0, I], 0, 0)]];
              }
              var Mr = 0;
              function Br(_) {
                return cr(Mr, Sr, _);
              }
              function qr(_) {
                var k = pr(_), I = u(ve[7], _), U = N0(_), Y = I[2];
                if (Y[0] === 10 && typeof U == "number" && U === 86) {
                  var y0 = Y[1], D0 = y0[2][1];
                  V0(_, 86), a(ju[3], D0, _[3]) && ue(_, [0, I[1], [16, ire, D0]]);
                  var A0 = _[30], D = _[29], u0 = _[28], Y0 = _[27], J0 = _[26], fr = _[25], Q0 = _[24], F0 = _[23], gr = _[22], mr = _[21], Cr = _[20], sr = _[19], Pr = _[18], K0 = _[17], Ur = _[16], d0 = _[15], Kr = _[14], re = _[13], xe = _[12], je = _[11], le = _[10], Ie = _[9], Me = _[8], Be = _[7], an = _[6], Ke = _[5], Ae = _[4], on = a(ju[4], D0, _[3]), rn = [0, _[1], _[2], on, Ae, Ke, an, Be, Me, Ie, le, je, xe, re, Kr, d0, Ur, K0, Pr, sr, Cr, mr, gr, F0, Q0, fr, J0, Y0, u0, D, A0], kn = qs(rn) ? n(rn) : u(ve[2], rn);
                  return [27, [0, y0, kn, lr([0, k], 0, 0)]];
                }
                var sn = x(fre, 0, _);
                if (sn[0] === 0)
                  var We = I, en = sn[1];
                else
                  var Pe = function(_n, Dn) {
                    return a(Qe(_n, Li, 94), _n, Dn);
                  }, We = a(sn[1][2], I, Pe), en = 0;
                return [19, [0, We, 0, lr(0, [0, en], 0)]];
              }
              var jr = 0;
              function $r(_) {
                return cr(jr, qr, _);
              }
              function ne(_) {
                var k = u(ve[7], _), I = x(ure, 0, _);
                if (I[0] === 0)
                  var Y = k, y0 = I[1];
                else
                  var U = function(sr, Pr) {
                    return a(Qe(sr, Li, 95), sr, Pr);
                  }, Y = a(I[1][2], k, U), y0 = 0;
                var D0 = _[19];
                if (D0) {
                  var A0 = Y[2], D = 0;
                  if (A0[0] === 14) {
                    var u0 = A0[1], Y0 = 0, J0 = u0[1];
                    if (typeof J0 != "number" && J0[0] === 0) {
                      var fr = u0[2], Q0 = 1 < tn(fr) ? 1 : 0;
                      if (Q0)
                        var F0 = At(fr, tn(fr) - 1 | 0), gr = At(fr, 0) === F0 ? 1 : 0;
                      else
                        var gr = Q0;
                      var mr = gr && [0, m7(fr, 1, tn(fr) - 2 | 0)], Cr = mr;
                      Y0 = 1;
                    }
                    Y0 || (D = 1);
                  } else
                    D = 1;
                  if (D)
                    var Cr = 0;
                } else
                  var Cr = D0;
                return [19, [0, Y, Cr, lr(0, [0, y0], 0)]];
              }
              var Qr = 0;
              function pe(_) {
                return cr(Qr, ne, _);
              }
              function oe(_) {
                var k = N0(_), I = 0;
                if (typeof k != "number" && k[0] === 4 && !n0(k[3], rre)) {
                  ie(_);
                  var U = N0(_);
                  if (typeof U != "number" && U[0] === 2)
                    return i(_, U[1]);
                  Ft(ere, _), I = 1;
                }
                return I || Ft(nre, _), [0, G1(_), tre];
              }
              function me(_, k, I) {
                function U(D) {
                  return _ ? u(mn[2], D) : a(ve[13], 0, D);
                }
                var Y = Vn(1, I);
                if (typeof Y == "number")
                  switch (Y) {
                    case 1:
                    case 9:
                    case 113:
                      return [0, U(I), 0];
                  }
                else if (Y[0] === 4 && !n0(Y[3], Q0e)) {
                  var y0 = z7(I);
                  return ie(I), [0, y0, [0, U(I)]];
                }
                var D0 = N0(I);
                if (k && typeof D0 == "number") {
                  var A0 = 0;
                  if ((D0 === 46 || D0 === 61) && (A0 = 1), A0)
                    return Ge(I, k[1]), ie(I), [0, u(mn[2], I), 0];
                }
                return [0, U(I), 0];
              }
              function ae(_, k) {
                var I = N0(_);
                if (typeof I == "number" && Vt === I) {
                  var U = cr(0, function(Ae) {
                    ie(Ae);
                    var on = N0(Ae);
                    return typeof on != "number" && on[0] === 4 && !n0(on[3], $0e) ? (ie(Ae), 2 <= k ? [0, a(ve[13], 0, Ae)] : [0, u(mn[2], Ae)]) : (Ft(Z0e, Ae), 0);
                  }, _), Y = U[2], y0 = Y && [0, [0, U[1], Y[1]]], D0 = y0 && [0, [1, y0[1]]];
                  return D0;
                }
                V0(_, 0);
                for (var A0 = 0, D = 0; ; ) {
                  var u0 = A0 ? A0[1] : 1, Y0 = N0(_);
                  if (typeof Y0 == "number") {
                    var J0 = 0;
                    if ((Y0 === 1 || Ln === Y0) && (J0 = 1), J0) {
                      var fr = de(D);
                      return V0(_, 1), [0, [0, fr]];
                    }
                  }
                  if (1 - u0 && Ge(_, 84), k === 2) {
                    var Q0 = N0(_), F0 = 0;
                    if (typeof Q0 == "number")
                      if (Q0 === 46)
                        var gr = z0e;
                      else if (Q0 === 61)
                        var gr = V0e;
                      else
                        F0 = 1;
                    else
                      F0 = 1;
                    if (F0)
                      var gr = 0;
                    var mr = N0(_), Cr = 0;
                    if (typeof mr == "number") {
                      var sr = 0;
                      if (mr !== 46 && mr !== 61 && (sr = 1), !sr) {
                        var Pr = 1;
                        Cr = 1;
                      }
                    }
                    if (!Cr)
                      var Pr = 0;
                    if (Pr) {
                      var K0 = z7(_), Ur = N0(_), d0 = 0;
                      if (typeof Ur == "number")
                        switch (Ur) {
                          case 1:
                          case 9:
                          case 113:
                            e(0, _, K0);
                            var Ie = [0, 0, 0, K0];
                            d0 = 1;
                            break;
                        }
                      else if (Ur[0] === 4 && !n0(Ur[3], K0e)) {
                        var Kr = Vn(1, _), re = 0;
                        if (typeof Kr == "number")
                          switch (Kr) {
                            case 1:
                            case 9:
                            case 113:
                              var xe = [0, gr, 0, u(mn[2], _)];
                              re = 1;
                              break;
                          }
                        else if (Kr[0] === 4 && !n0(Kr[3], W0e)) {
                          var je = z7(_);
                          ie(_);
                          var xe = [0, gr, [0, u(mn[2], _)], je];
                          re = 1;
                        }
                        if (!re) {
                          e(0, _, K0), ie(_);
                          var xe = [0, 0, [0, a(ve[13], 0, _)], K0];
                        }
                        var Ie = xe;
                        d0 = 1;
                      }
                      if (!d0)
                        var le = me(1, 0, _), Ie = [0, gr, le[2], le[1]];
                      var Be = Ie;
                    } else
                      var Me = me(0, 0, _), Be = [0, 0, Me[2], Me[1]];
                    var Ke = Be;
                  } else
                    var an = me(1, Y0e, _), Ke = [0, 0, an[2], an[1]];
                  var A0 = [0, fu(_, 9)], D = [0, Ke, D];
                }
              }
              function ce(_, k) {
                var I = x(0, 0, _);
                if (I[0] === 0)
                  return [0, I[1], k];
                function U(Y, y0) {
                  var D0 = y0[1];
                  return [0, D0, ir(Qe(Y, wA, 96), Y, D0, y0[2])];
                }
                return [0, 0, a(I[1][2], k, U)];
              }
              function ge(_) {
                var k = ys(1, _), I = pr(k);
                V0(k, 50);
                var U = N0(k), Y = 0;
                if (typeof U == "number")
                  switch (U) {
                    case 46:
                      if (iu(k)) {
                        V0(k, 46);
                        var y0 = N0(k), D0 = 0;
                        if (typeof y0 == "number") {
                          var A0 = 0;
                          if (Vt !== y0 && y0 && (A0 = 1), !A0) {
                            var J0 = 1;
                            Y = 2, D0 = 1;
                          }
                        }
                        if (!D0) {
                          var D = 1;
                          Y = 1;
                        }
                      }
                      break;
                    case 61:
                      if (iu(k)) {
                        var u0 = Vn(1, k), Y0 = 0;
                        if (typeof u0 == "number")
                          switch (u0) {
                            case 0:
                              ie(k);
                              var J0 = 0;
                              Y = 2, Y0 = 2;
                              break;
                            case 106:
                              ie(k), Ft(0, k);
                              var J0 = 0;
                              Y = 2, Y0 = 2;
                              break;
                            case 9:
                              Y0 = 1;
                              break;
                          }
                        else
                          u0[0] === 4 && !n0(u0[3], J0e) && (Y0 = 1);
                        switch (Y0) {
                          case 2:
                            break;
                          case 0:
                            ie(k);
                            var D = 0;
                            Y = 1;
                            break;
                          default:
                            var D = 2;
                            Y = 1;
                        }
                      }
                      break;
                    case 0:
                    case 106:
                      var J0 = 2;
                      Y = 2;
                      break;
                  }
                else if (U[0] === 2) {
                  var fr = ce(k, i(k, U[1])), Q0 = lr([0, I], [0, fr[1]], 0);
                  return [25, [0, 2, fr[2], 0, 0, Q0]];
                }
                switch (Y) {
                  case 0:
                    var D = 2;
                    break;
                  case 1:
                    break;
                  default:
                    var F0 = ae(k, J0), gr = ce(k, oe(k)), mr = lr([0, I], [0, gr[1]], 0);
                    return [25, [0, J0, gr[2], 0, F0, mr]];
                }
                var Cr = 2 <= D ? a(ve[13], 0, k) : u(mn[2], k), sr = N0(k), Pr = 0;
                if (typeof sr == "number" && sr === 9) {
                  V0(k, 9);
                  var K0 = ae(k, D);
                  Pr = 1;
                }
                if (!Pr)
                  var K0 = 0;
                var Ur = ce(k, oe(k)), d0 = lr([0, I], [0, Ur[1]], 0);
                return [25, [0, D, Ur[2], [0, Cr], K0, d0]];
              }
              var H0 = 0;
              function Fr(_) {
                return cr(H0, ge, _);
              }
              return N(p, function(_) {
                var k = Le(_), I = pr(_);
                return V0(_, 8), [0, k, [15, [0, lr([0, I], [0, c(_)[1]], 0)]]];
              }), N(y, function(_) {
                var k = pr(_), I = cr(0, function(Y0) {
                  V0(Y0, 32);
                  var J0 = 0;
                  if (N0(Y0) !== 8 && !x2(Y0)) {
                    var fr = a(ve[13], 0, Y0), Q0 = fr[2][1];
                    1 - a(ju[3], Q0, Y0[3]) && Ge(Y0, [15, Q0]);
                    var F0 = [0, fr];
                    J0 = 1;
                  }
                  if (!J0)
                    var F0 = 0;
                  var gr = x(0, 0, Y0), mr = 0;
                  if (gr[0] === 0)
                    var Cr = gr[1];
                  else {
                    var sr = gr[1];
                    if (F0) {
                      var Pr = function(xe, je) {
                        return a(Qe(xe, Nv, 97), xe, je);
                      }, K0 = [0, a(sr[2], F0[1], Pr)], Ur = 0;
                      mr = 1;
                    } else
                      var Cr = sr[1];
                  }
                  if (!mr)
                    var K0 = F0, Ur = Cr;
                  return [0, K0, Ur];
                }, _), U = I[2], Y = U[1], y0 = I[1], D0 = Y === 0 ? 1 : 0;
                if (D0)
                  var A0 = _[8], D = A0 || _[9], u0 = 1 - D;
                else
                  var u0 = D0;
                return u0 && ue(_, [0, y0, 35]), [0, y0, [1, [0, Y, lr([0, k], [0, U[2]], 0)]]];
              }), N(T, function(_) {
                var k = pr(_), I = cr(0, function(D0) {
                  V0(D0, 35);
                  var A0 = 0;
                  if (N0(D0) !== 8 && !x2(D0)) {
                    var D = a(ve[13], 0, D0), u0 = D[2][1];
                    1 - a(ju[3], u0, D0[3]) && Ge(D0, [15, u0]);
                    var Y0 = [0, D];
                    A0 = 1;
                  }
                  if (!A0)
                    var Y0 = 0;
                  var J0 = x(0, 0, D0), fr = 0;
                  if (J0[0] === 0)
                    var Q0 = J0[1];
                  else {
                    var F0 = J0[1];
                    if (Y0) {
                      var gr = function(Ur, d0) {
                        return a(Qe(Ur, Nv, 98), Ur, d0);
                      }, mr = [0, a(F0[2], Y0[1], gr)], Cr = 0;
                      fr = 1;
                    } else
                      var Q0 = F0[1];
                  }
                  if (!fr)
                    var mr = Y0, Cr = Q0;
                  return [0, mr, Cr];
                }, _), U = I[2], Y = I[1];
                1 - _[8] && ue(_, [0, Y, 34]);
                var y0 = lr([0, k], [0, U[2]], 0);
                return [0, Y, [3, [0, U[1], y0]]];
              }), N(E, function(_) {
                var k = cr(0, function(U) {
                  var Y = pr(U);
                  V0(U, 26);
                  var y0 = xn(Y, pr(U));
                  V0(U, 4);
                  var D0 = u(ve[7], U);
                  V0(U, 5);
                  var A0 = u(ve[2], U), D = 1 - U[5], u0 = D && nb(A0);
                  return u0 && B1(U, A0[1]), [36, [0, D0, A0, lr([0, y0], 0, 0)]];
                }, _), I = k[1];
                return V7(_, [0, I, 38]), [0, I, k[2]];
              }), N(h, function(_) {
                var k = u(ve[15], _), I = k[1], U = c(_);
                function Y(y0, D0) {
                  return ir(Qe(y0, V8, 99), y0, I, D0);
                }
                return [0, I, [0, a(U[2], k[2], Y)]];
              }), N(w, function(_, k) {
                1 - iu(k) && Ge(k, 10);
                var I = xn(_, pr(k));
                V0(k, 61), zu(k, 1);
                var U = u(mn[2], k), Y = N0(k) === 98 ? ds(k, U) : U, y0 = u(mn[3], k);
                V0(k, 82);
                var D0 = u(mn[1], k);
                k7(k);
                var A0 = x(0, 0, k);
                if (A0[0] === 0)
                  var u0 = D0, Y0 = A0[1];
                else
                  var D = function(J0, fr) {
                    return a(Qe(J0, _v, ti), J0, fr);
                  }, u0 = a(A0[1][2], D0, D), Y0 = 0;
                return [0, Y, y0, u0, lr([0, I], [0, Y0], 0)];
              }), N(G, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  return V0(k, 60), [11, a(w, I, k)];
                }, _);
              }), N(A, function(_) {
                if (A9(1, _) && !me0(1, _)) {
                  var k = cr(0, u(w, 0), _);
                  return [0, k[1], [32, k[2]]];
                }
                return u(ve[2], _);
              }), N(S, function(_, k, I) {
                var U = _ && _[1];
                1 - iu(I) && Ge(I, 11);
                var Y = xn(k, pr(I));
                V0(I, 62);
                var y0 = pr(I);
                V0(I, 61);
                var D0 = xn(Y, y0);
                zu(I, 1);
                var A0 = u(mn[2], I), D = N0(I) === 98 ? ds(I, A0) : A0, u0 = u(mn[3], I), Y0 = N0(I), J0 = 0;
                if (typeof Y0 == "number" && Y0 === 86) {
                  V0(I, 86);
                  var fr = [0, u(mn[1], I)];
                  J0 = 1;
                }
                if (!J0)
                  var fr = 0;
                if (U) {
                  var Q0 = N0(I), F0 = 0;
                  if (typeof Q0 == "number" && Q0 === 82) {
                    Ge(I, 70), ie(I);
                    var gr = 0;
                    if (N0(I) !== 8 && !x2(I)) {
                      var mr = [0, u(mn[1], I)];
                      gr = 1;
                    }
                    if (!gr)
                      var mr = 0;
                  } else
                    F0 = 1;
                  if (F0)
                    var mr = 0;
                  var Cr = mr;
                } else {
                  V0(I, 82);
                  var Cr = [0, u(mn[1], I)];
                }
                k7(I);
                var sr = x(0, 0, I);
                if (sr[0] === 0)
                  var Pr = Cr, K0 = fr, Ur = u0, d0 = D, Kr = sr[1];
                else {
                  var re = sr[1][2];
                  if (Cr)
                    var xe = function(en, _n) {
                      return a(Qe(en, _v, R7), en, _n);
                    }, Pr = [0, a(re, Cr[1], xe)], K0 = fr, Ur = u0, d0 = D, Kr = 0;
                  else if (fr)
                    var je = 0, le = function(en, _n) {
                      return a(Qe(en, _v, ji), en, _n);
                    }, Pr = je, K0 = [0, a(re, fr[1], le)], Ur = u0, d0 = D, Kr = 0;
                  else if (u0)
                    var Ie = 0, Me = 0, Be = function(en, _n) {
                      return a(Qe(en, _F, s7), en, _n);
                    }, Pr = Ie, K0 = Me, Ur = [0, a(re, u0[1], Be)], d0 = D, Kr = 0;
                  else
                    var an = 0, Ke = 0, Ae = 0, Pr = an, K0 = Ke, Ur = Ae, on = 0, d0 = a(re, D, function(en, _n) {
                      return a(Qe(en, Nv, L7), en, _n);
                    }), Kr = on;
                }
                return [0, d0, Ur, Pr, K0, lr([0, D0], [0, Kr], 0)];
              }), N(M, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  return V0(k, 60), [12, ir(S, X0e, I, k)];
                }, _);
              }), N(K, function(_) {
                var k = Vn(1, _);
                if (typeof k == "number" && k === 61) {
                  var I = cr(0, a(S, H0e, 0), _);
                  return [0, I[1], [33, I[2]]];
                }
                return u(ve[2], _);
              }), N(V, function(_, k) {
                1 - iu(k) && Ge(k, 16);
                var I = xn(_, pr(k));
                V0(k, 53);
                var U = u(mn[2], k), Y = N0(k) === 41 ? U : ds(k, U), y0 = u(mn[3], k), D0 = N0(k) === 41 ? y0 : ai(k, y0), A0 = u(mn[7], k), D = c(k);
                function u0(fr, Q0) {
                  var F0 = Q0[1];
                  return [0, F0, ir(Qe(fr, VH, j7), fr, F0, Q0[2])];
                }
                var Y0 = a(D[2], A0[2], u0), J0 = lr([0, I], 0, 0);
                return [0, Y, D0, A0[1], Y0, J0];
              }), N(f0, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  return V0(k, 60), [8, a(V, I, k)];
                }, _);
              }), N(m0, function(_) {
                var k = A9(1, _), I = 1, U = k || _e0(I, _);
                if (U) {
                  var Y = cr(0, u(V, 0), _);
                  return [0, Y[1], [26, Y[2]]];
                }
                return pe(_);
              }), N(k0, function(_, k) {
                var I = ys(1, k), U = xn(_, pr(I));
                V0(I, 40);
                var Y = a(ve[13], 0, I), y0 = N0(I), D0 = 0;
                if (typeof y0 == "number") {
                  var A0 = 0;
                  if (y0 !== 98 && y0 && (A0 = 1), !A0) {
                    var D = ds(I, Y);
                    D0 = 1;
                  }
                }
                if (!D0)
                  var D = Y;
                var u0 = u(mn[3], I), Y0 = N0(I), J0 = 0;
                if (typeof Y0 == "number" && !Y0) {
                  var fr = ai(I, u0);
                  J0 = 1;
                }
                if (!J0)
                  var fr = u0;
                var Q0 = fu(I, 41);
                if (Q0) {
                  var F0 = u(mn[5], I), gr = N0(I), mr = 0;
                  if (typeof gr == "number" && !gr) {
                    var Cr = $t(I), sr = function(On, bt) {
                      return pu(u(Qe(On, tH, 36), On), bt);
                    }, Pr = [0, a(Cr[2], F0, sr)];
                    mr = 1;
                  }
                  if (!mr)
                    var Pr = [0, F0];
                  var K0 = Pr;
                } else
                  var K0 = Q0;
                var Ur = N0(I), d0 = 0;
                if (typeof Ur != "number" && Ur[0] === 4 && !n0(Ur[3], U0e)) {
                  ie(I);
                  for (var Kr = 0; ; ) {
                    var re = [0, u(mn[5], I), Kr], xe = N0(I);
                    if (typeof xe == "number" && xe === 9) {
                      V0(I, 9);
                      var Kr = re;
                      continue;
                    }
                    var je = de(re), le = N0(I), Ie = 0;
                    if (typeof le == "number" && !le) {
                      var Me = ge0(I, je);
                      Ie = 1;
                    }
                    if (!Ie)
                      var Me = je;
                    var Be = Me;
                    d0 = 1;
                    break;
                  }
                }
                if (!d0)
                  var Be = 0;
                var an = N0(I), Ke = 0;
                if (typeof an == "number" && an === 52) {
                  var Ae = a(Ys[5], I, 0), on = N0(I), rn = 0;
                  if (typeof on == "number" && !on) {
                    var kn = [0, Fe0(I, Ae)];
                    rn = 1;
                  }
                  if (!rn)
                    var kn = [0, Ae];
                  var sn = kn;
                  Ke = 1;
                }
                if (!Ke)
                  var sn = 0;
                var Pe = a(mn[6], 1, I), We = c(I);
                function en(Dn, Xn) {
                  var On = Xn[1];
                  return [0, On, ir(Qe(Dn, VH, Vt), Dn, On, Xn[2])];
                }
                var _n = a(We[2], Pe, en);
                return [0, D, fr, _n, K0, Be, sn, lr([0, U], 0, 0)];
              }), N(g0, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  return V0(k, 60), [5, a(k0, I, k)];
                }, _);
              }), N(e0, function(_, k) {
                var I = _ && _[1], U = xn(I, pr(k));
                V0(k, 15);
                var Y = ds(k, a(ve[13], 0, k)), y0 = cr(0, function(mr) {
                  var Cr = ai(mr, u(mn[3], mr)), sr = u(mn[8], mr);
                  V0(mr, 86);
                  var Pr = u(mn[1], mr);
                  zu(mr, 1);
                  var K0 = N0(mr);
                  if (k7(mr), K0 === 66)
                    var Ur = $t(mr), d0 = function(re, xe) {
                      return a(Qe(re, _v, 31), re, xe);
                    }, Kr = a(Ur[2], Pr, d0);
                  else
                    var Kr = Pr;
                  return [12, [0, Cr, sr, Kr, 0]];
                }, k), D0 = u(mn[11], k), A0 = x(0, 0, k);
                if (A0[0] === 0)
                  var D = D0, u0 = y0, Y0 = A0[1];
                else {
                  var J0 = A0[1][2];
                  if (D0)
                    var fr = function(Pr, K0) {
                      return a(Qe(Pr, FH, Qc), Pr, K0);
                    }, D = [0, a(J0, D0[1], fr)], u0 = y0, Y0 = 0;
                  else
                    var Q0 = 0, D = Q0, F0 = 0, u0 = a(J0, y0, function(Pr, K0) {
                      return a(Qe(Pr, _v, fs2), Pr, K0);
                    }), Y0 = F0;
                }
                var gr = [0, u0[1], u0];
                return [0, Y, gr, D, lr([0, U], [0, Y0], 0)];
              }), N(x0, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  V0(k, 60);
                  var U = N0(k), Y = 0;
                  return typeof U == "number" && U === 64 && (Ge(k, 67), V0(k, 64), Y = 1), [7, a(e0, [0, I], k)];
                }, _);
              }), N(l, function(_, k) {
                var I = xn(k, pr(_));
                V0(_, 24);
                var U = a(ve[13], q0e, _), Y = u(mn[9], _), y0 = x(0, 0, _);
                if (y0[0] === 0)
                  var A0 = Y, D = y0[1];
                else
                  var D0 = function(u0, Y0) {
                    return a(Qe(u0, NE, Fv), u0, Y0);
                  }, A0 = a(y0[1][2], Y, D0), D = 0;
                return [0, U, A0, lr([0, I], [0, D], 0)];
              }), N(c0, function(_) {
                return cr(0, function(k) {
                  var I = pr(k);
                  return V0(k, 60), [13, a(l, k, I)];
                }, _);
              }), N(t0, function(_, k) {
                var I = Le(k), U = pr(k);
                V0(k, 60);
                var Y = xn(U, pr(k));
                return Zl(k, B0e), !_ && N0(k) !== 10 ? cr([0, I], function(y0) {
                  var D0 = N0(y0), A0 = 0;
                  if (typeof D0 != "number" && D0[0] === 2) {
                    var D = i(y0, D0[1]), u0 = $t(y0), Y0 = function(Cr, sr) {
                      var Pr = sr[1];
                      return [0, Pr, ir(Qe(Cr, wA, 39), Cr, Pr, sr[2])];
                    }, J0 = [1, a(u0[2], D, Y0)];
                    A0 = 1;
                  }
                  if (!A0)
                    var J0 = [0, ds(y0, a(ve[13], 0, y0))];
                  var fr = OL(0, function(mr) {
                    var Cr = pr(mr);
                    V0(mr, 0);
                    for (var sr = 0, Pr = 0; ; ) {
                      var K0 = N0(mr);
                      if (typeof K0 == "number") {
                        var Ur = 0;
                        if ((K0 === 1 || Ln === K0) && (Ur = 1), Ur) {
                          var d0 = de(Pr), Kr = d0 === 0 ? 1 : 0, re = Kr && pr(mr);
                          return V0(mr, 1), [0, [0, d0, mu([0, Cr], [0, c(mr)[1]], re, 0)], sr];
                        }
                      }
                      var xe = a(w0, j0e, mr), je = xe[2], le = 0;
                      if (sr)
                        if (sr[1])
                          if (je[0] === 10) {
                            Ge(mr, 79);
                            var Ae = sr;
                          } else
                            le = 1;
                        else
                          switch (je[0]) {
                            case 6:
                              var Ie = je[1][2], Me = 0;
                              if (Ie)
                                switch (Ie[1][0]) {
                                  case 4:
                                  case 6:
                                    Me = 1;
                                    break;
                                }
                              Me || Ge(mr, 79);
                              var Ae = sr;
                              break;
                            case 10:
                              Ge(mr, 78);
                              var Ae = sr;
                              break;
                            default:
                              le = 1;
                          }
                      else
                        switch (je[0]) {
                          case 6:
                            var Be = je[1][2], an = 0;
                            if (Be)
                              switch (Be[1][0]) {
                                case 4:
                                case 6:
                                  var Ke = sr;
                                  an = 1;
                                  break;
                              }
                            if (!an)
                              var Ke = G0e;
                            var Ae = Ke;
                            break;
                          case 10:
                            var Ae = M0e;
                            break;
                          default:
                            le = 1;
                        }
                      if (le)
                        var Ae = sr;
                      var sr = Ae, Pr = [0, xe, Pr];
                    }
                  }, y0), Q0 = fr[2], F0 = Q0 && Q0[1], gr = lr([0, Y], 0, 0);
                  return [9, [0, J0, fr[1], F0, gr]];
                }, k) : cr([0, I], u(a0, Y), k);
              }), N(a0, function(_, k) {
                var I = pr(k);
                V0(k, 10);
                var U = pr(k);
                Zl(k, R0e);
                var Y = pl([0, _, [0, I, [0, U, [0, pr(k), 0]]]]), y0 = u(mn[9], k), D0 = x(0, 0, k);
                if (D0[0] === 0)
                  var u0 = D0[1], Y0 = y0;
                else
                  var A0 = 0, D = function(J0, fr) {
                    return a(Qe(J0, NE, Yt), J0, fr);
                  }, u0 = A0, Y0 = a(D0[1][2], y0, D);
                return [10, [0, Y0, lr([0, Y], [0, u0], 0)]];
              }), N(w0, function(_, k) {
                var I = _ && _[1];
                1 - iu(k) && Ge(k, 13);
                var U = Vn(1, k);
                if (typeof U == "number")
                  switch (U) {
                    case 24:
                      return u(c0, k);
                    case 40:
                      return u(g0, k);
                    case 46:
                      if (N0(k) === 50)
                        return Fr(k);
                      break;
                    case 49:
                      if (I)
                        return a(X, [0, I], k);
                      break;
                    case 53:
                      return u(f0, k);
                    case 61:
                      var Y = N0(k);
                      return typeof Y == "number" && Y === 50 && I ? Fr(k) : u(G, k);
                    case 62:
                      return u(M, k);
                    case 15:
                    case 64:
                      return u(x0, k);
                  }
                else if (U[0] === 4 && !n0(U[3], L0e))
                  return a(t0, I, k);
                if (I) {
                  var y0 = N0(k);
                  return typeof y0 == "number" && y0 === 50 ? (Ge(k, 82), u(ve[2], k)) : u(c0, k);
                }
                return u(ve[2], k);
              }), N(_0, function(_) {
                Zl(_, C0e);
                var k = N0(_);
                if (typeof k != "number" && k[0] === 2)
                  return i(_, k[1]);
                var I = [0, Le(_), P0e];
                return Ft(D0e, _), I;
              }), N(E0, function(_) {
                var k = u(_0, _), I = k[2], U = k[1], Y = x(0, 0, _);
                if (Y[0] === 0)
                  return [0, [0, U, I], Y[1]];
                var y0 = 0;
                function D0(A0, D) {
                  return ir(Qe(A0, wA, vf), A0, U, D);
                }
                return [0, [0, U, a(Y[1][2], I, D0)], y0];
              }), N(X0, function(_, k, I) {
                var U = _ ? _[1] : 1, Y = N0(k);
                if (typeof Y == "number") {
                  var y0 = 0;
                  if ((Y === 1 || Ln === Y) && (y0 = 1), y0)
                    return de(I);
                }
                1 - U && Ge(k, 85);
                var D0 = cr(0, function(A0) {
                  var D = z7(A0), u0 = N0(A0), Y0 = 0;
                  if (typeof u0 != "number" && u0[0] === 4 && !n0(u0[3], N0e)) {
                    ie(A0);
                    var J0 = [0, z7(A0)];
                    Y0 = 1;
                  }
                  if (!Y0)
                    var J0 = 0;
                  return [0, D, J0];
                }, k);
                return ir(X0, [0, fu(k, 9)], k, [0, D0, I]);
              }), N(b, function(_, k) {
                return Cu(function(I) {
                  var U = I[2];
                  return U[2] ? 0 : e(A0e, _, U[1]);
                }, k);
              }), N(G0, function(_, k) {
                var I = xe0(1, ys(1, k)), U = pr(I), Y = Le(I);
                V0(I, 49);
                var y0 = N0(I);
                if (typeof y0 == "number") {
                  if (53 <= y0) {
                    if (!(63 <= y0))
                      switch (y0 + pU | 0) {
                        case 0:
                          return cr([0, Y], function(D) {
                            1 - iu(D) && Ge(D, 15);
                            var u0 = cr(0, u(V, 0), D), Y0 = [0, u0[1], [26, u0[2]]];
                            return [18, [0, [0, Y0], 0, 0, 0, lr([0, U], 0, 0)]];
                          }, I);
                        case 8:
                          if (Vn(1, I) !== 0)
                            return cr([0, Y], function(D) {
                              1 - iu(D) && Ge(D, 15);
                              var u0 = Vn(1, D);
                              if (typeof u0 == "number") {
                                if (u0 === 48)
                                  return Ge(D, 0), V0(D, 61), [18, [0, 0, 0, 0, 0, lr([0, U], 0, 0)]];
                                if (Vt === u0) {
                                  V0(D, 61);
                                  var Y0 = Le(D);
                                  V0(D, Vt);
                                  var J0 = u(E0, D), fr = lr([0, U], [0, J0[2]], 0);
                                  return [18, [0, 0, [0, [1, [0, Y0, 0]]], [0, J0[1]], 0, fr]];
                                }
                              }
                              var Q0 = cr(0, u(w, 0), D), F0 = [0, Q0[1], [32, Q0[2]]];
                              return [18, [0, [0, F0], 0, 0, 0, lr([0, U], 0, 0)]];
                            }, I);
                          break;
                        case 9:
                          return cr([0, Y], function(D) {
                            var u0 = cr(0, function(J0) {
                              return u(a(S, 0, 0), J0);
                            }, D), Y0 = [0, u0[1], [33, u0[2]]];
                            return [18, [0, [0, Y0], 0, 0, 0, lr([0, U], 0, 0)]];
                          }, I);
                      }
                  } else if (y0 === 36)
                    return cr([0, Y], function(D) {
                      var u0 = xn(U, pr(D)), Y0 = cr(0, function(Ur) {
                        return V0(Ur, 36);
                      }, D), J0 = ae0(1, D);
                      if (qs(J0))
                        var fr = 0, Q0 = [0, u(zn[10], J0)];
                      else if ($l(J0))
                        var fr = 0, Q0 = [0, a(Ys[3], J0, _)];
                      else if (N0(J0) === 48)
                        var fr = 0, Q0 = [0, u(zn[11], J0)];
                      else {
                        var F0 = u(ve[10], J0), gr = x(0, 0, J0);
                        if (gr[0] === 0)
                          var sr = gr[1], Pr = F0;
                        else
                          var mr = 0, Cr = function(Kr, re) {
                            return a(Qe(Kr, Li, T7), Kr, re);
                          }, sr = mr, Pr = a(gr[1][2], F0, Cr);
                        var fr = sr, Q0 = [1, Pr];
                      }
                      var K0 = lr([0, u0], [0, fr], 0);
                      return [17, [0, Y0[1], Q0, K0]];
                    }, I);
                }
                if ($l(I))
                  return cr([0, Y], function(D) {
                    var u0 = a(Ys[3], D, _);
                    return [18, [0, [0, u0], 0, 0, 1, lr([0, U], 0, 0)]];
                  }, I);
                if (qs(I))
                  return cr([0, Y], function(D) {
                    u(N9(D), _);
                    var u0 = u(zn[10], D);
                    return [18, [0, [0, u0], 0, 0, 1, lr([0, U], 0, 0)]];
                  }, I);
                if (typeof y0 == "number")
                  if (29 <= y0) {
                    if (y0 === 48) {
                      if (I[27][1])
                        return cr([0, Y], function(D) {
                          var u0 = a(ve[3], [0, _], D);
                          return [18, [0, [0, u0], 0, 0, 1, lr([0, U], 0, 0)]];
                        }, I);
                    } else if (Vt === y0)
                      return cr([0, Y], function(D) {
                        var u0 = Le(D);
                        V0(D, Vt);
                        var Y0 = D[27][3], J0 = N0(D), fr = 0;
                        if (typeof J0 != "number" && J0[0] === 4 && !n0(J0[3], O0e)) {
                          ie(D);
                          var Q0 = Y0 ? [0, a(ve[13], 0, D)] : (Ge(D, 13), 0), F0 = Q0;
                          fr = 1;
                        }
                        if (!fr)
                          var F0 = 0;
                        var gr = u(E0, D), mr = lr([0, U], [0, gr[2]], 0);
                        return [18, [0, 0, [0, [1, [0, u0, F0]]], [0, gr[1]], 1, mr]];
                      }, I);
                  } else {
                    var D0 = 0;
                    if ((y0 === 24 || 27 <= y0) && (D0 = 1), D0)
                      return cr([0, Y], function(D) {
                        var u0 = a(ve[3], [0, _], D);
                        return [18, [0, [0, u0], 0, 0, 1, lr([0, U], 0, 0)]];
                      }, I);
                  }
                var A0 = fu(I, 61) ? 0 : 1;
                return fu(I, 0) ? cr([0, Y], function(D) {
                  var u0 = ir(X0, 0, D, 0);
                  V0(D, 1);
                  var Y0 = N0(D), J0 = 0;
                  if (typeof Y0 != "number" && Y0[0] === 4 && !n0(Y0[3], T0e)) {
                    var fr = u(E0, D), Q0 = fr[2], F0 = [0, fr[1]];
                    J0 = 1;
                  }
                  if (!J0) {
                    a(b, D, u0);
                    var gr = x(0, 0, D), mr = gr[0] === 0 ? gr[1] : gr[1][1], Q0 = mr, F0 = 0;
                  }
                  return [18, [0, 0, [0, [0, u0]], F0, A0, lr([0, U], [0, Q0], 0)]];
                }, I) : (Ft(I0e, I), a(ve[3], [0, _], I));
              }), N(X, function(_) {
                var k = _ && _[1];
                function I(Y) {
                  1 - iu(Y) && Ge(Y, 13);
                  var y0 = pr(Y);
                  V0(Y, 60);
                  var D0 = xe0(1, ys(1, Y)), A0 = xn(y0, pr(D0));
                  V0(D0, 49);
                  var D = N0(D0);
                  if (typeof D == "number")
                    if (53 <= D) {
                      if (Vt === D) {
                        var u0 = Le(D0);
                        V0(D0, Vt);
                        var Y0 = D0[27][3], J0 = N0(D0), fr = 0;
                        if (typeof J0 != "number" && J0[0] === 4 && !n0(J0[3], S0e)) {
                          ie(D0);
                          var Q0 = Y0 ? [0, a(ve[13], 0, D0)] : (Ge(D0, 13), 0), F0 = Q0;
                          fr = 1;
                        }
                        if (!fr)
                          var F0 = 0;
                        var gr = u(E0, D0), mr = lr([0, A0], [0, gr[2]], 0);
                        return [6, [0, 0, 0, [0, [1, [0, u0, F0]]], [0, gr[1]], mr]];
                      }
                      if (!(63 <= D))
                        switch (D + pU | 0) {
                          case 0:
                            if (k) {
                              var Cr = cr(0, u(V, 0), D0);
                              return [6, [0, 0, [0, [6, Cr]], 0, 0, lr([0, A0], 0, 0)]];
                            }
                            break;
                          case 8:
                            if (k) {
                              var sr = cr(0, u(w, 0), D0);
                              return [6, [0, 0, [0, [4, sr]], 0, 0, lr([0, A0], 0, 0)]];
                            }
                            break;
                          case 9:
                            var Pr = cr(0, a(S, E0e, 0), D0);
                            return [6, [0, 0, [0, [5, Pr]], 0, 0, lr([0, A0], 0, 0)]];
                        }
                    } else {
                      var K0 = D - 15 | 0;
                      if (!(25 < K0 >>> 0))
                        switch (K0) {
                          case 21:
                            var Ur = xn(A0, pr(D0)), d0 = cr(0, function(Pt) {
                              return V0(Pt, 36);
                            }, D0), Kr = ae0(1, D0), re = N0(Kr), xe = 0;
                            if (typeof re == "number")
                              if (re === 15)
                                var je = 0, le = je, Ie = [0, [1, cr(0, function(Pt) {
                                  return a(e0, 0, Pt);
                                }, Kr)]];
                              else if (re === 40)
                                var le = 0, Ie = [0, [2, cr(0, u(k0, 0), Kr)]];
                              else
                                xe = 1;
                            else
                              xe = 1;
                            if (xe) {
                              var Me = u(mn[1], Kr), Be = x(0, 0, Kr);
                              if (Be[0] === 0)
                                var Ae = Be[1], on = Me;
                              else
                                var an = 0, Ke = function(Ku, pt) {
                                  return a(Qe(Ku, _v, Ln), Ku, pt);
                                }, Ae = an, on = a(Be[1][2], Me, Ke);
                              var le = Ae, Ie = [0, [3, on]];
                            }
                            var rn = lr([0, Ur], [0, le], 0);
                            return [6, [0, [0, d0[1]], Ie, 0, 0, rn]];
                          case 0:
                          case 9:
                          case 12:
                          case 13:
                          case 25:
                            var kn = N0(D0);
                            if (typeof kn == "number") {
                              var sn = 0;
                              if (25 <= kn)
                                if (29 <= kn) {
                                  if (kn === 40) {
                                    var Pe = [0, [2, cr(0, u(k0, 0), D0)]];
                                    sn = 1;
                                  }
                                } else
                                  27 <= kn && (sn = 2);
                              else if (kn === 15) {
                                var Pe = [0, [1, cr(0, function(yu) {
                                  return a(e0, 0, yu);
                                }, D0)]];
                                sn = 1;
                              } else
                                24 <= kn && (sn = 2);
                              var We = 0;
                              switch (sn) {
                                case 0:
                                  break;
                                case 2:
                                  var en = 0;
                                  typeof kn == "number" ? kn === 27 ? Ge(D0, 72) : kn === 28 ? Ge(D0, 71) : en = 1 : en = 1;
                                  var Pe = [0, [0, cr(0, function(yu) {
                                    return a(l, yu, 0);
                                  }, D0)]];
                                  We = 1;
                                  break;
                                default:
                                  We = 1;
                              }
                              if (We)
                                return [6, [0, 0, Pe, 0, 0, lr([0, A0], 0, 0)]];
                            }
                            throw [0, Fn, F0e];
                        }
                    }
                  var _n = N0(D0), Dn = 0;
                  typeof _n == "number" ? _n === 53 ? Ge(D0, 74) : _n === 61 ? Ge(D0, 73) : Dn = 1 : Dn = 1, V0(D0, 0);
                  var Xn = ir(X0, 0, D0, 0);
                  V0(D0, 1);
                  var On = N0(D0), bt = 0;
                  if (typeof On != "number" && On[0] === 4 && !n0(On[3], g0e)) {
                    var Ct = u(E0, D0), Tt = Ct[2], Zt = [0, Ct[1]];
                    bt = 1;
                  }
                  if (!bt) {
                    a(b, D0, Xn);
                    var Ut = x(0, 0, D0), Ot = Ut[0] === 0 ? Ut[1] : Ut[1][1], Tt = Ot, Zt = 0;
                  }
                  return [6, [0, 0, 0, [0, [0, Xn]], Zt, lr([0, A0], [0, Tt], 0)]];
                }
                var U = 0;
                return function(Y) {
                  return cr(U, I, Y);
                };
              }), [0, Rr, Ir, $0, B, Br, E, h, y, T, Ar, w0, X, M, Lr, p, G0, pe, Fr, m0, $r, K, P, i0, T0, A, b0, nr];
            }(j9), He0 = function(t4) {
              var n = function y(T, E) {
                return y.fun(T, E);
              }, e = function y(T, E) {
                return y.fun(T, E);
              }, i = function y(T, E) {
                return y.fun(T, E);
              };
              N(n, function(y, T) {
                for (var E = T[2], h = E[2], w = o2(y), G = 0, A = E[1]; ; ) {
                  if (A) {
                    var S = A[1];
                    if (S[0] === 0) {
                      var M = S[1], K = M[2];
                      switch (K[0]) {
                        case 0:
                          var V = K[2], f0 = K[1];
                          switch (f0[0]) {
                            case 0:
                              var m0 = [0, f0[1]];
                              break;
                            case 1:
                              var m0 = [1, f0[1]];
                              break;
                            case 2:
                              var m0 = ke(k0e);
                              break;
                            default:
                              var m0 = [2, f0[1]];
                          }
                          var k0 = V[2], g0 = 0;
                          if (k0[0] === 2) {
                            var e0 = k0[1];
                            if (!e0[1]) {
                              var x0 = [0, e0[3]], l = e0[2];
                              g0 = 1;
                            }
                          }
                          if (!g0)
                            var x0 = 0, l = a(i, y, V);
                          var c0 = [0, [0, [0, M[1], [0, m0, l, x0, K[3]]]], G];
                          break;
                        case 1:
                          ue(y, [0, K[2][1], 97]);
                          var c0 = G;
                          break;
                        default:
                          ue(y, [0, K[2][1], w0e]);
                          var c0 = G;
                      }
                      var G = c0, A = A[2];
                      continue;
                    }
                    var t0 = S[1], a0 = t0[1];
                    if (A[2]) {
                      ue(y, [0, a0, 66]);
                      var A = A[2];
                      continue;
                    }
                    var w0 = t0[2], _0 = w0[2], G = [0, [1, [0, a0, [0, a(i, y, w0[1]), _0]]], G], A = 0;
                    continue;
                  }
                  var E0 = [0, [0, de(G), w, h]];
                  return [0, T[1], E0];
                }
              });
              function x(y, T) {
                return u(ve[23], T) ? [0, a(i, y, T)] : (ue(y, [0, T[1], 26]), 0);
              }
              N(e, function(y, T) {
                for (var E = T[2], h = E[2], w = o2(y), G = 0, A = E[1]; ; ) {
                  if (A) {
                    var S = A[1];
                    switch (S[0]) {
                      case 0:
                        var M = S[1], K = M[2];
                        if (K[0] === 2) {
                          var V = K[1];
                          if (!V[1]) {
                            var G = [0, [0, [0, M[1], [0, V[2], [0, V[3]]]]], G], A = A[2];
                            continue;
                          }
                        }
                        var f0 = x(y, M);
                        if (f0)
                          var m0 = f0[1], k0 = [0, [0, [0, m0[1], [0, m0, 0]]], G];
                        else
                          var k0 = G;
                        var G = k0, A = A[2];
                        continue;
                      case 1:
                        var g0 = S[1], e0 = g0[1];
                        if (A[2]) {
                          ue(y, [0, e0, 65]);
                          var A = A[2];
                          continue;
                        }
                        var x0 = g0[2], l = x(y, x0[1]), c0 = l ? [0, [1, [0, e0, [0, l[1], x0[2]]]], G] : G, G = c0, A = 0;
                        continue;
                      default:
                        var G = [0, [2, S[1]], G], A = A[2];
                        continue;
                    }
                  }
                  var t0 = [1, [0, de(G), w, h]];
                  return [0, T[1], t0];
                }
              }), N(i, function(y, T) {
                var E = T[2], h = T[1];
                switch (E[0]) {
                  case 0:
                    return a(e, y, [0, h, E[1]]);
                  case 10:
                    var w = E[1], G = w[2][1], A = w[1], S = 0;
                    if (y[5] && Bs(G) ? ue(y, [0, A, 52]) : S = 1, S && 1 - y[5]) {
                      var M = 0;
                      if (y[17] && Un(G, d0e) ? ue(y, [0, A, 93]) : M = 1, M) {
                        var K = y[18], V = K && Un(G, h0e);
                        V && ue(y, [0, A, 92]);
                      }
                    }
                    return [0, h, [2, [0, w, o2(y), 0]]];
                  case 19:
                    return a(n, y, [0, h, E[1]]);
                  default:
                    return [0, h, [3, [0, h, E]]];
                }
              });
              function c(y) {
                function T(w) {
                  var G = N0(w);
                  return typeof G == "number" && G === 82 ? (V0(w, 82), [0, u(ve[10], w)]) : 0;
                }
                function E(w) {
                  var G = pr(w);
                  V0(w, 0);
                  for (var A = 0, S = 0, M = 0; ; ) {
                    var K = N0(w);
                    if (typeof K == "number") {
                      var V = 0;
                      if ((K === 1 || Ln === K) && (V = 1), V) {
                        S && ue(w, [0, S[1], 98]);
                        var f0 = de(M), m0 = pr(w);
                        V0(w, 1);
                        var k0 = we(w), g0 = N0(w) === 86 ? [1, u(t4[9], w)] : o2(w);
                        return [0, [0, f0, g0, mu([0, G], [0, k0], m0, 0)]];
                      }
                    }
                    if (N0(w) === 12)
                      var e0 = pr(w), x0 = cr(0, function(Jr) {
                        return V0(Jr, 12), p(Jr, y);
                      }, w), l = lr([0, e0], 0, 0), c0 = [0, [1, [0, x0[1], [0, x0[2], l]]]];
                    else {
                      var t0 = Le(w), a0 = a(ve[20], 0, w), w0 = N0(w), _0 = 0;
                      if (typeof w0 == "number" && w0 === 86) {
                        V0(w, 86);
                        var E0 = cr([0, t0], function(or) {
                          var _r = p(or, y);
                          return [0, _r, T(or)];
                        }, w), X0 = E0[2], b = a0[2];
                        switch (b[0]) {
                          case 0:
                            var G0 = [0, b[1]];
                            break;
                          case 1:
                            var G0 = [1, b[1]];
                            break;
                          case 2:
                            var G0 = ke(p0e);
                            break;
                          default:
                            var G0 = [2, b[1]];
                        }
                        var c0 = [0, [0, [0, E0[1], [0, G0, X0[1], X0[2], 0]]]];
                      } else
                        _0 = 1;
                      if (_0) {
                        var X = a0[2];
                        if (X[0] === 1) {
                          var s0 = X[1], dr = s0[2][1], Ar = s0[1], ar = 0;
                          SL(dr) && n0(dr, _0e) && n0(dr, y0e) && (ue(w, [0, Ar, 2]), ar = 1), !ar && f2(dr) && V7(w, [0, Ar, 55]);
                          var W0 = cr([0, t0], function(or, _r) {
                            return function(Ir) {
                              var fe = [0, _r, [2, [0, or, o2(Ir), 0]]];
                              return [0, fe, T(Ir)];
                            };
                          }(s0, Ar), w), Lr = W0[2], c0 = [0, [0, [0, W0[1], [0, [1, s0], Lr[1], Lr[2], 1]]]];
                        } else {
                          Ft(m0e, w);
                          var c0 = 0;
                        }
                      }
                    }
                    if (c0) {
                      var Tr = c0[1], Hr = A ? (ue(w, [0, Tr[1][1], 66]), 0) : S;
                      if (Tr[0] === 0)
                        var Rr = Hr, Wr = A;
                      else
                        var Or = N0(w) === 9 ? 1 : 0, xr = Or && [0, Le(w)], Rr = xr, Wr = 1;
                      N0(w) !== 1 && V0(w, 9);
                      var A = Wr, S = Rr, M = [0, Tr, M];
                      continue;
                    }
                  }
                }
                var h = 0;
                return function(w) {
                  return cr(h, E, w);
                };
              }
              function s(y) {
                function T(h) {
                  var w = pr(h);
                  V0(h, 6);
                  for (var G = 0; ; ) {
                    var A = N0(h);
                    if (typeof A == "number") {
                      var S = 0;
                      if (13 <= A)
                        Ln === A && (S = 1);
                      else if (7 <= A)
                        switch (A - 7 | 0) {
                          case 2:
                            var M = Le(h);
                            V0(h, 9);
                            var G = [0, [2, M], G];
                            continue;
                          case 5:
                            var K = pr(h), V = cr(0, function(_0) {
                              return V0(_0, 12), p(_0, y);
                            }, h), f0 = V[1], m0 = lr([0, K], 0, 0), k0 = [1, [0, f0, [0, V[2], m0]]];
                            N0(h) !== 7 && (ue(h, [0, f0, 65]), N0(h) === 9 && ie(h));
                            var G = [0, k0, G];
                            continue;
                          case 0:
                            S = 1;
                            break;
                        }
                      if (S) {
                        var g0 = de(G), e0 = pr(h);
                        V0(h, 7);
                        var x0 = N0(h) === 86 ? [1, u(t4[9], h)] : o2(h);
                        return [1, [0, g0, x0, mu([0, w], [0, we(h)], e0, 0)]];
                      }
                    }
                    var l = cr(0, function(w0) {
                      var _0 = p(w0, y), E0 = N0(w0), X0 = 0;
                      if (typeof E0 == "number" && E0 === 82) {
                        V0(w0, 82);
                        var b = [0, u(ve[10], w0)];
                        X0 = 1;
                      }
                      if (!X0)
                        var b = 0;
                      return [0, _0, b];
                    }, h), c0 = l[2], t0 = [0, [0, l[1], [0, c0[1], c0[2]]]];
                    N0(h) !== 7 && V0(h, 9);
                    var G = [0, t0, G];
                  }
                }
                var E = 0;
                return function(h) {
                  return cr(E, T, h);
                };
              }
              function p(y, T) {
                var E = N0(y);
                if (typeof E == "number") {
                  if (E === 6)
                    return u(s(T), y);
                  if (!E)
                    return u(c(T), y);
                }
                var h = ir(ve[14], y, 0, T);
                return [0, h[1], [2, h[2]]];
              }
              return [0, n, e, i, c, s, p];
            }(mn), wne = mne(ve), Ene = mn[9];
            function Xe0(t4, n) {
              var e = N0(n), i = 0;
              if (typeof e == "number" ? e === 28 ? n[5] ? Ge(n, 55) : n[14] && Ft(0, n) : e === 58 ? n[17] ? Ge(n, 2) : n[5] && Ge(n, 55) : e === 65 ? n[18] && Ge(n, 2) : i = 1 : i = 1, i)
                if (EL(e))
                  gi(n, 55);
                else {
                  var x = 0;
                  if (typeof e == "number")
                    switch (e) {
                      case 15:
                      case 16:
                      case 17:
                      case 18:
                      case 19:
                      case 20:
                      case 21:
                      case 22:
                      case 23:
                      case 24:
                      case 25:
                      case 26:
                      case 27:
                      case 32:
                      case 33:
                      case 34:
                      case 35:
                      case 36:
                      case 37:
                      case 38:
                      case 39:
                      case 40:
                      case 41:
                      case 43:
                      case 44:
                      case 45:
                      case 46:
                      case 47:
                      case 49:
                      case 50:
                      case 51:
                      case 58:
                      case 59:
                      case 65:
                        var c = 1;
                        x = 1;
                        break;
                    }
                  else if (e[0] === 4 && ve0(e[3])) {
                    var c = 1;
                    x = 1;
                  }
                  if (!x)
                    var c = 0;
                  var s = 0;
                  if (c)
                    var p = c;
                  else {
                    var y = wL(e);
                    if (y)
                      var p = y;
                    else {
                      var T = 0;
                      if (typeof e == "number")
                        switch (e) {
                          case 29:
                          case 30:
                          case 31:
                            break;
                          default:
                            T = 1;
                        }
                      else if (e[0] === 4) {
                        var E = e[3];
                        n0(E, ajr) && n0(E, ojr) && n0(E, cjr) && (T = 1);
                      } else
                        T = 1;
                      if (T) {
                        var h = 0;
                        s = 1;
                      } else
                        var p = 1;
                    }
                  }
                  if (!s)
                    var h = p;
                  if (h)
                    Ft(0, n);
                  else {
                    var w = 0;
                    t4 && le0(e) ? gi(n, t4[1]) : w = 1;
                  }
                }
              return z7(n);
            }
            var Ye0 = function t4(n) {
              return t4.fun(n);
            }, BL = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, qL = function t4(n) {
              return t4.fun(n);
            }, Ve0 = function t4(n, e) {
              return t4.fun(n, e);
            }, UL = function t4(n, e) {
              return t4.fun(n, e);
            }, HL = function t4(n, e) {
              return t4.fun(n, e);
            }, G9 = function t4(n, e) {
              return t4.fun(n, e);
            }, xb = function t4(n, e) {
              return t4.fun(n, e);
            }, M9 = function t4(n) {
              return t4.fun(n);
            }, ze0 = function t4(n) {
              return t4.fun(n);
            }, Ke0 = function t4(n) {
              return t4.fun(n);
            }, We0 = function t4(n, e, i) {
              return t4.fun(n, e, i);
            }, Je0 = function t4(n) {
              return t4.fun(n);
            }, $e0 = function t4(n) {
              return t4.fun(n);
            }, Ze0 = Ys[3], Sne = ci[3], gne = ci[1], Fne = ci[5], Tne = Ys[2], One = Ys[1], Ine = Ys[4], Ane = ci[4], Nne = ci[6], Cne = wne[13], Pne = He0[6], Dne = He0[3];
            N(Ye0, function(t4) {
              var n = pr(t4), e = de(n), i = 5;
              r:
                for (; ; ) {
                  if (e)
                    for (var x = e[2], c = e[1], s = c[2], p = c[1], y = s[2], T = 0, E = tn(y); ; ) {
                      if (E < (T + 5 | 0))
                        var h = 0;
                      else {
                        var w = Un(m7(y, T, i), MRr);
                        if (!w) {
                          var T = T + 1 | 0;
                          continue;
                        }
                        var h = w;
                      }
                      if (!h) {
                        var e = x;
                        continue r;
                      }
                      t4[30][1] = p[3];
                      var G = de([0, [0, p, s], x]);
                      break;
                    }
                  else
                    var G = e;
                  if (G === 0) {
                    var A = 0;
                    if (n) {
                      var S = n[1], M = S[2];
                      if (!M[1]) {
                        var K = M[2], V = 0;
                        if (1 <= tn(K) && At(K, 0) === 42) {
                          t4[30][1] = S[1][3];
                          var f0 = [0, S, 0];
                          A = 1, V = 1;
                        }
                      }
                    }
                    if (!A)
                      var f0 = 0;
                  } else
                    var f0 = G;
                  var m0 = a(Ve0, t4, function(c0) {
                    return 0;
                  }), k0 = Le(t4);
                  V0(t4, Ln);
                  var g0 = ju[1];
                  if (be(function(c0, t0) {
                    var a0 = t0[2];
                    switch (a0[0]) {
                      case 17:
                        return fb(t4, c0, Gc(0, [0, a0[1][1], Fre]));
                      case 18:
                        var w0 = a0[1], _0 = w0[1];
                        if (_0) {
                          if (!w0[2]) {
                            var E0 = _0[1], X0 = E0[2], b = 0;
                            switch (X0[0]) {
                              case 34:
                                var G0 = X0[1][1], X = 0, s0 = be(function(Tr, Hr) {
                                  return be(ML, Tr, [0, Hr[2][1], 0]);
                                }, X, G0);
                                return be(function(Tr, Hr) {
                                  return fb(t4, Tr, Hr);
                                }, c0, s0);
                              case 2:
                              case 23:
                                var dr = X0[1][1];
                                if (dr)
                                  var Ar = dr[1];
                                else
                                  b = 1;
                                break;
                              case 16:
                              case 26:
                              case 32:
                              case 33:
                                var Ar = X0[1][1];
                                break;
                              default:
                                b = 1;
                            }
                            return b ? c0 : fb(t4, c0, Gc(0, [0, E0[1], Ar[2][1]]));
                          }
                        } else {
                          var ar = w0[2];
                          if (ar) {
                            var W0 = ar[1];
                            if (W0[0] === 0) {
                              var Lr = W0[1];
                              return be(function(Tr, Hr) {
                                var Or = Hr[2], xr = Or[2];
                                return xr ? fb(t4, Tr, xr[1]) : fb(t4, Tr, Or[1]);
                              }, c0, Lr);
                            }
                            return c0;
                          }
                        }
                        return c0;
                      default:
                        return c0;
                    }
                  }, g0, m0), m0)
                    var e0 = bl(de(m0))[1], x0 = ht(bl(m0)[1], e0);
                  else
                    var x0 = k0;
                  var l = de(t4[2][1]);
                  return [0, x0, [0, m0, lr([0, f0], 0, 0), l]];
                }
            }), N(BL, function(t4, n, e) {
              for (var i = fe0(1, t4), x = Ere; ; ) {
                var c = x[3], s = x[2], p = x[1], y = N0(i), T = 0;
                if (typeof y == "number" && Ln === y)
                  var E = [0, i, p, s, c];
                else
                  T = 1;
                if (T)
                  if (u(n, y))
                    var E = [0, i, p, s, c];
                  else {
                    var h = 0;
                    if (typeof y == "number" || y[0] !== 2)
                      h = 1;
                    else {
                      var w = u(e, i), G = [0, w, s], A = w[2];
                      if (A[0] === 19) {
                        var S = A[1][2];
                        if (S) {
                          var M = Un(S[1], wre), K = M && 1 - i[20];
                          K && ue(i, [0, w[1], 43]);
                          var V = M ? ys(1, i) : i, f0 = [0, y, p], m0 = c || M, i = V, x = [0, f0, G, m0];
                          continue;
                        }
                      }
                      var E = [0, i, p, G, c];
                    }
                    if (h)
                      var E = [0, i, p, s, c];
                  }
                var k0 = fe0(0, i), g0 = de(p);
                return Cu(function(e0) {
                  if (typeof e0 != "number" && e0[0] === 2) {
                    var x0 = e0[1], l = x0[4];
                    return l && V7(k0, [0, x0[1], 45]);
                  }
                  return ke(Te(gre, Te(Tr0(e0), Sre)));
                }, g0), [0, k0, E[3], c];
              }
            }), N(qL, function(t4) {
              var n = u(Ys[6], t4), e = N0(t4);
              if (typeof e == "number") {
                var i = e - 49 | 0;
                if (!(11 < i >>> 0))
                  switch (i) {
                    case 0:
                      return a(kt[16], n, t4);
                    case 1:
                      u(N9(t4), n);
                      var x = Vn(1, t4);
                      if (typeof x == "number") {
                        var c = 0;
                        if ((x === 4 || x === 10) && (c = 1), c)
                          return u(kt[17], t4);
                      }
                      return u(kt[18], t4);
                    case 11:
                      if (Vn(1, t4) === 49)
                        return u(N9(t4), n), a(kt[12], 0, t4);
                      break;
                  }
              }
              return a(xb, [0, n], t4);
            }), N(Ve0, function(t4, n) {
              var e = ir(BL, t4, n, qL), i = a(UL, n, e[1]), x = e[2];
              return be(function(c, s) {
                return [0, s, c];
              }, i, x);
            }), N(UL, function(t4, n) {
              for (var e = 0; ; ) {
                var i = N0(n);
                if (typeof i == "number" && Ln === i || u(t4, i))
                  return de(e);
                var e = [0, u(qL, n), e];
              }
            }), N(HL, function(t4, n) {
              var e = ir(BL, n, t4, function(s) {
                return a(xb, 0, s);
              }), i = a(G9, t4, e[1]), x = e[2], c = be(function(s, p) {
                return [0, p, s];
              }, i, x);
              return [0, c, e[3]];
            }), N(G9, function(t4, n) {
              for (var e = 0; ; ) {
                var i = N0(n);
                if (typeof i == "number" && Ln === i || u(t4, i))
                  return de(e);
                var e = [0, a(xb, 0, n), e];
              }
            }), N(xb, function(t4, n) {
              var e = t4 && t4[1];
              1 - $l(n) && u(N9(n), e);
              var i = N0(n);
              if (typeof i == "number") {
                if (i === 27)
                  return u(kt[27], n);
                if (i === 28)
                  return u(kt[3], n);
              }
              if (qs(n))
                return u(zn[10], n);
              if ($l(n))
                return a(Ze0, n, e);
              if (typeof i == "number") {
                var x = i + Wt | 0;
                if (!(14 < x >>> 0))
                  switch (x) {
                    case 0:
                      if (n[27][1])
                        return u(zn[11], n);
                      break;
                    case 5:
                      return u(kt[19], n);
                    case 12:
                      return a(kt[11], 0, n);
                    case 13:
                      return u(kt[25], n);
                    case 14:
                      return u(kt[21], n);
                  }
              }
              return u(M9, n);
            }), N(M9, function(t4) {
              var n = N0(t4);
              if (typeof n == "number")
                switch (n) {
                  case 0:
                    return u(kt[7], t4);
                  case 8:
                    return u(kt[15], t4);
                  case 19:
                    return u(kt[22], t4);
                  case 20:
                    return u(kt[23], t4);
                  case 22:
                    return u(kt[24], t4);
                  case 23:
                    return u(kt[4], t4);
                  case 24:
                    return u(kt[26], t4);
                  case 25:
                    return u(kt[5], t4);
                  case 26:
                    return u(kt[6], t4);
                  case 32:
                    return u(kt[8], t4);
                  case 35:
                    return u(kt[9], t4);
                  case 37:
                    return u(kt[14], t4);
                  case 39:
                    return u(kt[1], t4);
                  case 59:
                    return u(kt[10], t4);
                  case 113:
                    return Ft(dre, t4), [0, Le(t4), hre];
                  case 16:
                  case 43:
                    return u(kt[2], t4);
                  case 1:
                  case 5:
                  case 7:
                  case 9:
                  case 10:
                  case 11:
                  case 12:
                  case 17:
                  case 18:
                  case 33:
                  case 34:
                  case 36:
                  case 38:
                  case 41:
                  case 42:
                  case 49:
                  case 83:
                  case 86:
                    return Ft(kre, t4), ie(t4), u(M9, t4);
                }
              if (qs(t4)) {
                var e = u(zn[10], t4);
                return B1(t4, e[1]), e;
              }
              if (typeof n == "number" && n === 28 && Vn(1, t4) === 6) {
                var i = Wl(1, t4);
                return ue(t4, [0, ht(Le(t4), i), 94]), u(kt[17], t4);
              }
              return M1(t4) ? u(kt[20], t4) : ($l(t4) && (Ft(0, t4), ie(t4)), u(kt[17], t4));
            }), N(ze0, function(t4) {
              var n = Le(t4), e = u(ci[1], t4), i = N0(t4);
              return typeof i == "number" && i === 9 ? ir(ci[7], t4, n, [0, e, 0]) : e;
            }), N(Ke0, function(t4) {
              var n = Le(t4), e = u(ci[2], t4), i = N0(t4);
              if (typeof i == "number" && i === 9) {
                var x = [0, a(j9[1], t4, e), 0];
                return [0, ir(ci[7], t4, n, x)];
              }
              return e;
            }), N(We0, function(t4, n, e) {
              var i = n && n[1];
              return cr(0, function(x) {
                var c = 1 - i, s = Xe0([0, e], x), p = c && (N0(x) === 85 ? 1 : 0);
                return p && (1 - iu(x) && Ge(x, 12), V0(x, 85)), [0, s, u(mn[10], x), p];
              }, t4);
            }), N(Je0, function(t4) {
              var n = Le(t4), e = pr(t4);
              V0(t4, 0);
              var i = a(G9, function(y) {
                return y === 1 ? 1 : 0;
              }, t4), x = i === 0 ? 1 : 0, c = Le(t4), s = x && pr(t4);
              V0(t4, 1);
              var p = [0, i, mu([0, e], [0, we(t4)], s, 0)];
              return [0, ht(n, c), p];
            }), N($e0, function(t4) {
              function n(i) {
                var x = pr(i);
                V0(i, 0);
                var c = a(HL, function(S) {
                  return S === 1 ? 1 : 0;
                }, i), s = c[1], p = s === 0 ? 1 : 0, y = p && pr(i);
                V0(i, 1);
                var T = N0(i), E = 0;
                if (!t4) {
                  var h = 0;
                  if (typeof T == "number" && (T === 1 || Ln === T) && (h = 1), !h) {
                    var w = f7(i);
                    if (w) {
                      var G = Us(i);
                      E = 1;
                    } else {
                      var G = w;
                      E = 1;
                    }
                  }
                }
                if (!E)
                  var G = we(i);
                var A = mu([0, x], [0, G], y, 0);
                return [0, [0, s, A], c[2]];
              }
              var e = 0;
              return function(i) {
                return OL(e, n, i);
              };
            }), bu(Nre, ve, [0, Ye0, M9, xb, G9, HL, UL, ze0, Ke0, Sne, gne, Fne, Tne, Xe0, We0, Je0, $e0, Cne, Pne, Dne, One, Ze0, Ine, Ane, Nne, Ene]);
            var Qe0 = [0, 0], rn0 = bn;
            function Lne(t4) {
              function n(e, i) {
                var x = i[2], c = i[1], s = sL(x), p = [0, [0, Cre, u(t4[1], s)], 0], y = P9(e, c[3]), T = [0, u(t4[5], y), 0], E = P9(e, c[2]), h = [0, u(t4[5], E), T], w = [0, [0, Pre, u(t4[4], h)], p], G = [0, [0, Dre, u(t4[5], c[3][2])], 0], A = [0, [0, Lre, u(t4[5], c[3][1])], G], S = [0, [0, Rre, u(t4[3], A)], 0], M = [0, [0, jre, u(t4[5], c[2][2])], 0], K = [0, [0, Gre, u(t4[5], c[2][1])], M], V = [0, [0, Mre, u(t4[3], K)], S], f0 = [0, [0, Bre, u(t4[3], V)], w];
                switch (i[3]) {
                  case 0:
                    var m0 = qre;
                    break;
                  case 1:
                    var m0 = Ure;
                    break;
                  case 2:
                    var m0 = Hre;
                    break;
                  case 3:
                    var m0 = Xre;
                    break;
                  case 4:
                    var m0 = Yre;
                    break;
                  default:
                    var m0 = Vre;
                }
                var k0 = [0, [0, zre, u(t4[1], m0)], f0], g0 = Tr0(x), e0 = [0, [0, Kre, u(t4[1], g0)], k0];
                return u(t4[3], e0);
              }
              return [0, n, function(e, i) {
                var x = de(Tp(function(c) {
                  return n(e, c);
                }, i));
                return u(t4[4], x);
              }];
            }
            var Rne = U70;
            function H1(t4) {
              return H70(_l(t4));
            }
            function _u(t4) {
              return q70(_l(t4));
            }
            function jne(t4) {
              return t4;
            }
            function Gne(t4) {
              return t4;
            }
            function en0(t4, n, e) {
              try {
                var i = new RegExp(bn(n), bn(e));
                return i;
              } catch {
                return u7;
              }
            }
            var Mne = Lne([0, rn0, Rne, H1, _u, jne, Gne, u7, en0]), Bne = [0, 1], nn0 = function(t4) {
              function n(E, h) {
                return _u(de(Tp(E, h)));
              }
              function e(E, h) {
                return h ? u(E, h[1]) : u7;
              }
              function i(E, h) {
                return h[0] === 0 ? u7 : u(E, h[1]);
              }
              function x(E) {
                return H1([0, [0, KWr, E[1]], [0, [0, zWr, E[2]], 0]]);
              }
              function c(E) {
                var h = E[1], w = h ? bn(h[1][1]) : u7, G = [0, [0, XWr, x(E[3])], 0];
                return H1([0, [0, VWr, w], [0, [0, YWr, x(E[2])], G]]);
              }
              function s(E) {
                return n(function(h) {
                  var w = h[2], G = 0;
                  if (typeof w == "number") {
                    var A = w;
                    if (55 <= A)
                      switch (A) {
                        case 55:
                          var S = hmr;
                          break;
                        case 56:
                          var S = kmr;
                          break;
                        case 57:
                          var S = wmr;
                          break;
                        case 58:
                          var S = Emr;
                          break;
                        case 59:
                          var S = Smr;
                          break;
                        case 60:
                          var S = gmr;
                          break;
                        case 61:
                          var S = Te(Tmr, Fmr);
                          break;
                        case 62:
                          var S = Te(Imr, Omr);
                          break;
                        case 63:
                          var S = Te(Nmr, Amr);
                          break;
                        case 64:
                          var S = Cmr;
                          break;
                        case 65:
                          var S = Pmr;
                          break;
                        case 66:
                          var S = Dmr;
                          break;
                        case 67:
                          var S = Lmr;
                          break;
                        case 68:
                          var S = Rmr;
                          break;
                        case 69:
                          var S = jmr;
                          break;
                        case 70:
                          var S = Gmr;
                          break;
                        case 71:
                          var S = Mmr;
                          break;
                        case 72:
                          var S = Bmr;
                          break;
                        case 73:
                          var S = qmr;
                          break;
                        case 74:
                          var S = Umr;
                          break;
                        case 75:
                          var S = Hmr;
                          break;
                        case 76:
                          var S = Xmr;
                          break;
                        case 77:
                          var S = Ymr;
                          break;
                        case 78:
                          var S = Vmr;
                          break;
                        case 79:
                          var S = zmr;
                          break;
                        case 80:
                          var S = Kmr;
                          break;
                        case 81:
                          var S = Wmr;
                          break;
                        case 82:
                          var S = Te($mr, Jmr);
                          break;
                        case 83:
                          var S = Zmr;
                          break;
                        case 84:
                          var S = Qmr;
                          break;
                        case 85:
                          var S = r9r;
                          break;
                        case 86:
                          var S = e9r;
                          break;
                        case 87:
                          var S = n9r;
                          break;
                        case 88:
                          var S = t9r;
                          break;
                        case 89:
                          var S = u9r;
                          break;
                        case 90:
                          var S = i9r;
                          break;
                        case 91:
                          var S = f9r;
                          break;
                        case 92:
                          var S = x9r;
                          break;
                        case 93:
                          var S = a9r;
                          break;
                        case 94:
                          var S = Te(c9r, o9r);
                          break;
                        case 95:
                          var S = s9r;
                          break;
                        case 96:
                          var S = v9r;
                          break;
                        case 97:
                          var S = l9r;
                          break;
                        case 98:
                          var S = b9r;
                          break;
                        case 99:
                          var S = p9r;
                          break;
                        case 100:
                          var S = m9r;
                          break;
                        case 101:
                          var S = _9r;
                          break;
                        case 102:
                          var S = y9r;
                          break;
                        case 103:
                          var S = d9r;
                          break;
                        case 104:
                          var S = h9r;
                          break;
                        case 105:
                          var S = k9r;
                          break;
                        case 106:
                          var S = w9r;
                          break;
                        case 107:
                          var S = E9r;
                          break;
                        default:
                          var S = S9r;
                      }
                    else
                      switch (A) {
                        case 0:
                          var S = y5r;
                          break;
                        case 1:
                          var S = d5r;
                          break;
                        case 2:
                          var S = h5r;
                          break;
                        case 3:
                          var S = k5r;
                          break;
                        case 4:
                          var S = w5r;
                          break;
                        case 5:
                          var S = E5r;
                          break;
                        case 6:
                          var S = S5r;
                          break;
                        case 7:
                          var S = g5r;
                          break;
                        case 8:
                          var S = F5r;
                          break;
                        case 9:
                          var S = T5r;
                          break;
                        case 10:
                          var S = O5r;
                          break;
                        case 11:
                          var S = I5r;
                          break;
                        case 12:
                          var S = A5r;
                          break;
                        case 13:
                          var S = N5r;
                          break;
                        case 14:
                          var S = C5r;
                          break;
                        case 15:
                          var S = P5r;
                          break;
                        case 16:
                          var S = D5r;
                          break;
                        case 17:
                          var S = L5r;
                          break;
                        case 18:
                          var S = R5r;
                          break;
                        case 19:
                          var S = j5r;
                          break;
                        case 20:
                          var S = G5r;
                          break;
                        case 21:
                          var S = M5r;
                          break;
                        case 22:
                          var S = B5r;
                          break;
                        case 23:
                          var S = q5r;
                          break;
                        case 24:
                          var S = U5r;
                          break;
                        case 25:
                          var S = H5r;
                          break;
                        case 26:
                          var S = X5r;
                          break;
                        case 27:
                          var S = Y5r;
                          break;
                        case 28:
                          var S = V5r;
                          break;
                        case 29:
                          var S = z5r;
                          break;
                        case 30:
                          var S = K5r;
                          break;
                        case 31:
                          var S = Te(J5r, W5r);
                          break;
                        case 32:
                          var S = $5r;
                          break;
                        case 33:
                          var S = Z5r;
                          break;
                        case 34:
                          var S = Q5r;
                          break;
                        case 35:
                          var S = rmr;
                          break;
                        case 36:
                          var S = emr;
                          break;
                        case 37:
                          var S = nmr;
                          break;
                        case 38:
                          var S = tmr;
                          break;
                        case 39:
                          var S = umr;
                          break;
                        case 40:
                          var S = imr;
                          break;
                        case 41:
                          var S = fmr;
                          break;
                        case 42:
                          var S = xmr;
                          break;
                        case 43:
                          var S = amr;
                          break;
                        case 44:
                          var S = omr;
                          break;
                        case 45:
                          var S = cmr;
                          break;
                        case 46:
                          var S = smr;
                          break;
                        case 47:
                          var S = vmr;
                          break;
                        case 48:
                          var S = lmr;
                          break;
                        case 49:
                          var S = bmr;
                          break;
                        case 50:
                          var S = pmr;
                          break;
                        case 51:
                          var S = mmr;
                          break;
                        case 52:
                          var S = _mr;
                          break;
                        case 53:
                          var S = ymr;
                          break;
                        default:
                          var S = dmr;
                      }
                  } else
                    switch (w[0]) {
                      case 0:
                        var M = w[2], K = w[1], S = ir(et(g9r), M, M, K);
                        break;
                      case 1:
                        var V = w[1], f0 = w[2], S = a(et(F9r), f0, V);
                        break;
                      case 2:
                        var m0 = w[1], S = u(et(T9r), m0);
                        break;
                      case 3:
                        var k0 = w[2], g0 = w[1], e0 = u(et(O9r), g0);
                        if (k0)
                          var x0 = k0[1], S = a(et(I9r), x0, e0);
                        else
                          var S = u(et(A9r), e0);
                        break;
                      case 4:
                        var l = w[1], S = a(et(N9r), l, l);
                        break;
                      case 5:
                        var c0 = w[3], t0 = w[2], a0 = w[1];
                        if (t0) {
                          var w0 = t0[1];
                          if (3 <= w0)
                            var S = a(et(C9r), c0, a0);
                          else {
                            switch (w0) {
                              case 0:
                                var _0 = b5r;
                                break;
                              case 1:
                                var _0 = p5r;
                                break;
                              case 2:
                                var _0 = m5r;
                                break;
                              default:
                                var _0 = _5r;
                            }
                            var S = R(et(P9r), a0, _0, c0, _0);
                          }
                        } else
                          var S = a(et(D9r), c0, a0);
                        break;
                      case 6:
                        var E0 = w[2], X0 = E0;
                        if (b7(X0) === 0)
                          var b = X0;
                        else {
                          var G0 = mz(X0);
                          Zn(G0, 0, vz(Hu(X0, 0)));
                          var b = G0;
                        }
                        var X = b, s0 = w[1], S = ir(et(L9r), E0, X, s0);
                        break;
                      case 7:
                        var S = w[1] ? R9r : j9r;
                        break;
                      case 8:
                        var dr = w[1], Ar = w[2], S = a(et(G9r), Ar, dr);
                        break;
                      case 9:
                        var ar = w[1], S = u(et(M9r), ar);
                        break;
                      case 10:
                        var W0 = w[1], S = u(et(B9r), W0);
                        break;
                      case 11:
                        var Lr = w[2], Tr = w[1], S = a(et(q9r), Tr, Lr);
                        break;
                      case 12:
                        var Hr = w[2], Or = w[1], S = a(et(U9r), Or, Hr);
                        break;
                      case 13:
                        var S = Te(X9r, Te(w[1], H9r));
                        break;
                      case 14:
                        var xr = w[1] ? Y9r : V9r, S = u(et(z9r), xr);
                        break;
                      case 15:
                        var S = Te(W9r, Te(w[1], K9r));
                        break;
                      case 16:
                        var Rr = Te($9r, Te(w[2], J9r)), S = Te(w[1], Rr);
                        break;
                      case 17:
                        var S = Te(Z9r, w[1]);
                        break;
                      case 18:
                        var S = w[1] ? Te(r_r, Q9r) : Te(n_r, e_r);
                        break;
                      case 19:
                        var Wr = w[1], S = u(et(t_r), Wr);
                        break;
                      case 20:
                        var S = Te(i_r, Te(w[1], u_r));
                        break;
                      case 21:
                        var Jr = w[1], or = w[2] ? f_r : x_r, _r = w[4] ? Te(a_r, Jr) : Jr, Ir = w[3] ? o_r : c_r, S = Te(l_r, Te(or, Te(Ir, Te(v_r, Te(_r, s_r)))));
                        break;
                      case 22:
                        var S = Te(p_r, Te(w[1], b_r));
                        break;
                      default:
                        var fe = w[1], S = u(et(m_r), fe);
                    }
                  var v0 = [0, [0, UWr, bn(S)], G];
                  return H1([0, [0, HWr, c(h[1])], v0]);
                }, E);
              }
              function p(E) {
                if (E) {
                  var h = E[1], w = [0, xn(h[3], h[2])];
                  return lr([0, h[1]], w, 0);
                }
                return E;
              }
              function y(E) {
                function h(_) {
                  return n(H0, _);
                }
                function w(_, k, I, U) {
                  var Y = t4[1];
                  if (Y) {
                    if (E)
                      var y0 = E[1], D0 = [0, P9(y0, k[3]), 0], A0 = [0, [0, EGr, _u([0, P9(y0, k[2]), D0])], 0];
                    else
                      var A0 = E;
                    var D = xn(A0, [0, [0, SGr, c(k)], 0]);
                  } else
                    var D = Y;
                  if (I) {
                    var u0 = I[1], Y0 = u0[1];
                    if (Y0) {
                      var J0 = u0[2];
                      if (J0)
                        var fr = [0, [0, gGr, h(J0)], 0], Q0 = [0, [0, FGr, h(Y0)], fr];
                      else
                        var Q0 = [0, [0, TGr, h(Y0)], 0];
                      var mr = Q0;
                    } else
                      var F0 = u0[2], gr = F0 && [0, [0, OGr, h(F0)], 0], mr = gr;
                    var Cr = mr;
                  } else
                    var Cr = I;
                  return H1(jc(xn(D, xn(Cr, [0, [0, IGr, bn(_)], 0])), U));
                }
                function G(_) {
                  return n(Q, _);
                }
                function A(_) {
                  var k = _[2], I = G(k[1]), U = [0, [0, NGr, I], [0, [0, AGr, h(k[3])], 0]];
                  return w(CGr, _[1], k[2], U);
                }
                function S(_) {
                  var k = _[2];
                  return w(cUr, _[1], k[2], [0, [0, oUr, bn(k[1])], [0, [0, aUr, u7], [0, [0, xUr, false], 0]]]);
                }
                function M(_) {
                  if (_[0] === 0)
                    return S(_[1]);
                  var k = _[1], I = k[2], U = M(I[1]), Y = [0, [0, tKr, U], [0, [0, nKr, S(I[2])], 0]];
                  return w(uKr, k[1], 0, Y);
                }
                function K(_) {
                  var k = _[2], I = k[1], U = I[0] === 0 ? S(I[1]) : K(I[1]), Y = [0, [0, Bzr, U], [0, [0, Mzr, S(k[2])], 0]];
                  return w(qzr, _[1], 0, Y);
                }
                function V(_) {
                  var k = _[2], I = k[1], U = I[0] === 0 ? S(I[1]) : K(I[1]), Y = [0, [0, Hzr, U], [0, [0, Uzr, e($r, k[2])], 0]];
                  return w(Xzr, _[1], k[3], Y);
                }
                function f0(_) {
                  var k = _[2], I = k[2], U = k[1], Y = _[1];
                  if (typeof U == "number")
                    var y0 = u7;
                  else
                    switch (U[0]) {
                      case 0:
                        var y0 = bn(U[1]);
                        break;
                      case 1:
                        var y0 = !!U[1];
                        break;
                      case 2:
                        var y0 = U[1];
                        break;
                      case 3:
                        var y0 = ke(CYr);
                        break;
                      default:
                        var D0 = U[1], y0 = en0(Y, D0[1], D0[2]);
                    }
                  var A0 = 0;
                  if (typeof U != "number" && U[0] === 4) {
                    var D = U[1], u0 = [0, [0, LYr, H1([0, [0, DYr, bn(D[1])], [0, [0, PYr, bn(D[2])], 0]])], 0], Y0 = [0, [0, jYr, y0], [0, [0, RYr, bn(I)], u0]];
                    A0 = 1;
                  }
                  if (!A0)
                    var Y0 = [0, [0, MYr, y0], [0, [0, GYr, bn(I)], 0]];
                  return w(BYr, Y, k[3], Y0);
                }
                function m0(_) {
                  var k = [0, [0, Yzr, g0(_[2])], 0];
                  return [0, [0, Vzr, g0(_[1])], k];
                }
                function k0(_, k) {
                  var I = k[2], U = [0, [0, qVr, !!I[3]], 0], Y = [0, [0, UVr, g0(I[2])], U], y0 = [0, [0, HVr, e(S, I[1])], Y];
                  return w(XVr, k[1], _, y0);
                }
                function g0(_) {
                  var k = _[2], I = _[1];
                  switch (k[0]) {
                    case 0:
                      return w(EVr, I, k[1], 0);
                    case 1:
                      return w(SVr, I, k[1], 0);
                    case 2:
                      return w(gVr, I, k[1], 0);
                    case 3:
                      return w(FVr, I, k[1], 0);
                    case 4:
                      return w(TVr, I, k[1], 0);
                    case 5:
                      return w(IVr, I, k[1], 0);
                    case 6:
                      return w(AVr, I, k[1], 0);
                    case 7:
                      return w(NVr, I, k[1], 0);
                    case 8:
                      return w(CVr, I, k[1], 0);
                    case 9:
                      return w(OVr, I, k[1], 0);
                    case 10:
                      return w(kKr, I, k[1], 0);
                    case 11:
                      var U = k[1], Y = [0, [0, PVr, g0(U[1])], 0];
                      return w(DVr, I, U[2], Y);
                    case 12:
                      return e0([0, I, k[1]]);
                    case 13:
                      return x0(1, [0, I, k[1]]);
                    case 14:
                      var y0 = k[1], D0 = [0, [0, Dzr, x0(0, y0[1])], 0], A0 = [0, [0, Lzr, n(fe, y0[2])], D0];
                      return w(Rzr, I, y0[3], A0);
                    case 15:
                      var D = k[1], u0 = [0, [0, jzr, g0(D[1])], 0];
                      return w(Gzr, I, D[2], u0);
                    case 16:
                      return V([0, I, k[1]]);
                    case 17:
                      var Y0 = k[1], J0 = m0(Y0);
                      return w(zzr, I, Y0[3], J0);
                    case 18:
                      var fr = k[1], Q0 = fr[1], F0 = [0, [0, Kzr, !!fr[2]], 0], gr = xn(m0(Q0), F0);
                      return w(Wzr, I, Q0[3], gr);
                    case 19:
                      var mr = k[1], Cr = mr[1], sr = [0, [0, Jzr, n(g0, [0, Cr[1], [0, Cr[2], Cr[3]]])], 0];
                      return w($zr, I, mr[2], sr);
                    case 20:
                      var Pr = k[1], K0 = Pr[1], Ur = [0, [0, Zzr, n(g0, [0, K0[1], [0, K0[2], K0[3]]])], 0];
                      return w(Qzr, I, Pr[2], Ur);
                    case 21:
                      var d0 = k[1], Kr = [0, [0, rKr, M(d0[1])], 0];
                      return w(eKr, I, d0[2], Kr);
                    case 22:
                      var re = k[1], xe = [0, [0, iKr, n(g0, re[1])], 0];
                      return w(fKr, I, re[2], xe);
                    case 23:
                      var je = k[1];
                      return w(oKr, I, je[3], [0, [0, aKr, bn(je[1])], [0, [0, xKr, bn(je[2])], 0]]);
                    case 24:
                      var le = k[1];
                      return w(vKr, I, le[3], [0, [0, sKr, le[1]], [0, [0, cKr, bn(le[2])], 0]]);
                    case 25:
                      var Ie = k[1];
                      return w(pKr, I, Ie[3], [0, [0, bKr, u7], [0, [0, lKr, bn(Ie[2])], 0]]);
                    default:
                      var Me = k[1], Be = Me[1], an = 0, Ke = Be ? mKr : _Kr;
                      return w(hKr, I, Me[2], [0, [0, dKr, !!Be], [0, [0, yKr, bn(Ke)], an]]);
                  }
                }
                function e0(_) {
                  var k = _[2], I = k[2][2], U = k[4], Y = y7(p(I[4]), U), y0 = [0, [0, LVr, e(qr, k[1])], 0], D0 = [0, [0, RVr, e(Mr, I[3])], y0], A0 = [0, [0, jVr, g0(k[3])], D0], D = [0, [0, GVr, e(Br, I[1])], A0], u0 = I[2], Y0 = [0, [0, MVr, n(function(J0) {
                    return k0(0, J0);
                  }, u0)], D];
                  return w(BVr, _[1], Y, Y0);
                }
                function x0(_, k) {
                  var I = k[2], U = I[3], Y = be(function(fr, Q0) {
                    var F0 = fr[4], gr = fr[3], mr = fr[2], Cr = fr[1];
                    switch (Q0[0]) {
                      case 0:
                        var sr = Q0[1], Pr = sr[2], K0 = Pr[2], Ur = Pr[1];
                        switch (Ur[0]) {
                          case 0:
                            var d0 = f0(Ur[1]);
                            break;
                          case 1:
                            var d0 = S(Ur[1]);
                            break;
                          case 2:
                            var d0 = ke(tzr);
                            break;
                          default:
                            var d0 = ke(uzr);
                        }
                        switch (K0[0]) {
                          case 0:
                            var xe = izr, je = g0(K0[1]);
                            break;
                          case 1:
                            var Kr = K0[1], xe = fzr, je = e0([0, Kr[1], Kr[2]]);
                            break;
                          default:
                            var re = K0[1], xe = xzr, je = e0([0, re[1], re[2]]);
                        }
                        var le = [0, [0, azr, bn(xe)], 0], Ie = [0, [0, ozr, e(Sr, Pr[7])], le];
                        return [0, [0, w(mzr, sr[1], Pr[8], [0, [0, pzr, d0], [0, [0, bzr, je], [0, [0, lzr, !!Pr[6]], [0, [0, vzr, !!Pr[3]], [0, [0, szr, !!Pr[4]], [0, [0, czr, !!Pr[5]], Ie]]]]]]), Cr], mr, gr, F0];
                      case 1:
                        var Me = Q0[1], Be = Me[2], an = [0, [0, _zr, g0(Be[1])], 0];
                        return [0, [0, w(yzr, Me[1], Be[2], an), Cr], mr, gr, F0];
                      case 2:
                        var Ke = Q0[1], Ae = Ke[2], on = [0, [0, dzr, e(Sr, Ae[5])], 0], rn = [0, [0, hzr, !!Ae[4]], on], kn = [0, [0, kzr, g0(Ae[3])], rn], sn = [0, [0, wzr, g0(Ae[2])], kn], Pe = [0, [0, Ezr, e(S, Ae[1])], sn];
                        return [0, Cr, [0, w(Szr, Ke[1], Ae[6], Pe), mr], gr, F0];
                      case 3:
                        var We = Q0[1], en = We[2], _n = [0, [0, gzr, !!en[2]], 0], Dn = [0, [0, Fzr, e0(en[1])], _n];
                        return [0, Cr, mr, [0, w(Tzr, We[1], en[3], Dn), gr], F0];
                      default:
                        var Xn = Q0[1], On = Xn[2], bt = [0, [0, Ozr, g0(On[2])], 0], Ct = [0, [0, Nzr, !!On[3]], [0, [0, Azr, !!On[4]], [0, [0, Izr, !!On[5]], bt]]], Tt = [0, [0, Czr, S(On[1])], Ct];
                        return [0, Cr, mr, gr, [0, w(Pzr, Xn[1], On[6], Tt), F0]];
                    }
                  }, WVr, U), y0 = [0, [0, JVr, _u(de(Y[4]))], 0], D0 = [0, [0, $Vr, _u(de(Y[3]))], y0], A0 = [0, [0, ZVr, _u(de(Y[2]))], D0], D = [0, [0, QVr, _u(de(Y[1]))], A0], u0 = [0, [0, rzr, !!I[1]], D], Y0 = _ ? [0, [0, ezr, !!I[2]], u0] : u0, J0 = p(I[4]);
                  return w(nzr, k[1], J0, Y0);
                }
                function l(_) {
                  var k = [0, [0, wKr, g0(_[2])], 0];
                  return w(EKr, _[1], 0, k);
                }
                function c0(_) {
                  var k = _[2];
                  switch (k[2]) {
                    case 0:
                      var I = vVr;
                      break;
                    case 1:
                      var I = lVr;
                      break;
                    default:
                      var I = bVr;
                  }
                  var U = [0, [0, pVr, bn(I)], 0], Y = [0, [0, mVr, n($0, k[1])], U];
                  return w(_Vr, _[1], k[3], Y);
                }
                function t0(_) {
                  var k = _[2];
                  return w(WYr, _[1], k[3], [0, [0, KYr, bn(k[1])], [0, [0, zYr, bn(k[2])], 0]]);
                }
                function a0(_) {
                  var k = _[2], I = [0, [0, zXr, f1], [0, [0, VXr, l(k[1])], 0]];
                  return w(KXr, _[1], k[2], I);
                }
                function w0(_, k) {
                  var I = k[1][2], U = [0, [0, pUr, !!k[3]], 0], Y = [0, [0, mUr, i(l, k[2])], U];
                  return w(yUr, _, I[2], [0, [0, _Ur, bn(I[1])], Y]);
                }
                function _0(_) {
                  var k = _[2];
                  return w(bUr, _[1], k[2], [0, [0, lUr, bn(k[1])], [0, [0, vUr, u7], [0, [0, sUr, false], 0]]]);
                }
                function E0(_) {
                  return n(q0, _[2][1]);
                }
                function X0(_) {
                  var k = _[2], I = [0, [0, BKr, w($Kr, k[2], 0, 0)], 0], U = [0, [0, qKr, n(ae, k[3][2])], I], Y = [0, [0, UKr, w(KKr, k[1], 0, 0)], U];
                  return w(HKr, _[1], k[4], Y);
                }
                function b(_) {
                  var k = _[2];
                  return w(yWr, _[1], k[2], [0, [0, _Wr, bn(k[1])], 0]);
                }
                function G0(_) {
                  var k = _[2], I = [0, [0, bWr, b(k[2])], 0], U = [0, [0, pWr, b(k[1])], I];
                  return w(mWr, _[1], 0, U);
                }
                function X(_) {
                  var k = _[2], I = k[1], U = I[0] === 0 ? b(I[1]) : X(I[1]), Y = [0, [0, vWr, U], [0, [0, sWr, b(k[2])], 0]];
                  return w(lWr, _[1], 0, Y);
                }
                function s0(_) {
                  switch (_[0]) {
                    case 0:
                      return b(_[1]);
                    case 1:
                      return G0(_[1]);
                    default:
                      return X(_[1]);
                  }
                }
                function dr(_) {
                  var k = _[2], I = [0, [0, RKr, n(ae, k[3][2])], 0], U = [0, [0, jKr, e(oe, k[2])], I], Y = k[1], y0 = Y[2], D0 = [0, [0, XKr, !!y0[2]], 0], A0 = [0, [0, YKr, n(pe, y0[3])], D0], D = [0, [0, VKr, s0(y0[1])], A0], u0 = [0, [0, GKr, w(zKr, Y[1], 0, D)], U];
                  return w(MKr, _[1], k[4], u0);
                }
                function Ar(_) {
                  var k = _[2], I = [0, [0, eVr, n(xr, k[2])], 0], U = [0, [0, nVr, n(vr, k[1])], I];
                  return w(tVr, _[1], k[3], U);
                }
                function ar(_, k) {
                  var I = k[2], U = I[7], Y = I[5], y0 = I[4];
                  if (y0)
                    var D0 = y0[1][2], A0 = y7(D0[3], U), D = A0, u0 = D0[2], Y0 = [0, D0[1]];
                  else
                    var D = U, u0 = 0, Y0 = 0;
                  if (Y)
                    var J0 = Y[1][2], fr = y7(J0[2], D), Q0 = fr, F0 = n(T0, J0[1]);
                  else
                    var Q0 = D, F0 = _u(0);
                  var gr = [0, [0, sHr, F0], [0, [0, cHr, n(S0, I[6])], 0]], mr = [0, [0, vHr, e($r, u0)], gr], Cr = [0, [0, lHr, e(xr, Y0)], mr], sr = [0, [0, bHr, e(qr, I[3])], Cr], Pr = I[2], K0 = Pr[2], Ur = [0, [0, wHr, n(er, K0[1])], 0], d0 = [0, [0, pHr, w(EHr, Pr[1], K0[2], Ur)], sr], Kr = [0, [0, mHr, e(S, I[1])], d0];
                  return w(_, k[1], Q0, Kr);
                }
                function W0(_) {
                  var k = _[2], I = [0, [0, gUr, G(k[1])], 0], U = p(k[2]);
                  return w(FUr, _[1], U, I);
                }
                function Lr(_) {
                  var k = _[2];
                  switch (k[0]) {
                    case 0:
                      var I = 0, U = S(k[1]);
                      break;
                    case 1:
                      var I = 0, U = _0(k[1]);
                      break;
                    default:
                      var I = 1, U = xr(k[1]);
                  }
                  return [0, [0, qWr, xr(_[1])], [0, [0, BWr, U], [0, [0, MWr, !!I], 0]]];
                }
                function Tr(_) {
                  var k = [0, [0, RWr, E0(_[3])], 0], I = [0, [0, jWr, e(ne, _[2])], k];
                  return [0, [0, GWr, xr(_[1])], I];
                }
                function Hr(_) {
                  var k = _[2], I = k[3], U = k[2], Y = k[1];
                  if (I) {
                    var y0 = I[1], D0 = y0[2], A0 = [0, [0, WXr, Or(D0[1])], 0], D = w(JXr, y0[1], D0[2], A0), u0 = de([0, D, Tp(j0, U)]), Y0 = Y ? [0, a0(Y[1]), u0] : u0;
                    return _u(Y0);
                  }
                  var J0 = k1(j0, U), fr = Y ? [0, a0(Y[1]), J0] : J0;
                  return _u(fr);
                }
                function Or(_) {
                  var k = _[2], I = _[1];
                  switch (k[0]) {
                    case 0:
                      var U = k[1], Y = [0, [0, jXr, i(l, U[2])], 0], y0 = [0, [0, GXr, n(b0, U[1])], Y];
                      return w(MXr, I, p(U[3]), y0);
                    case 1:
                      var D0 = k[1], A0 = [0, [0, BXr, i(l, D0[2])], 0], D = [0, [0, qXr, n(Z, D0[1])], A0];
                      return w(UXr, I, p(D0[3]), D);
                    case 2:
                      return w0(I, k[1]);
                    default:
                      return xr(k[1]);
                  }
                }
                function xr(_) {
                  var k = _[2], I = _[1];
                  switch (k[0]) {
                    case 0:
                      var U = k[1], Y = [0, [0, aBr, n(nr, U[1])], 0];
                      return w(oBr, I, p(U[2]), Y);
                    case 1:
                      var y0 = k[1], D0 = y0[7], A0 = y0[3], D = y0[2];
                      if (A0[0] === 0)
                        var u0 = 0, Y0 = W0(A0[1]);
                      else
                        var u0 = 1, Y0 = xr(A0[1]);
                      var J0 = D0[0] === 0 ? 0 : [0, D0[1]], fr = y0[9], Q0 = y7(p(D[2][4]), fr), F0 = [0, [0, cBr, e(qr, y0[8])], 0], gr = [0, [0, vBr, !!u0], [0, [0, sBr, e(l, J0)], F0]], mr = [0, [0, bBr, false], [0, [0, lBr, e(Fr, y0[6])], gr]], Cr = [0, [0, mBr, Y0], [0, [0, pBr, !!y0[4]], mr]];
                      return w(dBr, I, Q0, [0, [0, yBr, u7], [0, [0, _Br, Hr(D)], Cr]]);
                    case 2:
                      var sr = k[1], Pr = sr[1];
                      if (Pr) {
                        switch (Pr[1]) {
                          case 0:
                            var K0 = Ypr;
                            break;
                          case 1:
                            var K0 = Vpr;
                            break;
                          case 2:
                            var K0 = zpr;
                            break;
                          case 3:
                            var K0 = Kpr;
                            break;
                          case 4:
                            var K0 = Wpr;
                            break;
                          case 5:
                            var K0 = Jpr;
                            break;
                          case 6:
                            var K0 = $pr;
                            break;
                          case 7:
                            var K0 = Zpr;
                            break;
                          case 8:
                            var K0 = Qpr;
                            break;
                          case 9:
                            var K0 = r5r;
                            break;
                          case 10:
                            var K0 = e5r;
                            break;
                          case 11:
                            var K0 = n5r;
                            break;
                          case 12:
                            var K0 = t5r;
                            break;
                          case 13:
                            var K0 = u5r;
                            break;
                          default:
                            var K0 = i5r;
                        }
                        var Ur = K0;
                      } else
                        var Ur = hBr;
                      var d0 = [0, [0, kBr, xr(sr[3])], 0], Kr = [0, [0, wBr, Or(sr[2])], d0];
                      return w(SBr, I, sr[4], [0, [0, EBr, bn(Ur)], Kr]);
                    case 3:
                      var re = k[1], xe = [0, [0, gBr, xr(re[3])], 0], je = [0, [0, FBr, xr(re[2])], xe];
                      switch (re[1]) {
                        case 0:
                          var le = Epr;
                          break;
                        case 1:
                          var le = Spr;
                          break;
                        case 2:
                          var le = gpr;
                          break;
                        case 3:
                          var le = Fpr;
                          break;
                        case 4:
                          var le = Tpr;
                          break;
                        case 5:
                          var le = Opr;
                          break;
                        case 6:
                          var le = Ipr;
                          break;
                        case 7:
                          var le = Apr;
                          break;
                        case 8:
                          var le = Npr;
                          break;
                        case 9:
                          var le = Cpr;
                          break;
                        case 10:
                          var le = Ppr;
                          break;
                        case 11:
                          var le = Dpr;
                          break;
                        case 12:
                          var le = Lpr;
                          break;
                        case 13:
                          var le = Rpr;
                          break;
                        case 14:
                          var le = jpr;
                          break;
                        case 15:
                          var le = Gpr;
                          break;
                        case 16:
                          var le = Mpr;
                          break;
                        case 17:
                          var le = Bpr;
                          break;
                        case 18:
                          var le = qpr;
                          break;
                        case 19:
                          var le = Upr;
                          break;
                        case 20:
                          var le = Hpr;
                          break;
                        default:
                          var le = Xpr;
                      }
                      return w(OBr, I, re[4], [0, [0, TBr, bn(le)], je]);
                    case 4:
                      var Ie = k[1], Me = Ie[4], Be = y7(p(Ie[3][2][2]), Me);
                      return w(IBr, I, Be, Tr(Ie));
                    case 5:
                      return ar(oHr, [0, I, k[1]]);
                    case 6:
                      var an = k[1], Ke = [0, [0, ABr, e(xr, an[2])], 0];
                      return w(CBr, I, 0, [0, [0, NBr, n(yr, an[1])], Ke]);
                    case 7:
                      var Ae = k[1], on = [0, [0, PBr, xr(Ae[3])], 0], rn = [0, [0, DBr, xr(Ae[2])], on], kn = [0, [0, LBr, xr(Ae[1])], rn];
                      return w(RBr, I, Ae[4], kn);
                    case 8:
                      return Rr([0, I, k[1]]);
                    case 9:
                      var sn = k[1], Pe = [0, [0, jBr, e(xr, sn[2])], 0];
                      return w(MBr, I, 0, [0, [0, GBr, n(yr, sn[1])], Pe]);
                    case 10:
                      return S(k[1]);
                    case 11:
                      var We = k[1], en = [0, [0, BBr, xr(We[1])], 0];
                      return w(qBr, I, We[2], en);
                    case 12:
                      return dr([0, I, k[1]]);
                    case 13:
                      return X0([0, I, k[1]]);
                    case 14:
                      var _n = k[1], Dn = _n[1];
                      return typeof Dn != "number" && Dn[0] === 3 ? w(VYr, I, _n[3], [0, [0, YYr, u7], [0, [0, XYr, bn(_n[2])], 0]]) : f0([0, I, _n]);
                    case 15:
                      var Xn = k[1];
                      switch (Xn[1]) {
                        case 0:
                          var On = UBr;
                          break;
                        case 1:
                          var On = HBr;
                          break;
                        default:
                          var On = XBr;
                      }
                      var bt = [0, [0, YBr, xr(Xn[3])], 0], Ct = [0, [0, VBr, xr(Xn[2])], bt];
                      return w(KBr, I, Xn[4], [0, [0, zBr, bn(On)], Ct]);
                    case 16:
                      var Tt = k[1], Zt = Lr(Tt);
                      return w(WBr, I, Tt[3], Zt);
                    case 17:
                      var Ut = k[1], Ot = [0, [0, JBr, S(Ut[2])], 0], Pt = [0, [0, $Br, S(Ut[1])], Ot];
                      return w(ZBr, I, Ut[3], Pt);
                    case 18:
                      var yu = k[1], Ku = yu[4], pt = yu[3];
                      if (pt)
                        var xu = pt[1], Gu = y7(p(xu[2][2]), Ku), K7 = Gu, Vi = E0(xu);
                      else
                        var K7 = Ku, Vi = _u(0);
                      var a7 = [0, [0, rqr, e(ne, yu[2])], [0, [0, QBr, Vi], 0]];
                      return w(nqr, I, K7, [0, [0, eqr, xr(yu[1])], a7]);
                    case 19:
                      var Yc = k[1], W7 = [0, [0, tqr, n(p0, Yc[1])], 0];
                      return w(uqr, I, p(Yc[2]), W7);
                    case 20:
                      var Ht = k[1], mt = Ht[1], U0 = mt[4], R0 = y7(p(mt[3][2][2]), U0), Re = [0, [0, iqr, !!Ht[3]], 0];
                      return w(fqr, I, R0, xn(Tr(mt), Re));
                    case 21:
                      var Xe = k[1], he = Xe[1], _e = [0, [0, xqr, !!Xe[3]], 0], rt = xn(Lr(he), _e);
                      return w(aqr, I, he[3], rt);
                    case 22:
                      var wn = k[1], ft = [0, [0, oqr, n(xr, wn[1])], 0];
                      return w(cqr, I, wn[2], ft);
                    case 23:
                      return w(sqr, I, k[1][1], 0);
                    case 24:
                      var xt = k[1], Gn = [0, [0, oVr, Ar(xt[2])], 0], tt = [0, [0, cVr, xr(xt[1])], Gn];
                      return w(sVr, I, xt[3], tt);
                    case 25:
                      return Ar([0, I, k[1]]);
                    case 26:
                      return w(vqr, I, k[1][1], 0);
                    case 27:
                      var wt = k[1], un = [0, [0, lqr, l(wt[2])], 0], vn = [0, [0, bqr, xr(wt[1])], un];
                      return w(pqr, I, wt[3], vn);
                    case 28:
                      var ut = k[1], It = ut[3], Ti = ut[2], hs = ut[1];
                      if (7 <= hs)
                        return w(_qr, I, It, [0, [0, mqr, xr(Ti)], 0]);
                      switch (hs) {
                        case 0:
                          var Ou = yqr;
                          break;
                        case 1:
                          var Ou = dqr;
                          break;
                        case 2:
                          var Ou = hqr;
                          break;
                        case 3:
                          var Ou = kqr;
                          break;
                        case 4:
                          var Ou = wqr;
                          break;
                        case 5:
                          var Ou = Eqr;
                          break;
                        case 6:
                          var Ou = Sqr;
                          break;
                        default:
                          var Ou = ke(gqr);
                      }
                      var Vs = [0, [0, Tqr, true], [0, [0, Fqr, xr(Ti)], 0]];
                      return w(Iqr, I, It, [0, [0, Oqr, bn(Ou)], Vs]);
                    case 29:
                      var zi = k[1], zs = zi[1] ? Aqr : Nqr, Ks = [0, [0, Cqr, !!zi[3]], 0], nn = [0, [0, Pqr, xr(zi[2])], Ks];
                      return w(Lqr, I, zi[4], [0, [0, Dqr, bn(zs)], nn]);
                    default:
                      var si = k[1], Ws = [0, [0, Rqr, !!si[3]], 0], c2 = [0, [0, jqr, e(xr, si[1])], Ws];
                      return w(Gqr, I, si[2], c2);
                  }
                }
                function Rr(_) {
                  var k = _[2], I = k[7], U = k[3], Y = k[2], y0 = U[0] === 0 ? U[1] : ke(Jqr), D0 = I[0] === 0 ? 0 : [0, I[1]], A0 = k[9], D = y7(p(Y[2][4]), A0), u0 = [0, [0, $qr, e(qr, k[8])], 0], Y0 = [0, [0, Qqr, false], [0, [0, Zqr, e(l, D0)], u0]], J0 = [0, [0, rUr, e(Fr, k[6])], Y0], fr = [0, [0, nUr, !!k[4]], [0, [0, eUr, !!k[5]], J0]], Q0 = [0, [0, tUr, W0(y0)], fr], F0 = [0, [0, uUr, Hr(Y)], Q0], gr = [0, [0, iUr, e(S, k[1])], F0];
                  return w(fUr, _[1], D, gr);
                }
                function Wr(_) {
                  var k = _[2], I = [0, [0, IXr, n(fe, k[3])], 0], U = [0, [0, AXr, x0(0, k[4])], I], Y = [0, [0, NXr, e(qr, k[2])], U], y0 = [0, [0, CXr, S(k[1])], Y];
                  return w(PXr, _[1], k[5], y0);
                }
                function Jr(_, k) {
                  var I = k[2], U = _ ? nHr : tHr, Y = [0, [0, uHr, e(g0, I[4])], 0], y0 = [0, [0, iHr, e(g0, I[3])], Y], D0 = [0, [0, fHr, e(qr, I[2])], y0], A0 = [0, [0, xHr, S(I[1])], D0];
                  return w(U, k[1], I[5], A0);
                }
                function or(_) {
                  var k = _[2], I = [0, [0, ZUr, g0(k[3])], 0], U = [0, [0, QUr, e(qr, k[2])], I], Y = [0, [0, rHr, S(k[1])], U];
                  return w(eHr, _[1], k[4], Y);
                }
                function _r(_) {
                  if (_) {
                    var k = _[1];
                    if (k[0] === 0)
                      return n(ge, k[1]);
                    var I = k[1], U = I[2];
                    if (U) {
                      var Y = [0, [0, VUr, S(U[1])], 0];
                      return _u([0, w(zUr, I[1], 0, Y), 0]);
                    }
                    return _u(0);
                  }
                  return _u(0);
                }
                function Ir(_) {
                  return _ ? XUr : YUr;
                }
                function fe(_) {
                  var k = _[2], I = k[1], U = I[0] === 0 ? S(I[1]) : K(I[1]), Y = [0, [0, LXr, U], [0, [0, DXr, e($r, k[2])], 0]];
                  return w(RXr, _[1], k[3], Y);
                }
                function v0(_) {
                  var k = _[2], I = k[6], U = k[4], Y = _u(U ? [0, fe(U[1]), 0] : 0), y0 = I ? n(T0, I[1][2][1]) : _u(0), D0 = [0, [0, DUr, Y], [0, [0, PUr, y0], [0, [0, CUr, n(fe, k[5])], 0]]], A0 = [0, [0, LUr, x0(0, k[3])], D0], D = [0, [0, RUr, e(qr, k[2])], A0], u0 = [0, [0, jUr, S(k[1])], D];
                  return w(GUr, _[1], k[7], u0);
                }
                function P(_) {
                  var k = _[2], I = k[2], U = k[1], Y = ht(U[1], I[1]), y0 = [0, [0, IUr, e(Fr, k[3])], 0], D0 = [0, [0, AUr, w0(Y, [0, U, [1, I], 0])], y0];
                  return w(NUr, _[1], k[4], D0);
                }
                function L(_) {
                  var k = _[2], I = k[2], U = k[1], Y = [0, [0, TUr, w0(ht(U[1], I[1]), [0, U, [1, I], 0])], 0];
                  return w(OUr, _[1], k[3], Y);
                }
                function Q(_) {
                  var k = _[2], I = _[1];
                  switch (k[0]) {
                    case 0:
                      return W0([0, I, k[1]]);
                    case 1:
                      var U = k[1], Y = [0, [0, PGr, e(S, U[1])], 0];
                      return w(DGr, I, U[2], Y);
                    case 2:
                      return ar(aHr, [0, I, k[1]]);
                    case 3:
                      var y0 = k[1], D0 = [0, [0, LGr, e(S, y0[1])], 0];
                      return w(RGr, I, y0[2], D0);
                    case 4:
                      return w(jGr, I, k[1][1], 0);
                    case 5:
                      return v0([0, I, k[1]]);
                    case 6:
                      var A0 = k[1], D = A0[5], u0 = A0[4], Y0 = A0[3], J0 = A0[2];
                      if (Y0) {
                        var fr = Y0[1];
                        if (fr[0] !== 0 && !fr[1][2])
                          return w(MGr, I, D, [0, [0, GGr, e(t0, u0)], 0]);
                      }
                      if (J0) {
                        var Q0 = J0[1];
                        switch (Q0[0]) {
                          case 0:
                            var F0 = L(Q0[1]);
                            break;
                          case 1:
                            var F0 = P(Q0[1]);
                            break;
                          case 2:
                            var F0 = v0(Q0[1]);
                            break;
                          case 3:
                            var F0 = g0(Q0[1]);
                            break;
                          case 4:
                            var F0 = or(Q0[1]);
                            break;
                          case 5:
                            var F0 = Jr(1, Q0[1]);
                            break;
                          default:
                            var F0 = Wr(Q0[1]);
                        }
                        var gr = F0;
                      } else
                        var gr = u7;
                      var mr = [0, [0, BGr, e(t0, u0)], 0], Cr = [0, [0, UGr, gr], [0, [0, qGr, _r(Y0)], mr]], sr = A0[1], Pr = sr && 1;
                      return w(XGr, I, D, [0, [0, HGr, !!Pr], Cr]);
                    case 7:
                      return P([0, I, k[1]]);
                    case 8:
                      var K0 = k[1], Ur = [0, [0, MUr, n(fe, K0[3])], 0], d0 = [0, [0, BUr, x0(0, K0[4])], Ur], Kr = [0, [0, qUr, e(qr, K0[2])], d0], re = [0, [0, UUr, S(K0[1])], Kr];
                      return w(HUr, I, K0[5], re);
                    case 9:
                      var xe = k[1], je = xe[1], le = je[0] === 0 ? S(je[1]) : t0(je[1]), Ie = 0, Me = xe[3] ? "ES" : "CommonJS", Be = [0, [0, zGr, le], [0, [0, VGr, W0(xe[2])], [0, [0, YGr, Me], Ie]]];
                      return w(KGr, I, xe[4], Be);
                    case 10:
                      var an = k[1], Ke = [0, [0, WGr, l(an[1])], 0];
                      return w(JGr, I, an[2], Ke);
                    case 11:
                      var Ae = k[1], on = [0, [0, KUr, g0(Ae[3])], 0], rn = [0, [0, WUr, e(qr, Ae[2])], on], kn = [0, [0, JUr, S(Ae[1])], rn];
                      return w($Ur, I, Ae[4], kn);
                    case 12:
                      return Jr(1, [0, I, k[1]]);
                    case 13:
                      return L([0, I, k[1]]);
                    case 14:
                      var sn = k[1], Pe = [0, [0, $Gr, xr(sn[2])], 0], We = [0, [0, ZGr, Q(sn[1])], Pe];
                      return w(QGr, I, sn[3], We);
                    case 15:
                      return w(rMr, I, k[1][1], 0);
                    case 16:
                      var en = k[1], _n = en[2], Dn = _n[2], Xn = _n[1];
                      switch (Dn[0]) {
                        case 0:
                          var On = Dn[1], bt = [0, [0, vXr, !!On[2]], [0, [0, sXr, !!On[3]], 0]], Ct = On[1], Tt = [0, [0, lXr, n(function(du) {
                            var hu = du[2], Ii = hu[2], w7 = Ii[2], Wi = w7[1], nv = 0, Lb = Wi ? JYr : $Yr, tv = [0, [0, aXr, w(rVr, Ii[1], w7[2], [0, [0, QYr, !!Wi], [0, [0, ZYr, bn(Lb)], 0]])], nv], Rb = [0, [0, oXr, S(hu[1])], tv];
                            return w(cXr, du[1], 0, Rb);
                          }, Ct)], bt], mt = w(bXr, Xn, p(On[4]), Tt);
                          break;
                        case 1:
                          var Zt = Dn[1], Ut = [0, [0, mXr, !!Zt[2]], [0, [0, pXr, !!Zt[3]], 0]], Ot = Zt[1], Pt = [0, [0, _Xr, n(function(du) {
                            var hu = du[2], Ii = hu[2], w7 = Ii[2], Wi = [0, [0, iXr, w(HYr, Ii[1], w7[3], [0, [0, UYr, w7[1]], [0, [0, qYr, bn(w7[2])], 0]])], 0], nv = [0, [0, fXr, S(hu[1])], Wi];
                            return w(xXr, du[1], 0, nv);
                          }, Ot)], Ut], mt = w(yXr, Xn, p(Zt[4]), Pt);
                          break;
                        case 2:
                          var yu = Dn[1], Ku = yu[1];
                          if (Ku[0] === 0)
                            var pt = Ku[1], Gu = k1(function(du) {
                              var hu = [0, [0, tXr, S(du[2][1])], 0];
                              return w(uXr, du[1], 0, hu);
                            }, pt);
                          else
                            var xu = Ku[1], Gu = k1(function(du) {
                              var hu = du[2], Ii = [0, [0, rXr, t0(hu[2])], 0], w7 = [0, [0, eXr, S(hu[1])], Ii];
                              return w(nXr, du[1], 0, w7);
                            }, xu);
                          var K7 = [0, [0, hXr, !!yu[2]], [0, [0, dXr, !!yu[3]], 0]], Vi = [0, [0, kXr, _u(Gu)], K7], mt = w(wXr, Xn, p(yu[4]), Vi);
                          break;
                        default:
                          var a7 = Dn[1], Yc = [0, [0, EXr, !!a7[2]], 0], W7 = a7[1], Ht = [0, [0, SXr, n(function(du) {
                            var hu = [0, [0, ZHr, S(du[2][1])], 0];
                            return w(QHr, du[1], 0, hu);
                          }, W7)], Yc], mt = w(gXr, Xn, p(a7[3]), Ht);
                      }
                      var U0 = [0, [0, TXr, S(en[1])], [0, [0, FXr, mt], 0]];
                      return w(OXr, I, en[3], U0);
                    case 17:
                      var R0 = k[1], Re = R0[2], Xe = Re[0] === 0 ? Q(Re[1]) : xr(Re[1]), he = [0, [0, nMr, Xe], [0, [0, eMr, bn(Ir(1))], 0]];
                      return w(tMr, I, R0[3], he);
                    case 18:
                      var _e = k[1], rt = _e[5], wn = _e[4], ft = _e[3], xt = _e[2];
                      if (xt) {
                        var Gn = xt[1];
                        if (Gn[0] !== 0) {
                          var tt = [0, [0, uMr, bn(Ir(wn))], 0], wt = [0, [0, iMr, e(S, Gn[1][2])], tt];
                          return w(xMr, I, rt, [0, [0, fMr, e(t0, ft)], wt]);
                        }
                      }
                      var un = [0, [0, aMr, bn(Ir(wn))], 0], vn = [0, [0, oMr, e(t0, ft)], un], ut = [0, [0, cMr, _r(xt)], vn];
                      return w(vMr, I, rt, [0, [0, sMr, e(Q, _e[1])], ut]);
                    case 19:
                      var It = k[1], Ti = [0, [0, lMr, e(rn0, It[2])], 0], hs = [0, [0, bMr, xr(It[1])], Ti];
                      return w(pMr, I, It[3], hs);
                    case 20:
                      var Ou = k[1], Vs = function(du) {
                        return du[0] === 0 ? c0(du[1]) : xr(du[1]);
                      }, zi = [0, [0, mMr, Q(Ou[4])], 0], zs = [0, [0, _Mr, e(xr, Ou[3])], zi], Ks = [0, [0, yMr, e(xr, Ou[2])], zs], nn = [0, [0, dMr, e(Vs, Ou[1])], Ks];
                      return w(hMr, I, Ou[5], nn);
                    case 21:
                      var si = k[1], Ws = si[1], c2 = Ws[0] === 0 ? c0(Ws[1]) : Or(Ws[1]), B9 = [0, [0, kMr, !!si[4]], 0], q9 = [0, [0, wMr, Q(si[3])], B9], U9 = [0, [0, SMr, c2], [0, [0, EMr, xr(si[2])], q9]];
                      return w(gMr, I, si[5], U9);
                    case 22:
                      var Js = k[1], s2 = Js[1], H9 = s2[0] === 0 ? c0(s2[1]) : Or(s2[1]), X9 = [0, [0, FMr, !!Js[4]], 0], Y9 = [0, [0, TMr, Q(Js[3])], X9], X1 = [0, [0, IMr, H9], [0, [0, OMr, xr(Js[2])], Y9]];
                      return w(AMr, I, Js[5], X1);
                    case 23:
                      var vi = k[1], ob = vi[7], cb = vi[3], sb = vi[2], V9 = cb[0] === 0 ? cb[1] : ke(Mqr), z9 = ob[0] === 0 ? 0 : [0, ob[1]], K9 = vi[9], vb = y7(p(sb[2][4]), K9), W9 = [0, [0, Bqr, e(qr, vi[8])], 0], J9 = [0, [0, Uqr, false], [0, [0, qqr, e(l, z9)], W9]], $9 = [0, [0, Hqr, e(Fr, vi[6])], J9], Z9 = [0, [0, Yqr, !!vi[4]], [0, [0, Xqr, !!vi[5]], $9]], lb = [0, [0, Vqr, W0(V9)], Z9], Q9 = [0, [0, zqr, Hr(sb)], lb];
                      return w(Wqr, I, vb, [0, [0, Kqr, e(S, vi[1])], Q9]);
                    case 24:
                      var Y1 = k[1], v2 = Y1[3];
                      if (v2) {
                        var bb = v2[1][2], pb = bb[2], mb = bb[1], An = mb[2], Mn = function(hu) {
                          return y7(hu, pb);
                        };
                        switch (An[0]) {
                          case 0:
                            var V1 = An[1], _b = QD(V1[2], pb), Bn = [0, [0, V1[1], _b]];
                            break;
                          case 1:
                            var yb = An[1], r_ = Mn(yb[2]), Bn = [1, [0, yb[1], r_]];
                            break;
                          case 2:
                            var Vc = An[1], e_ = Mn(Vc[7]), Bn = [2, [0, Vc[1], Vc[2], Vc[3], Vc[4], Vc[5], Vc[6], e_]];
                            break;
                          case 3:
                            var l2 = An[1], db = Mn(l2[2]), Bn = [3, [0, l2[1], db]];
                            break;
                          case 4:
                            var Bn = [4, [0, Mn(An[1][1])]];
                            break;
                          case 5:
                            var zc = An[1], n_ = Mn(zc[7]), Bn = [5, [0, zc[1], zc[2], zc[3], zc[4], zc[5], zc[6], n_]];
                            break;
                          case 6:
                            var $s = An[1], hb = Mn($s[5]), Bn = [6, [0, $s[1], $s[2], $s[3], $s[4], hb]];
                            break;
                          case 7:
                            var z1 = An[1], t_ = Mn(z1[4]), Bn = [7, [0, z1[1], z1[2], z1[3], t_]];
                            break;
                          case 8:
                            var ks = An[1], u_ = Mn(ks[5]), Bn = [8, [0, ks[1], ks[2], ks[3], ks[4], u_]];
                            break;
                          case 9:
                            var K1 = An[1], i_ = Mn(K1[4]), Bn = [9, [0, K1[1], K1[2], K1[3], i_]];
                            break;
                          case 10:
                            var b2 = An[1], f_ = Mn(b2[2]), Bn = [10, [0, b2[1], f_]];
                            break;
                          case 11:
                            var Zs = An[1], kb = Mn(Zs[4]), Bn = [11, [0, Zs[1], Zs[2], Zs[3], kb]];
                            break;
                          case 12:
                            var Qs = An[1], x_ = Mn(Qs[5]), Bn = [12, [0, Qs[1], Qs[2], Qs[3], Qs[4], x_]];
                            break;
                          case 13:
                            var Ki = An[1], Kc = Mn(Ki[3]), Bn = [13, [0, Ki[1], Ki[2], Kc]];
                            break;
                          case 14:
                            var r1 = An[1], a_ = Mn(r1[3]), Bn = [14, [0, r1[1], r1[2], a_]];
                            break;
                          case 15:
                            var Bn = [15, [0, Mn(An[1][1])]];
                            break;
                          case 16:
                            var p2 = An[1], m2 = Mn(p2[3]), Bn = [16, [0, p2[1], p2[2], m2]];
                            break;
                          case 17:
                            var _2 = An[1], o_ = Mn(_2[3]), Bn = [17, [0, _2[1], _2[2], o_]];
                            break;
                          case 18:
                            var e1 = An[1], c_ = Mn(e1[5]), Bn = [18, [0, e1[1], e1[2], e1[3], e1[4], c_]];
                            break;
                          case 19:
                            var y2 = An[1], XL = Mn(y2[3]), Bn = [19, [0, y2[1], y2[2], XL]];
                            break;
                          case 20:
                            var W1 = An[1], YL = Mn(W1[5]), Bn = [20, [0, W1[1], W1[2], W1[3], W1[4], YL]];
                            break;
                          case 21:
                            var J1 = An[1], VL = Mn(J1[5]), Bn = [21, [0, J1[1], J1[2], J1[3], J1[4], VL]];
                            break;
                          case 22:
                            var $1 = An[1], zL = Mn($1[5]), Bn = [22, [0, $1[1], $1[2], $1[3], $1[4], zL]];
                            break;
                          case 23:
                            var Oi = An[1], KL = Oi[10], WL = Mn(Oi[9]), Bn = [23, [0, Oi[1], Oi[2], Oi[3], Oi[4], Oi[5], Oi[6], Oi[7], Oi[8], WL, KL]];
                            break;
                          case 24:
                            var d2 = An[1], JL = Mn(d2[4]), Bn = [24, [0, d2[1], d2[2], d2[3], JL]];
                            break;
                          case 25:
                            var Z1 = An[1], $L = Mn(Z1[5]), Bn = [25, [0, Z1[1], Z1[2], Z1[3], Z1[4], $L]];
                            break;
                          case 26:
                            var Q1 = An[1], ZL = Mn(Q1[5]), Bn = [26, [0, Q1[1], Q1[2], Q1[3], Q1[4], ZL]];
                            break;
                          case 27:
                            var wb = An[1], QL = Mn(wb[3]), Bn = [27, [0, wb[1], wb[2], QL]];
                            break;
                          case 28:
                            var Eb = An[1], rR = Eb[3], eR = Mn(Eb[2]), Bn = [28, [0, Eb[1], eR, rR]];
                            break;
                          case 29:
                            var h2 = An[1], nR = h2[4], tR = Mn(h2[3]), Bn = [29, [0, h2[1], h2[2], tR, nR]];
                            break;
                          case 30:
                            var s_ = An[1], uR = Mn(s_[2]), Bn = [30, [0, s_[1], uR]];
                            break;
                          case 31:
                            var k2 = An[1], iR = Mn(k2[4]), Bn = [31, [0, k2[1], k2[2], k2[3], iR]];
                            break;
                          case 32:
                            var w2 = An[1], fR = Mn(w2[4]), Bn = [32, [0, w2[1], w2[2], w2[3], fR]];
                            break;
                          case 33:
                            var rv = An[1], xR = Mn(rv[5]), Bn = [33, [0, rv[1], rv[2], rv[3], rv[4], xR]];
                            break;
                          case 34:
                            var Sb = An[1], aR = Mn(Sb[3]), Bn = [34, [0, Sb[1], Sb[2], aR]];
                            break;
                          case 35:
                            var gb = An[1], oR = Mn(gb[3]), Bn = [35, [0, gb[1], gb[2], oR]];
                            break;
                          default:
                            var Fb = An[1], cR = Mn(Fb[3]), Bn = [36, [0, Fb[1], Fb[2], cR]];
                        }
                        var v_ = Q([0, mb[1], Bn]);
                      } else
                        var v_ = u7;
                      var sR = [0, [0, CMr, Q(Y1[2])], [0, [0, NMr, v_], 0]], vR = [0, [0, PMr, xr(Y1[1])], sR];
                      return w(DMr, I, Y1[4], vR);
                    case 25:
                      var ev = k[1], Tb = ev[4], l_ = ev[3];
                      if (Tb) {
                        var Ob = Tb[1];
                        if (Ob[0] === 0)
                          var lR = Ob[1], p_ = k1(function(hu) {
                            var Ii = hu[1], w7 = hu[3], Wi = hu[2], nv = Wi ? ht(w7[1], Wi[1][1]) : w7[1], Lb = Wi ? Wi[1] : w7, tv = 0, Rb = 0;
                            if (Ii)
                              switch (Ii[1]) {
                                case 0:
                                  var jb = $c;
                                  break;
                                case 1:
                                  var jb = es;
                                  break;
                                default:
                                  tv = 1;
                              }
                            else
                              tv = 1;
                            if (tv)
                              var jb = u7;
                            var CR = [0, [0, TWr, S(Lb)], [0, [0, FWr, jb], Rb]];
                            return w(IWr, nv, 0, [0, [0, OWr, S(w7)], CR]);
                          }, lR);
                        else
                          var b_ = Ob[1], bR = [0, [0, SWr, S(b_[2])], 0], p_ = [0, w(gWr, b_[1], 0, bR), 0];
                        var Ib = p_;
                      } else
                        var Ib = Tb;
                      if (l_)
                        var m_ = l_[1], pR = [0, [0, wWr, S(m_)], 0], __ = [0, w(EWr, m_[1], 0, pR), Ib];
                      else
                        var __ = Ib;
                      switch (ev[1]) {
                        case 0:
                          var Ab = LMr;
                          break;
                        case 1:
                          var Ab = RMr;
                          break;
                        default:
                          var Ab = jMr;
                      }
                      var mR = [0, [0, GMr, bn(Ab)], 0], _R = [0, [0, MMr, t0(ev[2])], mR], yR = [0, [0, BMr, _u(__)], _R];
                      return w(qMr, I, ev[5], yR);
                    case 26:
                      return Wr([0, I, k[1]]);
                    case 27:
                      var Nb = k[1], dR = [0, [0, UMr, Q(Nb[2])], 0], hR = [0, [0, HMr, S(Nb[1])], dR];
                      return w(XMr, I, Nb[3], hR);
                    case 28:
                      var y_ = k[1], kR = [0, [0, YMr, e(xr, y_[1])], 0];
                      return w(VMr, I, y_[2], kR);
                    case 29:
                      var Cb = k[1], wR = [0, [0, zMr, n(i0, Cb[2])], 0], ER = [0, [0, KMr, xr(Cb[1])], wR];
                      return w(WMr, I, Cb[3], ER);
                    case 30:
                      var d_ = k[1], SR = [0, [0, JMr, xr(d_[1])], 0];
                      return w($Mr, I, d_[2], SR);
                    case 31:
                      var E2 = k[1], gR = [0, [0, ZMr, e(W0, E2[3])], 0], FR = [0, [0, QMr, e(l0, E2[2])], gR], TR = [0, [0, rBr, W0(E2[1])], FR];
                      return w(eBr, I, E2[4], TR);
                    case 32:
                      return or([0, I, k[1]]);
                    case 33:
                      return Jr(0, [0, I, k[1]]);
                    case 34:
                      return c0([0, I, k[1]]);
                    case 35:
                      var Pb = k[1], OR = [0, [0, nBr, Q(Pb[2])], 0], IR = [0, [0, tBr, xr(Pb[1])], OR];
                      return w(uBr, I, Pb[3], IR);
                    default:
                      var Db = k[1], AR = [0, [0, iBr, Q(Db[2])], 0], NR = [0, [0, fBr, xr(Db[1])], AR];
                      return w(xBr, I, Db[3], NR);
                  }
                }
                function i0(_) {
                  var k = _[2], I = [0, [0, dUr, n(Q, k[2])], 0], U = [0, [0, hUr, e(xr, k[1])], I];
                  return w(kUr, _[1], k[3], U);
                }
                function l0(_) {
                  var k = _[2], I = [0, [0, wUr, W0(k[2])], 0], U = [0, [0, EUr, e(Or, k[1])], I];
                  return w(SUr, _[1], k[3], U);
                }
                function S0(_) {
                  var k = _[2], I = [0, [0, _Hr, xr(k[1])], 0];
                  return w(yHr, _[1], k[2], I);
                }
                function T0(_) {
                  var k = _[2], I = [0, [0, dHr, e($r, k[2])], 0], U = [0, [0, hHr, S(k[1])], I];
                  return w(kHr, _[1], 0, U);
                }
                function er(_) {
                  switch (_[0]) {
                    case 0:
                      var k = _[1], I = k[2], U = I[6], Y = I[2];
                      switch (Y[0]) {
                        case 0:
                          var A0 = U, D = 0, u0 = f0(Y[1]);
                          break;
                        case 1:
                          var A0 = U, D = 0, u0 = S(Y[1]);
                          break;
                        case 2:
                          var A0 = U, D = 0, u0 = _0(Y[1]);
                          break;
                        default:
                          var y0 = Y[1][2], D0 = y7(y0[2], U), A0 = D0, D = 1, u0 = xr(y0[1]);
                      }
                      switch (I[1]) {
                        case 0:
                          var Y0 = SHr;
                          break;
                        case 1:
                          var Y0 = gHr;
                          break;
                        case 2:
                          var Y0 = FHr;
                          break;
                        default:
                          var Y0 = THr;
                      }
                      var J0 = [0, [0, IHr, !!D], [0, [0, OHr, n(S0, I[5])], 0]], fr = [0, [0, NHr, bn(Y0)], [0, [0, AHr, !!I[4]], J0]], Q0 = [0, [0, PHr, u0], [0, [0, CHr, Rr(I[3])], fr]];
                      return w(DHr, k[1], A0, Q0);
                    case 1:
                      var F0 = _[1], gr = F0[2], mr = gr[6], Cr = gr[2], sr = gr[1];
                      switch (sr[0]) {
                        case 0:
                          var d0 = mr, Kr = 0, re = f0(sr[1]);
                          break;
                        case 1:
                          var d0 = mr, Kr = 0, re = S(sr[1]);
                          break;
                        case 2:
                          var Pr = ke(HHr), d0 = Pr[3], Kr = Pr[2], re = Pr[1];
                          break;
                        default:
                          var K0 = sr[1][2], Ur = y7(K0[2], mr), d0 = Ur, Kr = 1, re = xr(K0[1]);
                      }
                      if (typeof Cr == "number")
                        if (Cr)
                          var xe = 0, je = 0;
                        else
                          var xe = 1, je = 0;
                      else
                        var xe = 0, je = [0, Cr[1]];
                      var le = xe && [0, [0, XHr, !!xe], 0], Ie = [0, [0, YHr, e(Sr, gr[5])], 0], Me = [0, [0, zHr, !!Kr], [0, [0, VHr, !!gr[4]], Ie]], Be = [0, [0, KHr, i(l, gr[3])], Me], an = xn([0, [0, JHr, re], [0, [0, WHr, e(xr, je)], Be]], le);
                      return w($Hr, F0[1], d0, an);
                    default:
                      var Ke = _[1], Ae = Ke[2], on = Ae[2];
                      if (typeof on == "number")
                        if (on)
                          var rn = 0, kn = 0;
                        else
                          var rn = 1, kn = 0;
                      else
                        var rn = 0, kn = [0, on[1]];
                      var sn = rn && [0, [0, LHr, !!rn], 0], Pe = [0, [0, RHr, e(Sr, Ae[5])], 0], We = [0, [0, GHr, false], [0, [0, jHr, !!Ae[4]], Pe]], en = [0, [0, MHr, i(l, Ae[3])], We], _n = [0, [0, BHr, e(xr, kn)], en], Dn = xn([0, [0, qHr, _0(Ae[1])], _n], sn);
                      return w(UHr, Ke[1], Ae[6], Dn);
                  }
                }
                function j0(_) {
                  var k = _[2], I = k[2], U = k[1];
                  if (I) {
                    var Y = [0, [0, HXr, xr(I[1])], 0], y0 = [0, [0, XXr, Or(U)], Y];
                    return w(YXr, _[1], 0, y0);
                  }
                  return Or(U);
                }
                function B(_, k) {
                  var I = [0, [0, $Xr, Or(k[1])], 0];
                  return w(ZXr, _, k[2], I);
                }
                function Z(_) {
                  switch (_[0]) {
                    case 0:
                      var k = _[1], I = k[2], U = I[2], Y = I[1];
                      if (U) {
                        var y0 = [0, [0, QXr, xr(U[1])], 0], D0 = [0, [0, rYr, Or(Y)], y0];
                        return w(eYr, k[1], 0, D0);
                      }
                      return Or(Y);
                    case 1:
                      var A0 = _[1];
                      return B(A0[1], A0[2]);
                    default:
                      return u7;
                  }
                }
                function p0(_) {
                  if (_[0] === 0) {
                    var k = _[1], I = k[2];
                    switch (I[0]) {
                      case 0:
                        var U = xr(I[2]), Y0 = 0, J0 = I[3], fr = 0, Q0 = nYr, F0 = U, gr = I[1];
                        break;
                      case 1:
                        var Y = I[2], y0 = Rr([0, Y[1], Y[2]]), Y0 = 0, J0 = 0, fr = 1, Q0 = tYr, F0 = y0, gr = I[1];
                        break;
                      case 2:
                        var D0 = I[2], A0 = Rr([0, D0[1], D0[2]]), Y0 = I[3], J0 = 0, fr = 0, Q0 = uYr, F0 = A0, gr = I[1];
                        break;
                      default:
                        var D = I[2], u0 = Rr([0, D[1], D[2]]), Y0 = I[3], J0 = 0, fr = 0, Q0 = iYr, F0 = u0, gr = I[1];
                    }
                    switch (gr[0]) {
                      case 0:
                        var Pr = Y0, K0 = 0, Ur = f0(gr[1]);
                        break;
                      case 1:
                        var Pr = Y0, K0 = 0, Ur = S(gr[1]);
                        break;
                      case 2:
                        var mr = ke(fYr), Pr = mr[3], K0 = mr[2], Ur = mr[1];
                        break;
                      default:
                        var Cr = gr[1][2], sr = y7(Cr[2], Y0), Pr = sr, K0 = 1, Ur = xr(Cr[1]);
                    }
                    return w(lYr, k[1], Pr, [0, [0, vYr, Ur], [0, [0, sYr, F0], [0, [0, cYr, bn(Q0)], [0, [0, oYr, !!fr], [0, [0, aYr, !!J0], [0, [0, xYr, !!K0], 0]]]]]]);
                  }
                  var d0 = _[1], Kr = d0[2], re = [0, [0, bYr, xr(Kr[1])], 0];
                  return w(pYr, d0[1], Kr[2], re);
                }
                function b0(_) {
                  if (_[0] === 0) {
                    var k = _[1], I = k[2], U = I[3], Y = I[2], y0 = I[1];
                    switch (y0[0]) {
                      case 0:
                        var D = 0, u0 = 0, Y0 = f0(y0[1]);
                        break;
                      case 1:
                        var D = 0, u0 = 0, Y0 = S(y0[1]);
                        break;
                      default:
                        var D0 = y0[1][2], A0 = xr(D0[1]), D = D0[2], u0 = 1, Y0 = A0;
                    }
                    if (U)
                      var J0 = U[1], fr = ht(Y[1], J0[1]), Q0 = [0, [0, mYr, xr(J0)], 0], F0 = w(yYr, fr, 0, [0, [0, _Yr, Or(Y)], Q0]);
                    else
                      var F0 = Or(Y);
                    return w(gYr, k[1], D, [0, [0, SYr, Y0], [0, [0, EYr, F0], [0, [0, wYr, Gi], [0, [0, kYr, false], [0, [0, hYr, !!I[4]], [0, [0, dYr, !!u0], 0]]]]]]);
                  }
                  var gr = _[1];
                  return B(gr[1], gr[2]);
                }
                function O0(_) {
                  var k = _[2], I = [0, [0, FYr, xr(k[1])], 0];
                  return w(TYr, _[1], k[2], I);
                }
                function q0(_) {
                  return _[0] === 0 ? xr(_[1]) : O0(_[1]);
                }
                function nr(_) {
                  switch (_[0]) {
                    case 0:
                      return xr(_[1]);
                    case 1:
                      return O0(_[1]);
                    default:
                      return u7;
                  }
                }
                function yr(_) {
                  var k = _[2], I = [0, [0, OYr, !!k[3]], 0], U = [0, [0, IYr, xr(k[2])], I], Y = [0, [0, AYr, Or(k[1])], U];
                  return w(NYr, _[1], 0, Y);
                }
                function vr(_) {
                  var k = _[2], I = k[1], U = H1([0, [0, iVr, bn(I[1])], [0, [0, uVr, bn(I[2])], 0]]);
                  return w(aVr, _[1], 0, [0, [0, xVr, U], [0, [0, fVr, !!k[2]], 0]]);
                }
                function $0(_) {
                  var k = _[2], I = [0, [0, yVr, e(xr, k[2])], 0], U = [0, [0, dVr, Or(k[1])], I];
                  return w(hVr, _[1], 0, U);
                }
                function Sr(_) {
                  var k = _[2], I = k[1] ? pY : "plus";
                  return w(wVr, _[1], k[2], [0, [0, kVr, I], 0]);
                }
                function Mr(_) {
                  var k = _[2];
                  return k0(k[2], k[1]);
                }
                function Br(_) {
                  var k = _[2], I = [0, [0, VVr, g0(k[1][2])], [0, [0, YVr, false], 0]], U = [0, [0, zVr, e(S, 0)], I];
                  return w(KVr, _[1], k[2], U);
                }
                function qr(_) {
                  var k = _[2], I = [0, [0, SKr, n(jr, k[1])], 0], U = p(k[2]);
                  return w(gKr, _[1], U, I);
                }
                function jr(_) {
                  var k = _[2], I = k[1][2], U = [0, [0, FKr, e(g0, k[4])], 0], Y = [0, [0, TKr, e(Sr, k[3])], U], y0 = [0, [0, OKr, i(l, k[2])], Y];
                  return w(AKr, _[1], I[2], [0, [0, IKr, bn(I[1])], y0]);
                }
                function $r(_) {
                  var k = _[2], I = [0, [0, NKr, n(g0, k[1])], 0], U = p(k[2]);
                  return w(CKr, _[1], U, I);
                }
                function ne(_) {
                  var k = _[2], I = [0, [0, PKr, n(Qr, k[1])], 0], U = p(k[2]);
                  return w(DKr, _[1], U, I);
                }
                function Qr(_) {
                  if (_[0] === 0)
                    return g0(_[1]);
                  var k = _[1], I = k[1], U = k[2][1];
                  return V([0, I, [0, [0, Gc(0, [0, I, LKr])], 0, U]]);
                }
                function pe(_) {
                  if (_[0] === 0) {
                    var k = _[1], I = k[2], U = I[1], Y = U[0] === 0 ? b(U[1]) : G0(U[1]), y0 = [0, [0, QKr, Y], [0, [0, ZKr, e(ce, I[2])], 0]];
                    return w(rWr, k[1], 0, y0);
                  }
                  var D0 = _[1], A0 = D0[2], D = [0, [0, eWr, xr(A0[1])], 0];
                  return w(nWr, D0[1], A0[2], D);
                }
                function oe(_) {
                  var k = [0, [0, WKr, s0(_[2][1])], 0];
                  return w(JKr, _[1], 0, k);
                }
                function me(_) {
                  var k = _[2], I = k[1], U = _[1], Y = I ? xr(I[1]) : w(tWr, [0, U[1], [0, U[2][1], U[2][2] + 1 | 0], [0, U[3][1], U[3][2] - 1 | 0]], 0, 0);
                  return w(iWr, U, p(k[2]), [0, [0, uWr, Y], 0]);
                }
                function ae(_) {
                  var k = _[2], I = _[1];
                  switch (k[0]) {
                    case 0:
                      return dr([0, I, k[1]]);
                    case 1:
                      return X0([0, I, k[1]]);
                    case 2:
                      return me([0, I, k[1]]);
                    case 3:
                      var U = k[1], Y = [0, [0, fWr, xr(U[1])], 0];
                      return w(xWr, I, U[2], Y);
                    default:
                      var y0 = k[1];
                      return w(cWr, I, 0, [0, [0, oWr, bn(y0[1])], [0, [0, aWr, bn(y0[2])], 0]]);
                  }
                }
                function ce(_) {
                  return _[0] === 0 ? f0([0, _[1], _[2]]) : me([0, _[1], _[2]]);
                }
                function ge(_) {
                  var k = _[2], I = k[2], U = k[1], Y = S(I ? I[1] : U), y0 = [0, [0, hWr, S(U)], [0, [0, dWr, Y], 0]];
                  return w(kWr, _[1], 0, y0);
                }
                function H0(_) {
                  var k = _[2];
                  if (k[1])
                    var I = k[2], U = AWr;
                  else
                    var I = k[2], U = NWr;
                  return w(U, _[1], 0, [0, [0, CWr, bn(I)], 0]);
                }
                function Fr(_) {
                  var k = _[2], I = k[1];
                  if (I)
                    var U = [0, [0, PWr, xr(I[1])], 0], Y = DWr;
                  else
                    var U = 0, Y = LWr;
                  return w(Y, _[1], k[2], U);
                }
                return [0, A, xr];
              }
              function T(E) {
                return y(E)[1];
              }
              return [0, T, function(E) {
                return y(E)[2];
              }, s];
            }(Bne);
            function ab(t4, n, e) {
              var i = n[e];
              return Bp(i) ? i | 0 : t4;
            }
            function qne(t4, n) {
              var e = qV(n, eK) ? {} : n, i = B7(t4), x = ab(Bv[5], e, Wre), c = ab(Bv[4], e, Jre), s = ab(Bv[3], e, $re), p = ab(Bv[2], e, Zre), y = [0, [0, ab(Bv[1], e, Qre), p, s, c, x]], T = e.tokens, E = Bp(T), h = E && T | 0, w = e.comments, G = Bp(w) ? w | 0 : 1, A = e.all_comments, S = Bp(A) ? A | 0 : 1, M = [0, 0], K = h && [0, function(b0) {
                return M[1] = [0, b0, M[1]], 0;
              }], V = [0, y], f0 = [0, K], m0 = oz ? oz[1] : 1, k0 = f0 && f0[1], g0 = V && V[1], e0 = [0, g0], x0 = [0, k0], l = 0, c0 = x0 && x0[1], t0 = e0 && e0[1], a0 = xne([0, c0], [0, t0], l, i), w0 = u(ve[1], a0), _0 = de(a0[1][1]), E0 = [0, GL[1], 0], X0 = de(be(function(b0, O0) {
                var q0 = b0[2], nr = b0[1];
                return a(GL[3], O0, nr) ? [0, nr, q0] : [0, a(GL[4], O0, nr), [0, O0, q0]];
              }, E0, _0)[2]);
              if (X0 && m0)
                throw [0, Wee, X0[1], X0[2]];
              Qe0[1] = 0;
              for (var b = tn(i) - 0 | 0, G0 = i, X = 0, s0 = 0; ; ) {
                if (s0 === b)
                  var dr = X;
                else {
                  var Ar = Hu(G0, s0), ar = 0;
                  if (0 <= Ar && !(Kn < Ar))
                    var W0 = 1;
                  else
                    ar = 1;
                  if (ar) {
                    var Lr = 0;
                    if (iI <= Ar && !(d8 < Ar))
                      var W0 = 2;
                    else
                      Lr = 1;
                    if (Lr) {
                      var Tr = 0;
                      if (dv <= Ar && !(f6 < Ar))
                        var W0 = 3;
                      else
                        Tr = 1;
                      if (Tr) {
                        var Hr = 0;
                        if (v1 <= Ar && !(l8 < Ar))
                          var W0 = 4;
                        else
                          Hr = 1;
                        if (Hr)
                          var W0 = 0;
                      }
                    }
                  }
                  if (W0 === 0) {
                    var X = TL(X, s0, 0), s0 = s0 + 1 | 0;
                    continue;
                  }
                  if (!((b - s0 | 0) < W0)) {
                    var Or = W0 - 1 | 0, xr = s0 + W0 | 0;
                    if (3 < Or >>> 0)
                      throw [0, Fn, _o0];
                    switch (Or) {
                      case 0:
                        var Rr = Hu(G0, s0);
                        break;
                      case 1:
                        var Rr = (Hu(G0, s0) & 31) << 6 | Hu(G0, s0 + 1 | 0) & 63;
                        break;
                      case 2:
                        var Rr = (Hu(G0, s0) & 15) << 12 | (Hu(G0, s0 + 1 | 0) & 63) << 6 | Hu(G0, s0 + 2 | 0) & 63;
                        break;
                      default:
                        var Rr = (Hu(G0, s0) & 7) << 18 | (Hu(G0, s0 + 1 | 0) & 63) << 12 | (Hu(G0, s0 + 2 | 0) & 63) << 6 | Hu(G0, s0 + 3 | 0) & 63;
                    }
                    var X = TL(X, s0, [0, Rr]), s0 = xr;
                    continue;
                  }
                  var dr = TL(X, s0, 0);
                }
                for (var Wr = kGr, Jr = de([0, 6, dr]); ; ) {
                  var or = Wr[3], _r = Wr[2], Ir = Wr[1];
                  if (Jr) {
                    var fe = Jr[1];
                    if (fe === 5) {
                      var v0 = Jr[2];
                      if (v0 && v0[1] === 6) {
                        var P = _l(de([0, Ir, _r])), Wr = [0, Ir + 2 | 0, 0, [0, P, or]], Jr = v0[2];
                        continue;
                      }
                    } else if (!(6 <= fe)) {
                      var L = Jr[2], Wr = [0, Ir + Te0(fe) | 0, [0, Ir, _r], or], Jr = L;
                      continue;
                    }
                    var Q = _l(de([0, Ir, _r])), i0 = Jr[2], Wr = [0, Ir + Te0(fe) | 0, 0, [0, Q, or]], Jr = i0;
                    continue;
                  }
                  var l0 = _l(de(or));
                  if (G)
                    var T0 = w0;
                  else
                    var S0 = u(Yee[1], 0), T0 = a(Qe(S0, -201766268, 25), S0, w0);
                  if (S)
                    var j0 = T0;
                  else
                    var er = T0[2], j0 = [0, T0[1], [0, er[1], er[2], 0]];
                  var B = a(nn0[1], [0, l0], j0), Z = xn(X0, Qe0[1]);
                  if (B.errors = u(nn0[3], Z), h) {
                    var p0 = M[1];
                    B.tokens = _u(Tp(u(Mne[1], l0), p0));
                  }
                  return B;
                }
              }
            }
            if (typeof I0 < "u")
              var tn0 = I0;
            else {
              var un0 = {};
              qN.flow = un0;
              var tn0 = un0;
            }
            tn0.parse = function(t4, n) {
              try {
                var e = qne(t4, n);
                return e;
              } catch (i) {
                return i = gt(i), i[1] === UN ? u(nK, i[2]) : u(nK, new Gee(bn(Te(ree, Pp(i)))));
              }
            }, xN(0);
          }(globalThis);
        } });
        Dt();
        var Tae = Hu0(), Oae = pae(), Iae = mae(), Aae = wae(), Nae = { comments: false, enums: true, esproposal_decorators: true, esproposal_export_star_as: true, tokens: true };
        function Cae(I0) {
          let { message: L0, loc: { start: rr, end: hr } } = I0;
          return Tae(L0, { start: { line: rr.line, column: rr.column + 1 }, end: { line: hr.line, column: hr.column + 1 } });
        }
        function Pae(I0, L0) {
          let rr = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, { parse: hr } = Fae(), se = hr(Iae(I0), Nae), [qe] = se.errors;
          if (qe)
            throw Cae(qe);
          return rr.originalText = I0, Aae(se, rr);
        }
        s70.exports = { parsers: { flow: Oae(Pae) } };
      });
      return Dae();
    });
  }
});

// node_modules/prettier/parser-typescript.js
var require_parser_typescript = __commonJS({
  "node_modules/prettier/parser-typescript.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.typescript = e();
      }
    })(function() {
      "use strict";
      var Et = (a, _) => () => (_ || a((_ = { exports: {} }).exports, _), _.exports);
      var Ra = Et((BT, Bf) => {
        var rl = function(a) {
          return a && a.Math == Math && a;
        };
        Bf.exports = rl(typeof globalThis == "object" && globalThis) || rl(typeof window == "object" && window) || rl(typeof self == "object" && self) || rl(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var $a = Et((qT, qf) => {
        qf.exports = function(a) {
          try {
            return !!a();
          } catch {
            return true;
          }
        };
      });
      var Wo = Et((UT, Uf) => {
        var Vh = $a();
        Uf.exports = !Vh(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var tl = Et((zT, zf) => {
        var Wh = $a();
        zf.exports = !Wh(function() {
          var a = function() {
          }.bind();
          return typeof a != "function" || a.hasOwnProperty("prototype");
        });
      });
      var il = Et((VT, Vf) => {
        var Kh = tl(), nl = Function.prototype.call;
        Vf.exports = Kh ? nl.bind(nl) : function() {
          return nl.apply(nl, arguments);
        };
      });
      var Gf = Et((Hf) => {
        "use strict";
        var Wf = {}.propertyIsEnumerable, Kf = Object.getOwnPropertyDescriptor, Hh = Kf && !Wf.call({ 1: 2 }, 1);
        Hf.f = Hh ? function(_) {
          var D = Kf(this, _);
          return !!D && D.enumerable;
        } : Wf;
      });
      var ep = Et((KT, Xf) => {
        Xf.exports = function(a, _) {
          return { enumerable: !(a & 1), configurable: !(a & 2), writable: !(a & 4), value: _ };
        };
      });
      var Qa = Et((HT, Yf) => {
        var $f = tl(), Qf = Function.prototype, rp = Qf.call, Gh = $f && Qf.bind.bind(rp, rp);
        Yf.exports = $f ? Gh : function(a) {
          return function() {
            return rp.apply(a, arguments);
          };
        };
      });
      var Iu = Et((GT, ed) => {
        var Zf = Qa(), Xh = Zf({}.toString), $h = Zf("".slice);
        ed.exports = function(a) {
          return $h(Xh(a), 8, -1);
        };
      });
      var td = Et((XT, rd) => {
        var Qh = Qa(), Yh = $a(), Zh = Iu(), tp = Object, e0 = Qh("".split);
        rd.exports = Yh(function() {
          return !tp("z").propertyIsEnumerable(0);
        }) ? function(a) {
          return Zh(a) == "String" ? e0(a, "") : tp(a);
        } : tp;
      });
      var np = Et(($T, nd) => {
        nd.exports = function(a) {
          return a == null;
        };
      });
      var ip = Et((QT, id) => {
        var r0 = np(), t0 = TypeError;
        id.exports = function(a) {
          if (r0(a))
            throw t0("Can't call method on " + a);
          return a;
        };
      });
      var al = Et((YT, ad) => {
        var n0 = td(), i0 = ip();
        ad.exports = function(a) {
          return n0(i0(a));
        };
      });
      var op = Et((ZT, od) => {
        var ap = typeof document == "object" && document.all, a0 = typeof ap > "u" && ap !== void 0;
        od.exports = { all: ap, IS_HTMLDDA: a0 };
      });
      var xa = Et((e6, _d) => {
        var sd = op(), o0 = sd.all;
        _d.exports = sd.IS_HTMLDDA ? function(a) {
          return typeof a == "function" || a === o0;
        } : function(a) {
          return typeof a == "function";
        };
      });
      var C_ = Et((r6, ld) => {
        var cd = xa(), ud = op(), s0 = ud.all;
        ld.exports = ud.IS_HTMLDDA ? function(a) {
          return typeof a == "object" ? a !== null : cd(a) || a === s0;
        } : function(a) {
          return typeof a == "object" ? a !== null : cd(a);
        };
      });
      var Ou = Et((t6, pd) => {
        var sp = Ra(), _0 = xa(), c0 = function(a) {
          return _0(a) ? a : void 0;
        };
        pd.exports = function(a, _) {
          return arguments.length < 2 ? c0(sp[a]) : sp[a] && sp[a][_];
        };
      });
      var dd = Et((n6, fd) => {
        var u0 = Qa();
        fd.exports = u0({}.isPrototypeOf);
      });
      var gd = Et((i6, md) => {
        var l0 = Ou();
        md.exports = l0("navigator", "userAgent") || "";
      });
      var Sd = Et((a6, Td) => {
        var Ed = Ra(), _p = gd(), yd = Ed.process, hd = Ed.Deno, vd = yd && yd.versions || hd && hd.version, bd = vd && vd.v8, Ya, ol;
        bd && (Ya = bd.split("."), ol = Ya[0] > 0 && Ya[0] < 4 ? 1 : +(Ya[0] + Ya[1]));
        !ol && _p && (Ya = _p.match(/Edge\/(\d+)/), (!Ya || Ya[1] >= 74) && (Ya = _p.match(/Chrome\/(\d+)/), Ya && (ol = +Ya[1])));
        Td.exports = ol;
      });
      var cp = Et((o6, Dd) => {
        var Cd = Sd(), p0 = $a();
        Dd.exports = !!Object.getOwnPropertySymbols && !p0(function() {
          var a = Symbol();
          return !String(a) || !(Object(a) instanceof Symbol) || !Symbol.sham && Cd && Cd < 41;
        });
      });
      var up = Et((s6, xd) => {
        var f0 = cp();
        xd.exports = f0 && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var lp = Et((_6, wd) => {
        var d0 = Ou(), m0 = xa(), g0 = dd(), y0 = up(), h0 = Object;
        wd.exports = y0 ? function(a) {
          return typeof a == "symbol";
        } : function(a) {
          var _ = d0("Symbol");
          return m0(_) && g0(_.prototype, h0(a));
        };
      });
      var kd = Et((c6, Ad) => {
        var v0 = String;
        Ad.exports = function(a) {
          try {
            return v0(a);
          } catch {
            return "Object";
          }
        };
      });
      var sl = Et((u6, Pd) => {
        var b0 = xa(), E0 = kd(), T0 = TypeError;
        Pd.exports = function(a) {
          if (b0(a))
            return a;
          throw T0(E0(a) + " is not a function");
        };
      });
      var Id = Et((l6, Nd) => {
        var S0 = sl(), C0 = np();
        Nd.exports = function(a, _) {
          var D = a[_];
          return C0(D) ? void 0 : S0(D);
        };
      });
      var Md = Et((p6, Od) => {
        var pp = il(), fp = xa(), dp = C_(), D0 = TypeError;
        Od.exports = function(a, _) {
          var D, T;
          if (_ === "string" && fp(D = a.toString) && !dp(T = pp(D, a)) || fp(D = a.valueOf) && !dp(T = pp(D, a)) || _ !== "string" && fp(D = a.toString) && !dp(T = pp(D, a)))
            return T;
          throw D0("Can't convert object to primitive value");
        };
      });
      var Rd = Et((f6, Ld) => {
        Ld.exports = false;
      });
      var _l = Et((d6, Jd) => {
        var jd = Ra(), x0 = Object.defineProperty;
        Jd.exports = function(a, _) {
          try {
            x0(jd, a, { value: _, configurable: true, writable: true });
          } catch {
            jd[a] = _;
          }
          return _;
        };
      });
      var cl = Et((m6, Bd) => {
        var w0 = Ra(), A0 = _l(), Fd = "__core-js_shared__", k0 = w0[Fd] || A0(Fd, {});
        Bd.exports = k0;
      });
      var mp = Et((g6, Ud) => {
        var P0 = Rd(), qd = cl();
        (Ud.exports = function(a, _) {
          return qd[a] || (qd[a] = _ !== void 0 ? _ : {});
        })("versions", []).push({ version: "3.26.1", mode: P0 ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var gp = Et((y6, zd) => {
        var N0 = ip(), I0 = Object;
        zd.exports = function(a) {
          return I0(N0(a));
        };
      });
      var Ps = Et((h6, Vd) => {
        var O0 = Qa(), M0 = gp(), L0 = O0({}.hasOwnProperty);
        Vd.exports = Object.hasOwn || function(_, D) {
          return L0(M0(_), D);
        };
      });
      var yp = Et((v6, Wd) => {
        var R0 = Qa(), j0 = 0, J0 = Math.random(), F0 = R0(1 .toString);
        Wd.exports = function(a) {
          return "Symbol(" + (a === void 0 ? "" : a) + ")_" + F0(++j0 + J0, 36);
        };
      });
      var Mu = Et((b6, $d) => {
        var B0 = Ra(), q0 = mp(), Kd = Ps(), U0 = yp(), Hd = cp(), Xd = up(), Fc = q0("wks"), D_ = B0.Symbol, Gd = D_ && D_.for, z0 = Xd ? D_ : D_ && D_.withoutSetter || U0;
        $d.exports = function(a) {
          if (!Kd(Fc, a) || !(Hd || typeof Fc[a] == "string")) {
            var _ = "Symbol." + a;
            Hd && Kd(D_, a) ? Fc[a] = D_[a] : Xd && Gd ? Fc[a] = Gd(_) : Fc[a] = z0(_);
          }
          return Fc[a];
        };
      });
      var em = Et((E6, Zd) => {
        var V0 = il(), Qd = C_(), Yd = lp(), W0 = Id(), K0 = Md(), H0 = Mu(), G0 = TypeError, X0 = H0("toPrimitive");
        Zd.exports = function(a, _) {
          if (!Qd(a) || Yd(a))
            return a;
          var D = W0(a, X0), T;
          if (D) {
            if (_ === void 0 && (_ = "default"), T = V0(D, a, _), !Qd(T) || Yd(T))
              return T;
            throw G0("Can't convert object to primitive value");
          }
          return _ === void 0 && (_ = "number"), K0(a, _);
        };
      });
      var hp = Et((T6, rm) => {
        var $0 = em(), Q0 = lp();
        rm.exports = function(a) {
          var _ = $0(a, "string");
          return Q0(_) ? _ : _ + "";
        };
      });
      var im = Et((S6, nm) => {
        var Y0 = Ra(), tm = C_(), vp = Y0.document, Z0 = tm(vp) && tm(vp.createElement);
        nm.exports = function(a) {
          return Z0 ? vp.createElement(a) : {};
        };
      });
      var bp = Et((C6, am) => {
        var ev = Wo(), rv = $a(), tv = im();
        am.exports = !ev && !rv(function() {
          return Object.defineProperty(tv("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Ep = Et((sm) => {
        var nv = Wo(), iv = il(), av = Gf(), ov = ep(), sv = al(), _v = hp(), cv = Ps(), uv = bp(), om = Object.getOwnPropertyDescriptor;
        sm.f = nv ? om : function(_, D) {
          if (_ = sv(_), D = _v(D), uv)
            try {
              return om(_, D);
            } catch {
            }
          if (cv(_, D))
            return ov(!iv(av.f, _, D), _[D]);
        };
      });
      var cm = Et((x6, _m) => {
        var lv = Wo(), pv = $a();
        _m.exports = lv && pv(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var ul = Et((w6, um) => {
        var fv = C_(), dv = String, mv = TypeError;
        um.exports = function(a) {
          if (fv(a))
            return a;
          throw mv(dv(a) + " is not an object");
        };
      });
      var Lu = Et((pm) => {
        var gv = Wo(), yv = bp(), hv = cm(), ll = ul(), lm = hp(), vv = TypeError, Tp = Object.defineProperty, bv = Object.getOwnPropertyDescriptor, Sp = "enumerable", Cp = "configurable", Dp = "writable";
        pm.f = gv ? hv ? function(_, D, T) {
          if (ll(_), D = lm(D), ll(T), typeof _ == "function" && D === "prototype" && "value" in T && Dp in T && !T[Dp]) {
            var ae = bv(_, D);
            ae && ae[Dp] && (_[D] = T.value, T = { configurable: Cp in T ? T[Cp] : ae[Cp], enumerable: Sp in T ? T[Sp] : ae[Sp], writable: false });
          }
          return Tp(_, D, T);
        } : Tp : function(_, D, T) {
          if (ll(_), D = lm(D), ll(T), yv)
            try {
              return Tp(_, D, T);
            } catch {
            }
          if ("get" in T || "set" in T)
            throw vv("Accessors not supported");
          return "value" in T && (_[D] = T.value), _;
        };
      });
      var xp = Et((k6, fm) => {
        var Ev = Wo(), Tv = Lu(), Sv = ep();
        fm.exports = Ev ? function(a, _, D) {
          return Tv.f(a, _, Sv(1, D));
        } : function(a, _, D) {
          return a[_] = D, a;
        };
      });
      var gm = Et((P6, mm) => {
        var wp = Wo(), Cv = Ps(), dm = Function.prototype, Dv = wp && Object.getOwnPropertyDescriptor, Ap = Cv(dm, "name"), xv = Ap && function() {
        }.name === "something", wv = Ap && (!wp || wp && Dv(dm, "name").configurable);
        mm.exports = { EXISTS: Ap, PROPER: xv, CONFIGURABLE: wv };
      });
      var Pp = Et((N6, ym) => {
        var Av = Qa(), kv = xa(), kp = cl(), Pv = Av(Function.toString);
        kv(kp.inspectSource) || (kp.inspectSource = function(a) {
          return Pv(a);
        });
        ym.exports = kp.inspectSource;
      });
      var bm = Et((I6, vm) => {
        var Nv = Ra(), Iv = xa(), hm = Nv.WeakMap;
        vm.exports = Iv(hm) && /native code/.test(String(hm));
      });
      var Sm = Et((O6, Tm) => {
        var Ov = mp(), Mv = yp(), Em = Ov("keys");
        Tm.exports = function(a) {
          return Em[a] || (Em[a] = Mv(a));
        };
      });
      var Np = Et((M6, Cm) => {
        Cm.exports = {};
      });
      var Am = Et((L6, wm) => {
        var Lv = bm(), xm = Ra(), Rv = C_(), jv = xp(), Ip = Ps(), Op = cl(), Jv = Sm(), Fv = Np(), Dm = "Object already initialized", Mp = xm.TypeError, Bv = xm.WeakMap, pl, Ru, fl, qv = function(a) {
          return fl(a) ? Ru(a) : pl(a, {});
        }, Uv = function(a) {
          return function(_) {
            var D;
            if (!Rv(_) || (D = Ru(_)).type !== a)
              throw Mp("Incompatible receiver, " + a + " required");
            return D;
          };
        };
        Lv || Op.state ? (Za = Op.state || (Op.state = new Bv()), Za.get = Za.get, Za.has = Za.has, Za.set = Za.set, pl = function(a, _) {
          if (Za.has(a))
            throw Mp(Dm);
          return _.facade = a, Za.set(a, _), _;
        }, Ru = function(a) {
          return Za.get(a) || {};
        }, fl = function(a) {
          return Za.has(a);
        }) : (x_ = Jv("state"), Fv[x_] = true, pl = function(a, _) {
          if (Ip(a, x_))
            throw Mp(Dm);
          return _.facade = a, jv(a, x_, _), _;
        }, Ru = function(a) {
          return Ip(a, x_) ? a[x_] : {};
        }, fl = function(a) {
          return Ip(a, x_);
        });
        var Za, x_;
        wm.exports = { set: pl, get: Ru, has: fl, enforce: qv, getterFor: Uv };
      });
      var Rp = Et((R6, Pm) => {
        var zv = $a(), Vv = xa(), dl = Ps(), Lp = Wo(), Wv = gm().CONFIGURABLE, Kv = Pp(), km = Am(), Hv = km.enforce, Gv = km.get, ml = Object.defineProperty, Xv = Lp && !zv(function() {
          return ml(function() {
          }, "length", { value: 8 }).length !== 8;
        }), $v = String(String).split("String"), Qv = Pm.exports = function(a, _, D) {
          String(_).slice(0, 7) === "Symbol(" && (_ = "[" + String(_).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), D && D.getter && (_ = "get " + _), D && D.setter && (_ = "set " + _), (!dl(a, "name") || Wv && a.name !== _) && (Lp ? ml(a, "name", { value: _, configurable: true }) : a.name = _), Xv && D && dl(D, "arity") && a.length !== D.arity && ml(a, "length", { value: D.arity });
          try {
            D && dl(D, "constructor") && D.constructor ? Lp && ml(a, "prototype", { writable: false }) : a.prototype && (a.prototype = void 0);
          } catch {
          }
          var T = Hv(a);
          return dl(T, "source") || (T.source = $v.join(typeof _ == "string" ? _ : "")), a;
        };
        Function.prototype.toString = Qv(function() {
          return Vv(this) && Gv(this).source || Kv(this);
        }, "toString");
      });
      var Im = Et((j6, Nm) => {
        var Yv = xa(), Zv = Lu(), e1 = Rp(), r1 = _l();
        Nm.exports = function(a, _, D, T) {
          T || (T = {});
          var ae = T.enumerable, z = T.name !== void 0 ? T.name : _;
          if (Yv(D) && e1(D, z, T), T.global)
            ae ? a[_] = D : r1(_, D);
          else {
            try {
              T.unsafe ? a[_] && (ae = true) : delete a[_];
            } catch {
            }
            ae ? a[_] = D : Zv.f(a, _, { value: D, enumerable: false, configurable: !T.nonConfigurable, writable: !T.nonWritable });
          }
          return a;
        };
      });
      var Mm = Et((J6, Om) => {
        var t1 = Math.ceil, n1 = Math.floor;
        Om.exports = Math.trunc || function(_) {
          var D = +_;
          return (D > 0 ? n1 : t1)(D);
        };
      });
      var jp = Et((F6, Lm) => {
        var i1 = Mm();
        Lm.exports = function(a) {
          var _ = +a;
          return _ !== _ || _ === 0 ? 0 : i1(_);
        };
      });
      var jm = Et((B6, Rm) => {
        var a1 = jp(), o1 = Math.max, s1 = Math.min;
        Rm.exports = function(a, _) {
          var D = a1(a);
          return D < 0 ? o1(D + _, 0) : s1(D, _);
        };
      });
      var Fm = Et((q6, Jm) => {
        var _1 = jp(), c1 = Math.min;
        Jm.exports = function(a) {
          return a > 0 ? c1(_1(a), 9007199254740991) : 0;
        };
      });
      var gl = Et((U6, Bm) => {
        var u1 = Fm();
        Bm.exports = function(a) {
          return u1(a.length);
        };
      });
      var zm = Et((z6, Um) => {
        var l1 = al(), p1 = jm(), f1 = gl(), qm = function(a) {
          return function(_, D, T) {
            var ae = l1(_), z = f1(ae), I = p1(T, z), E;
            if (a && D != D) {
              for (; z > I; )
                if (E = ae[I++], E != E)
                  return true;
            } else
              for (; z > I; I++)
                if ((a || I in ae) && ae[I] === D)
                  return a || I || 0;
            return !a && -1;
          };
        };
        Um.exports = { includes: qm(true), indexOf: qm(false) };
      });
      var Km = Et((V6, Wm) => {
        var d1 = Qa(), Jp = Ps(), m1 = al(), g1 = zm().indexOf, y1 = Np(), Vm = d1([].push);
        Wm.exports = function(a, _) {
          var D = m1(a), T = 0, ae = [], z;
          for (z in D)
            !Jp(y1, z) && Jp(D, z) && Vm(ae, z);
          for (; _.length > T; )
            Jp(D, z = _[T++]) && (~g1(ae, z) || Vm(ae, z));
          return ae;
        };
      });
      var Gm = Et((W6, Hm) => {
        Hm.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var $m = Et((Xm) => {
        var h1 = Km(), v1 = Gm(), b1 = v1.concat("length", "prototype");
        Xm.f = Object.getOwnPropertyNames || function(_) {
          return h1(_, b1);
        };
      });
      var Ym = Et((Qm) => {
        Qm.f = Object.getOwnPropertySymbols;
      });
      var eg = Et((G6, Zm) => {
        var E1 = Ou(), T1 = Qa(), S1 = $m(), C1 = Ym(), D1 = ul(), x1 = T1([].concat);
        Zm.exports = E1("Reflect", "ownKeys") || function(_) {
          var D = S1.f(D1(_)), T = C1.f;
          return T ? x1(D, T(_)) : D;
        };
      });
      var ng = Et((X6, tg) => {
        var rg = Ps(), w1 = eg(), A1 = Ep(), k1 = Lu();
        tg.exports = function(a, _, D) {
          for (var T = w1(_), ae = k1.f, z = A1.f, I = 0; I < T.length; I++) {
            var E = T[I];
            !rg(a, E) && !(D && rg(D, E)) && ae(a, E, z(_, E));
          }
        };
      });
      var ag = Et(($6, ig) => {
        var P1 = $a(), N1 = xa(), I1 = /#|\.prototype\./, ju = function(a, _) {
          var D = M1[O1(a)];
          return D == R1 ? true : D == L1 ? false : N1(_) ? P1(_) : !!_;
        }, O1 = ju.normalize = function(a) {
          return String(a).replace(I1, ".").toLowerCase();
        }, M1 = ju.data = {}, L1 = ju.NATIVE = "N", R1 = ju.POLYFILL = "P";
        ig.exports = ju;
      });
      var Bp = Et((Q6, og) => {
        var Fp = Ra(), j1 = Ep().f, J1 = xp(), F1 = Im(), B1 = _l(), q1 = ng(), U1 = ag();
        og.exports = function(a, _) {
          var D = a.target, T = a.global, ae = a.stat, z, I, E, N, e, t3;
          if (T ? I = Fp : ae ? I = Fp[D] || B1(D, {}) : I = (Fp[D] || {}).prototype, I)
            for (E in _) {
              if (e = _[E], a.dontCallGetSet ? (t3 = j1(I, E), N = t3 && t3.value) : N = I[E], z = U1(T ? E : D + (ae ? "." : "#") + E, a.forced), !z && N !== void 0) {
                if (typeof e == typeof N)
                  continue;
                q1(e, N);
              }
              (a.sham || N && N.sham) && J1(e, "sham", true), F1(I, E, e, a);
            }
        };
      });
      var sg = Et(() => {
        var z1 = Bp(), qp = Ra();
        z1({ global: true, forced: qp.globalThis !== qp }, { globalThis: qp });
      });
      var _g = Et(() => {
        sg();
      });
      var Up = Et((tS, cg) => {
        var V1 = Iu();
        cg.exports = Array.isArray || function(_) {
          return V1(_) == "Array";
        };
      });
      var lg = Et((nS, ug) => {
        var W1 = TypeError, K1 = 9007199254740991;
        ug.exports = function(a) {
          if (a > K1)
            throw W1("Maximum allowed index exceeded");
          return a;
        };
      });
      var fg = Et((iS, pg) => {
        var H1 = Iu(), G1 = Qa();
        pg.exports = function(a) {
          if (H1(a) === "Function")
            return G1(a);
        };
      });
      var gg = Et((aS, mg) => {
        var dg = fg(), X1 = sl(), $1 = tl(), Q1 = dg(dg.bind);
        mg.exports = function(a, _) {
          return X1(a), _ === void 0 ? a : $1 ? Q1(a, _) : function() {
            return a.apply(_, arguments);
          };
        };
      });
      var vg = Et((oS, hg) => {
        "use strict";
        var Y1 = Up(), Z1 = gl(), eb = lg(), rb = gg(), yg = function(a, _, D, T, ae, z, I, E) {
          for (var N = ae, e = 0, t3 = I ? rb(I, E) : false, w, s; e < T; )
            e in D && (w = t3 ? t3(D[e], e, _) : D[e], z > 0 && Y1(w) ? (s = Z1(w), N = yg(a, _, w, s, N, z - 1) - 1) : (eb(N + 1), a[N] = w), N++), e++;
          return N;
        };
        hg.exports = yg;
      });
      var Tg = Et((sS, Eg) => {
        var tb = Mu(), nb = tb("toStringTag"), bg = {};
        bg[nb] = "z";
        Eg.exports = String(bg) === "[object z]";
      });
      var Cg = Et((_S, Sg) => {
        var ib = Tg(), ab = xa(), yl = Iu(), ob = Mu(), sb = ob("toStringTag"), _b = Object, cb = yl(function() {
          return arguments;
        }()) == "Arguments", ub = function(a, _) {
          try {
            return a[_];
          } catch {
          }
        };
        Sg.exports = ib ? yl : function(a) {
          var _, D, T;
          return a === void 0 ? "Undefined" : a === null ? "Null" : typeof (D = ub(_ = _b(a), sb)) == "string" ? D : cb ? yl(_) : (T = yl(_)) == "Object" && ab(_.callee) ? "Arguments" : T;
        };
      });
      var Pg = Et((cS, kg) => {
        var lb = Qa(), pb = $a(), Dg = xa(), fb = Cg(), db = Ou(), mb = Pp(), xg = function() {
        }, gb = [], wg = db("Reflect", "construct"), zp = /^\s*(?:class|function)\b/, yb = lb(zp.exec), hb = !zp.exec(xg), Ju = function(_) {
          if (!Dg(_))
            return false;
          try {
            return wg(xg, gb, _), true;
          } catch {
            return false;
          }
        }, Ag = function(_) {
          if (!Dg(_))
            return false;
          switch (fb(_)) {
            case "AsyncFunction":
            case "GeneratorFunction":
            case "AsyncGeneratorFunction":
              return false;
          }
          try {
            return hb || !!yb(zp, mb(_));
          } catch {
            return true;
          }
        };
        Ag.sham = true;
        kg.exports = !wg || pb(function() {
          var a;
          return Ju(Ju.call) || !Ju(Object) || !Ju(function() {
            a = true;
          }) || a;
        }) ? Ag : Ju;
      });
      var Mg = Et((uS, Og) => {
        var Ng = Up(), vb = Pg(), bb = C_(), Eb = Mu(), Tb = Eb("species"), Ig = Array;
        Og.exports = function(a) {
          var _;
          return Ng(a) && (_ = a.constructor, vb(_) && (_ === Ig || Ng(_.prototype)) ? _ = void 0 : bb(_) && (_ = _[Tb], _ === null && (_ = void 0))), _ === void 0 ? Ig : _;
        };
      });
      var Rg = Et((lS, Lg) => {
        var Sb = Mg();
        Lg.exports = function(a, _) {
          return new (Sb(a))(_ === 0 ? 0 : _);
        };
      });
      var jg = Et(() => {
        "use strict";
        var Cb = Bp(), Db = vg(), xb = sl(), wb = gp(), Ab = gl(), kb = Rg();
        Cb({ target: "Array", proto: true }, { flatMap: function(_) {
          var D = wb(this), T = Ab(D), ae;
          return xb(_), ae = kb(D, 0), ae.length = Db(ae, D, D, T, 0, 1, _, arguments.length > 1 ? arguments[1] : void 0), ae;
        } });
      });
      var Bg = Et((dS, Fg) => {
        var Jg = Rp(), Pb = Lu();
        Fg.exports = function(a, _, D) {
          return D.get && Jg(D.get, _, { getter: true }), D.set && Jg(D.set, _, { setter: true }), Pb.f(a, _, D);
        };
      });
      var Ug = Et((mS, qg) => {
        "use strict";
        var Nb = ul();
        qg.exports = function() {
          var a = Nb(this), _ = "";
          return a.hasIndices && (_ += "d"), a.global && (_ += "g"), a.ignoreCase && (_ += "i"), a.multiline && (_ += "m"), a.dotAll && (_ += "s"), a.unicode && (_ += "u"), a.unicodeSets && (_ += "v"), a.sticky && (_ += "y"), _;
        };
      });
      var Wg = Et(() => {
        var Ib = Ra(), Ob = Wo(), Mb = Bg(), Lb = Ug(), Rb = $a(), zg = Ib.RegExp, Vg = zg.prototype, jb = Ob && Rb(function() {
          var a = true;
          try {
            zg(".", "d");
          } catch {
            a = false;
          }
          var _ = {}, D = "", T = a ? "dgimsy" : "gimsy", ae = function(N, e) {
            Object.defineProperty(_, N, { get: function() {
              return D += e, true;
            } });
          }, z = { dotAll: "s", global: "g", ignoreCase: "i", multiline: "m", sticky: "y" };
          a && (z.hasIndices = "d");
          for (var I in z)
            ae(I, z[I]);
          var E = Object.getOwnPropertyDescriptor(Vg, "flags").get.call(_);
          return E !== T || D !== T;
        });
        jb && Mb(Vg, "flags", { configurable: true, get: Lb });
      });
      var JT = Et((hS, By) => {
        _g();
        jg();
        Wg();
        var $p = Object.defineProperty, Jb = Object.getOwnPropertyDescriptor, Qp = Object.getOwnPropertyNames, Fb = Object.prototype.hasOwnProperty, Bu = (a, _) => function() {
          return a && (_ = (0, a[Qp(a)[0]])(a = 0)), _;
        }, Ur = (a, _) => function() {
          return _ || (0, a[Qp(a)[0]])((_ = { exports: {} }).exports, _), _.exports;
        }, Tl = (a, _) => {
          for (var D in _)
            $p(a, D, { get: _[D], enumerable: true });
        }, Bb = (a, _, D, T) => {
          if (_ && typeof _ == "object" || typeof _ == "function")
            for (let ae of Qp(_))
              !Fb.call(a, ae) && ae !== D && $p(a, ae, { get: () => _[ae], enumerable: !(T = Jb(_, ae)) || T.enumerable });
          return a;
        }, ja = (a) => Bb($p({}, "__esModule", { value: true }), a), ba, Jr = Bu({ "<define:process>"() {
          ba = { env: {}, argv: [] };
        } }), Xg = Ur({ "src/common/parser-create-error.js"(a, _) {
          "use strict";
          Jr();
          function D(T, ae) {
            let z = new SyntaxError(T + " (" + ae.start.line + ":" + ae.start.column + ")");
            return z.loc = ae, z;
          }
          _.exports = D;
        } }), qb = Ur({ "src/utils/try-combinations.js"(a, _) {
          "use strict";
          Jr();
          function D() {
            let T;
            for (var ae = arguments.length, z = new Array(ae), I = 0; I < ae; I++)
              z[I] = arguments[I];
            for (let [E, N] of z.entries())
              try {
                return { result: N() };
              } catch (e) {
                E === 0 && (T = e);
              }
            return { error: T };
          }
          _.exports = D;
        } }), $g = {};
        Tl($g, { EOL: () => Kp, arch: () => Ub, cpus: () => ny, default: () => _y, endianness: () => Qg, freemem: () => ry, getNetworkInterfaces: () => sy, hostname: () => Yg, loadavg: () => Zg, networkInterfaces: () => oy, platform: () => zb, release: () => ay, tmpDir: () => Vp, tmpdir: () => Wp, totalmem: () => ty, type: () => iy, uptime: () => ey });
        function Qg() {
          if (typeof hl > "u") {
            var a = new ArrayBuffer(2), _ = new Uint8Array(a), D = new Uint16Array(a);
            if (_[0] = 1, _[1] = 2, D[0] === 258)
              hl = "BE";
            else if (D[0] === 513)
              hl = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return hl;
        }
        function Yg() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function Zg() {
          return [];
        }
        function ey() {
          return 0;
        }
        function ry() {
          return Number.MAX_VALUE;
        }
        function ty() {
          return Number.MAX_VALUE;
        }
        function ny() {
          return [];
        }
        function iy() {
          return "Browser";
        }
        function ay() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function oy() {
        }
        function sy() {
        }
        function Ub() {
          return "javascript";
        }
        function zb() {
          return "browser";
        }
        function Vp() {
          return "/tmp";
        }
        var hl, Wp, Kp, _y, Vb = Bu({ "node-modules-polyfills:os"() {
          Jr(), Wp = Vp, Kp = `
`, _y = { EOL: Kp, tmpdir: Wp, tmpDir: Vp, networkInterfaces: oy, getNetworkInterfaces: sy, release: ay, type: iy, cpus: ny, totalmem: ty, freemem: ry, uptime: ey, loadavg: Zg, hostname: Yg, endianness: Qg };
        } }), Wb = Ur({ "node-modules-polyfills-commonjs:os"(a, _) {
          Jr();
          var D = (Vb(), ja($g));
          if (D && D.default) {
            _.exports = D.default;
            for (let T in D)
              _.exports[T] = D[T];
          } else
            D && (_.exports = D);
        } }), Kb = Ur({ "node_modules/detect-newline/index.js"(a, _) {
          "use strict";
          Jr();
          var D = (T) => {
            if (typeof T != "string")
              throw new TypeError("Expected a string");
            let ae = T.match(/(?:\r?\n)/g) || [];
            if (ae.length === 0)
              return;
            let z = ae.filter((E) => E === `\r
`).length, I = ae.length - z;
            return z > I ? `\r
` : `
`;
          };
          _.exports = D, _.exports.graceful = (T) => typeof T == "string" && D(T) || `
`;
        } }), Hb = Ur({ "node_modules/jest-docblock/build/index.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.extract = q, a.parse = fe, a.parseWithComments = Ee, a.print = Se, a.strip = F;
          function _() {
            let se = Wb();
            return _ = function() {
              return se;
            }, se;
          }
          function D() {
            let se = T(Kb());
            return D = function() {
              return se;
            }, se;
          }
          function T(se) {
            return se && se.__esModule ? se : { default: se };
          }
          var ae = /\*\/$/, z = /^\/\*\*?/, I = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, E = /(^|\s+)\/\/([^\r\n]*)/g, N = /^(\r?\n)+/, e = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, t3 = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, w = /(\r?\n|^) *\* ?/g, s = [];
          function q(se) {
            let Me = se.match(I);
            return Me ? Me[0].trimLeft() : "";
          }
          function F(se) {
            let Me = se.match(I);
            return Me && Me[0] ? se.substring(Me[0].length) : se;
          }
          function fe(se) {
            return Ee(se).pragmas;
          }
          function Ee(se) {
            let Me = (0, D().default)(se) || _().EOL;
            se = se.replace(z, "").replace(ae, "").replace(w, "$1");
            let Q = "";
            for (; Q !== se; )
              Q = se, se = se.replace(e, `${Me}$1 $2${Me}`);
            se = se.replace(N, "").trimRight();
            let Be = /* @__PURE__ */ Object.create(null), je = se.replace(t3, "").replace(N, "").trimRight(), V;
            for (; V = t3.exec(se); ) {
              let B = V[2].replace(E, "");
              typeof Be[V[1]] == "string" || Array.isArray(Be[V[1]]) ? Be[V[1]] = s.concat(Be[V[1]], B) : Be[V[1]] = B;
            }
            return { comments: je, pragmas: Be };
          }
          function Se(se) {
            let { comments: Me = "", pragmas: Q = {} } = se, Be = (0, D().default)(Me) || _().EOL, je = "/**", V = " *", B = " */", U = Object.keys(Q), m = U.map((g) => J(g, Q[g])).reduce((g, O) => g.concat(O), []).map((g) => `${V} ${g}${Be}`).join("");
            if (!Me) {
              if (U.length === 0)
                return "";
              if (U.length === 1 && !Array.isArray(Q[U[0]])) {
                let g = Q[U[0]];
                return `${je} ${J(U[0], g)[0]}${B}`;
              }
            }
            let v = Me.split(Be).map((g) => `${V} ${g}`).join(Be) + Be;
            return je + Be + (Me ? v : "") + (Me && U.length ? V + Be : "") + m + B;
          }
          function J(se, Me) {
            return s.concat(Me).map((Q) => `@${se} ${Q}`.trim());
          }
        } }), Gb = Ur({ "src/common/end-of-line.js"(a, _) {
          "use strict";
          Jr();
          function D(I) {
            let E = I.indexOf("\r");
            return E >= 0 ? I.charAt(E + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function T(I) {
            switch (I) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function ae(I, E) {
            let N;
            switch (E) {
              case `
`:
                N = /\n/g;
                break;
              case "\r":
                N = /\r/g;
                break;
              case `\r
`:
                N = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(E)}.`);
            }
            let e = I.match(N);
            return e ? e.length : 0;
          }
          function z(I) {
            return I.replace(/\r\n?/g, `
`);
          }
          _.exports = { guessEndOfLine: D, convertEndOfLineToChars: T, countEndOfLineChars: ae, normalizeEndOfLine: z };
        } }), Xb = Ur({ "src/language-js/utils/get-shebang.js"(a, _) {
          "use strict";
          Jr();
          function D(T) {
            if (!T.startsWith("#!"))
              return "";
            let ae = T.indexOf(`
`);
            return ae === -1 ? T : T.slice(0, ae);
          }
          _.exports = D;
        } }), $b = Ur({ "src/language-js/pragma.js"(a, _) {
          "use strict";
          Jr();
          var { parseWithComments: D, strip: T, extract: ae, print: z } = Hb(), { normalizeEndOfLine: I } = Gb(), E = Xb();
          function N(w) {
            let s = E(w);
            s && (w = w.slice(s.length + 1));
            let q = ae(w), { pragmas: F, comments: fe } = D(q);
            return { shebang: s, text: w, pragmas: F, comments: fe };
          }
          function e(w) {
            let s = Object.keys(N(w).pragmas);
            return s.includes("prettier") || s.includes("format");
          }
          function t3(w) {
            let { shebang: s, text: q, pragmas: F, comments: fe } = N(w), Ee = T(q), Se = z({ pragmas: Object.assign({ format: "" }, F), comments: fe.trimStart() });
            return (s ? `${s}
` : "") + I(Se) + (Ee.startsWith(`
`) ? `
` : `

`) + Ee;
          }
          _.exports = { hasPragma: e, insertPragma: t3 };
        } }), cy = Ur({ "src/utils/is-non-empty-array.js"(a, _) {
          "use strict";
          Jr();
          function D(T) {
            return Array.isArray(T) && T.length > 0;
          }
          _.exports = D;
        } }), uy = Ur({ "src/language-js/loc.js"(a, _) {
          "use strict";
          Jr();
          var D = cy();
          function T(N) {
            var e, t3;
            let w = N.range ? N.range[0] : N.start, s = (e = (t3 = N.declaration) === null || t3 === void 0 ? void 0 : t3.decorators) !== null && e !== void 0 ? e : N.decorators;
            return D(s) ? Math.min(T(s[0]), w) : w;
          }
          function ae(N) {
            return N.range ? N.range[1] : N.end;
          }
          function z(N, e) {
            let t3 = T(N);
            return Number.isInteger(t3) && t3 === T(e);
          }
          function I(N, e) {
            let t3 = ae(N);
            return Number.isInteger(t3) && t3 === ae(e);
          }
          function E(N, e) {
            return z(N, e) && I(N, e);
          }
          _.exports = { locStart: T, locEnd: ae, hasSameLocStart: z, hasSameLoc: E };
        } }), Qb = Ur({ "src/language-js/parse/utils/create-parser.js"(a, _) {
          "use strict";
          Jr();
          var { hasPragma: D } = $b(), { locStart: T, locEnd: ae } = uy();
          function z(I) {
            return I = typeof I == "function" ? { parse: I } : I, Object.assign({ astFormat: "estree", hasPragma: D, locStart: T, locEnd: ae }, I);
          }
          _.exports = z;
        } }), Yb = Ur({ "src/language-js/parse/utils/replace-hashbang.js"(a, _) {
          "use strict";
          Jr();
          function D(T) {
            return T.charAt(0) === "#" && T.charAt(1) === "!" ? "//" + T.slice(2) : T;
          }
          _.exports = D;
        } }), Zb = Ur({ "src/language-js/utils/is-ts-keyword-type.js"(a, _) {
          "use strict";
          Jr();
          function D(T) {
            let { type: ae } = T;
            return ae.startsWith("TS") && ae.endsWith("Keyword");
          }
          _.exports = D;
        } }), eE = Ur({ "src/language-js/utils/is-block-comment.js"(a, _) {
          "use strict";
          Jr();
          var D = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]), T = (ae) => D.has(ae == null ? void 0 : ae.type);
          _.exports = T;
        } }), rE = Ur({ "src/language-js/utils/is-type-cast-comment.js"(a, _) {
          "use strict";
          Jr();
          var D = eE();
          function T(ae) {
            return D(ae) && ae.value[0] === "*" && /@type\b/.test(ae.value);
          }
          _.exports = T;
        } }), tE = Ur({ "src/utils/get-last.js"(a, _) {
          "use strict";
          Jr();
          var D = (T) => T[T.length - 1];
          _.exports = D;
        } }), ly = Ur({ "src/language-js/parse/postprocess/visit-node.js"(a, _) {
          "use strict";
          Jr();
          function D(T, ae) {
            if (Array.isArray(T)) {
              for (let z = 0; z < T.length; z++)
                T[z] = D(T[z], ae);
              return T;
            }
            if (T && typeof T == "object" && typeof T.type == "string") {
              let z = Object.keys(T);
              for (let I = 0; I < z.length; I++)
                T[z[I]] = D(T[z[I]], ae);
              return ae(T) || T;
            }
            return T;
          }
          _.exports = D;
        } }), py = Ur({ "src/language-js/parse/postprocess/throw-syntax-error.js"(a, _) {
          "use strict";
          Jr();
          var D = Xg();
          function T(ae, z) {
            let { start: I, end: E } = ae.loc;
            throw D(z, { start: { line: I.line, column: I.column + 1 }, end: { line: E.line, column: E.column + 1 } });
          }
          _.exports = T;
        } }), nE = Ur({ "src/language-js/parse/postprocess/typescript.js"(a, _) {
          "use strict";
          Jr();
          var D = cy(), T = ly(), ae = py(), z = { AbstractKeyword: 126, SourceFile: 308, PropertyDeclaration: 169 };
          function I(t3) {
            for (; t3 && t3.kind !== z.SourceFile; )
              t3 = t3.parent;
            return t3;
          }
          function E(t3) {
            let { illegalDecorators: w } = t3;
            if (!D(w))
              return;
            let [{ expression: s }] = w, q = I(s), [F, fe] = [s.pos, s.end].map((Ee) => {
              let { line: Se, character: J } = q.getLineAndCharacterOfPosition(Ee);
              return { line: Se + 1, column: J };
            });
            ae({ loc: { start: F, end: fe } }, "Decorators are not valid here.");
          }
          function N(t3, w) {
            t3.kind !== z.PropertyDeclaration || t3.modifiers && !t3.modifiers.some((s) => s.kind === z.AbstractKeyword) || t3.initializer && w.value === null && ae(w, "Abstract property cannot have an initializer");
          }
          function e(t3, w) {
            let { esTreeNodeToTSNodeMap: s, tsNodeToESTreeNodeMap: q } = w.tsParseResult;
            T(t3, (F) => {
              let fe = s.get(F);
              if (!fe)
                return;
              let Ee = q.get(fe);
              Ee === F && (E(fe), N(fe, Ee));
            });
          }
          _.exports = { throwErrorForInvalidNodes: e };
        } }), iE = Ur({ "src/language-js/parse/postprocess/index.js"(a, _) {
          "use strict";
          Jr();
          var { locStart: D, locEnd: T } = uy(), ae = Zb(), z = rE(), I = tE(), E = ly(), { throwErrorForInvalidNodes: N } = nE(), e = py();
          function t3(F, fe) {
            if (fe.parser === "typescript" && /@|abstract/.test(fe.originalText) && N(F, fe), fe.parser !== "typescript" && fe.parser !== "flow" && fe.parser !== "acorn" && fe.parser !== "espree" && fe.parser !== "meriyah") {
              let Se = /* @__PURE__ */ new Set();
              F = E(F, (J) => {
                J.leadingComments && J.leadingComments.some(z) && Se.add(D(J));
              }), F = E(F, (J) => {
                if (J.type === "ParenthesizedExpression") {
                  let { expression: se } = J;
                  if (se.type === "TypeCastExpression")
                    return se.range = J.range, se;
                  let Me = D(J);
                  if (!Se.has(Me))
                    return se.extra = Object.assign(Object.assign({}, se.extra), {}, { parenthesized: true }), se;
                }
              });
            }
            return F = E(F, (Se) => {
              switch (Se.type) {
                case "ChainExpression":
                  return w(Se.expression);
                case "LogicalExpression": {
                  if (s(Se))
                    return q(Se);
                  break;
                }
                case "VariableDeclaration": {
                  let J = I(Se.declarations);
                  J && J.init && Ee(Se, J);
                  break;
                }
                case "TSParenthesizedType":
                  return ae(Se.typeAnnotation) || Se.typeAnnotation.type === "TSThisType" || (Se.typeAnnotation.range = [D(Se), T(Se)]), Se.typeAnnotation;
                case "TSTypeParameter":
                  if (typeof Se.name == "string") {
                    let J = D(Se);
                    Se.name = { type: "Identifier", name: Se.name, range: [J, J + Se.name.length] };
                  }
                  break;
                case "ObjectExpression":
                  if (fe.parser === "typescript") {
                    let J = Se.properties.find((se) => se.type === "Property" && se.value.type === "TSEmptyBodyFunctionExpression");
                    J && e(J.value, "Unexpected token.");
                  }
                  break;
                case "SequenceExpression": {
                  let J = I(Se.expressions);
                  Se.range = [D(Se), Math.min(T(J), T(Se))];
                  break;
                }
                case "TopicReference":
                  fe.__isUsingHackPipeline = true;
                  break;
                case "ExportAllDeclaration": {
                  let { exported: J } = Se;
                  if (fe.parser === "meriyah" && J && J.type === "Identifier") {
                    let se = fe.originalText.slice(D(J), T(J));
                    (se.startsWith('"') || se.startsWith("'")) && (Se.exported = Object.assign(Object.assign({}, Se.exported), {}, { type: "Literal", value: Se.exported.name, raw: se }));
                  }
                  break;
                }
                case "PropertyDefinition":
                  if (fe.parser === "meriyah" && Se.static && !Se.computed && !Se.key) {
                    let J = "static", se = D(Se);
                    Object.assign(Se, { static: false, key: { type: "Identifier", name: J, range: [se, se + J.length] } });
                  }
                  break;
              }
            }), F;
            function Ee(Se, J) {
              fe.originalText[T(J)] !== ";" && (Se.range = [D(Se), T(J)]);
            }
          }
          function w(F) {
            switch (F.type) {
              case "CallExpression":
                F.type = "OptionalCallExpression", F.callee = w(F.callee);
                break;
              case "MemberExpression":
                F.type = "OptionalMemberExpression", F.object = w(F.object);
                break;
              case "TSNonNullExpression":
                F.expression = w(F.expression);
                break;
            }
            return F;
          }
          function s(F) {
            return F.type === "LogicalExpression" && F.right.type === "LogicalExpression" && F.operator === F.right.operator;
          }
          function q(F) {
            return s(F) ? q({ type: "LogicalExpression", operator: F.operator, left: q({ type: "LogicalExpression", operator: F.operator, left: F.left, right: F.right.left, range: [D(F.left), T(F.right.left)] }), right: F.right.right, range: [D(F), T(F)] }) : F;
          }
          _.exports = t3;
        } }), Ns = Ur({ "scripts/build/shims/debug.cjs"(a, _) {
          "use strict";
          Jr(), _.exports = () => () => {
          };
        } }), Di = Ur({ "node_modules/typescript/lib/typescript.js"(a, _) {
          "use strict";
          Jr();
          var D = a && a.__spreadArray || function(e, t3, w) {
            if (w || arguments.length === 2)
              for (var s = 0, q = t3.length, F; s < q; s++)
                (F || !(s in t3)) && (F || (F = Array.prototype.slice.call(t3, 0, s)), F[s] = t3[s]);
            return e.concat(F || Array.prototype.slice.call(t3));
          }, T = a && a.__assign || function() {
            return T = Object.assign || function(e) {
              for (var t3, w = 1, s = arguments.length; w < s; w++) {
                t3 = arguments[w];
                for (var q in t3)
                  Object.prototype.hasOwnProperty.call(t3, q) && (e[q] = t3[q]);
              }
              return e;
            }, T.apply(this, arguments);
          }, ae = a && a.__makeTemplateObject || function(e, t3) {
            return Object.defineProperty ? Object.defineProperty(e, "raw", { value: t3 }) : e.raw = t3, e;
          }, z = a && a.__generator || function(e, t3) {
            var w = { label: 0, sent: function() {
              if (F[0] & 1)
                throw F[1];
              return F[1];
            }, trys: [], ops: [] }, s, q, F, fe;
            return fe = { next: Ee(0), throw: Ee(1), return: Ee(2) }, typeof Symbol == "function" && (fe[Symbol.iterator] = function() {
              return this;
            }), fe;
            function Ee(J) {
              return function(se) {
                return Se([J, se]);
              };
            }
            function Se(J) {
              if (s)
                throw new TypeError("Generator is already executing.");
              for (; fe && (fe = 0, J[0] && (w = 0)), w; )
                try {
                  if (s = 1, q && (F = J[0] & 2 ? q.return : J[0] ? q.throw || ((F = q.return) && F.call(q), 0) : q.next) && !(F = F.call(q, J[1])).done)
                    return F;
                  switch (q = 0, F && (J = [J[0] & 2, F.value]), J[0]) {
                    case 0:
                    case 1:
                      F = J;
                      break;
                    case 4:
                      return w.label++, { value: J[1], done: false };
                    case 5:
                      w.label++, q = J[1], J = [0];
                      continue;
                    case 7:
                      J = w.ops.pop(), w.trys.pop();
                      continue;
                    default:
                      if (F = w.trys, !(F = F.length > 0 && F[F.length - 1]) && (J[0] === 6 || J[0] === 2)) {
                        w = 0;
                        continue;
                      }
                      if (J[0] === 3 && (!F || J[1] > F[0] && J[1] < F[3])) {
                        w.label = J[1];
                        break;
                      }
                      if (J[0] === 6 && w.label < F[1]) {
                        w.label = F[1], F = J;
                        break;
                      }
                      if (F && w.label < F[2]) {
                        w.label = F[2], w.ops.push(J);
                        break;
                      }
                      F[2] && w.ops.pop(), w.trys.pop();
                      continue;
                  }
                  J = t3.call(e, w);
                } catch (se) {
                  J = [6, se], q = 0;
                } finally {
                  s = F = 0;
                }
              if (J[0] & 5)
                throw J[1];
              return { value: J[0] ? J[1] : void 0, done: true };
            }
          }, I = a && a.__rest || function(e, t3) {
            var w = {};
            for (var s in e)
              Object.prototype.hasOwnProperty.call(e, s) && t3.indexOf(s) < 0 && (w[s] = e[s]);
            if (e != null && typeof Object.getOwnPropertySymbols == "function")
              for (var q = 0, s = Object.getOwnPropertySymbols(e); q < s.length; q++)
                t3.indexOf(s[q]) < 0 && Object.prototype.propertyIsEnumerable.call(e, s[q]) && (w[s[q]] = e[s[q]]);
            return w;
          }, E = a && a.__extends || function() {
            var e = function(t3, w) {
              return e = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(s, q) {
                s.__proto__ = q;
              } || function(s, q) {
                for (var F in q)
                  Object.prototype.hasOwnProperty.call(q, F) && (s[F] = q[F]);
              }, e(t3, w);
            };
            return function(t3, w) {
              if (typeof w != "function" && w !== null)
                throw new TypeError("Class extends value " + String(w) + " is not a constructor or null");
              e(t3, w);
              function s() {
                this.constructor = t3;
              }
              t3.prototype = w === null ? Object.create(w) : (s.prototype = w.prototype, new s());
            };
          }(), N;
          (function(e) {
            e.versionMajorMinor = "4.9", e.version = "".concat(e.versionMajorMinor, ".3");
            var t3;
            (function(s) {
              s[s.LessThan = -1] = "LessThan", s[s.EqualTo = 0] = "EqualTo", s[s.GreaterThan = 1] = "GreaterThan";
            })(t3 = e.Comparison || (e.Comparison = {}));
            var w;
            (function(s) {
              var q = typeof globalThis < "u" || typeof globalThis < "u" ? globalThis : typeof self < "u" ? self : void 0;
              function F() {
                var Ee = q == null ? void 0 : q.Map, Se = typeof Ee < "u" && "entries" in Ee.prototype && new Ee([[0, 0]]).size === 1 ? Ee : void 0;
                if (!Se)
                  throw new Error("No compatible Map implementation found.");
                return Se;
              }
              s.tryGetNativeMap = F;
              function fe() {
                var Ee = q == null ? void 0 : q.Set, Se = typeof Ee < "u" && "entries" in Ee.prototype && new Ee([0]).size === 1 ? Ee : void 0;
                if (!Se)
                  throw new Error("No compatible Set implementation found.");
                return Se;
              }
              s.tryGetNativeSet = fe;
            })(w || (w = {})), e.Map = w.tryGetNativeMap(), e.Set = w.tryGetNativeSet();
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(C) {
              if (C) {
                if (Vt(C))
                  return pt(C);
                if (C instanceof e.Map)
                  return C.entries();
                if (C instanceof e.Set)
                  return C.values();
                throw new Error("Iteration not supported.");
              }
            }
            e.getIterator = t3, e.emptyArray = [], e.emptyMap = new e.Map(), e.emptySet = new e.Set();
            function w(C) {
              return C ? C.length : 0;
            }
            e.length = w;
            function s(C, W) {
              if (C)
                for (var ee = 0; ee < C.length; ee++) {
                  var le = W(C[ee], ee);
                  if (le)
                    return le;
                }
            }
            e.forEach = s;
            function q(C, W) {
              if (C)
                for (var ee = C.length - 1; ee >= 0; ee--) {
                  var le = W(C[ee], ee);
                  if (le)
                    return le;
                }
            }
            e.forEachRight = q;
            function F(C, W) {
              if (C !== void 0)
                for (var ee = 0; ee < C.length; ee++) {
                  var le = W(C[ee], ee);
                  if (le !== void 0)
                    return le;
                }
            }
            e.firstDefined = F;
            function fe(C, W) {
              for (; ; ) {
                var ee = C.next();
                if (ee.done)
                  return;
                var le = W(ee.value);
                if (le !== void 0)
                  return le;
              }
            }
            e.firstDefinedIterator = fe;
            function Ee(C, W, ee) {
              var le = ee;
              if (C)
                for (var Ze = C.next(), Ir = 0; !Ze.done; Ze = C.next(), Ir++)
                  le = W(le, Ze.value, Ir);
              return le;
            }
            e.reduceLeftIterator = Ee;
            function Se(C, W, ee) {
              var le = [];
              e.Debug.assertEqual(C.length, W.length);
              for (var Ze = 0; Ze < C.length; Ze++)
                le.push(ee(C[Ze], W[Ze], Ze));
              return le;
            }
            e.zipWith = Se;
            function J(C, W) {
              e.Debug.assertEqual(C.length, W.length);
              var ee = 0;
              return { next: function() {
                return ee === C.length ? { value: void 0, done: true } : (ee++, { value: [C[ee - 1], W[ee - 1]], done: false });
              } };
            }
            e.zipToIterator = J;
            function se(C, W) {
              e.Debug.assert(C.length === W.length);
              for (var ee = new e.Map(), le = 0; le < C.length; ++le)
                ee.set(C[le], W[le]);
              return ee;
            }
            e.zipToMap = se;
            function Me(C, W) {
              if (C.length <= 1)
                return C;
              for (var ee = [], le = 0, Ze = C.length; le < Ze; le++)
                le && ee.push(W), ee.push(C[le]);
              return ee;
            }
            e.intersperse = Me;
            function Q(C, W) {
              if (C) {
                for (var ee = 0; ee < C.length; ee++)
                  if (!W(C[ee], ee))
                    return false;
              }
              return true;
            }
            e.every = Q;
            function Be(C, W, ee) {
              if (C !== void 0)
                for (var le = ee != null ? ee : 0; le < C.length; le++) {
                  var Ze = C[le];
                  if (W(Ze, le))
                    return Ze;
                }
            }
            e.find = Be;
            function je(C, W, ee) {
              if (C !== void 0)
                for (var le = ee != null ? ee : C.length - 1; le >= 0; le--) {
                  var Ze = C[le];
                  if (W(Ze, le))
                    return Ze;
                }
            }
            e.findLast = je;
            function V(C, W, ee) {
              if (C === void 0)
                return -1;
              for (var le = ee != null ? ee : 0; le < C.length; le++)
                if (W(C[le], le))
                  return le;
              return -1;
            }
            e.findIndex = V;
            function B(C, W, ee) {
              if (C === void 0)
                return -1;
              for (var le = ee != null ? ee : C.length - 1; le >= 0; le--)
                if (W(C[le], le))
                  return le;
              return -1;
            }
            e.findLastIndex = B;
            function U(C, W) {
              for (var ee = 0; ee < C.length; ee++) {
                var le = W(C[ee], ee);
                if (le)
                  return le;
              }
              return e.Debug.fail();
            }
            e.findMap = U;
            function m(C, W, ee) {
              if (ee === void 0 && (ee = On), C)
                for (var le = 0, Ze = C; le < Ze.length; le++) {
                  var Ir = Ze[le];
                  if (ee(Ir, W))
                    return true;
                }
              return false;
            }
            e.contains = m;
            function v(C, W, ee) {
              return ee === void 0 && (ee = On), C.length === W.length && C.every(function(le, Ze) {
                return ee(le, W[Ze]);
              });
            }
            e.arraysEqual = v;
            function g(C, W, ee) {
              for (var le = ee || 0; le < C.length; le++)
                if (m(W, C.charCodeAt(le)))
                  return le;
              return -1;
            }
            e.indexOfAnyCharCode = g;
            function O(C, W) {
              var ee = 0;
              if (C)
                for (var le = 0; le < C.length; le++) {
                  var Ze = C[le];
                  W(Ze, le) && ee++;
                }
              return ee;
            }
            e.countWhere = O;
            function S(C, W) {
              if (C) {
                for (var ee = C.length, le = 0; le < ee && W(C[le]); )
                  le++;
                if (le < ee) {
                  var Ze = C.slice(0, le);
                  for (le++; le < ee; ) {
                    var Ir = C[le];
                    W(Ir) && Ze.push(Ir), le++;
                  }
                  return Ze;
                }
              }
              return C;
            }
            e.filter = S;
            function te(C, W) {
              for (var ee = 0, le = 0; le < C.length; le++)
                W(C[le], le, C) && (C[ee] = C[le], ee++);
              C.length = ee;
            }
            e.filterMutate = te;
            function Je(C) {
              C.length = 0;
            }
            e.clear = Je;
            function qe(C, W) {
              var ee;
              if (C) {
                ee = [];
                for (var le = 0; le < C.length; le++)
                  ee.push(W(C[le], le));
              }
              return ee;
            }
            e.map = qe;
            function ge(C, W) {
              return { next: function() {
                var ee = C.next();
                return ee.done ? ee : { value: W(ee.value), done: false };
              } };
            }
            e.mapIterator = ge;
            function ie(C, W) {
              if (C)
                for (var ee = 0; ee < C.length; ee++) {
                  var le = C[ee], Ze = W(le, ee);
                  if (le !== Ze) {
                    var Ir = C.slice(0, ee);
                    for (Ir.push(Ze), ee++; ee < C.length; ee++)
                      Ir.push(W(C[ee], ee));
                    return Ir;
                  }
                }
              return C;
            }
            e.sameMap = ie;
            function H(C) {
              for (var W = [], ee = 0, le = C; ee < le.length; ee++) {
                var Ze = le[ee];
                Ze && (Vt(Ze) ? h(W, Ze) : W.push(Ze));
              }
              return W;
            }
            e.flatten = H;
            function pe(C, W) {
              var ee;
              if (C)
                for (var le = 0; le < C.length; le++) {
                  var Ze = W(C[le], le);
                  Ze && (Vt(Ze) ? ee = h(ee, Ze) : ee = rt(ee, Ze));
                }
              return ee || e.emptyArray;
            }
            e.flatMap = pe;
            function j(C, W) {
              var ee = [];
              if (C)
                for (var le = 0; le < C.length; le++) {
                  var Ze = W(C[le], le);
                  Ze && (Vt(Ze) ? h(ee, Ze) : ee.push(Ze));
                }
              return ee;
            }
            e.flatMapToMutable = j;
            function be(C, W) {
              var ee = C.next();
              if (ee.done)
                return e.emptyIterator;
              var le = Ze(ee.value);
              return { next: function() {
                for (; ; ) {
                  var Ir = le.next();
                  if (!Ir.done)
                    return Ir;
                  var Ar = C.next();
                  if (Ar.done)
                    return Ar;
                  le = Ze(Ar.value);
                }
              } };
              function Ze(Ir) {
                var Ar = W(Ir);
                return Ar === void 0 ? e.emptyIterator : Vt(Ar) ? pt(Ar) : Ar;
              }
            }
            e.flatMapIterator = be;
            function Xe(C, W) {
              var ee;
              if (C)
                for (var le = 0; le < C.length; le++) {
                  var Ze = C[le], Ir = W(Ze, le);
                  (ee || Ze !== Ir || Vt(Ir)) && (ee || (ee = C.slice(0, le)), Vt(Ir) ? h(ee, Ir) : ee.push(Ir));
                }
              return ee || C;
            }
            e.sameFlatMap = Xe;
            function Re(C, W) {
              for (var ee = [], le = 0; le < C.length; le++) {
                var Ze = W(C[le], le);
                if (Ze === void 0)
                  return;
                ee.push(Ze);
              }
              return ee;
            }
            e.mapAllOrFail = Re;
            function Fe(C, W) {
              var ee = [];
              if (C)
                for (var le = 0; le < C.length; le++) {
                  var Ze = W(C[le], le);
                  Ze !== void 0 && ee.push(Ze);
                }
              return ee;
            }
            e.mapDefined = Fe;
            function dr(C, W) {
              return { next: function() {
                for (; ; ) {
                  var ee = C.next();
                  if (ee.done)
                    return ee;
                  var le = W(ee.value);
                  if (le !== void 0)
                    return { value: le, done: false };
                }
              } };
            }
            e.mapDefinedIterator = dr;
            function ze(C, W) {
              if (C) {
                var ee = new e.Map();
                return C.forEach(function(le, Ze) {
                  var Ir = W(Ze, le);
                  if (Ir !== void 0) {
                    var Ar = Ir[0], hr = Ir[1];
                    Ar !== void 0 && hr !== void 0 && ee.set(Ar, hr);
                  }
                }), ee;
              }
            }
            e.mapDefinedEntries = ze;
            function ve(C, W) {
              if (C) {
                var ee = new e.Set();
                return C.forEach(function(le) {
                  var Ze = W(le);
                  Ze !== void 0 && ee.add(Ze);
                }), ee;
              }
            }
            e.mapDefinedValues = ve;
            function er(C, W, ee) {
              if (C.has(W))
                return C.get(W);
              var le = ee();
              return C.set(W, le), le;
            }
            e.getOrUpdate = er;
            function ar(C, W) {
              return C.has(W) ? false : (C.add(W), true);
            }
            e.tryAddToSet = ar, e.emptyIterator = { next: function() {
              return { value: void 0, done: true };
            } };
            function Cr(C) {
              var W = false;
              return { next: function() {
                var ee = W;
                return W = true, ee ? { value: void 0, done: true } : { value: C, done: false };
              } };
            }
            e.singleIterator = Cr;
            function Ce(C, W, ee) {
              var le;
              if (C) {
                le = [];
                for (var Ze = C.length, Ir = void 0, Ar = void 0, hr = 0, yt = 0; hr < Ze; ) {
                  for (; yt < Ze; ) {
                    var Pt = C[yt];
                    if (Ar = W(Pt, yt), yt === 0)
                      Ir = Ar;
                    else if (Ar !== Ir)
                      break;
                    yt++;
                  }
                  if (hr < yt) {
                    var Ut = ee(C.slice(hr, yt), Ir, hr, yt);
                    Ut && le.push(Ut), hr = yt;
                  }
                  Ir = Ar, yt++;
                }
              }
              return le;
            }
            e.spanMap = Ce;
            function $e(C, W) {
              if (C) {
                var ee = new e.Map();
                return C.forEach(function(le, Ze) {
                  var Ir = W(Ze, le), Ar = Ir[0], hr = Ir[1];
                  ee.set(Ar, hr);
                }), ee;
              }
            }
            e.mapEntries = $e;
            function gr(C, W) {
              if (C)
                if (W)
                  for (var ee = 0, le = C; ee < le.length; ee++) {
                    var Ze = le[ee];
                    if (W(Ze))
                      return true;
                  }
                else
                  return C.length > 0;
              return false;
            }
            e.some = gr;
            function X(C, W, ee) {
              for (var le, Ze = 0; Ze < C.length; Ze++)
                W(C[Ze]) ? le = le === void 0 ? Ze : le : le !== void 0 && (ee(le, Ze), le = void 0);
              le !== void 0 && ee(le, C.length);
            }
            e.getRangesWhere = X;
            function Te(C, W) {
              return gr(W) ? gr(C) ? D(D([], C, true), W, true) : W : C;
            }
            e.concatenate = Te;
            function we(C, W) {
              return W;
            }
            function he(C) {
              return C.map(we);
            }
            e.indicesOf = he;
            function yr(C, W, ee) {
              var le = he(C);
              jr(C, le, ee);
              for (var Ze = C[le[0]], Ir = [le[0]], Ar = 1; Ar < le.length; Ar++) {
                var hr = le[Ar], yt = C[hr];
                W(Ze, yt) || (Ir.push(hr), Ze = yt);
              }
              return Ir.sort(), Ir.map(function(Pt) {
                return C[Pt];
              });
            }
            function kr(C, W) {
              for (var ee = [], le = 0, Ze = C; le < Ze.length; le++) {
                var Ir = Ze[le];
                oe(ee, Ir, W);
              }
              return ee;
            }
            function nr(C, W, ee) {
              return C.length === 0 ? [] : C.length === 1 ? C.slice() : ee ? yr(C, W, ee) : kr(C, W);
            }
            e.deduplicate = nr;
            function tr(C, W) {
              if (C.length === 0)
                return e.emptyArray;
              for (var ee = C[0], le = [ee], Ze = 1; Ze < C.length; Ze++) {
                var Ir = C[Ze];
                switch (W(Ir, ee)) {
                  case true:
                  case 0:
                    continue;
                  case -1:
                    return e.Debug.fail("Array is unsorted.");
                }
                le.push(ee = Ir);
              }
              return le;
            }
            function Lr() {
              return [];
            }
            e.createSortedArray = Lr;
            function zr(C, W, ee, le) {
              if (C.length === 0)
                return C.push(W), true;
              var Ze = Mr(C, W, Dn, ee);
              return Ze < 0 ? (C.splice(~Ze, 0, W), true) : le ? (C.splice(Ze, 0, W), true) : false;
            }
            e.insertSorted = zr;
            function ye(C, W, ee) {
              return tr(qr(C, W), ee || W || Le);
            }
            e.sortAndDeduplicate = ye;
            function ir(C, W) {
              if (C.length < 2)
                return true;
              for (var ee = C[0], le = 0, Ze = C.slice(1); le < Ze.length; le++) {
                var Ir = Ze[le];
                if (W(ee, Ir) === 1)
                  return false;
                ee = Ir;
              }
              return true;
            }
            e.arrayIsSorted = ir;
            function Dr(C, W, ee) {
              if (ee === void 0 && (ee = On), !C || !W)
                return C === W;
              if (C.length !== W.length)
                return false;
              for (var le = 0; le < C.length; le++)
                if (!ee(C[le], W[le], le))
                  return false;
              return true;
            }
            e.arrayIsEqualTo = Dr;
            function Pr(C) {
              var W;
              if (C)
                for (var ee = 0; ee < C.length; ee++) {
                  var le = C[ee];
                  (W || !le) && (W || (W = C.slice(0, ee)), le && W.push(le));
                }
              return W || C;
            }
            e.compact = Pr;
            function Br(C, W, ee) {
              if (!W || !C || W.length === 0 || C.length === 0)
                return W;
              var le = [];
              e:
                for (var Ze = 0, Ir = 0; Ir < W.length; Ir++) {
                  Ir > 0 && e.Debug.assertGreaterThanOrEqual(ee(W[Ir], W[Ir - 1]), 0);
                  r:
                    for (var Ar = Ze; Ze < C.length; Ze++)
                      switch (Ze > Ar && e.Debug.assertGreaterThanOrEqual(ee(C[Ze], C[Ze - 1]), 0), ee(W[Ir], C[Ze])) {
                        case -1:
                          le.push(W[Ir]);
                          continue e;
                        case 0:
                          continue e;
                        case 1:
                          continue r;
                      }
                }
              return le;
            }
            e.relativeComplement = Br;
            function ut(C, W) {
              for (var ee = 0, le = 0, Ze = C; le < Ze.length; le++) {
                var Ir = Ze[le];
                ee += Ir[W];
              }
              return ee;
            }
            e.sum = ut;
            function rt(C, W) {
              return W === void 0 ? C : C === void 0 ? [W] : (C.push(W), C);
            }
            e.append = rt;
            function Z(C, W) {
              return C === void 0 ? W : W === void 0 ? C : Vt(C) ? Vt(W) ? Te(C, W) : rt(C, W) : Vt(W) ? rt(W, C) : [C, W];
            }
            e.combine = Z;
            function f(C, W) {
              return W < 0 ? C.length + W : W;
            }
            function h(C, W, ee, le) {
              if (W === void 0 || W.length === 0)
                return C;
              if (C === void 0)
                return W.slice(ee, le);
              ee = ee === void 0 ? 0 : f(W, ee), le = le === void 0 ? W.length : f(W, le);
              for (var Ze = ee; Ze < le && Ze < W.length; Ze++)
                W[Ze] !== void 0 && C.push(W[Ze]);
              return C;
            }
            e.addRange = h;
            function oe(C, W, ee) {
              return m(C, W, ee) ? false : (C.push(W), true);
            }
            e.pushIfUnique = oe;
            function xr(C, W, ee) {
              return C ? (oe(C, W, ee), C) : [W];
            }
            e.appendIfUnique = xr;
            function jr(C, W, ee) {
              W.sort(function(le, Ze) {
                return ee(C[le], C[Ze]) || L(le, Ze);
              });
            }
            function qr(C, W) {
              return C.length === 0 ? C : C.slice().sort(W);
            }
            e.sort = qr;
            function pt(C) {
              var W = 0;
              return { next: function() {
                return W === C.length ? { value: void 0, done: true } : (W++, { value: C[W - 1], done: false });
              } };
            }
            e.arrayIterator = pt;
            function Ge(C) {
              var W = C.length;
              return { next: function() {
                return W === 0 ? { value: void 0, done: true } : (W--, { value: C[W], done: false });
              } };
            }
            e.arrayReverseIterator = Ge;
            function K(C, W) {
              var ee = he(C);
              return jr(C, ee, W), ee.map(function(le) {
                return C[le];
              });
            }
            e.stableSort = K;
            function r(C, W, ee, le) {
              for (; ee < le; ) {
                if (C[ee] !== W[ee])
                  return false;
                ee++;
              }
              return true;
            }
            e.rangeEquals = r;
            function ct(C, W) {
              if (C && (W = f(C, W), W < C.length))
                return C[W];
            }
            e.elementAt = ct;
            function ft(C) {
              return C === void 0 || C.length === 0 ? void 0 : C[0];
            }
            e.firstOrUndefined = ft;
            function Ie(C) {
              return e.Debug.assert(C.length !== 0), C[0];
            }
            e.first = Ie;
            function me(C) {
              return C === void 0 || C.length === 0 ? void 0 : C[C.length - 1];
            }
            e.lastOrUndefined = me;
            function xe(C) {
              return e.Debug.assert(C.length !== 0), C[C.length - 1];
            }
            e.last = xe;
            function Ye(C) {
              return C && C.length === 1 ? C[0] : void 0;
            }
            e.singleOrUndefined = Ye;
            function vr(C) {
              return e.Debug.checkDefined(Ye(C));
            }
            e.single = vr;
            function nt(C) {
              return C && C.length === 1 ? C[0] : C;
            }
            e.singleOrMany = nt;
            function pr(C, W, ee) {
              var le = C.slice(0);
              return le[W] = ee, le;
            }
            e.replaceElement = pr;
            function Mr(C, W, ee, le, Ze) {
              return ot(C, ee(W), ee, le, Ze);
            }
            e.binarySearch = Mr;
            function ot(C, W, ee, le, Ze) {
              if (!gr(C))
                return -1;
              for (var Ir = Ze || 0, Ar = C.length - 1; Ir <= Ar; ) {
                var hr = Ir + (Ar - Ir >> 1), yt = ee(C[hr], hr);
                switch (le(yt, W)) {
                  case -1:
                    Ir = hr + 1;
                    break;
                  case 0:
                    return hr;
                  case 1:
                    Ar = hr - 1;
                    break;
                }
              }
              return ~Ir;
            }
            e.binarySearchKey = ot;
            function At(C, W, ee, le, Ze) {
              if (C && C.length > 0) {
                var Ir = C.length;
                if (Ir > 0) {
                  var Ar = le === void 0 || le < 0 ? 0 : le, hr = Ze === void 0 || Ar + Ze > Ir - 1 ? Ir - 1 : Ar + Ze, yt = void 0;
                  for (arguments.length <= 2 ? (yt = C[Ar], Ar++) : yt = ee; Ar <= hr; )
                    yt = W(yt, C[Ar], Ar), Ar++;
                  return yt;
                }
              }
              return ee;
            }
            e.reduceLeft = At;
            var re = Object.prototype.hasOwnProperty;
            function de(C, W) {
              return re.call(C, W);
            }
            e.hasProperty = de;
            function He(C, W) {
              return re.call(C, W) ? C[W] : void 0;
            }
            e.getProperty = He;
            function Nr(C) {
              var W = [];
              for (var ee in C)
                re.call(C, ee) && W.push(ee);
              return W;
            }
            e.getOwnKeys = Nr;
            function Yr(C) {
              var W = [];
              do
                for (var ee = Object.getOwnPropertyNames(C), le = 0, Ze = ee; le < Ze.length; le++) {
                  var Ir = Ze[le];
                  oe(W, Ir);
                }
              while (C = Object.getPrototypeOf(C));
              return W;
            }
            e.getAllKeys = Yr;
            function Ct(C) {
              var W = [];
              for (var ee in C)
                re.call(C, ee) && W.push(C[ee]);
              return W;
            }
            e.getOwnValues = Ct;
            var xt = Object.entries || function(C) {
              for (var W = Nr(C), ee = Array(W.length), le = 0; le < W.length; le++)
                ee[le] = [W[le], C[W[le]]];
              return ee;
            };
            function Lt(C) {
              return C ? xt(C) : [];
            }
            e.getEntries = Lt;
            function zt(C, W) {
              for (var ee = new Array(C), le = 0; le < C; le++)
                ee[le] = W(le);
              return ee;
            }
            e.arrayOf = zt;
            function Zt(C, W) {
              for (var ee = [], le = C.next(); !le.done; le = C.next())
                ee.push(W ? W(le.value) : le.value);
              return ee;
            }
            e.arrayFrom = Zt;
            function mt(C) {
              for (var W = [], ee = 1; ee < arguments.length; ee++)
                W[ee - 1] = arguments[ee];
              for (var le = 0, Ze = W; le < Ze.length; le++) {
                var Ir = Ze[le];
                if (Ir !== void 0)
                  for (var Ar in Ir)
                    de(Ir, Ar) && (C[Ar] = Ir[Ar]);
              }
              return C;
            }
            e.assign = mt;
            function at(C, W, ee) {
              if (ee === void 0 && (ee = On), C === W)
                return true;
              if (!C || !W)
                return false;
              for (var le in C)
                if (re.call(C, le) && (!re.call(W, le) || !ee(C[le], W[le])))
                  return false;
              for (var le in W)
                if (re.call(W, le) && !re.call(C, le))
                  return false;
              return true;
            }
            e.equalOwnProperties = at;
            function k(C, W, ee) {
              ee === void 0 && (ee = Dn);
              for (var le = new e.Map(), Ze = 0, Ir = C; Ze < Ir.length; Ze++) {
                var Ar = Ir[Ze], hr = W(Ar);
                hr !== void 0 && le.set(hr, ee(Ar));
              }
              return le;
            }
            e.arrayToMap = k;
            function ue(C, W, ee) {
              ee === void 0 && (ee = Dn);
              for (var le = [], Ze = 0, Ir = C; Ze < Ir.length; Ze++) {
                var Ar = Ir[Ze];
                le[W(Ar)] = ee(Ar);
              }
              return le;
            }
            e.arrayToNumericMap = ue;
            function Qe(C, W, ee) {
              ee === void 0 && (ee = Dn);
              for (var le = cn(), Ze = 0, Ir = C; Ze < Ir.length; Ze++) {
                var Ar = Ir[Ze];
                le.add(W(Ar), ee(Ar));
              }
              return le;
            }
            e.arrayToMultiMap = Qe;
            function Sr(C, W, ee) {
              return ee === void 0 && (ee = Dn), Zt(Qe(C, W).values(), ee);
            }
            e.group = Sr;
            function Kr(C) {
              var W = {};
              for (var ee in C)
                re.call(C, ee) && (W[ee] = C[ee]);
              return W;
            }
            e.clone = Kr;
            function Hr(C, W) {
              var ee = {};
              for (var le in W)
                re.call(W, le) && (ee[le] = W[le]);
              for (var le in C)
                re.call(C, le) && (ee[le] = C[le]);
              return ee;
            }
            e.extend = Hr;
            function Dt(C, W) {
              for (var ee in W)
                re.call(W, ee) && (C[ee] = W[ee]);
            }
            e.copyProperties = Dt;
            function Xt(C, W) {
              return W ? W.bind(C) : void 0;
            }
            e.maybeBind = Xt;
            function cn() {
              var C = new e.Map();
              return C.add = In, C.remove = yn, C;
            }
            e.createMultiMap = cn;
            function In(C, W) {
              var ee = this.get(C);
              return ee ? ee.push(W) : this.set(C, ee = [W]), ee;
            }
            function yn(C, W) {
              var ee = this.get(C);
              ee && (Rn(ee, W), ee.length || this.delete(C));
            }
            function hn() {
              return cn();
            }
            e.createUnderscoreEscapedMultiMap = hn;
            function ln(C) {
              var W = (C == null ? void 0 : C.slice()) || [], ee = 0;
              function le() {
                return ee === W.length;
              }
              function Ze() {
                for (var Ar = [], hr = 0; hr < arguments.length; hr++)
                  Ar[hr] = arguments[hr];
                W.push.apply(W, Ar);
              }
              function Ir() {
                if (le())
                  throw new Error("Queue is empty");
                var Ar = W[ee];
                if (W[ee] = void 0, ee++, ee > 100 && ee > W.length >> 1) {
                  var hr = W.length - ee;
                  W.copyWithin(0, ee), W.length = hr, ee = 0;
                }
                return Ar;
              }
              return { enqueue: Ze, dequeue: Ir, isEmpty: le };
            }
            e.createQueue = ln;
            function En(C, W) {
              var ee = new e.Map(), le = 0;
              function Ze() {
                var Ar = ee.values(), hr;
                return { next: function() {
                  for (; ; )
                    if (hr) {
                      var yt = hr.next();
                      if (!yt.done)
                        return { value: yt.value };
                      hr = void 0;
                    } else {
                      var yt = Ar.next();
                      if (yt.done)
                        return { value: void 0, done: true };
                      if (!Vt(yt.value))
                        return { value: yt.value };
                      hr = pt(yt.value);
                    }
                } };
              }
              var Ir = { has: function(Ar) {
                var hr = C(Ar);
                if (!ee.has(hr))
                  return false;
                var yt = ee.get(hr);
                if (!Vt(yt))
                  return W(yt, Ar);
                for (var Pt = 0, Ut = yt; Pt < Ut.length; Pt++) {
                  var jt = Ut[Pt];
                  if (W(jt, Ar))
                    return true;
                }
                return false;
              }, add: function(Ar) {
                var hr = C(Ar);
                if (ee.has(hr)) {
                  var yt = ee.get(hr);
                  if (Vt(yt))
                    m(yt, Ar, W) || (yt.push(Ar), le++);
                  else {
                    var Pt = yt;
                    W(Pt, Ar) || (ee.set(hr, [Pt, Ar]), le++);
                  }
                } else
                  ee.set(hr, Ar), le++;
                return this;
              }, delete: function(Ar) {
                var hr = C(Ar);
                if (!ee.has(hr))
                  return false;
                var yt = ee.get(hr);
                if (Vt(yt)) {
                  for (var Pt = 0; Pt < yt.length; Pt++)
                    if (W(yt[Pt], Ar))
                      return yt.length === 1 ? ee.delete(hr) : yt.length === 2 ? ee.set(hr, yt[1 - Pt]) : Mn(yt, Pt), le--, true;
                } else {
                  var Ut = yt;
                  if (W(Ut, Ar))
                    return ee.delete(hr), le--, true;
                }
                return false;
              }, clear: function() {
                ee.clear(), le = 0;
              }, get size() {
                return le;
              }, forEach: function(Ar) {
                for (var hr = 0, yt = Zt(ee.values()); hr < yt.length; hr++) {
                  var Pt = yt[hr];
                  if (Vt(Pt))
                    for (var Ut = 0, jt = Pt; Ut < jt.length; Ut++) {
                      var Ht = jt[Ut];
                      Ar(Ht, Ht);
                    }
                  else {
                    var Ht = Pt;
                    Ar(Ht, Ht);
                  }
                }
              }, keys: function() {
                return Ze();
              }, values: function() {
                return Ze();
              }, entries: function() {
                var Ar = Ze();
                return { next: function() {
                  var hr = Ar.next();
                  return hr.done ? hr : { value: [hr.value, hr.value] };
                } };
              } };
              return Ir;
            }
            e.createSet = En;
            function Vt(C) {
              return Array.isArray ? Array.isArray(C) : C instanceof Array;
            }
            e.isArray = Vt;
            function ui(C) {
              return Vt(C) ? C : [C];
            }
            e.toArray = ui;
            function ei(C) {
              return typeof C == "string";
            }
            e.isString = ei;
            function hi(C) {
              return typeof C == "number";
            }
            e.isNumber = hi;
            function ri(C, W) {
              return C !== void 0 && W(C) ? C : void 0;
            }
            e.tryCast = ri;
            function vi(C, W) {
              return C !== void 0 && W(C) ? C : e.Debug.fail("Invalid cast. The supplied value ".concat(C, " did not pass the test '").concat(e.Debug.getFunctionName(W), "'."));
            }
            e.cast = vi;
            function Qn(C) {
            }
            e.noop = Qn, e.noopPush = { push: Qn, length: 0 };
            function Yn() {
              return false;
            }
            e.returnFalse = Yn;
            function oi() {
              return true;
            }
            e.returnTrue = oi;
            function bi() {
            }
            e.returnUndefined = bi;
            function Dn(C) {
              return C;
            }
            e.identity = Dn;
            function Kn(C) {
              return C.toLowerCase();
            }
            e.toLowerCase = Kn;
            var si = /[^\u0130\u0131\u00DFa-z0-9\\/:\-_\. ]+/g;
            function di(C) {
              return si.test(C) ? C.replace(si, Kn) : C;
            }
            e.toFileNameLowerCase = di;
            function Zn() {
              throw new Error("Not implemented");
            }
            e.notImplemented = Zn;
            function Fn(C) {
              var W;
              return function() {
                return C && (W = C(), C = void 0), W;
              };
            }
            e.memoize = Fn;
            function gt(C) {
              var W = new e.Map();
              return function(ee) {
                var le = "".concat(typeof ee, ":").concat(ee), Ze = W.get(le);
                return Ze === void 0 && !W.has(le) && (Ze = C(ee), W.set(le, Ze)), Ze;
              };
            }
            e.memoizeOne = gt;
            function mi(C, W, ee, le, Ze) {
              if (Ze) {
                for (var Ir = [], Ar = 0; Ar < arguments.length; Ar++)
                  Ir[Ar] = arguments[Ar];
                return function(hr) {
                  return At(Ir, function(yt, Pt) {
                    return Pt(yt);
                  }, hr);
                };
              } else
                return le ? function(hr) {
                  return le(ee(W(C(hr))));
                } : ee ? function(hr) {
                  return ee(W(C(hr)));
                } : W ? function(hr) {
                  return W(C(hr));
                } : C ? function(hr) {
                  return C(hr);
                } : function(hr) {
                  return hr;
                };
            }
            e.compose = mi;
            var dn;
            (function(C) {
              C[C.None = 0] = "None", C[C.Normal = 1] = "Normal", C[C.Aggressive = 2] = "Aggressive", C[C.VeryAggressive = 3] = "VeryAggressive";
            })(dn = e.AssertionLevel || (e.AssertionLevel = {}));
            function On(C, W) {
              return C === W;
            }
            e.equateValues = On;
            function br(C, W) {
              return C === W || C !== void 0 && W !== void 0 && C.toUpperCase() === W.toUpperCase();
            }
            e.equateStringsCaseInsensitive = br;
            function Ae(C, W) {
              return On(C, W);
            }
            e.equateStringsCaseSensitive = Ae;
            function ur(C, W) {
              return C === W ? 0 : C === void 0 ? -1 : W === void 0 ? 1 : C < W ? -1 : 1;
            }
            function L(C, W) {
              return ur(C, W);
            }
            e.compareValues = L;
            function qt(C, W) {
              return L(C == null ? void 0 : C.start, W == null ? void 0 : W.start) || L(C == null ? void 0 : C.length, W == null ? void 0 : W.length);
            }
            e.compareTextSpans = qt;
            function nn(C, W) {
              return At(C, function(ee, le) {
                return W(ee, le) === -1 ? ee : le;
              });
            }
            e.min = nn;
            function fr(C, W) {
              return C === W ? 0 : C === void 0 ? -1 : W === void 0 ? 1 : (C = C.toUpperCase(), W = W.toUpperCase(), C < W ? -1 : C > W ? 1 : 0);
            }
            e.compareStringsCaseInsensitive = fr;
            function Le(C, W) {
              return ur(C, W);
            }
            e.compareStringsCaseSensitive = Le;
            function Ve(C) {
              return C ? fr : Le;
            }
            e.getStringComparer = Ve;
            var _r = function() {
              var C, W, ee = hr();
              return yt;
              function le(Pt, Ut, jt) {
                if (Pt === Ut)
                  return 0;
                if (Pt === void 0)
                  return -1;
                if (Ut === void 0)
                  return 1;
                var Ht = jt(Pt, Ut);
                return Ht < 0 ? -1 : Ht > 0 ? 1 : 0;
              }
              function Ze(Pt) {
                var Ut = new Intl.Collator(Pt, { usage: "sort", sensitivity: "variant" }).compare;
                return function(jt, Ht) {
                  return le(jt, Ht, Ut);
                };
              }
              function Ir(Pt) {
                if (Pt !== void 0)
                  return Ar();
                return function(jt, Ht) {
                  return le(jt, Ht, Ut);
                };
                function Ut(jt, Ht) {
                  return jt.localeCompare(Ht);
                }
              }
              function Ar() {
                return function(jt, Ht) {
                  return le(jt, Ht, Pt);
                };
                function Pt(jt, Ht) {
                  return Ut(jt.toUpperCase(), Ht.toUpperCase()) || Ut(jt, Ht);
                }
                function Ut(jt, Ht) {
                  return jt < Ht ? -1 : jt > Ht ? 1 : 0;
                }
              }
              function hr() {
                return typeof Intl == "object" && typeof Intl.Collator == "function" ? Ze : typeof String.prototype.localeCompare == "function" && typeof String.prototype.toLocaleUpperCase == "function" && "a".localeCompare("B") < 0 ? Ir : Ar;
              }
              function yt(Pt) {
                return Pt === void 0 ? C || (C = ee(Pt)) : Pt === "en-US" ? W || (W = ee(Pt)) : ee(Pt);
              }
            }(), lr, Vr;
            function tt() {
              return Vr;
            }
            e.getUILocale = tt;
            function dt(C) {
              Vr !== C && (Vr = C, lr = void 0);
            }
            e.setUILocale = dt;
            function It(C, W) {
              var ee = lr || (lr = _r(Vr));
              return ee(C, W);
            }
            e.compareStringsCaseSensitiveUI = It;
            function an(C, W, ee, le) {
              return C === W ? 0 : C === void 0 ? -1 : W === void 0 ? 1 : le(C[ee], W[ee]);
            }
            e.compareProperties = an;
            function sn(C, W) {
              return L(C ? 1 : 0, W ? 1 : 0);
            }
            e.compareBooleans = sn;
            function _e(C, W, ee) {
              for (var le = Math.max(2, Math.floor(C.length * 0.34)), Ze = Math.floor(C.length * 0.4) + 1, Ir, Ar = 0, hr = W; Ar < hr.length; Ar++) {
                var yt = hr[Ar], Pt = ee(yt);
                if (Pt !== void 0 && Math.abs(Pt.length - C.length) <= le) {
                  if (Pt === C || Pt.length < 3 && Pt.toLowerCase() !== C.toLowerCase())
                    continue;
                  var Ut = Gr(C, Pt, Ze - 0.1);
                  if (Ut === void 0)
                    continue;
                  e.Debug.assert(Ut < Ze), Ze = Ut, Ir = yt;
                }
              }
              return Ir;
            }
            e.getSpellingSuggestion = _e;
            function Gr(C, W, ee) {
              for (var le = new Array(W.length + 1), Ze = new Array(W.length + 1), Ir = ee + 0.01, Ar = 0; Ar <= W.length; Ar++)
                le[Ar] = Ar;
              for (var Ar = 1; Ar <= C.length; Ar++) {
                var hr = C.charCodeAt(Ar - 1), yt = Math.ceil(Ar > ee ? Ar - ee : 1), Pt = Math.floor(W.length > ee + Ar ? ee + Ar : W.length);
                Ze[0] = Ar;
                for (var Ut = Ar, jt = 1; jt < yt; jt++)
                  Ze[jt] = Ir;
                for (var jt = yt; jt <= Pt; jt++) {
                  var Ht = C[Ar - 1].toLowerCase() === W[jt - 1].toLowerCase() ? le[jt - 1] + 0.1 : le[jt - 1] + 2, gi = hr === W.charCodeAt(jt - 1) ? le[jt - 1] : Math.min(le[jt] + 1, Ze[jt - 1] + 1, Ht);
                  Ze[jt] = gi, Ut = Math.min(Ut, gi);
                }
                for (var jt = Pt + 1; jt <= W.length; jt++)
                  Ze[jt] = Ir;
                if (Ut > ee)
                  return;
                var Pi = le;
                le = Ze, Ze = Pi;
              }
              var Gn = le[W.length];
              return Gn > ee ? void 0 : Gn;
            }
            function Kt(C, W) {
              var ee = C.length - W.length;
              return ee >= 0 && C.indexOf(W, ee) === ee;
            }
            e.endsWith = Kt;
            function en(C, W) {
              return Kt(C, W) ? C.slice(0, C.length - W.length) : C;
            }
            e.removeSuffix = en;
            function Ot(C, W) {
              return Kt(C, W) ? C.slice(0, C.length - W.length) : void 0;
            }
            e.tryRemoveSuffix = Ot;
            function rr(C, W) {
              return C.indexOf(W) !== -1;
            }
            e.stringContains = rr;
            function Hn(C) {
              for (var W = C.length, ee = W - 1; ee > 0; ee--) {
                var le = C.charCodeAt(ee);
                if (le >= 48 && le <= 57)
                  do
                    --ee, le = C.charCodeAt(ee);
                  while (ee > 0 && le >= 48 && le <= 57);
                else if (ee > 4 && (le === 110 || le === 78)) {
                  if (--ee, le = C.charCodeAt(ee), le !== 105 && le !== 73 || (--ee, le = C.charCodeAt(ee), le !== 109 && le !== 77))
                    break;
                  --ee, le = C.charCodeAt(ee);
                } else
                  break;
                if (le !== 45 && le !== 46)
                  break;
                W = ee;
              }
              return W === C.length ? C : C.slice(0, W);
            }
            e.removeMinAndVersionNumbers = Hn;
            function rn(C, W) {
              for (var ee = 0; ee < C.length; ee++)
                if (C[ee] === W)
                  return xn(C, ee), true;
              return false;
            }
            e.orderedRemoveItem = rn;
            function xn(C, W) {
              for (var ee = W; ee < C.length - 1; ee++)
                C[ee] = C[ee + 1];
              C.pop();
            }
            e.orderedRemoveItemAt = xn;
            function Mn(C, W) {
              C[W] = C[C.length - 1], C.pop();
            }
            e.unorderedRemoveItemAt = Mn;
            function Rn(C, W) {
              return kn(C, function(ee) {
                return ee === W;
              });
            }
            e.unorderedRemoveItem = Rn;
            function kn(C, W) {
              for (var ee = 0; ee < C.length; ee++)
                if (W(C[ee]))
                  return Mn(C, ee), true;
              return false;
            }
            function on(C) {
              return C ? Dn : di;
            }
            e.createGetCanonicalFileName = on;
            function Xr(C) {
              var W = C.prefix, ee = C.suffix;
              return "".concat(W, "*").concat(ee);
            }
            e.patternText = Xr;
            function wr(C, W) {
              return e.Debug.assert(xi(C, W)), W.substring(C.prefix.length, W.length - C.suffix.length);
            }
            e.matchedText = wr;
            function fn(C, W, ee) {
              for (var le, Ze = -1, Ir = 0, Ar = C; Ir < Ar.length; Ir++) {
                var hr = Ar[Ir], yt = W(hr);
                xi(yt, ee) && yt.prefix.length > Ze && (Ze = yt.prefix.length, le = hr);
              }
              return le;
            }
            e.findBestPatternMatch = fn;
            function mn(C, W) {
              return C.lastIndexOf(W, 0) === 0;
            }
            e.startsWith = mn;
            function Mi(C, W) {
              return mn(C, W) ? C.substr(W.length) : C;
            }
            e.removePrefix = Mi;
            function An(C, W, ee) {
              return ee === void 0 && (ee = Dn), mn(ee(C), ee(W)) ? C.substring(W.length) : void 0;
            }
            e.tryRemovePrefix = An;
            function xi(C, W) {
              var ee = C.prefix, le = C.suffix;
              return W.length >= ee.length + le.length && mn(W, ee) && Kt(W, le);
            }
            e.isPatternMatch = xi;
            function ti(C, W) {
              return function(ee) {
                return C(ee) && W(ee);
              };
            }
            e.and = ti;
            function li() {
              for (var C = [], W = 0; W < arguments.length; W++)
                C[W] = arguments[W];
              return function() {
                for (var ee = [], le = 0; le < arguments.length; le++)
                  ee[le] = arguments[le];
                for (var Ze, Ir = 0, Ar = C; Ir < Ar.length; Ir++) {
                  var hr = Ar[Ir];
                  if (Ze = hr.apply(void 0, ee), Ze)
                    return Ze;
                }
                return Ze;
              };
            }
            e.or = li;
            function Bn(C) {
              return function() {
                for (var W = [], ee = 0; ee < arguments.length; ee++)
                  W[ee] = arguments[ee];
                return !C.apply(void 0, W);
              };
            }
            e.not = Bn;
            function vn(C) {
            }
            e.assertType = vn;
            function Ue(C) {
              return C === void 0 ? void 0 : [C];
            }
            e.singleElementArray = Ue;
            function Vn(C, W, ee, le, Ze, Ir) {
              Ir = Ir || Qn;
              for (var Ar = 0, hr = 0, yt = C.length, Pt = W.length, Ut = false; Ar < yt && hr < Pt; ) {
                var jt = C[Ar], Ht = W[hr], gi = ee(jt, Ht);
                gi === -1 ? (le(jt), Ar++, Ut = true) : gi === 1 ? (Ze(Ht), hr++, Ut = true) : (Ir(Ht, jt), Ar++, hr++);
              }
              for (; Ar < yt; )
                le(C[Ar++]), Ut = true;
              for (; hr < Pt; )
                Ze(W[hr++]), Ut = true;
              return Ut;
            }
            e.enumerateInsertsAndDeletes = Vn;
            function Ei(C, W) {
              for (var ee = Array(C), le = 0; le < C; le++)
                ee[le] = W(le);
              return ee;
            }
            e.fill = Ei;
            function ni(C) {
              var W = [];
              return Fi(C, W, void 0, 0), W;
            }
            e.cartesianProduct = ni;
            function Fi(C, W, ee, le) {
              for (var Ze = 0, Ir = C[le]; Ze < Ir.length; Ze++) {
                var Ar = Ir[Ze], hr = void 0;
                ee ? (hr = ee.slice(), hr.push(Ar)) : hr = [Ar], le === C.length - 1 ? W.push(hr) : Fi(C, W, hr, le + 1);
              }
            }
            function Tn(C, W, ee) {
              return ee === void 0 && (ee = " "), W <= C.length ? C : ee.repeat(W - C.length) + C;
            }
            e.padLeft = Tn;
            function jn(C, W, ee) {
              return ee === void 0 && (ee = " "), W <= C.length ? C : C + ee.repeat(W - C.length);
            }
            e.padRight = jn;
            function Ti(C, W) {
              for (var ee = C.length, le = 0; le < ee && W(C[le]); )
                le++;
              return C.slice(0, le);
            }
            e.takeWhile = Ti, e.trimString = String.prototype.trim ? function(C) {
              return C.trim();
            } : function(C) {
              return e.trimStringEnd(e.trimStringStart(C));
            }, e.trimStringEnd = String.prototype.trimEnd ? function(C) {
              return C.trimEnd();
            } : Si, e.trimStringStart = String.prototype.trimStart ? function(C) {
              return C.trimStart();
            } : function(C) {
              return C.replace(/^\s+/g, "");
            };
            function Si(C) {
              for (var W = C.length - 1; W >= 0 && e.isWhiteSpaceLike(C.charCodeAt(W)); )
                W--;
              return C.slice(0, W + 1);
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(s) {
              s[s.Off = 0] = "Off", s[s.Error = 1] = "Error", s[s.Warning = 2] = "Warning", s[s.Info = 3] = "Info", s[s.Verbose = 4] = "Verbose";
            })(t3 = e.LogLevel || (e.LogLevel = {}));
            var w;
            (function(s) {
              var q, F = 0;
              s.currentLogLevel = t3.Warning, s.isDebugging = false, s.enableDeprecationWarnings = true;
              function fe() {
                return q != null ? q : q = new e.Version(e.version);
              }
              s.getTypeScriptVersion = fe;
              function Ee(me) {
                return s.currentLogLevel <= me;
              }
              s.shouldLog = Ee;
              function Se(me, xe) {
                s.loggingHost && Ee(me) && s.loggingHost.log(me, xe);
              }
              function J(me) {
                Se(t3.Info, me);
              }
              s.log = J, function(me) {
                function xe(pr) {
                  Se(t3.Error, pr);
                }
                me.error = xe;
                function Ye(pr) {
                  Se(t3.Warning, pr);
                }
                me.warn = Ye;
                function vr(pr) {
                  Se(t3.Info, pr);
                }
                me.log = vr;
                function nt(pr) {
                  Se(t3.Verbose, pr);
                }
                me.trace = nt;
              }(J = s.log || (s.log = {}));
              var se = {};
              function Me() {
                return F;
              }
              s.getAssertionLevel = Me;
              function Q(me) {
                var xe = F;
                if (F = me, me > xe)
                  for (var Ye = 0, vr = e.getOwnKeys(se); Ye < vr.length; Ye++) {
                    var nt = vr[Ye], pr = se[nt];
                    pr !== void 0 && s[nt] !== pr.assertion && me >= pr.level && (s[nt] = pr, se[nt] = void 0);
                  }
              }
              s.setAssertionLevel = Q;
              function Be(me) {
                return F >= me;
              }
              s.shouldAssert = Be;
              function je(me, xe) {
                return Be(me) ? true : (se[xe] = { level: me, assertion: s[xe] }, s[xe] = e.noop, false);
              }
              function V(me, xe) {
                debugger;
                var Ye = new Error(me ? "Debug Failure. ".concat(me) : "Debug Failure.");
                throw Error.captureStackTrace && Error.captureStackTrace(Ye, xe || V), Ye;
              }
              s.fail = V;
              function B(me, xe, Ye) {
                return V("".concat(xe || "Unexpected node.", `\r
Node `).concat(ar(me.kind), " was unexpected."), Ye || B);
              }
              s.failBadSyntaxKind = B;
              function U(me, xe, Ye, vr) {
                me || (xe = xe ? "False expression: ".concat(xe) : "False expression.", Ye && (xe += `\r
Verbose Debug Information: ` + (typeof Ye == "string" ? Ye : Ye())), V(xe, vr || U));
              }
              s.assert = U;
              function m(me, xe, Ye, vr, nt) {
                if (me !== xe) {
                  var pr = Ye ? vr ? "".concat(Ye, " ").concat(vr) : Ye : "";
                  V("Expected ".concat(me, " === ").concat(xe, ". ").concat(pr), nt || m);
                }
              }
              s.assertEqual = m;
              function v(me, xe, Ye, vr) {
                me >= xe && V("Expected ".concat(me, " < ").concat(xe, ". ").concat(Ye || ""), vr || v);
              }
              s.assertLessThan = v;
              function g(me, xe, Ye) {
                me > xe && V("Expected ".concat(me, " <= ").concat(xe), Ye || g);
              }
              s.assertLessThanOrEqual = g;
              function O(me, xe, Ye) {
                me < xe && V("Expected ".concat(me, " >= ").concat(xe), Ye || O);
              }
              s.assertGreaterThanOrEqual = O;
              function S(me, xe, Ye) {
                me == null && V(xe, Ye || S);
              }
              s.assertIsDefined = S;
              function te(me, xe, Ye) {
                return S(me, xe, Ye || te), me;
              }
              s.checkDefined = te;
              function Je(me, xe, Ye) {
                for (var vr = 0, nt = me; vr < nt.length; vr++) {
                  var pr = nt[vr];
                  S(pr, xe, Ye || Je);
                }
              }
              s.assertEachIsDefined = Je;
              function qe(me, xe, Ye) {
                return Je(me, xe, Ye || qe), me;
              }
              s.checkEachDefined = qe;
              function ge(me, xe, Ye) {
                xe === void 0 && (xe = "Illegal value:");
                var vr = typeof me == "object" && e.hasProperty(me, "kind") && e.hasProperty(me, "pos") ? "SyntaxKind: " + ar(me.kind) : JSON.stringify(me);
                return V("".concat(xe, " ").concat(vr), Ye || ge);
              }
              s.assertNever = ge;
              function ie(me, xe, Ye, vr) {
                je(1, "assertEachNode") && U(xe === void 0 || e.every(me, xe), Ye || "Unexpected node.", function() {
                  return "Node array did not pass test '".concat(Fe(xe), "'.");
                }, vr || ie);
              }
              s.assertEachNode = ie;
              function H(me, xe, Ye, vr) {
                je(1, "assertNode") && U(me !== void 0 && (xe === void 0 || xe(me)), Ye || "Unexpected node.", function() {
                  return "Node ".concat(ar(me == null ? void 0 : me.kind), " did not pass test '").concat(Fe(xe), "'.");
                }, vr || H);
              }
              s.assertNode = H;
              function pe(me, xe, Ye, vr) {
                je(1, "assertNotNode") && U(me === void 0 || xe === void 0 || !xe(me), Ye || "Unexpected node.", function() {
                  return "Node ".concat(ar(me.kind), " should not have passed test '").concat(Fe(xe), "'.");
                }, vr || pe);
              }
              s.assertNotNode = pe;
              function j(me, xe, Ye, vr) {
                je(1, "assertOptionalNode") && U(xe === void 0 || me === void 0 || xe(me), Ye || "Unexpected node.", function() {
                  return "Node ".concat(ar(me == null ? void 0 : me.kind), " did not pass test '").concat(Fe(xe), "'.");
                }, vr || j);
              }
              s.assertOptionalNode = j;
              function be(me, xe, Ye, vr) {
                je(1, "assertOptionalToken") && U(xe === void 0 || me === void 0 || me.kind === xe, Ye || "Unexpected node.", function() {
                  return "Node ".concat(ar(me == null ? void 0 : me.kind), " was not a '").concat(ar(xe), "' token.");
                }, vr || be);
              }
              s.assertOptionalToken = be;
              function Xe(me, xe, Ye) {
                je(1, "assertMissingNode") && U(me === void 0, xe || "Unexpected node.", function() {
                  return "Node ".concat(ar(me.kind), " was unexpected'.");
                }, Ye || Xe);
              }
              s.assertMissingNode = Xe;
              function Re(me) {
              }
              s.type = Re;
              function Fe(me) {
                if (typeof me != "function")
                  return "";
                if (e.hasProperty(me, "name"))
                  return me.name;
                var xe = Function.prototype.toString.call(me), Ye = /^function\s+([\w\$]+)\s*\(/.exec(xe);
                return Ye ? Ye[1] : "";
              }
              s.getFunctionName = Fe;
              function dr(me) {
                return "{ name: ".concat(e.unescapeLeadingUnderscores(me.escapedName), "; flags: ").concat(Te(me.flags), "; declarations: ").concat(e.map(me.declarations, function(xe) {
                  return ar(xe.kind);
                }), " }");
              }
              s.formatSymbol = dr;
              function ze(me, xe, Ye) {
                me === void 0 && (me = 0);
                var vr = er(xe);
                if (me === 0)
                  return vr.length > 0 && vr[0][0] === 0 ? vr[0][1] : "0";
                if (Ye) {
                  for (var nt = [], pr = me, Mr = 0, ot = vr; Mr < ot.length; Mr++) {
                    var At = ot[Mr], re = At[0], de = At[1];
                    if (re > me)
                      break;
                    re !== 0 && re & me && (nt.push(de), pr &= ~re);
                  }
                  if (pr === 0)
                    return nt.join("|");
                } else
                  for (var He = 0, Nr = vr; He < Nr.length; He++) {
                    var Yr = Nr[He], re = Yr[0], de = Yr[1];
                    if (re === me)
                      return de;
                  }
                return me.toString();
              }
              s.formatEnum = ze;
              var ve = new e.Map();
              function er(me) {
                var xe = ve.get(me);
                if (xe)
                  return xe;
                var Ye = [];
                for (var vr in me) {
                  var nt = me[vr];
                  typeof nt == "number" && Ye.push([nt, vr]);
                }
                var pr = e.stableSort(Ye, function(Mr, ot) {
                  return e.compareValues(Mr[0], ot[0]);
                });
                return ve.set(me, pr), pr;
              }
              function ar(me) {
                return ze(me, e.SyntaxKind, false);
              }
              s.formatSyntaxKind = ar;
              function Cr(me) {
                return ze(me, e.SnippetKind, false);
              }
              s.formatSnippetKind = Cr;
              function Ce(me) {
                return ze(me, e.NodeFlags, true);
              }
              s.formatNodeFlags = Ce;
              function $e(me) {
                return ze(me, e.ModifierFlags, true);
              }
              s.formatModifierFlags = $e;
              function gr(me) {
                return ze(me, e.TransformFlags, true);
              }
              s.formatTransformFlags = gr;
              function X(me) {
                return ze(me, e.EmitFlags, true);
              }
              s.formatEmitFlags = X;
              function Te(me) {
                return ze(me, e.SymbolFlags, true);
              }
              s.formatSymbolFlags = Te;
              function we(me) {
                return ze(me, e.TypeFlags, true);
              }
              s.formatTypeFlags = we;
              function he(me) {
                return ze(me, e.SignatureFlags, true);
              }
              s.formatSignatureFlags = he;
              function yr(me) {
                return ze(me, e.ObjectFlags, true);
              }
              s.formatObjectFlags = yr;
              function kr(me) {
                return ze(me, e.FlowFlags, true);
              }
              s.formatFlowFlags = kr;
              function nr(me) {
                return ze(me, e.RelationComparisonResult, true);
              }
              s.formatRelationComparisonResult = nr;
              function tr(me) {
                return ze(me, e.CheckMode, true);
              }
              s.formatCheckMode = tr;
              function Lr(me) {
                return ze(me, e.SignatureCheckMode, true);
              }
              s.formatSignatureCheckMode = Lr;
              function zr(me) {
                return ze(me, e.TypeFacts, true);
              }
              s.formatTypeFacts = zr;
              var ye = false, ir;
              function Dr() {
                if (xr(), !ir)
                  throw new Error("Debugging helpers could not be loaded.");
                return ir;
              }
              function Pr(me) {
                return console.log(Br(me));
              }
              s.printControlFlowGraph = Pr;
              function Br(me) {
                return Dr().formatControlFlowGraph(me);
              }
              s.formatControlFlowGraph = Br;
              var ut;
              function rt(me) {
                "__debugFlowFlags" in me || Object.defineProperties(me, { __tsDebuggerDisplay: { value: function() {
                  var xe = this.flags & 2 ? "FlowStart" : this.flags & 4 ? "FlowBranchLabel" : this.flags & 8 ? "FlowLoopLabel" : this.flags & 16 ? "FlowAssignment" : this.flags & 32 ? "FlowTrueCondition" : this.flags & 64 ? "FlowFalseCondition" : this.flags & 128 ? "FlowSwitchClause" : this.flags & 256 ? "FlowArrayMutation" : this.flags & 512 ? "FlowCall" : this.flags & 1024 ? "FlowReduceLabel" : this.flags & 1 ? "FlowUnreachable" : "UnknownFlow", Ye = this.flags & ~(2048 - 1);
                  return "".concat(xe).concat(Ye ? " (".concat(kr(Ye), ")") : "");
                } }, __debugFlowFlags: { get: function() {
                  return ze(this.flags, e.FlowFlags, true);
                } }, __debugToString: { value: function() {
                  return Br(this);
                } } });
              }
              function Z(me) {
                ye && (typeof Object.setPrototypeOf == "function" ? (ut || (ut = Object.create(Object.prototype), rt(ut)), Object.setPrototypeOf(me, ut)) : rt(me));
              }
              s.attachFlowNodeDebugInfo = Z;
              var f;
              function h(me) {
                "__tsDebuggerDisplay" in me || Object.defineProperties(me, { __tsDebuggerDisplay: { value: function(xe) {
                  return xe = String(xe).replace(/(?:,[\s\w\d_]+:[^,]+)+\]$/, "]"), "NodeArray ".concat(xe);
                } } });
              }
              function oe(me) {
                ye && (typeof Object.setPrototypeOf == "function" ? (f || (f = Object.create(Array.prototype), h(f)), Object.setPrototypeOf(me, f)) : h(me));
              }
              s.attachNodeArrayDebugInfo = oe;
              function xr() {
                if (ye)
                  return;
                var me, xe;
                function Ye() {
                  return me === void 0 && typeof WeakMap == "function" && (me = /* @__PURE__ */ new WeakMap()), me;
                }
                function vr() {
                  return xe === void 0 && typeof WeakMap == "function" && (xe = /* @__PURE__ */ new WeakMap()), xe;
                }
                Object.defineProperties(e.objectAllocator.getSymbolConstructor().prototype, { __tsDebuggerDisplay: { value: function() {
                  var de = this.flags & 33554432 ? "TransientSymbol" : "Symbol", He = this.flags & -33554433;
                  return "".concat(de, " '").concat(e.symbolName(this), "'").concat(He ? " (".concat(Te(He), ")") : "");
                } }, __debugFlags: { get: function() {
                  return Te(this.flags);
                } } }), Object.defineProperties(e.objectAllocator.getTypeConstructor().prototype, { __tsDebuggerDisplay: { value: function() {
                  var de = this.flags & 98304 ? "NullableType" : this.flags & 384 ? "LiteralType ".concat(JSON.stringify(this.value)) : this.flags & 2048 ? "LiteralType ".concat(this.value.negative ? "-" : "").concat(this.value.base10Value, "n") : this.flags & 8192 ? "UniqueESSymbolType" : this.flags & 32 ? "EnumType" : this.flags & 67359327 ? "IntrinsicType ".concat(this.intrinsicName) : this.flags & 1048576 ? "UnionType" : this.flags & 2097152 ? "IntersectionType" : this.flags & 4194304 ? "IndexType" : this.flags & 8388608 ? "IndexedAccessType" : this.flags & 16777216 ? "ConditionalType" : this.flags & 33554432 ? "SubstitutionType" : this.flags & 262144 ? "TypeParameter" : this.flags & 524288 ? this.objectFlags & 3 ? "InterfaceType" : this.objectFlags & 4 ? "TypeReference" : this.objectFlags & 8 ? "TupleType" : this.objectFlags & 16 ? "AnonymousType" : this.objectFlags & 32 ? "MappedType" : this.objectFlags & 1024 ? "ReverseMappedType" : this.objectFlags & 256 ? "EvolvingArrayType" : "ObjectType" : "Type", He = this.flags & 524288 ? this.objectFlags & -1344 : 0;
                  return "".concat(de).concat(this.symbol ? " '".concat(e.symbolName(this.symbol), "'") : "").concat(He ? " (".concat(yr(He), ")") : "");
                } }, __debugFlags: { get: function() {
                  return we(this.flags);
                } }, __debugObjectFlags: { get: function() {
                  return this.flags & 524288 ? yr(this.objectFlags) : "";
                } }, __debugTypeToString: { value: function() {
                  var de = Ye(), He = de == null ? void 0 : de.get(this);
                  return He === void 0 && (He = this.checker.typeToString(this), de == null || de.set(this, He)), He;
                } } }), Object.defineProperties(e.objectAllocator.getSignatureConstructor().prototype, { __debugFlags: { get: function() {
                  return he(this.flags);
                } }, __debugSignatureToString: { value: function() {
                  var de;
                  return (de = this.checker) === null || de === void 0 ? void 0 : de.signatureToString(this);
                } } });
                for (var nt = [e.objectAllocator.getNodeConstructor(), e.objectAllocator.getIdentifierConstructor(), e.objectAllocator.getTokenConstructor(), e.objectAllocator.getSourceFileConstructor()], pr = 0, Mr = nt; pr < Mr.length; pr++) {
                  var ot = Mr[pr];
                  e.hasProperty(ot.prototype, "__debugKind") || Object.defineProperties(ot.prototype, { __tsDebuggerDisplay: { value: function() {
                    var de = e.isGeneratedIdentifier(this) ? "GeneratedIdentifier" : e.isIdentifier(this) ? "Identifier '".concat(e.idText(this), "'") : e.isPrivateIdentifier(this) ? "PrivateIdentifier '".concat(e.idText(this), "'") : e.isStringLiteral(this) ? "StringLiteral ".concat(JSON.stringify(this.text.length < 10 ? this.text : this.text.slice(10) + "...")) : e.isNumericLiteral(this) ? "NumericLiteral ".concat(this.text) : e.isBigIntLiteral(this) ? "BigIntLiteral ".concat(this.text, "n") : e.isTypeParameterDeclaration(this) ? "TypeParameterDeclaration" : e.isParameter(this) ? "ParameterDeclaration" : e.isConstructorDeclaration(this) ? "ConstructorDeclaration" : e.isGetAccessorDeclaration(this) ? "GetAccessorDeclaration" : e.isSetAccessorDeclaration(this) ? "SetAccessorDeclaration" : e.isCallSignatureDeclaration(this) ? "CallSignatureDeclaration" : e.isConstructSignatureDeclaration(this) ? "ConstructSignatureDeclaration" : e.isIndexSignatureDeclaration(this) ? "IndexSignatureDeclaration" : e.isTypePredicateNode(this) ? "TypePredicateNode" : e.isTypeReferenceNode(this) ? "TypeReferenceNode" : e.isFunctionTypeNode(this) ? "FunctionTypeNode" : e.isConstructorTypeNode(this) ? "ConstructorTypeNode" : e.isTypeQueryNode(this) ? "TypeQueryNode" : e.isTypeLiteralNode(this) ? "TypeLiteralNode" : e.isArrayTypeNode(this) ? "ArrayTypeNode" : e.isTupleTypeNode(this) ? "TupleTypeNode" : e.isOptionalTypeNode(this) ? "OptionalTypeNode" : e.isRestTypeNode(this) ? "RestTypeNode" : e.isUnionTypeNode(this) ? "UnionTypeNode" : e.isIntersectionTypeNode(this) ? "IntersectionTypeNode" : e.isConditionalTypeNode(this) ? "ConditionalTypeNode" : e.isInferTypeNode(this) ? "InferTypeNode" : e.isParenthesizedTypeNode(this) ? "ParenthesizedTypeNode" : e.isThisTypeNode(this) ? "ThisTypeNode" : e.isTypeOperatorNode(this) ? "TypeOperatorNode" : e.isIndexedAccessTypeNode(this) ? "IndexedAccessTypeNode" : e.isMappedTypeNode(this) ? "MappedTypeNode" : e.isLiteralTypeNode(this) ? "LiteralTypeNode" : e.isNamedTupleMember(this) ? "NamedTupleMember" : e.isImportTypeNode(this) ? "ImportTypeNode" : ar(this.kind);
                    return "".concat(de).concat(this.flags ? " (".concat(Ce(this.flags), ")") : "");
                  } }, __debugKind: { get: function() {
                    return ar(this.kind);
                  } }, __debugNodeFlags: { get: function() {
                    return Ce(this.flags);
                  } }, __debugModifierFlags: { get: function() {
                    return $e(e.getEffectiveModifierFlagsNoCache(this));
                  } }, __debugTransformFlags: { get: function() {
                    return gr(this.transformFlags);
                  } }, __debugIsParseTreeNode: { get: function() {
                    return e.isParseTreeNode(this);
                  } }, __debugEmitFlags: { get: function() {
                    return X(e.getEmitFlags(this));
                  } }, __debugGetText: { value: function(de) {
                    if (e.nodeIsSynthesized(this))
                      return "";
                    var He = vr(), Nr = He == null ? void 0 : He.get(this);
                    if (Nr === void 0) {
                      var Yr = e.getParseTreeNode(this), Ct = Yr && e.getSourceFileOfNode(Yr);
                      Nr = Ct ? e.getSourceTextOfNodeFromSourceFile(Ct, Yr, de) : "", He == null || He.set(this, Nr);
                    }
                    return Nr;
                  } } });
                }
                try {
                  if (false)
                    var At, re;
                } catch {
                }
                ye = true;
              }
              s.enableDebugInfo = xr;
              function jr(me, xe, Ye, vr, nt) {
                var pr = xe ? "DeprecationError: " : "DeprecationWarning: ";
                return pr += "'".concat(me, "' "), pr += vr ? "has been deprecated since v".concat(vr) : "is deprecated", pr += xe ? " and can no longer be used." : Ye ? " and will no longer be usable after v".concat(Ye, ".") : ".", pr += nt ? " ".concat(e.formatStringFromArgs(nt, [me], 0)) : "", pr;
              }
              function qr(me, xe, Ye, vr) {
                var nt = jr(me, true, xe, Ye, vr);
                return function() {
                  throw new TypeError(nt);
                };
              }
              function pt(me, xe, Ye, vr) {
                var nt = false;
                return function() {
                  s.enableDeprecationWarnings && !nt && (J.warn(jr(me, false, xe, Ye, vr)), nt = true);
                };
              }
              function Ge(me, xe) {
                var Ye, vr;
                xe === void 0 && (xe = {});
                var nt = typeof xe.typeScriptVersion == "string" ? new e.Version(xe.typeScriptVersion) : (Ye = xe.typeScriptVersion) !== null && Ye !== void 0 ? Ye : fe(), pr = typeof xe.errorAfter == "string" ? new e.Version(xe.errorAfter) : xe.errorAfter, Mr = typeof xe.warnAfter == "string" ? new e.Version(xe.warnAfter) : xe.warnAfter, ot = typeof xe.since == "string" ? new e.Version(xe.since) : (vr = xe.since) !== null && vr !== void 0 ? vr : Mr, At = xe.error || pr && nt.compareTo(pr) <= 0, re = !Mr || nt.compareTo(Mr) >= 0;
                return At ? qr(me, pr, ot, xe.message) : re ? pt(me, pr, ot, xe.message) : e.noop;
              }
              s.createDeprecation = Ge;
              function K(me, xe) {
                return function() {
                  return me(), xe.apply(this, arguments);
                };
              }
              function r(me, xe) {
                var Ye, vr = Ge((Ye = xe == null ? void 0 : xe.name) !== null && Ye !== void 0 ? Ye : Fe(me), xe);
                return K(vr, me);
              }
              s.deprecate = r;
              function ct(me) {
                var xe = me & 7, Ye = xe === 0 ? "in out" : xe === 3 ? "[bivariant]" : xe === 2 ? "in" : xe === 1 ? "out" : xe === 4 ? "[independent]" : "";
                return me & 8 ? Ye += " (unmeasurable)" : me & 16 && (Ye += " (unreliable)"), Ye;
              }
              s.formatVariance = ct;
              var ft = function() {
                function me() {
                }
                return me.prototype.__debugToString = function() {
                  var xe;
                  switch (this.kind) {
                    case 3:
                      return ((xe = this.debugInfo) === null || xe === void 0 ? void 0 : xe.call(this)) || "(function mapper)";
                    case 0:
                      return "".concat(this.source.__debugTypeToString(), " -> ").concat(this.target.__debugTypeToString());
                    case 1:
                      return e.zipWith(this.sources, this.targets || e.map(this.sources, function() {
                        return "any";
                      }), function(Ye, vr) {
                        return "".concat(Ye.__debugTypeToString(), " -> ").concat(typeof vr == "string" ? vr : vr.__debugTypeToString());
                      }).join(", ");
                    case 2:
                      return e.zipWith(this.sources, this.targets, function(Ye, vr) {
                        return "".concat(Ye.__debugTypeToString(), " -> ").concat(vr().__debugTypeToString());
                      }).join(", ");
                    case 5:
                    case 4:
                      return "m1: ".concat(this.mapper1.__debugToString().split(`
`).join(`
    `), `
m2: `).concat(this.mapper2.__debugToString().split(`
`).join(`
    `));
                    default:
                      return ge(this);
                  }
                }, me;
              }();
              s.DebugTypeMapper = ft;
              function Ie(me) {
                return s.isDebugging ? Object.setPrototypeOf(me, ft.prototype) : me;
              }
              s.attachDebugPrototypeIfDebug = Ie;
            })(w = e.Debug || (e.Debug = {}));
          })(N || (N = {}));
          var N;
          (function(e) {
            e.tryGetNativePerformanceHooks = () => {
            }, e.timestamp = Date.now;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(w) {
              var s, q;
              function F(te, Je, qe, ge) {
                return te ? fe(Je, qe, ge) : w.nullTimer;
              }
              w.createTimerIf = F;
              function fe(te, Je, qe) {
                var ge = 0;
                return { enter: ie, exit: H };
                function ie() {
                  ++ge === 1 && Q(Je);
                }
                function H() {
                  --ge === 0 ? (Q(qe), Be(te, Je, qe)) : ge < 0 && e.Debug.fail("enter/exit count does not match.");
                }
              }
              w.createTimer = fe, w.nullTimer = { enter: e.noop, exit: e.noop };
              var Ee = false, Se = e.timestamp(), J = new e.Map(), se = new e.Map(), Me = new e.Map();
              function Q(te) {
                var Je;
                if (Ee) {
                  var qe = (Je = se.get(te)) !== null && Je !== void 0 ? Je : 0;
                  se.set(te, qe + 1), J.set(te, e.timestamp()), q == null || q.mark(te);
                }
              }
              w.mark = Q;
              function Be(te, Je, qe) {
                var ge, ie;
                if (Ee) {
                  var H = (ge = qe !== void 0 ? J.get(qe) : void 0) !== null && ge !== void 0 ? ge : e.timestamp(), pe = (ie = Je !== void 0 ? J.get(Je) : void 0) !== null && ie !== void 0 ? ie : Se, j = Me.get(te) || 0;
                  Me.set(te, j + (H - pe)), q == null || q.measure(te, Je, qe);
                }
              }
              w.measure = Be;
              function je(te) {
                return se.get(te) || 0;
              }
              w.getCount = je;
              function V(te) {
                return Me.get(te) || 0;
              }
              w.getDuration = V;
              function B(te) {
                Me.forEach(function(Je, qe) {
                  return te(qe, Je);
                });
              }
              w.forEachMeasure = B;
              function U(te) {
                J.forEach(function(Je, qe) {
                  return te(qe);
                });
              }
              w.forEachMark = U;
              function m(te) {
                te !== void 0 ? Me.delete(te) : Me.clear(), q == null || q.clearMeasures(te);
              }
              w.clearMeasures = m;
              function v(te) {
                te !== void 0 ? (se.delete(te), J.delete(te)) : (se.clear(), J.clear()), q == null || q.clearMarks(te);
              }
              w.clearMarks = v;
              function g() {
                return Ee;
              }
              w.isEnabled = g;
              function O(te) {
                var Je;
                return te === void 0 && (te = e.sys), Ee || (Ee = true, s || (s = e.tryGetNativePerformanceHooks()), s && (Se = s.performance.timeOrigin, (s.shouldWriteNativeEvents || !((Je = te == null ? void 0 : te.cpuProfilingEnabled) === null || Je === void 0) && Je.call(te) || te != null && te.debugMode) && (q = s.performance))), true;
              }
              w.enable = O;
              function S() {
                Ee && (J.clear(), se.clear(), Me.clear(), q = void 0, Ee = false);
              }
              w.disable = S;
            })(t3 = e.performance || (e.performance = {}));
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3, w = { logEvent: e.noop, logErrEvent: e.noop, logPerfEvent: e.noop, logInfoEvent: e.noop, logStartCommand: e.noop, logStopCommand: e.noop, logStartUpdateProgram: e.noop, logStopUpdateProgram: e.noop, logStartUpdateGraph: e.noop, logStopUpdateGraph: e.noop, logStartResolveModule: e.noop, logStopResolveModule: e.noop, logStartParseSourceFile: e.noop, logStopParseSourceFile: e.noop, logStartReadFile: e.noop, logStopReadFile: e.noop, logStartBindFile: e.noop, logStopBindFile: e.noop, logStartScheduledOperation: e.noop, logStopScheduledOperation: e.noop }, s;
            try {
              var q = (t3 = ba.env.TS_ETW_MODULE_PATH) !== null && t3 !== void 0 ? t3 : "./node_modules/@microsoft/typescript-etw";
              s = void 0;
            } catch {
              s = void 0;
            }
            e.perfLogger = s && s.logEvent ? s : w;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(r) {
              r[r.Unknown = 0] = "Unknown", r[r.EndOfFileToken = 1] = "EndOfFileToken", r[r.SingleLineCommentTrivia = 2] = "SingleLineCommentTrivia", r[r.MultiLineCommentTrivia = 3] = "MultiLineCommentTrivia", r[r.NewLineTrivia = 4] = "NewLineTrivia", r[r.WhitespaceTrivia = 5] = "WhitespaceTrivia", r[r.ShebangTrivia = 6] = "ShebangTrivia", r[r.ConflictMarkerTrivia = 7] = "ConflictMarkerTrivia", r[r.NumericLiteral = 8] = "NumericLiteral", r[r.BigIntLiteral = 9] = "BigIntLiteral", r[r.StringLiteral = 10] = "StringLiteral", r[r.JsxText = 11] = "JsxText", r[r.JsxTextAllWhiteSpaces = 12] = "JsxTextAllWhiteSpaces", r[r.RegularExpressionLiteral = 13] = "RegularExpressionLiteral", r[r.NoSubstitutionTemplateLiteral = 14] = "NoSubstitutionTemplateLiteral", r[r.TemplateHead = 15] = "TemplateHead", r[r.TemplateMiddle = 16] = "TemplateMiddle", r[r.TemplateTail = 17] = "TemplateTail", r[r.OpenBraceToken = 18] = "OpenBraceToken", r[r.CloseBraceToken = 19] = "CloseBraceToken", r[r.OpenParenToken = 20] = "OpenParenToken", r[r.CloseParenToken = 21] = "CloseParenToken", r[r.OpenBracketToken = 22] = "OpenBracketToken", r[r.CloseBracketToken = 23] = "CloseBracketToken", r[r.DotToken = 24] = "DotToken", r[r.DotDotDotToken = 25] = "DotDotDotToken", r[r.SemicolonToken = 26] = "SemicolonToken", r[r.CommaToken = 27] = "CommaToken", r[r.QuestionDotToken = 28] = "QuestionDotToken", r[r.LessThanToken = 29] = "LessThanToken", r[r.LessThanSlashToken = 30] = "LessThanSlashToken", r[r.GreaterThanToken = 31] = "GreaterThanToken", r[r.LessThanEqualsToken = 32] = "LessThanEqualsToken", r[r.GreaterThanEqualsToken = 33] = "GreaterThanEqualsToken", r[r.EqualsEqualsToken = 34] = "EqualsEqualsToken", r[r.ExclamationEqualsToken = 35] = "ExclamationEqualsToken", r[r.EqualsEqualsEqualsToken = 36] = "EqualsEqualsEqualsToken", r[r.ExclamationEqualsEqualsToken = 37] = "ExclamationEqualsEqualsToken", r[r.EqualsGreaterThanToken = 38] = "EqualsGreaterThanToken", r[r.PlusToken = 39] = "PlusToken", r[r.MinusToken = 40] = "MinusToken", r[r.AsteriskToken = 41] = "AsteriskToken", r[r.AsteriskAsteriskToken = 42] = "AsteriskAsteriskToken", r[r.SlashToken = 43] = "SlashToken", r[r.PercentToken = 44] = "PercentToken", r[r.PlusPlusToken = 45] = "PlusPlusToken", r[r.MinusMinusToken = 46] = "MinusMinusToken", r[r.LessThanLessThanToken = 47] = "LessThanLessThanToken", r[r.GreaterThanGreaterThanToken = 48] = "GreaterThanGreaterThanToken", r[r.GreaterThanGreaterThanGreaterThanToken = 49] = "GreaterThanGreaterThanGreaterThanToken", r[r.AmpersandToken = 50] = "AmpersandToken", r[r.BarToken = 51] = "BarToken", r[r.CaretToken = 52] = "CaretToken", r[r.ExclamationToken = 53] = "ExclamationToken", r[r.TildeToken = 54] = "TildeToken", r[r.AmpersandAmpersandToken = 55] = "AmpersandAmpersandToken", r[r.BarBarToken = 56] = "BarBarToken", r[r.QuestionToken = 57] = "QuestionToken", r[r.ColonToken = 58] = "ColonToken", r[r.AtToken = 59] = "AtToken", r[r.QuestionQuestionToken = 60] = "QuestionQuestionToken", r[r.BacktickToken = 61] = "BacktickToken", r[r.HashToken = 62] = "HashToken", r[r.EqualsToken = 63] = "EqualsToken", r[r.PlusEqualsToken = 64] = "PlusEqualsToken", r[r.MinusEqualsToken = 65] = "MinusEqualsToken", r[r.AsteriskEqualsToken = 66] = "AsteriskEqualsToken", r[r.AsteriskAsteriskEqualsToken = 67] = "AsteriskAsteriskEqualsToken", r[r.SlashEqualsToken = 68] = "SlashEqualsToken", r[r.PercentEqualsToken = 69] = "PercentEqualsToken", r[r.LessThanLessThanEqualsToken = 70] = "LessThanLessThanEqualsToken", r[r.GreaterThanGreaterThanEqualsToken = 71] = "GreaterThanGreaterThanEqualsToken", r[r.GreaterThanGreaterThanGreaterThanEqualsToken = 72] = "GreaterThanGreaterThanGreaterThanEqualsToken", r[r.AmpersandEqualsToken = 73] = "AmpersandEqualsToken", r[r.BarEqualsToken = 74] = "BarEqualsToken", r[r.BarBarEqualsToken = 75] = "BarBarEqualsToken", r[r.AmpersandAmpersandEqualsToken = 76] = "AmpersandAmpersandEqualsToken", r[r.QuestionQuestionEqualsToken = 77] = "QuestionQuestionEqualsToken", r[r.CaretEqualsToken = 78] = "CaretEqualsToken", r[r.Identifier = 79] = "Identifier", r[r.PrivateIdentifier = 80] = "PrivateIdentifier", r[r.BreakKeyword = 81] = "BreakKeyword", r[r.CaseKeyword = 82] = "CaseKeyword", r[r.CatchKeyword = 83] = "CatchKeyword", r[r.ClassKeyword = 84] = "ClassKeyword", r[r.ConstKeyword = 85] = "ConstKeyword", r[r.ContinueKeyword = 86] = "ContinueKeyword", r[r.DebuggerKeyword = 87] = "DebuggerKeyword", r[r.DefaultKeyword = 88] = "DefaultKeyword", r[r.DeleteKeyword = 89] = "DeleteKeyword", r[r.DoKeyword = 90] = "DoKeyword", r[r.ElseKeyword = 91] = "ElseKeyword", r[r.EnumKeyword = 92] = "EnumKeyword", r[r.ExportKeyword = 93] = "ExportKeyword", r[r.ExtendsKeyword = 94] = "ExtendsKeyword", r[r.FalseKeyword = 95] = "FalseKeyword", r[r.FinallyKeyword = 96] = "FinallyKeyword", r[r.ForKeyword = 97] = "ForKeyword", r[r.FunctionKeyword = 98] = "FunctionKeyword", r[r.IfKeyword = 99] = "IfKeyword", r[r.ImportKeyword = 100] = "ImportKeyword", r[r.InKeyword = 101] = "InKeyword", r[r.InstanceOfKeyword = 102] = "InstanceOfKeyword", r[r.NewKeyword = 103] = "NewKeyword", r[r.NullKeyword = 104] = "NullKeyword", r[r.ReturnKeyword = 105] = "ReturnKeyword", r[r.SuperKeyword = 106] = "SuperKeyword", r[r.SwitchKeyword = 107] = "SwitchKeyword", r[r.ThisKeyword = 108] = "ThisKeyword", r[r.ThrowKeyword = 109] = "ThrowKeyword", r[r.TrueKeyword = 110] = "TrueKeyword", r[r.TryKeyword = 111] = "TryKeyword", r[r.TypeOfKeyword = 112] = "TypeOfKeyword", r[r.VarKeyword = 113] = "VarKeyword", r[r.VoidKeyword = 114] = "VoidKeyword", r[r.WhileKeyword = 115] = "WhileKeyword", r[r.WithKeyword = 116] = "WithKeyword", r[r.ImplementsKeyword = 117] = "ImplementsKeyword", r[r.InterfaceKeyword = 118] = "InterfaceKeyword", r[r.LetKeyword = 119] = "LetKeyword", r[r.PackageKeyword = 120] = "PackageKeyword", r[r.PrivateKeyword = 121] = "PrivateKeyword", r[r.ProtectedKeyword = 122] = "ProtectedKeyword", r[r.PublicKeyword = 123] = "PublicKeyword", r[r.StaticKeyword = 124] = "StaticKeyword", r[r.YieldKeyword = 125] = "YieldKeyword", r[r.AbstractKeyword = 126] = "AbstractKeyword", r[r.AccessorKeyword = 127] = "AccessorKeyword", r[r.AsKeyword = 128] = "AsKeyword", r[r.AssertsKeyword = 129] = "AssertsKeyword", r[r.AssertKeyword = 130] = "AssertKeyword", r[r.AnyKeyword = 131] = "AnyKeyword", r[r.AsyncKeyword = 132] = "AsyncKeyword", r[r.AwaitKeyword = 133] = "AwaitKeyword", r[r.BooleanKeyword = 134] = "BooleanKeyword", r[r.ConstructorKeyword = 135] = "ConstructorKeyword", r[r.DeclareKeyword = 136] = "DeclareKeyword", r[r.GetKeyword = 137] = "GetKeyword", r[r.InferKeyword = 138] = "InferKeyword", r[r.IntrinsicKeyword = 139] = "IntrinsicKeyword", r[r.IsKeyword = 140] = "IsKeyword", r[r.KeyOfKeyword = 141] = "KeyOfKeyword", r[r.ModuleKeyword = 142] = "ModuleKeyword", r[r.NamespaceKeyword = 143] = "NamespaceKeyword", r[r.NeverKeyword = 144] = "NeverKeyword", r[r.OutKeyword = 145] = "OutKeyword", r[r.ReadonlyKeyword = 146] = "ReadonlyKeyword", r[r.RequireKeyword = 147] = "RequireKeyword", r[r.NumberKeyword = 148] = "NumberKeyword", r[r.ObjectKeyword = 149] = "ObjectKeyword", r[r.SatisfiesKeyword = 150] = "SatisfiesKeyword", r[r.SetKeyword = 151] = "SetKeyword", r[r.StringKeyword = 152] = "StringKeyword", r[r.SymbolKeyword = 153] = "SymbolKeyword", r[r.TypeKeyword = 154] = "TypeKeyword", r[r.UndefinedKeyword = 155] = "UndefinedKeyword", r[r.UniqueKeyword = 156] = "UniqueKeyword", r[r.UnknownKeyword = 157] = "UnknownKeyword", r[r.FromKeyword = 158] = "FromKeyword", r[r.GlobalKeyword = 159] = "GlobalKeyword", r[r.BigIntKeyword = 160] = "BigIntKeyword", r[r.OverrideKeyword = 161] = "OverrideKeyword", r[r.OfKeyword = 162] = "OfKeyword", r[r.QualifiedName = 163] = "QualifiedName", r[r.ComputedPropertyName = 164] = "ComputedPropertyName", r[r.TypeParameter = 165] = "TypeParameter", r[r.Parameter = 166] = "Parameter", r[r.Decorator = 167] = "Decorator", r[r.PropertySignature = 168] = "PropertySignature", r[r.PropertyDeclaration = 169] = "PropertyDeclaration", r[r.MethodSignature = 170] = "MethodSignature", r[r.MethodDeclaration = 171] = "MethodDeclaration", r[r.ClassStaticBlockDeclaration = 172] = "ClassStaticBlockDeclaration", r[r.Constructor = 173] = "Constructor", r[r.GetAccessor = 174] = "GetAccessor", r[r.SetAccessor = 175] = "SetAccessor", r[r.CallSignature = 176] = "CallSignature", r[r.ConstructSignature = 177] = "ConstructSignature", r[r.IndexSignature = 178] = "IndexSignature", r[r.TypePredicate = 179] = "TypePredicate", r[r.TypeReference = 180] = "TypeReference", r[r.FunctionType = 181] = "FunctionType", r[r.ConstructorType = 182] = "ConstructorType", r[r.TypeQuery = 183] = "TypeQuery", r[r.TypeLiteral = 184] = "TypeLiteral", r[r.ArrayType = 185] = "ArrayType", r[r.TupleType = 186] = "TupleType", r[r.OptionalType = 187] = "OptionalType", r[r.RestType = 188] = "RestType", r[r.UnionType = 189] = "UnionType", r[r.IntersectionType = 190] = "IntersectionType", r[r.ConditionalType = 191] = "ConditionalType", r[r.InferType = 192] = "InferType", r[r.ParenthesizedType = 193] = "ParenthesizedType", r[r.ThisType = 194] = "ThisType", r[r.TypeOperator = 195] = "TypeOperator", r[r.IndexedAccessType = 196] = "IndexedAccessType", r[r.MappedType = 197] = "MappedType", r[r.LiteralType = 198] = "LiteralType", r[r.NamedTupleMember = 199] = "NamedTupleMember", r[r.TemplateLiteralType = 200] = "TemplateLiteralType", r[r.TemplateLiteralTypeSpan = 201] = "TemplateLiteralTypeSpan", r[r.ImportType = 202] = "ImportType", r[r.ObjectBindingPattern = 203] = "ObjectBindingPattern", r[r.ArrayBindingPattern = 204] = "ArrayBindingPattern", r[r.BindingElement = 205] = "BindingElement", r[r.ArrayLiteralExpression = 206] = "ArrayLiteralExpression", r[r.ObjectLiteralExpression = 207] = "ObjectLiteralExpression", r[r.PropertyAccessExpression = 208] = "PropertyAccessExpression", r[r.ElementAccessExpression = 209] = "ElementAccessExpression", r[r.CallExpression = 210] = "CallExpression", r[r.NewExpression = 211] = "NewExpression", r[r.TaggedTemplateExpression = 212] = "TaggedTemplateExpression", r[r.TypeAssertionExpression = 213] = "TypeAssertionExpression", r[r.ParenthesizedExpression = 214] = "ParenthesizedExpression", r[r.FunctionExpression = 215] = "FunctionExpression", r[r.ArrowFunction = 216] = "ArrowFunction", r[r.DeleteExpression = 217] = "DeleteExpression", r[r.TypeOfExpression = 218] = "TypeOfExpression", r[r.VoidExpression = 219] = "VoidExpression", r[r.AwaitExpression = 220] = "AwaitExpression", r[r.PrefixUnaryExpression = 221] = "PrefixUnaryExpression", r[r.PostfixUnaryExpression = 222] = "PostfixUnaryExpression", r[r.BinaryExpression = 223] = "BinaryExpression", r[r.ConditionalExpression = 224] = "ConditionalExpression", r[r.TemplateExpression = 225] = "TemplateExpression", r[r.YieldExpression = 226] = "YieldExpression", r[r.SpreadElement = 227] = "SpreadElement", r[r.ClassExpression = 228] = "ClassExpression", r[r.OmittedExpression = 229] = "OmittedExpression", r[r.ExpressionWithTypeArguments = 230] = "ExpressionWithTypeArguments", r[r.AsExpression = 231] = "AsExpression", r[r.NonNullExpression = 232] = "NonNullExpression", r[r.MetaProperty = 233] = "MetaProperty", r[r.SyntheticExpression = 234] = "SyntheticExpression", r[r.SatisfiesExpression = 235] = "SatisfiesExpression", r[r.TemplateSpan = 236] = "TemplateSpan", r[r.SemicolonClassElement = 237] = "SemicolonClassElement", r[r.Block = 238] = "Block", r[r.EmptyStatement = 239] = "EmptyStatement", r[r.VariableStatement = 240] = "VariableStatement", r[r.ExpressionStatement = 241] = "ExpressionStatement", r[r.IfStatement = 242] = "IfStatement", r[r.DoStatement = 243] = "DoStatement", r[r.WhileStatement = 244] = "WhileStatement", r[r.ForStatement = 245] = "ForStatement", r[r.ForInStatement = 246] = "ForInStatement", r[r.ForOfStatement = 247] = "ForOfStatement", r[r.ContinueStatement = 248] = "ContinueStatement", r[r.BreakStatement = 249] = "BreakStatement", r[r.ReturnStatement = 250] = "ReturnStatement", r[r.WithStatement = 251] = "WithStatement", r[r.SwitchStatement = 252] = "SwitchStatement", r[r.LabeledStatement = 253] = "LabeledStatement", r[r.ThrowStatement = 254] = "ThrowStatement", r[r.TryStatement = 255] = "TryStatement", r[r.DebuggerStatement = 256] = "DebuggerStatement", r[r.VariableDeclaration = 257] = "VariableDeclaration", r[r.VariableDeclarationList = 258] = "VariableDeclarationList", r[r.FunctionDeclaration = 259] = "FunctionDeclaration", r[r.ClassDeclaration = 260] = "ClassDeclaration", r[r.InterfaceDeclaration = 261] = "InterfaceDeclaration", r[r.TypeAliasDeclaration = 262] = "TypeAliasDeclaration", r[r.EnumDeclaration = 263] = "EnumDeclaration", r[r.ModuleDeclaration = 264] = "ModuleDeclaration", r[r.ModuleBlock = 265] = "ModuleBlock", r[r.CaseBlock = 266] = "CaseBlock", r[r.NamespaceExportDeclaration = 267] = "NamespaceExportDeclaration", r[r.ImportEqualsDeclaration = 268] = "ImportEqualsDeclaration", r[r.ImportDeclaration = 269] = "ImportDeclaration", r[r.ImportClause = 270] = "ImportClause", r[r.NamespaceImport = 271] = "NamespaceImport", r[r.NamedImports = 272] = "NamedImports", r[r.ImportSpecifier = 273] = "ImportSpecifier", r[r.ExportAssignment = 274] = "ExportAssignment", r[r.ExportDeclaration = 275] = "ExportDeclaration", r[r.NamedExports = 276] = "NamedExports", r[r.NamespaceExport = 277] = "NamespaceExport", r[r.ExportSpecifier = 278] = "ExportSpecifier", r[r.MissingDeclaration = 279] = "MissingDeclaration", r[r.ExternalModuleReference = 280] = "ExternalModuleReference", r[r.JsxElement = 281] = "JsxElement", r[r.JsxSelfClosingElement = 282] = "JsxSelfClosingElement", r[r.JsxOpeningElement = 283] = "JsxOpeningElement", r[r.JsxClosingElement = 284] = "JsxClosingElement", r[r.JsxFragment = 285] = "JsxFragment", r[r.JsxOpeningFragment = 286] = "JsxOpeningFragment", r[r.JsxClosingFragment = 287] = "JsxClosingFragment", r[r.JsxAttribute = 288] = "JsxAttribute", r[r.JsxAttributes = 289] = "JsxAttributes", r[r.JsxSpreadAttribute = 290] = "JsxSpreadAttribute", r[r.JsxExpression = 291] = "JsxExpression", r[r.CaseClause = 292] = "CaseClause", r[r.DefaultClause = 293] = "DefaultClause", r[r.HeritageClause = 294] = "HeritageClause", r[r.CatchClause = 295] = "CatchClause", r[r.AssertClause = 296] = "AssertClause", r[r.AssertEntry = 297] = "AssertEntry", r[r.ImportTypeAssertionContainer = 298] = "ImportTypeAssertionContainer", r[r.PropertyAssignment = 299] = "PropertyAssignment", r[r.ShorthandPropertyAssignment = 300] = "ShorthandPropertyAssignment", r[r.SpreadAssignment = 301] = "SpreadAssignment", r[r.EnumMember = 302] = "EnumMember", r[r.UnparsedPrologue = 303] = "UnparsedPrologue", r[r.UnparsedPrepend = 304] = "UnparsedPrepend", r[r.UnparsedText = 305] = "UnparsedText", r[r.UnparsedInternalText = 306] = "UnparsedInternalText", r[r.UnparsedSyntheticReference = 307] = "UnparsedSyntheticReference", r[r.SourceFile = 308] = "SourceFile", r[r.Bundle = 309] = "Bundle", r[r.UnparsedSource = 310] = "UnparsedSource", r[r.InputFiles = 311] = "InputFiles", r[r.JSDocTypeExpression = 312] = "JSDocTypeExpression", r[r.JSDocNameReference = 313] = "JSDocNameReference", r[r.JSDocMemberName = 314] = "JSDocMemberName", r[r.JSDocAllType = 315] = "JSDocAllType", r[r.JSDocUnknownType = 316] = "JSDocUnknownType", r[r.JSDocNullableType = 317] = "JSDocNullableType", r[r.JSDocNonNullableType = 318] = "JSDocNonNullableType", r[r.JSDocOptionalType = 319] = "JSDocOptionalType", r[r.JSDocFunctionType = 320] = "JSDocFunctionType", r[r.JSDocVariadicType = 321] = "JSDocVariadicType", r[r.JSDocNamepathType = 322] = "JSDocNamepathType", r[r.JSDoc = 323] = "JSDoc", r[r.JSDocComment = 323] = "JSDocComment", r[r.JSDocText = 324] = "JSDocText", r[r.JSDocTypeLiteral = 325] = "JSDocTypeLiteral", r[r.JSDocSignature = 326] = "JSDocSignature", r[r.JSDocLink = 327] = "JSDocLink", r[r.JSDocLinkCode = 328] = "JSDocLinkCode", r[r.JSDocLinkPlain = 329] = "JSDocLinkPlain", r[r.JSDocTag = 330] = "JSDocTag", r[r.JSDocAugmentsTag = 331] = "JSDocAugmentsTag", r[r.JSDocImplementsTag = 332] = "JSDocImplementsTag", r[r.JSDocAuthorTag = 333] = "JSDocAuthorTag", r[r.JSDocDeprecatedTag = 334] = "JSDocDeprecatedTag", r[r.JSDocClassTag = 335] = "JSDocClassTag", r[r.JSDocPublicTag = 336] = "JSDocPublicTag", r[r.JSDocPrivateTag = 337] = "JSDocPrivateTag", r[r.JSDocProtectedTag = 338] = "JSDocProtectedTag", r[r.JSDocReadonlyTag = 339] = "JSDocReadonlyTag", r[r.JSDocOverrideTag = 340] = "JSDocOverrideTag", r[r.JSDocCallbackTag = 341] = "JSDocCallbackTag", r[r.JSDocEnumTag = 342] = "JSDocEnumTag", r[r.JSDocParameterTag = 343] = "JSDocParameterTag", r[r.JSDocReturnTag = 344] = "JSDocReturnTag", r[r.JSDocThisTag = 345] = "JSDocThisTag", r[r.JSDocTypeTag = 346] = "JSDocTypeTag", r[r.JSDocTemplateTag = 347] = "JSDocTemplateTag", r[r.JSDocTypedefTag = 348] = "JSDocTypedefTag", r[r.JSDocSeeTag = 349] = "JSDocSeeTag", r[r.JSDocPropertyTag = 350] = "JSDocPropertyTag", r[r.SyntaxList = 351] = "SyntaxList", r[r.NotEmittedStatement = 352] = "NotEmittedStatement", r[r.PartiallyEmittedExpression = 353] = "PartiallyEmittedExpression", r[r.CommaListExpression = 354] = "CommaListExpression", r[r.MergeDeclarationMarker = 355] = "MergeDeclarationMarker", r[r.EndOfDeclarationMarker = 356] = "EndOfDeclarationMarker", r[r.SyntheticReferenceExpression = 357] = "SyntheticReferenceExpression", r[r.Count = 358] = "Count", r[r.FirstAssignment = 63] = "FirstAssignment", r[r.LastAssignment = 78] = "LastAssignment", r[r.FirstCompoundAssignment = 64] = "FirstCompoundAssignment", r[r.LastCompoundAssignment = 78] = "LastCompoundAssignment", r[r.FirstReservedWord = 81] = "FirstReservedWord", r[r.LastReservedWord = 116] = "LastReservedWord", r[r.FirstKeyword = 81] = "FirstKeyword", r[r.LastKeyword = 162] = "LastKeyword", r[r.FirstFutureReservedWord = 117] = "FirstFutureReservedWord", r[r.LastFutureReservedWord = 125] = "LastFutureReservedWord", r[r.FirstTypeNode = 179] = "FirstTypeNode", r[r.LastTypeNode = 202] = "LastTypeNode", r[r.FirstPunctuation = 18] = "FirstPunctuation", r[r.LastPunctuation = 78] = "LastPunctuation", r[r.FirstToken = 0] = "FirstToken", r[r.LastToken = 162] = "LastToken", r[r.FirstTriviaToken = 2] = "FirstTriviaToken", r[r.LastTriviaToken = 7] = "LastTriviaToken", r[r.FirstLiteralToken = 8] = "FirstLiteralToken", r[r.LastLiteralToken = 14] = "LastLiteralToken", r[r.FirstTemplateToken = 14] = "FirstTemplateToken", r[r.LastTemplateToken = 17] = "LastTemplateToken", r[r.FirstBinaryOperator = 29] = "FirstBinaryOperator", r[r.LastBinaryOperator = 78] = "LastBinaryOperator", r[r.FirstStatement = 240] = "FirstStatement", r[r.LastStatement = 256] = "LastStatement", r[r.FirstNode = 163] = "FirstNode", r[r.FirstJSDocNode = 312] = "FirstJSDocNode", r[r.LastJSDocNode = 350] = "LastJSDocNode", r[r.FirstJSDocTagNode = 330] = "FirstJSDocTagNode", r[r.LastJSDocTagNode = 350] = "LastJSDocTagNode", r[r.FirstContextualKeyword = 126] = "FirstContextualKeyword", r[r.LastContextualKeyword = 162] = "LastContextualKeyword";
            })(t3 = e.SyntaxKind || (e.SyntaxKind = {}));
            var w;
            (function(r) {
              r[r.None = 0] = "None", r[r.Let = 1] = "Let", r[r.Const = 2] = "Const", r[r.NestedNamespace = 4] = "NestedNamespace", r[r.Synthesized = 8] = "Synthesized", r[r.Namespace = 16] = "Namespace", r[r.OptionalChain = 32] = "OptionalChain", r[r.ExportContext = 64] = "ExportContext", r[r.ContainsThis = 128] = "ContainsThis", r[r.HasImplicitReturn = 256] = "HasImplicitReturn", r[r.HasExplicitReturn = 512] = "HasExplicitReturn", r[r.GlobalAugmentation = 1024] = "GlobalAugmentation", r[r.HasAsyncFunctions = 2048] = "HasAsyncFunctions", r[r.DisallowInContext = 4096] = "DisallowInContext", r[r.YieldContext = 8192] = "YieldContext", r[r.DecoratorContext = 16384] = "DecoratorContext", r[r.AwaitContext = 32768] = "AwaitContext", r[r.DisallowConditionalTypesContext = 65536] = "DisallowConditionalTypesContext", r[r.ThisNodeHasError = 131072] = "ThisNodeHasError", r[r.JavaScriptFile = 262144] = "JavaScriptFile", r[r.ThisNodeOrAnySubNodesHasError = 524288] = "ThisNodeOrAnySubNodesHasError", r[r.HasAggregatedChildData = 1048576] = "HasAggregatedChildData", r[r.PossiblyContainsDynamicImport = 2097152] = "PossiblyContainsDynamicImport", r[r.PossiblyContainsImportMeta = 4194304] = "PossiblyContainsImportMeta", r[r.JSDoc = 8388608] = "JSDoc", r[r.Ambient = 16777216] = "Ambient", r[r.InWithStatement = 33554432] = "InWithStatement", r[r.JsonFile = 67108864] = "JsonFile", r[r.TypeCached = 134217728] = "TypeCached", r[r.Deprecated = 268435456] = "Deprecated", r[r.BlockScoped = 3] = "BlockScoped", r[r.ReachabilityCheckFlags = 768] = "ReachabilityCheckFlags", r[r.ReachabilityAndEmitFlags = 2816] = "ReachabilityAndEmitFlags", r[r.ContextFlags = 50720768] = "ContextFlags", r[r.TypeExcludesFlags = 40960] = "TypeExcludesFlags", r[r.PermanentlySetIncrementalFlags = 6291456] = "PermanentlySetIncrementalFlags";
            })(w = e.NodeFlags || (e.NodeFlags = {}));
            var s;
            (function(r) {
              r[r.None = 0] = "None", r[r.Export = 1] = "Export", r[r.Ambient = 2] = "Ambient", r[r.Public = 4] = "Public", r[r.Private = 8] = "Private", r[r.Protected = 16] = "Protected", r[r.Static = 32] = "Static", r[r.Readonly = 64] = "Readonly", r[r.Accessor = 128] = "Accessor", r[r.Abstract = 256] = "Abstract", r[r.Async = 512] = "Async", r[r.Default = 1024] = "Default", r[r.Const = 2048] = "Const", r[r.HasComputedJSDocModifiers = 4096] = "HasComputedJSDocModifiers", r[r.Deprecated = 8192] = "Deprecated", r[r.Override = 16384] = "Override", r[r.In = 32768] = "In", r[r.Out = 65536] = "Out", r[r.Decorator = 131072] = "Decorator", r[r.HasComputedFlags = 536870912] = "HasComputedFlags", r[r.AccessibilityModifier = 28] = "AccessibilityModifier", r[r.ParameterPropertyModifier = 16476] = "ParameterPropertyModifier", r[r.NonPublicAccessibilityModifier = 24] = "NonPublicAccessibilityModifier", r[r.TypeScriptModifier = 117086] = "TypeScriptModifier", r[r.ExportDefault = 1025] = "ExportDefault", r[r.All = 258047] = "All", r[r.Modifier = 126975] = "Modifier";
            })(s = e.ModifierFlags || (e.ModifierFlags = {}));
            var q;
            (function(r) {
              r[r.None = 0] = "None", r[r.IntrinsicNamedElement = 1] = "IntrinsicNamedElement", r[r.IntrinsicIndexedElement = 2] = "IntrinsicIndexedElement", r[r.IntrinsicElement = 3] = "IntrinsicElement";
            })(q = e.JsxFlags || (e.JsxFlags = {}));
            var F;
            (function(r) {
              r[r.Succeeded = 1] = "Succeeded", r[r.Failed = 2] = "Failed", r[r.Reported = 4] = "Reported", r[r.ReportsUnmeasurable = 8] = "ReportsUnmeasurable", r[r.ReportsUnreliable = 16] = "ReportsUnreliable", r[r.ReportsMask = 24] = "ReportsMask";
            })(F = e.RelationComparisonResult || (e.RelationComparisonResult = {}));
            var fe;
            (function(r) {
              r[r.None = 0] = "None", r[r.Auto = 1] = "Auto", r[r.Loop = 2] = "Loop", r[r.Unique = 3] = "Unique", r[r.Node = 4] = "Node", r[r.KindMask = 7] = "KindMask", r[r.ReservedInNestedScopes = 8] = "ReservedInNestedScopes", r[r.Optimistic = 16] = "Optimistic", r[r.FileLevel = 32] = "FileLevel", r[r.AllowNameSubstitution = 64] = "AllowNameSubstitution";
            })(fe = e.GeneratedIdentifierFlags || (e.GeneratedIdentifierFlags = {}));
            var Ee;
            (function(r) {
              r[r.None = 0] = "None", r[r.PrecedingLineBreak = 1] = "PrecedingLineBreak", r[r.PrecedingJSDocComment = 2] = "PrecedingJSDocComment", r[r.Unterminated = 4] = "Unterminated", r[r.ExtendedUnicodeEscape = 8] = "ExtendedUnicodeEscape", r[r.Scientific = 16] = "Scientific", r[r.Octal = 32] = "Octal", r[r.HexSpecifier = 64] = "HexSpecifier", r[r.BinarySpecifier = 128] = "BinarySpecifier", r[r.OctalSpecifier = 256] = "OctalSpecifier", r[r.ContainsSeparator = 512] = "ContainsSeparator", r[r.UnicodeEscape = 1024] = "UnicodeEscape", r[r.ContainsInvalidEscape = 2048] = "ContainsInvalidEscape", r[r.BinaryOrOctalSpecifier = 384] = "BinaryOrOctalSpecifier", r[r.NumericLiteralFlags = 1008] = "NumericLiteralFlags", r[r.TemplateLiteralLikeFlags = 2048] = "TemplateLiteralLikeFlags";
            })(Ee = e.TokenFlags || (e.TokenFlags = {}));
            var Se;
            (function(r) {
              r[r.Unreachable = 1] = "Unreachable", r[r.Start = 2] = "Start", r[r.BranchLabel = 4] = "BranchLabel", r[r.LoopLabel = 8] = "LoopLabel", r[r.Assignment = 16] = "Assignment", r[r.TrueCondition = 32] = "TrueCondition", r[r.FalseCondition = 64] = "FalseCondition", r[r.SwitchClause = 128] = "SwitchClause", r[r.ArrayMutation = 256] = "ArrayMutation", r[r.Call = 512] = "Call", r[r.ReduceLabel = 1024] = "ReduceLabel", r[r.Referenced = 2048] = "Referenced", r[r.Shared = 4096] = "Shared", r[r.Label = 12] = "Label", r[r.Condition = 96] = "Condition";
            })(Se = e.FlowFlags || (e.FlowFlags = {}));
            var J;
            (function(r) {
              r[r.ExpectError = 0] = "ExpectError", r[r.Ignore = 1] = "Ignore";
            })(J = e.CommentDirectiveType || (e.CommentDirectiveType = {}));
            var se = function() {
              function r() {
              }
              return r;
            }();
            e.OperationCanceledException = se;
            var Me;
            (function(r) {
              r[r.RootFile = 0] = "RootFile", r[r.SourceFromProjectReference = 1] = "SourceFromProjectReference", r[r.OutputFromProjectReference = 2] = "OutputFromProjectReference", r[r.Import = 3] = "Import", r[r.ReferenceFile = 4] = "ReferenceFile", r[r.TypeReferenceDirective = 5] = "TypeReferenceDirective", r[r.LibFile = 6] = "LibFile", r[r.LibReferenceDirective = 7] = "LibReferenceDirective", r[r.AutomaticTypeDirectiveFile = 8] = "AutomaticTypeDirectiveFile";
            })(Me = e.FileIncludeKind || (e.FileIncludeKind = {}));
            var Q;
            (function(r) {
              r[r.FilePreprocessingReferencedDiagnostic = 0] = "FilePreprocessingReferencedDiagnostic", r[r.FilePreprocessingFileExplainingDiagnostic = 1] = "FilePreprocessingFileExplainingDiagnostic";
            })(Q = e.FilePreprocessingDiagnosticsKind || (e.FilePreprocessingDiagnosticsKind = {}));
            var Be;
            (function(r) {
              r[r.Not = 0] = "Not", r[r.SafeModules = 1] = "SafeModules", r[r.Completely = 2] = "Completely";
            })(Be = e.StructureIsReused || (e.StructureIsReused = {}));
            var je;
            (function(r) {
              r[r.Success = 0] = "Success", r[r.DiagnosticsPresent_OutputsSkipped = 1] = "DiagnosticsPresent_OutputsSkipped", r[r.DiagnosticsPresent_OutputsGenerated = 2] = "DiagnosticsPresent_OutputsGenerated", r[r.InvalidProject_OutputsSkipped = 3] = "InvalidProject_OutputsSkipped", r[r.ProjectReferenceCycle_OutputsSkipped = 4] = "ProjectReferenceCycle_OutputsSkipped", r[r.ProjectReferenceCycle_OutputsSkupped = 4] = "ProjectReferenceCycle_OutputsSkupped";
            })(je = e.ExitStatus || (e.ExitStatus = {}));
            var V;
            (function(r) {
              r[r.Ok = 0] = "Ok", r[r.NeedsOverride = 1] = "NeedsOverride", r[r.HasInvalidOverride = 2] = "HasInvalidOverride";
            })(V = e.MemberOverrideStatus || (e.MemberOverrideStatus = {}));
            var B;
            (function(r) {
              r[r.None = 0] = "None", r[r.Literal = 1] = "Literal", r[r.Subtype = 2] = "Subtype";
            })(B = e.UnionReduction || (e.UnionReduction = {}));
            var U;
            (function(r) {
              r[r.None = 0] = "None", r[r.Signature = 1] = "Signature", r[r.NoConstraints = 2] = "NoConstraints", r[r.Completions = 4] = "Completions", r[r.SkipBindingPatterns = 8] = "SkipBindingPatterns";
            })(U = e.ContextFlags || (e.ContextFlags = {}));
            var m;
            (function(r) {
              r[r.None = 0] = "None", r[r.NoTruncation = 1] = "NoTruncation", r[r.WriteArrayAsGenericType = 2] = "WriteArrayAsGenericType", r[r.GenerateNamesForShadowedTypeParams = 4] = "GenerateNamesForShadowedTypeParams", r[r.UseStructuralFallback = 8] = "UseStructuralFallback", r[r.ForbidIndexedAccessSymbolReferences = 16] = "ForbidIndexedAccessSymbolReferences", r[r.WriteTypeArgumentsOfSignature = 32] = "WriteTypeArgumentsOfSignature", r[r.UseFullyQualifiedType = 64] = "UseFullyQualifiedType", r[r.UseOnlyExternalAliasing = 128] = "UseOnlyExternalAliasing", r[r.SuppressAnyReturnType = 256] = "SuppressAnyReturnType", r[r.WriteTypeParametersInQualifiedName = 512] = "WriteTypeParametersInQualifiedName", r[r.MultilineObjectLiterals = 1024] = "MultilineObjectLiterals", r[r.WriteClassExpressionAsTypeLiteral = 2048] = "WriteClassExpressionAsTypeLiteral", r[r.UseTypeOfFunction = 4096] = "UseTypeOfFunction", r[r.OmitParameterModifiers = 8192] = "OmitParameterModifiers", r[r.UseAliasDefinedOutsideCurrentScope = 16384] = "UseAliasDefinedOutsideCurrentScope", r[r.UseSingleQuotesForStringLiteralType = 268435456] = "UseSingleQuotesForStringLiteralType", r[r.NoTypeReduction = 536870912] = "NoTypeReduction", r[r.OmitThisParameter = 33554432] = "OmitThisParameter", r[r.AllowThisInObjectLiteral = 32768] = "AllowThisInObjectLiteral", r[r.AllowQualifiedNameInPlaceOfIdentifier = 65536] = "AllowQualifiedNameInPlaceOfIdentifier", r[r.AllowQualifedNameInPlaceOfIdentifier = 65536] = "AllowQualifedNameInPlaceOfIdentifier", r[r.AllowAnonymousIdentifier = 131072] = "AllowAnonymousIdentifier", r[r.AllowEmptyUnionOrIntersection = 262144] = "AllowEmptyUnionOrIntersection", r[r.AllowEmptyTuple = 524288] = "AllowEmptyTuple", r[r.AllowUniqueESSymbolType = 1048576] = "AllowUniqueESSymbolType", r[r.AllowEmptyIndexInfoType = 2097152] = "AllowEmptyIndexInfoType", r[r.WriteComputedProps = 1073741824] = "WriteComputedProps", r[r.AllowNodeModulesRelativePaths = 67108864] = "AllowNodeModulesRelativePaths", r[r.DoNotIncludeSymbolChain = 134217728] = "DoNotIncludeSymbolChain", r[r.IgnoreErrors = 70221824] = "IgnoreErrors", r[r.InObjectTypeLiteral = 4194304] = "InObjectTypeLiteral", r[r.InTypeAlias = 8388608] = "InTypeAlias", r[r.InInitialEntityName = 16777216] = "InInitialEntityName";
            })(m = e.NodeBuilderFlags || (e.NodeBuilderFlags = {}));
            var v;
            (function(r) {
              r[r.None = 0] = "None", r[r.NoTruncation = 1] = "NoTruncation", r[r.WriteArrayAsGenericType = 2] = "WriteArrayAsGenericType", r[r.UseStructuralFallback = 8] = "UseStructuralFallback", r[r.WriteTypeArgumentsOfSignature = 32] = "WriteTypeArgumentsOfSignature", r[r.UseFullyQualifiedType = 64] = "UseFullyQualifiedType", r[r.SuppressAnyReturnType = 256] = "SuppressAnyReturnType", r[r.MultilineObjectLiterals = 1024] = "MultilineObjectLiterals", r[r.WriteClassExpressionAsTypeLiteral = 2048] = "WriteClassExpressionAsTypeLiteral", r[r.UseTypeOfFunction = 4096] = "UseTypeOfFunction", r[r.OmitParameterModifiers = 8192] = "OmitParameterModifiers", r[r.UseAliasDefinedOutsideCurrentScope = 16384] = "UseAliasDefinedOutsideCurrentScope", r[r.UseSingleQuotesForStringLiteralType = 268435456] = "UseSingleQuotesForStringLiteralType", r[r.NoTypeReduction = 536870912] = "NoTypeReduction", r[r.OmitThisParameter = 33554432] = "OmitThisParameter", r[r.AllowUniqueESSymbolType = 1048576] = "AllowUniqueESSymbolType", r[r.AddUndefined = 131072] = "AddUndefined", r[r.WriteArrowStyleSignature = 262144] = "WriteArrowStyleSignature", r[r.InArrayType = 524288] = "InArrayType", r[r.InElementType = 2097152] = "InElementType", r[r.InFirstTypeArgument = 4194304] = "InFirstTypeArgument", r[r.InTypeAlias = 8388608] = "InTypeAlias", r[r.WriteOwnNameForAnyLike = 0] = "WriteOwnNameForAnyLike", r[r.NodeBuilderFlagsMask = 848330091] = "NodeBuilderFlagsMask";
            })(v = e.TypeFormatFlags || (e.TypeFormatFlags = {}));
            var g;
            (function(r) {
              r[r.None = 0] = "None", r[r.WriteTypeParametersOrArguments = 1] = "WriteTypeParametersOrArguments", r[r.UseOnlyExternalAliasing = 2] = "UseOnlyExternalAliasing", r[r.AllowAnyNodeKind = 4] = "AllowAnyNodeKind", r[r.UseAliasDefinedOutsideCurrentScope = 8] = "UseAliasDefinedOutsideCurrentScope", r[r.WriteComputedProps = 16] = "WriteComputedProps", r[r.DoNotIncludeSymbolChain = 32] = "DoNotIncludeSymbolChain";
            })(g = e.SymbolFormatFlags || (e.SymbolFormatFlags = {}));
            var O;
            (function(r) {
              r[r.Accessible = 0] = "Accessible", r[r.NotAccessible = 1] = "NotAccessible", r[r.CannotBeNamed = 2] = "CannotBeNamed";
            })(O = e.SymbolAccessibility || (e.SymbolAccessibility = {}));
            var S;
            (function(r) {
              r[r.UnionOrIntersection = 0] = "UnionOrIntersection", r[r.Spread = 1] = "Spread";
            })(S = e.SyntheticSymbolKind || (e.SyntheticSymbolKind = {}));
            var te;
            (function(r) {
              r[r.This = 0] = "This", r[r.Identifier = 1] = "Identifier", r[r.AssertsThis = 2] = "AssertsThis", r[r.AssertsIdentifier = 3] = "AssertsIdentifier";
            })(te = e.TypePredicateKind || (e.TypePredicateKind = {}));
            var Je;
            (function(r) {
              r[r.Unknown = 0] = "Unknown", r[r.TypeWithConstructSignatureAndValue = 1] = "TypeWithConstructSignatureAndValue", r[r.VoidNullableOrNeverType = 2] = "VoidNullableOrNeverType", r[r.NumberLikeType = 3] = "NumberLikeType", r[r.BigIntLikeType = 4] = "BigIntLikeType", r[r.StringLikeType = 5] = "StringLikeType", r[r.BooleanType = 6] = "BooleanType", r[r.ArrayLikeType = 7] = "ArrayLikeType", r[r.ESSymbolType = 8] = "ESSymbolType", r[r.Promise = 9] = "Promise", r[r.TypeWithCallSignature = 10] = "TypeWithCallSignature", r[r.ObjectType = 11] = "ObjectType";
            })(Je = e.TypeReferenceSerializationKind || (e.TypeReferenceSerializationKind = {}));
            var qe;
            (function(r) {
              r[r.None = 0] = "None", r[r.FunctionScopedVariable = 1] = "FunctionScopedVariable", r[r.BlockScopedVariable = 2] = "BlockScopedVariable", r[r.Property = 4] = "Property", r[r.EnumMember = 8] = "EnumMember", r[r.Function = 16] = "Function", r[r.Class = 32] = "Class", r[r.Interface = 64] = "Interface", r[r.ConstEnum = 128] = "ConstEnum", r[r.RegularEnum = 256] = "RegularEnum", r[r.ValueModule = 512] = "ValueModule", r[r.NamespaceModule = 1024] = "NamespaceModule", r[r.TypeLiteral = 2048] = "TypeLiteral", r[r.ObjectLiteral = 4096] = "ObjectLiteral", r[r.Method = 8192] = "Method", r[r.Constructor = 16384] = "Constructor", r[r.GetAccessor = 32768] = "GetAccessor", r[r.SetAccessor = 65536] = "SetAccessor", r[r.Signature = 131072] = "Signature", r[r.TypeParameter = 262144] = "TypeParameter", r[r.TypeAlias = 524288] = "TypeAlias", r[r.ExportValue = 1048576] = "ExportValue", r[r.Alias = 2097152] = "Alias", r[r.Prototype = 4194304] = "Prototype", r[r.ExportStar = 8388608] = "ExportStar", r[r.Optional = 16777216] = "Optional", r[r.Transient = 33554432] = "Transient", r[r.Assignment = 67108864] = "Assignment", r[r.ModuleExports = 134217728] = "ModuleExports", r[r.All = 67108863] = "All", r[r.Enum = 384] = "Enum", r[r.Variable = 3] = "Variable", r[r.Value = 111551] = "Value", r[r.Type = 788968] = "Type", r[r.Namespace = 1920] = "Namespace", r[r.Module = 1536] = "Module", r[r.Accessor = 98304] = "Accessor", r[r.FunctionScopedVariableExcludes = 111550] = "FunctionScopedVariableExcludes", r[r.BlockScopedVariableExcludes = 111551] = "BlockScopedVariableExcludes", r[r.ParameterExcludes = 111551] = "ParameterExcludes", r[r.PropertyExcludes = 0] = "PropertyExcludes", r[r.EnumMemberExcludes = 900095] = "EnumMemberExcludes", r[r.FunctionExcludes = 110991] = "FunctionExcludes", r[r.ClassExcludes = 899503] = "ClassExcludes", r[r.InterfaceExcludes = 788872] = "InterfaceExcludes", r[r.RegularEnumExcludes = 899327] = "RegularEnumExcludes", r[r.ConstEnumExcludes = 899967] = "ConstEnumExcludes", r[r.ValueModuleExcludes = 110735] = "ValueModuleExcludes", r[r.NamespaceModuleExcludes = 0] = "NamespaceModuleExcludes", r[r.MethodExcludes = 103359] = "MethodExcludes", r[r.GetAccessorExcludes = 46015] = "GetAccessorExcludes", r[r.SetAccessorExcludes = 78783] = "SetAccessorExcludes", r[r.AccessorExcludes = 13247] = "AccessorExcludes", r[r.TypeParameterExcludes = 526824] = "TypeParameterExcludes", r[r.TypeAliasExcludes = 788968] = "TypeAliasExcludes", r[r.AliasExcludes = 2097152] = "AliasExcludes", r[r.ModuleMember = 2623475] = "ModuleMember", r[r.ExportHasLocal = 944] = "ExportHasLocal", r[r.BlockScoped = 418] = "BlockScoped", r[r.PropertyOrAccessor = 98308] = "PropertyOrAccessor", r[r.ClassMember = 106500] = "ClassMember", r[r.ExportSupportsDefaultModifier = 112] = "ExportSupportsDefaultModifier", r[r.ExportDoesNotSupportDefaultModifier = -113] = "ExportDoesNotSupportDefaultModifier", r[r.Classifiable = 2885600] = "Classifiable", r[r.LateBindingContainer = 6256] = "LateBindingContainer";
            })(qe = e.SymbolFlags || (e.SymbolFlags = {}));
            var ge;
            (function(r) {
              r[r.Numeric = 0] = "Numeric", r[r.Literal = 1] = "Literal";
            })(ge = e.EnumKind || (e.EnumKind = {}));
            var ie;
            (function(r) {
              r[r.Instantiated = 1] = "Instantiated", r[r.SyntheticProperty = 2] = "SyntheticProperty", r[r.SyntheticMethod = 4] = "SyntheticMethod", r[r.Readonly = 8] = "Readonly", r[r.ReadPartial = 16] = "ReadPartial", r[r.WritePartial = 32] = "WritePartial", r[r.HasNonUniformType = 64] = "HasNonUniformType", r[r.HasLiteralType = 128] = "HasLiteralType", r[r.ContainsPublic = 256] = "ContainsPublic", r[r.ContainsProtected = 512] = "ContainsProtected", r[r.ContainsPrivate = 1024] = "ContainsPrivate", r[r.ContainsStatic = 2048] = "ContainsStatic", r[r.Late = 4096] = "Late", r[r.ReverseMapped = 8192] = "ReverseMapped", r[r.OptionalParameter = 16384] = "OptionalParameter", r[r.RestParameter = 32768] = "RestParameter", r[r.DeferredType = 65536] = "DeferredType", r[r.HasNeverType = 131072] = "HasNeverType", r[r.Mapped = 262144] = "Mapped", r[r.StripOptional = 524288] = "StripOptional", r[r.Unresolved = 1048576] = "Unresolved", r[r.Synthetic = 6] = "Synthetic", r[r.Discriminant = 192] = "Discriminant", r[r.Partial = 48] = "Partial";
            })(ie = e.CheckFlags || (e.CheckFlags = {}));
            var H;
            (function(r) {
              r.Call = "__call", r.Constructor = "__constructor", r.New = "__new", r.Index = "__index", r.ExportStar = "__export", r.Global = "__global", r.Missing = "__missing", r.Type = "__type", r.Object = "__object", r.JSXAttributes = "__jsxAttributes", r.Class = "__class", r.Function = "__function", r.Computed = "__computed", r.Resolving = "__resolving__", r.ExportEquals = "export=", r.Default = "default", r.This = "this";
            })(H = e.InternalSymbolName || (e.InternalSymbolName = {}));
            var pe;
            (function(r) {
              r[r.TypeChecked = 1] = "TypeChecked", r[r.LexicalThis = 2] = "LexicalThis", r[r.CaptureThis = 4] = "CaptureThis", r[r.CaptureNewTarget = 8] = "CaptureNewTarget", r[r.SuperInstance = 256] = "SuperInstance", r[r.SuperStatic = 512] = "SuperStatic", r[r.ContextChecked = 1024] = "ContextChecked", r[r.MethodWithSuperPropertyAccessInAsync = 2048] = "MethodWithSuperPropertyAccessInAsync", r[r.MethodWithSuperPropertyAssignmentInAsync = 4096] = "MethodWithSuperPropertyAssignmentInAsync", r[r.CaptureArguments = 8192] = "CaptureArguments", r[r.EnumValuesComputed = 16384] = "EnumValuesComputed", r[r.LexicalModuleMergesWithClass = 32768] = "LexicalModuleMergesWithClass", r[r.LoopWithCapturedBlockScopedBinding = 65536] = "LoopWithCapturedBlockScopedBinding", r[r.ContainsCapturedBlockScopeBinding = 131072] = "ContainsCapturedBlockScopeBinding", r[r.CapturedBlockScopedBinding = 262144] = "CapturedBlockScopedBinding", r[r.BlockScopedBindingInLoop = 524288] = "BlockScopedBindingInLoop", r[r.ClassWithBodyScopedClassBinding = 1048576] = "ClassWithBodyScopedClassBinding", r[r.BodyScopedClassBinding = 2097152] = "BodyScopedClassBinding", r[r.NeedsLoopOutParameter = 4194304] = "NeedsLoopOutParameter", r[r.AssignmentsMarked = 8388608] = "AssignmentsMarked", r[r.ClassWithConstructorReference = 16777216] = "ClassWithConstructorReference", r[r.ConstructorReferenceInClass = 33554432] = "ConstructorReferenceInClass", r[r.ContainsClassWithPrivateIdentifiers = 67108864] = "ContainsClassWithPrivateIdentifiers", r[r.ContainsSuperPropertyInStaticInitializer = 134217728] = "ContainsSuperPropertyInStaticInitializer", r[r.InCheckIdentifier = 268435456] = "InCheckIdentifier";
            })(pe = e.NodeCheckFlags || (e.NodeCheckFlags = {}));
            var j;
            (function(r) {
              r[r.Any = 1] = "Any", r[r.Unknown = 2] = "Unknown", r[r.String = 4] = "String", r[r.Number = 8] = "Number", r[r.Boolean = 16] = "Boolean", r[r.Enum = 32] = "Enum", r[r.BigInt = 64] = "BigInt", r[r.StringLiteral = 128] = "StringLiteral", r[r.NumberLiteral = 256] = "NumberLiteral", r[r.BooleanLiteral = 512] = "BooleanLiteral", r[r.EnumLiteral = 1024] = "EnumLiteral", r[r.BigIntLiteral = 2048] = "BigIntLiteral", r[r.ESSymbol = 4096] = "ESSymbol", r[r.UniqueESSymbol = 8192] = "UniqueESSymbol", r[r.Void = 16384] = "Void", r[r.Undefined = 32768] = "Undefined", r[r.Null = 65536] = "Null", r[r.Never = 131072] = "Never", r[r.TypeParameter = 262144] = "TypeParameter", r[r.Object = 524288] = "Object", r[r.Union = 1048576] = "Union", r[r.Intersection = 2097152] = "Intersection", r[r.Index = 4194304] = "Index", r[r.IndexedAccess = 8388608] = "IndexedAccess", r[r.Conditional = 16777216] = "Conditional", r[r.Substitution = 33554432] = "Substitution", r[r.NonPrimitive = 67108864] = "NonPrimitive", r[r.TemplateLiteral = 134217728] = "TemplateLiteral", r[r.StringMapping = 268435456] = "StringMapping", r[r.AnyOrUnknown = 3] = "AnyOrUnknown", r[r.Nullable = 98304] = "Nullable", r[r.Literal = 2944] = "Literal", r[r.Unit = 109440] = "Unit", r[r.StringOrNumberLiteral = 384] = "StringOrNumberLiteral", r[r.StringOrNumberLiteralOrUnique = 8576] = "StringOrNumberLiteralOrUnique", r[r.DefinitelyFalsy = 117632] = "DefinitelyFalsy", r[r.PossiblyFalsy = 117724] = "PossiblyFalsy", r[r.Intrinsic = 67359327] = "Intrinsic", r[r.Primitive = 131068] = "Primitive", r[r.StringLike = 402653316] = "StringLike", r[r.NumberLike = 296] = "NumberLike", r[r.BigIntLike = 2112] = "BigIntLike", r[r.BooleanLike = 528] = "BooleanLike", r[r.EnumLike = 1056] = "EnumLike", r[r.ESSymbolLike = 12288] = "ESSymbolLike", r[r.VoidLike = 49152] = "VoidLike", r[r.DefinitelyNonNullable = 470302716] = "DefinitelyNonNullable", r[r.DisjointDomains = 469892092] = "DisjointDomains", r[r.UnionOrIntersection = 3145728] = "UnionOrIntersection", r[r.StructuredType = 3670016] = "StructuredType", r[r.TypeVariable = 8650752] = "TypeVariable", r[r.InstantiableNonPrimitive = 58982400] = "InstantiableNonPrimitive", r[r.InstantiablePrimitive = 406847488] = "InstantiablePrimitive", r[r.Instantiable = 465829888] = "Instantiable", r[r.StructuredOrInstantiable = 469499904] = "StructuredOrInstantiable", r[r.ObjectFlagsType = 3899393] = "ObjectFlagsType", r[r.Simplifiable = 25165824] = "Simplifiable", r[r.Singleton = 67358815] = "Singleton", r[r.Narrowable = 536624127] = "Narrowable", r[r.IncludesMask = 205258751] = "IncludesMask", r[r.IncludesMissingType = 262144] = "IncludesMissingType", r[r.IncludesNonWideningType = 4194304] = "IncludesNonWideningType", r[r.IncludesWildcard = 8388608] = "IncludesWildcard", r[r.IncludesEmptyObject = 16777216] = "IncludesEmptyObject", r[r.IncludesInstantiable = 33554432] = "IncludesInstantiable", r[r.NotPrimitiveUnion = 36323363] = "NotPrimitiveUnion";
            })(j = e.TypeFlags || (e.TypeFlags = {}));
            var be;
            (function(r) {
              r[r.Class = 1] = "Class", r[r.Interface = 2] = "Interface", r[r.Reference = 4] = "Reference", r[r.Tuple = 8] = "Tuple", r[r.Anonymous = 16] = "Anonymous", r[r.Mapped = 32] = "Mapped", r[r.Instantiated = 64] = "Instantiated", r[r.ObjectLiteral = 128] = "ObjectLiteral", r[r.EvolvingArray = 256] = "EvolvingArray", r[r.ObjectLiteralPatternWithComputedProperties = 512] = "ObjectLiteralPatternWithComputedProperties", r[r.ReverseMapped = 1024] = "ReverseMapped", r[r.JsxAttributes = 2048] = "JsxAttributes", r[r.JSLiteral = 4096] = "JSLiteral", r[r.FreshLiteral = 8192] = "FreshLiteral", r[r.ArrayLiteral = 16384] = "ArrayLiteral", r[r.PrimitiveUnion = 32768] = "PrimitiveUnion", r[r.ContainsWideningType = 65536] = "ContainsWideningType", r[r.ContainsObjectOrArrayLiteral = 131072] = "ContainsObjectOrArrayLiteral", r[r.NonInferrableType = 262144] = "NonInferrableType", r[r.CouldContainTypeVariablesComputed = 524288] = "CouldContainTypeVariablesComputed", r[r.CouldContainTypeVariables = 1048576] = "CouldContainTypeVariables", r[r.ClassOrInterface = 3] = "ClassOrInterface", r[r.RequiresWidening = 196608] = "RequiresWidening", r[r.PropagatingFlags = 458752] = "PropagatingFlags", r[r.ObjectTypeKindMask = 1343] = "ObjectTypeKindMask", r[r.ContainsSpread = 2097152] = "ContainsSpread", r[r.ObjectRestType = 4194304] = "ObjectRestType", r[r.InstantiationExpressionType = 8388608] = "InstantiationExpressionType", r[r.IsClassInstanceClone = 16777216] = "IsClassInstanceClone", r[r.IdenticalBaseTypeCalculated = 33554432] = "IdenticalBaseTypeCalculated", r[r.IdenticalBaseTypeExists = 67108864] = "IdenticalBaseTypeExists", r[r.IsGenericTypeComputed = 2097152] = "IsGenericTypeComputed", r[r.IsGenericObjectType = 4194304] = "IsGenericObjectType", r[r.IsGenericIndexType = 8388608] = "IsGenericIndexType", r[r.IsGenericType = 12582912] = "IsGenericType", r[r.ContainsIntersections = 16777216] = "ContainsIntersections", r[r.IsUnknownLikeUnionComputed = 33554432] = "IsUnknownLikeUnionComputed", r[r.IsUnknownLikeUnion = 67108864] = "IsUnknownLikeUnion", r[r.IsNeverIntersectionComputed = 16777216] = "IsNeverIntersectionComputed", r[r.IsNeverIntersection = 33554432] = "IsNeverIntersection";
            })(be = e.ObjectFlags || (e.ObjectFlags = {}));
            var Xe;
            (function(r) {
              r[r.Invariant = 0] = "Invariant", r[r.Covariant = 1] = "Covariant", r[r.Contravariant = 2] = "Contravariant", r[r.Bivariant = 3] = "Bivariant", r[r.Independent = 4] = "Independent", r[r.VarianceMask = 7] = "VarianceMask", r[r.Unmeasurable = 8] = "Unmeasurable", r[r.Unreliable = 16] = "Unreliable", r[r.AllowsStructuralFallback = 24] = "AllowsStructuralFallback";
            })(Xe = e.VarianceFlags || (e.VarianceFlags = {}));
            var Re;
            (function(r) {
              r[r.Required = 1] = "Required", r[r.Optional = 2] = "Optional", r[r.Rest = 4] = "Rest", r[r.Variadic = 8] = "Variadic", r[r.Fixed = 3] = "Fixed", r[r.Variable = 12] = "Variable", r[r.NonRequired = 14] = "NonRequired", r[r.NonRest = 11] = "NonRest";
            })(Re = e.ElementFlags || (e.ElementFlags = {}));
            var Fe;
            (function(r) {
              r[r.None = 0] = "None", r[r.IncludeUndefined = 1] = "IncludeUndefined", r[r.NoIndexSignatures = 2] = "NoIndexSignatures", r[r.Writing = 4] = "Writing", r[r.CacheSymbol = 8] = "CacheSymbol", r[r.NoTupleBoundsCheck = 16] = "NoTupleBoundsCheck", r[r.ExpressionPosition = 32] = "ExpressionPosition", r[r.ReportDeprecated = 64] = "ReportDeprecated", r[r.SuppressNoImplicitAnyError = 128] = "SuppressNoImplicitAnyError", r[r.Contextual = 256] = "Contextual", r[r.Persistent = 1] = "Persistent";
            })(Fe = e.AccessFlags || (e.AccessFlags = {}));
            var dr;
            (function(r) {
              r[r.Component = 0] = "Component", r[r.Function = 1] = "Function", r[r.Mixed = 2] = "Mixed";
            })(dr = e.JsxReferenceKind || (e.JsxReferenceKind = {}));
            var ze;
            (function(r) {
              r[r.Call = 0] = "Call", r[r.Construct = 1] = "Construct";
            })(ze = e.SignatureKind || (e.SignatureKind = {}));
            var ve;
            (function(r) {
              r[r.None = 0] = "None", r[r.HasRestParameter = 1] = "HasRestParameter", r[r.HasLiteralTypes = 2] = "HasLiteralTypes", r[r.Abstract = 4] = "Abstract", r[r.IsInnerCallChain = 8] = "IsInnerCallChain", r[r.IsOuterCallChain = 16] = "IsOuterCallChain", r[r.IsUntypedSignatureInJSFile = 32] = "IsUntypedSignatureInJSFile", r[r.PropagatingFlags = 39] = "PropagatingFlags", r[r.CallChainFlags = 24] = "CallChainFlags";
            })(ve = e.SignatureFlags || (e.SignatureFlags = {}));
            var er;
            (function(r) {
              r[r.String = 0] = "String", r[r.Number = 1] = "Number";
            })(er = e.IndexKind || (e.IndexKind = {}));
            var ar;
            (function(r) {
              r[r.Simple = 0] = "Simple", r[r.Array = 1] = "Array", r[r.Deferred = 2] = "Deferred", r[r.Function = 3] = "Function", r[r.Composite = 4] = "Composite", r[r.Merged = 5] = "Merged";
            })(ar = e.TypeMapKind || (e.TypeMapKind = {}));
            var Cr;
            (function(r) {
              r[r.NakedTypeVariable = 1] = "NakedTypeVariable", r[r.SpeculativeTuple = 2] = "SpeculativeTuple", r[r.SubstituteSource = 4] = "SubstituteSource", r[r.HomomorphicMappedType = 8] = "HomomorphicMappedType", r[r.PartialHomomorphicMappedType = 16] = "PartialHomomorphicMappedType", r[r.MappedTypeConstraint = 32] = "MappedTypeConstraint", r[r.ContravariantConditional = 64] = "ContravariantConditional", r[r.ReturnType = 128] = "ReturnType", r[r.LiteralKeyof = 256] = "LiteralKeyof", r[r.NoConstraints = 512] = "NoConstraints", r[r.AlwaysStrict = 1024] = "AlwaysStrict", r[r.MaxValue = 2048] = "MaxValue", r[r.PriorityImpliesCombination = 416] = "PriorityImpliesCombination", r[r.Circularity = -1] = "Circularity";
            })(Cr = e.InferencePriority || (e.InferencePriority = {}));
            var Ce;
            (function(r) {
              r[r.None = 0] = "None", r[r.NoDefault = 1] = "NoDefault", r[r.AnyDefault = 2] = "AnyDefault", r[r.SkippedGenericFunction = 4] = "SkippedGenericFunction";
            })(Ce = e.InferenceFlags || (e.InferenceFlags = {}));
            var $e;
            (function(r) {
              r[r.False = 0] = "False", r[r.Unknown = 1] = "Unknown", r[r.Maybe = 3] = "Maybe", r[r.True = -1] = "True";
            })($e = e.Ternary || (e.Ternary = {}));
            var gr;
            (function(r) {
              r[r.None = 0] = "None", r[r.ExportsProperty = 1] = "ExportsProperty", r[r.ModuleExports = 2] = "ModuleExports", r[r.PrototypeProperty = 3] = "PrototypeProperty", r[r.ThisProperty = 4] = "ThisProperty", r[r.Property = 5] = "Property", r[r.Prototype = 6] = "Prototype", r[r.ObjectDefinePropertyValue = 7] = "ObjectDefinePropertyValue", r[r.ObjectDefinePropertyExports = 8] = "ObjectDefinePropertyExports", r[r.ObjectDefinePrototypeProperty = 9] = "ObjectDefinePrototypeProperty";
            })(gr = e.AssignmentDeclarationKind || (e.AssignmentDeclarationKind = {}));
            var X;
            (function(r) {
              r[r.Warning = 0] = "Warning", r[r.Error = 1] = "Error", r[r.Suggestion = 2] = "Suggestion", r[r.Message = 3] = "Message";
            })(X = e.DiagnosticCategory || (e.DiagnosticCategory = {}));
            function Te(r, ct) {
              ct === void 0 && (ct = true);
              var ft = X[r.category];
              return ct ? ft.toLowerCase() : ft;
            }
            e.diagnosticCategoryName = Te;
            var we;
            (function(r) {
              r[r.Classic = 1] = "Classic", r[r.NodeJs = 2] = "NodeJs", r[r.Node16 = 3] = "Node16", r[r.NodeNext = 99] = "NodeNext";
            })(we = e.ModuleResolutionKind || (e.ModuleResolutionKind = {}));
            var he;
            (function(r) {
              r[r.Legacy = 1] = "Legacy", r[r.Auto = 2] = "Auto", r[r.Force = 3] = "Force";
            })(he = e.ModuleDetectionKind || (e.ModuleDetectionKind = {}));
            var yr;
            (function(r) {
              r[r.FixedPollingInterval = 0] = "FixedPollingInterval", r[r.PriorityPollingInterval = 1] = "PriorityPollingInterval", r[r.DynamicPriorityPolling = 2] = "DynamicPriorityPolling", r[r.FixedChunkSizePolling = 3] = "FixedChunkSizePolling", r[r.UseFsEvents = 4] = "UseFsEvents", r[r.UseFsEventsOnParentDirectory = 5] = "UseFsEventsOnParentDirectory";
            })(yr = e.WatchFileKind || (e.WatchFileKind = {}));
            var kr;
            (function(r) {
              r[r.UseFsEvents = 0] = "UseFsEvents", r[r.FixedPollingInterval = 1] = "FixedPollingInterval", r[r.DynamicPriorityPolling = 2] = "DynamicPriorityPolling", r[r.FixedChunkSizePolling = 3] = "FixedChunkSizePolling";
            })(kr = e.WatchDirectoryKind || (e.WatchDirectoryKind = {}));
            var nr;
            (function(r) {
              r[r.FixedInterval = 0] = "FixedInterval", r[r.PriorityInterval = 1] = "PriorityInterval", r[r.DynamicPriority = 2] = "DynamicPriority", r[r.FixedChunkSize = 3] = "FixedChunkSize";
            })(nr = e.PollingWatchKind || (e.PollingWatchKind = {}));
            var tr;
            (function(r) {
              r[r.None = 0] = "None", r[r.CommonJS = 1] = "CommonJS", r[r.AMD = 2] = "AMD", r[r.UMD = 3] = "UMD", r[r.System = 4] = "System", r[r.ES2015 = 5] = "ES2015", r[r.ES2020 = 6] = "ES2020", r[r.ES2022 = 7] = "ES2022", r[r.ESNext = 99] = "ESNext", r[r.Node16 = 100] = "Node16", r[r.NodeNext = 199] = "NodeNext";
            })(tr = e.ModuleKind || (e.ModuleKind = {}));
            var Lr;
            (function(r) {
              r[r.None = 0] = "None", r[r.Preserve = 1] = "Preserve", r[r.React = 2] = "React", r[r.ReactNative = 3] = "ReactNative", r[r.ReactJSX = 4] = "ReactJSX", r[r.ReactJSXDev = 5] = "ReactJSXDev";
            })(Lr = e.JsxEmit || (e.JsxEmit = {}));
            var zr;
            (function(r) {
              r[r.Remove = 0] = "Remove", r[r.Preserve = 1] = "Preserve", r[r.Error = 2] = "Error";
            })(zr = e.ImportsNotUsedAsValues || (e.ImportsNotUsedAsValues = {}));
            var ye;
            (function(r) {
              r[r.CarriageReturnLineFeed = 0] = "CarriageReturnLineFeed", r[r.LineFeed = 1] = "LineFeed";
            })(ye = e.NewLineKind || (e.NewLineKind = {}));
            var ir;
            (function(r) {
              r[r.Unknown = 0] = "Unknown", r[r.JS = 1] = "JS", r[r.JSX = 2] = "JSX", r[r.TS = 3] = "TS", r[r.TSX = 4] = "TSX", r[r.External = 5] = "External", r[r.JSON = 6] = "JSON", r[r.Deferred = 7] = "Deferred";
            })(ir = e.ScriptKind || (e.ScriptKind = {}));
            var Dr;
            (function(r) {
              r[r.ES3 = 0] = "ES3", r[r.ES5 = 1] = "ES5", r[r.ES2015 = 2] = "ES2015", r[r.ES2016 = 3] = "ES2016", r[r.ES2017 = 4] = "ES2017", r[r.ES2018 = 5] = "ES2018", r[r.ES2019 = 6] = "ES2019", r[r.ES2020 = 7] = "ES2020", r[r.ES2021 = 8] = "ES2021", r[r.ES2022 = 9] = "ES2022", r[r.ESNext = 99] = "ESNext", r[r.JSON = 100] = "JSON", r[r.Latest = 99] = "Latest";
            })(Dr = e.ScriptTarget || (e.ScriptTarget = {}));
            var Pr;
            (function(r) {
              r[r.Standard = 0] = "Standard", r[r.JSX = 1] = "JSX";
            })(Pr = e.LanguageVariant || (e.LanguageVariant = {}));
            var Br;
            (function(r) {
              r[r.None = 0] = "None", r[r.Recursive = 1] = "Recursive";
            })(Br = e.WatchDirectoryFlags || (e.WatchDirectoryFlags = {}));
            var ut;
            (function(r) {
              r[r.nullCharacter = 0] = "nullCharacter", r[r.maxAsciiCharacter = 127] = "maxAsciiCharacter", r[r.lineFeed = 10] = "lineFeed", r[r.carriageReturn = 13] = "carriageReturn", r[r.lineSeparator = 8232] = "lineSeparator", r[r.paragraphSeparator = 8233] = "paragraphSeparator", r[r.nextLine = 133] = "nextLine", r[r.space = 32] = "space", r[r.nonBreakingSpace = 160] = "nonBreakingSpace", r[r.enQuad = 8192] = "enQuad", r[r.emQuad = 8193] = "emQuad", r[r.enSpace = 8194] = "enSpace", r[r.emSpace = 8195] = "emSpace", r[r.threePerEmSpace = 8196] = "threePerEmSpace", r[r.fourPerEmSpace = 8197] = "fourPerEmSpace", r[r.sixPerEmSpace = 8198] = "sixPerEmSpace", r[r.figureSpace = 8199] = "figureSpace", r[r.punctuationSpace = 8200] = "punctuationSpace", r[r.thinSpace = 8201] = "thinSpace", r[r.hairSpace = 8202] = "hairSpace", r[r.zeroWidthSpace = 8203] = "zeroWidthSpace", r[r.narrowNoBreakSpace = 8239] = "narrowNoBreakSpace", r[r.ideographicSpace = 12288] = "ideographicSpace", r[r.mathematicalSpace = 8287] = "mathematicalSpace", r[r.ogham = 5760] = "ogham", r[r._ = 95] = "_", r[r.$ = 36] = "$", r[r._0 = 48] = "_0", r[r._1 = 49] = "_1", r[r._2 = 50] = "_2", r[r._3 = 51] = "_3", r[r._4 = 52] = "_4", r[r._5 = 53] = "_5", r[r._6 = 54] = "_6", r[r._7 = 55] = "_7", r[r._8 = 56] = "_8", r[r._9 = 57] = "_9", r[r.a = 97] = "a", r[r.b = 98] = "b", r[r.c = 99] = "c", r[r.d = 100] = "d", r[r.e = 101] = "e", r[r.f = 102] = "f", r[r.g = 103] = "g", r[r.h = 104] = "h", r[r.i = 105] = "i", r[r.j = 106] = "j", r[r.k = 107] = "k", r[r.l = 108] = "l", r[r.m = 109] = "m", r[r.n = 110] = "n", r[r.o = 111] = "o", r[r.p = 112] = "p", r[r.q = 113] = "q", r[r.r = 114] = "r", r[r.s = 115] = "s", r[r.t = 116] = "t", r[r.u = 117] = "u", r[r.v = 118] = "v", r[r.w = 119] = "w", r[r.x = 120] = "x", r[r.y = 121] = "y", r[r.z = 122] = "z", r[r.A = 65] = "A", r[r.B = 66] = "B", r[r.C = 67] = "C", r[r.D = 68] = "D", r[r.E = 69] = "E", r[r.F = 70] = "F", r[r.G = 71] = "G", r[r.H = 72] = "H", r[r.I = 73] = "I", r[r.J = 74] = "J", r[r.K = 75] = "K", r[r.L = 76] = "L", r[r.M = 77] = "M", r[r.N = 78] = "N", r[r.O = 79] = "O", r[r.P = 80] = "P", r[r.Q = 81] = "Q", r[r.R = 82] = "R", r[r.S = 83] = "S", r[r.T = 84] = "T", r[r.U = 85] = "U", r[r.V = 86] = "V", r[r.W = 87] = "W", r[r.X = 88] = "X", r[r.Y = 89] = "Y", r[r.Z = 90] = "Z", r[r.ampersand = 38] = "ampersand", r[r.asterisk = 42] = "asterisk", r[r.at = 64] = "at", r[r.backslash = 92] = "backslash", r[r.backtick = 96] = "backtick", r[r.bar = 124] = "bar", r[r.caret = 94] = "caret", r[r.closeBrace = 125] = "closeBrace", r[r.closeBracket = 93] = "closeBracket", r[r.closeParen = 41] = "closeParen", r[r.colon = 58] = "colon", r[r.comma = 44] = "comma", r[r.dot = 46] = "dot", r[r.doubleQuote = 34] = "doubleQuote", r[r.equals = 61] = "equals", r[r.exclamation = 33] = "exclamation", r[r.greaterThan = 62] = "greaterThan", r[r.hash = 35] = "hash", r[r.lessThan = 60] = "lessThan", r[r.minus = 45] = "minus", r[r.openBrace = 123] = "openBrace", r[r.openBracket = 91] = "openBracket", r[r.openParen = 40] = "openParen", r[r.percent = 37] = "percent", r[r.plus = 43] = "plus", r[r.question = 63] = "question", r[r.semicolon = 59] = "semicolon", r[r.singleQuote = 39] = "singleQuote", r[r.slash = 47] = "slash", r[r.tilde = 126] = "tilde", r[r.backspace = 8] = "backspace", r[r.formFeed = 12] = "formFeed", r[r.byteOrderMark = 65279] = "byteOrderMark", r[r.tab = 9] = "tab", r[r.verticalTab = 11] = "verticalTab";
            })(ut = e.CharacterCodes || (e.CharacterCodes = {}));
            var rt;
            (function(r) {
              r.Ts = ".ts", r.Tsx = ".tsx", r.Dts = ".d.ts", r.Js = ".js", r.Jsx = ".jsx", r.Json = ".json", r.TsBuildInfo = ".tsbuildinfo", r.Mjs = ".mjs", r.Mts = ".mts", r.Dmts = ".d.mts", r.Cjs = ".cjs", r.Cts = ".cts", r.Dcts = ".d.cts";
            })(rt = e.Extension || (e.Extension = {}));
            var Z;
            (function(r) {
              r[r.None = 0] = "None", r[r.ContainsTypeScript = 1] = "ContainsTypeScript", r[r.ContainsJsx = 2] = "ContainsJsx", r[r.ContainsESNext = 4] = "ContainsESNext", r[r.ContainsES2022 = 8] = "ContainsES2022", r[r.ContainsES2021 = 16] = "ContainsES2021", r[r.ContainsES2020 = 32] = "ContainsES2020", r[r.ContainsES2019 = 64] = "ContainsES2019", r[r.ContainsES2018 = 128] = "ContainsES2018", r[r.ContainsES2017 = 256] = "ContainsES2017", r[r.ContainsES2016 = 512] = "ContainsES2016", r[r.ContainsES2015 = 1024] = "ContainsES2015", r[r.ContainsGenerator = 2048] = "ContainsGenerator", r[r.ContainsDestructuringAssignment = 4096] = "ContainsDestructuringAssignment", r[r.ContainsTypeScriptClassSyntax = 8192] = "ContainsTypeScriptClassSyntax", r[r.ContainsLexicalThis = 16384] = "ContainsLexicalThis", r[r.ContainsRestOrSpread = 32768] = "ContainsRestOrSpread", r[r.ContainsObjectRestOrSpread = 65536] = "ContainsObjectRestOrSpread", r[r.ContainsComputedPropertyName = 131072] = "ContainsComputedPropertyName", r[r.ContainsBlockScopedBinding = 262144] = "ContainsBlockScopedBinding", r[r.ContainsBindingPattern = 524288] = "ContainsBindingPattern", r[r.ContainsYield = 1048576] = "ContainsYield", r[r.ContainsAwait = 2097152] = "ContainsAwait", r[r.ContainsHoistedDeclarationOrCompletion = 4194304] = "ContainsHoistedDeclarationOrCompletion", r[r.ContainsDynamicImport = 8388608] = "ContainsDynamicImport", r[r.ContainsClassFields = 16777216] = "ContainsClassFields", r[r.ContainsDecorators = 33554432] = "ContainsDecorators", r[r.ContainsPossibleTopLevelAwait = 67108864] = "ContainsPossibleTopLevelAwait", r[r.ContainsLexicalSuper = 134217728] = "ContainsLexicalSuper", r[r.ContainsUpdateExpressionForIdentifier = 268435456] = "ContainsUpdateExpressionForIdentifier", r[r.ContainsPrivateIdentifierInExpression = 536870912] = "ContainsPrivateIdentifierInExpression", r[r.HasComputedFlags = -2147483648] = "HasComputedFlags", r[r.AssertTypeScript = 1] = "AssertTypeScript", r[r.AssertJsx = 2] = "AssertJsx", r[r.AssertESNext = 4] = "AssertESNext", r[r.AssertES2022 = 8] = "AssertES2022", r[r.AssertES2021 = 16] = "AssertES2021", r[r.AssertES2020 = 32] = "AssertES2020", r[r.AssertES2019 = 64] = "AssertES2019", r[r.AssertES2018 = 128] = "AssertES2018", r[r.AssertES2017 = 256] = "AssertES2017", r[r.AssertES2016 = 512] = "AssertES2016", r[r.AssertES2015 = 1024] = "AssertES2015", r[r.AssertGenerator = 2048] = "AssertGenerator", r[r.AssertDestructuringAssignment = 4096] = "AssertDestructuringAssignment", r[r.OuterExpressionExcludes = -2147483648] = "OuterExpressionExcludes", r[r.PropertyAccessExcludes = -2147483648] = "PropertyAccessExcludes", r[r.NodeExcludes = -2147483648] = "NodeExcludes", r[r.ArrowFunctionExcludes = -2072174592] = "ArrowFunctionExcludes", r[r.FunctionExcludes = -1937940480] = "FunctionExcludes", r[r.ConstructorExcludes = -1937948672] = "ConstructorExcludes", r[r.MethodOrAccessorExcludes = -2005057536] = "MethodOrAccessorExcludes", r[r.PropertyExcludes = -2013249536] = "PropertyExcludes", r[r.ClassExcludes = -2147344384] = "ClassExcludes", r[r.ModuleExcludes = -1941676032] = "ModuleExcludes", r[r.TypeExcludes = -2] = "TypeExcludes", r[r.ObjectLiteralExcludes = -2147278848] = "ObjectLiteralExcludes", r[r.ArrayLiteralOrCallOrNewExcludes = -2147450880] = "ArrayLiteralOrCallOrNewExcludes", r[r.VariableDeclarationListExcludes = -2146893824] = "VariableDeclarationListExcludes", r[r.ParameterExcludes = -2147483648] = "ParameterExcludes", r[r.CatchClauseExcludes = -2147418112] = "CatchClauseExcludes", r[r.BindingPatternExcludes = -2147450880] = "BindingPatternExcludes", r[r.ContainsLexicalThisOrSuper = 134234112] = "ContainsLexicalThisOrSuper", r[r.PropertyNamePropagatingFlags = 134234112] = "PropertyNamePropagatingFlags";
            })(Z = e.TransformFlags || (e.TransformFlags = {}));
            var f;
            (function(r) {
              r[r.TabStop = 0] = "TabStop", r[r.Placeholder = 1] = "Placeholder", r[r.Choice = 2] = "Choice", r[r.Variable = 3] = "Variable";
            })(f = e.SnippetKind || (e.SnippetKind = {}));
            var h;
            (function(r) {
              r[r.None = 0] = "None", r[r.SingleLine = 1] = "SingleLine", r[r.AdviseOnEmitNode = 2] = "AdviseOnEmitNode", r[r.NoSubstitution = 4] = "NoSubstitution", r[r.CapturesThis = 8] = "CapturesThis", r[r.NoLeadingSourceMap = 16] = "NoLeadingSourceMap", r[r.NoTrailingSourceMap = 32] = "NoTrailingSourceMap", r[r.NoSourceMap = 48] = "NoSourceMap", r[r.NoNestedSourceMaps = 64] = "NoNestedSourceMaps", r[r.NoTokenLeadingSourceMaps = 128] = "NoTokenLeadingSourceMaps", r[r.NoTokenTrailingSourceMaps = 256] = "NoTokenTrailingSourceMaps", r[r.NoTokenSourceMaps = 384] = "NoTokenSourceMaps", r[r.NoLeadingComments = 512] = "NoLeadingComments", r[r.NoTrailingComments = 1024] = "NoTrailingComments", r[r.NoComments = 1536] = "NoComments", r[r.NoNestedComments = 2048] = "NoNestedComments", r[r.HelperName = 4096] = "HelperName", r[r.ExportName = 8192] = "ExportName", r[r.LocalName = 16384] = "LocalName", r[r.InternalName = 32768] = "InternalName", r[r.Indented = 65536] = "Indented", r[r.NoIndentation = 131072] = "NoIndentation", r[r.AsyncFunctionBody = 262144] = "AsyncFunctionBody", r[r.ReuseTempVariableScope = 524288] = "ReuseTempVariableScope", r[r.CustomPrologue = 1048576] = "CustomPrologue", r[r.NoHoisting = 2097152] = "NoHoisting", r[r.HasEndOfDeclarationMarker = 4194304] = "HasEndOfDeclarationMarker", r[r.Iterator = 8388608] = "Iterator", r[r.NoAsciiEscaping = 16777216] = "NoAsciiEscaping", r[r.TypeScriptClassWrapper = 33554432] = "TypeScriptClassWrapper", r[r.NeverApplyImportHelper = 67108864] = "NeverApplyImportHelper", r[r.IgnoreSourceNewlines = 134217728] = "IgnoreSourceNewlines", r[r.Immutable = 268435456] = "Immutable", r[r.IndirectCall = 536870912] = "IndirectCall";
            })(h = e.EmitFlags || (e.EmitFlags = {}));
            var oe;
            (function(r) {
              r[r.Extends = 1] = "Extends", r[r.Assign = 2] = "Assign", r[r.Rest = 4] = "Rest", r[r.Decorate = 8] = "Decorate", r[r.Metadata = 16] = "Metadata", r[r.Param = 32] = "Param", r[r.Awaiter = 64] = "Awaiter", r[r.Generator = 128] = "Generator", r[r.Values = 256] = "Values", r[r.Read = 512] = "Read", r[r.SpreadArray = 1024] = "SpreadArray", r[r.Await = 2048] = "Await", r[r.AsyncGenerator = 4096] = "AsyncGenerator", r[r.AsyncDelegator = 8192] = "AsyncDelegator", r[r.AsyncValues = 16384] = "AsyncValues", r[r.ExportStar = 32768] = "ExportStar", r[r.ImportStar = 65536] = "ImportStar", r[r.ImportDefault = 131072] = "ImportDefault", r[r.MakeTemplateObject = 262144] = "MakeTemplateObject", r[r.ClassPrivateFieldGet = 524288] = "ClassPrivateFieldGet", r[r.ClassPrivateFieldSet = 1048576] = "ClassPrivateFieldSet", r[r.ClassPrivateFieldIn = 2097152] = "ClassPrivateFieldIn", r[r.CreateBinding = 4194304] = "CreateBinding", r[r.FirstEmitHelper = 1] = "FirstEmitHelper", r[r.LastEmitHelper = 4194304] = "LastEmitHelper", r[r.ForOfIncludes = 256] = "ForOfIncludes", r[r.ForAwaitOfIncludes = 16384] = "ForAwaitOfIncludes", r[r.AsyncGeneratorIncludes = 6144] = "AsyncGeneratorIncludes", r[r.AsyncDelegatorIncludes = 26624] = "AsyncDelegatorIncludes", r[r.SpreadIncludes = 1536] = "SpreadIncludes";
            })(oe = e.ExternalEmitHelpers || (e.ExternalEmitHelpers = {}));
            var xr;
            (function(r) {
              r[r.SourceFile = 0] = "SourceFile", r[r.Expression = 1] = "Expression", r[r.IdentifierName = 2] = "IdentifierName", r[r.MappedTypeParameter = 3] = "MappedTypeParameter", r[r.Unspecified = 4] = "Unspecified", r[r.EmbeddedStatement = 5] = "EmbeddedStatement", r[r.JsxAttributeValue = 6] = "JsxAttributeValue";
            })(xr = e.EmitHint || (e.EmitHint = {}));
            var jr;
            (function(r) {
              r[r.Parentheses = 1] = "Parentheses", r[r.TypeAssertions = 2] = "TypeAssertions", r[r.NonNullAssertions = 4] = "NonNullAssertions", r[r.PartiallyEmittedExpressions = 8] = "PartiallyEmittedExpressions", r[r.Assertions = 6] = "Assertions", r[r.All = 15] = "All", r[r.ExcludeJSDocTypeAssertion = 16] = "ExcludeJSDocTypeAssertion";
            })(jr = e.OuterExpressionKinds || (e.OuterExpressionKinds = {}));
            var qr;
            (function(r) {
              r[r.None = 0] = "None", r[r.InParameters = 1] = "InParameters", r[r.VariablesHoistedInParameters = 2] = "VariablesHoistedInParameters";
            })(qr = e.LexicalEnvironmentFlags || (e.LexicalEnvironmentFlags = {}));
            var pt;
            (function(r) {
              r.Prologue = "prologue", r.EmitHelpers = "emitHelpers", r.NoDefaultLib = "no-default-lib", r.Reference = "reference", r.Type = "type", r.TypeResolutionModeRequire = "type-require", r.TypeResolutionModeImport = "type-import", r.Lib = "lib", r.Prepend = "prepend", r.Text = "text", r.Internal = "internal";
            })(pt = e.BundleFileSectionKind || (e.BundleFileSectionKind = {}));
            var Ge;
            (function(r) {
              r[r.None = 0] = "None", r[r.SingleLine = 0] = "SingleLine", r[r.MultiLine = 1] = "MultiLine", r[r.PreserveLines = 2] = "PreserveLines", r[r.LinesMask = 3] = "LinesMask", r[r.NotDelimited = 0] = "NotDelimited", r[r.BarDelimited = 4] = "BarDelimited", r[r.AmpersandDelimited = 8] = "AmpersandDelimited", r[r.CommaDelimited = 16] = "CommaDelimited", r[r.AsteriskDelimited = 32] = "AsteriskDelimited", r[r.DelimitersMask = 60] = "DelimitersMask", r[r.AllowTrailingComma = 64] = "AllowTrailingComma", r[r.Indented = 128] = "Indented", r[r.SpaceBetweenBraces = 256] = "SpaceBetweenBraces", r[r.SpaceBetweenSiblings = 512] = "SpaceBetweenSiblings", r[r.Braces = 1024] = "Braces", r[r.Parenthesis = 2048] = "Parenthesis", r[r.AngleBrackets = 4096] = "AngleBrackets", r[r.SquareBrackets = 8192] = "SquareBrackets", r[r.BracketsMask = 15360] = "BracketsMask", r[r.OptionalIfUndefined = 16384] = "OptionalIfUndefined", r[r.OptionalIfEmpty = 32768] = "OptionalIfEmpty", r[r.Optional = 49152] = "Optional", r[r.PreferNewLine = 65536] = "PreferNewLine", r[r.NoTrailingNewLine = 131072] = "NoTrailingNewLine", r[r.NoInterveningComments = 262144] = "NoInterveningComments", r[r.NoSpaceIfEmpty = 524288] = "NoSpaceIfEmpty", r[r.SingleElement = 1048576] = "SingleElement", r[r.SpaceAfterList = 2097152] = "SpaceAfterList", r[r.Modifiers = 2359808] = "Modifiers", r[r.HeritageClauses = 512] = "HeritageClauses", r[r.SingleLineTypeLiteralMembers = 768] = "SingleLineTypeLiteralMembers", r[r.MultiLineTypeLiteralMembers = 32897] = "MultiLineTypeLiteralMembers", r[r.SingleLineTupleTypeElements = 528] = "SingleLineTupleTypeElements", r[r.MultiLineTupleTypeElements = 657] = "MultiLineTupleTypeElements", r[r.UnionTypeConstituents = 516] = "UnionTypeConstituents", r[r.IntersectionTypeConstituents = 520] = "IntersectionTypeConstituents", r[r.ObjectBindingPatternElements = 525136] = "ObjectBindingPatternElements", r[r.ArrayBindingPatternElements = 524880] = "ArrayBindingPatternElements", r[r.ObjectLiteralExpressionProperties = 526226] = "ObjectLiteralExpressionProperties", r[r.ImportClauseEntries = 526226] = "ImportClauseEntries", r[r.ArrayLiteralExpressionElements = 8914] = "ArrayLiteralExpressionElements", r[r.CommaListElements = 528] = "CommaListElements", r[r.CallExpressionArguments = 2576] = "CallExpressionArguments", r[r.NewExpressionArguments = 18960] = "NewExpressionArguments", r[r.TemplateExpressionSpans = 262144] = "TemplateExpressionSpans", r[r.SingleLineBlockStatements = 768] = "SingleLineBlockStatements", r[r.MultiLineBlockStatements = 129] = "MultiLineBlockStatements", r[r.VariableDeclarationList = 528] = "VariableDeclarationList", r[r.SingleLineFunctionBodyStatements = 768] = "SingleLineFunctionBodyStatements", r[r.MultiLineFunctionBodyStatements = 1] = "MultiLineFunctionBodyStatements", r[r.ClassHeritageClauses = 0] = "ClassHeritageClauses", r[r.ClassMembers = 129] = "ClassMembers", r[r.InterfaceMembers = 129] = "InterfaceMembers", r[r.EnumMembers = 145] = "EnumMembers", r[r.CaseBlockClauses = 129] = "CaseBlockClauses", r[r.NamedImportsOrExportsElements = 525136] = "NamedImportsOrExportsElements", r[r.JsxElementOrFragmentChildren = 262144] = "JsxElementOrFragmentChildren", r[r.JsxElementAttributes = 262656] = "JsxElementAttributes", r[r.CaseOrDefaultClauseStatements = 163969] = "CaseOrDefaultClauseStatements", r[r.HeritageClauseTypes = 528] = "HeritageClauseTypes", r[r.SourceFileStatements = 131073] = "SourceFileStatements", r[r.Decorators = 2146305] = "Decorators", r[r.TypeArguments = 53776] = "TypeArguments", r[r.TypeParameters = 53776] = "TypeParameters", r[r.Parameters = 2576] = "Parameters", r[r.IndexSignatureParameters = 8848] = "IndexSignatureParameters", r[r.JSDocComment = 33] = "JSDocComment";
            })(Ge = e.ListFormat || (e.ListFormat = {}));
            var K;
            (function(r) {
              r[r.None = 0] = "None", r[r.TripleSlashXML = 1] = "TripleSlashXML", r[r.SingleLine = 2] = "SingleLine", r[r.MultiLine = 4] = "MultiLine", r[r.All = 7] = "All", r[r.Default = 7] = "Default";
            })(K = e.PragmaKindFlags || (e.PragmaKindFlags = {})), e.commentPragmas = { reference: { args: [{ name: "types", optional: true, captureSpan: true }, { name: "lib", optional: true, captureSpan: true }, { name: "path", optional: true, captureSpan: true }, { name: "no-default-lib", optional: true }, { name: "resolution-mode", optional: true }], kind: 1 }, "amd-dependency": { args: [{ name: "path" }, { name: "name", optional: true }], kind: 1 }, "amd-module": { args: [{ name: "name" }], kind: 1 }, "ts-check": { kind: 2 }, "ts-nocheck": { kind: 2 }, jsx: { args: [{ name: "factory" }], kind: 4 }, jsxfrag: { args: [{ name: "factory" }], kind: 4 }, jsximportsource: { args: [{ name: "factory" }], kind: 4 }, jsxruntime: { args: [{ name: "factory" }], kind: 4 } };
          })(N || (N = {}));
          var N;
          (function(e) {
            e.directorySeparator = "/", e.altDirectorySeparator = "\\";
            var t3 = "://", w = /\\/g;
            function s(ye) {
              return ye === 47 || ye === 92;
            }
            e.isAnyDirectorySeparator = s;
            function q(ye) {
              return B(ye) < 0;
            }
            e.isUrl = q;
            function F(ye) {
              return B(ye) > 0;
            }
            e.isRootedDiskPath = F;
            function fe(ye) {
              var ir = B(ye);
              return ir > 0 && ir === ye.length;
            }
            e.isDiskPathRoot = fe;
            function Ee(ye) {
              return B(ye) !== 0;
            }
            e.pathIsAbsolute = Ee;
            function Se(ye) {
              return /^\.\.?($|[\\/])/.test(ye);
            }
            e.pathIsRelative = Se;
            function J(ye) {
              return !Ee(ye) && !Se(ye);
            }
            e.pathIsBareSpecifier = J;
            function se(ye) {
              return e.stringContains(v(ye), ".");
            }
            e.hasExtension = se;
            function Me(ye, ir) {
              return ye.length > ir.length && e.endsWith(ye, ir);
            }
            e.fileExtensionIs = Me;
            function Q(ye, ir) {
              for (var Dr = 0, Pr = ir; Dr < Pr.length; Dr++) {
                var Br = Pr[Dr];
                if (Me(ye, Br))
                  return true;
              }
              return false;
            }
            e.fileExtensionIsOneOf = Q;
            function Be(ye) {
              return ye.length > 0 && s(ye.charCodeAt(ye.length - 1));
            }
            e.hasTrailingDirectorySeparator = Be;
            function je(ye) {
              return ye >= 97 && ye <= 122 || ye >= 65 && ye <= 90;
            }
            function V(ye, ir) {
              var Dr = ye.charCodeAt(ir);
              if (Dr === 58)
                return ir + 1;
              if (Dr === 37 && ye.charCodeAt(ir + 1) === 51) {
                var Pr = ye.charCodeAt(ir + 2);
                if (Pr === 97 || Pr === 65)
                  return ir + 3;
              }
              return -1;
            }
            function B(ye) {
              if (!ye)
                return 0;
              var ir = ye.charCodeAt(0);
              if (ir === 47 || ir === 92) {
                if (ye.charCodeAt(1) !== ir)
                  return 1;
                var Dr = ye.indexOf(ir === 47 ? e.directorySeparator : e.altDirectorySeparator, 2);
                return Dr < 0 ? ye.length : Dr + 1;
              }
              if (je(ir) && ye.charCodeAt(1) === 58) {
                var Pr = ye.charCodeAt(2);
                if (Pr === 47 || Pr === 92)
                  return 3;
                if (ye.length === 2)
                  return 2;
              }
              var Br = ye.indexOf(t3);
              if (Br !== -1) {
                var ut = Br + t3.length, rt = ye.indexOf(e.directorySeparator, ut);
                if (rt !== -1) {
                  var Z = ye.slice(0, Br), f = ye.slice(ut, rt);
                  if (Z === "file" && (f === "" || f === "localhost") && je(ye.charCodeAt(rt + 1))) {
                    var h = V(ye, rt + 2);
                    if (h !== -1) {
                      if (ye.charCodeAt(h) === 47)
                        return ~(h + 1);
                      if (h === ye.length)
                        return ~h;
                    }
                  }
                  return ~(rt + 1);
                }
                return ~ye.length;
              }
              return 0;
            }
            function U(ye) {
              var ir = B(ye);
              return ir < 0 ? ~ir : ir;
            }
            e.getRootLength = U;
            function m(ye) {
              ye = ge(ye);
              var ir = U(ye);
              return ir === ye.length ? ye : (ye = ze(ye), ye.slice(0, Math.max(ir, ye.lastIndexOf(e.directorySeparator))));
            }
            e.getDirectoryPath = m;
            function v(ye, ir, Dr) {
              ye = ge(ye);
              var Pr = U(ye);
              if (Pr === ye.length)
                return "";
              ye = ze(ye);
              var Br = ye.slice(Math.max(U(ye), ye.lastIndexOf(e.directorySeparator) + 1)), ut = ir !== void 0 && Dr !== void 0 ? S(Br, ir, Dr) : void 0;
              return ut ? Br.slice(0, Br.length - ut.length) : Br;
            }
            e.getBaseFileName = v;
            function g(ye, ir, Dr) {
              if (e.startsWith(ir, ".") || (ir = "." + ir), ye.length >= ir.length && ye.charCodeAt(ye.length - ir.length) === 46) {
                var Pr = ye.slice(ye.length - ir.length);
                if (Dr(Pr, ir))
                  return Pr;
              }
            }
            function O(ye, ir, Dr) {
              if (typeof ir == "string")
                return g(ye, ir, Dr) || "";
              for (var Pr = 0, Br = ir; Pr < Br.length; Pr++) {
                var ut = Br[Pr], rt = g(ye, ut, Dr);
                if (rt)
                  return rt;
              }
              return "";
            }
            function S(ye, ir, Dr) {
              if (ir)
                return O(ze(ye), ir, Dr ? e.equateStringsCaseInsensitive : e.equateStringsCaseSensitive);
              var Pr = v(ye), Br = Pr.lastIndexOf(".");
              return Br >= 0 ? Pr.substring(Br) : "";
            }
            e.getAnyExtensionFromPath = S;
            function te(ye, ir) {
              var Dr = ye.substring(0, ir), Pr = ye.substring(ir).split(e.directorySeparator);
              return Pr.length && !e.lastOrUndefined(Pr) && Pr.pop(), D([Dr], Pr, true);
            }
            function Je(ye, ir) {
              return ir === void 0 && (ir = ""), ye = H(ir, ye), te(ye, U(ye));
            }
            e.getPathComponents = Je;
            function qe(ye) {
              if (ye.length === 0)
                return "";
              var ir = ye[0] && ve(ye[0]);
              return ir + ye.slice(1).join(e.directorySeparator);
            }
            e.getPathFromPathComponents = qe;
            function ge(ye) {
              return ye.indexOf("\\") !== -1 ? ye.replace(w, e.directorySeparator) : ye;
            }
            e.normalizeSlashes = ge;
            function ie(ye) {
              if (!e.some(ye))
                return [];
              for (var ir = [ye[0]], Dr = 1; Dr < ye.length; Dr++) {
                var Pr = ye[Dr];
                if (Pr && Pr !== ".") {
                  if (Pr === "..") {
                    if (ir.length > 1) {
                      if (ir[ir.length - 1] !== "..") {
                        ir.pop();
                        continue;
                      }
                    } else if (ir[0])
                      continue;
                  }
                  ir.push(Pr);
                }
              }
              return ir;
            }
            e.reducePathComponents = ie;
            function H(ye) {
              for (var ir = [], Dr = 1; Dr < arguments.length; Dr++)
                ir[Dr - 1] = arguments[Dr];
              ye && (ye = ge(ye));
              for (var Pr = 0, Br = ir; Pr < Br.length; Pr++) {
                var ut = Br[Pr];
                ut && (ut = ge(ut), !ye || U(ut) !== 0 ? ye = ut : ye = ve(ye) + ut);
              }
              return ye;
            }
            e.combinePaths = H;
            function pe(ye) {
              for (var ir = [], Dr = 1; Dr < arguments.length; Dr++)
                ir[Dr - 1] = arguments[Dr];
              return Xe(e.some(ir) ? H.apply(void 0, D([ye], ir, false)) : ge(ye));
            }
            e.resolvePath = pe;
            function j(ye, ir) {
              return ie(Je(ye, ir));
            }
            e.getNormalizedPathComponents = j;
            function be(ye, ir) {
              return qe(j(ye, ir));
            }
            e.getNormalizedAbsolutePath = be;
            function Xe(ye) {
              if (ye = ge(ye), !Cr.test(ye))
                return ye;
              var ir = ye.replace(/\/\.\//g, "/").replace(/^\.\//, "");
              if (ir !== ye && (ye = ir, !Cr.test(ye)))
                return ye;
              var Dr = qe(ie(Je(ye)));
              return Dr && Be(ye) ? ve(Dr) : Dr;
            }
            e.normalizePath = Xe;
            function Re(ye) {
              return ye.length === 0 ? "" : ye.slice(1).join(e.directorySeparator);
            }
            function Fe(ye, ir) {
              return Re(j(ye, ir));
            }
            e.getNormalizedAbsolutePathWithoutRoot = Fe;
            function dr(ye, ir, Dr) {
              var Pr = F(ye) ? Xe(ye) : be(ye, ir);
              return Dr(Pr);
            }
            e.toPath = dr;
            function ze(ye) {
              return Be(ye) ? ye.substr(0, ye.length - 1) : ye;
            }
            e.removeTrailingDirectorySeparator = ze;
            function ve(ye) {
              return Be(ye) ? ye : ye + e.directorySeparator;
            }
            e.ensureTrailingDirectorySeparator = ve;
            function er(ye) {
              return !Ee(ye) && !Se(ye) ? "./" + ye : ye;
            }
            e.ensurePathIsNonModuleName = er;
            function ar(ye, ir, Dr, Pr) {
              var Br = Dr !== void 0 && Pr !== void 0 ? S(ye, Dr, Pr) : S(ye);
              return Br ? ye.slice(0, ye.length - Br.length) + (e.startsWith(ir, ".") ? ir : "." + ir) : ye;
            }
            e.changeAnyExtension = ar;
            var Cr = /(?:\/\/)|(?:^|\/)\.\.?(?:$|\/)/;
            function Ce(ye, ir, Dr) {
              if (ye === ir)
                return 0;
              if (ye === void 0)
                return -1;
              if (ir === void 0)
                return 1;
              var Pr = ye.substring(0, U(ye)), Br = ir.substring(0, U(ir)), ut = e.compareStringsCaseInsensitive(Pr, Br);
              if (ut !== 0)
                return ut;
              var rt = ye.substring(Pr.length), Z = ir.substring(Br.length);
              if (!Cr.test(rt) && !Cr.test(Z))
                return Dr(rt, Z);
              for (var f = ie(Je(ye)), h = ie(Je(ir)), oe = Math.min(f.length, h.length), xr = 1; xr < oe; xr++) {
                var jr = Dr(f[xr], h[xr]);
                if (jr !== 0)
                  return jr;
              }
              return e.compareValues(f.length, h.length);
            }
            function $e(ye, ir) {
              return Ce(ye, ir, e.compareStringsCaseSensitive);
            }
            e.comparePathsCaseSensitive = $e;
            function gr(ye, ir) {
              return Ce(ye, ir, e.compareStringsCaseInsensitive);
            }
            e.comparePathsCaseInsensitive = gr;
            function X(ye, ir, Dr, Pr) {
              return typeof Dr == "string" ? (ye = H(Dr, ye), ir = H(Dr, ir)) : typeof Dr == "boolean" && (Pr = Dr), Ce(ye, ir, e.getStringComparer(Pr));
            }
            e.comparePaths = X;
            function Te(ye, ir, Dr, Pr) {
              if (typeof Dr == "string" ? (ye = H(Dr, ye), ir = H(Dr, ir)) : typeof Dr == "boolean" && (Pr = Dr), ye === void 0 || ir === void 0)
                return false;
              if (ye === ir)
                return true;
              var Br = ie(Je(ye)), ut = ie(Je(ir));
              if (ut.length < Br.length)
                return false;
              for (var rt = Pr ? e.equateStringsCaseInsensitive : e.equateStringsCaseSensitive, Z = 0; Z < Br.length; Z++) {
                var f = Z === 0 ? e.equateStringsCaseInsensitive : rt;
                if (!f(Br[Z], ut[Z]))
                  return false;
              }
              return true;
            }
            e.containsPath = Te;
            function we(ye, ir, Dr) {
              var Pr = Dr(ye), Br = Dr(ir);
              return e.startsWith(Pr, Br + "/") || e.startsWith(Pr, Br + "\\");
            }
            e.startsWithDirectory = we;
            function he(ye, ir, Dr, Pr) {
              var Br = ie(Je(ye)), ut = ie(Je(ir)), rt;
              for (rt = 0; rt < Br.length && rt < ut.length; rt++) {
                var Z = Pr(Br[rt]), f = Pr(ut[rt]), h = rt === 0 ? e.equateStringsCaseInsensitive : Dr;
                if (!h(Z, f))
                  break;
              }
              if (rt === 0)
                return ut;
              for (var oe = ut.slice(rt), xr = []; rt < Br.length; rt++)
                xr.push("..");
              return D(D([""], xr, true), oe, true);
            }
            e.getPathComponentsRelativeTo = he;
            function yr(ye, ir, Dr) {
              e.Debug.assert(U(ye) > 0 == U(ir) > 0, "Paths must either both be absolute or both be relative");
              var Pr = typeof Dr == "function" ? Dr : e.identity, Br = typeof Dr == "boolean" ? Dr : false, ut = he(ye, ir, Br ? e.equateStringsCaseInsensitive : e.equateStringsCaseSensitive, Pr);
              return qe(ut);
            }
            e.getRelativePathFromDirectory = yr;
            function kr(ye, ir, Dr) {
              return F(ye) ? tr(ir, ye, ir, Dr, false) : ye;
            }
            e.convertToRelativePath = kr;
            function nr(ye, ir, Dr) {
              return er(yr(m(ye), ir, Dr));
            }
            e.getRelativePathFromFile = nr;
            function tr(ye, ir, Dr, Pr, Br) {
              var ut = he(pe(Dr, ye), pe(Dr, ir), e.equateStringsCaseSensitive, Pr), rt = ut[0];
              if (Br && F(rt)) {
                var Z = rt.charAt(0) === e.directorySeparator ? "file://" : "file:///";
                ut[0] = Z + rt;
              }
              return qe(ut);
            }
            e.getRelativePathToDirectoryOrUrl = tr;
            function Lr(ye, ir) {
              for (; ; ) {
                var Dr = ir(ye);
                if (Dr !== void 0)
                  return Dr;
                var Pr = m(ye);
                if (Pr === ye)
                  return;
                ye = Pr;
              }
            }
            e.forEachAncestorDirectory = Lr;
            function zr(ye) {
              return e.endsWith(ye, "/node_modules");
            }
            e.isNodeModulesDirectory = zr;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(w, s, q, F, fe, Ee, Se) {
              return { code: w, category: s, key: q, message: F, reportsUnnecessary: fe, elidedInCompatabilityPyramid: Ee, reportsDeprecated: Se };
            }
            e.Diagnostics = { Unterminated_string_literal: t3(1002, e.DiagnosticCategory.Error, "Unterminated_string_literal_1002", "Unterminated string literal."), Identifier_expected: t3(1003, e.DiagnosticCategory.Error, "Identifier_expected_1003", "Identifier expected."), _0_expected: t3(1005, e.DiagnosticCategory.Error, "_0_expected_1005", "'{0}' expected."), A_file_cannot_have_a_reference_to_itself: t3(1006, e.DiagnosticCategory.Error, "A_file_cannot_have_a_reference_to_itself_1006", "A file cannot have a reference to itself."), The_parser_expected_to_find_a_1_to_match_the_0_token_here: t3(1007, e.DiagnosticCategory.Error, "The_parser_expected_to_find_a_1_to_match_the_0_token_here_1007", "The parser expected to find a '{1}' to match the '{0}' token here."), Trailing_comma_not_allowed: t3(1009, e.DiagnosticCategory.Error, "Trailing_comma_not_allowed_1009", "Trailing comma not allowed."), Asterisk_Slash_expected: t3(1010, e.DiagnosticCategory.Error, "Asterisk_Slash_expected_1010", "'*/' expected."), An_element_access_expression_should_take_an_argument: t3(1011, e.DiagnosticCategory.Error, "An_element_access_expression_should_take_an_argument_1011", "An element access expression should take an argument."), Unexpected_token: t3(1012, e.DiagnosticCategory.Error, "Unexpected_token_1012", "Unexpected token."), A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma: t3(1013, e.DiagnosticCategory.Error, "A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma_1013", "A rest parameter or binding pattern may not have a trailing comma."), A_rest_parameter_must_be_last_in_a_parameter_list: t3(1014, e.DiagnosticCategory.Error, "A_rest_parameter_must_be_last_in_a_parameter_list_1014", "A rest parameter must be last in a parameter list."), Parameter_cannot_have_question_mark_and_initializer: t3(1015, e.DiagnosticCategory.Error, "Parameter_cannot_have_question_mark_and_initializer_1015", "Parameter cannot have question mark and initializer."), A_required_parameter_cannot_follow_an_optional_parameter: t3(1016, e.DiagnosticCategory.Error, "A_required_parameter_cannot_follow_an_optional_parameter_1016", "A required parameter cannot follow an optional parameter."), An_index_signature_cannot_have_a_rest_parameter: t3(1017, e.DiagnosticCategory.Error, "An_index_signature_cannot_have_a_rest_parameter_1017", "An index signature cannot have a rest parameter."), An_index_signature_parameter_cannot_have_an_accessibility_modifier: t3(1018, e.DiagnosticCategory.Error, "An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018", "An index signature parameter cannot have an accessibility modifier."), An_index_signature_parameter_cannot_have_a_question_mark: t3(1019, e.DiagnosticCategory.Error, "An_index_signature_parameter_cannot_have_a_question_mark_1019", "An index signature parameter cannot have a question mark."), An_index_signature_parameter_cannot_have_an_initializer: t3(1020, e.DiagnosticCategory.Error, "An_index_signature_parameter_cannot_have_an_initializer_1020", "An index signature parameter cannot have an initializer."), An_index_signature_must_have_a_type_annotation: t3(1021, e.DiagnosticCategory.Error, "An_index_signature_must_have_a_type_annotation_1021", "An index signature must have a type annotation."), An_index_signature_parameter_must_have_a_type_annotation: t3(1022, e.DiagnosticCategory.Error, "An_index_signature_parameter_must_have_a_type_annotation_1022", "An index signature parameter must have a type annotation."), readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature: t3(1024, e.DiagnosticCategory.Error, "readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature_1024", "'readonly' modifier can only appear on a property declaration or index signature."), An_index_signature_cannot_have_a_trailing_comma: t3(1025, e.DiagnosticCategory.Error, "An_index_signature_cannot_have_a_trailing_comma_1025", "An index signature cannot have a trailing comma."), Accessibility_modifier_already_seen: t3(1028, e.DiagnosticCategory.Error, "Accessibility_modifier_already_seen_1028", "Accessibility modifier already seen."), _0_modifier_must_precede_1_modifier: t3(1029, e.DiagnosticCategory.Error, "_0_modifier_must_precede_1_modifier_1029", "'{0}' modifier must precede '{1}' modifier."), _0_modifier_already_seen: t3(1030, e.DiagnosticCategory.Error, "_0_modifier_already_seen_1030", "'{0}' modifier already seen."), _0_modifier_cannot_appear_on_class_elements_of_this_kind: t3(1031, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_class_elements_of_this_kind_1031", "'{0}' modifier cannot appear on class elements of this kind."), super_must_be_followed_by_an_argument_list_or_member_access: t3(1034, e.DiagnosticCategory.Error, "super_must_be_followed_by_an_argument_list_or_member_access_1034", "'super' must be followed by an argument list or member access."), Only_ambient_modules_can_use_quoted_names: t3(1035, e.DiagnosticCategory.Error, "Only_ambient_modules_can_use_quoted_names_1035", "Only ambient modules can use quoted names."), Statements_are_not_allowed_in_ambient_contexts: t3(1036, e.DiagnosticCategory.Error, "Statements_are_not_allowed_in_ambient_contexts_1036", "Statements are not allowed in ambient contexts."), A_declare_modifier_cannot_be_used_in_an_already_ambient_context: t3(1038, e.DiagnosticCategory.Error, "A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038", "A 'declare' modifier cannot be used in an already ambient context."), Initializers_are_not_allowed_in_ambient_contexts: t3(1039, e.DiagnosticCategory.Error, "Initializers_are_not_allowed_in_ambient_contexts_1039", "Initializers are not allowed in ambient contexts."), _0_modifier_cannot_be_used_in_an_ambient_context: t3(1040, e.DiagnosticCategory.Error, "_0_modifier_cannot_be_used_in_an_ambient_context_1040", "'{0}' modifier cannot be used in an ambient context."), _0_modifier_cannot_be_used_here: t3(1042, e.DiagnosticCategory.Error, "_0_modifier_cannot_be_used_here_1042", "'{0}' modifier cannot be used here."), _0_modifier_cannot_appear_on_a_module_or_namespace_element: t3(1044, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_a_module_or_namespace_element_1044", "'{0}' modifier cannot appear on a module or namespace element."), Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier: t3(1046, e.DiagnosticCategory.Error, "Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier_1046", "Top-level declarations in .d.ts files must start with either a 'declare' or 'export' modifier."), A_rest_parameter_cannot_be_optional: t3(1047, e.DiagnosticCategory.Error, "A_rest_parameter_cannot_be_optional_1047", "A rest parameter cannot be optional."), A_rest_parameter_cannot_have_an_initializer: t3(1048, e.DiagnosticCategory.Error, "A_rest_parameter_cannot_have_an_initializer_1048", "A rest parameter cannot have an initializer."), A_set_accessor_must_have_exactly_one_parameter: t3(1049, e.DiagnosticCategory.Error, "A_set_accessor_must_have_exactly_one_parameter_1049", "A 'set' accessor must have exactly one parameter."), A_set_accessor_cannot_have_an_optional_parameter: t3(1051, e.DiagnosticCategory.Error, "A_set_accessor_cannot_have_an_optional_parameter_1051", "A 'set' accessor cannot have an optional parameter."), A_set_accessor_parameter_cannot_have_an_initializer: t3(1052, e.DiagnosticCategory.Error, "A_set_accessor_parameter_cannot_have_an_initializer_1052", "A 'set' accessor parameter cannot have an initializer."), A_set_accessor_cannot_have_rest_parameter: t3(1053, e.DiagnosticCategory.Error, "A_set_accessor_cannot_have_rest_parameter_1053", "A 'set' accessor cannot have rest parameter."), A_get_accessor_cannot_have_parameters: t3(1054, e.DiagnosticCategory.Error, "A_get_accessor_cannot_have_parameters_1054", "A 'get' accessor cannot have parameters."), Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value: t3(1055, e.DiagnosticCategory.Error, "Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Prom_1055", "Type '{0}' is not a valid async function return type in ES5/ES3 because it does not refer to a Promise-compatible constructor value."), Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher: t3(1056, e.DiagnosticCategory.Error, "Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056", "Accessors are only available when targeting ECMAScript 5 and higher."), The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: t3(1058, e.DiagnosticCategory.Error, "The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_t_1058", "The return type of an async function must either be a valid promise or must not contain a callable 'then' member."), A_promise_must_have_a_then_method: t3(1059, e.DiagnosticCategory.Error, "A_promise_must_have_a_then_method_1059", "A promise must have a 'then' method."), The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback: t3(1060, e.DiagnosticCategory.Error, "The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback_1060", "The first parameter of the 'then' method of a promise must be a callback."), Enum_member_must_have_initializer: t3(1061, e.DiagnosticCategory.Error, "Enum_member_must_have_initializer_1061", "Enum member must have initializer."), Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method: t3(1062, e.DiagnosticCategory.Error, "Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062", "Type is referenced directly or indirectly in the fulfillment callback of its own 'then' method."), An_export_assignment_cannot_be_used_in_a_namespace: t3(1063, e.DiagnosticCategory.Error, "An_export_assignment_cannot_be_used_in_a_namespace_1063", "An export assignment cannot be used in a namespace."), The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0: t3(1064, e.DiagnosticCategory.Error, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_wri_1064", "The return type of an async function or method must be the global Promise<T> type. Did you mean to write 'Promise<{0}>'?"), In_ambient_enum_declarations_member_initializer_must_be_constant_expression: t3(1066, e.DiagnosticCategory.Error, "In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066", "In ambient enum declarations member initializer must be constant expression."), Unexpected_token_A_constructor_method_accessor_or_property_was_expected: t3(1068, e.DiagnosticCategory.Error, "Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068", "Unexpected token. A constructor, method, accessor, or property was expected."), Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces: t3(1069, e.DiagnosticCategory.Error, "Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces_1069", "Unexpected token. A type parameter name was expected without curly braces."), _0_modifier_cannot_appear_on_a_type_member: t3(1070, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_a_type_member_1070", "'{0}' modifier cannot appear on a type member."), _0_modifier_cannot_appear_on_an_index_signature: t3(1071, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_an_index_signature_1071", "'{0}' modifier cannot appear on an index signature."), A_0_modifier_cannot_be_used_with_an_import_declaration: t3(1079, e.DiagnosticCategory.Error, "A_0_modifier_cannot_be_used_with_an_import_declaration_1079", "A '{0}' modifier cannot be used with an import declaration."), Invalid_reference_directive_syntax: t3(1084, e.DiagnosticCategory.Error, "Invalid_reference_directive_syntax_1084", "Invalid 'reference' directive syntax."), Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0: t3(1085, e.DiagnosticCategory.Error, "Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0_1085", "Octal literals are not available when targeting ECMAScript 5 and higher. Use the syntax '{0}'."), _0_modifier_cannot_appear_on_a_constructor_declaration: t3(1089, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_a_constructor_declaration_1089", "'{0}' modifier cannot appear on a constructor declaration."), _0_modifier_cannot_appear_on_a_parameter: t3(1090, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_a_parameter_1090", "'{0}' modifier cannot appear on a parameter."), Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement: t3(1091, e.DiagnosticCategory.Error, "Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091", "Only a single variable declaration is allowed in a 'for...in' statement."), Type_parameters_cannot_appear_on_a_constructor_declaration: t3(1092, e.DiagnosticCategory.Error, "Type_parameters_cannot_appear_on_a_constructor_declaration_1092", "Type parameters cannot appear on a constructor declaration."), Type_annotation_cannot_appear_on_a_constructor_declaration: t3(1093, e.DiagnosticCategory.Error, "Type_annotation_cannot_appear_on_a_constructor_declaration_1093", "Type annotation cannot appear on a constructor declaration."), An_accessor_cannot_have_type_parameters: t3(1094, e.DiagnosticCategory.Error, "An_accessor_cannot_have_type_parameters_1094", "An accessor cannot have type parameters."), A_set_accessor_cannot_have_a_return_type_annotation: t3(1095, e.DiagnosticCategory.Error, "A_set_accessor_cannot_have_a_return_type_annotation_1095", "A 'set' accessor cannot have a return type annotation."), An_index_signature_must_have_exactly_one_parameter: t3(1096, e.DiagnosticCategory.Error, "An_index_signature_must_have_exactly_one_parameter_1096", "An index signature must have exactly one parameter."), _0_list_cannot_be_empty: t3(1097, e.DiagnosticCategory.Error, "_0_list_cannot_be_empty_1097", "'{0}' list cannot be empty."), Type_parameter_list_cannot_be_empty: t3(1098, e.DiagnosticCategory.Error, "Type_parameter_list_cannot_be_empty_1098", "Type parameter list cannot be empty."), Type_argument_list_cannot_be_empty: t3(1099, e.DiagnosticCategory.Error, "Type_argument_list_cannot_be_empty_1099", "Type argument list cannot be empty."), Invalid_use_of_0_in_strict_mode: t3(1100, e.DiagnosticCategory.Error, "Invalid_use_of_0_in_strict_mode_1100", "Invalid use of '{0}' in strict mode."), with_statements_are_not_allowed_in_strict_mode: t3(1101, e.DiagnosticCategory.Error, "with_statements_are_not_allowed_in_strict_mode_1101", "'with' statements are not allowed in strict mode."), delete_cannot_be_called_on_an_identifier_in_strict_mode: t3(1102, e.DiagnosticCategory.Error, "delete_cannot_be_called_on_an_identifier_in_strict_mode_1102", "'delete' cannot be called on an identifier in strict mode."), for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: t3(1103, e.DiagnosticCategory.Error, "for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1103", "'for await' loops are only allowed within async functions and at the top levels of modules."), A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement: t3(1104, e.DiagnosticCategory.Error, "A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104", "A 'continue' statement can only be used within an enclosing iteration statement."), A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement: t3(1105, e.DiagnosticCategory.Error, "A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105", "A 'break' statement can only be used within an enclosing iteration or switch statement."), The_left_hand_side_of_a_for_of_statement_may_not_be_async: t3(1106, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_of_statement_may_not_be_async_1106", "The left-hand side of a 'for...of' statement may not be 'async'."), Jump_target_cannot_cross_function_boundary: t3(1107, e.DiagnosticCategory.Error, "Jump_target_cannot_cross_function_boundary_1107", "Jump target cannot cross function boundary."), A_return_statement_can_only_be_used_within_a_function_body: t3(1108, e.DiagnosticCategory.Error, "A_return_statement_can_only_be_used_within_a_function_body_1108", "A 'return' statement can only be used within a function body."), Expression_expected: t3(1109, e.DiagnosticCategory.Error, "Expression_expected_1109", "Expression expected."), Type_expected: t3(1110, e.DiagnosticCategory.Error, "Type_expected_1110", "Type expected."), A_default_clause_cannot_appear_more_than_once_in_a_switch_statement: t3(1113, e.DiagnosticCategory.Error, "A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113", "A 'default' clause cannot appear more than once in a 'switch' statement."), Duplicate_label_0: t3(1114, e.DiagnosticCategory.Error, "Duplicate_label_0_1114", "Duplicate label '{0}'."), A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement: t3(1115, e.DiagnosticCategory.Error, "A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115", "A 'continue' statement can only jump to a label of an enclosing iteration statement."), A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement: t3(1116, e.DiagnosticCategory.Error, "A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116", "A 'break' statement can only jump to a label of an enclosing statement."), An_object_literal_cannot_have_multiple_properties_with_the_same_name: t3(1117, e.DiagnosticCategory.Error, "An_object_literal_cannot_have_multiple_properties_with_the_same_name_1117", "An object literal cannot have multiple properties with the same name."), An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name: t3(1118, e.DiagnosticCategory.Error, "An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118", "An object literal cannot have multiple get/set accessors with the same name."), An_object_literal_cannot_have_property_and_accessor_with_the_same_name: t3(1119, e.DiagnosticCategory.Error, "An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119", "An object literal cannot have property and accessor with the same name."), An_export_assignment_cannot_have_modifiers: t3(1120, e.DiagnosticCategory.Error, "An_export_assignment_cannot_have_modifiers_1120", "An export assignment cannot have modifiers."), Octal_literals_are_not_allowed_in_strict_mode: t3(1121, e.DiagnosticCategory.Error, "Octal_literals_are_not_allowed_in_strict_mode_1121", "Octal literals are not allowed in strict mode."), Variable_declaration_list_cannot_be_empty: t3(1123, e.DiagnosticCategory.Error, "Variable_declaration_list_cannot_be_empty_1123", "Variable declaration list cannot be empty."), Digit_expected: t3(1124, e.DiagnosticCategory.Error, "Digit_expected_1124", "Digit expected."), Hexadecimal_digit_expected: t3(1125, e.DiagnosticCategory.Error, "Hexadecimal_digit_expected_1125", "Hexadecimal digit expected."), Unexpected_end_of_text: t3(1126, e.DiagnosticCategory.Error, "Unexpected_end_of_text_1126", "Unexpected end of text."), Invalid_character: t3(1127, e.DiagnosticCategory.Error, "Invalid_character_1127", "Invalid character."), Declaration_or_statement_expected: t3(1128, e.DiagnosticCategory.Error, "Declaration_or_statement_expected_1128", "Declaration or statement expected."), Statement_expected: t3(1129, e.DiagnosticCategory.Error, "Statement_expected_1129", "Statement expected."), case_or_default_expected: t3(1130, e.DiagnosticCategory.Error, "case_or_default_expected_1130", "'case' or 'default' expected."), Property_or_signature_expected: t3(1131, e.DiagnosticCategory.Error, "Property_or_signature_expected_1131", "Property or signature expected."), Enum_member_expected: t3(1132, e.DiagnosticCategory.Error, "Enum_member_expected_1132", "Enum member expected."), Variable_declaration_expected: t3(1134, e.DiagnosticCategory.Error, "Variable_declaration_expected_1134", "Variable declaration expected."), Argument_expression_expected: t3(1135, e.DiagnosticCategory.Error, "Argument_expression_expected_1135", "Argument expression expected."), Property_assignment_expected: t3(1136, e.DiagnosticCategory.Error, "Property_assignment_expected_1136", "Property assignment expected."), Expression_or_comma_expected: t3(1137, e.DiagnosticCategory.Error, "Expression_or_comma_expected_1137", "Expression or comma expected."), Parameter_declaration_expected: t3(1138, e.DiagnosticCategory.Error, "Parameter_declaration_expected_1138", "Parameter declaration expected."), Type_parameter_declaration_expected: t3(1139, e.DiagnosticCategory.Error, "Type_parameter_declaration_expected_1139", "Type parameter declaration expected."), Type_argument_expected: t3(1140, e.DiagnosticCategory.Error, "Type_argument_expected_1140", "Type argument expected."), String_literal_expected: t3(1141, e.DiagnosticCategory.Error, "String_literal_expected_1141", "String literal expected."), Line_break_not_permitted_here: t3(1142, e.DiagnosticCategory.Error, "Line_break_not_permitted_here_1142", "Line break not permitted here."), or_expected: t3(1144, e.DiagnosticCategory.Error, "or_expected_1144", "'{' or ';' expected."), or_JSX_element_expected: t3(1145, e.DiagnosticCategory.Error, "or_JSX_element_expected_1145", "'{' or JSX element expected."), Declaration_expected: t3(1146, e.DiagnosticCategory.Error, "Declaration_expected_1146", "Declaration expected."), Import_declarations_in_a_namespace_cannot_reference_a_module: t3(1147, e.DiagnosticCategory.Error, "Import_declarations_in_a_namespace_cannot_reference_a_module_1147", "Import declarations in a namespace cannot reference a module."), Cannot_use_imports_exports_or_module_augmentations_when_module_is_none: t3(1148, e.DiagnosticCategory.Error, "Cannot_use_imports_exports_or_module_augmentations_when_module_is_none_1148", "Cannot use imports, exports, or module augmentations when '--module' is 'none'."), File_name_0_differs_from_already_included_file_name_1_only_in_casing: t3(1149, e.DiagnosticCategory.Error, "File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149", "File name '{0}' differs from already included file name '{1}' only in casing."), const_declarations_must_be_initialized: t3(1155, e.DiagnosticCategory.Error, "const_declarations_must_be_initialized_1155", "'const' declarations must be initialized."), const_declarations_can_only_be_declared_inside_a_block: t3(1156, e.DiagnosticCategory.Error, "const_declarations_can_only_be_declared_inside_a_block_1156", "'const' declarations can only be declared inside a block."), let_declarations_can_only_be_declared_inside_a_block: t3(1157, e.DiagnosticCategory.Error, "let_declarations_can_only_be_declared_inside_a_block_1157", "'let' declarations can only be declared inside a block."), Unterminated_template_literal: t3(1160, e.DiagnosticCategory.Error, "Unterminated_template_literal_1160", "Unterminated template literal."), Unterminated_regular_expression_literal: t3(1161, e.DiagnosticCategory.Error, "Unterminated_regular_expression_literal_1161", "Unterminated regular expression literal."), An_object_member_cannot_be_declared_optional: t3(1162, e.DiagnosticCategory.Error, "An_object_member_cannot_be_declared_optional_1162", "An object member cannot be declared optional."), A_yield_expression_is_only_allowed_in_a_generator_body: t3(1163, e.DiagnosticCategory.Error, "A_yield_expression_is_only_allowed_in_a_generator_body_1163", "A 'yield' expression is only allowed in a generator body."), Computed_property_names_are_not_allowed_in_enums: t3(1164, e.DiagnosticCategory.Error, "Computed_property_names_are_not_allowed_in_enums_1164", "Computed property names are not allowed in enums."), A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: t3(1165, e.DiagnosticCategory.Error, "A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_t_1165", "A computed property name in an ambient context must refer to an expression whose type is a literal type or a 'unique symbol' type."), A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type: t3(1166, e.DiagnosticCategory.Error, "A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_1166", "A computed property name in a class property declaration must have a simple literal type or a 'unique symbol' type."), A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: t3(1168, e.DiagnosticCategory.Error, "A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_ty_1168", "A computed property name in a method overload must refer to an expression whose type is a literal type or a 'unique symbol' type."), A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: t3(1169, e.DiagnosticCategory.Error, "A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_1169", "A computed property name in an interface must refer to an expression whose type is a literal type or a 'unique symbol' type."), A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: t3(1170, e.DiagnosticCategory.Error, "A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type__1170", "A computed property name in a type literal must refer to an expression whose type is a literal type or a 'unique symbol' type."), A_comma_expression_is_not_allowed_in_a_computed_property_name: t3(1171, e.DiagnosticCategory.Error, "A_comma_expression_is_not_allowed_in_a_computed_property_name_1171", "A comma expression is not allowed in a computed property name."), extends_clause_already_seen: t3(1172, e.DiagnosticCategory.Error, "extends_clause_already_seen_1172", "'extends' clause already seen."), extends_clause_must_precede_implements_clause: t3(1173, e.DiagnosticCategory.Error, "extends_clause_must_precede_implements_clause_1173", "'extends' clause must precede 'implements' clause."), Classes_can_only_extend_a_single_class: t3(1174, e.DiagnosticCategory.Error, "Classes_can_only_extend_a_single_class_1174", "Classes can only extend a single class."), implements_clause_already_seen: t3(1175, e.DiagnosticCategory.Error, "implements_clause_already_seen_1175", "'implements' clause already seen."), Interface_declaration_cannot_have_implements_clause: t3(1176, e.DiagnosticCategory.Error, "Interface_declaration_cannot_have_implements_clause_1176", "Interface declaration cannot have 'implements' clause."), Binary_digit_expected: t3(1177, e.DiagnosticCategory.Error, "Binary_digit_expected_1177", "Binary digit expected."), Octal_digit_expected: t3(1178, e.DiagnosticCategory.Error, "Octal_digit_expected_1178", "Octal digit expected."), Unexpected_token_expected: t3(1179, e.DiagnosticCategory.Error, "Unexpected_token_expected_1179", "Unexpected token. '{' expected."), Property_destructuring_pattern_expected: t3(1180, e.DiagnosticCategory.Error, "Property_destructuring_pattern_expected_1180", "Property destructuring pattern expected."), Array_element_destructuring_pattern_expected: t3(1181, e.DiagnosticCategory.Error, "Array_element_destructuring_pattern_expected_1181", "Array element destructuring pattern expected."), A_destructuring_declaration_must_have_an_initializer: t3(1182, e.DiagnosticCategory.Error, "A_destructuring_declaration_must_have_an_initializer_1182", "A destructuring declaration must have an initializer."), An_implementation_cannot_be_declared_in_ambient_contexts: t3(1183, e.DiagnosticCategory.Error, "An_implementation_cannot_be_declared_in_ambient_contexts_1183", "An implementation cannot be declared in ambient contexts."), Modifiers_cannot_appear_here: t3(1184, e.DiagnosticCategory.Error, "Modifiers_cannot_appear_here_1184", "Modifiers cannot appear here."), Merge_conflict_marker_encountered: t3(1185, e.DiagnosticCategory.Error, "Merge_conflict_marker_encountered_1185", "Merge conflict marker encountered."), A_rest_element_cannot_have_an_initializer: t3(1186, e.DiagnosticCategory.Error, "A_rest_element_cannot_have_an_initializer_1186", "A rest element cannot have an initializer."), A_parameter_property_may_not_be_declared_using_a_binding_pattern: t3(1187, e.DiagnosticCategory.Error, "A_parameter_property_may_not_be_declared_using_a_binding_pattern_1187", "A parameter property may not be declared using a binding pattern."), Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement: t3(1188, e.DiagnosticCategory.Error, "Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188", "Only a single variable declaration is allowed in a 'for...of' statement."), The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer: t3(1189, e.DiagnosticCategory.Error, "The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189", "The variable declaration of a 'for...in' statement cannot have an initializer."), The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer: t3(1190, e.DiagnosticCategory.Error, "The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190", "The variable declaration of a 'for...of' statement cannot have an initializer."), An_import_declaration_cannot_have_modifiers: t3(1191, e.DiagnosticCategory.Error, "An_import_declaration_cannot_have_modifiers_1191", "An import declaration cannot have modifiers."), Module_0_has_no_default_export: t3(1192, e.DiagnosticCategory.Error, "Module_0_has_no_default_export_1192", "Module '{0}' has no default export."), An_export_declaration_cannot_have_modifiers: t3(1193, e.DiagnosticCategory.Error, "An_export_declaration_cannot_have_modifiers_1193", "An export declaration cannot have modifiers."), Export_declarations_are_not_permitted_in_a_namespace: t3(1194, e.DiagnosticCategory.Error, "Export_declarations_are_not_permitted_in_a_namespace_1194", "Export declarations are not permitted in a namespace."), export_Asterisk_does_not_re_export_a_default: t3(1195, e.DiagnosticCategory.Error, "export_Asterisk_does_not_re_export_a_default_1195", "'export *' does not re-export a default."), Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified: t3(1196, e.DiagnosticCategory.Error, "Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified_1196", "Catch clause variable type annotation must be 'any' or 'unknown' if specified."), Catch_clause_variable_cannot_have_an_initializer: t3(1197, e.DiagnosticCategory.Error, "Catch_clause_variable_cannot_have_an_initializer_1197", "Catch clause variable cannot have an initializer."), An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive: t3(1198, e.DiagnosticCategory.Error, "An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198", "An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive."), Unterminated_Unicode_escape_sequence: t3(1199, e.DiagnosticCategory.Error, "Unterminated_Unicode_escape_sequence_1199", "Unterminated Unicode escape sequence."), Line_terminator_not_permitted_before_arrow: t3(1200, e.DiagnosticCategory.Error, "Line_terminator_not_permitted_before_arrow_1200", "Line terminator not permitted before arrow."), Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead: t3(1202, e.DiagnosticCategory.Error, "Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_1202", `Import assignment cannot be used when targeting ECMAScript modules. Consider using 'import * as ns from "mod"', 'import {a} from "mod"', 'import d from "mod"', or another module format instead.`), Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead: t3(1203, e.DiagnosticCategory.Error, "Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or__1203", "Export assignment cannot be used when targeting ECMAScript modules. Consider using 'export default' or another module format instead."), Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type: t3(1205, e.DiagnosticCategory.Error, "Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type_1205", "Re-exporting a type when the '--isolatedModules' flag is provided requires using 'export type'."), Decorators_are_not_valid_here: t3(1206, e.DiagnosticCategory.Error, "Decorators_are_not_valid_here_1206", "Decorators are not valid here."), Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name: t3(1207, e.DiagnosticCategory.Error, "Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207", "Decorators cannot be applied to multiple get/set accessors of the same name."), _0_cannot_be_compiled_under_isolatedModules_because_it_is_considered_a_global_script_file_Add_an_import_export_or_an_empty_export_statement_to_make_it_a_module: t3(1208, e.DiagnosticCategory.Error, "_0_cannot_be_compiled_under_isolatedModules_because_it_is_considered_a_global_script_file_Add_an_imp_1208", "'{0}' cannot be compiled under '--isolatedModules' because it is considered a global script file. Add an import, export, or an empty 'export {}' statement to make it a module."), Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0: t3(1209, e.DiagnosticCategory.Error, "Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0_1209", "Invalid optional chain from new expression. Did you mean to call '{0}()'?"), Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode: t3(1210, e.DiagnosticCategory.Error, "Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of__1210", "Code contained in a class is evaluated in JavaScript's strict mode which does not allow this use of '{0}'. For more information, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Strict_mode."), A_class_declaration_without_the_default_modifier_must_have_a_name: t3(1211, e.DiagnosticCategory.Error, "A_class_declaration_without_the_default_modifier_must_have_a_name_1211", "A class declaration without the 'default' modifier must have a name."), Identifier_expected_0_is_a_reserved_word_in_strict_mode: t3(1212, e.DiagnosticCategory.Error, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212", "Identifier expected. '{0}' is a reserved word in strict mode."), Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode: t3(1213, e.DiagnosticCategory.Error, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213", "Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode."), Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode: t3(1214, e.DiagnosticCategory.Error, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214", "Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode."), Invalid_use_of_0_Modules_are_automatically_in_strict_mode: t3(1215, e.DiagnosticCategory.Error, "Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215", "Invalid use of '{0}'. Modules are automatically in strict mode."), Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules: t3(1216, e.DiagnosticCategory.Error, "Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules_1216", "Identifier expected. '__esModule' is reserved as an exported marker when transforming ECMAScript modules."), Export_assignment_is_not_supported_when_module_flag_is_system: t3(1218, e.DiagnosticCategory.Error, "Export_assignment_is_not_supported_when_module_flag_is_system_1218", "Export assignment is not supported when '--module' flag is 'system'."), Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_in_your_tsconfig_or_jsconfig_to_remove_this_warning: t3(1219, e.DiagnosticCategory.Error, "Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_t_1219", "Experimental support for decorators is a feature that is subject to change in a future release. Set the 'experimentalDecorators' option in your 'tsconfig' or 'jsconfig' to remove this warning."), Generators_are_not_allowed_in_an_ambient_context: t3(1221, e.DiagnosticCategory.Error, "Generators_are_not_allowed_in_an_ambient_context_1221", "Generators are not allowed in an ambient context."), An_overload_signature_cannot_be_declared_as_a_generator: t3(1222, e.DiagnosticCategory.Error, "An_overload_signature_cannot_be_declared_as_a_generator_1222", "An overload signature cannot be declared as a generator."), _0_tag_already_specified: t3(1223, e.DiagnosticCategory.Error, "_0_tag_already_specified_1223", "'{0}' tag already specified."), Signature_0_must_be_a_type_predicate: t3(1224, e.DiagnosticCategory.Error, "Signature_0_must_be_a_type_predicate_1224", "Signature '{0}' must be a type predicate."), Cannot_find_parameter_0: t3(1225, e.DiagnosticCategory.Error, "Cannot_find_parameter_0_1225", "Cannot find parameter '{0}'."), Type_predicate_0_is_not_assignable_to_1: t3(1226, e.DiagnosticCategory.Error, "Type_predicate_0_is_not_assignable_to_1_1226", "Type predicate '{0}' is not assignable to '{1}'."), Parameter_0_is_not_in_the_same_position_as_parameter_1: t3(1227, e.DiagnosticCategory.Error, "Parameter_0_is_not_in_the_same_position_as_parameter_1_1227", "Parameter '{0}' is not in the same position as parameter '{1}'."), A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods: t3(1228, e.DiagnosticCategory.Error, "A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228", "A type predicate is only allowed in return type position for functions and methods."), A_type_predicate_cannot_reference_a_rest_parameter: t3(1229, e.DiagnosticCategory.Error, "A_type_predicate_cannot_reference_a_rest_parameter_1229", "A type predicate cannot reference a rest parameter."), A_type_predicate_cannot_reference_element_0_in_a_binding_pattern: t3(1230, e.DiagnosticCategory.Error, "A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230", "A type predicate cannot reference element '{0}' in a binding pattern."), An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration: t3(1231, e.DiagnosticCategory.Error, "An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration_1231", "An export assignment must be at the top level of a file or module declaration."), An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: t3(1232, e.DiagnosticCategory.Error, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1232", "An import declaration can only be used at the top level of a namespace or module."), An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: t3(1233, e.DiagnosticCategory.Error, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1233", "An export declaration can only be used at the top level of a namespace or module."), An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file: t3(1234, e.DiagnosticCategory.Error, "An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234", "An ambient module declaration is only allowed at the top level in a file."), A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module: t3(1235, e.DiagnosticCategory.Error, "A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module_1235", "A namespace declaration is only allowed at the top level of a namespace or module."), The_return_type_of_a_property_decorator_function_must_be_either_void_or_any: t3(1236, e.DiagnosticCategory.Error, "The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236", "The return type of a property decorator function must be either 'void' or 'any'."), The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any: t3(1237, e.DiagnosticCategory.Error, "The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237", "The return type of a parameter decorator function must be either 'void' or 'any'."), Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression: t3(1238, e.DiagnosticCategory.Error, "Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238", "Unable to resolve signature of class decorator when called as an expression."), Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression: t3(1239, e.DiagnosticCategory.Error, "Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239", "Unable to resolve signature of parameter decorator when called as an expression."), Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression: t3(1240, e.DiagnosticCategory.Error, "Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240", "Unable to resolve signature of property decorator when called as an expression."), Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression: t3(1241, e.DiagnosticCategory.Error, "Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241", "Unable to resolve signature of method decorator when called as an expression."), abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration: t3(1242, e.DiagnosticCategory.Error, "abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration_1242", "'abstract' modifier can only appear on a class, method, or property declaration."), _0_modifier_cannot_be_used_with_1_modifier: t3(1243, e.DiagnosticCategory.Error, "_0_modifier_cannot_be_used_with_1_modifier_1243", "'{0}' modifier cannot be used with '{1}' modifier."), Abstract_methods_can_only_appear_within_an_abstract_class: t3(1244, e.DiagnosticCategory.Error, "Abstract_methods_can_only_appear_within_an_abstract_class_1244", "Abstract methods can only appear within an abstract class."), Method_0_cannot_have_an_implementation_because_it_is_marked_abstract: t3(1245, e.DiagnosticCategory.Error, "Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245", "Method '{0}' cannot have an implementation because it is marked abstract."), An_interface_property_cannot_have_an_initializer: t3(1246, e.DiagnosticCategory.Error, "An_interface_property_cannot_have_an_initializer_1246", "An interface property cannot have an initializer."), A_type_literal_property_cannot_have_an_initializer: t3(1247, e.DiagnosticCategory.Error, "A_type_literal_property_cannot_have_an_initializer_1247", "A type literal property cannot have an initializer."), A_class_member_cannot_have_the_0_keyword: t3(1248, e.DiagnosticCategory.Error, "A_class_member_cannot_have_the_0_keyword_1248", "A class member cannot have the '{0}' keyword."), A_decorator_can_only_decorate_a_method_implementation_not_an_overload: t3(1249, e.DiagnosticCategory.Error, "A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249", "A decorator can only decorate a method implementation, not an overload."), Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5: t3(1250, e.DiagnosticCategory.Error, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_1250", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'."), Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode: t3(1251, e.DiagnosticCategory.Error, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_d_1251", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Class definitions are automatically in strict mode."), Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode: t3(1252, e.DiagnosticCategory.Error, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_1252", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Modules are automatically in strict mode."), A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference: t3(1254, e.DiagnosticCategory.Error, "A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_refere_1254", "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference."), A_definite_assignment_assertion_is_not_permitted_in_this_context: t3(1255, e.DiagnosticCategory.Error, "A_definite_assignment_assertion_is_not_permitted_in_this_context_1255", "A definite assignment assertion '!' is not permitted in this context."), A_required_element_cannot_follow_an_optional_element: t3(1257, e.DiagnosticCategory.Error, "A_required_element_cannot_follow_an_optional_element_1257", "A required element cannot follow an optional element."), A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration: t3(1258, e.DiagnosticCategory.Error, "A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration_1258", "A default export must be at the top level of a file or module declaration."), Module_0_can_only_be_default_imported_using_the_1_flag: t3(1259, e.DiagnosticCategory.Error, "Module_0_can_only_be_default_imported_using_the_1_flag_1259", "Module '{0}' can only be default-imported using the '{1}' flag"), Keywords_cannot_contain_escape_characters: t3(1260, e.DiagnosticCategory.Error, "Keywords_cannot_contain_escape_characters_1260", "Keywords cannot contain escape characters."), Already_included_file_name_0_differs_from_file_name_1_only_in_casing: t3(1261, e.DiagnosticCategory.Error, "Already_included_file_name_0_differs_from_file_name_1_only_in_casing_1261", "Already included file name '{0}' differs from file name '{1}' only in casing."), Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module: t3(1262, e.DiagnosticCategory.Error, "Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module_1262", "Identifier expected. '{0}' is a reserved word at the top-level of a module."), Declarations_with_initializers_cannot_also_have_definite_assignment_assertions: t3(1263, e.DiagnosticCategory.Error, "Declarations_with_initializers_cannot_also_have_definite_assignment_assertions_1263", "Declarations with initializers cannot also have definite assignment assertions."), Declarations_with_definite_assignment_assertions_must_also_have_type_annotations: t3(1264, e.DiagnosticCategory.Error, "Declarations_with_definite_assignment_assertions_must_also_have_type_annotations_1264", "Declarations with definite assignment assertions must also have type annotations."), A_rest_element_cannot_follow_another_rest_element: t3(1265, e.DiagnosticCategory.Error, "A_rest_element_cannot_follow_another_rest_element_1265", "A rest element cannot follow another rest element."), An_optional_element_cannot_follow_a_rest_element: t3(1266, e.DiagnosticCategory.Error, "An_optional_element_cannot_follow_a_rest_element_1266", "An optional element cannot follow a rest element."), Property_0_cannot_have_an_initializer_because_it_is_marked_abstract: t3(1267, e.DiagnosticCategory.Error, "Property_0_cannot_have_an_initializer_because_it_is_marked_abstract_1267", "Property '{0}' cannot have an initializer because it is marked abstract."), An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type: t3(1268, e.DiagnosticCategory.Error, "An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type_1268", "An index signature parameter type must be 'string', 'number', 'symbol', or a template literal type."), Cannot_use_export_import_on_a_type_or_type_only_namespace_when_the_isolatedModules_flag_is_provided: t3(1269, e.DiagnosticCategory.Error, "Cannot_use_export_import_on_a_type_or_type_only_namespace_when_the_isolatedModules_flag_is_provided_1269", "Cannot use 'export import' on a type or type-only namespace when the '--isolatedModules' flag is provided."), Decorator_function_return_type_0_is_not_assignable_to_type_1: t3(1270, e.DiagnosticCategory.Error, "Decorator_function_return_type_0_is_not_assignable_to_type_1_1270", "Decorator function return type '{0}' is not assignable to type '{1}'."), Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any: t3(1271, e.DiagnosticCategory.Error, "Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any_1271", "Decorator function return type is '{0}' but is expected to be 'void' or 'any'."), A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled: t3(1272, e.DiagnosticCategory.Error, "A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_w_1272", "A type referenced in a decorated signature must be imported with 'import type' or a namespace import when 'isolatedModules' and 'emitDecoratorMetadata' are enabled."), _0_modifier_cannot_appear_on_a_type_parameter: t3(1273, e.DiagnosticCategory.Error, "_0_modifier_cannot_appear_on_a_type_parameter_1273", "'{0}' modifier cannot appear on a type parameter"), _0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias: t3(1274, e.DiagnosticCategory.Error, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias_1274", "'{0}' modifier can only appear on a type parameter of a class, interface or type alias"), accessor_modifier_can_only_appear_on_a_property_declaration: t3(1275, e.DiagnosticCategory.Error, "accessor_modifier_can_only_appear_on_a_property_declaration_1275", "'accessor' modifier can only appear on a property declaration."), An_accessor_property_cannot_be_declared_optional: t3(1276, e.DiagnosticCategory.Error, "An_accessor_property_cannot_be_declared_optional_1276", "An 'accessor' property cannot be declared optional."), with_statements_are_not_allowed_in_an_async_function_block: t3(1300, e.DiagnosticCategory.Error, "with_statements_are_not_allowed_in_an_async_function_block_1300", "'with' statements are not allowed in an async function block."), await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: t3(1308, e.DiagnosticCategory.Error, "await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1308", "'await' expressions are only allowed within async functions and at the top levels of modules."), The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level: t3(1309, e.DiagnosticCategory.Error, "The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level_1309", "The current file is a CommonJS module and cannot use 'await' at the top level."), Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern: t3(1312, e.DiagnosticCategory.Error, "Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_1312", "Did you mean to use a ':'? An '=' can only follow a property name when the containing object literal is part of a destructuring pattern."), The_body_of_an_if_statement_cannot_be_the_empty_statement: t3(1313, e.DiagnosticCategory.Error, "The_body_of_an_if_statement_cannot_be_the_empty_statement_1313", "The body of an 'if' statement cannot be the empty statement."), Global_module_exports_may_only_appear_in_module_files: t3(1314, e.DiagnosticCategory.Error, "Global_module_exports_may_only_appear_in_module_files_1314", "Global module exports may only appear in module files."), Global_module_exports_may_only_appear_in_declaration_files: t3(1315, e.DiagnosticCategory.Error, "Global_module_exports_may_only_appear_in_declaration_files_1315", "Global module exports may only appear in declaration files."), Global_module_exports_may_only_appear_at_top_level: t3(1316, e.DiagnosticCategory.Error, "Global_module_exports_may_only_appear_at_top_level_1316", "Global module exports may only appear at top level."), A_parameter_property_cannot_be_declared_using_a_rest_parameter: t3(1317, e.DiagnosticCategory.Error, "A_parameter_property_cannot_be_declared_using_a_rest_parameter_1317", "A parameter property cannot be declared using a rest parameter."), An_abstract_accessor_cannot_have_an_implementation: t3(1318, e.DiagnosticCategory.Error, "An_abstract_accessor_cannot_have_an_implementation_1318", "An abstract accessor cannot have an implementation."), A_default_export_can_only_be_used_in_an_ECMAScript_style_module: t3(1319, e.DiagnosticCategory.Error, "A_default_export_can_only_be_used_in_an_ECMAScript_style_module_1319", "A default export can only be used in an ECMAScript-style module."), Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: t3(1320, e.DiagnosticCategory.Error, "Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member_1320", "Type of 'await' operand must either be a valid promise or must not contain a callable 'then' member."), Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: t3(1321, e.DiagnosticCategory.Error, "Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_cal_1321", "Type of 'yield' operand in an async generator must either be a valid promise or must not contain a callable 'then' member."), Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: t3(1322, e.DiagnosticCategory.Error, "Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_con_1322", "Type of iterated elements of a 'yield*' operand must either be a valid promise or must not contain a callable 'then' member."), Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_or_nodenext: t3(1323, e.DiagnosticCategory.Error, "Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd__1323", "Dynamic imports are only supported when the '--module' flag is set to 'es2020', 'es2022', 'esnext', 'commonjs', 'amd', 'system', 'umd', 'node16', or 'nodenext'."), Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nodenext: t3(1324, e.DiagnosticCategory.Error, "Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nod_1324", "Dynamic imports only support a second argument when the '--module' option is set to 'esnext', 'node16', or 'nodenext'."), Argument_of_dynamic_import_cannot_be_spread_element: t3(1325, e.DiagnosticCategory.Error, "Argument_of_dynamic_import_cannot_be_spread_element_1325", "Argument of dynamic import cannot be spread element."), This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments: t3(1326, e.DiagnosticCategory.Error, "This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot__1326", "This use of 'import' is invalid. 'import()' calls can be written, but they must have parentheses and cannot have type arguments."), String_literal_with_double_quotes_expected: t3(1327, e.DiagnosticCategory.Error, "String_literal_with_double_quotes_expected_1327", "String literal with double quotes expected."), Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal: t3(1328, e.DiagnosticCategory.Error, "Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_li_1328", "Property value can only be string literal, numeric literal, 'true', 'false', 'null', object literal or array literal."), _0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0: t3(1329, e.DiagnosticCategory.Error, "_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write__1329", "'{0}' accepts too few arguments to be used as a decorator here. Did you mean to call it first and write '@{0}()'?"), A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly: t3(1330, e.DiagnosticCategory.Error, "A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly_1330", "A property of an interface or type literal whose type is a 'unique symbol' type must be 'readonly'."), A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly: t3(1331, e.DiagnosticCategory.Error, "A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly_1331", "A property of a class whose type is a 'unique symbol' type must be both 'static' and 'readonly'."), A_variable_whose_type_is_a_unique_symbol_type_must_be_const: t3(1332, e.DiagnosticCategory.Error, "A_variable_whose_type_is_a_unique_symbol_type_must_be_const_1332", "A variable whose type is a 'unique symbol' type must be 'const'."), unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name: t3(1333, e.DiagnosticCategory.Error, "unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name_1333", "'unique symbol' types may not be used on a variable declaration with a binding name."), unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement: t3(1334, e.DiagnosticCategory.Error, "unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement_1334", "'unique symbol' types are only allowed on variables in a variable statement."), unique_symbol_types_are_not_allowed_here: t3(1335, e.DiagnosticCategory.Error, "unique_symbol_types_are_not_allowed_here_1335", "'unique symbol' types are not allowed here."), An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead: t3(1337, e.DiagnosticCategory.Error, "An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_o_1337", "An index signature parameter type cannot be a literal type or generic type. Consider using a mapped object type instead."), infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type: t3(1338, e.DiagnosticCategory.Error, "infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type_1338", "'infer' declarations are only permitted in the 'extends' clause of a conditional type."), Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here: t3(1339, e.DiagnosticCategory.Error, "Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here_1339", "Module '{0}' does not refer to a value, but is used as a value here."), Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0: t3(1340, e.DiagnosticCategory.Error, "Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0_1340", "Module '{0}' does not refer to a type, but is used as a type here. Did you mean 'typeof import('{0}')'?"), Class_constructor_may_not_be_an_accessor: t3(1341, e.DiagnosticCategory.Error, "Class_constructor_may_not_be_an_accessor_1341", "Class constructor may not be an accessor."), Type_arguments_cannot_be_used_here: t3(1342, e.DiagnosticCategory.Error, "Type_arguments_cannot_be_used_here_1342", "Type arguments cannot be used here."), The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_or_nodenext: t3(1343, e.DiagnosticCategory.Error, "The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system__1343", "The 'import.meta' meta-property is only allowed when the '--module' option is 'es2020', 'es2022', 'esnext', 'system', 'node16', or 'nodenext'."), A_label_is_not_allowed_here: t3(1344, e.DiagnosticCategory.Error, "A_label_is_not_allowed_here_1344", "'A label is not allowed here."), An_expression_of_type_void_cannot_be_tested_for_truthiness: t3(1345, e.DiagnosticCategory.Error, "An_expression_of_type_void_cannot_be_tested_for_truthiness_1345", "An expression of type 'void' cannot be tested for truthiness."), This_parameter_is_not_allowed_with_use_strict_directive: t3(1346, e.DiagnosticCategory.Error, "This_parameter_is_not_allowed_with_use_strict_directive_1346", "This parameter is not allowed with 'use strict' directive."), use_strict_directive_cannot_be_used_with_non_simple_parameter_list: t3(1347, e.DiagnosticCategory.Error, "use_strict_directive_cannot_be_used_with_non_simple_parameter_list_1347", "'use strict' directive cannot be used with non-simple parameter list."), Non_simple_parameter_declared_here: t3(1348, e.DiagnosticCategory.Error, "Non_simple_parameter_declared_here_1348", "Non-simple parameter declared here."), use_strict_directive_used_here: t3(1349, e.DiagnosticCategory.Error, "use_strict_directive_used_here_1349", "'use strict' directive used here."), Print_the_final_configuration_instead_of_building: t3(1350, e.DiagnosticCategory.Message, "Print_the_final_configuration_instead_of_building_1350", "Print the final configuration instead of building."), An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal: t3(1351, e.DiagnosticCategory.Error, "An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal_1351", "An identifier or keyword cannot immediately follow a numeric literal."), A_bigint_literal_cannot_use_exponential_notation: t3(1352, e.DiagnosticCategory.Error, "A_bigint_literal_cannot_use_exponential_notation_1352", "A bigint literal cannot use exponential notation."), A_bigint_literal_must_be_an_integer: t3(1353, e.DiagnosticCategory.Error, "A_bigint_literal_must_be_an_integer_1353", "A bigint literal must be an integer."), readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types: t3(1354, e.DiagnosticCategory.Error, "readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types_1354", "'readonly' type modifier is only permitted on array and tuple literal types."), A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals: t3(1355, e.DiagnosticCategory.Error, "A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array__1355", "A 'const' assertions can only be applied to references to enum members, or string, number, boolean, array, or object literals."), Did_you_mean_to_mark_this_function_as_async: t3(1356, e.DiagnosticCategory.Error, "Did_you_mean_to_mark_this_function_as_async_1356", "Did you mean to mark this function as 'async'?"), An_enum_member_name_must_be_followed_by_a_or: t3(1357, e.DiagnosticCategory.Error, "An_enum_member_name_must_be_followed_by_a_or_1357", "An enum member name must be followed by a ',', '=', or '}'."), Tagged_template_expressions_are_not_permitted_in_an_optional_chain: t3(1358, e.DiagnosticCategory.Error, "Tagged_template_expressions_are_not_permitted_in_an_optional_chain_1358", "Tagged template expressions are not permitted in an optional chain."), Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here: t3(1359, e.DiagnosticCategory.Error, "Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here_1359", "Identifier expected. '{0}' is a reserved word that cannot be used here."), Type_0_does_not_satisfy_the_expected_type_1: t3(1360, e.DiagnosticCategory.Error, "Type_0_does_not_satisfy_the_expected_type_1_1360", "Type '{0}' does not satisfy the expected type '{1}'."), _0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type: t3(1361, e.DiagnosticCategory.Error, "_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type_1361", "'{0}' cannot be used as a value because it was imported using 'import type'."), _0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type: t3(1362, e.DiagnosticCategory.Error, "_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type_1362", "'{0}' cannot be used as a value because it was exported using 'export type'."), A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both: t3(1363, e.DiagnosticCategory.Error, "A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both_1363", "A type-only import can specify a default import or named bindings, but not both."), Convert_to_type_only_export: t3(1364, e.DiagnosticCategory.Message, "Convert_to_type_only_export_1364", "Convert to type-only export"), Convert_all_re_exported_types_to_type_only_exports: t3(1365, e.DiagnosticCategory.Message, "Convert_all_re_exported_types_to_type_only_exports_1365", "Convert all re-exported types to type-only exports"), Split_into_two_separate_import_declarations: t3(1366, e.DiagnosticCategory.Message, "Split_into_two_separate_import_declarations_1366", "Split into two separate import declarations"), Split_all_invalid_type_only_imports: t3(1367, e.DiagnosticCategory.Message, "Split_all_invalid_type_only_imports_1367", "Split all invalid type-only imports"), Class_constructor_may_not_be_a_generator: t3(1368, e.DiagnosticCategory.Error, "Class_constructor_may_not_be_a_generator_1368", "Class constructor may not be a generator."), Did_you_mean_0: t3(1369, e.DiagnosticCategory.Message, "Did_you_mean_0_1369", "Did you mean '{0}'?"), This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error: t3(1371, e.DiagnosticCategory.Error, "This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set__1371", "This import is never used as a value and must use 'import type' because 'importsNotUsedAsValues' is set to 'error'."), Convert_to_type_only_import: t3(1373, e.DiagnosticCategory.Message, "Convert_to_type_only_import_1373", "Convert to type-only import"), Convert_all_imports_not_used_as_a_value_to_type_only_imports: t3(1374, e.DiagnosticCategory.Message, "Convert_all_imports_not_used_as_a_value_to_type_only_imports_1374", "Convert all imports not used as a value to type-only imports"), await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: t3(1375, e.DiagnosticCategory.Error, "await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_fi_1375", "'await' expressions are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."), _0_was_imported_here: t3(1376, e.DiagnosticCategory.Message, "_0_was_imported_here_1376", "'{0}' was imported here."), _0_was_exported_here: t3(1377, e.DiagnosticCategory.Message, "_0_was_exported_here_1377", "'{0}' was exported here."), Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher: t3(1378, e.DiagnosticCategory.Error, "Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_n_1378", "Top-level 'await' expressions are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', or 'nodenext', and the 'target' option is set to 'es2017' or higher."), An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type: t3(1379, e.DiagnosticCategory.Error, "An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type_1379", "An import alias cannot reference a declaration that was exported using 'export type'."), An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type: t3(1380, e.DiagnosticCategory.Error, "An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type_1380", "An import alias cannot reference a declaration that was imported using 'import type'."), Unexpected_token_Did_you_mean_or_rbrace: t3(1381, e.DiagnosticCategory.Error, "Unexpected_token_Did_you_mean_or_rbrace_1381", "Unexpected token. Did you mean `{'}'}` or `&rbrace;`?"), Unexpected_token_Did_you_mean_or_gt: t3(1382, e.DiagnosticCategory.Error, "Unexpected_token_Did_you_mean_or_gt_1382", "Unexpected token. Did you mean `{'>'}` or `&gt;`?"), Only_named_exports_may_use_export_type: t3(1383, e.DiagnosticCategory.Error, "Only_named_exports_may_use_export_type_1383", "Only named exports may use 'export type'."), Function_type_notation_must_be_parenthesized_when_used_in_a_union_type: t3(1385, e.DiagnosticCategory.Error, "Function_type_notation_must_be_parenthesized_when_used_in_a_union_type_1385", "Function type notation must be parenthesized when used in a union type."), Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type: t3(1386, e.DiagnosticCategory.Error, "Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type_1386", "Constructor type notation must be parenthesized when used in a union type."), Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: t3(1387, e.DiagnosticCategory.Error, "Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1387", "Function type notation must be parenthesized when used in an intersection type."), Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: t3(1388, e.DiagnosticCategory.Error, "Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1388", "Constructor type notation must be parenthesized when used in an intersection type."), _0_is_not_allowed_as_a_variable_declaration_name: t3(1389, e.DiagnosticCategory.Error, "_0_is_not_allowed_as_a_variable_declaration_name_1389", "'{0}' is not allowed as a variable declaration name."), _0_is_not_allowed_as_a_parameter_name: t3(1390, e.DiagnosticCategory.Error, "_0_is_not_allowed_as_a_parameter_name_1390", "'{0}' is not allowed as a parameter name."), An_import_alias_cannot_use_import_type: t3(1392, e.DiagnosticCategory.Error, "An_import_alias_cannot_use_import_type_1392", "An import alias cannot use 'import type'"), Imported_via_0_from_file_1: t3(1393, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_1393", "Imported via {0} from file '{1}'"), Imported_via_0_from_file_1_with_packageId_2: t3(1394, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_with_packageId_2_1394", "Imported via {0} from file '{1}' with packageId '{2}'"), Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions: t3(1395, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions_1395", "Imported via {0} from file '{1}' to import 'importHelpers' as specified in compilerOptions"), Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions: t3(1396, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions_1396", "Imported via {0} from file '{1}' with packageId '{2}' to import 'importHelpers' as specified in compilerOptions"), Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions: t3(1397, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions_1397", "Imported via {0} from file '{1}' to import 'jsx' and 'jsxs' factory functions"), Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions: t3(1398, e.DiagnosticCategory.Message, "Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions_1398", "Imported via {0} from file '{1}' with packageId '{2}' to import 'jsx' and 'jsxs' factory functions"), File_is_included_via_import_here: t3(1399, e.DiagnosticCategory.Message, "File_is_included_via_import_here_1399", "File is included via import here."), Referenced_via_0_from_file_1: t3(1400, e.DiagnosticCategory.Message, "Referenced_via_0_from_file_1_1400", "Referenced via '{0}' from file '{1}'"), File_is_included_via_reference_here: t3(1401, e.DiagnosticCategory.Message, "File_is_included_via_reference_here_1401", "File is included via reference here."), Type_library_referenced_via_0_from_file_1: t3(1402, e.DiagnosticCategory.Message, "Type_library_referenced_via_0_from_file_1_1402", "Type library referenced via '{0}' from file '{1}'"), Type_library_referenced_via_0_from_file_1_with_packageId_2: t3(1403, e.DiagnosticCategory.Message, "Type_library_referenced_via_0_from_file_1_with_packageId_2_1403", "Type library referenced via '{0}' from file '{1}' with packageId '{2}'"), File_is_included_via_type_library_reference_here: t3(1404, e.DiagnosticCategory.Message, "File_is_included_via_type_library_reference_here_1404", "File is included via type library reference here."), Library_referenced_via_0_from_file_1: t3(1405, e.DiagnosticCategory.Message, "Library_referenced_via_0_from_file_1_1405", "Library referenced via '{0}' from file '{1}'"), File_is_included_via_library_reference_here: t3(1406, e.DiagnosticCategory.Message, "File_is_included_via_library_reference_here_1406", "File is included via library reference here."), Matched_by_include_pattern_0_in_1: t3(1407, e.DiagnosticCategory.Message, "Matched_by_include_pattern_0_in_1_1407", "Matched by include pattern '{0}' in '{1}'"), File_is_matched_by_include_pattern_specified_here: t3(1408, e.DiagnosticCategory.Message, "File_is_matched_by_include_pattern_specified_here_1408", "File is matched by include pattern specified here."), Part_of_files_list_in_tsconfig_json: t3(1409, e.DiagnosticCategory.Message, "Part_of_files_list_in_tsconfig_json_1409", "Part of 'files' list in tsconfig.json"), File_is_matched_by_files_list_specified_here: t3(1410, e.DiagnosticCategory.Message, "File_is_matched_by_files_list_specified_here_1410", "File is matched by 'files' list specified here."), Output_from_referenced_project_0_included_because_1_specified: t3(1411, e.DiagnosticCategory.Message, "Output_from_referenced_project_0_included_because_1_specified_1411", "Output from referenced project '{0}' included because '{1}' specified"), Output_from_referenced_project_0_included_because_module_is_specified_as_none: t3(1412, e.DiagnosticCategory.Message, "Output_from_referenced_project_0_included_because_module_is_specified_as_none_1412", "Output from referenced project '{0}' included because '--module' is specified as 'none'"), File_is_output_from_referenced_project_specified_here: t3(1413, e.DiagnosticCategory.Message, "File_is_output_from_referenced_project_specified_here_1413", "File is output from referenced project specified here."), Source_from_referenced_project_0_included_because_1_specified: t3(1414, e.DiagnosticCategory.Message, "Source_from_referenced_project_0_included_because_1_specified_1414", "Source from referenced project '{0}' included because '{1}' specified"), Source_from_referenced_project_0_included_because_module_is_specified_as_none: t3(1415, e.DiagnosticCategory.Message, "Source_from_referenced_project_0_included_because_module_is_specified_as_none_1415", "Source from referenced project '{0}' included because '--module' is specified as 'none'"), File_is_source_from_referenced_project_specified_here: t3(1416, e.DiagnosticCategory.Message, "File_is_source_from_referenced_project_specified_here_1416", "File is source from referenced project specified here."), Entry_point_of_type_library_0_specified_in_compilerOptions: t3(1417, e.DiagnosticCategory.Message, "Entry_point_of_type_library_0_specified_in_compilerOptions_1417", "Entry point of type library '{0}' specified in compilerOptions"), Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1: t3(1418, e.DiagnosticCategory.Message, "Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1_1418", "Entry point of type library '{0}' specified in compilerOptions with packageId '{1}'"), File_is_entry_point_of_type_library_specified_here: t3(1419, e.DiagnosticCategory.Message, "File_is_entry_point_of_type_library_specified_here_1419", "File is entry point of type library specified here."), Entry_point_for_implicit_type_library_0: t3(1420, e.DiagnosticCategory.Message, "Entry_point_for_implicit_type_library_0_1420", "Entry point for implicit type library '{0}'"), Entry_point_for_implicit_type_library_0_with_packageId_1: t3(1421, e.DiagnosticCategory.Message, "Entry_point_for_implicit_type_library_0_with_packageId_1_1421", "Entry point for implicit type library '{0}' with packageId '{1}'"), Library_0_specified_in_compilerOptions: t3(1422, e.DiagnosticCategory.Message, "Library_0_specified_in_compilerOptions_1422", "Library '{0}' specified in compilerOptions"), File_is_library_specified_here: t3(1423, e.DiagnosticCategory.Message, "File_is_library_specified_here_1423", "File is library specified here."), Default_library: t3(1424, e.DiagnosticCategory.Message, "Default_library_1424", "Default library"), Default_library_for_target_0: t3(1425, e.DiagnosticCategory.Message, "Default_library_for_target_0_1425", "Default library for target '{0}'"), File_is_default_library_for_target_specified_here: t3(1426, e.DiagnosticCategory.Message, "File_is_default_library_for_target_specified_here_1426", "File is default library for target specified here."), Root_file_specified_for_compilation: t3(1427, e.DiagnosticCategory.Message, "Root_file_specified_for_compilation_1427", "Root file specified for compilation"), File_is_output_of_project_reference_source_0: t3(1428, e.DiagnosticCategory.Message, "File_is_output_of_project_reference_source_0_1428", "File is output of project reference source '{0}'"), File_redirects_to_file_0: t3(1429, e.DiagnosticCategory.Message, "File_redirects_to_file_0_1429", "File redirects to file '{0}'"), The_file_is_in_the_program_because_Colon: t3(1430, e.DiagnosticCategory.Message, "The_file_is_in_the_program_because_Colon_1430", "The file is in the program because:"), for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: t3(1431, e.DiagnosticCategory.Error, "for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_1431", "'for await' loops are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."), Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_or_nodenext_and_the_target_option_is_set_to_es2017_or_higher: t3(1432, e.DiagnosticCategory.Error, "Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_nod_1432", "Top-level 'for await' loops are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', or 'nodenext', and the 'target' option is set to 'es2017' or higher."), Decorators_may_not_be_applied_to_this_parameters: t3(1433, e.DiagnosticCategory.Error, "Decorators_may_not_be_applied_to_this_parameters_1433", "Decorators may not be applied to 'this' parameters."), Unexpected_keyword_or_identifier: t3(1434, e.DiagnosticCategory.Error, "Unexpected_keyword_or_identifier_1434", "Unexpected keyword or identifier."), Unknown_keyword_or_identifier_Did_you_mean_0: t3(1435, e.DiagnosticCategory.Error, "Unknown_keyword_or_identifier_Did_you_mean_0_1435", "Unknown keyword or identifier. Did you mean '{0}'?"), Decorators_must_precede_the_name_and_all_keywords_of_property_declarations: t3(1436, e.DiagnosticCategory.Error, "Decorators_must_precede_the_name_and_all_keywords_of_property_declarations_1436", "Decorators must precede the name and all keywords of property declarations."), Namespace_must_be_given_a_name: t3(1437, e.DiagnosticCategory.Error, "Namespace_must_be_given_a_name_1437", "Namespace must be given a name."), Interface_must_be_given_a_name: t3(1438, e.DiagnosticCategory.Error, "Interface_must_be_given_a_name_1438", "Interface must be given a name."), Type_alias_must_be_given_a_name: t3(1439, e.DiagnosticCategory.Error, "Type_alias_must_be_given_a_name_1439", "Type alias must be given a name."), Variable_declaration_not_allowed_at_this_location: t3(1440, e.DiagnosticCategory.Error, "Variable_declaration_not_allowed_at_this_location_1440", "Variable declaration not allowed at this location."), Cannot_start_a_function_call_in_a_type_annotation: t3(1441, e.DiagnosticCategory.Error, "Cannot_start_a_function_call_in_a_type_annotation_1441", "Cannot start a function call in a type annotation."), Expected_for_property_initializer: t3(1442, e.DiagnosticCategory.Error, "Expected_for_property_initializer_1442", "Expected '=' for property initializer."), Module_declaration_names_may_only_use_or_quoted_strings: t3(1443, e.DiagnosticCategory.Error, "Module_declaration_names_may_only_use_or_quoted_strings_1443", `Module declaration names may only use ' or " quoted strings.`), _0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: t3(1444, e.DiagnosticCategory.Error, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedMod_1444", "'{0}' is a type and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."), _0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: t3(1446, e.DiagnosticCategory.Error, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveVa_1446", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."), _0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_isolatedModules_is_enabled: t3(1448, e.DiagnosticCategory.Error, "_0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_isol_1448", "'{0}' resolves to a type-only declaration and must be re-exported using a type-only re-export when 'isolatedModules' is enabled."), Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed: t3(1449, e.DiagnosticCategory.Message, "Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed_1449", "Preserve unused imported values in the JavaScript output that would otherwise be removed."), Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments: t3(1450, e.DiagnosticCategory.Message, "Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_assertion_as_arguments_1450", "Dynamic imports can only accept a module specifier and an optional assertion as arguments"), Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression: t3(1451, e.DiagnosticCategory.Error, "Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member__1451", "Private identifiers are only allowed in class bodies and may only be used as part of a class member declaration, property access, or on the left-hand-side of an 'in' expression"), resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext: t3(1452, e.DiagnosticCategory.Error, "resolution_mode_assertions_are_only_supported_when_moduleResolution_is_node16_or_nodenext_1452", "'resolution-mode' assertions are only supported when `moduleResolution` is `node16` or `nodenext`."), resolution_mode_should_be_either_require_or_import: t3(1453, e.DiagnosticCategory.Error, "resolution_mode_should_be_either_require_or_import_1453", "`resolution-mode` should be either `require` or `import`."), resolution_mode_can_only_be_set_for_type_only_imports: t3(1454, e.DiagnosticCategory.Error, "resolution_mode_can_only_be_set_for_type_only_imports_1454", "`resolution-mode` can only be set for type-only imports."), resolution_mode_is_the_only_valid_key_for_type_import_assertions: t3(1455, e.DiagnosticCategory.Error, "resolution_mode_is_the_only_valid_key_for_type_import_assertions_1455", "`resolution-mode` is the only valid key for type import assertions."), Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: t3(1456, e.DiagnosticCategory.Error, "Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1456", "Type import assertions should have exactly one key - `resolution-mode` - with value `import` or `require`."), Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk: t3(1457, e.DiagnosticCategory.Message, "Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk_1457", "Matched by default include pattern '**/*'"), File_is_ECMAScript_module_because_0_has_field_type_with_value_module: t3(1458, e.DiagnosticCategory.Message, "File_is_ECMAScript_module_because_0_has_field_type_with_value_module_1458", `File is ECMAScript module because '{0}' has field "type" with value "module"`), File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module: t3(1459, e.DiagnosticCategory.Message, "File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module_1459", `File is CommonJS module because '{0}' has field "type" whose value is not "module"`), File_is_CommonJS_module_because_0_does_not_have_field_type: t3(1460, e.DiagnosticCategory.Message, "File_is_CommonJS_module_because_0_does_not_have_field_type_1460", `File is CommonJS module because '{0}' does not have field "type"`), File_is_CommonJS_module_because_package_json_was_not_found: t3(1461, e.DiagnosticCategory.Message, "File_is_CommonJS_module_because_package_json_was_not_found_1461", "File is CommonJS module because 'package.json' was not found"), The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output: t3(1470, e.DiagnosticCategory.Error, "The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output_1470", "The 'import.meta' meta-property is not allowed in files which will build into CommonJS output."), Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead: t3(1471, e.DiagnosticCategory.Error, "Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_c_1471", "Module '{0}' cannot be imported using this construct. The specifier only resolves to an ES module, which cannot be imported with 'require'. Use an ECMAScript import instead."), catch_or_finally_expected: t3(1472, e.DiagnosticCategory.Error, "catch_or_finally_expected_1472", "'catch' or 'finally' expected."), An_import_declaration_can_only_be_used_at_the_top_level_of_a_module: t3(1473, e.DiagnosticCategory.Error, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_module_1473", "An import declaration can only be used at the top level of a module."), An_export_declaration_can_only_be_used_at_the_top_level_of_a_module: t3(1474, e.DiagnosticCategory.Error, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_module_1474", "An export declaration can only be used at the top level of a module."), Control_what_method_is_used_to_detect_module_format_JS_files: t3(1475, e.DiagnosticCategory.Message, "Control_what_method_is_used_to_detect_module_format_JS_files_1475", "Control what method is used to detect module-format JS files."), auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules: t3(1476, e.DiagnosticCategory.Message, "auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_w_1476", '"auto": Treat files with imports, exports, import.meta, jsx (with jsx: react-jsx), or esm format (with module: node16+) as modules.'), An_instantiation_expression_cannot_be_followed_by_a_property_access: t3(1477, e.DiagnosticCategory.Error, "An_instantiation_expression_cannot_be_followed_by_a_property_access_1477", "An instantiation expression cannot be followed by a property access."), Identifier_or_string_literal_expected: t3(1478, e.DiagnosticCategory.Error, "Identifier_or_string_literal_expected_1478", "Identifier or string literal expected."), The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead: t3(1479, e.DiagnosticCategory.Error, "The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_reference_1479", `The current file is a CommonJS module whose imports will produce 'require' calls; however, the referenced file is an ECMAScript module and cannot be imported with 'require'. Consider writing a dynamic 'import("{0}")' call instead.`), To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module: t3(1480, e.DiagnosticCategory.Message, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_packag_1480", 'To convert this file to an ECMAScript module, change its file extension to \'{0}\' or create a local package.json file with `{ "type": "module" }`.'), To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1: t3(1481, e.DiagnosticCategory.Message, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Co_1481", `To convert this file to an ECMAScript module, change its file extension to '{0}', or add the field \`"type": "module"\` to '{1}'.`), To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0: t3(1482, e.DiagnosticCategory.Message, "To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0_1482", 'To convert this file to an ECMAScript module, add the field `"type": "module"` to \'{0}\'.'), To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module: t3(1483, e.DiagnosticCategory.Message, "To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module_1483", 'To convert this file to an ECMAScript module, create a local package.json file with `{ "type": "module" }`.'), The_types_of_0_are_incompatible_between_these_types: t3(2200, e.DiagnosticCategory.Error, "The_types_of_0_are_incompatible_between_these_types_2200", "The types of '{0}' are incompatible between these types."), The_types_returned_by_0_are_incompatible_between_these_types: t3(2201, e.DiagnosticCategory.Error, "The_types_returned_by_0_are_incompatible_between_these_types_2201", "The types returned by '{0}' are incompatible between these types."), Call_signature_return_types_0_and_1_are_incompatible: t3(2202, e.DiagnosticCategory.Error, "Call_signature_return_types_0_and_1_are_incompatible_2202", "Call signature return types '{0}' and '{1}' are incompatible.", void 0, true), Construct_signature_return_types_0_and_1_are_incompatible: t3(2203, e.DiagnosticCategory.Error, "Construct_signature_return_types_0_and_1_are_incompatible_2203", "Construct signature return types '{0}' and '{1}' are incompatible.", void 0, true), Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: t3(2204, e.DiagnosticCategory.Error, "Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2204", "Call signatures with no arguments have incompatible return types '{0}' and '{1}'.", void 0, true), Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: t3(2205, e.DiagnosticCategory.Error, "Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2205", "Construct signatures with no arguments have incompatible return types '{0}' and '{1}'.", void 0, true), The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement: t3(2206, e.DiagnosticCategory.Error, "The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement_2206", "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement."), The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement: t3(2207, e.DiagnosticCategory.Error, "The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement_2207", "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement."), This_type_parameter_might_need_an_extends_0_constraint: t3(2208, e.DiagnosticCategory.Error, "This_type_parameter_might_need_an_extends_0_constraint_2208", "This type parameter might need an `extends {0}` constraint."), The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: t3(2209, e.DiagnosticCategory.Error, "The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_roo_2209", "The project root is ambiguous, but is required to resolve export map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."), The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: t3(2210, e.DiagnosticCategory.Error, "The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_roo_2210", "The project root is ambiguous, but is required to resolve import map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."), Add_extends_constraint: t3(2211, e.DiagnosticCategory.Message, "Add_extends_constraint_2211", "Add `extends` constraint."), Add_extends_constraint_to_all_type_parameters: t3(2212, e.DiagnosticCategory.Message, "Add_extends_constraint_to_all_type_parameters_2212", "Add `extends` constraint to all type parameters"), Duplicate_identifier_0: t3(2300, e.DiagnosticCategory.Error, "Duplicate_identifier_0_2300", "Duplicate identifier '{0}'."), Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: t3(2301, e.DiagnosticCategory.Error, "Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301", "Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."), Static_members_cannot_reference_class_type_parameters: t3(2302, e.DiagnosticCategory.Error, "Static_members_cannot_reference_class_type_parameters_2302", "Static members cannot reference class type parameters."), Circular_definition_of_import_alias_0: t3(2303, e.DiagnosticCategory.Error, "Circular_definition_of_import_alias_0_2303", "Circular definition of import alias '{0}'."), Cannot_find_name_0: t3(2304, e.DiagnosticCategory.Error, "Cannot_find_name_0_2304", "Cannot find name '{0}'."), Module_0_has_no_exported_member_1: t3(2305, e.DiagnosticCategory.Error, "Module_0_has_no_exported_member_1_2305", "Module '{0}' has no exported member '{1}'."), File_0_is_not_a_module: t3(2306, e.DiagnosticCategory.Error, "File_0_is_not_a_module_2306", "File '{0}' is not a module."), Cannot_find_module_0_or_its_corresponding_type_declarations: t3(2307, e.DiagnosticCategory.Error, "Cannot_find_module_0_or_its_corresponding_type_declarations_2307", "Cannot find module '{0}' or its corresponding type declarations."), Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity: t3(2308, e.DiagnosticCategory.Error, "Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308", "Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity."), An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements: t3(2309, e.DiagnosticCategory.Error, "An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309", "An export assignment cannot be used in a module with other exported elements."), Type_0_recursively_references_itself_as_a_base_type: t3(2310, e.DiagnosticCategory.Error, "Type_0_recursively_references_itself_as_a_base_type_2310", "Type '{0}' recursively references itself as a base type."), Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function: t3(2311, e.DiagnosticCategory.Error, "Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function_2311", "Cannot find name '{0}'. Did you mean to write this in an async function?"), An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members: t3(2312, e.DiagnosticCategory.Error, "An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_me_2312", "An interface can only extend an object type or intersection of object types with statically known members."), Type_parameter_0_has_a_circular_constraint: t3(2313, e.DiagnosticCategory.Error, "Type_parameter_0_has_a_circular_constraint_2313", "Type parameter '{0}' has a circular constraint."), Generic_type_0_requires_1_type_argument_s: t3(2314, e.DiagnosticCategory.Error, "Generic_type_0_requires_1_type_argument_s_2314", "Generic type '{0}' requires {1} type argument(s)."), Type_0_is_not_generic: t3(2315, e.DiagnosticCategory.Error, "Type_0_is_not_generic_2315", "Type '{0}' is not generic."), Global_type_0_must_be_a_class_or_interface_type: t3(2316, e.DiagnosticCategory.Error, "Global_type_0_must_be_a_class_or_interface_type_2316", "Global type '{0}' must be a class or interface type."), Global_type_0_must_have_1_type_parameter_s: t3(2317, e.DiagnosticCategory.Error, "Global_type_0_must_have_1_type_parameter_s_2317", "Global type '{0}' must have {1} type parameter(s)."), Cannot_find_global_type_0: t3(2318, e.DiagnosticCategory.Error, "Cannot_find_global_type_0_2318", "Cannot find global type '{0}'."), Named_property_0_of_types_1_and_2_are_not_identical: t3(2319, e.DiagnosticCategory.Error, "Named_property_0_of_types_1_and_2_are_not_identical_2319", "Named property '{0}' of types '{1}' and '{2}' are not identical."), Interface_0_cannot_simultaneously_extend_types_1_and_2: t3(2320, e.DiagnosticCategory.Error, "Interface_0_cannot_simultaneously_extend_types_1_and_2_2320", "Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'."), Excessive_stack_depth_comparing_types_0_and_1: t3(2321, e.DiagnosticCategory.Error, "Excessive_stack_depth_comparing_types_0_and_1_2321", "Excessive stack depth comparing types '{0}' and '{1}'."), Type_0_is_not_assignable_to_type_1: t3(2322, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_2322", "Type '{0}' is not assignable to type '{1}'."), Cannot_redeclare_exported_variable_0: t3(2323, e.DiagnosticCategory.Error, "Cannot_redeclare_exported_variable_0_2323", "Cannot redeclare exported variable '{0}'."), Property_0_is_missing_in_type_1: t3(2324, e.DiagnosticCategory.Error, "Property_0_is_missing_in_type_1_2324", "Property '{0}' is missing in type '{1}'."), Property_0_is_private_in_type_1_but_not_in_type_2: t3(2325, e.DiagnosticCategory.Error, "Property_0_is_private_in_type_1_but_not_in_type_2_2325", "Property '{0}' is private in type '{1}' but not in type '{2}'."), Types_of_property_0_are_incompatible: t3(2326, e.DiagnosticCategory.Error, "Types_of_property_0_are_incompatible_2326", "Types of property '{0}' are incompatible."), Property_0_is_optional_in_type_1_but_required_in_type_2: t3(2327, e.DiagnosticCategory.Error, "Property_0_is_optional_in_type_1_but_required_in_type_2_2327", "Property '{0}' is optional in type '{1}' but required in type '{2}'."), Types_of_parameters_0_and_1_are_incompatible: t3(2328, e.DiagnosticCategory.Error, "Types_of_parameters_0_and_1_are_incompatible_2328", "Types of parameters '{0}' and '{1}' are incompatible."), Index_signature_for_type_0_is_missing_in_type_1: t3(2329, e.DiagnosticCategory.Error, "Index_signature_for_type_0_is_missing_in_type_1_2329", "Index signature for type '{0}' is missing in type '{1}'."), _0_and_1_index_signatures_are_incompatible: t3(2330, e.DiagnosticCategory.Error, "_0_and_1_index_signatures_are_incompatible_2330", "'{0}' and '{1}' index signatures are incompatible."), this_cannot_be_referenced_in_a_module_or_namespace_body: t3(2331, e.DiagnosticCategory.Error, "this_cannot_be_referenced_in_a_module_or_namespace_body_2331", "'this' cannot be referenced in a module or namespace body."), this_cannot_be_referenced_in_current_location: t3(2332, e.DiagnosticCategory.Error, "this_cannot_be_referenced_in_current_location_2332", "'this' cannot be referenced in current location."), this_cannot_be_referenced_in_constructor_arguments: t3(2333, e.DiagnosticCategory.Error, "this_cannot_be_referenced_in_constructor_arguments_2333", "'this' cannot be referenced in constructor arguments."), this_cannot_be_referenced_in_a_static_property_initializer: t3(2334, e.DiagnosticCategory.Error, "this_cannot_be_referenced_in_a_static_property_initializer_2334", "'this' cannot be referenced in a static property initializer."), super_can_only_be_referenced_in_a_derived_class: t3(2335, e.DiagnosticCategory.Error, "super_can_only_be_referenced_in_a_derived_class_2335", "'super' can only be referenced in a derived class."), super_cannot_be_referenced_in_constructor_arguments: t3(2336, e.DiagnosticCategory.Error, "super_cannot_be_referenced_in_constructor_arguments_2336", "'super' cannot be referenced in constructor arguments."), Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors: t3(2337, e.DiagnosticCategory.Error, "Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337", "Super calls are not permitted outside constructors or in nested functions inside constructors."), super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class: t3(2338, e.DiagnosticCategory.Error, "super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338", "'super' property access is permitted only in a constructor, member function, or member accessor of a derived class."), Property_0_does_not_exist_on_type_1: t3(2339, e.DiagnosticCategory.Error, "Property_0_does_not_exist_on_type_1_2339", "Property '{0}' does not exist on type '{1}'."), Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword: t3(2340, e.DiagnosticCategory.Error, "Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340", "Only public and protected methods of the base class are accessible via the 'super' keyword."), Property_0_is_private_and_only_accessible_within_class_1: t3(2341, e.DiagnosticCategory.Error, "Property_0_is_private_and_only_accessible_within_class_1_2341", "Property '{0}' is private and only accessible within class '{1}'."), This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0: t3(2343, e.DiagnosticCategory.Error, "This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_ve_2343", "This syntax requires an imported helper named '{1}' which does not exist in '{0}'. Consider upgrading your version of '{0}'."), Type_0_does_not_satisfy_the_constraint_1: t3(2344, e.DiagnosticCategory.Error, "Type_0_does_not_satisfy_the_constraint_1_2344", "Type '{0}' does not satisfy the constraint '{1}'."), Argument_of_type_0_is_not_assignable_to_parameter_of_type_1: t3(2345, e.DiagnosticCategory.Error, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345", "Argument of type '{0}' is not assignable to parameter of type '{1}'."), Call_target_does_not_contain_any_signatures: t3(2346, e.DiagnosticCategory.Error, "Call_target_does_not_contain_any_signatures_2346", "Call target does not contain any signatures."), Untyped_function_calls_may_not_accept_type_arguments: t3(2347, e.DiagnosticCategory.Error, "Untyped_function_calls_may_not_accept_type_arguments_2347", "Untyped function calls may not accept type arguments."), Value_of_type_0_is_not_callable_Did_you_mean_to_include_new: t3(2348, e.DiagnosticCategory.Error, "Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348", "Value of type '{0}' is not callable. Did you mean to include 'new'?"), This_expression_is_not_callable: t3(2349, e.DiagnosticCategory.Error, "This_expression_is_not_callable_2349", "This expression is not callable."), Only_a_void_function_can_be_called_with_the_new_keyword: t3(2350, e.DiagnosticCategory.Error, "Only_a_void_function_can_be_called_with_the_new_keyword_2350", "Only a void function can be called with the 'new' keyword."), This_expression_is_not_constructable: t3(2351, e.DiagnosticCategory.Error, "This_expression_is_not_constructable_2351", "This expression is not constructable."), Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first: t3(2352, e.DiagnosticCategory.Error, "Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the__2352", "Conversion of type '{0}' to type '{1}' may be a mistake because neither type sufficiently overlaps with the other. If this was intentional, convert the expression to 'unknown' first."), Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1: t3(2353, e.DiagnosticCategory.Error, "Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353", "Object literal may only specify known properties, and '{0}' does not exist in type '{1}'."), This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found: t3(2354, e.DiagnosticCategory.Error, "This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found_2354", "This syntax requires an imported helper but module '{0}' cannot be found."), A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value: t3(2355, e.DiagnosticCategory.Error, "A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value_2355", "A function whose declared type is neither 'void' nor 'any' must return a value."), An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type: t3(2356, e.DiagnosticCategory.Error, "An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type_2356", "An arithmetic operand must be of type 'any', 'number', 'bigint' or an enum type."), The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access: t3(2357, e.DiagnosticCategory.Error, "The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access_2357", "The operand of an increment or decrement operator must be a variable or a property access."), The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: t3(2358, e.DiagnosticCategory.Error, "The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358", "The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter."), The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type: t3(2359, e.DiagnosticCategory.Error, "The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_F_2359", "The right-hand side of an 'instanceof' expression must be of type 'any' or of a type assignable to the 'Function' interface type."), The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: t3(2362, e.DiagnosticCategory.Error, "The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2362", "The left-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."), The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: t3(2363, e.DiagnosticCategory.Error, "The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2363", "The right-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."), The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access: t3(2364, e.DiagnosticCategory.Error, "The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access_2364", "The left-hand side of an assignment expression must be a variable or a property access."), Operator_0_cannot_be_applied_to_types_1_and_2: t3(2365, e.DiagnosticCategory.Error, "Operator_0_cannot_be_applied_to_types_1_and_2_2365", "Operator '{0}' cannot be applied to types '{1}' and '{2}'."), Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined: t3(2366, e.DiagnosticCategory.Error, "Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined_2366", "Function lacks ending return statement and return type does not include 'undefined'."), This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap: t3(2367, e.DiagnosticCategory.Error, "This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap_2367", "This comparison appears to be unintentional because the types '{0}' and '{1}' have no overlap."), Type_parameter_name_cannot_be_0: t3(2368, e.DiagnosticCategory.Error, "Type_parameter_name_cannot_be_0_2368", "Type parameter name cannot be '{0}'."), A_parameter_property_is_only_allowed_in_a_constructor_implementation: t3(2369, e.DiagnosticCategory.Error, "A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369", "A parameter property is only allowed in a constructor implementation."), A_rest_parameter_must_be_of_an_array_type: t3(2370, e.DiagnosticCategory.Error, "A_rest_parameter_must_be_of_an_array_type_2370", "A rest parameter must be of an array type."), A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation: t3(2371, e.DiagnosticCategory.Error, "A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371", "A parameter initializer is only allowed in a function or constructor implementation."), Parameter_0_cannot_reference_itself: t3(2372, e.DiagnosticCategory.Error, "Parameter_0_cannot_reference_itself_2372", "Parameter '{0}' cannot reference itself."), Parameter_0_cannot_reference_identifier_1_declared_after_it: t3(2373, e.DiagnosticCategory.Error, "Parameter_0_cannot_reference_identifier_1_declared_after_it_2373", "Parameter '{0}' cannot reference identifier '{1}' declared after it."), Duplicate_index_signature_for_type_0: t3(2374, e.DiagnosticCategory.Error, "Duplicate_index_signature_for_type_0_2374", "Duplicate index signature for type '{0}'."), Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: t3(2375, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2375", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."), A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers: t3(2376, e.DiagnosticCategory.Error, "A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_2376", "A 'super' call must be the first statement in the constructor to refer to 'super' or 'this' when a derived class contains initialized properties, parameter properties, or private identifiers."), Constructors_for_derived_classes_must_contain_a_super_call: t3(2377, e.DiagnosticCategory.Error, "Constructors_for_derived_classes_must_contain_a_super_call_2377", "Constructors for derived classes must contain a 'super' call."), A_get_accessor_must_return_a_value: t3(2378, e.DiagnosticCategory.Error, "A_get_accessor_must_return_a_value_2378", "A 'get' accessor must return a value."), Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: t3(2379, e.DiagnosticCategory.Error, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_tr_2379", "Argument of type '{0}' is not assignable to parameter of type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."), The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type: t3(2380, e.DiagnosticCategory.Error, "The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type_2380", "The return type of a 'get' accessor must be assignable to its 'set' accessor type"), Overload_signatures_must_all_be_exported_or_non_exported: t3(2383, e.DiagnosticCategory.Error, "Overload_signatures_must_all_be_exported_or_non_exported_2383", "Overload signatures must all be exported or non-exported."), Overload_signatures_must_all_be_ambient_or_non_ambient: t3(2384, e.DiagnosticCategory.Error, "Overload_signatures_must_all_be_ambient_or_non_ambient_2384", "Overload signatures must all be ambient or non-ambient."), Overload_signatures_must_all_be_public_private_or_protected: t3(2385, e.DiagnosticCategory.Error, "Overload_signatures_must_all_be_public_private_or_protected_2385", "Overload signatures must all be public, private or protected."), Overload_signatures_must_all_be_optional_or_required: t3(2386, e.DiagnosticCategory.Error, "Overload_signatures_must_all_be_optional_or_required_2386", "Overload signatures must all be optional or required."), Function_overload_must_be_static: t3(2387, e.DiagnosticCategory.Error, "Function_overload_must_be_static_2387", "Function overload must be static."), Function_overload_must_not_be_static: t3(2388, e.DiagnosticCategory.Error, "Function_overload_must_not_be_static_2388", "Function overload must not be static."), Function_implementation_name_must_be_0: t3(2389, e.DiagnosticCategory.Error, "Function_implementation_name_must_be_0_2389", "Function implementation name must be '{0}'."), Constructor_implementation_is_missing: t3(2390, e.DiagnosticCategory.Error, "Constructor_implementation_is_missing_2390", "Constructor implementation is missing."), Function_implementation_is_missing_or_not_immediately_following_the_declaration: t3(2391, e.DiagnosticCategory.Error, "Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391", "Function implementation is missing or not immediately following the declaration."), Multiple_constructor_implementations_are_not_allowed: t3(2392, e.DiagnosticCategory.Error, "Multiple_constructor_implementations_are_not_allowed_2392", "Multiple constructor implementations are not allowed."), Duplicate_function_implementation: t3(2393, e.DiagnosticCategory.Error, "Duplicate_function_implementation_2393", "Duplicate function implementation."), This_overload_signature_is_not_compatible_with_its_implementation_signature: t3(2394, e.DiagnosticCategory.Error, "This_overload_signature_is_not_compatible_with_its_implementation_signature_2394", "This overload signature is not compatible with its implementation signature."), Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local: t3(2395, e.DiagnosticCategory.Error, "Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395", "Individual declarations in merged declaration '{0}' must be all exported or all local."), Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters: t3(2396, e.DiagnosticCategory.Error, "Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396", "Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters."), Declaration_name_conflicts_with_built_in_global_identifier_0: t3(2397, e.DiagnosticCategory.Error, "Declaration_name_conflicts_with_built_in_global_identifier_0_2397", "Declaration name conflicts with built-in global identifier '{0}'."), constructor_cannot_be_used_as_a_parameter_property_name: t3(2398, e.DiagnosticCategory.Error, "constructor_cannot_be_used_as_a_parameter_property_name_2398", "'constructor' cannot be used as a parameter property name."), Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference: t3(2399, e.DiagnosticCategory.Error, "Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399", "Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference."), Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference: t3(2400, e.DiagnosticCategory.Error, "Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400", "Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference."), A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers: t3(2401, e.DiagnosticCategory.Error, "A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_in_2401", "A 'super' call must be a root-level statement within a constructor of a derived class that contains initialized properties, parameter properties, or private identifiers."), Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference: t3(2402, e.DiagnosticCategory.Error, "Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402", "Expression resolves to '_super' that compiler uses to capture base class reference."), Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2: t3(2403, e.DiagnosticCategory.Error, "Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403", "Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'."), The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation: t3(2404, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404", "The left-hand side of a 'for...in' statement cannot use a type annotation."), The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any: t3(2405, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405", "The left-hand side of a 'for...in' statement must be of type 'string' or 'any'."), The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access: t3(2406, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access_2406", "The left-hand side of a 'for...in' statement must be a variable or a property access."), The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0: t3(2407, e.DiagnosticCategory.Error, "The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_2407", "The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter, but here has type '{0}'."), Setters_cannot_return_a_value: t3(2408, e.DiagnosticCategory.Error, "Setters_cannot_return_a_value_2408", "Setters cannot return a value."), Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class: t3(2409, e.DiagnosticCategory.Error, "Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409", "Return type of constructor signature must be assignable to the instance type of the class."), The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any: t3(2410, e.DiagnosticCategory.Error, "The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any_2410", "The 'with' statement is not supported. All symbols in a 'with' block will have type 'any'."), Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target: t3(2412, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2412", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the type of the target."), Property_0_of_type_1_is_not_assignable_to_2_index_type_3: t3(2411, e.DiagnosticCategory.Error, "Property_0_of_type_1_is_not_assignable_to_2_index_type_3_2411", "Property '{0}' of type '{1}' is not assignable to '{2}' index type '{3}'."), _0_index_type_1_is_not_assignable_to_2_index_type_3: t3(2413, e.DiagnosticCategory.Error, "_0_index_type_1_is_not_assignable_to_2_index_type_3_2413", "'{0}' index type '{1}' is not assignable to '{2}' index type '{3}'."), Class_name_cannot_be_0: t3(2414, e.DiagnosticCategory.Error, "Class_name_cannot_be_0_2414", "Class name cannot be '{0}'."), Class_0_incorrectly_extends_base_class_1: t3(2415, e.DiagnosticCategory.Error, "Class_0_incorrectly_extends_base_class_1_2415", "Class '{0}' incorrectly extends base class '{1}'."), Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2: t3(2416, e.DiagnosticCategory.Error, "Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2_2416", "Property '{0}' in type '{1}' is not assignable to the same property in base type '{2}'."), Class_static_side_0_incorrectly_extends_base_class_static_side_1: t3(2417, e.DiagnosticCategory.Error, "Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417", "Class static side '{0}' incorrectly extends base class static side '{1}'."), Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1: t3(2418, e.DiagnosticCategory.Error, "Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1_2418", "Type of computed property's value is '{0}', which is not assignable to type '{1}'."), Types_of_construct_signatures_are_incompatible: t3(2419, e.DiagnosticCategory.Error, "Types_of_construct_signatures_are_incompatible_2419", "Types of construct signatures are incompatible."), Class_0_incorrectly_implements_interface_1: t3(2420, e.DiagnosticCategory.Error, "Class_0_incorrectly_implements_interface_1_2420", "Class '{0}' incorrectly implements interface '{1}'."), A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members: t3(2422, e.DiagnosticCategory.Error, "A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_memb_2422", "A class can only implement an object type or intersection of object types with statically known members."), Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor: t3(2423, e.DiagnosticCategory.Error, "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423", "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor."), Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function: t3(2425, e.DiagnosticCategory.Error, "Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425", "Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function."), Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function: t3(2426, e.DiagnosticCategory.Error, "Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426", "Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function."), Interface_name_cannot_be_0: t3(2427, e.DiagnosticCategory.Error, "Interface_name_cannot_be_0_2427", "Interface name cannot be '{0}'."), All_declarations_of_0_must_have_identical_type_parameters: t3(2428, e.DiagnosticCategory.Error, "All_declarations_of_0_must_have_identical_type_parameters_2428", "All declarations of '{0}' must have identical type parameters."), Interface_0_incorrectly_extends_interface_1: t3(2430, e.DiagnosticCategory.Error, "Interface_0_incorrectly_extends_interface_1_2430", "Interface '{0}' incorrectly extends interface '{1}'."), Enum_name_cannot_be_0: t3(2431, e.DiagnosticCategory.Error, "Enum_name_cannot_be_0_2431", "Enum name cannot be '{0}'."), In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element: t3(2432, e.DiagnosticCategory.Error, "In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432", "In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element."), A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged: t3(2433, e.DiagnosticCategory.Error, "A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433", "A namespace declaration cannot be in a different file from a class or function with which it is merged."), A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged: t3(2434, e.DiagnosticCategory.Error, "A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434", "A namespace declaration cannot be located prior to a class or function with which it is merged."), Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces: t3(2435, e.DiagnosticCategory.Error, "Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435", "Ambient modules cannot be nested in other modules or namespaces."), Ambient_module_declaration_cannot_specify_relative_module_name: t3(2436, e.DiagnosticCategory.Error, "Ambient_module_declaration_cannot_specify_relative_module_name_2436", "Ambient module declaration cannot specify relative module name."), Module_0_is_hidden_by_a_local_declaration_with_the_same_name: t3(2437, e.DiagnosticCategory.Error, "Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437", "Module '{0}' is hidden by a local declaration with the same name."), Import_name_cannot_be_0: t3(2438, e.DiagnosticCategory.Error, "Import_name_cannot_be_0_2438", "Import name cannot be '{0}'."), Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name: t3(2439, e.DiagnosticCategory.Error, "Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439", "Import or export declaration in an ambient module declaration cannot reference module through relative module name."), Import_declaration_conflicts_with_local_declaration_of_0: t3(2440, e.DiagnosticCategory.Error, "Import_declaration_conflicts_with_local_declaration_of_0_2440", "Import declaration conflicts with local declaration of '{0}'."), Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module: t3(2441, e.DiagnosticCategory.Error, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module."), Types_have_separate_declarations_of_a_private_property_0: t3(2442, e.DiagnosticCategory.Error, "Types_have_separate_declarations_of_a_private_property_0_2442", "Types have separate declarations of a private property '{0}'."), Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2: t3(2443, e.DiagnosticCategory.Error, "Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443", "Property '{0}' is protected but type '{1}' is not a class derived from '{2}'."), Property_0_is_protected_in_type_1_but_public_in_type_2: t3(2444, e.DiagnosticCategory.Error, "Property_0_is_protected_in_type_1_but_public_in_type_2_2444", "Property '{0}' is protected in type '{1}' but public in type '{2}'."), Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses: t3(2445, e.DiagnosticCategory.Error, "Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445", "Property '{0}' is protected and only accessible within class '{1}' and its subclasses."), Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2: t3(2446, e.DiagnosticCategory.Error, "Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_cl_2446", "Property '{0}' is protected and only accessible through an instance of class '{1}'. This is an instance of class '{2}'."), The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead: t3(2447, e.DiagnosticCategory.Error, "The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447", "The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead."), Block_scoped_variable_0_used_before_its_declaration: t3(2448, e.DiagnosticCategory.Error, "Block_scoped_variable_0_used_before_its_declaration_2448", "Block-scoped variable '{0}' used before its declaration."), Class_0_used_before_its_declaration: t3(2449, e.DiagnosticCategory.Error, "Class_0_used_before_its_declaration_2449", "Class '{0}' used before its declaration."), Enum_0_used_before_its_declaration: t3(2450, e.DiagnosticCategory.Error, "Enum_0_used_before_its_declaration_2450", "Enum '{0}' used before its declaration."), Cannot_redeclare_block_scoped_variable_0: t3(2451, e.DiagnosticCategory.Error, "Cannot_redeclare_block_scoped_variable_0_2451", "Cannot redeclare block-scoped variable '{0}'."), An_enum_member_cannot_have_a_numeric_name: t3(2452, e.DiagnosticCategory.Error, "An_enum_member_cannot_have_a_numeric_name_2452", "An enum member cannot have a numeric name."), Variable_0_is_used_before_being_assigned: t3(2454, e.DiagnosticCategory.Error, "Variable_0_is_used_before_being_assigned_2454", "Variable '{0}' is used before being assigned."), Type_alias_0_circularly_references_itself: t3(2456, e.DiagnosticCategory.Error, "Type_alias_0_circularly_references_itself_2456", "Type alias '{0}' circularly references itself."), Type_alias_name_cannot_be_0: t3(2457, e.DiagnosticCategory.Error, "Type_alias_name_cannot_be_0_2457", "Type alias name cannot be '{0}'."), An_AMD_module_cannot_have_multiple_name_assignments: t3(2458, e.DiagnosticCategory.Error, "An_AMD_module_cannot_have_multiple_name_assignments_2458", "An AMD module cannot have multiple name assignments."), Module_0_declares_1_locally_but_it_is_not_exported: t3(2459, e.DiagnosticCategory.Error, "Module_0_declares_1_locally_but_it_is_not_exported_2459", "Module '{0}' declares '{1}' locally, but it is not exported."), Module_0_declares_1_locally_but_it_is_exported_as_2: t3(2460, e.DiagnosticCategory.Error, "Module_0_declares_1_locally_but_it_is_exported_as_2_2460", "Module '{0}' declares '{1}' locally, but it is exported as '{2}'."), Type_0_is_not_an_array_type: t3(2461, e.DiagnosticCategory.Error, "Type_0_is_not_an_array_type_2461", "Type '{0}' is not an array type."), A_rest_element_must_be_last_in_a_destructuring_pattern: t3(2462, e.DiagnosticCategory.Error, "A_rest_element_must_be_last_in_a_destructuring_pattern_2462", "A rest element must be last in a destructuring pattern."), A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature: t3(2463, e.DiagnosticCategory.Error, "A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463", "A binding pattern parameter cannot be optional in an implementation signature."), A_computed_property_name_must_be_of_type_string_number_symbol_or_any: t3(2464, e.DiagnosticCategory.Error, "A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464", "A computed property name must be of type 'string', 'number', 'symbol', or 'any'."), this_cannot_be_referenced_in_a_computed_property_name: t3(2465, e.DiagnosticCategory.Error, "this_cannot_be_referenced_in_a_computed_property_name_2465", "'this' cannot be referenced in a computed property name."), super_cannot_be_referenced_in_a_computed_property_name: t3(2466, e.DiagnosticCategory.Error, "super_cannot_be_referenced_in_a_computed_property_name_2466", "'super' cannot be referenced in a computed property name."), A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type: t3(2467, e.DiagnosticCategory.Error, "A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467", "A computed property name cannot reference a type parameter from its containing type."), Cannot_find_global_value_0: t3(2468, e.DiagnosticCategory.Error, "Cannot_find_global_value_0_2468", "Cannot find global value '{0}'."), The_0_operator_cannot_be_applied_to_type_symbol: t3(2469, e.DiagnosticCategory.Error, "The_0_operator_cannot_be_applied_to_type_symbol_2469", "The '{0}' operator cannot be applied to type 'symbol'."), Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher: t3(2472, e.DiagnosticCategory.Error, "Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472", "Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher."), Enum_declarations_must_all_be_const_or_non_const: t3(2473, e.DiagnosticCategory.Error, "Enum_declarations_must_all_be_const_or_non_const_2473", "Enum declarations must all be const or non-const."), const_enum_member_initializers_can_only_contain_literal_values_and_other_computed_enum_values: t3(2474, e.DiagnosticCategory.Error, "const_enum_member_initializers_can_only_contain_literal_values_and_other_computed_enum_values_2474", "const enum member initializers can only contain literal values and other computed enum values."), const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query: t3(2475, e.DiagnosticCategory.Error, "const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475", "'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment or type query."), A_const_enum_member_can_only_be_accessed_using_a_string_literal: t3(2476, e.DiagnosticCategory.Error, "A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476", "A const enum member can only be accessed using a string literal."), const_enum_member_initializer_was_evaluated_to_a_non_finite_value: t3(2477, e.DiagnosticCategory.Error, "const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477", "'const' enum member initializer was evaluated to a non-finite value."), const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN: t3(2478, e.DiagnosticCategory.Error, "const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478", "'const' enum member initializer was evaluated to disallowed value 'NaN'."), let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations: t3(2480, e.DiagnosticCategory.Error, "let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480", "'let' is not allowed to be used as a name in 'let' or 'const' declarations."), Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1: t3(2481, e.DiagnosticCategory.Error, "Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481", "Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'."), The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation: t3(2483, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483", "The left-hand side of a 'for...of' statement cannot use a type annotation."), Export_declaration_conflicts_with_exported_declaration_of_0: t3(2484, e.DiagnosticCategory.Error, "Export_declaration_conflicts_with_exported_declaration_of_0_2484", "Export declaration conflicts with exported declaration of '{0}'."), The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access: t3(2487, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access_2487", "The left-hand side of a 'for...of' statement must be a variable or a property access."), Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator: t3(2488, e.DiagnosticCategory.Error, "Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488", "Type '{0}' must have a '[Symbol.iterator]()' method that returns an iterator."), An_iterator_must_have_a_next_method: t3(2489, e.DiagnosticCategory.Error, "An_iterator_must_have_a_next_method_2489", "An iterator must have a 'next()' method."), The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property: t3(2490, e.DiagnosticCategory.Error, "The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property_2490", "The type returned by the '{0}()' method of an iterator must have a 'value' property."), The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern: t3(2491, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491", "The left-hand side of a 'for...in' statement cannot be a destructuring pattern."), Cannot_redeclare_identifier_0_in_catch_clause: t3(2492, e.DiagnosticCategory.Error, "Cannot_redeclare_identifier_0_in_catch_clause_2492", "Cannot redeclare identifier '{0}' in catch clause."), Tuple_type_0_of_length_1_has_no_element_at_index_2: t3(2493, e.DiagnosticCategory.Error, "Tuple_type_0_of_length_1_has_no_element_at_index_2_2493", "Tuple type '{0}' of length '{1}' has no element at index '{2}'."), Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher: t3(2494, e.DiagnosticCategory.Error, "Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494", "Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher."), Type_0_is_not_an_array_type_or_a_string_type: t3(2495, e.DiagnosticCategory.Error, "Type_0_is_not_an_array_type_or_a_string_type_2495", "Type '{0}' is not an array type or a string type."), The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression: t3(2496, e.DiagnosticCategory.Error, "The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_stand_2496", "The 'arguments' object cannot be referenced in an arrow function in ES3 and ES5. Consider using a standard function expression."), This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export: t3(2497, e.DiagnosticCategory.Error, "This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_2497", "This module can only be referenced with ECMAScript imports/exports by turning on the '{0}' flag and referencing its default export."), Module_0_uses_export_and_cannot_be_used_with_export_Asterisk: t3(2498, e.DiagnosticCategory.Error, "Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498", "Module '{0}' uses 'export =' and cannot be used with 'export *'."), An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments: t3(2499, e.DiagnosticCategory.Error, "An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499", "An interface can only extend an identifier/qualified-name with optional type arguments."), A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments: t3(2500, e.DiagnosticCategory.Error, "A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500", "A class can only implement an identifier/qualified-name with optional type arguments."), A_rest_element_cannot_contain_a_binding_pattern: t3(2501, e.DiagnosticCategory.Error, "A_rest_element_cannot_contain_a_binding_pattern_2501", "A rest element cannot contain a binding pattern."), _0_is_referenced_directly_or_indirectly_in_its_own_type_annotation: t3(2502, e.DiagnosticCategory.Error, "_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502", "'{0}' is referenced directly or indirectly in its own type annotation."), Cannot_find_namespace_0: t3(2503, e.DiagnosticCategory.Error, "Cannot_find_namespace_0_2503", "Cannot find namespace '{0}'."), Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator: t3(2504, e.DiagnosticCategory.Error, "Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator_2504", "Type '{0}' must have a '[Symbol.asyncIterator]()' method that returns an async iterator."), A_generator_cannot_have_a_void_type_annotation: t3(2505, e.DiagnosticCategory.Error, "A_generator_cannot_have_a_void_type_annotation_2505", "A generator cannot have a 'void' type annotation."), _0_is_referenced_directly_or_indirectly_in_its_own_base_expression: t3(2506, e.DiagnosticCategory.Error, "_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506", "'{0}' is referenced directly or indirectly in its own base expression."), Type_0_is_not_a_constructor_function_type: t3(2507, e.DiagnosticCategory.Error, "Type_0_is_not_a_constructor_function_type_2507", "Type '{0}' is not a constructor function type."), No_base_constructor_has_the_specified_number_of_type_arguments: t3(2508, e.DiagnosticCategory.Error, "No_base_constructor_has_the_specified_number_of_type_arguments_2508", "No base constructor has the specified number of type arguments."), Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members: t3(2509, e.DiagnosticCategory.Error, "Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_2509", "Base constructor return type '{0}' is not an object type or intersection of object types with statically known members."), Base_constructors_must_all_have_the_same_return_type: t3(2510, e.DiagnosticCategory.Error, "Base_constructors_must_all_have_the_same_return_type_2510", "Base constructors must all have the same return type."), Cannot_create_an_instance_of_an_abstract_class: t3(2511, e.DiagnosticCategory.Error, "Cannot_create_an_instance_of_an_abstract_class_2511", "Cannot create an instance of an abstract class."), Overload_signatures_must_all_be_abstract_or_non_abstract: t3(2512, e.DiagnosticCategory.Error, "Overload_signatures_must_all_be_abstract_or_non_abstract_2512", "Overload signatures must all be abstract or non-abstract."), Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression: t3(2513, e.DiagnosticCategory.Error, "Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513", "Abstract method '{0}' in class '{1}' cannot be accessed via super expression."), A_tuple_type_cannot_be_indexed_with_a_negative_value: t3(2514, e.DiagnosticCategory.Error, "A_tuple_type_cannot_be_indexed_with_a_negative_value_2514", "A tuple type cannot be indexed with a negative value."), Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2: t3(2515, e.DiagnosticCategory.Error, "Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515", "Non-abstract class '{0}' does not implement inherited abstract member '{1}' from class '{2}'."), All_declarations_of_an_abstract_method_must_be_consecutive: t3(2516, e.DiagnosticCategory.Error, "All_declarations_of_an_abstract_method_must_be_consecutive_2516", "All declarations of an abstract method must be consecutive."), Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type: t3(2517, e.DiagnosticCategory.Error, "Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517", "Cannot assign an abstract constructor type to a non-abstract constructor type."), A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard: t3(2518, e.DiagnosticCategory.Error, "A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518", "A 'this'-based type guard is not compatible with a parameter-based type guard."), An_async_iterator_must_have_a_next_method: t3(2519, e.DiagnosticCategory.Error, "An_async_iterator_must_have_a_next_method_2519", "An async iterator must have a 'next()' method."), Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions: t3(2520, e.DiagnosticCategory.Error, "Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520", "Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions."), The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method: t3(2522, e.DiagnosticCategory.Error, "The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_usi_2522", "The 'arguments' object cannot be referenced in an async function or method in ES3 and ES5. Consider using a standard function or method."), yield_expressions_cannot_be_used_in_a_parameter_initializer: t3(2523, e.DiagnosticCategory.Error, "yield_expressions_cannot_be_used_in_a_parameter_initializer_2523", "'yield' expressions cannot be used in a parameter initializer."), await_expressions_cannot_be_used_in_a_parameter_initializer: t3(2524, e.DiagnosticCategory.Error, "await_expressions_cannot_be_used_in_a_parameter_initializer_2524", "'await' expressions cannot be used in a parameter initializer."), Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value: t3(2525, e.DiagnosticCategory.Error, "Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value_2525", "Initializer provides no value for this binding element and the binding element has no default value."), A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface: t3(2526, e.DiagnosticCategory.Error, "A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526", "A 'this' type is available only in a non-static member of a class or interface."), The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary: t3(2527, e.DiagnosticCategory.Error, "The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary_2527", "The inferred type of '{0}' references an inaccessible '{1}' type. A type annotation is necessary."), A_module_cannot_have_multiple_default_exports: t3(2528, e.DiagnosticCategory.Error, "A_module_cannot_have_multiple_default_exports_2528", "A module cannot have multiple default exports."), Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions: t3(2529, e.DiagnosticCategory.Error, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions."), Property_0_is_incompatible_with_index_signature: t3(2530, e.DiagnosticCategory.Error, "Property_0_is_incompatible_with_index_signature_2530", "Property '{0}' is incompatible with index signature."), Object_is_possibly_null: t3(2531, e.DiagnosticCategory.Error, "Object_is_possibly_null_2531", "Object is possibly 'null'."), Object_is_possibly_undefined: t3(2532, e.DiagnosticCategory.Error, "Object_is_possibly_undefined_2532", "Object is possibly 'undefined'."), Object_is_possibly_null_or_undefined: t3(2533, e.DiagnosticCategory.Error, "Object_is_possibly_null_or_undefined_2533", "Object is possibly 'null' or 'undefined'."), A_function_returning_never_cannot_have_a_reachable_end_point: t3(2534, e.DiagnosticCategory.Error, "A_function_returning_never_cannot_have_a_reachable_end_point_2534", "A function returning 'never' cannot have a reachable end point."), Enum_type_0_has_members_with_initializers_that_are_not_literals: t3(2535, e.DiagnosticCategory.Error, "Enum_type_0_has_members_with_initializers_that_are_not_literals_2535", "Enum type '{0}' has members with initializers that are not literals."), Type_0_cannot_be_used_to_index_type_1: t3(2536, e.DiagnosticCategory.Error, "Type_0_cannot_be_used_to_index_type_1_2536", "Type '{0}' cannot be used to index type '{1}'."), Type_0_has_no_matching_index_signature_for_type_1: t3(2537, e.DiagnosticCategory.Error, "Type_0_has_no_matching_index_signature_for_type_1_2537", "Type '{0}' has no matching index signature for type '{1}'."), Type_0_cannot_be_used_as_an_index_type: t3(2538, e.DiagnosticCategory.Error, "Type_0_cannot_be_used_as_an_index_type_2538", "Type '{0}' cannot be used as an index type."), Cannot_assign_to_0_because_it_is_not_a_variable: t3(2539, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_not_a_variable_2539", "Cannot assign to '{0}' because it is not a variable."), Cannot_assign_to_0_because_it_is_a_read_only_property: t3(2540, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_a_read_only_property_2540", "Cannot assign to '{0}' because it is a read-only property."), Index_signature_in_type_0_only_permits_reading: t3(2542, e.DiagnosticCategory.Error, "Index_signature_in_type_0_only_permits_reading_2542", "Index signature in type '{0}' only permits reading."), Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference: t3(2543, e.DiagnosticCategory.Error, "Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_me_2543", "Duplicate identifier '_newTarget'. Compiler uses variable declaration '_newTarget' to capture 'new.target' meta-property reference."), Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference: t3(2544, e.DiagnosticCategory.Error, "Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta__2544", "Expression resolves to variable declaration '_newTarget' that compiler uses to capture 'new.target' meta-property reference."), A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any: t3(2545, e.DiagnosticCategory.Error, "A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any_2545", "A mixin class must have a constructor with a single rest parameter of type 'any[]'."), The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property: t3(2547, e.DiagnosticCategory.Error, "The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_pro_2547", "The type returned by the '{0}()' method of an async iterator must be a promise for a type with a 'value' property."), Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: t3(2548, e.DiagnosticCategory.Error, "Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator_2548", "Type '{0}' is not an array type or does not have a '[Symbol.iterator]()' method that returns an iterator."), Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: t3(2549, e.DiagnosticCategory.Error, "Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns__2549", "Type '{0}' is not an array type or a string type or does not have a '[Symbol.iterator]()' method that returns an iterator."), Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later: t3(2550, e.DiagnosticCategory.Error, "Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_c_2550", "Property '{0}' does not exist on type '{1}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{2}' or later."), Property_0_does_not_exist_on_type_1_Did_you_mean_2: t3(2551, e.DiagnosticCategory.Error, "Property_0_does_not_exist_on_type_1_Did_you_mean_2_2551", "Property '{0}' does not exist on type '{1}'. Did you mean '{2}'?"), Cannot_find_name_0_Did_you_mean_1: t3(2552, e.DiagnosticCategory.Error, "Cannot_find_name_0_Did_you_mean_1_2552", "Cannot find name '{0}'. Did you mean '{1}'?"), Computed_values_are_not_permitted_in_an_enum_with_string_valued_members: t3(2553, e.DiagnosticCategory.Error, "Computed_values_are_not_permitted_in_an_enum_with_string_valued_members_2553", "Computed values are not permitted in an enum with string valued members."), Expected_0_arguments_but_got_1: t3(2554, e.DiagnosticCategory.Error, "Expected_0_arguments_but_got_1_2554", "Expected {0} arguments, but got {1}."), Expected_at_least_0_arguments_but_got_1: t3(2555, e.DiagnosticCategory.Error, "Expected_at_least_0_arguments_but_got_1_2555", "Expected at least {0} arguments, but got {1}."), A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter: t3(2556, e.DiagnosticCategory.Error, "A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter_2556", "A spread argument must either have a tuple type or be passed to a rest parameter."), Expected_0_type_arguments_but_got_1: t3(2558, e.DiagnosticCategory.Error, "Expected_0_type_arguments_but_got_1_2558", "Expected {0} type arguments, but got {1}."), Type_0_has_no_properties_in_common_with_type_1: t3(2559, e.DiagnosticCategory.Error, "Type_0_has_no_properties_in_common_with_type_1_2559", "Type '{0}' has no properties in common with type '{1}'."), Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it: t3(2560, e.DiagnosticCategory.Error, "Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it_2560", "Value of type '{0}' has no properties in common with type '{1}'. Did you mean to call it?"), Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2: t3(2561, e.DiagnosticCategory.Error, "Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_writ_2561", "Object literal may only specify known properties, but '{0}' does not exist in type '{1}'. Did you mean to write '{2}'?"), Base_class_expressions_cannot_reference_class_type_parameters: t3(2562, e.DiagnosticCategory.Error, "Base_class_expressions_cannot_reference_class_type_parameters_2562", "Base class expressions cannot reference class type parameters."), The_containing_function_or_module_body_is_too_large_for_control_flow_analysis: t3(2563, e.DiagnosticCategory.Error, "The_containing_function_or_module_body_is_too_large_for_control_flow_analysis_2563", "The containing function or module body is too large for control flow analysis."), Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor: t3(2564, e.DiagnosticCategory.Error, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor_2564", "Property '{0}' has no initializer and is not definitely assigned in the constructor."), Property_0_is_used_before_being_assigned: t3(2565, e.DiagnosticCategory.Error, "Property_0_is_used_before_being_assigned_2565", "Property '{0}' is used before being assigned."), A_rest_element_cannot_have_a_property_name: t3(2566, e.DiagnosticCategory.Error, "A_rest_element_cannot_have_a_property_name_2566", "A rest element cannot have a property name."), Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations: t3(2567, e.DiagnosticCategory.Error, "Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations_2567", "Enum declarations can only merge with namespace or other enum declarations."), Property_0_may_not_exist_on_type_1_Did_you_mean_2: t3(2568, e.DiagnosticCategory.Error, "Property_0_may_not_exist_on_type_1_Did_you_mean_2_2568", "Property '{0}' may not exist on type '{1}'. Did you mean '{2}'?"), Could_not_find_name_0_Did_you_mean_1: t3(2570, e.DiagnosticCategory.Error, "Could_not_find_name_0_Did_you_mean_1_2570", "Could not find name '{0}'. Did you mean '{1}'?"), Object_is_of_type_unknown: t3(2571, e.DiagnosticCategory.Error, "Object_is_of_type_unknown_2571", "Object is of type 'unknown'."), A_rest_element_type_must_be_an_array_type: t3(2574, e.DiagnosticCategory.Error, "A_rest_element_type_must_be_an_array_type_2574", "A rest element type must be an array type."), No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments: t3(2575, e.DiagnosticCategory.Error, "No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments_2575", "No overload expects {0} arguments, but overloads do exist that expect either {1} or {2} arguments."), Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead: t3(2576, e.DiagnosticCategory.Error, "Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead_2576", "Property '{0}' does not exist on type '{1}'. Did you mean to access the static member '{2}' instead?"), Return_type_annotation_circularly_references_itself: t3(2577, e.DiagnosticCategory.Error, "Return_type_annotation_circularly_references_itself_2577", "Return type annotation circularly references itself."), Unused_ts_expect_error_directive: t3(2578, e.DiagnosticCategory.Error, "Unused_ts_expect_error_directive_2578", "Unused '@ts-expect-error' directive."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode: t3(2580, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2580", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node`."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery: t3(2581, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2581", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery`."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha: t3(2582, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2582", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha`."), Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later: t3(2583, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2583", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{1}' or later."), Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom: t3(2584, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2584", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to include 'dom'."), _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later: t3(2585, e.DiagnosticCategory.Error, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_2585", "'{0}' only refers to a type, but is being used as a value here. Do you need to change your target library? Try changing the 'lib' compiler option to es2015 or later."), Cannot_assign_to_0_because_it_is_a_constant: t3(2588, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_a_constant_2588", "Cannot assign to '{0}' because it is a constant."), Type_instantiation_is_excessively_deep_and_possibly_infinite: t3(2589, e.DiagnosticCategory.Error, "Type_instantiation_is_excessively_deep_and_possibly_infinite_2589", "Type instantiation is excessively deep and possibly infinite."), Expression_produces_a_union_type_that_is_too_complex_to_represent: t3(2590, e.DiagnosticCategory.Error, "Expression_produces_a_union_type_that_is_too_complex_to_represent_2590", "Expression produces a union type that is too complex to represent."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig: t3(2591, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2591", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node` and then add 'node' to the types field in your tsconfig."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig: t3(2592, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2592", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery` and then add 'jquery' to the types field in your tsconfig."), Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig: t3(2593, e.DiagnosticCategory.Error, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2593", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha` and then add 'jest' or 'mocha' to the types field in your tsconfig."), This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag: t3(2594, e.DiagnosticCategory.Error, "This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag_2594", "This module is declared with 'export =', and can only be used with a default import when using the '{0}' flag."), _0_can_only_be_imported_by_using_a_default_import: t3(2595, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_using_a_default_import_2595", "'{0}' can only be imported by using a default import."), _0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: t3(2596, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import_2596", "'{0}' can only be imported by turning on the 'esModuleInterop' flag and using a default import."), _0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import: t3(2597, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import_2597", "'{0}' can only be imported by using a 'require' call or by using a default import."), _0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: t3(2598, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using__2598", "'{0}' can only be imported by using a 'require' call or by turning on the 'esModuleInterop' flag and using a default import."), JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist: t3(2602, e.DiagnosticCategory.Error, "JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602", "JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist."), Property_0_in_type_1_is_not_assignable_to_type_2: t3(2603, e.DiagnosticCategory.Error, "Property_0_in_type_1_is_not_assignable_to_type_2_2603", "Property '{0}' in type '{1}' is not assignable to type '{2}'."), JSX_element_type_0_does_not_have_any_construct_or_call_signatures: t3(2604, e.DiagnosticCategory.Error, "JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604", "JSX element type '{0}' does not have any construct or call signatures."), Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property: t3(2606, e.DiagnosticCategory.Error, "Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606", "Property '{0}' of JSX spread attribute is not assignable to target property."), JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property: t3(2607, e.DiagnosticCategory.Error, "JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607", "JSX element class does not support attributes because it does not have a '{0}' property."), The_global_type_JSX_0_may_not_have_more_than_one_property: t3(2608, e.DiagnosticCategory.Error, "The_global_type_JSX_0_may_not_have_more_than_one_property_2608", "The global type 'JSX.{0}' may not have more than one property."), JSX_spread_child_must_be_an_array_type: t3(2609, e.DiagnosticCategory.Error, "JSX_spread_child_must_be_an_array_type_2609", "JSX spread child must be an array type."), _0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property: t3(2610, e.DiagnosticCategory.Error, "_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property_2610", "'{0}' is defined as an accessor in class '{1}', but is overridden here in '{2}' as an instance property."), _0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor: t3(2611, e.DiagnosticCategory.Error, "_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor_2611", "'{0}' is defined as a property in class '{1}', but is overridden here in '{2}' as an accessor."), Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration: t3(2612, e.DiagnosticCategory.Error, "Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_2612", "Property '{0}' will overwrite the base property in '{1}'. If this is intentional, add an initializer. Otherwise, add a 'declare' modifier or remove the redundant declaration."), Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead: t3(2613, e.DiagnosticCategory.Error, "Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead_2613", "Module '{0}' has no default export. Did you mean to use 'import { {1} } from {0}' instead?"), Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead: t3(2614, e.DiagnosticCategory.Error, "Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead_2614", "Module '{0}' has no exported member '{1}'. Did you mean to use 'import {1} from {0}' instead?"), Type_of_property_0_circularly_references_itself_in_mapped_type_1: t3(2615, e.DiagnosticCategory.Error, "Type_of_property_0_circularly_references_itself_in_mapped_type_1_2615", "Type of property '{0}' circularly references itself in mapped type '{1}'."), _0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import: t3(2616, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import_2616", "'{0}' can only be imported by using 'import {1} = require({2})' or a default import."), _0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: t3(2617, e.DiagnosticCategory.Error, "_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_us_2617", "'{0}' can only be imported by using 'import {1} = require({2})' or by turning on the 'esModuleInterop' flag and using a default import."), Source_has_0_element_s_but_target_requires_1: t3(2618, e.DiagnosticCategory.Error, "Source_has_0_element_s_but_target_requires_1_2618", "Source has {0} element(s) but target requires {1}."), Source_has_0_element_s_but_target_allows_only_1: t3(2619, e.DiagnosticCategory.Error, "Source_has_0_element_s_but_target_allows_only_1_2619", "Source has {0} element(s) but target allows only {1}."), Target_requires_0_element_s_but_source_may_have_fewer: t3(2620, e.DiagnosticCategory.Error, "Target_requires_0_element_s_but_source_may_have_fewer_2620", "Target requires {0} element(s) but source may have fewer."), Target_allows_only_0_element_s_but_source_may_have_more: t3(2621, e.DiagnosticCategory.Error, "Target_allows_only_0_element_s_but_source_may_have_more_2621", "Target allows only {0} element(s) but source may have more."), Source_provides_no_match_for_required_element_at_position_0_in_target: t3(2623, e.DiagnosticCategory.Error, "Source_provides_no_match_for_required_element_at_position_0_in_target_2623", "Source provides no match for required element at position {0} in target."), Source_provides_no_match_for_variadic_element_at_position_0_in_target: t3(2624, e.DiagnosticCategory.Error, "Source_provides_no_match_for_variadic_element_at_position_0_in_target_2624", "Source provides no match for variadic element at position {0} in target."), Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target: t3(2625, e.DiagnosticCategory.Error, "Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target_2625", "Variadic element at position {0} in source does not match element at position {1} in target."), Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target: t3(2626, e.DiagnosticCategory.Error, "Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target_2626", "Type at position {0} in source is not compatible with type at position {1} in target."), Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target: t3(2627, e.DiagnosticCategory.Error, "Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target_2627", "Type at positions {0} through {1} in source is not compatible with type at position {2} in target."), Cannot_assign_to_0_because_it_is_an_enum: t3(2628, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_an_enum_2628", "Cannot assign to '{0}' because it is an enum."), Cannot_assign_to_0_because_it_is_a_class: t3(2629, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_a_class_2629", "Cannot assign to '{0}' because it is a class."), Cannot_assign_to_0_because_it_is_a_function: t3(2630, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_a_function_2630", "Cannot assign to '{0}' because it is a function."), Cannot_assign_to_0_because_it_is_a_namespace: t3(2631, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_a_namespace_2631", "Cannot assign to '{0}' because it is a namespace."), Cannot_assign_to_0_because_it_is_an_import: t3(2632, e.DiagnosticCategory.Error, "Cannot_assign_to_0_because_it_is_an_import_2632", "Cannot assign to '{0}' because it is an import."), JSX_property_access_expressions_cannot_include_JSX_namespace_names: t3(2633, e.DiagnosticCategory.Error, "JSX_property_access_expressions_cannot_include_JSX_namespace_names_2633", "JSX property access expressions cannot include JSX namespace names"), _0_index_signatures_are_incompatible: t3(2634, e.DiagnosticCategory.Error, "_0_index_signatures_are_incompatible_2634", "'{0}' index signatures are incompatible."), Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable: t3(2635, e.DiagnosticCategory.Error, "Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable_2635", "Type '{0}' has no signatures for which the type argument list is applicable."), Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation: t3(2636, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation_2636", "Type '{0}' is not assignable to type '{1}' as implied by variance annotation."), Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types: t3(2637, e.DiagnosticCategory.Error, "Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_t_2637", "Variance annotations are only supported in type aliases for object, function, constructor, and mapped types."), Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator: t3(2638, e.DiagnosticCategory.Error, "Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operato_2638", "Type '{0}' may represent a primitive value, which is not permitted as the right operand of the 'in' operator."), Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity: t3(2649, e.DiagnosticCategory.Error, "Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity_2649", "Cannot augment module '{0}' with value exports because it resolves to a non-module entity."), A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums: t3(2651, e.DiagnosticCategory.Error, "A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651", "A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums."), Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead: t3(2652, e.DiagnosticCategory.Error, "Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652", "Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead."), Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1: t3(2653, e.DiagnosticCategory.Error, "Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653", "Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'."), JSX_expressions_must_have_one_parent_element: t3(2657, e.DiagnosticCategory.Error, "JSX_expressions_must_have_one_parent_element_2657", "JSX expressions must have one parent element."), Type_0_provides_no_match_for_the_signature_1: t3(2658, e.DiagnosticCategory.Error, "Type_0_provides_no_match_for_the_signature_1_2658", "Type '{0}' provides no match for the signature '{1}'."), super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher: t3(2659, e.DiagnosticCategory.Error, "super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659", "'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher."), super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions: t3(2660, e.DiagnosticCategory.Error, "super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660", "'super' can only be referenced in members of derived classes or object literal expressions."), Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module: t3(2661, e.DiagnosticCategory.Error, "Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module_2661", "Cannot export '{0}'. Only local declarations can be exported from a module."), Cannot_find_name_0_Did_you_mean_the_static_member_1_0: t3(2662, e.DiagnosticCategory.Error, "Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662", "Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?"), Cannot_find_name_0_Did_you_mean_the_instance_member_this_0: t3(2663, e.DiagnosticCategory.Error, "Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663", "Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?"), Invalid_module_name_in_augmentation_module_0_cannot_be_found: t3(2664, e.DiagnosticCategory.Error, "Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664", "Invalid module name in augmentation, module '{0}' cannot be found."), Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented: t3(2665, e.DiagnosticCategory.Error, "Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augm_2665", "Invalid module name in augmentation. Module '{0}' resolves to an untyped module at '{1}', which cannot be augmented."), Exports_and_export_assignments_are_not_permitted_in_module_augmentations: t3(2666, e.DiagnosticCategory.Error, "Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666", "Exports and export assignments are not permitted in module augmentations."), Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module: t3(2667, e.DiagnosticCategory.Error, "Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667", "Imports are not permitted in module augmentations. Consider moving them to the enclosing external module."), export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible: t3(2668, e.DiagnosticCategory.Error, "export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668", "'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible."), Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations: t3(2669, e.DiagnosticCategory.Error, "Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669", "Augmentations for the global scope can only be directly nested in external modules or ambient module declarations."), Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context: t3(2670, e.DiagnosticCategory.Error, "Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670", "Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context."), Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity: t3(2671, e.DiagnosticCategory.Error, "Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671", "Cannot augment module '{0}' because it resolves to a non-module entity."), Cannot_assign_a_0_constructor_type_to_a_1_constructor_type: t3(2672, e.DiagnosticCategory.Error, "Cannot_assign_a_0_constructor_type_to_a_1_constructor_type_2672", "Cannot assign a '{0}' constructor type to a '{1}' constructor type."), Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration: t3(2673, e.DiagnosticCategory.Error, "Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration_2673", "Constructor of class '{0}' is private and only accessible within the class declaration."), Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration: t3(2674, e.DiagnosticCategory.Error, "Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration_2674", "Constructor of class '{0}' is protected and only accessible within the class declaration."), Cannot_extend_a_class_0_Class_constructor_is_marked_as_private: t3(2675, e.DiagnosticCategory.Error, "Cannot_extend_a_class_0_Class_constructor_is_marked_as_private_2675", "Cannot extend a class '{0}'. Class constructor is marked as private."), Accessors_must_both_be_abstract_or_non_abstract: t3(2676, e.DiagnosticCategory.Error, "Accessors_must_both_be_abstract_or_non_abstract_2676", "Accessors must both be abstract or non-abstract."), A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type: t3(2677, e.DiagnosticCategory.Error, "A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type_2677", "A type predicate's type must be assignable to its parameter's type."), Type_0_is_not_comparable_to_type_1: t3(2678, e.DiagnosticCategory.Error, "Type_0_is_not_comparable_to_type_1_2678", "Type '{0}' is not comparable to type '{1}'."), A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void: t3(2679, e.DiagnosticCategory.Error, "A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void_2679", "A function that is called with the 'new' keyword cannot have a 'this' type that is 'void'."), A_0_parameter_must_be_the_first_parameter: t3(2680, e.DiagnosticCategory.Error, "A_0_parameter_must_be_the_first_parameter_2680", "A '{0}' parameter must be the first parameter."), A_constructor_cannot_have_a_this_parameter: t3(2681, e.DiagnosticCategory.Error, "A_constructor_cannot_have_a_this_parameter_2681", "A constructor cannot have a 'this' parameter."), this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation: t3(2683, e.DiagnosticCategory.Error, "this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_2683", "'this' implicitly has type 'any' because it does not have a type annotation."), The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1: t3(2684, e.DiagnosticCategory.Error, "The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1_2684", "The 'this' context of type '{0}' is not assignable to method's 'this' of type '{1}'."), The_this_types_of_each_signature_are_incompatible: t3(2685, e.DiagnosticCategory.Error, "The_this_types_of_each_signature_are_incompatible_2685", "The 'this' types of each signature are incompatible."), _0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead: t3(2686, e.DiagnosticCategory.Error, "_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead_2686", "'{0}' refers to a UMD global, but the current file is a module. Consider adding an import instead."), All_declarations_of_0_must_have_identical_modifiers: t3(2687, e.DiagnosticCategory.Error, "All_declarations_of_0_must_have_identical_modifiers_2687", "All declarations of '{0}' must have identical modifiers."), Cannot_find_type_definition_file_for_0: t3(2688, e.DiagnosticCategory.Error, "Cannot_find_type_definition_file_for_0_2688", "Cannot find type definition file for '{0}'."), Cannot_extend_an_interface_0_Did_you_mean_implements: t3(2689, e.DiagnosticCategory.Error, "Cannot_extend_an_interface_0_Did_you_mean_implements_2689", "Cannot extend an interface '{0}'. Did you mean 'implements'?"), _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0: t3(2690, e.DiagnosticCategory.Error, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0_2690", "'{0}' only refers to a type, but is being used as a value here. Did you mean to use '{1} in {0}'?"), An_import_path_cannot_end_with_a_0_extension_Consider_importing_1_instead: t3(2691, e.DiagnosticCategory.Error, "An_import_path_cannot_end_with_a_0_extension_Consider_importing_1_instead_2691", "An import path cannot end with a '{0}' extension. Consider importing '{1}' instead."), _0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible: t3(2692, e.DiagnosticCategory.Error, "_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible_2692", "'{0}' is a primitive, but '{1}' is a wrapper object. Prefer using '{0}' when possible."), _0_only_refers_to_a_type_but_is_being_used_as_a_value_here: t3(2693, e.DiagnosticCategory.Error, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_2693", "'{0}' only refers to a type, but is being used as a value here."), Namespace_0_has_no_exported_member_1: t3(2694, e.DiagnosticCategory.Error, "Namespace_0_has_no_exported_member_1_2694", "Namespace '{0}' has no exported member '{1}'."), Left_side_of_comma_operator_is_unused_and_has_no_side_effects: t3(2695, e.DiagnosticCategory.Error, "Left_side_of_comma_operator_is_unused_and_has_no_side_effects_2695", "Left side of comma operator is unused and has no side effects.", true), The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead: t3(2696, e.DiagnosticCategory.Error, "The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead_2696", "The 'Object' type is assignable to very few other types. Did you mean to use the 'any' type instead?"), An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: t3(2697, e.DiagnosticCategory.Error, "An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_in_2697", "An async function or method must return a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."), Spread_types_may_only_be_created_from_object_types: t3(2698, e.DiagnosticCategory.Error, "Spread_types_may_only_be_created_from_object_types_2698", "Spread types may only be created from object types."), Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1: t3(2699, e.DiagnosticCategory.Error, "Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1_2699", "Static property '{0}' conflicts with built-in property 'Function.{0}' of constructor function '{1}'."), Rest_types_may_only_be_created_from_object_types: t3(2700, e.DiagnosticCategory.Error, "Rest_types_may_only_be_created_from_object_types_2700", "Rest types may only be created from object types."), The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access: t3(2701, e.DiagnosticCategory.Error, "The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access_2701", "The target of an object rest assignment must be a variable or a property access."), _0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here: t3(2702, e.DiagnosticCategory.Error, "_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here_2702", "'{0}' only refers to a type, but is being used as a namespace here."), The_operand_of_a_delete_operator_must_be_a_property_reference: t3(2703, e.DiagnosticCategory.Error, "The_operand_of_a_delete_operator_must_be_a_property_reference_2703", "The operand of a 'delete' operator must be a property reference."), The_operand_of_a_delete_operator_cannot_be_a_read_only_property: t3(2704, e.DiagnosticCategory.Error, "The_operand_of_a_delete_operator_cannot_be_a_read_only_property_2704", "The operand of a 'delete' operator cannot be a read-only property."), An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: t3(2705, e.DiagnosticCategory.Error, "An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_de_2705", "An async function or method in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."), Required_type_parameters_may_not_follow_optional_type_parameters: t3(2706, e.DiagnosticCategory.Error, "Required_type_parameters_may_not_follow_optional_type_parameters_2706", "Required type parameters may not follow optional type parameters."), Generic_type_0_requires_between_1_and_2_type_arguments: t3(2707, e.DiagnosticCategory.Error, "Generic_type_0_requires_between_1_and_2_type_arguments_2707", "Generic type '{0}' requires between {1} and {2} type arguments."), Cannot_use_namespace_0_as_a_value: t3(2708, e.DiagnosticCategory.Error, "Cannot_use_namespace_0_as_a_value_2708", "Cannot use namespace '{0}' as a value."), Cannot_use_namespace_0_as_a_type: t3(2709, e.DiagnosticCategory.Error, "Cannot_use_namespace_0_as_a_type_2709", "Cannot use namespace '{0}' as a type."), _0_are_specified_twice_The_attribute_named_0_will_be_overwritten: t3(2710, e.DiagnosticCategory.Error, "_0_are_specified_twice_The_attribute_named_0_will_be_overwritten_2710", "'{0}' are specified twice. The attribute named '{0}' will be overwritten."), A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: t3(2711, e.DiagnosticCategory.Error, "A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES20_2711", "A dynamic import call returns a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."), A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: t3(2712, e.DiagnosticCategory.Error, "A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declarat_2712", "A dynamic import call in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."), Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1: t3(2713, e.DiagnosticCategory.Error, "Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_p_2713", `Cannot access '{0}.{1}' because '{0}' is a type, but not a namespace. Did you mean to retrieve the type of the property '{1}' in '{0}' with '{0}["{1}"]'?`), The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context: t3(2714, e.DiagnosticCategory.Error, "The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context_2714", "The expression of an export assignment must be an identifier or qualified name in an ambient context."), Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor: t3(2715, e.DiagnosticCategory.Error, "Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor_2715", "Abstract property '{0}' in class '{1}' cannot be accessed in the constructor."), Type_parameter_0_has_a_circular_default: t3(2716, e.DiagnosticCategory.Error, "Type_parameter_0_has_a_circular_default_2716", "Type parameter '{0}' has a circular default."), Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2: t3(2717, e.DiagnosticCategory.Error, "Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_t_2717", "Subsequent property declarations must have the same type.  Property '{0}' must be of type '{1}', but here has type '{2}'."), Duplicate_property_0: t3(2718, e.DiagnosticCategory.Error, "Duplicate_property_0_2718", "Duplicate property '{0}'."), Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated: t3(2719, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated_2719", "Type '{0}' is not assignable to type '{1}'. Two different types with this name exist, but they are unrelated."), Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass: t3(2720, e.DiagnosticCategory.Error, "Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclas_2720", "Class '{0}' incorrectly implements class '{1}'. Did you mean to extend '{1}' and inherit its members as a subclass?"), Cannot_invoke_an_object_which_is_possibly_null: t3(2721, e.DiagnosticCategory.Error, "Cannot_invoke_an_object_which_is_possibly_null_2721", "Cannot invoke an object which is possibly 'null'."), Cannot_invoke_an_object_which_is_possibly_undefined: t3(2722, e.DiagnosticCategory.Error, "Cannot_invoke_an_object_which_is_possibly_undefined_2722", "Cannot invoke an object which is possibly 'undefined'."), Cannot_invoke_an_object_which_is_possibly_null_or_undefined: t3(2723, e.DiagnosticCategory.Error, "Cannot_invoke_an_object_which_is_possibly_null_or_undefined_2723", "Cannot invoke an object which is possibly 'null' or 'undefined'."), _0_has_no_exported_member_named_1_Did_you_mean_2: t3(2724, e.DiagnosticCategory.Error, "_0_has_no_exported_member_named_1_Did_you_mean_2_2724", "'{0}' has no exported member named '{1}'. Did you mean '{2}'?"), Class_name_cannot_be_Object_when_targeting_ES5_with_module_0: t3(2725, e.DiagnosticCategory.Error, "Class_name_cannot_be_Object_when_targeting_ES5_with_module_0_2725", "Class name cannot be 'Object' when targeting ES5 with module {0}."), Cannot_find_lib_definition_for_0: t3(2726, e.DiagnosticCategory.Error, "Cannot_find_lib_definition_for_0_2726", "Cannot find lib definition for '{0}'."), Cannot_find_lib_definition_for_0_Did_you_mean_1: t3(2727, e.DiagnosticCategory.Error, "Cannot_find_lib_definition_for_0_Did_you_mean_1_2727", "Cannot find lib definition for '{0}'. Did you mean '{1}'?"), _0_is_declared_here: t3(2728, e.DiagnosticCategory.Message, "_0_is_declared_here_2728", "'{0}' is declared here."), Property_0_is_used_before_its_initialization: t3(2729, e.DiagnosticCategory.Error, "Property_0_is_used_before_its_initialization_2729", "Property '{0}' is used before its initialization."), An_arrow_function_cannot_have_a_this_parameter: t3(2730, e.DiagnosticCategory.Error, "An_arrow_function_cannot_have_a_this_parameter_2730", "An arrow function cannot have a 'this' parameter."), Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String: t3(2731, e.DiagnosticCategory.Error, "Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_i_2731", "Implicit conversion of a 'symbol' to a 'string' will fail at runtime. Consider wrapping this expression in 'String(...)'."), Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension: t3(2732, e.DiagnosticCategory.Error, "Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension_2732", "Cannot find module '{0}'. Consider using '--resolveJsonModule' to import module with '.json' extension."), Property_0_was_also_declared_here: t3(2733, e.DiagnosticCategory.Error, "Property_0_was_also_declared_here_2733", "Property '{0}' was also declared here."), Are_you_missing_a_semicolon: t3(2734, e.DiagnosticCategory.Error, "Are_you_missing_a_semicolon_2734", "Are you missing a semicolon?"), Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1: t3(2735, e.DiagnosticCategory.Error, "Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1_2735", "Did you mean for '{0}' to be constrained to type 'new (...args: any[]) => {1}'?"), Operator_0_cannot_be_applied_to_type_1: t3(2736, e.DiagnosticCategory.Error, "Operator_0_cannot_be_applied_to_type_1_2736", "Operator '{0}' cannot be applied to type '{1}'."), BigInt_literals_are_not_available_when_targeting_lower_than_ES2020: t3(2737, e.DiagnosticCategory.Error, "BigInt_literals_are_not_available_when_targeting_lower_than_ES2020_2737", "BigInt literals are not available when targeting lower than ES2020."), An_outer_value_of_this_is_shadowed_by_this_container: t3(2738, e.DiagnosticCategory.Message, "An_outer_value_of_this_is_shadowed_by_this_container_2738", "An outer value of 'this' is shadowed by this container."), Type_0_is_missing_the_following_properties_from_type_1_Colon_2: t3(2739, e.DiagnosticCategory.Error, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_2739", "Type '{0}' is missing the following properties from type '{1}': {2}"), Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more: t3(2740, e.DiagnosticCategory.Error, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more_2740", "Type '{0}' is missing the following properties from type '{1}': {2}, and {3} more."), Property_0_is_missing_in_type_1_but_required_in_type_2: t3(2741, e.DiagnosticCategory.Error, "Property_0_is_missing_in_type_1_but_required_in_type_2_2741", "Property '{0}' is missing in type '{1}' but required in type '{2}'."), The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary: t3(2742, e.DiagnosticCategory.Error, "The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_a_2742", "The inferred type of '{0}' cannot be named without a reference to '{1}'. This is likely not portable. A type annotation is necessary."), No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments: t3(2743, e.DiagnosticCategory.Error, "No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments_2743", "No overload expects {0} type arguments, but overloads do exist that expect either {1} or {2} type arguments."), Type_parameter_defaults_can_only_reference_previously_declared_type_parameters: t3(2744, e.DiagnosticCategory.Error, "Type_parameter_defaults_can_only_reference_previously_declared_type_parameters_2744", "Type parameter defaults can only reference previously declared type parameters."), This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided: t3(2745, e.DiagnosticCategory.Error, "This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_pr_2745", "This JSX tag's '{0}' prop expects type '{1}' which requires multiple children, but only a single child was provided."), This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided: t3(2746, e.DiagnosticCategory.Error, "This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided_2746", "This JSX tag's '{0}' prop expects a single child of type '{1}', but multiple children were provided."), _0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2: t3(2747, e.DiagnosticCategory.Error, "_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_t_2747", "'{0}' components don't accept text as child elements. Text in JSX has the type 'string', but the expected type of '{1}' is '{2}'."), Cannot_access_ambient_const_enums_when_the_isolatedModules_flag_is_provided: t3(2748, e.DiagnosticCategory.Error, "Cannot_access_ambient_const_enums_when_the_isolatedModules_flag_is_provided_2748", "Cannot access ambient const enums when the '--isolatedModules' flag is provided."), _0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0: t3(2749, e.DiagnosticCategory.Error, "_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0_2749", "'{0}' refers to a value, but is being used as a type here. Did you mean 'typeof {0}'?"), The_implementation_signature_is_declared_here: t3(2750, e.DiagnosticCategory.Error, "The_implementation_signature_is_declared_here_2750", "The implementation signature is declared here."), Circularity_originates_in_type_at_this_location: t3(2751, e.DiagnosticCategory.Error, "Circularity_originates_in_type_at_this_location_2751", "Circularity originates in type at this location."), The_first_export_default_is_here: t3(2752, e.DiagnosticCategory.Error, "The_first_export_default_is_here_2752", "The first export default is here."), Another_export_default_is_here: t3(2753, e.DiagnosticCategory.Error, "Another_export_default_is_here_2753", "Another export default is here."), super_may_not_use_type_arguments: t3(2754, e.DiagnosticCategory.Error, "super_may_not_use_type_arguments_2754", "'super' may not use type arguments."), No_constituent_of_type_0_is_callable: t3(2755, e.DiagnosticCategory.Error, "No_constituent_of_type_0_is_callable_2755", "No constituent of type '{0}' is callable."), Not_all_constituents_of_type_0_are_callable: t3(2756, e.DiagnosticCategory.Error, "Not_all_constituents_of_type_0_are_callable_2756", "Not all constituents of type '{0}' are callable."), Type_0_has_no_call_signatures: t3(2757, e.DiagnosticCategory.Error, "Type_0_has_no_call_signatures_2757", "Type '{0}' has no call signatures."), Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other: t3(2758, e.DiagnosticCategory.Error, "Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_2758", "Each member of the union type '{0}' has signatures, but none of those signatures are compatible with each other."), No_constituent_of_type_0_is_constructable: t3(2759, e.DiagnosticCategory.Error, "No_constituent_of_type_0_is_constructable_2759", "No constituent of type '{0}' is constructable."), Not_all_constituents_of_type_0_are_constructable: t3(2760, e.DiagnosticCategory.Error, "Not_all_constituents_of_type_0_are_constructable_2760", "Not all constituents of type '{0}' are constructable."), Type_0_has_no_construct_signatures: t3(2761, e.DiagnosticCategory.Error, "Type_0_has_no_construct_signatures_2761", "Type '{0}' has no construct signatures."), Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other: t3(2762, e.DiagnosticCategory.Error, "Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_2762", "Each member of the union type '{0}' has construct signatures, but none of those signatures are compatible with each other."), Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0: t3(2763, e.DiagnosticCategory.Error, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_s_2763", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but for-of will always send '{0}'."), Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0: t3(2764, e.DiagnosticCategory.Error, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_al_2764", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array spread will always send '{0}'."), Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0: t3(2765, e.DiagnosticCategory.Error, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring__2765", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array destructuring will always send '{0}'."), Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0: t3(2766, e.DiagnosticCategory.Error, "Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_co_2766", "Cannot delegate iteration to value because the 'next' method of its iterator expects type '{1}', but the containing generator will always send '{0}'."), The_0_property_of_an_iterator_must_be_a_method: t3(2767, e.DiagnosticCategory.Error, "The_0_property_of_an_iterator_must_be_a_method_2767", "The '{0}' property of an iterator must be a method."), The_0_property_of_an_async_iterator_must_be_a_method: t3(2768, e.DiagnosticCategory.Error, "The_0_property_of_an_async_iterator_must_be_a_method_2768", "The '{0}' property of an async iterator must be a method."), No_overload_matches_this_call: t3(2769, e.DiagnosticCategory.Error, "No_overload_matches_this_call_2769", "No overload matches this call."), The_last_overload_gave_the_following_error: t3(2770, e.DiagnosticCategory.Error, "The_last_overload_gave_the_following_error_2770", "The last overload gave the following error."), The_last_overload_is_declared_here: t3(2771, e.DiagnosticCategory.Error, "The_last_overload_is_declared_here_2771", "The last overload is declared here."), Overload_0_of_1_2_gave_the_following_error: t3(2772, e.DiagnosticCategory.Error, "Overload_0_of_1_2_gave_the_following_error_2772", "Overload {0} of {1}, '{2}', gave the following error."), Did_you_forget_to_use_await: t3(2773, e.DiagnosticCategory.Error, "Did_you_forget_to_use_await_2773", "Did you forget to use 'await'?"), This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead: t3(2774, e.DiagnosticCategory.Error, "This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_2774", "This condition will always return true since this function is always defined. Did you mean to call it instead?"), Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation: t3(2775, e.DiagnosticCategory.Error, "Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation_2775", "Assertions require every name in the call target to be declared with an explicit type annotation."), Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name: t3(2776, e.DiagnosticCategory.Error, "Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name_2776", "Assertions require the call target to be an identifier or qualified name."), The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access: t3(2777, e.DiagnosticCategory.Error, "The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access_2777", "The operand of an increment or decrement operator may not be an optional property access."), The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access: t3(2778, e.DiagnosticCategory.Error, "The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access_2778", "The target of an object rest assignment may not be an optional property access."), The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access: t3(2779, e.DiagnosticCategory.Error, "The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access_2779", "The left-hand side of an assignment expression may not be an optional property access."), The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access: t3(2780, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access_2780", "The left-hand side of a 'for...in' statement may not be an optional property access."), The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access: t3(2781, e.DiagnosticCategory.Error, "The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access_2781", "The left-hand side of a 'for...of' statement may not be an optional property access."), _0_needs_an_explicit_type_annotation: t3(2782, e.DiagnosticCategory.Message, "_0_needs_an_explicit_type_annotation_2782", "'{0}' needs an explicit type annotation."), _0_is_specified_more_than_once_so_this_usage_will_be_overwritten: t3(2783, e.DiagnosticCategory.Error, "_0_is_specified_more_than_once_so_this_usage_will_be_overwritten_2783", "'{0}' is specified more than once, so this usage will be overwritten."), get_and_set_accessors_cannot_declare_this_parameters: t3(2784, e.DiagnosticCategory.Error, "get_and_set_accessors_cannot_declare_this_parameters_2784", "'get' and 'set' accessors cannot declare 'this' parameters."), This_spread_always_overwrites_this_property: t3(2785, e.DiagnosticCategory.Error, "This_spread_always_overwrites_this_property_2785", "This spread always overwrites this property."), _0_cannot_be_used_as_a_JSX_component: t3(2786, e.DiagnosticCategory.Error, "_0_cannot_be_used_as_a_JSX_component_2786", "'{0}' cannot be used as a JSX component."), Its_return_type_0_is_not_a_valid_JSX_element: t3(2787, e.DiagnosticCategory.Error, "Its_return_type_0_is_not_a_valid_JSX_element_2787", "Its return type '{0}' is not a valid JSX element."), Its_instance_type_0_is_not_a_valid_JSX_element: t3(2788, e.DiagnosticCategory.Error, "Its_instance_type_0_is_not_a_valid_JSX_element_2788", "Its instance type '{0}' is not a valid JSX element."), Its_element_type_0_is_not_a_valid_JSX_element: t3(2789, e.DiagnosticCategory.Error, "Its_element_type_0_is_not_a_valid_JSX_element_2789", "Its element type '{0}' is not a valid JSX element."), The_operand_of_a_delete_operator_must_be_optional: t3(2790, e.DiagnosticCategory.Error, "The_operand_of_a_delete_operator_must_be_optional_2790", "The operand of a 'delete' operator must be optional."), Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later: t3(2791, e.DiagnosticCategory.Error, "Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_lat_2791", "Exponentiation cannot be performed on 'bigint' values unless the 'target' option is set to 'es2016' or later."), Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_the_paths_option: t3(2792, e.DiagnosticCategory.Error, "Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_th_2792", "Cannot find module '{0}'. Did you mean to set the 'moduleResolution' option to 'node', or to add aliases to the 'paths' option?"), The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible: t3(2793, e.DiagnosticCategory.Error, "The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_2793", "The call would have succeeded against this implementation, but implementation signatures of overloads are not externally visible."), Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise: t3(2794, e.DiagnosticCategory.Error, "Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise_2794", "Expected {0} arguments, but got {1}. Did you forget to include 'void' in your type argument to 'Promise'?"), The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types: t3(2795, e.DiagnosticCategory.Error, "The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types_2795", "The 'intrinsic' keyword can only be used to declare compiler provided intrinsic types."), It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked: t3(2796, e.DiagnosticCategory.Error, "It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tag_2796", "It is likely that you are missing a comma to separate these two template expressions. They form a tagged template expression which cannot be invoked."), A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract: t3(2797, e.DiagnosticCategory.Error, "A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_2797", "A mixin class that extends from a type variable containing an abstract construct signature must also be declared 'abstract'."), The_declaration_was_marked_as_deprecated_here: t3(2798, e.DiagnosticCategory.Error, "The_declaration_was_marked_as_deprecated_here_2798", "The declaration was marked as deprecated here."), Type_produces_a_tuple_type_that_is_too_large_to_represent: t3(2799, e.DiagnosticCategory.Error, "Type_produces_a_tuple_type_that_is_too_large_to_represent_2799", "Type produces a tuple type that is too large to represent."), Expression_produces_a_tuple_type_that_is_too_large_to_represent: t3(2800, e.DiagnosticCategory.Error, "Expression_produces_a_tuple_type_that_is_too_large_to_represent_2800", "Expression produces a tuple type that is too large to represent."), This_condition_will_always_return_true_since_this_0_is_always_defined: t3(2801, e.DiagnosticCategory.Error, "This_condition_will_always_return_true_since_this_0_is_always_defined_2801", "This condition will always return true since this '{0}' is always defined."), Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher: t3(2802, e.DiagnosticCategory.Error, "Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es201_2802", "Type '{0}' can only be iterated through when using the '--downlevelIteration' flag or with a '--target' of 'es2015' or higher."), Cannot_assign_to_private_method_0_Private_methods_are_not_writable: t3(2803, e.DiagnosticCategory.Error, "Cannot_assign_to_private_method_0_Private_methods_are_not_writable_2803", "Cannot assign to private method '{0}'. Private methods are not writable."), Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name: t3(2804, e.DiagnosticCategory.Error, "Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name_2804", "Duplicate identifier '{0}'. Static and instance elements cannot share the same private name."), Private_accessor_was_defined_without_a_getter: t3(2806, e.DiagnosticCategory.Error, "Private_accessor_was_defined_without_a_getter_2806", "Private accessor was defined without a getter."), This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0: t3(2807, e.DiagnosticCategory.Error, "This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_o_2807", "This syntax requires an imported helper named '{1}' with {2} parameters, which is not compatible with the one in '{0}'. Consider upgrading your version of '{0}'."), A_get_accessor_must_be_at_least_as_accessible_as_the_setter: t3(2808, e.DiagnosticCategory.Error, "A_get_accessor_must_be_at_least_as_accessible_as_the_setter_2808", "A get accessor must be at least as accessible as the setter"), Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_the_whole_assignment_in_parentheses: t3(2809, e.DiagnosticCategory.Error, "Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_d_2809", "Declaration or statement expected. This '=' follows a block of statements, so if you intended to write a destructuring assignment, you might need to wrap the the whole assignment in parentheses."), Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments: t3(2810, e.DiagnosticCategory.Error, "Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_2810", "Expected 1 argument, but got 0. 'new Promise()' needs a JSDoc hint to produce a 'resolve' that can be called without arguments."), Initializer_for_property_0: t3(2811, e.DiagnosticCategory.Error, "Initializer_for_property_0_2811", "Initializer for property '{0}'"), Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom: t3(2812, e.DiagnosticCategory.Error, "Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom_2812", "Property '{0}' does not exist on type '{1}'. Try changing the 'lib' compiler option to include 'dom'."), Class_declaration_cannot_implement_overload_list_for_0: t3(2813, e.DiagnosticCategory.Error, "Class_declaration_cannot_implement_overload_list_for_0_2813", "Class declaration cannot implement overload list for '{0}'."), Function_with_bodies_can_only_merge_with_classes_that_are_ambient: t3(2814, e.DiagnosticCategory.Error, "Function_with_bodies_can_only_merge_with_classes_that_are_ambient_2814", "Function with bodies can only merge with classes that are ambient."), arguments_cannot_be_referenced_in_property_initializers: t3(2815, e.DiagnosticCategory.Error, "arguments_cannot_be_referenced_in_property_initializers_2815", "'arguments' cannot be referenced in property initializers."), Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class: t3(2816, e.DiagnosticCategory.Error, "Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class_2816", "Cannot use 'this' in a static property initializer of a decorated class."), Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block: t3(2817, e.DiagnosticCategory.Error, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block_2817", "Property '{0}' has no initializer and is not definitely assigned in a class static block."), Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers: t3(2818, e.DiagnosticCategory.Error, "Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializer_2818", "Duplicate identifier '{0}'. Compiler reserves name '{1}' when emitting 'super' references in static initializers."), Namespace_name_cannot_be_0: t3(2819, e.DiagnosticCategory.Error, "Namespace_name_cannot_be_0_2819", "Namespace name cannot be '{0}'."), Type_0_is_not_assignable_to_type_1_Did_you_mean_2: t3(2820, e.DiagnosticCategory.Error, "Type_0_is_not_assignable_to_type_1_Did_you_mean_2_2820", "Type '{0}' is not assignable to type '{1}'. Did you mean '{2}'?"), Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_or_nodenext: t3(2821, e.DiagnosticCategory.Error, "Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_or_nodenext_2821", "Import assertions are only supported when the '--module' option is set to 'esnext' or 'nodenext'."), Import_assertions_cannot_be_used_with_type_only_imports_or_exports: t3(2822, e.DiagnosticCategory.Error, "Import_assertions_cannot_be_used_with_type_only_imports_or_exports_2822", "Import assertions cannot be used with type-only imports or exports."), Cannot_find_namespace_0_Did_you_mean_1: t3(2833, e.DiagnosticCategory.Error, "Cannot_find_namespace_0_Did_you_mean_1_2833", "Cannot find namespace '{0}'. Did you mean '{1}'?"), Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path: t3(2834, e.DiagnosticCategory.Error, "Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_n_2834", "Relative import paths need explicit file extensions in EcmaScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Consider adding an extension to the import path."), Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0: t3(2835, e.DiagnosticCategory.Error, "Relative_import_paths_need_explicit_file_extensions_in_EcmaScript_imports_when_moduleResolution_is_n_2835", "Relative import paths need explicit file extensions in EcmaScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Did you mean '{0}'?"), Import_assertions_are_not_allowed_on_statements_that_transpile_to_commonjs_require_calls: t3(2836, e.DiagnosticCategory.Error, "Import_assertions_are_not_allowed_on_statements_that_transpile_to_commonjs_require_calls_2836", "Import assertions are not allowed on statements that transpile to commonjs 'require' calls."), Import_assertion_values_must_be_string_literal_expressions: t3(2837, e.DiagnosticCategory.Error, "Import_assertion_values_must_be_string_literal_expressions_2837", "Import assertion values must be string literal expressions."), All_declarations_of_0_must_have_identical_constraints: t3(2838, e.DiagnosticCategory.Error, "All_declarations_of_0_must_have_identical_constraints_2838", "All declarations of '{0}' must have identical constraints."), This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value: t3(2839, e.DiagnosticCategory.Error, "This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value_2839", "This condition will always return '{0}' since JavaScript compares objects by reference, not value."), An_interface_cannot_extend_a_primitive_type_like_0_an_interface_can_only_extend_named_types_and_classes: t3(2840, e.DiagnosticCategory.Error, "An_interface_cannot_extend_a_primitive_type_like_0_an_interface_can_only_extend_named_types_and_clas_2840", "An interface cannot extend a primitive type like '{0}'; an interface can only extend named types and classes"), The_type_of_this_expression_cannot_be_named_without_a_resolution_mode_assertion_which_is_an_unstable_feature_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: t3(2841, e.DiagnosticCategory.Error, "The_type_of_this_expression_cannot_be_named_without_a_resolution_mode_assertion_which_is_an_unstable_2841", "The type of this expression cannot be named without a 'resolution-mode' assertion, which is an unstable feature. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."), _0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation: t3(2842, e.DiagnosticCategory.Error, "_0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation_2842", "'{0}' is an unused renaming of '{1}'. Did you intend to use it as a type annotation?"), We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here: t3(2843, e.DiagnosticCategory.Error, "We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here_2843", "We can only write a type for '{0}' by adding a type for the entire parameter here."), Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: t3(2844, e.DiagnosticCategory.Error, "Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2844", "Type of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."), This_condition_will_always_return_0: t3(2845, e.DiagnosticCategory.Error, "This_condition_will_always_return_0_2845", "This condition will always return '{0}'."), Import_declaration_0_is_using_private_name_1: t3(4e3, e.DiagnosticCategory.Error, "Import_declaration_0_is_using_private_name_1_4000", "Import declaration '{0}' is using private name '{1}'."), Type_parameter_0_of_exported_class_has_or_is_using_private_name_1: t3(4002, e.DiagnosticCategory.Error, "Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002", "Type parameter '{0}' of exported class has or is using private name '{1}'."), Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1: t3(4004, e.DiagnosticCategory.Error, "Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004", "Type parameter '{0}' of exported interface has or is using private name '{1}'."), Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: t3(4006, e.DiagnosticCategory.Error, "Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006", "Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."), Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: t3(4008, e.DiagnosticCategory.Error, "Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008", "Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'."), Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: t3(4010, e.DiagnosticCategory.Error, "Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010", "Type parameter '{0}' of public static method from exported class has or is using private name '{1}'."), Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: t3(4012, e.DiagnosticCategory.Error, "Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012", "Type parameter '{0}' of public method from exported class has or is using private name '{1}'."), Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: t3(4014, e.DiagnosticCategory.Error, "Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014", "Type parameter '{0}' of method from exported interface has or is using private name '{1}'."), Type_parameter_0_of_exported_function_has_or_is_using_private_name_1: t3(4016, e.DiagnosticCategory.Error, "Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016", "Type parameter '{0}' of exported function has or is using private name '{1}'."), Implements_clause_of_exported_class_0_has_or_is_using_private_name_1: t3(4019, e.DiagnosticCategory.Error, "Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019", "Implements clause of exported class '{0}' has or is using private name '{1}'."), extends_clause_of_exported_class_0_has_or_is_using_private_name_1: t3(4020, e.DiagnosticCategory.Error, "extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020", "'extends' clause of exported class '{0}' has or is using private name '{1}'."), extends_clause_of_exported_class_has_or_is_using_private_name_0: t3(4021, e.DiagnosticCategory.Error, "extends_clause_of_exported_class_has_or_is_using_private_name_0_4021", "'extends' clause of exported class has or is using private name '{0}'."), extends_clause_of_exported_interface_0_has_or_is_using_private_name_1: t3(4022, e.DiagnosticCategory.Error, "extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022", "'extends' clause of exported interface '{0}' has or is using private name '{1}'."), Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4023, e.DiagnosticCategory.Error, "Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023", "Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named."), Exported_variable_0_has_or_is_using_name_1_from_private_module_2: t3(4024, e.DiagnosticCategory.Error, "Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024", "Exported variable '{0}' has or is using name '{1}' from private module '{2}'."), Exported_variable_0_has_or_is_using_private_name_1: t3(4025, e.DiagnosticCategory.Error, "Exported_variable_0_has_or_is_using_private_name_1_4025", "Exported variable '{0}' has or is using private name '{1}'."), Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4026, e.DiagnosticCategory.Error, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026", "Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."), Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4027, e.DiagnosticCategory.Error, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027", "Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'."), Public_static_property_0_of_exported_class_has_or_is_using_private_name_1: t3(4028, e.DiagnosticCategory.Error, "Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028", "Public static property '{0}' of exported class has or is using private name '{1}'."), Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4029, e.DiagnosticCategory.Error, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029", "Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."), Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4030, e.DiagnosticCategory.Error, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030", "Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'."), Public_property_0_of_exported_class_has_or_is_using_private_name_1: t3(4031, e.DiagnosticCategory.Error, "Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031", "Public property '{0}' of exported class has or is using private name '{1}'."), Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4032, e.DiagnosticCategory.Error, "Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032", "Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'."), Property_0_of_exported_interface_has_or_is_using_private_name_1: t3(4033, e.DiagnosticCategory.Error, "Property_0_of_exported_interface_has_or_is_using_private_name_1_4033", "Property '{0}' of exported interface has or is using private name '{1}'."), Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4034, e.DiagnosticCategory.Error, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_mod_4034", "Parameter type of public static setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."), Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1: t3(4035, e.DiagnosticCategory.Error, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1_4035", "Parameter type of public static setter '{0}' from exported class has or is using private name '{1}'."), Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4036, e.DiagnosticCategory.Error, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4036", "Parameter type of public setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."), Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1: t3(4037, e.DiagnosticCategory.Error, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1_4037", "Parameter type of public setter '{0}' from exported class has or is using private name '{1}'."), Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4038, e.DiagnosticCategory.Error, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_modul_4038", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."), Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4039, e.DiagnosticCategory.Error, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_4039", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."), Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1: t3(4040, e.DiagnosticCategory.Error, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1_4040", "Return type of public static getter '{0}' from exported class has or is using private name '{1}'."), Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4041, e.DiagnosticCategory.Error, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_4041", "Return type of public getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."), Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4042, e.DiagnosticCategory.Error, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4042", "Return type of public getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."), Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1: t3(4043, e.DiagnosticCategory.Error, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1_4043", "Return type of public getter '{0}' from exported class has or is using private name '{1}'."), Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: t3(4044, e.DiagnosticCategory.Error, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044", "Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'."), Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0: t3(4045, e.DiagnosticCategory.Error, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045", "Return type of constructor signature from exported interface has or is using private name '{0}'."), Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: t3(4046, e.DiagnosticCategory.Error, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046", "Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'."), Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0: t3(4047, e.DiagnosticCategory.Error, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047", "Return type of call signature from exported interface has or is using private name '{0}'."), Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: t3(4048, e.DiagnosticCategory.Error, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048", "Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'."), Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0: t3(4049, e.DiagnosticCategory.Error, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049", "Return type of index signature from exported interface has or is using private name '{0}'."), Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: t3(4050, e.DiagnosticCategory.Error, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050", "Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named."), Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: t3(4051, e.DiagnosticCategory.Error, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051", "Return type of public static method from exported class has or is using name '{0}' from private module '{1}'."), Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0: t3(4052, e.DiagnosticCategory.Error, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052", "Return type of public static method from exported class has or is using private name '{0}'."), Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: t3(4053, e.DiagnosticCategory.Error, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053", "Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named."), Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: t3(4054, e.DiagnosticCategory.Error, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054", "Return type of public method from exported class has or is using name '{0}' from private module '{1}'."), Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0: t3(4055, e.DiagnosticCategory.Error, "Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055", "Return type of public method from exported class has or is using private name '{0}'."), Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1: t3(4056, e.DiagnosticCategory.Error, "Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056", "Return type of method from exported interface has or is using name '{0}' from private module '{1}'."), Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0: t3(4057, e.DiagnosticCategory.Error, "Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057", "Return type of method from exported interface has or is using private name '{0}'."), Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: t3(4058, e.DiagnosticCategory.Error, "Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058", "Return type of exported function has or is using name '{0}' from external module {1} but cannot be named."), Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1: t3(4059, e.DiagnosticCategory.Error, "Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059", "Return type of exported function has or is using name '{0}' from private module '{1}'."), Return_type_of_exported_function_has_or_is_using_private_name_0: t3(4060, e.DiagnosticCategory.Error, "Return_type_of_exported_function_has_or_is_using_private_name_0_4060", "Return type of exported function has or is using private name '{0}'."), Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4061, e.DiagnosticCategory.Error, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named."), Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4062, e.DiagnosticCategory.Error, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'."), Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1: t3(4063, e.DiagnosticCategory.Error, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063", "Parameter '{0}' of constructor from exported class has or is using private name '{1}'."), Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4064, e.DiagnosticCategory.Error, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064", "Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'."), Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: t3(4065, e.DiagnosticCategory.Error, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065", "Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."), Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4066, e.DiagnosticCategory.Error, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066", "Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'."), Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: t3(4067, e.DiagnosticCategory.Error, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067", "Parameter '{0}' of call signature from exported interface has or is using private name '{1}'."), Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4068, e.DiagnosticCategory.Error, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named."), Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4069, e.DiagnosticCategory.Error, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'."), Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: t3(4070, e.DiagnosticCategory.Error, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070", "Parameter '{0}' of public static method from exported class has or is using private name '{1}'."), Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4071, e.DiagnosticCategory.Error, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071", "Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named."), Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4072, e.DiagnosticCategory.Error, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072", "Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'."), Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: t3(4073, e.DiagnosticCategory.Error, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073", "Parameter '{0}' of public method from exported class has or is using private name '{1}'."), Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4074, e.DiagnosticCategory.Error, "Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074", "Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'."), Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: t3(4075, e.DiagnosticCategory.Error, "Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075", "Parameter '{0}' of method from exported interface has or is using private name '{1}'."), Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4076, e.DiagnosticCategory.Error, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076", "Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named."), Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2: t3(4077, e.DiagnosticCategory.Error, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077", "Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'."), Parameter_0_of_exported_function_has_or_is_using_private_name_1: t3(4078, e.DiagnosticCategory.Error, "Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078", "Parameter '{0}' of exported function has or is using private name '{1}'."), Exported_type_alias_0_has_or_is_using_private_name_1: t3(4081, e.DiagnosticCategory.Error, "Exported_type_alias_0_has_or_is_using_private_name_1_4081", "Exported type alias '{0}' has or is using private name '{1}'."), Default_export_of_the_module_has_or_is_using_private_name_0: t3(4082, e.DiagnosticCategory.Error, "Default_export_of_the_module_has_or_is_using_private_name_0_4082", "Default export of the module has or is using private name '{0}'."), Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1: t3(4083, e.DiagnosticCategory.Error, "Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1_4083", "Type parameter '{0}' of exported type alias has or is using private name '{1}'."), Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2: t3(4084, e.DiagnosticCategory.Error, "Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2_4084", "Exported type alias '{0}' has or is using private name '{1}' from module {2}."), Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict: t3(4090, e.DiagnosticCategory.Error, "Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_librar_4090", "Conflicting definitions for '{0}' found at '{1}' and '{2}'. Consider installing a specific version of this library to resolve the conflict."), Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4091, e.DiagnosticCategory.Error, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4091", "Parameter '{0}' of index signature from exported interface has or is using name '{1}' from private module '{2}'."), Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1: t3(4092, e.DiagnosticCategory.Error, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1_4092", "Parameter '{0}' of index signature from exported interface has or is using private name '{1}'."), Property_0_of_exported_class_expression_may_not_be_private_or_protected: t3(4094, e.DiagnosticCategory.Error, "Property_0_of_exported_class_expression_may_not_be_private_or_protected_4094", "Property '{0}' of exported class expression may not be private or protected."), Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4095, e.DiagnosticCategory.Error, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_4095", "Public static method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."), Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4096, e.DiagnosticCategory.Error, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4096", "Public static method '{0}' of exported class has or is using name '{1}' from private module '{2}'."), Public_static_method_0_of_exported_class_has_or_is_using_private_name_1: t3(4097, e.DiagnosticCategory.Error, "Public_static_method_0_of_exported_class_has_or_is_using_private_name_1_4097", "Public static method '{0}' of exported class has or is using private name '{1}'."), Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4098, e.DiagnosticCategory.Error, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4098", "Public method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."), Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: t3(4099, e.DiagnosticCategory.Error, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4099", "Public method '{0}' of exported class has or is using name '{1}' from private module '{2}'."), Public_method_0_of_exported_class_has_or_is_using_private_name_1: t3(4100, e.DiagnosticCategory.Error, "Public_method_0_of_exported_class_has_or_is_using_private_name_1_4100", "Public method '{0}' of exported class has or is using private name '{1}'."), Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: t3(4101, e.DiagnosticCategory.Error, "Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4101", "Method '{0}' of exported interface has or is using name '{1}' from private module '{2}'."), Method_0_of_exported_interface_has_or_is_using_private_name_1: t3(4102, e.DiagnosticCategory.Error, "Method_0_of_exported_interface_has_or_is_using_private_name_1_4102", "Method '{0}' of exported interface has or is using private name '{1}'."), Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1: t3(4103, e.DiagnosticCategory.Error, "Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1_4103", "Type parameter '{0}' of exported mapped object type is using private name '{1}'."), The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1: t3(4104, e.DiagnosticCategory.Error, "The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1_4104", "The type '{0}' is 'readonly' and cannot be assigned to the mutable type '{1}'."), Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter: t3(4105, e.DiagnosticCategory.Error, "Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter_4105", "Private or protected member '{0}' cannot be accessed on a type parameter."), Parameter_0_of_accessor_has_or_is_using_private_name_1: t3(4106, e.DiagnosticCategory.Error, "Parameter_0_of_accessor_has_or_is_using_private_name_1_4106", "Parameter '{0}' of accessor has or is using private name '{1}'."), Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2: t3(4107, e.DiagnosticCategory.Error, "Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2_4107", "Parameter '{0}' of accessor has or is using name '{1}' from private module '{2}'."), Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: t3(4108, e.DiagnosticCategory.Error, "Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4108", "Parameter '{0}' of accessor has or is using name '{1}' from external module '{2}' but cannot be named."), Type_arguments_for_0_circularly_reference_themselves: t3(4109, e.DiagnosticCategory.Error, "Type_arguments_for_0_circularly_reference_themselves_4109", "Type arguments for '{0}' circularly reference themselves."), Tuple_type_arguments_circularly_reference_themselves: t3(4110, e.DiagnosticCategory.Error, "Tuple_type_arguments_circularly_reference_themselves_4110", "Tuple type arguments circularly reference themselves."), Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0: t3(4111, e.DiagnosticCategory.Error, "Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0_4111", "Property '{0}' comes from an index signature, so it must be accessed with ['{0}']."), This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class: t3(4112, e.DiagnosticCategory.Error, "This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another__4112", "This member cannot have an 'override' modifier because its containing class '{0}' does not extend another class."), This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0: t3(4113, e.DiagnosticCategory.Error, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_4113", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'."), This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0: t3(4114, e.DiagnosticCategory.Error, "This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0_4114", "This member must have an 'override' modifier because it overrides a member in the base class '{0}'."), This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0: t3(4115, e.DiagnosticCategory.Error, "This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0_4115", "This parameter property must have an 'override' modifier because it overrides a member in base class '{0}'."), This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0: t3(4116, e.DiagnosticCategory.Error, "This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared__4116", "This member must have an 'override' modifier because it overrides an abstract method that is declared in the base class '{0}'."), This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: t3(4117, e.DiagnosticCategory.Error, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you__4117", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'. Did you mean '{1}'?"), The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized: t3(4118, e.DiagnosticCategory.Error, "The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized_4118", "The type of this node cannot be serialized because its property '{0}' cannot be serialized."), This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: t3(4119, e.DiagnosticCategory.Error, "This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_4119", "This member must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."), This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: t3(4120, e.DiagnosticCategory.Error, "This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_4120", "This parameter property must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."), This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class: t3(4121, e.DiagnosticCategory.Error, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_4121", "This member cannot have a JSDoc comment with an '@override' tag because its containing class '{0}' does not extend another class."), This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0: t3(4122, e.DiagnosticCategory.Error, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4122", "This member cannot have a JSDoc comment with an '@override' tag because it is not declared in the base class '{0}'."), This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: t3(4123, e.DiagnosticCategory.Error, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4123", "This member cannot have a JSDoc comment with an 'override' tag because it is not declared in the base class '{0}'. Did you mean '{1}'?"), Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: t3(4124, e.DiagnosticCategory.Error, "Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_w_4124", "Compiler option '{0}' of value '{1}' is unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."), resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: t3(4125, e.DiagnosticCategory.Error, "resolution_mode_assertions_are_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_wi_4125", "'resolution-mode' assertions are unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."), The_current_host_does_not_support_the_0_option: t3(5001, e.DiagnosticCategory.Error, "The_current_host_does_not_support_the_0_option_5001", "The current host does not support the '{0}' option."), Cannot_find_the_common_subdirectory_path_for_the_input_files: t3(5009, e.DiagnosticCategory.Error, "Cannot_find_the_common_subdirectory_path_for_the_input_files_5009", "Cannot find the common subdirectory path for the input files."), File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: t3(5010, e.DiagnosticCategory.Error, "File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0_5010", "File specification cannot end in a recursive directory wildcard ('**'): '{0}'."), Cannot_read_file_0_Colon_1: t3(5012, e.DiagnosticCategory.Error, "Cannot_read_file_0_Colon_1_5012", "Cannot read file '{0}': {1}."), Failed_to_parse_file_0_Colon_1: t3(5014, e.DiagnosticCategory.Error, "Failed_to_parse_file_0_Colon_1_5014", "Failed to parse file '{0}': {1}."), Unknown_compiler_option_0: t3(5023, e.DiagnosticCategory.Error, "Unknown_compiler_option_0_5023", "Unknown compiler option '{0}'."), Compiler_option_0_requires_a_value_of_type_1: t3(5024, e.DiagnosticCategory.Error, "Compiler_option_0_requires_a_value_of_type_1_5024", "Compiler option '{0}' requires a value of type {1}."), Unknown_compiler_option_0_Did_you_mean_1: t3(5025, e.DiagnosticCategory.Error, "Unknown_compiler_option_0_Did_you_mean_1_5025", "Unknown compiler option '{0}'. Did you mean '{1}'?"), Could_not_write_file_0_Colon_1: t3(5033, e.DiagnosticCategory.Error, "Could_not_write_file_0_Colon_1_5033", "Could not write file '{0}': {1}."), Option_project_cannot_be_mixed_with_source_files_on_a_command_line: t3(5042, e.DiagnosticCategory.Error, "Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042", "Option 'project' cannot be mixed with source files on a command line."), Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher: t3(5047, e.DiagnosticCategory.Error, "Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047", "Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher."), Option_0_cannot_be_specified_when_option_target_is_ES3: t3(5048, e.DiagnosticCategory.Error, "Option_0_cannot_be_specified_when_option_target_is_ES3_5048", "Option '{0}' cannot be specified when option 'target' is 'ES3'."), Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided: t3(5051, e.DiagnosticCategory.Error, "Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided_5051", "Option '{0} can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided."), Option_0_cannot_be_specified_without_specifying_option_1: t3(5052, e.DiagnosticCategory.Error, "Option_0_cannot_be_specified_without_specifying_option_1_5052", "Option '{0}' cannot be specified without specifying option '{1}'."), Option_0_cannot_be_specified_with_option_1: t3(5053, e.DiagnosticCategory.Error, "Option_0_cannot_be_specified_with_option_1_5053", "Option '{0}' cannot be specified with option '{1}'."), A_tsconfig_json_file_is_already_defined_at_Colon_0: t3(5054, e.DiagnosticCategory.Error, "A_tsconfig_json_file_is_already_defined_at_Colon_0_5054", "A 'tsconfig.json' file is already defined at: '{0}'."), Cannot_write_file_0_because_it_would_overwrite_input_file: t3(5055, e.DiagnosticCategory.Error, "Cannot_write_file_0_because_it_would_overwrite_input_file_5055", "Cannot write file '{0}' because it would overwrite input file."), Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files: t3(5056, e.DiagnosticCategory.Error, "Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056", "Cannot write file '{0}' because it would be overwritten by multiple input files."), Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0: t3(5057, e.DiagnosticCategory.Error, "Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057", "Cannot find a tsconfig.json file at the specified directory: '{0}'."), The_specified_path_does_not_exist_Colon_0: t3(5058, e.DiagnosticCategory.Error, "The_specified_path_does_not_exist_Colon_0_5058", "The specified path does not exist: '{0}'."), Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier: t3(5059, e.DiagnosticCategory.Error, "Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier_5059", "Invalid value for '--reactNamespace'. '{0}' is not a valid identifier."), Pattern_0_can_have_at_most_one_Asterisk_character: t3(5061, e.DiagnosticCategory.Error, "Pattern_0_can_have_at_most_one_Asterisk_character_5061", "Pattern '{0}' can have at most one '*' character."), Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character: t3(5062, e.DiagnosticCategory.Error, "Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character_5062", "Substitution '{0}' in pattern '{1}' can have at most one '*' character."), Substitutions_for_pattern_0_should_be_an_array: t3(5063, e.DiagnosticCategory.Error, "Substitutions_for_pattern_0_should_be_an_array_5063", "Substitutions for pattern '{0}' should be an array."), Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2: t3(5064, e.DiagnosticCategory.Error, "Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2_5064", "Substitution '{0}' for pattern '{1}' has incorrect type, expected 'string', got '{2}'."), File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: t3(5065, e.DiagnosticCategory.Error, "File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildca_5065", "File specification cannot contain a parent directory ('..') that appears after a recursive directory wildcard ('**'): '{0}'."), Substitutions_for_pattern_0_shouldn_t_be_an_empty_array: t3(5066, e.DiagnosticCategory.Error, "Substitutions_for_pattern_0_shouldn_t_be_an_empty_array_5066", "Substitutions for pattern '{0}' shouldn't be an empty array."), Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name: t3(5067, e.DiagnosticCategory.Error, "Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name_5067", "Invalid value for 'jsxFactory'. '{0}' is not a valid identifier or qualified-name."), Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig: t3(5068, e.DiagnosticCategory.Error, "Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript__5068", "Adding a tsconfig.json file will help organize projects that contain both TypeScript and JavaScript files. Learn more at https://aka.ms/tsconfig."), Option_0_cannot_be_specified_without_specifying_option_1_or_option_2: t3(5069, e.DiagnosticCategory.Error, "Option_0_cannot_be_specified_without_specifying_option_1_or_option_2_5069", "Option '{0}' cannot be specified without specifying option '{1}' or option '{2}'."), Option_resolveJsonModule_cannot_be_specified_without_node_module_resolution_strategy: t3(5070, e.DiagnosticCategory.Error, "Option_resolveJsonModule_cannot_be_specified_without_node_module_resolution_strategy_5070", "Option '--resolveJsonModule' cannot be specified without 'node' module resolution strategy."), Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_esNext: t3(5071, e.DiagnosticCategory.Error, "Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_5071", "Option '--resolveJsonModule' can only be specified when module code generation is 'commonjs', 'amd', 'es2015' or 'esNext'."), Unknown_build_option_0: t3(5072, e.DiagnosticCategory.Error, "Unknown_build_option_0_5072", "Unknown build option '{0}'."), Build_option_0_requires_a_value_of_type_1: t3(5073, e.DiagnosticCategory.Error, "Build_option_0_requires_a_value_of_type_1_5073", "Build option '{0}' requires a value of type {1}."), Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified: t3(5074, e.DiagnosticCategory.Error, "Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBui_5074", "Option '--incremental' can only be specified using tsconfig, emitting to single file or when option '--tsBuildInfoFile' is specified."), _0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2: t3(5075, e.DiagnosticCategory.Error, "_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_5075", "'{0}' is assignable to the constraint of type '{1}', but '{1}' could be instantiated with a different subtype of constraint '{2}'."), _0_and_1_operations_cannot_be_mixed_without_parentheses: t3(5076, e.DiagnosticCategory.Error, "_0_and_1_operations_cannot_be_mixed_without_parentheses_5076", "'{0}' and '{1}' operations cannot be mixed without parentheses."), Unknown_build_option_0_Did_you_mean_1: t3(5077, e.DiagnosticCategory.Error, "Unknown_build_option_0_Did_you_mean_1_5077", "Unknown build option '{0}'. Did you mean '{1}'?"), Unknown_watch_option_0: t3(5078, e.DiagnosticCategory.Error, "Unknown_watch_option_0_5078", "Unknown watch option '{0}'."), Unknown_watch_option_0_Did_you_mean_1: t3(5079, e.DiagnosticCategory.Error, "Unknown_watch_option_0_Did_you_mean_1_5079", "Unknown watch option '{0}'. Did you mean '{1}'?"), Watch_option_0_requires_a_value_of_type_1: t3(5080, e.DiagnosticCategory.Error, "Watch_option_0_requires_a_value_of_type_1_5080", "Watch option '{0}' requires a value of type {1}."), Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0: t3(5081, e.DiagnosticCategory.Error, "Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0_5081", "Cannot find a tsconfig.json file at the current directory: {0}."), _0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1: t3(5082, e.DiagnosticCategory.Error, "_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1_5082", "'{0}' could be instantiated with an arbitrary type which could be unrelated to '{1}'."), Cannot_read_file_0: t3(5083, e.DiagnosticCategory.Error, "Cannot_read_file_0_5083", "Cannot read file '{0}'."), Tuple_members_must_all_have_names_or_all_not_have_names: t3(5084, e.DiagnosticCategory.Error, "Tuple_members_must_all_have_names_or_all_not_have_names_5084", "Tuple members must all have names or all not have names."), A_tuple_member_cannot_be_both_optional_and_rest: t3(5085, e.DiagnosticCategory.Error, "A_tuple_member_cannot_be_both_optional_and_rest_5085", "A tuple member cannot be both optional and rest."), A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type: t3(5086, e.DiagnosticCategory.Error, "A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_c_5086", "A labeled tuple element is declared as optional with a question mark after the name and before the colon, rather than after the type."), A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type: t3(5087, e.DiagnosticCategory.Error, "A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type_5087", "A labeled tuple element is declared as rest with a '...' before the name, rather than before the type."), The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary: t3(5088, e.DiagnosticCategory.Error, "The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialize_5088", "The inferred type of '{0}' references a type with a cyclic structure which cannot be trivially serialized. A type annotation is necessary."), Option_0_cannot_be_specified_when_option_jsx_is_1: t3(5089, e.DiagnosticCategory.Error, "Option_0_cannot_be_specified_when_option_jsx_is_1_5089", "Option '{0}' cannot be specified when option 'jsx' is '{1}'."), Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash: t3(5090, e.DiagnosticCategory.Error, "Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash_5090", "Non-relative paths are not allowed when 'baseUrl' is not set. Did you forget a leading './'?"), Option_preserveConstEnums_cannot_be_disabled_when_isolatedModules_is_enabled: t3(5091, e.DiagnosticCategory.Error, "Option_preserveConstEnums_cannot_be_disabled_when_isolatedModules_is_enabled_5091", "Option 'preserveConstEnums' cannot be disabled when 'isolatedModules' is enabled."), The_root_value_of_a_0_file_must_be_an_object: t3(5092, e.DiagnosticCategory.Error, "The_root_value_of_a_0_file_must_be_an_object_5092", "The root value of a '{0}' file must be an object."), Compiler_option_0_may_only_be_used_with_build: t3(5093, e.DiagnosticCategory.Error, "Compiler_option_0_may_only_be_used_with_build_5093", "Compiler option '--{0}' may only be used with '--build'."), Compiler_option_0_may_not_be_used_with_build: t3(5094, e.DiagnosticCategory.Error, "Compiler_option_0_may_not_be_used_with_build_5094", "Compiler option '--{0}' may not be used with '--build'."), Option_preserveValueImports_can_only_be_used_when_module_is_set_to_es2015_or_later: t3(5095, e.DiagnosticCategory.Error, "Option_preserveValueImports_can_only_be_used_when_module_is_set_to_es2015_or_later_5095", "Option 'preserveValueImports' can only be used when 'module' is set to 'es2015' or later."), Generates_a_sourcemap_for_each_corresponding_d_ts_file: t3(6e3, e.DiagnosticCategory.Message, "Generates_a_sourcemap_for_each_corresponding_d_ts_file_6000", "Generates a sourcemap for each corresponding '.d.ts' file."), Concatenate_and_emit_output_to_single_file: t3(6001, e.DiagnosticCategory.Message, "Concatenate_and_emit_output_to_single_file_6001", "Concatenate and emit output to single file."), Generates_corresponding_d_ts_file: t3(6002, e.DiagnosticCategory.Message, "Generates_corresponding_d_ts_file_6002", "Generates corresponding '.d.ts' file."), Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations: t3(6004, e.DiagnosticCategory.Message, "Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004", "Specify the location where debugger should locate TypeScript files instead of source locations."), Watch_input_files: t3(6005, e.DiagnosticCategory.Message, "Watch_input_files_6005", "Watch input files."), Redirect_output_structure_to_the_directory: t3(6006, e.DiagnosticCategory.Message, "Redirect_output_structure_to_the_directory_6006", "Redirect output structure to the directory."), Do_not_erase_const_enum_declarations_in_generated_code: t3(6007, e.DiagnosticCategory.Message, "Do_not_erase_const_enum_declarations_in_generated_code_6007", "Do not erase const enum declarations in generated code."), Do_not_emit_outputs_if_any_errors_were_reported: t3(6008, e.DiagnosticCategory.Message, "Do_not_emit_outputs_if_any_errors_were_reported_6008", "Do not emit outputs if any errors were reported."), Do_not_emit_comments_to_output: t3(6009, e.DiagnosticCategory.Message, "Do_not_emit_comments_to_output_6009", "Do not emit comments to output."), Do_not_emit_outputs: t3(6010, e.DiagnosticCategory.Message, "Do_not_emit_outputs_6010", "Do not emit outputs."), Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking: t3(6011, e.DiagnosticCategory.Message, "Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011", "Allow default imports from modules with no default export. This does not affect code emit, just typechecking."), Skip_type_checking_of_declaration_files: t3(6012, e.DiagnosticCategory.Message, "Skip_type_checking_of_declaration_files_6012", "Skip type checking of declaration files."), Do_not_resolve_the_real_path_of_symlinks: t3(6013, e.DiagnosticCategory.Message, "Do_not_resolve_the_real_path_of_symlinks_6013", "Do not resolve the real path of symlinks."), Only_emit_d_ts_declaration_files: t3(6014, e.DiagnosticCategory.Message, "Only_emit_d_ts_declaration_files_6014", "Only emit '.d.ts' declaration files."), Specify_ECMAScript_target_version: t3(6015, e.DiagnosticCategory.Message, "Specify_ECMAScript_target_version_6015", "Specify ECMAScript target version."), Specify_module_code_generation: t3(6016, e.DiagnosticCategory.Message, "Specify_module_code_generation_6016", "Specify module code generation."), Print_this_message: t3(6017, e.DiagnosticCategory.Message, "Print_this_message_6017", "Print this message."), Print_the_compiler_s_version: t3(6019, e.DiagnosticCategory.Message, "Print_the_compiler_s_version_6019", "Print the compiler's version."), Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json: t3(6020, e.DiagnosticCategory.Message, "Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json_6020", "Compile the project given the path to its configuration file, or to a folder with a 'tsconfig.json'."), Syntax_Colon_0: t3(6023, e.DiagnosticCategory.Message, "Syntax_Colon_0_6023", "Syntax: {0}"), options: t3(6024, e.DiagnosticCategory.Message, "options_6024", "options"), file: t3(6025, e.DiagnosticCategory.Message, "file_6025", "file"), Examples_Colon_0: t3(6026, e.DiagnosticCategory.Message, "Examples_Colon_0_6026", "Examples: {0}"), Options_Colon: t3(6027, e.DiagnosticCategory.Message, "Options_Colon_6027", "Options:"), Version_0: t3(6029, e.DiagnosticCategory.Message, "Version_0_6029", "Version {0}"), Insert_command_line_options_and_files_from_a_file: t3(6030, e.DiagnosticCategory.Message, "Insert_command_line_options_and_files_from_a_file_6030", "Insert command line options and files from a file."), Starting_compilation_in_watch_mode: t3(6031, e.DiagnosticCategory.Message, "Starting_compilation_in_watch_mode_6031", "Starting compilation in watch mode..."), File_change_detected_Starting_incremental_compilation: t3(6032, e.DiagnosticCategory.Message, "File_change_detected_Starting_incremental_compilation_6032", "File change detected. Starting incremental compilation..."), KIND: t3(6034, e.DiagnosticCategory.Message, "KIND_6034", "KIND"), FILE: t3(6035, e.DiagnosticCategory.Message, "FILE_6035", "FILE"), VERSION: t3(6036, e.DiagnosticCategory.Message, "VERSION_6036", "VERSION"), LOCATION: t3(6037, e.DiagnosticCategory.Message, "LOCATION_6037", "LOCATION"), DIRECTORY: t3(6038, e.DiagnosticCategory.Message, "DIRECTORY_6038", "DIRECTORY"), STRATEGY: t3(6039, e.DiagnosticCategory.Message, "STRATEGY_6039", "STRATEGY"), FILE_OR_DIRECTORY: t3(6040, e.DiagnosticCategory.Message, "FILE_OR_DIRECTORY_6040", "FILE OR DIRECTORY"), Errors_Files: t3(6041, e.DiagnosticCategory.Message, "Errors_Files_6041", "Errors  Files"), Generates_corresponding_map_file: t3(6043, e.DiagnosticCategory.Message, "Generates_corresponding_map_file_6043", "Generates corresponding '.map' file."), Compiler_option_0_expects_an_argument: t3(6044, e.DiagnosticCategory.Error, "Compiler_option_0_expects_an_argument_6044", "Compiler option '{0}' expects an argument."), Unterminated_quoted_string_in_response_file_0: t3(6045, e.DiagnosticCategory.Error, "Unterminated_quoted_string_in_response_file_0_6045", "Unterminated quoted string in response file '{0}'."), Argument_for_0_option_must_be_Colon_1: t3(6046, e.DiagnosticCategory.Error, "Argument_for_0_option_must_be_Colon_1_6046", "Argument for '{0}' option must be: {1}."), Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1: t3(6048, e.DiagnosticCategory.Error, "Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048", "Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'."), Unable_to_open_file_0: t3(6050, e.DiagnosticCategory.Error, "Unable_to_open_file_0_6050", "Unable to open file '{0}'."), Corrupted_locale_file_0: t3(6051, e.DiagnosticCategory.Error, "Corrupted_locale_file_0_6051", "Corrupted locale file {0}."), Raise_error_on_expressions_and_declarations_with_an_implied_any_type: t3(6052, e.DiagnosticCategory.Message, "Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052", "Raise error on expressions and declarations with an implied 'any' type."), File_0_not_found: t3(6053, e.DiagnosticCategory.Error, "File_0_not_found_6053", "File '{0}' not found."), File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1: t3(6054, e.DiagnosticCategory.Error, "File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1_6054", "File '{0}' has an unsupported extension. The only supported extensions are {1}."), Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures: t3(6055, e.DiagnosticCategory.Message, "Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055", "Suppress noImplicitAny errors for indexing objects lacking index signatures."), Do_not_emit_declarations_for_code_that_has_an_internal_annotation: t3(6056, e.DiagnosticCategory.Message, "Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056", "Do not emit declarations for code that has an '@internal' annotation."), Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir: t3(6058, e.DiagnosticCategory.Message, "Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir_6058", "Specify the root directory of input files. Use to control the output directory structure with --outDir."), File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files: t3(6059, e.DiagnosticCategory.Error, "File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059", "File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files."), Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix: t3(6060, e.DiagnosticCategory.Message, "Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060", "Specify the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)."), NEWLINE: t3(6061, e.DiagnosticCategory.Message, "NEWLINE_6061", "NEWLINE"), Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line: t3(6064, e.DiagnosticCategory.Error, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line_6064", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'null' on command line."), Enables_experimental_support_for_ES7_decorators: t3(6065, e.DiagnosticCategory.Message, "Enables_experimental_support_for_ES7_decorators_6065", "Enables experimental support for ES7 decorators."), Enables_experimental_support_for_emitting_type_metadata_for_decorators: t3(6066, e.DiagnosticCategory.Message, "Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066", "Enables experimental support for emitting type metadata for decorators."), Specify_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6: t3(6069, e.DiagnosticCategory.Message, "Specify_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6_6069", "Specify module resolution strategy: 'node' (Node.js) or 'classic' (TypeScript pre-1.6)."), Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file: t3(6070, e.DiagnosticCategory.Message, "Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070", "Initializes a TypeScript project and creates a tsconfig.json file."), Successfully_created_a_tsconfig_json_file: t3(6071, e.DiagnosticCategory.Message, "Successfully_created_a_tsconfig_json_file_6071", "Successfully created a tsconfig.json file."), Suppress_excess_property_checks_for_object_literals: t3(6072, e.DiagnosticCategory.Message, "Suppress_excess_property_checks_for_object_literals_6072", "Suppress excess property checks for object literals."), Stylize_errors_and_messages_using_color_and_context_experimental: t3(6073, e.DiagnosticCategory.Message, "Stylize_errors_and_messages_using_color_and_context_experimental_6073", "Stylize errors and messages using color and context (experimental)."), Do_not_report_errors_on_unused_labels: t3(6074, e.DiagnosticCategory.Message, "Do_not_report_errors_on_unused_labels_6074", "Do not report errors on unused labels."), Report_error_when_not_all_code_paths_in_function_return_a_value: t3(6075, e.DiagnosticCategory.Message, "Report_error_when_not_all_code_paths_in_function_return_a_value_6075", "Report error when not all code paths in function return a value."), Report_errors_for_fallthrough_cases_in_switch_statement: t3(6076, e.DiagnosticCategory.Message, "Report_errors_for_fallthrough_cases_in_switch_statement_6076", "Report errors for fallthrough cases in switch statement."), Do_not_report_errors_on_unreachable_code: t3(6077, e.DiagnosticCategory.Message, "Do_not_report_errors_on_unreachable_code_6077", "Do not report errors on unreachable code."), Disallow_inconsistently_cased_references_to_the_same_file: t3(6078, e.DiagnosticCategory.Message, "Disallow_inconsistently_cased_references_to_the_same_file_6078", "Disallow inconsistently-cased references to the same file."), Specify_library_files_to_be_included_in_the_compilation: t3(6079, e.DiagnosticCategory.Message, "Specify_library_files_to_be_included_in_the_compilation_6079", "Specify library files to be included in the compilation."), Specify_JSX_code_generation: t3(6080, e.DiagnosticCategory.Message, "Specify_JSX_code_generation_6080", "Specify JSX code generation."), File_0_has_an_unsupported_extension_so_skipping_it: t3(6081, e.DiagnosticCategory.Message, "File_0_has_an_unsupported_extension_so_skipping_it_6081", "File '{0}' has an unsupported extension, so skipping it."), Only_amd_and_system_modules_are_supported_alongside_0: t3(6082, e.DiagnosticCategory.Error, "Only_amd_and_system_modules_are_supported_alongside_0_6082", "Only 'amd' and 'system' modules are supported alongside --{0}."), Base_directory_to_resolve_non_absolute_module_names: t3(6083, e.DiagnosticCategory.Message, "Base_directory_to_resolve_non_absolute_module_names_6083", "Base directory to resolve non-absolute module names."), Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit: t3(6084, e.DiagnosticCategory.Message, "Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react__6084", "[Deprecated] Use '--jsxFactory' instead. Specify the object invoked for createElement when targeting 'react' JSX emit"), Enable_tracing_of_the_name_resolution_process: t3(6085, e.DiagnosticCategory.Message, "Enable_tracing_of_the_name_resolution_process_6085", "Enable tracing of the name resolution process."), Resolving_module_0_from_1: t3(6086, e.DiagnosticCategory.Message, "Resolving_module_0_from_1_6086", "======== Resolving module '{0}' from '{1}'. ========"), Explicitly_specified_module_resolution_kind_Colon_0: t3(6087, e.DiagnosticCategory.Message, "Explicitly_specified_module_resolution_kind_Colon_0_6087", "Explicitly specified module resolution kind: '{0}'."), Module_resolution_kind_is_not_specified_using_0: t3(6088, e.DiagnosticCategory.Message, "Module_resolution_kind_is_not_specified_using_0_6088", "Module resolution kind is not specified, using '{0}'."), Module_name_0_was_successfully_resolved_to_1: t3(6089, e.DiagnosticCategory.Message, "Module_name_0_was_successfully_resolved_to_1_6089", "======== Module name '{0}' was successfully resolved to '{1}'. ========"), Module_name_0_was_not_resolved: t3(6090, e.DiagnosticCategory.Message, "Module_name_0_was_not_resolved_6090", "======== Module name '{0}' was not resolved. ========"), paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0: t3(6091, e.DiagnosticCategory.Message, "paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0_6091", "'paths' option is specified, looking for a pattern to match module name '{0}'."), Module_name_0_matched_pattern_1: t3(6092, e.DiagnosticCategory.Message, "Module_name_0_matched_pattern_1_6092", "Module name '{0}', matched pattern '{1}'."), Trying_substitution_0_candidate_module_location_Colon_1: t3(6093, e.DiagnosticCategory.Message, "Trying_substitution_0_candidate_module_location_Colon_1_6093", "Trying substitution '{0}', candidate module location: '{1}'."), Resolving_module_name_0_relative_to_base_url_1_2: t3(6094, e.DiagnosticCategory.Message, "Resolving_module_name_0_relative_to_base_url_1_2_6094", "Resolving module name '{0}' relative to base url '{1}' - '{2}'."), Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_type_1: t3(6095, e.DiagnosticCategory.Message, "Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_type_1_6095", "Loading module as file / folder, candidate module location '{0}', target file type '{1}'."), File_0_does_not_exist: t3(6096, e.DiagnosticCategory.Message, "File_0_does_not_exist_6096", "File '{0}' does not exist."), File_0_exist_use_it_as_a_name_resolution_result: t3(6097, e.DiagnosticCategory.Message, "File_0_exist_use_it_as_a_name_resolution_result_6097", "File '{0}' exist - use it as a name resolution result."), Loading_module_0_from_node_modules_folder_target_file_type_1: t3(6098, e.DiagnosticCategory.Message, "Loading_module_0_from_node_modules_folder_target_file_type_1_6098", "Loading module '{0}' from 'node_modules' folder, target file type '{1}'."), Found_package_json_at_0: t3(6099, e.DiagnosticCategory.Message, "Found_package_json_at_0_6099", "Found 'package.json' at '{0}'."), package_json_does_not_have_a_0_field: t3(6100, e.DiagnosticCategory.Message, "package_json_does_not_have_a_0_field_6100", "'package.json' does not have a '{0}' field."), package_json_has_0_field_1_that_references_2: t3(6101, e.DiagnosticCategory.Message, "package_json_has_0_field_1_that_references_2_6101", "'package.json' has '{0}' field '{1}' that references '{2}'."), Allow_javascript_files_to_be_compiled: t3(6102, e.DiagnosticCategory.Message, "Allow_javascript_files_to_be_compiled_6102", "Allow javascript files to be compiled."), Checking_if_0_is_the_longest_matching_prefix_for_1_2: t3(6104, e.DiagnosticCategory.Message, "Checking_if_0_is_the_longest_matching_prefix_for_1_2_6104", "Checking if '{0}' is the longest matching prefix for '{1}' - '{2}'."), Expected_type_of_0_field_in_package_json_to_be_1_got_2: t3(6105, e.DiagnosticCategory.Message, "Expected_type_of_0_field_in_package_json_to_be_1_got_2_6105", "Expected type of '{0}' field in 'package.json' to be '{1}', got '{2}'."), baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1: t3(6106, e.DiagnosticCategory.Message, "baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1_6106", "'baseUrl' option is set to '{0}', using this value to resolve non-relative module name '{1}'."), rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0: t3(6107, e.DiagnosticCategory.Message, "rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0_6107", "'rootDirs' option is set, using it to resolve relative module name '{0}'."), Longest_matching_prefix_for_0_is_1: t3(6108, e.DiagnosticCategory.Message, "Longest_matching_prefix_for_0_is_1_6108", "Longest matching prefix for '{0}' is '{1}'."), Loading_0_from_the_root_dir_1_candidate_location_2: t3(6109, e.DiagnosticCategory.Message, "Loading_0_from_the_root_dir_1_candidate_location_2_6109", "Loading '{0}' from the root dir '{1}', candidate location '{2}'."), Trying_other_entries_in_rootDirs: t3(6110, e.DiagnosticCategory.Message, "Trying_other_entries_in_rootDirs_6110", "Trying other entries in 'rootDirs'."), Module_resolution_using_rootDirs_has_failed: t3(6111, e.DiagnosticCategory.Message, "Module_resolution_using_rootDirs_has_failed_6111", "Module resolution using 'rootDirs' has failed."), Do_not_emit_use_strict_directives_in_module_output: t3(6112, e.DiagnosticCategory.Message, "Do_not_emit_use_strict_directives_in_module_output_6112", "Do not emit 'use strict' directives in module output."), Enable_strict_null_checks: t3(6113, e.DiagnosticCategory.Message, "Enable_strict_null_checks_6113", "Enable strict null checks."), Unknown_option_excludes_Did_you_mean_exclude: t3(6114, e.DiagnosticCategory.Error, "Unknown_option_excludes_Did_you_mean_exclude_6114", "Unknown option 'excludes'. Did you mean 'exclude'?"), Raise_error_on_this_expressions_with_an_implied_any_type: t3(6115, e.DiagnosticCategory.Message, "Raise_error_on_this_expressions_with_an_implied_any_type_6115", "Raise error on 'this' expressions with an implied 'any' type."), Resolving_type_reference_directive_0_containing_file_1_root_directory_2: t3(6116, e.DiagnosticCategory.Message, "Resolving_type_reference_directive_0_containing_file_1_root_directory_2_6116", "======== Resolving type reference directive '{0}', containing file '{1}', root directory '{2}'. ========"), Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2: t3(6119, e.DiagnosticCategory.Message, "Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2_6119", "======== Type reference directive '{0}' was successfully resolved to '{1}', primary: {2}. ========"), Type_reference_directive_0_was_not_resolved: t3(6120, e.DiagnosticCategory.Message, "Type_reference_directive_0_was_not_resolved_6120", "======== Type reference directive '{0}' was not resolved. ========"), Resolving_with_primary_search_path_0: t3(6121, e.DiagnosticCategory.Message, "Resolving_with_primary_search_path_0_6121", "Resolving with primary search path '{0}'."), Root_directory_cannot_be_determined_skipping_primary_search_paths: t3(6122, e.DiagnosticCategory.Message, "Root_directory_cannot_be_determined_skipping_primary_search_paths_6122", "Root directory cannot be determined, skipping primary search paths."), Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set: t3(6123, e.DiagnosticCategory.Message, "Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set_6123", "======== Resolving type reference directive '{0}', containing file '{1}', root directory not set. ========"), Type_declaration_files_to_be_included_in_compilation: t3(6124, e.DiagnosticCategory.Message, "Type_declaration_files_to_be_included_in_compilation_6124", "Type declaration files to be included in compilation."), Looking_up_in_node_modules_folder_initial_location_0: t3(6125, e.DiagnosticCategory.Message, "Looking_up_in_node_modules_folder_initial_location_0_6125", "Looking up in 'node_modules' folder, initial location '{0}'."), Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder: t3(6126, e.DiagnosticCategory.Message, "Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_mod_6126", "Containing file is not specified and root directory cannot be determined, skipping lookup in 'node_modules' folder."), Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1: t3(6127, e.DiagnosticCategory.Message, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1_6127", "======== Resolving type reference directive '{0}', containing file not set, root directory '{1}'. ========"), Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set: t3(6128, e.DiagnosticCategory.Message, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set_6128", "======== Resolving type reference directive '{0}', containing file not set, root directory not set. ========"), Resolving_real_path_for_0_result_1: t3(6130, e.DiagnosticCategory.Message, "Resolving_real_path_for_0_result_1_6130", "Resolving real path for '{0}', result '{1}'."), Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system: t3(6131, e.DiagnosticCategory.Error, "Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system_6131", "Cannot compile modules using option '{0}' unless the '--module' flag is 'amd' or 'system'."), File_name_0_has_a_1_extension_stripping_it: t3(6132, e.DiagnosticCategory.Message, "File_name_0_has_a_1_extension_stripping_it_6132", "File name '{0}' has a '{1}' extension - stripping it."), _0_is_declared_but_its_value_is_never_read: t3(6133, e.DiagnosticCategory.Error, "_0_is_declared_but_its_value_is_never_read_6133", "'{0}' is declared but its value is never read.", true), Report_errors_on_unused_locals: t3(6134, e.DiagnosticCategory.Message, "Report_errors_on_unused_locals_6134", "Report errors on unused locals."), Report_errors_on_unused_parameters: t3(6135, e.DiagnosticCategory.Message, "Report_errors_on_unused_parameters_6135", "Report errors on unused parameters."), The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files: t3(6136, e.DiagnosticCategory.Message, "The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files_6136", "The maximum dependency depth to search under node_modules and load JavaScript files."), Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1: t3(6137, e.DiagnosticCategory.Error, "Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1_6137", "Cannot import type declaration files. Consider importing '{0}' instead of '{1}'."), Property_0_is_declared_but_its_value_is_never_read: t3(6138, e.DiagnosticCategory.Error, "Property_0_is_declared_but_its_value_is_never_read_6138", "Property '{0}' is declared but its value is never read.", true), Import_emit_helpers_from_tslib: t3(6139, e.DiagnosticCategory.Message, "Import_emit_helpers_from_tslib_6139", "Import emit helpers from 'tslib'."), Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2: t3(6140, e.DiagnosticCategory.Error, "Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using__6140", "Auto discovery for typings is enabled in project '{0}'. Running extra resolution pass for module '{1}' using cache location '{2}'."), Parse_in_strict_mode_and_emit_use_strict_for_each_source_file: t3(6141, e.DiagnosticCategory.Message, "Parse_in_strict_mode_and_emit_use_strict_for_each_source_file_6141", 'Parse in strict mode and emit "use strict" for each source file.'), Module_0_was_resolved_to_1_but_jsx_is_not_set: t3(6142, e.DiagnosticCategory.Error, "Module_0_was_resolved_to_1_but_jsx_is_not_set_6142", "Module '{0}' was resolved to '{1}', but '--jsx' is not set."), Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1: t3(6144, e.DiagnosticCategory.Message, "Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1_6144", "Module '{0}' was resolved as locally declared ambient module in file '{1}'."), Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified: t3(6145, e.DiagnosticCategory.Message, "Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified_6145", "Module '{0}' was resolved as ambient module declared in '{1}' since this file was not modified."), Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h: t3(6146, e.DiagnosticCategory.Message, "Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h_6146", "Specify the JSX factory function to use when targeting 'react' JSX emit, e.g. 'React.createElement' or 'h'."), Resolution_for_module_0_was_found_in_cache_from_location_1: t3(6147, e.DiagnosticCategory.Message, "Resolution_for_module_0_was_found_in_cache_from_location_1_6147", "Resolution for module '{0}' was found in cache from location '{1}'."), Directory_0_does_not_exist_skipping_all_lookups_in_it: t3(6148, e.DiagnosticCategory.Message, "Directory_0_does_not_exist_skipping_all_lookups_in_it_6148", "Directory '{0}' does not exist, skipping all lookups in it."), Show_diagnostic_information: t3(6149, e.DiagnosticCategory.Message, "Show_diagnostic_information_6149", "Show diagnostic information."), Show_verbose_diagnostic_information: t3(6150, e.DiagnosticCategory.Message, "Show_verbose_diagnostic_information_6150", "Show verbose diagnostic information."), Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file: t3(6151, e.DiagnosticCategory.Message, "Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file_6151", "Emit a single file with source maps instead of having a separate file."), Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set: t3(6152, e.DiagnosticCategory.Message, "Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap__6152", "Emit the source alongside the sourcemaps within a single file; requires '--inlineSourceMap' or '--sourceMap' to be set."), Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule: t3(6153, e.DiagnosticCategory.Message, "Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule_6153", "Transpile each file as a separate module (similar to 'ts.transpileModule')."), Print_names_of_generated_files_part_of_the_compilation: t3(6154, e.DiagnosticCategory.Message, "Print_names_of_generated_files_part_of_the_compilation_6154", "Print names of generated files part of the compilation."), Print_names_of_files_part_of_the_compilation: t3(6155, e.DiagnosticCategory.Message, "Print_names_of_files_part_of_the_compilation_6155", "Print names of files part of the compilation."), The_locale_used_when_displaying_messages_to_the_user_e_g_en_us: t3(6156, e.DiagnosticCategory.Message, "The_locale_used_when_displaying_messages_to_the_user_e_g_en_us_6156", "The locale used when displaying messages to the user (e.g. 'en-us')"), Do_not_generate_custom_helper_functions_like_extends_in_compiled_output: t3(6157, e.DiagnosticCategory.Message, "Do_not_generate_custom_helper_functions_like_extends_in_compiled_output_6157", "Do not generate custom helper functions like '__extends' in compiled output."), Do_not_include_the_default_library_file_lib_d_ts: t3(6158, e.DiagnosticCategory.Message, "Do_not_include_the_default_library_file_lib_d_ts_6158", "Do not include the default library file (lib.d.ts)."), Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files: t3(6159, e.DiagnosticCategory.Message, "Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files_6159", "Do not add triple-slash references or imported modules to the list of compiled files."), Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files: t3(6160, e.DiagnosticCategory.Message, "Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files_6160", "[Deprecated] Use '--skipLibCheck' instead. Skip type checking of default library declaration files."), List_of_folders_to_include_type_definitions_from: t3(6161, e.DiagnosticCategory.Message, "List_of_folders_to_include_type_definitions_from_6161", "List of folders to include type definitions from."), Disable_size_limitations_on_JavaScript_projects: t3(6162, e.DiagnosticCategory.Message, "Disable_size_limitations_on_JavaScript_projects_6162", "Disable size limitations on JavaScript projects."), The_character_set_of_the_input_files: t3(6163, e.DiagnosticCategory.Message, "The_character_set_of_the_input_files_6163", "The character set of the input files."), Do_not_truncate_error_messages: t3(6165, e.DiagnosticCategory.Message, "Do_not_truncate_error_messages_6165", "Do not truncate error messages."), Output_directory_for_generated_declaration_files: t3(6166, e.DiagnosticCategory.Message, "Output_directory_for_generated_declaration_files_6166", "Output directory for generated declaration files."), A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl: t3(6167, e.DiagnosticCategory.Message, "A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl_6167", "A series of entries which re-map imports to lookup locations relative to the 'baseUrl'."), List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime: t3(6168, e.DiagnosticCategory.Message, "List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime_6168", "List of root folders whose combined content represents the structure of the project at runtime."), Show_all_compiler_options: t3(6169, e.DiagnosticCategory.Message, "Show_all_compiler_options_6169", "Show all compiler options."), Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file: t3(6170, e.DiagnosticCategory.Message, "Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file_6170", "[Deprecated] Use '--outFile' instead. Concatenate and emit output to single file"), Command_line_Options: t3(6171, e.DiagnosticCategory.Message, "Command_line_Options_6171", "Command-line Options"), Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3: t3(6179, e.DiagnosticCategory.Message, "Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3_6179", "Provide full support for iterables in 'for-of', spread, and destructuring when targeting 'ES5' or 'ES3'."), Enable_all_strict_type_checking_options: t3(6180, e.DiagnosticCategory.Message, "Enable_all_strict_type_checking_options_6180", "Enable all strict type-checking options."), Scoped_package_detected_looking_in_0: t3(6182, e.DiagnosticCategory.Message, "Scoped_package_detected_looking_in_0_6182", "Scoped package detected, looking in '{0}'"), Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2: t3(6183, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_6183", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."), Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: t3(6184, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package__6184", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."), Enable_strict_checking_of_function_types: t3(6186, e.DiagnosticCategory.Message, "Enable_strict_checking_of_function_types_6186", "Enable strict checking of function types."), Enable_strict_checking_of_property_initialization_in_classes: t3(6187, e.DiagnosticCategory.Message, "Enable_strict_checking_of_property_initialization_in_classes_6187", "Enable strict checking of property initialization in classes."), Numeric_separators_are_not_allowed_here: t3(6188, e.DiagnosticCategory.Error, "Numeric_separators_are_not_allowed_here_6188", "Numeric separators are not allowed here."), Multiple_consecutive_numeric_separators_are_not_permitted: t3(6189, e.DiagnosticCategory.Error, "Multiple_consecutive_numeric_separators_are_not_permitted_6189", "Multiple consecutive numeric separators are not permitted."), Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen: t3(6191, e.DiagnosticCategory.Message, "Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen_6191", "Whether to keep outdated console output in watch mode instead of clearing the screen."), All_imports_in_import_declaration_are_unused: t3(6192, e.DiagnosticCategory.Error, "All_imports_in_import_declaration_are_unused_6192", "All imports in import declaration are unused.", true), Found_1_error_Watching_for_file_changes: t3(6193, e.DiagnosticCategory.Message, "Found_1_error_Watching_for_file_changes_6193", "Found 1 error. Watching for file changes."), Found_0_errors_Watching_for_file_changes: t3(6194, e.DiagnosticCategory.Message, "Found_0_errors_Watching_for_file_changes_6194", "Found {0} errors. Watching for file changes."), Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols: t3(6195, e.DiagnosticCategory.Message, "Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols_6195", "Resolve 'keyof' to string valued property names only (no numbers or symbols)."), _0_is_declared_but_never_used: t3(6196, e.DiagnosticCategory.Error, "_0_is_declared_but_never_used_6196", "'{0}' is declared but never used.", true), Include_modules_imported_with_json_extension: t3(6197, e.DiagnosticCategory.Message, "Include_modules_imported_with_json_extension_6197", "Include modules imported with '.json' extension"), All_destructured_elements_are_unused: t3(6198, e.DiagnosticCategory.Error, "All_destructured_elements_are_unused_6198", "All destructured elements are unused.", true), All_variables_are_unused: t3(6199, e.DiagnosticCategory.Error, "All_variables_are_unused_6199", "All variables are unused.", true), Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0: t3(6200, e.DiagnosticCategory.Error, "Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0_6200", "Definitions of the following identifiers conflict with those in another file: {0}"), Conflicts_are_in_this_file: t3(6201, e.DiagnosticCategory.Message, "Conflicts_are_in_this_file_6201", "Conflicts are in this file."), Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0: t3(6202, e.DiagnosticCategory.Error, "Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0_6202", "Project references may not form a circular graph. Cycle detected: {0}"), _0_was_also_declared_here: t3(6203, e.DiagnosticCategory.Message, "_0_was_also_declared_here_6203", "'{0}' was also declared here."), and_here: t3(6204, e.DiagnosticCategory.Message, "and_here_6204", "and here."), All_type_parameters_are_unused: t3(6205, e.DiagnosticCategory.Error, "All_type_parameters_are_unused_6205", "All type parameters are unused."), package_json_has_a_typesVersions_field_with_version_specific_path_mappings: t3(6206, e.DiagnosticCategory.Message, "package_json_has_a_typesVersions_field_with_version_specific_path_mappings_6206", "'package.json' has a 'typesVersions' field with version-specific path mappings."), package_json_does_not_have_a_typesVersions_entry_that_matches_version_0: t3(6207, e.DiagnosticCategory.Message, "package_json_does_not_have_a_typesVersions_entry_that_matches_version_0_6207", "'package.json' does not have a 'typesVersions' entry that matches version '{0}'."), package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2: t3(6208, e.DiagnosticCategory.Message, "package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_ma_6208", "'package.json' has a 'typesVersions' entry '{0}' that matches compiler version '{1}', looking for a pattern to match module name '{2}'."), package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range: t3(6209, e.DiagnosticCategory.Message, "package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range_6209", "'package.json' has a 'typesVersions' entry '{0}' that is not a valid semver range."), An_argument_for_0_was_not_provided: t3(6210, e.DiagnosticCategory.Message, "An_argument_for_0_was_not_provided_6210", "An argument for '{0}' was not provided."), An_argument_matching_this_binding_pattern_was_not_provided: t3(6211, e.DiagnosticCategory.Message, "An_argument_matching_this_binding_pattern_was_not_provided_6211", "An argument matching this binding pattern was not provided."), Did_you_mean_to_call_this_expression: t3(6212, e.DiagnosticCategory.Message, "Did_you_mean_to_call_this_expression_6212", "Did you mean to call this expression?"), Did_you_mean_to_use_new_with_this_expression: t3(6213, e.DiagnosticCategory.Message, "Did_you_mean_to_use_new_with_this_expression_6213", "Did you mean to use 'new' with this expression?"), Enable_strict_bind_call_and_apply_methods_on_functions: t3(6214, e.DiagnosticCategory.Message, "Enable_strict_bind_call_and_apply_methods_on_functions_6214", "Enable strict 'bind', 'call', and 'apply' methods on functions."), Using_compiler_options_of_project_reference_redirect_0: t3(6215, e.DiagnosticCategory.Message, "Using_compiler_options_of_project_reference_redirect_0_6215", "Using compiler options of project reference redirect '{0}'."), Found_1_error: t3(6216, e.DiagnosticCategory.Message, "Found_1_error_6216", "Found 1 error."), Found_0_errors: t3(6217, e.DiagnosticCategory.Message, "Found_0_errors_6217", "Found {0} errors."), Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2: t3(6218, e.DiagnosticCategory.Message, "Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2_6218", "======== Module name '{0}' was successfully resolved to '{1}' with Package ID '{2}'. ========"), Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3: t3(6219, e.DiagnosticCategory.Message, "Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3_6219", "======== Type reference directive '{0}' was successfully resolved to '{1}' with Package ID '{2}', primary: {3}. ========"), package_json_had_a_falsy_0_field: t3(6220, e.DiagnosticCategory.Message, "package_json_had_a_falsy_0_field_6220", "'package.json' had a falsy '{0}' field."), Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects: t3(6221, e.DiagnosticCategory.Message, "Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects_6221", "Disable use of source files instead of declaration files from referenced projects."), Emit_class_fields_with_Define_instead_of_Set: t3(6222, e.DiagnosticCategory.Message, "Emit_class_fields_with_Define_instead_of_Set_6222", "Emit class fields with Define instead of Set."), Generates_a_CPU_profile: t3(6223, e.DiagnosticCategory.Message, "Generates_a_CPU_profile_6223", "Generates a CPU profile."), Disable_solution_searching_for_this_project: t3(6224, e.DiagnosticCategory.Message, "Disable_solution_searching_for_this_project_6224", "Disable solution searching for this project."), Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory: t3(6225, e.DiagnosticCategory.Message, "Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_Dynami_6225", "Specify strategy for watching file: 'FixedPollingInterval' (default), 'PriorityPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling', 'UseFsEvents', 'UseFsEventsOnParentDirectory'."), Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling: t3(6226, e.DiagnosticCategory.Message, "Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively__6226", "Specify strategy for watching directory on platforms that don't support recursive watching natively: 'UseFsEvents' (default), 'FixedPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling'."), Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize: t3(6227, e.DiagnosticCategory.Message, "Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_6227", "Specify strategy for creating a polling watch when it fails to create using file system events: 'FixedInterval' (default), 'PriorityInterval', 'DynamicPriority', 'FixedChunkSize'."), Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3: t3(6229, e.DiagnosticCategory.Error, "Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3_6229", "Tag '{0}' expects at least '{1}' arguments, but the JSX factory '{2}' provides at most '{3}'."), Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line: t3(6230, e.DiagnosticCategory.Error, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line_6230", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'false' or 'null' on command line."), Could_not_resolve_the_path_0_with_the_extensions_Colon_1: t3(6231, e.DiagnosticCategory.Error, "Could_not_resolve_the_path_0_with_the_extensions_Colon_1_6231", "Could not resolve the path '{0}' with the extensions: {1}."), Declaration_augments_declaration_in_another_file_This_cannot_be_serialized: t3(6232, e.DiagnosticCategory.Error, "Declaration_augments_declaration_in_another_file_This_cannot_be_serialized_6232", "Declaration augments declaration in another file. This cannot be serialized."), This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file: t3(6233, e.DiagnosticCategory.Error, "This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_fil_6233", "This is the declaration being augmented. Consider moving the augmenting declaration into the same file."), This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without: t3(6234, e.DiagnosticCategory.Error, "This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without_6234", "This expression is not callable because it is a 'get' accessor. Did you mean to use it without '()'?"), Disable_loading_referenced_projects: t3(6235, e.DiagnosticCategory.Message, "Disable_loading_referenced_projects_6235", "Disable loading referenced projects."), Arguments_for_the_rest_parameter_0_were_not_provided: t3(6236, e.DiagnosticCategory.Error, "Arguments_for_the_rest_parameter_0_were_not_provided_6236", "Arguments for the rest parameter '{0}' were not provided."), Generates_an_event_trace_and_a_list_of_types: t3(6237, e.DiagnosticCategory.Message, "Generates_an_event_trace_and_a_list_of_types_6237", "Generates an event trace and a list of types."), Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react: t3(6238, e.DiagnosticCategory.Error, "Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react_6238", "Specify the module specifier to be used to import the 'jsx' and 'jsxs' factory functions from. eg, react"), File_0_exists_according_to_earlier_cached_lookups: t3(6239, e.DiagnosticCategory.Message, "File_0_exists_according_to_earlier_cached_lookups_6239", "File '{0}' exists according to earlier cached lookups."), File_0_does_not_exist_according_to_earlier_cached_lookups: t3(6240, e.DiagnosticCategory.Message, "File_0_does_not_exist_according_to_earlier_cached_lookups_6240", "File '{0}' does not exist according to earlier cached lookups."), Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1: t3(6241, e.DiagnosticCategory.Message, "Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1_6241", "Resolution for type reference directive '{0}' was found in cache from location '{1}'."), Resolving_type_reference_directive_0_containing_file_1: t3(6242, e.DiagnosticCategory.Message, "Resolving_type_reference_directive_0_containing_file_1_6242", "======== Resolving type reference directive '{0}', containing file '{1}'. ========"), Interpret_optional_property_types_as_written_rather_than_adding_undefined: t3(6243, e.DiagnosticCategory.Message, "Interpret_optional_property_types_as_written_rather_than_adding_undefined_6243", "Interpret optional property types as written, rather than adding 'undefined'."), Modules: t3(6244, e.DiagnosticCategory.Message, "Modules_6244", "Modules"), File_Management: t3(6245, e.DiagnosticCategory.Message, "File_Management_6245", "File Management"), Emit: t3(6246, e.DiagnosticCategory.Message, "Emit_6246", "Emit"), JavaScript_Support: t3(6247, e.DiagnosticCategory.Message, "JavaScript_Support_6247", "JavaScript Support"), Type_Checking: t3(6248, e.DiagnosticCategory.Message, "Type_Checking_6248", "Type Checking"), Editor_Support: t3(6249, e.DiagnosticCategory.Message, "Editor_Support_6249", "Editor Support"), Watch_and_Build_Modes: t3(6250, e.DiagnosticCategory.Message, "Watch_and_Build_Modes_6250", "Watch and Build Modes"), Compiler_Diagnostics: t3(6251, e.DiagnosticCategory.Message, "Compiler_Diagnostics_6251", "Compiler Diagnostics"), Interop_Constraints: t3(6252, e.DiagnosticCategory.Message, "Interop_Constraints_6252", "Interop Constraints"), Backwards_Compatibility: t3(6253, e.DiagnosticCategory.Message, "Backwards_Compatibility_6253", "Backwards Compatibility"), Language_and_Environment: t3(6254, e.DiagnosticCategory.Message, "Language_and_Environment_6254", "Language and Environment"), Projects: t3(6255, e.DiagnosticCategory.Message, "Projects_6255", "Projects"), Output_Formatting: t3(6256, e.DiagnosticCategory.Message, "Output_Formatting_6256", "Output Formatting"), Completeness: t3(6257, e.DiagnosticCategory.Message, "Completeness_6257", "Completeness"), _0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file: t3(6258, e.DiagnosticCategory.Error, "_0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file_6258", "'{0}' should be set inside the 'compilerOptions' object of the config json file"), Found_1_error_in_1: t3(6259, e.DiagnosticCategory.Message, "Found_1_error_in_1_6259", "Found 1 error in {1}"), Found_0_errors_in_the_same_file_starting_at_Colon_1: t3(6260, e.DiagnosticCategory.Message, "Found_0_errors_in_the_same_file_starting_at_Colon_1_6260", "Found {0} errors in the same file, starting at: {1}"), Found_0_errors_in_1_files: t3(6261, e.DiagnosticCategory.Message, "Found_0_errors_in_1_files_6261", "Found {0} errors in {1} files."), Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve: t3(6270, e.DiagnosticCategory.Message, "Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve_6270", "Directory '{0}' has no containing package.json scope. Imports will not resolve."), Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1: t3(6271, e.DiagnosticCategory.Message, "Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6271", "Import specifier '{0}' does not exist in package.json scope at path '{1}'."), Invalid_import_specifier_0_has_no_possible_resolutions: t3(6272, e.DiagnosticCategory.Message, "Invalid_import_specifier_0_has_no_possible_resolutions_6272", "Invalid import specifier '{0}' has no possible resolutions."), package_json_scope_0_has_no_imports_defined: t3(6273, e.DiagnosticCategory.Message, "package_json_scope_0_has_no_imports_defined_6273", "package.json scope '{0}' has no imports defined."), package_json_scope_0_explicitly_maps_specifier_1_to_null: t3(6274, e.DiagnosticCategory.Message, "package_json_scope_0_explicitly_maps_specifier_1_to_null_6274", "package.json scope '{0}' explicitly maps specifier '{1}' to null."), package_json_scope_0_has_invalid_type_for_target_of_specifier_1: t3(6275, e.DiagnosticCategory.Message, "package_json_scope_0_has_invalid_type_for_target_of_specifier_1_6275", "package.json scope '{0}' has invalid type for target of specifier '{1}'"), Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1: t3(6276, e.DiagnosticCategory.Message, "Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6276", "Export specifier '{0}' does not exist in package.json scope at path '{1}'."), Enable_project_compilation: t3(6302, e.DiagnosticCategory.Message, "Enable_project_compilation_6302", "Enable project compilation"), Composite_projects_may_not_disable_declaration_emit: t3(6304, e.DiagnosticCategory.Error, "Composite_projects_may_not_disable_declaration_emit_6304", "Composite projects may not disable declaration emit."), Output_file_0_has_not_been_built_from_source_file_1: t3(6305, e.DiagnosticCategory.Error, "Output_file_0_has_not_been_built_from_source_file_1_6305", "Output file '{0}' has not been built from source file '{1}'."), Referenced_project_0_must_have_setting_composite_Colon_true: t3(6306, e.DiagnosticCategory.Error, "Referenced_project_0_must_have_setting_composite_Colon_true_6306", `Referenced project '{0}' must have setting "composite": true.`), File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern: t3(6307, e.DiagnosticCategory.Error, "File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_includ_6307", "File '{0}' is not listed within the file list of project '{1}'. Projects must list all files or use an 'include' pattern."), Cannot_prepend_project_0_because_it_does_not_have_outFile_set: t3(6308, e.DiagnosticCategory.Error, "Cannot_prepend_project_0_because_it_does_not_have_outFile_set_6308", "Cannot prepend project '{0}' because it does not have 'outFile' set"), Output_file_0_from_project_1_does_not_exist: t3(6309, e.DiagnosticCategory.Error, "Output_file_0_from_project_1_does_not_exist_6309", "Output file '{0}' from project '{1}' does not exist"), Referenced_project_0_may_not_disable_emit: t3(6310, e.DiagnosticCategory.Error, "Referenced_project_0_may_not_disable_emit_6310", "Referenced project '{0}' may not disable emit."), Project_0_is_out_of_date_because_output_1_is_older_than_input_2: t3(6350, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_output_1_is_older_than_input_2_6350", "Project '{0}' is out of date because output '{1}' is older than input '{2}'"), Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2: t3(6351, e.DiagnosticCategory.Message, "Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2_6351", "Project '{0}' is up to date because newest input '{1}' is older than output '{2}'"), Project_0_is_out_of_date_because_output_file_1_does_not_exist: t3(6352, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_output_file_1_does_not_exist_6352", "Project '{0}' is out of date because output file '{1}' does not exist"), Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date: t3(6353, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date_6353", "Project '{0}' is out of date because its dependency '{1}' is out of date"), Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies: t3(6354, e.DiagnosticCategory.Message, "Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies_6354", "Project '{0}' is up to date with .d.ts files from its dependencies"), Projects_in_this_build_Colon_0: t3(6355, e.DiagnosticCategory.Message, "Projects_in_this_build_Colon_0_6355", "Projects in this build: {0}"), A_non_dry_build_would_delete_the_following_files_Colon_0: t3(6356, e.DiagnosticCategory.Message, "A_non_dry_build_would_delete_the_following_files_Colon_0_6356", "A non-dry build would delete the following files: {0}"), A_non_dry_build_would_build_project_0: t3(6357, e.DiagnosticCategory.Message, "A_non_dry_build_would_build_project_0_6357", "A non-dry build would build project '{0}'"), Building_project_0: t3(6358, e.DiagnosticCategory.Message, "Building_project_0_6358", "Building project '{0}'..."), Updating_output_timestamps_of_project_0: t3(6359, e.DiagnosticCategory.Message, "Updating_output_timestamps_of_project_0_6359", "Updating output timestamps of project '{0}'..."), Project_0_is_up_to_date: t3(6361, e.DiagnosticCategory.Message, "Project_0_is_up_to_date_6361", "Project '{0}' is up to date"), Skipping_build_of_project_0_because_its_dependency_1_has_errors: t3(6362, e.DiagnosticCategory.Message, "Skipping_build_of_project_0_because_its_dependency_1_has_errors_6362", "Skipping build of project '{0}' because its dependency '{1}' has errors"), Project_0_can_t_be_built_because_its_dependency_1_has_errors: t3(6363, e.DiagnosticCategory.Message, "Project_0_can_t_be_built_because_its_dependency_1_has_errors_6363", "Project '{0}' can't be built because its dependency '{1}' has errors"), Build_one_or_more_projects_and_their_dependencies_if_out_of_date: t3(6364, e.DiagnosticCategory.Message, "Build_one_or_more_projects_and_their_dependencies_if_out_of_date_6364", "Build one or more projects and their dependencies, if out of date"), Delete_the_outputs_of_all_projects: t3(6365, e.DiagnosticCategory.Message, "Delete_the_outputs_of_all_projects_6365", "Delete the outputs of all projects."), Show_what_would_be_built_or_deleted_if_specified_with_clean: t3(6367, e.DiagnosticCategory.Message, "Show_what_would_be_built_or_deleted_if_specified_with_clean_6367", "Show what would be built (or deleted, if specified with '--clean')"), Option_build_must_be_the_first_command_line_argument: t3(6369, e.DiagnosticCategory.Error, "Option_build_must_be_the_first_command_line_argument_6369", "Option '--build' must be the first command line argument."), Options_0_and_1_cannot_be_combined: t3(6370, e.DiagnosticCategory.Error, "Options_0_and_1_cannot_be_combined_6370", "Options '{0}' and '{1}' cannot be combined."), Updating_unchanged_output_timestamps_of_project_0: t3(6371, e.DiagnosticCategory.Message, "Updating_unchanged_output_timestamps_of_project_0_6371", "Updating unchanged output timestamps of project '{0}'..."), Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed: t3(6372, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed_6372", "Project '{0}' is out of date because output of its dependency '{1}' has changed"), Updating_output_of_project_0: t3(6373, e.DiagnosticCategory.Message, "Updating_output_of_project_0_6373", "Updating output of project '{0}'..."), A_non_dry_build_would_update_timestamps_for_output_of_project_0: t3(6374, e.DiagnosticCategory.Message, "A_non_dry_build_would_update_timestamps_for_output_of_project_0_6374", "A non-dry build would update timestamps for output of project '{0}'"), A_non_dry_build_would_update_output_of_project_0: t3(6375, e.DiagnosticCategory.Message, "A_non_dry_build_would_update_output_of_project_0_6375", "A non-dry build would update output of project '{0}'"), Cannot_update_output_of_project_0_because_there_was_error_reading_file_1: t3(6376, e.DiagnosticCategory.Message, "Cannot_update_output_of_project_0_because_there_was_error_reading_file_1_6376", "Cannot update output of project '{0}' because there was error reading file '{1}'"), Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1: t3(6377, e.DiagnosticCategory.Error, "Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1_6377", "Cannot write file '{0}' because it will overwrite '.tsbuildinfo' file generated by referenced project '{1}'"), Composite_projects_may_not_disable_incremental_compilation: t3(6379, e.DiagnosticCategory.Error, "Composite_projects_may_not_disable_incremental_compilation_6379", "Composite projects may not disable incremental compilation."), Specify_file_to_store_incremental_compilation_information: t3(6380, e.DiagnosticCategory.Message, "Specify_file_to_store_incremental_compilation_information_6380", "Specify file to store incremental compilation information"), Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2: t3(6381, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_curren_6381", "Project '{0}' is out of date because output for it was generated with version '{1}' that differs with current version '{2}'"), Skipping_build_of_project_0_because_its_dependency_1_was_not_built: t3(6382, e.DiagnosticCategory.Message, "Skipping_build_of_project_0_because_its_dependency_1_was_not_built_6382", "Skipping build of project '{0}' because its dependency '{1}' was not built"), Project_0_can_t_be_built_because_its_dependency_1_was_not_built: t3(6383, e.DiagnosticCategory.Message, "Project_0_can_t_be_built_because_its_dependency_1_was_not_built_6383", "Project '{0}' can't be built because its dependency '{1}' was not built"), Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: t3(6384, e.DiagnosticCategory.Message, "Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_di_6384", "Have recompiles in '--incremental' and '--watch' assume that changes within a file will only affect files directly depending on it."), _0_is_deprecated: t3(6385, e.DiagnosticCategory.Suggestion, "_0_is_deprecated_6385", "'{0}' is deprecated.", void 0, void 0, true), Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_native_implementation_of_the_Web_Performance_API_could_not_be_found: t3(6386, e.DiagnosticCategory.Message, "Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_nativ_6386", "Performance timings for '--diagnostics' or '--extendedDiagnostics' are not available in this session. A native implementation of the Web Performance API could not be found."), The_signature_0_of_1_is_deprecated: t3(6387, e.DiagnosticCategory.Suggestion, "The_signature_0_of_1_is_deprecated_6387", "The signature '{0}' of '{1}' is deprecated.", void 0, void 0, true), Project_0_is_being_forcibly_rebuilt: t3(6388, e.DiagnosticCategory.Message, "Project_0_is_being_forcibly_rebuilt_6388", "Project '{0}' is being forcibly rebuilt"), Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved: t3(6389, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved_6389", "Reusing resolution of module '{0}' from '{1}' of old program, it was not resolved."), Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2: t3(6390, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6390", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."), Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: t3(6391, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6391", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."), Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved: t3(6392, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved_6392", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was not resolved."), Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: t3(6393, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6393", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."), Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: t3(6394, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6394", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."), Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: t3(6395, e.DiagnosticCategory.Message, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved_6395", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was not resolved."), Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: t3(6396, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6396", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."), Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: t3(6397, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6397", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."), Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: t3(6398, e.DiagnosticCategory.Message, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_re_6398", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was not resolved."), Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted: t3(6399, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitte_6399", "Project '{0}' is out of date because buildinfo file '{1}' indicates that some of the changes were not emitted"), Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files: t3(6400, e.DiagnosticCategory.Message, "Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_fil_6400", "Project '{0}' is up to date but needs to update timestamps of output files that are older than input files"), Project_0_is_out_of_date_because_there_was_error_reading_file_1: t3(6401, e.DiagnosticCategory.Message, "Project_0_is_out_of_date_because_there_was_error_reading_file_1_6401", "Project '{0}' is out of date because there was error reading file '{1}'"), Resolving_in_0_mode_with_conditions_1: t3(6402, e.DiagnosticCategory.Message, "Resolving_in_0_mode_with_conditions_1_6402", "Resolving in {0} mode with conditions {1}."), Matched_0_condition_1: t3(6403, e.DiagnosticCategory.Message, "Matched_0_condition_1_6403", "Matched '{0}' condition '{1}'."), Using_0_subpath_1_with_target_2: t3(6404, e.DiagnosticCategory.Message, "Using_0_subpath_1_with_target_2_6404", "Using '{0}' subpath '{1}' with target '{2}'."), Saw_non_matching_condition_0: t3(6405, e.DiagnosticCategory.Message, "Saw_non_matching_condition_0_6405", "Saw non-matching condition '{0}'."), The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1: t3(6500, e.DiagnosticCategory.Message, "The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1_6500", "The expected type comes from property '{0}' which is declared here on type '{1}'"), The_expected_type_comes_from_this_index_signature: t3(6501, e.DiagnosticCategory.Message, "The_expected_type_comes_from_this_index_signature_6501", "The expected type comes from this index signature."), The_expected_type_comes_from_the_return_type_of_this_signature: t3(6502, e.DiagnosticCategory.Message, "The_expected_type_comes_from_the_return_type_of_this_signature_6502", "The expected type comes from the return type of this signature."), Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing: t3(6503, e.DiagnosticCategory.Message, "Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing_6503", "Print names of files that are part of the compilation and then stop processing."), File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option: t3(6504, e.DiagnosticCategory.Error, "File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option_6504", "File '{0}' is a JavaScript file. Did you mean to enable the 'allowJs' option?"), Print_names_of_files_and_the_reason_they_are_part_of_the_compilation: t3(6505, e.DiagnosticCategory.Message, "Print_names_of_files_and_the_reason_they_are_part_of_the_compilation_6505", "Print names of files and the reason they are part of the compilation."), Consider_adding_a_declare_modifier_to_this_class: t3(6506, e.DiagnosticCategory.Message, "Consider_adding_a_declare_modifier_to_this_class_6506", "Consider adding a 'declare' modifier to this class."), Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these_files: t3(6600, e.DiagnosticCategory.Message, "Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these__6600", "Allow JavaScript files to be a part of your program. Use the 'checkJS' option to get errors from these files."), Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export: t3(6601, e.DiagnosticCategory.Message, "Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export_6601", "Allow 'import x from y' when a module doesn't have a default export."), Allow_accessing_UMD_globals_from_modules: t3(6602, e.DiagnosticCategory.Message, "Allow_accessing_UMD_globals_from_modules_6602", "Allow accessing UMD globals from modules."), Disable_error_reporting_for_unreachable_code: t3(6603, e.DiagnosticCategory.Message, "Disable_error_reporting_for_unreachable_code_6603", "Disable error reporting for unreachable code."), Disable_error_reporting_for_unused_labels: t3(6604, e.DiagnosticCategory.Message, "Disable_error_reporting_for_unused_labels_6604", "Disable error reporting for unused labels."), Ensure_use_strict_is_always_emitted: t3(6605, e.DiagnosticCategory.Message, "Ensure_use_strict_is_always_emitted_6605", "Ensure 'use strict' is always emitted."), Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: t3(6606, e.DiagnosticCategory.Message, "Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_wi_6606", "Have recompiles in projects that use 'incremental' and 'watch' mode assume that changes within a file will only affect files directly depending on it."), Specify_the_base_directory_to_resolve_non_relative_module_names: t3(6607, e.DiagnosticCategory.Message, "Specify_the_base_directory_to_resolve_non_relative_module_names_6607", "Specify the base directory to resolve non-relative module names."), No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files: t3(6608, e.DiagnosticCategory.Message, "No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files_6608", "No longer supported. In early versions, manually set the text encoding for reading files."), Enable_error_reporting_in_type_checked_JavaScript_files: t3(6609, e.DiagnosticCategory.Message, "Enable_error_reporting_in_type_checked_JavaScript_files_6609", "Enable error reporting in type-checked JavaScript files."), Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references: t3(6611, e.DiagnosticCategory.Message, "Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references_6611", "Enable constraints that allow a TypeScript project to be used with project references."), Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project: t3(6612, e.DiagnosticCategory.Message, "Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project_6612", "Generate .d.ts files from TypeScript and JavaScript files in your project."), Specify_the_output_directory_for_generated_declaration_files: t3(6613, e.DiagnosticCategory.Message, "Specify_the_output_directory_for_generated_declaration_files_6613", "Specify the output directory for generated declaration files."), Create_sourcemaps_for_d_ts_files: t3(6614, e.DiagnosticCategory.Message, "Create_sourcemaps_for_d_ts_files_6614", "Create sourcemaps for d.ts files."), Output_compiler_performance_information_after_building: t3(6615, e.DiagnosticCategory.Message, "Output_compiler_performance_information_after_building_6615", "Output compiler performance information after building."), Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project: t3(6616, e.DiagnosticCategory.Message, "Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project_6616", "Disables inference for type acquisition by looking at filenames in a project."), Reduce_the_number_of_projects_loaded_automatically_by_TypeScript: t3(6617, e.DiagnosticCategory.Message, "Reduce_the_number_of_projects_loaded_automatically_by_TypeScript_6617", "Reduce the number of projects loaded automatically by TypeScript."), Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server: t3(6618, e.DiagnosticCategory.Message, "Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server_6618", "Remove the 20mb cap on total source code size for JavaScript files in the TypeScript language server."), Opt_a_project_out_of_multi_project_reference_checking_when_editing: t3(6619, e.DiagnosticCategory.Message, "Opt_a_project_out_of_multi_project_reference_checking_when_editing_6619", "Opt a project out of multi-project reference checking when editing."), Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects: t3(6620, e.DiagnosticCategory.Message, "Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects_6620", "Disable preferring source files instead of declaration files when referencing composite projects."), Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration: t3(6621, e.DiagnosticCategory.Message, "Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration_6621", "Emit more compliant, but verbose and less performant JavaScript for iteration."), Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files: t3(6622, e.DiagnosticCategory.Message, "Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files_6622", "Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files."), Only_output_d_ts_files_and_not_JavaScript_files: t3(6623, e.DiagnosticCategory.Message, "Only_output_d_ts_files_and_not_JavaScript_files_6623", "Only output d.ts files and not JavaScript files."), Emit_design_type_metadata_for_decorated_declarations_in_source_files: t3(6624, e.DiagnosticCategory.Message, "Emit_design_type_metadata_for_decorated_declarations_in_source_files_6624", "Emit design-type metadata for decorated declarations in source files."), Disable_the_type_acquisition_for_JavaScript_projects: t3(6625, e.DiagnosticCategory.Message, "Disable_the_type_acquisition_for_JavaScript_projects_6625", "Disable the type acquisition for JavaScript projects"), Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility: t3(6626, e.DiagnosticCategory.Message, "Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheti_6626", "Emit additional JavaScript to ease support for importing CommonJS modules. This enables 'allowSyntheticDefaultImports' for type compatibility."), Filters_results_from_the_include_option: t3(6627, e.DiagnosticCategory.Message, "Filters_results_from_the_include_option_6627", "Filters results from the `include` option."), Remove_a_list_of_directories_from_the_watch_process: t3(6628, e.DiagnosticCategory.Message, "Remove_a_list_of_directories_from_the_watch_process_6628", "Remove a list of directories from the watch process."), Remove_a_list_of_files_from_the_watch_mode_s_processing: t3(6629, e.DiagnosticCategory.Message, "Remove_a_list_of_files_from_the_watch_mode_s_processing_6629", "Remove a list of files from the watch mode's processing."), Enable_experimental_support_for_TC39_stage_2_draft_decorators: t3(6630, e.DiagnosticCategory.Message, "Enable_experimental_support_for_TC39_stage_2_draft_decorators_6630", "Enable experimental support for TC39 stage 2 draft decorators."), Print_files_read_during_the_compilation_including_why_it_was_included: t3(6631, e.DiagnosticCategory.Message, "Print_files_read_during_the_compilation_including_why_it_was_included_6631", "Print files read during the compilation including why it was included."), Output_more_detailed_compiler_performance_information_after_building: t3(6632, e.DiagnosticCategory.Message, "Output_more_detailed_compiler_performance_information_after_building_6632", "Output more detailed compiler performance information after building."), Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_are_inherited: t3(6633, e.DiagnosticCategory.Message, "Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_a_6633", "Specify one or more path or node module references to base configuration files from which settings are inherited."), Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers: t3(6634, e.DiagnosticCategory.Message, "Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers_6634", "Specify what approach the watcher should use if the system runs out of native file watchers."), Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include: t3(6635, e.DiagnosticCategory.Message, "Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include_6635", "Include a list of files. This does not support glob patterns, as opposed to `include`."), Build_all_projects_including_those_that_appear_to_be_up_to_date: t3(6636, e.DiagnosticCategory.Message, "Build_all_projects_including_those_that_appear_to_be_up_to_date_6636", "Build all projects, including those that appear to be up to date."), Ensure_that_casing_is_correct_in_imports: t3(6637, e.DiagnosticCategory.Message, "Ensure_that_casing_is_correct_in_imports_6637", "Ensure that casing is correct in imports."), Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging: t3(6638, e.DiagnosticCategory.Message, "Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging_6638", "Emit a v8 CPU profile of the compiler run for debugging."), Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file: t3(6639, e.DiagnosticCategory.Message, "Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file_6639", "Allow importing helper functions from tslib once per project, instead of including them per-file."), Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation: t3(6641, e.DiagnosticCategory.Message, "Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation_6641", "Specify a list of glob patterns that match files to be included in compilation."), Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects: t3(6642, e.DiagnosticCategory.Message, "Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects_6642", "Save .tsbuildinfo files to allow for incremental compilation of projects."), Include_sourcemap_files_inside_the_emitted_JavaScript: t3(6643, e.DiagnosticCategory.Message, "Include_sourcemap_files_inside_the_emitted_JavaScript_6643", "Include sourcemap files inside the emitted JavaScript."), Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript: t3(6644, e.DiagnosticCategory.Message, "Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript_6644", "Include source code in the sourcemaps inside the emitted JavaScript."), Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports: t3(6645, e.DiagnosticCategory.Message, "Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports_6645", "Ensure that each file can be safely transpiled without relying on other imports."), Specify_what_JSX_code_is_generated: t3(6646, e.DiagnosticCategory.Message, "Specify_what_JSX_code_is_generated_6646", "Specify what JSX code is generated."), Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h: t3(6647, e.DiagnosticCategory.Message, "Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h_6647", "Specify the JSX factory function used when targeting React JSX emit, e.g. 'React.createElement' or 'h'."), Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment: t3(6648, e.DiagnosticCategory.Message, "Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragme_6648", "Specify the JSX Fragment reference used for fragments when targeting React JSX emit e.g. 'React.Fragment' or 'Fragment'."), Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk: t3(6649, e.DiagnosticCategory.Message, "Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Ast_6649", "Specify module specifier used to import the JSX factory functions when using 'jsx: react-jsx*'."), Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option: t3(6650, e.DiagnosticCategory.Message, "Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option_6650", "Make keyof only return strings instead of string, numbers or symbols. Legacy option."), Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment: t3(6651, e.DiagnosticCategory.Message, "Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment_6651", "Specify a set of bundled library declaration files that describe the target runtime environment."), Print_the_names_of_emitted_files_after_a_compilation: t3(6652, e.DiagnosticCategory.Message, "Print_the_names_of_emitted_files_after_a_compilation_6652", "Print the names of emitted files after a compilation."), Print_all_of_the_files_read_during_the_compilation: t3(6653, e.DiagnosticCategory.Message, "Print_all_of_the_files_read_during_the_compilation_6653", "Print all of the files read during the compilation."), Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit: t3(6654, e.DiagnosticCategory.Message, "Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit_6654", "Set the language of the messaging from TypeScript. This does not affect emit."), Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations: t3(6655, e.DiagnosticCategory.Message, "Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6655", "Specify the location where debugger should locate map files instead of generated locations."), Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs: t3(6656, e.DiagnosticCategory.Message, "Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicabl_6656", "Specify the maximum folder depth used for checking JavaScript files from 'node_modules'. Only applicable with 'allowJs'."), Specify_what_module_code_is_generated: t3(6657, e.DiagnosticCategory.Message, "Specify_what_module_code_is_generated_6657", "Specify what module code is generated."), Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier: t3(6658, e.DiagnosticCategory.Message, "Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier_6658", "Specify how TypeScript looks up a file from a given module specifier."), Set_the_newline_character_for_emitting_files: t3(6659, e.DiagnosticCategory.Message, "Set_the_newline_character_for_emitting_files_6659", "Set the newline character for emitting files."), Disable_emitting_files_from_a_compilation: t3(6660, e.DiagnosticCategory.Message, "Disable_emitting_files_from_a_compilation_6660", "Disable emitting files from a compilation."), Disable_generating_custom_helper_functions_like_extends_in_compiled_output: t3(6661, e.DiagnosticCategory.Message, "Disable_generating_custom_helper_functions_like_extends_in_compiled_output_6661", "Disable generating custom helper functions like '__extends' in compiled output."), Disable_emitting_files_if_any_type_checking_errors_are_reported: t3(6662, e.DiagnosticCategory.Message, "Disable_emitting_files_if_any_type_checking_errors_are_reported_6662", "Disable emitting files if any type checking errors are reported."), Disable_truncating_types_in_error_messages: t3(6663, e.DiagnosticCategory.Message, "Disable_truncating_types_in_error_messages_6663", "Disable truncating types in error messages."), Enable_error_reporting_for_fallthrough_cases_in_switch_statements: t3(6664, e.DiagnosticCategory.Message, "Enable_error_reporting_for_fallthrough_cases_in_switch_statements_6664", "Enable error reporting for fallthrough cases in switch statements."), Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type: t3(6665, e.DiagnosticCategory.Message, "Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type_6665", "Enable error reporting for expressions and declarations with an implied 'any' type."), Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier: t3(6666, e.DiagnosticCategory.Message, "Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier_6666", "Ensure overriding members in derived classes are marked with an override modifier."), Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function: t3(6667, e.DiagnosticCategory.Message, "Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function_6667", "Enable error reporting for codepaths that do not explicitly return in a function."), Enable_error_reporting_when_this_is_given_the_type_any: t3(6668, e.DiagnosticCategory.Message, "Enable_error_reporting_when_this_is_given_the_type_any_6668", "Enable error reporting when 'this' is given the type 'any'."), Disable_adding_use_strict_directives_in_emitted_JavaScript_files: t3(6669, e.DiagnosticCategory.Message, "Disable_adding_use_strict_directives_in_emitted_JavaScript_files_6669", "Disable adding 'use strict' directives in emitted JavaScript files."), Disable_including_any_library_files_including_the_default_lib_d_ts: t3(6670, e.DiagnosticCategory.Message, "Disable_including_any_library_files_including_the_default_lib_d_ts_6670", "Disable including any library files, including the default lib.d.ts."), Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type: t3(6671, e.DiagnosticCategory.Message, "Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type_6671", "Enforces using indexed accessors for keys declared using an indexed type."), Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project: t3(6672, e.DiagnosticCategory.Message, "Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add__6672", "Disallow 'import's, 'require's or '<reference>'s from expanding the number of files TypeScript should add to a project."), Disable_strict_checking_of_generic_signatures_in_function_types: t3(6673, e.DiagnosticCategory.Message, "Disable_strict_checking_of_generic_signatures_in_function_types_6673", "Disable strict checking of generic signatures in function types."), Add_undefined_to_a_type_when_accessed_using_an_index: t3(6674, e.DiagnosticCategory.Message, "Add_undefined_to_a_type_when_accessed_using_an_index_6674", "Add 'undefined' to a type when accessed using an index."), Enable_error_reporting_when_local_variables_aren_t_read: t3(6675, e.DiagnosticCategory.Message, "Enable_error_reporting_when_local_variables_aren_t_read_6675", "Enable error reporting when local variables aren't read."), Raise_an_error_when_a_function_parameter_isn_t_read: t3(6676, e.DiagnosticCategory.Message, "Raise_an_error_when_a_function_parameter_isn_t_read_6676", "Raise an error when a function parameter isn't read."), Deprecated_setting_Use_outFile_instead: t3(6677, e.DiagnosticCategory.Message, "Deprecated_setting_Use_outFile_instead_6677", "Deprecated setting. Use 'outFile' instead."), Specify_an_output_folder_for_all_emitted_files: t3(6678, e.DiagnosticCategory.Message, "Specify_an_output_folder_for_all_emitted_files_6678", "Specify an output folder for all emitted files."), Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output: t3(6679, e.DiagnosticCategory.Message, "Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designa_6679", "Specify a file that bundles all outputs into one JavaScript file. If 'declaration' is true, also designates a file that bundles all .d.ts output."), Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations: t3(6680, e.DiagnosticCategory.Message, "Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations_6680", "Specify a set of entries that re-map imports to additional lookup locations."), Specify_a_list_of_language_service_plugins_to_include: t3(6681, e.DiagnosticCategory.Message, "Specify_a_list_of_language_service_plugins_to_include_6681", "Specify a list of language service plugins to include."), Disable_erasing_const_enum_declarations_in_generated_code: t3(6682, e.DiagnosticCategory.Message, "Disable_erasing_const_enum_declarations_in_generated_code_6682", "Disable erasing 'const enum' declarations in generated code."), Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node: t3(6683, e.DiagnosticCategory.Message, "Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node_6683", "Disable resolving symlinks to their realpath. This correlates to the same flag in node."), Disable_wiping_the_console_in_watch_mode: t3(6684, e.DiagnosticCategory.Message, "Disable_wiping_the_console_in_watch_mode_6684", "Disable wiping the console in watch mode."), Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read: t3(6685, e.DiagnosticCategory.Message, "Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read_6685", "Enable color and formatting in TypeScript's output to make compiler errors easier to read."), Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit: t3(6686, e.DiagnosticCategory.Message, "Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit_6686", "Specify the object invoked for 'createElement'. This only applies when targeting 'react' JSX emit."), Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references: t3(6687, e.DiagnosticCategory.Message, "Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references_6687", "Specify an array of objects that specify paths for projects. Used in project references."), Disable_emitting_comments: t3(6688, e.DiagnosticCategory.Message, "Disable_emitting_comments_6688", "Disable emitting comments."), Enable_importing_json_files: t3(6689, e.DiagnosticCategory.Message, "Enable_importing_json_files_6689", "Enable importing .json files."), Specify_the_root_folder_within_your_source_files: t3(6690, e.DiagnosticCategory.Message, "Specify_the_root_folder_within_your_source_files_6690", "Specify the root folder within your source files."), Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules: t3(6691, e.DiagnosticCategory.Message, "Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules_6691", "Allow multiple folders to be treated as one when resolving modules."), Skip_type_checking_d_ts_files_that_are_included_with_TypeScript: t3(6692, e.DiagnosticCategory.Message, "Skip_type_checking_d_ts_files_that_are_included_with_TypeScript_6692", "Skip type checking .d.ts files that are included with TypeScript."), Skip_type_checking_all_d_ts_files: t3(6693, e.DiagnosticCategory.Message, "Skip_type_checking_all_d_ts_files_6693", "Skip type checking all .d.ts files."), Create_source_map_files_for_emitted_JavaScript_files: t3(6694, e.DiagnosticCategory.Message, "Create_source_map_files_for_emitted_JavaScript_files_6694", "Create source map files for emitted JavaScript files."), Specify_the_root_path_for_debuggers_to_find_the_reference_source_code: t3(6695, e.DiagnosticCategory.Message, "Specify_the_root_path_for_debuggers_to_find_the_reference_source_code_6695", "Specify the root path for debuggers to find the reference source code."), Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function: t3(6697, e.DiagnosticCategory.Message, "Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function_6697", "Check that the arguments for 'bind', 'call', and 'apply' methods match the original function."), When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible: t3(6698, e.DiagnosticCategory.Message, "When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible_6698", "When assigning functions, check to ensure parameters and the return values are subtype-compatible."), When_type_checking_take_into_account_null_and_undefined: t3(6699, e.DiagnosticCategory.Message, "When_type_checking_take_into_account_null_and_undefined_6699", "When type checking, take into account 'null' and 'undefined'."), Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor: t3(6700, e.DiagnosticCategory.Message, "Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor_6700", "Check for class properties that are declared but not set in the constructor."), Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments: t3(6701, e.DiagnosticCategory.Message, "Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments_6701", "Disable emitting declarations that have '@internal' in their JSDoc comments."), Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals: t3(6702, e.DiagnosticCategory.Message, "Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals_6702", "Disable reporting of excess property errors during the creation of object literals."), Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures: t3(6703, e.DiagnosticCategory.Message, "Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures_6703", "Suppress 'noImplicitAny' errors when indexing objects that lack index signatures."), Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively: t3(6704, e.DiagnosticCategory.Message, "Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_supp_6704", "Synchronously call callbacks and update the state of directory watchers on platforms that don`t support recursive watching natively."), Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations: t3(6705, e.DiagnosticCategory.Message, "Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declaratio_6705", "Set the JavaScript language version for emitted JavaScript and include compatible library declarations."), Log_paths_used_during_the_moduleResolution_process: t3(6706, e.DiagnosticCategory.Message, "Log_paths_used_during_the_moduleResolution_process_6706", "Log paths used during the 'moduleResolution' process."), Specify_the_path_to_tsbuildinfo_incremental_compilation_file: t3(6707, e.DiagnosticCategory.Message, "Specify_the_path_to_tsbuildinfo_incremental_compilation_file_6707", "Specify the path to .tsbuildinfo incremental compilation file."), Specify_options_for_automatic_acquisition_of_declaration_files: t3(6709, e.DiagnosticCategory.Message, "Specify_options_for_automatic_acquisition_of_declaration_files_6709", "Specify options for automatic acquisition of declaration files."), Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types: t3(6710, e.DiagnosticCategory.Message, "Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types_6710", "Specify multiple folders that act like './node_modules/@types'."), Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file: t3(6711, e.DiagnosticCategory.Message, "Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file_6711", "Specify type package names to be included without being referenced in a source file."), Emit_ECMAScript_standard_compliant_class_fields: t3(6712, e.DiagnosticCategory.Message, "Emit_ECMAScript_standard_compliant_class_fields_6712", "Emit ECMAScript-standard-compliant class fields."), Enable_verbose_logging: t3(6713, e.DiagnosticCategory.Message, "Enable_verbose_logging_6713", "Enable verbose logging."), Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality: t3(6714, e.DiagnosticCategory.Message, "Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality_6714", "Specify how directories are watched on systems that lack recursive file-watching functionality."), Specify_how_the_TypeScript_watch_mode_works: t3(6715, e.DiagnosticCategory.Message, "Specify_how_the_TypeScript_watch_mode_works_6715", "Specify how the TypeScript watch mode works."), Require_undeclared_properties_from_index_signatures_to_use_element_accesses: t3(6717, e.DiagnosticCategory.Message, "Require_undeclared_properties_from_index_signatures_to_use_element_accesses_6717", "Require undeclared properties from index signatures to use element accesses."), Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types: t3(6718, e.DiagnosticCategory.Message, "Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types_6718", "Specify emit/checking behavior for imports that are only used for types."), Default_catch_clause_variables_as_unknown_instead_of_any: t3(6803, e.DiagnosticCategory.Message, "Default_catch_clause_variables_as_unknown_instead_of_any_6803", "Default catch clause variables as 'unknown' instead of 'any'."), one_of_Colon: t3(6900, e.DiagnosticCategory.Message, "one_of_Colon_6900", "one of:"), one_or_more_Colon: t3(6901, e.DiagnosticCategory.Message, "one_or_more_Colon_6901", "one or more:"), type_Colon: t3(6902, e.DiagnosticCategory.Message, "type_Colon_6902", "type:"), default_Colon: t3(6903, e.DiagnosticCategory.Message, "default_Colon_6903", "default:"), module_system_or_esModuleInterop: t3(6904, e.DiagnosticCategory.Message, "module_system_or_esModuleInterop_6904", 'module === "system" or esModuleInterop'), false_unless_strict_is_set: t3(6905, e.DiagnosticCategory.Message, "false_unless_strict_is_set_6905", "`false`, unless `strict` is set"), false_unless_composite_is_set: t3(6906, e.DiagnosticCategory.Message, "false_unless_composite_is_set_6906", "`false`, unless `composite` is set"), node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified: t3(6907, e.DiagnosticCategory.Message, "node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified_6907", '`["node_modules", "bower_components", "jspm_packages"]`, plus the value of `outDir` if one is specified.'), if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk: t3(6908, e.DiagnosticCategory.Message, "if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk_6908", '`[]` if `files` is specified, otherwise `["**/*"]`'), true_if_composite_false_otherwise: t3(6909, e.DiagnosticCategory.Message, "true_if_composite_false_otherwise_6909", "`true` if `composite`, `false` otherwise"), module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node: t3(69010, e.DiagnosticCategory.Message, "module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node_69010", "module === `AMD` or `UMD` or `System` or `ES6`, then `Classic`, Otherwise `Node`"), Computed_from_the_list_of_input_files: t3(6911, e.DiagnosticCategory.Message, "Computed_from_the_list_of_input_files_6911", "Computed from the list of input files"), Platform_specific: t3(6912, e.DiagnosticCategory.Message, "Platform_specific_6912", "Platform specific"), You_can_learn_about_all_of_the_compiler_options_at_0: t3(6913, e.DiagnosticCategory.Message, "You_can_learn_about_all_of_the_compiler_options_at_0_6913", "You can learn about all of the compiler options at {0}"), Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_config_watch_mode_with_Colon: t3(6914, e.DiagnosticCategory.Message, "Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_conf_6914", "Including --watch, -w will start watching the current project for the file changes. Once set, you can config watch mode with:"), Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_trigger_building_composite_projects_which_you_can_learn_more_about_at_0: t3(6915, e.DiagnosticCategory.Message, "Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_tr_6915", "Using --build, -b will make tsc behave more like a build orchestrator than a compiler. This is used to trigger building composite projects which you can learn more about at {0}"), COMMON_COMMANDS: t3(6916, e.DiagnosticCategory.Message, "COMMON_COMMANDS_6916", "COMMON COMMANDS"), ALL_COMPILER_OPTIONS: t3(6917, e.DiagnosticCategory.Message, "ALL_COMPILER_OPTIONS_6917", "ALL COMPILER OPTIONS"), WATCH_OPTIONS: t3(6918, e.DiagnosticCategory.Message, "WATCH_OPTIONS_6918", "WATCH OPTIONS"), BUILD_OPTIONS: t3(6919, e.DiagnosticCategory.Message, "BUILD_OPTIONS_6919", "BUILD OPTIONS"), COMMON_COMPILER_OPTIONS: t3(6920, e.DiagnosticCategory.Message, "COMMON_COMPILER_OPTIONS_6920", "COMMON COMPILER OPTIONS"), COMMAND_LINE_FLAGS: t3(6921, e.DiagnosticCategory.Message, "COMMAND_LINE_FLAGS_6921", "COMMAND LINE FLAGS"), tsc_Colon_The_TypeScript_Compiler: t3(6922, e.DiagnosticCategory.Message, "tsc_Colon_The_TypeScript_Compiler_6922", "tsc: The TypeScript Compiler"), Compiles_the_current_project_tsconfig_json_in_the_working_directory: t3(6923, e.DiagnosticCategory.Message, "Compiles_the_current_project_tsconfig_json_in_the_working_directory_6923", "Compiles the current project (tsconfig.json in the working directory.)"), Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options: t3(6924, e.DiagnosticCategory.Message, "Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options_6924", "Ignoring tsconfig.json, compiles the specified files with default compiler options."), Build_a_composite_project_in_the_working_directory: t3(6925, e.DiagnosticCategory.Message, "Build_a_composite_project_in_the_working_directory_6925", "Build a composite project in the working directory."), Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory: t3(6926, e.DiagnosticCategory.Message, "Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory_6926", "Creates a tsconfig.json with the recommended settings in the working directory."), Compiles_the_TypeScript_project_located_at_the_specified_path: t3(6927, e.DiagnosticCategory.Message, "Compiles_the_TypeScript_project_located_at_the_specified_path_6927", "Compiles the TypeScript project located at the specified path."), An_expanded_version_of_this_information_showing_all_possible_compiler_options: t3(6928, e.DiagnosticCategory.Message, "An_expanded_version_of_this_information_showing_all_possible_compiler_options_6928", "An expanded version of this information, showing all possible compiler options"), Compiles_the_current_project_with_additional_settings: t3(6929, e.DiagnosticCategory.Message, "Compiles_the_current_project_with_additional_settings_6929", "Compiles the current project, with additional settings."), true_for_ES2022_and_above_including_ESNext: t3(6930, e.DiagnosticCategory.Message, "true_for_ES2022_and_above_including_ESNext_6930", "`true` for ES2022 and above, including ESNext."), List_of_file_name_suffixes_to_search_when_resolving_a_module: t3(6931, e.DiagnosticCategory.Error, "List_of_file_name_suffixes_to_search_when_resolving_a_module_6931", "List of file name suffixes to search when resolving a module."), Variable_0_implicitly_has_an_1_type: t3(7005, e.DiagnosticCategory.Error, "Variable_0_implicitly_has_an_1_type_7005", "Variable '{0}' implicitly has an '{1}' type."), Parameter_0_implicitly_has_an_1_type: t3(7006, e.DiagnosticCategory.Error, "Parameter_0_implicitly_has_an_1_type_7006", "Parameter '{0}' implicitly has an '{1}' type."), Member_0_implicitly_has_an_1_type: t3(7008, e.DiagnosticCategory.Error, "Member_0_implicitly_has_an_1_type_7008", "Member '{0}' implicitly has an '{1}' type."), new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type: t3(7009, e.DiagnosticCategory.Error, "new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009", "'new' expression, whose target lacks a construct signature, implicitly has an 'any' type."), _0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type: t3(7010, e.DiagnosticCategory.Error, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010", "'{0}', which lacks return-type annotation, implicitly has an '{1}' return type."), Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: t3(7011, e.DiagnosticCategory.Error, "Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011", "Function expression, which lacks return-type annotation, implicitly has an '{0}' return type."), Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: t3(7013, e.DiagnosticCategory.Error, "Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013", "Construct signature, which lacks return-type annotation, implicitly has an 'any' return type."), Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: t3(7014, e.DiagnosticCategory.Error, "Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7014", "Function type, which lacks return-type annotation, implicitly has an '{0}' return type."), Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number: t3(7015, e.DiagnosticCategory.Error, "Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015", "Element implicitly has an 'any' type because index expression is not of type 'number'."), Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type: t3(7016, e.DiagnosticCategory.Error, "Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type_7016", "Could not find a declaration file for module '{0}'. '{1}' implicitly has an 'any' type."), Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature: t3(7017, e.DiagnosticCategory.Error, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_7017", "Element implicitly has an 'any' type because type '{0}' has no index signature."), Object_literal_s_property_0_implicitly_has_an_1_type: t3(7018, e.DiagnosticCategory.Error, "Object_literal_s_property_0_implicitly_has_an_1_type_7018", "Object literal's property '{0}' implicitly has an '{1}' type."), Rest_parameter_0_implicitly_has_an_any_type: t3(7019, e.DiagnosticCategory.Error, "Rest_parameter_0_implicitly_has_an_any_type_7019", "Rest parameter '{0}' implicitly has an 'any[]' type."), Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: t3(7020, e.DiagnosticCategory.Error, "Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020", "Call signature, which lacks return-type annotation, implicitly has an 'any' return type."), _0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer: t3(7022, e.DiagnosticCategory.Error, "_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022", "'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer."), _0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: t3(7023, e.DiagnosticCategory.Error, "_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023", "'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."), Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: t3(7024, e.DiagnosticCategory.Error, "Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024", "Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."), Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation: t3(7025, e.DiagnosticCategory.Error, "Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_retu_7025", "Generator implicitly has yield type '{0}' because it does not yield any values. Consider supplying a return type annotation."), JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists: t3(7026, e.DiagnosticCategory.Error, "JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026", "JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists."), Unreachable_code_detected: t3(7027, e.DiagnosticCategory.Error, "Unreachable_code_detected_7027", "Unreachable code detected.", true), Unused_label: t3(7028, e.DiagnosticCategory.Error, "Unused_label_7028", "Unused label.", true), Fallthrough_case_in_switch: t3(7029, e.DiagnosticCategory.Error, "Fallthrough_case_in_switch_7029", "Fallthrough case in switch."), Not_all_code_paths_return_a_value: t3(7030, e.DiagnosticCategory.Error, "Not_all_code_paths_return_a_value_7030", "Not all code paths return a value."), Binding_element_0_implicitly_has_an_1_type: t3(7031, e.DiagnosticCategory.Error, "Binding_element_0_implicitly_has_an_1_type_7031", "Binding element '{0}' implicitly has an '{1}' type."), Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation: t3(7032, e.DiagnosticCategory.Error, "Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation_7032", "Property '{0}' implicitly has type 'any', because its set accessor lacks a parameter type annotation."), Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation: t3(7033, e.DiagnosticCategory.Error, "Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation_7033", "Property '{0}' implicitly has type 'any', because its get accessor lacks a return type annotation."), Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined: t3(7034, e.DiagnosticCategory.Error, "Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined_7034", "Variable '{0}' implicitly has type '{1}' in some locations where its type cannot be determined."), Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0: t3(7035, e.DiagnosticCategory.Error, "Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare__7035", "Try `npm i --save-dev @types/{1}` if it exists or add a new declaration (.d.ts) file containing `declare module '{0}';`"), Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0: t3(7036, e.DiagnosticCategory.Error, "Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0_7036", "Dynamic import's specifier must be of type 'string', but here has type '{0}'."), Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports: t3(7037, e.DiagnosticCategory.Message, "Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for__7037", "Enables emit interoperability between CommonJS and ES Modules via creation of namespace objects for all imports. Implies 'allowSyntheticDefaultImports'."), Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead: t3(7038, e.DiagnosticCategory.Message, "Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cau_7038", "Type originates at this import. A namespace-style import cannot be called or constructed, and will cause a failure at runtime. Consider using a default import or import require here instead."), Mapped_object_type_implicitly_has_an_any_template_type: t3(7039, e.DiagnosticCategory.Error, "Mapped_object_type_implicitly_has_an_any_template_type_7039", "Mapped object type implicitly has an 'any' template type."), If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1: t3(7040, e.DiagnosticCategory.Error, "If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_S_7040", "If the '{0}' package actually exposes this module, consider sending a pull request to amend 'https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/{1}'"), The_containing_arrow_function_captures_the_global_value_of_this: t3(7041, e.DiagnosticCategory.Error, "The_containing_arrow_function_captures_the_global_value_of_this_7041", "The containing arrow function captures the global value of 'this'."), Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used: t3(7042, e.DiagnosticCategory.Error, "Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used_7042", "Module '{0}' was resolved to '{1}', but '--resolveJsonModule' is not used."), Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: t3(7043, e.DiagnosticCategory.Suggestion, "Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7043", "Variable '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."), Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: t3(7044, e.DiagnosticCategory.Suggestion, "Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7044", "Parameter '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."), Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: t3(7045, e.DiagnosticCategory.Suggestion, "Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7045", "Member '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."), Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage: t3(7046, e.DiagnosticCategory.Suggestion, "Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage_7046", "Variable '{0}' implicitly has type '{1}' in some locations, but a better type may be inferred from usage."), Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage: t3(7047, e.DiagnosticCategory.Suggestion, "Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage_7047", "Rest parameter '{0}' implicitly has an 'any[]' type, but a better type may be inferred from usage."), Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage: t3(7048, e.DiagnosticCategory.Suggestion, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage_7048", "Property '{0}' implicitly has type 'any', but a better type for its get accessor may be inferred from usage."), Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage: t3(7049, e.DiagnosticCategory.Suggestion, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage_7049", "Property '{0}' implicitly has type 'any', but a better type for its set accessor may be inferred from usage."), _0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage: t3(7050, e.DiagnosticCategory.Suggestion, "_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage_7050", "'{0}' implicitly has an '{1}' return type, but a better type may be inferred from usage."), Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1: t3(7051, e.DiagnosticCategory.Error, "Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1_7051", "Parameter has a name but no type. Did you mean '{0}: {1}'?"), Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1: t3(7052, e.DiagnosticCategory.Error, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1_7052", "Element implicitly has an 'any' type because type '{0}' has no index signature. Did you mean to call '{1}'?"), Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1: t3(7053, e.DiagnosticCategory.Error, "Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1_7053", "Element implicitly has an 'any' type because expression of type '{0}' can't be used to index type '{1}'."), No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1: t3(7054, e.DiagnosticCategory.Error, "No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1_7054", "No index signature with a parameter of type '{0}' was found on type '{1}'."), _0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type: t3(7055, e.DiagnosticCategory.Error, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type_7055", "'{0}', which lacks return-type annotation, implicitly has an '{1}' yield type."), The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed: t3(7056, e.DiagnosticCategory.Error, "The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_ty_7056", "The inferred type of this node exceeds the maximum length the compiler will serialize. An explicit type annotation is needed."), yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation: t3(7057, e.DiagnosticCategory.Error, "yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_t_7057", "'yield' expression implicitly results in an 'any' type because its containing generator lacks a return-type annotation."), If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1: t3(7058, e.DiagnosticCategory.Error, "If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_decl_7058", "If the '{0}' package actually exposes this module, try adding a new declaration (.d.ts) file containing `declare module '{1}';`"), This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead: t3(7059, e.DiagnosticCategory.Error, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead_7059", "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead."), This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint: t3(7060, e.DiagnosticCategory.Error, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_cons_7060", "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma or explicit constraint."), A_mapped_type_may_not_declare_properties_or_methods: t3(7061, e.DiagnosticCategory.Error, "A_mapped_type_may_not_declare_properties_or_methods_7061", "A mapped type may not declare properties or methods."), You_cannot_rename_this_element: t3(8e3, e.DiagnosticCategory.Error, "You_cannot_rename_this_element_8000", "You cannot rename this element."), You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library: t3(8001, e.DiagnosticCategory.Error, "You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001", "You cannot rename elements that are defined in the standard TypeScript library."), import_can_only_be_used_in_TypeScript_files: t3(8002, e.DiagnosticCategory.Error, "import_can_only_be_used_in_TypeScript_files_8002", "'import ... =' can only be used in TypeScript files."), export_can_only_be_used_in_TypeScript_files: t3(8003, e.DiagnosticCategory.Error, "export_can_only_be_used_in_TypeScript_files_8003", "'export =' can only be used in TypeScript files."), Type_parameter_declarations_can_only_be_used_in_TypeScript_files: t3(8004, e.DiagnosticCategory.Error, "Type_parameter_declarations_can_only_be_used_in_TypeScript_files_8004", "Type parameter declarations can only be used in TypeScript files."), implements_clauses_can_only_be_used_in_TypeScript_files: t3(8005, e.DiagnosticCategory.Error, "implements_clauses_can_only_be_used_in_TypeScript_files_8005", "'implements' clauses can only be used in TypeScript files."), _0_declarations_can_only_be_used_in_TypeScript_files: t3(8006, e.DiagnosticCategory.Error, "_0_declarations_can_only_be_used_in_TypeScript_files_8006", "'{0}' declarations can only be used in TypeScript files."), Type_aliases_can_only_be_used_in_TypeScript_files: t3(8008, e.DiagnosticCategory.Error, "Type_aliases_can_only_be_used_in_TypeScript_files_8008", "Type aliases can only be used in TypeScript files."), The_0_modifier_can_only_be_used_in_TypeScript_files: t3(8009, e.DiagnosticCategory.Error, "The_0_modifier_can_only_be_used_in_TypeScript_files_8009", "The '{0}' modifier can only be used in TypeScript files."), Type_annotations_can_only_be_used_in_TypeScript_files: t3(8010, e.DiagnosticCategory.Error, "Type_annotations_can_only_be_used_in_TypeScript_files_8010", "Type annotations can only be used in TypeScript files."), Type_arguments_can_only_be_used_in_TypeScript_files: t3(8011, e.DiagnosticCategory.Error, "Type_arguments_can_only_be_used_in_TypeScript_files_8011", "Type arguments can only be used in TypeScript files."), Parameter_modifiers_can_only_be_used_in_TypeScript_files: t3(8012, e.DiagnosticCategory.Error, "Parameter_modifiers_can_only_be_used_in_TypeScript_files_8012", "Parameter modifiers can only be used in TypeScript files."), Non_null_assertions_can_only_be_used_in_TypeScript_files: t3(8013, e.DiagnosticCategory.Error, "Non_null_assertions_can_only_be_used_in_TypeScript_files_8013", "Non-null assertions can only be used in TypeScript files."), Type_assertion_expressions_can_only_be_used_in_TypeScript_files: t3(8016, e.DiagnosticCategory.Error, "Type_assertion_expressions_can_only_be_used_in_TypeScript_files_8016", "Type assertion expressions can only be used in TypeScript files."), Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0: t3(8017, e.DiagnosticCategory.Error, "Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0_8017", "Octal literal types must use ES2015 syntax. Use the syntax '{0}'."), Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0: t3(8018, e.DiagnosticCategory.Error, "Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0_8018", "Octal literals are not allowed in enums members initializer. Use the syntax '{0}'."), Report_errors_in_js_files: t3(8019, e.DiagnosticCategory.Message, "Report_errors_in_js_files_8019", "Report errors in .js files."), JSDoc_types_can_only_be_used_inside_documentation_comments: t3(8020, e.DiagnosticCategory.Error, "JSDoc_types_can_only_be_used_inside_documentation_comments_8020", "JSDoc types can only be used inside documentation comments."), JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags: t3(8021, e.DiagnosticCategory.Error, "JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags_8021", "JSDoc '@typedef' tag should either have a type annotation or be followed by '@property' or '@member' tags."), JSDoc_0_is_not_attached_to_a_class: t3(8022, e.DiagnosticCategory.Error, "JSDoc_0_is_not_attached_to_a_class_8022", "JSDoc '@{0}' is not attached to a class."), JSDoc_0_1_does_not_match_the_extends_2_clause: t3(8023, e.DiagnosticCategory.Error, "JSDoc_0_1_does_not_match_the_extends_2_clause_8023", "JSDoc '@{0} {1}' does not match the 'extends {2}' clause."), JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name: t3(8024, e.DiagnosticCategory.Error, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_8024", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name."), Class_declarations_cannot_have_more_than_one_augments_or_extends_tag: t3(8025, e.DiagnosticCategory.Error, "Class_declarations_cannot_have_more_than_one_augments_or_extends_tag_8025", "Class declarations cannot have more than one '@augments' or '@extends' tag."), Expected_0_type_arguments_provide_these_with_an_extends_tag: t3(8026, e.DiagnosticCategory.Error, "Expected_0_type_arguments_provide_these_with_an_extends_tag_8026", "Expected {0} type arguments; provide these with an '@extends' tag."), Expected_0_1_type_arguments_provide_these_with_an_extends_tag: t3(8027, e.DiagnosticCategory.Error, "Expected_0_1_type_arguments_provide_these_with_an_extends_tag_8027", "Expected {0}-{1} type arguments; provide these with an '@extends' tag."), JSDoc_may_only_appear_in_the_last_parameter_of_a_signature: t3(8028, e.DiagnosticCategory.Error, "JSDoc_may_only_appear_in_the_last_parameter_of_a_signature_8028", "JSDoc '...' may only appear in the last parameter of a signature."), JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type: t3(8029, e.DiagnosticCategory.Error, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_h_8029", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name. It would match 'arguments' if it had an array type."), The_type_of_a_function_declaration_must_match_the_function_s_signature: t3(8030, e.DiagnosticCategory.Error, "The_type_of_a_function_declaration_must_match_the_function_s_signature_8030", "The type of a function declaration must match the function's signature."), You_cannot_rename_a_module_via_a_global_import: t3(8031, e.DiagnosticCategory.Error, "You_cannot_rename_a_module_via_a_global_import_8031", "You cannot rename a module via a global import."), Qualified_name_0_is_not_allowed_without_a_leading_param_object_1: t3(8032, e.DiagnosticCategory.Error, "Qualified_name_0_is_not_allowed_without_a_leading_param_object_1_8032", "Qualified name '{0}' is not allowed without a leading '@param {object} {1}'."), A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags: t3(8033, e.DiagnosticCategory.Error, "A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags_8033", "A JSDoc '@typedef' comment may not contain multiple '@type' tags."), The_tag_was_first_specified_here: t3(8034, e.DiagnosticCategory.Error, "The_tag_was_first_specified_here_8034", "The tag was first specified here."), You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder: t3(8035, e.DiagnosticCategory.Error, "You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder_8035", "You cannot rename elements that are defined in a 'node_modules' folder."), You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder: t3(8036, e.DiagnosticCategory.Error, "You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder_8036", "You cannot rename elements that are defined in another 'node_modules' folder."), Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files: t3(8037, e.DiagnosticCategory.Error, "Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files_8037", "Type satisfaction expressions can only be used in TypeScript files."), Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit: t3(9005, e.DiagnosticCategory.Error, "Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_9005", "Declaration emit for this file requires using private name '{0}'. An explicit type annotation may unblock declaration emit."), Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit: t3(9006, e.DiagnosticCategory.Error, "Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotati_9006", "Declaration emit for this file requires using private name '{0}' from module '{1}'. An explicit type annotation may unblock declaration emit."), JSX_attributes_must_only_be_assigned_a_non_empty_expression: t3(17e3, e.DiagnosticCategory.Error, "JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000", "JSX attributes must only be assigned a non-empty 'expression'."), JSX_elements_cannot_have_multiple_attributes_with_the_same_name: t3(17001, e.DiagnosticCategory.Error, "JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001", "JSX elements cannot have multiple attributes with the same name."), Expected_corresponding_JSX_closing_tag_for_0: t3(17002, e.DiagnosticCategory.Error, "Expected_corresponding_JSX_closing_tag_for_0_17002", "Expected corresponding JSX closing tag for '{0}'."), Cannot_use_JSX_unless_the_jsx_flag_is_provided: t3(17004, e.DiagnosticCategory.Error, "Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004", "Cannot use JSX unless the '--jsx' flag is provided."), A_constructor_cannot_contain_a_super_call_when_its_class_extends_null: t3(17005, e.DiagnosticCategory.Error, "A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005", "A constructor cannot contain a 'super' call when its class extends 'null'."), An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: t3(17006, e.DiagnosticCategory.Error, "An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006", "An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."), A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: t3(17007, e.DiagnosticCategory.Error, "A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007", "A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."), JSX_element_0_has_no_corresponding_closing_tag: t3(17008, e.DiagnosticCategory.Error, "JSX_element_0_has_no_corresponding_closing_tag_17008", "JSX element '{0}' has no corresponding closing tag."), super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class: t3(17009, e.DiagnosticCategory.Error, "super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009", "'super' must be called before accessing 'this' in the constructor of a derived class."), Unknown_type_acquisition_option_0: t3(17010, e.DiagnosticCategory.Error, "Unknown_type_acquisition_option_0_17010", "Unknown type acquisition option '{0}'."), super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class: t3(17011, e.DiagnosticCategory.Error, "super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class_17011", "'super' must be called before accessing a property of 'super' in the constructor of a derived class."), _0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2: t3(17012, e.DiagnosticCategory.Error, "_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2_17012", "'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"), Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor: t3(17013, e.DiagnosticCategory.Error, "Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constru_17013", "Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."), JSX_fragment_has_no_corresponding_closing_tag: t3(17014, e.DiagnosticCategory.Error, "JSX_fragment_has_no_corresponding_closing_tag_17014", "JSX fragment has no corresponding closing tag."), Expected_corresponding_closing_tag_for_JSX_fragment: t3(17015, e.DiagnosticCategory.Error, "Expected_corresponding_closing_tag_for_JSX_fragment_17015", "Expected corresponding closing tag for JSX fragment."), The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option: t3(17016, e.DiagnosticCategory.Error, "The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_com_17016", "The 'jsxFragmentFactory' compiler option must be provided to use JSX fragments with the 'jsxFactory' compiler option."), An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments: t3(17017, e.DiagnosticCategory.Error, "An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments_17017", "An @jsxFrag pragma is required when using an @jsx pragma with JSX fragments."), Unknown_type_acquisition_option_0_Did_you_mean_1: t3(17018, e.DiagnosticCategory.Error, "Unknown_type_acquisition_option_0_Did_you_mean_1_17018", "Unknown type acquisition option '{0}'. Did you mean '{1}'?"), Circularity_detected_while_resolving_configuration_Colon_0: t3(18e3, e.DiagnosticCategory.Error, "Circularity_detected_while_resolving_configuration_Colon_0_18000", "Circularity detected while resolving configuration: {0}"), The_files_list_in_config_file_0_is_empty: t3(18002, e.DiagnosticCategory.Error, "The_files_list_in_config_file_0_is_empty_18002", "The 'files' list in config file '{0}' is empty."), No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2: t3(18003, e.DiagnosticCategory.Error, "No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2_18003", "No inputs were found in config file '{0}'. Specified 'include' paths were '{1}' and 'exclude' paths were '{2}'."), File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module: t3(80001, e.DiagnosticCategory.Suggestion, "File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module_80001", "File is a CommonJS module; it may be converted to an ES module."), This_constructor_function_may_be_converted_to_a_class_declaration: t3(80002, e.DiagnosticCategory.Suggestion, "This_constructor_function_may_be_converted_to_a_class_declaration_80002", "This constructor function may be converted to a class declaration."), Import_may_be_converted_to_a_default_import: t3(80003, e.DiagnosticCategory.Suggestion, "Import_may_be_converted_to_a_default_import_80003", "Import may be converted to a default import."), JSDoc_types_may_be_moved_to_TypeScript_types: t3(80004, e.DiagnosticCategory.Suggestion, "JSDoc_types_may_be_moved_to_TypeScript_types_80004", "JSDoc types may be moved to TypeScript types."), require_call_may_be_converted_to_an_import: t3(80005, e.DiagnosticCategory.Suggestion, "require_call_may_be_converted_to_an_import_80005", "'require' call may be converted to an import."), This_may_be_converted_to_an_async_function: t3(80006, e.DiagnosticCategory.Suggestion, "This_may_be_converted_to_an_async_function_80006", "This may be converted to an async function."), await_has_no_effect_on_the_type_of_this_expression: t3(80007, e.DiagnosticCategory.Suggestion, "await_has_no_effect_on_the_type_of_this_expression_80007", "'await' has no effect on the type of this expression."), Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers: t3(80008, e.DiagnosticCategory.Suggestion, "Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accur_80008", "Numeric literals with absolute values equal to 2^53 or greater are too large to be represented accurately as integers."), Add_missing_super_call: t3(90001, e.DiagnosticCategory.Message, "Add_missing_super_call_90001", "Add missing 'super()' call"), Make_super_call_the_first_statement_in_the_constructor: t3(90002, e.DiagnosticCategory.Message, "Make_super_call_the_first_statement_in_the_constructor_90002", "Make 'super()' call the first statement in the constructor"), Change_extends_to_implements: t3(90003, e.DiagnosticCategory.Message, "Change_extends_to_implements_90003", "Change 'extends' to 'implements'"), Remove_unused_declaration_for_Colon_0: t3(90004, e.DiagnosticCategory.Message, "Remove_unused_declaration_for_Colon_0_90004", "Remove unused declaration for: '{0}'"), Remove_import_from_0: t3(90005, e.DiagnosticCategory.Message, "Remove_import_from_0_90005", "Remove import from '{0}'"), Implement_interface_0: t3(90006, e.DiagnosticCategory.Message, "Implement_interface_0_90006", "Implement interface '{0}'"), Implement_inherited_abstract_class: t3(90007, e.DiagnosticCategory.Message, "Implement_inherited_abstract_class_90007", "Implement inherited abstract class"), Add_0_to_unresolved_variable: t3(90008, e.DiagnosticCategory.Message, "Add_0_to_unresolved_variable_90008", "Add '{0}.' to unresolved variable"), Remove_variable_statement: t3(90010, e.DiagnosticCategory.Message, "Remove_variable_statement_90010", "Remove variable statement"), Remove_template_tag: t3(90011, e.DiagnosticCategory.Message, "Remove_template_tag_90011", "Remove template tag"), Remove_type_parameters: t3(90012, e.DiagnosticCategory.Message, "Remove_type_parameters_90012", "Remove type parameters"), Import_0_from_1: t3(90013, e.DiagnosticCategory.Message, "Import_0_from_1_90013", `Import '{0}' from "{1}"`), Change_0_to_1: t3(90014, e.DiagnosticCategory.Message, "Change_0_to_1_90014", "Change '{0}' to '{1}'"), Declare_property_0: t3(90016, e.DiagnosticCategory.Message, "Declare_property_0_90016", "Declare property '{0}'"), Add_index_signature_for_property_0: t3(90017, e.DiagnosticCategory.Message, "Add_index_signature_for_property_0_90017", "Add index signature for property '{0}'"), Disable_checking_for_this_file: t3(90018, e.DiagnosticCategory.Message, "Disable_checking_for_this_file_90018", "Disable checking for this file"), Ignore_this_error_message: t3(90019, e.DiagnosticCategory.Message, "Ignore_this_error_message_90019", "Ignore this error message"), Initialize_property_0_in_the_constructor: t3(90020, e.DiagnosticCategory.Message, "Initialize_property_0_in_the_constructor_90020", "Initialize property '{0}' in the constructor"), Initialize_static_property_0: t3(90021, e.DiagnosticCategory.Message, "Initialize_static_property_0_90021", "Initialize static property '{0}'"), Change_spelling_to_0: t3(90022, e.DiagnosticCategory.Message, "Change_spelling_to_0_90022", "Change spelling to '{0}'"), Declare_method_0: t3(90023, e.DiagnosticCategory.Message, "Declare_method_0_90023", "Declare method '{0}'"), Declare_static_method_0: t3(90024, e.DiagnosticCategory.Message, "Declare_static_method_0_90024", "Declare static method '{0}'"), Prefix_0_with_an_underscore: t3(90025, e.DiagnosticCategory.Message, "Prefix_0_with_an_underscore_90025", "Prefix '{0}' with an underscore"), Rewrite_as_the_indexed_access_type_0: t3(90026, e.DiagnosticCategory.Message, "Rewrite_as_the_indexed_access_type_0_90026", "Rewrite as the indexed access type '{0}'"), Declare_static_property_0: t3(90027, e.DiagnosticCategory.Message, "Declare_static_property_0_90027", "Declare static property '{0}'"), Call_decorator_expression: t3(90028, e.DiagnosticCategory.Message, "Call_decorator_expression_90028", "Call decorator expression"), Add_async_modifier_to_containing_function: t3(90029, e.DiagnosticCategory.Message, "Add_async_modifier_to_containing_function_90029", "Add async modifier to containing function"), Replace_infer_0_with_unknown: t3(90030, e.DiagnosticCategory.Message, "Replace_infer_0_with_unknown_90030", "Replace 'infer {0}' with 'unknown'"), Replace_all_unused_infer_with_unknown: t3(90031, e.DiagnosticCategory.Message, "Replace_all_unused_infer_with_unknown_90031", "Replace all unused 'infer' with 'unknown'"), Add_parameter_name: t3(90034, e.DiagnosticCategory.Message, "Add_parameter_name_90034", "Add parameter name"), Declare_private_property_0: t3(90035, e.DiagnosticCategory.Message, "Declare_private_property_0_90035", "Declare private property '{0}'"), Replace_0_with_Promise_1: t3(90036, e.DiagnosticCategory.Message, "Replace_0_with_Promise_1_90036", "Replace '{0}' with 'Promise<{1}>'"), Fix_all_incorrect_return_type_of_an_async_functions: t3(90037, e.DiagnosticCategory.Message, "Fix_all_incorrect_return_type_of_an_async_functions_90037", "Fix all incorrect return type of an async functions"), Declare_private_method_0: t3(90038, e.DiagnosticCategory.Message, "Declare_private_method_0_90038", "Declare private method '{0}'"), Remove_unused_destructuring_declaration: t3(90039, e.DiagnosticCategory.Message, "Remove_unused_destructuring_declaration_90039", "Remove unused destructuring declaration"), Remove_unused_declarations_for_Colon_0: t3(90041, e.DiagnosticCategory.Message, "Remove_unused_declarations_for_Colon_0_90041", "Remove unused declarations for: '{0}'"), Declare_a_private_field_named_0: t3(90053, e.DiagnosticCategory.Message, "Declare_a_private_field_named_0_90053", "Declare a private field named '{0}'."), Includes_imports_of_types_referenced_by_0: t3(90054, e.DiagnosticCategory.Message, "Includes_imports_of_types_referenced_by_0_90054", "Includes imports of types referenced by '{0}'"), Remove_type_from_import_declaration_from_0: t3(90055, e.DiagnosticCategory.Message, "Remove_type_from_import_declaration_from_0_90055", `Remove 'type' from import declaration from "{0}"`), Remove_type_from_import_of_0_from_1: t3(90056, e.DiagnosticCategory.Message, "Remove_type_from_import_of_0_from_1_90056", `Remove 'type' from import of '{0}' from "{1}"`), Add_import_from_0: t3(90057, e.DiagnosticCategory.Message, "Add_import_from_0_90057", 'Add import from "{0}"'), Update_import_from_0: t3(90058, e.DiagnosticCategory.Message, "Update_import_from_0_90058", 'Update import from "{0}"'), Export_0_from_module_1: t3(90059, e.DiagnosticCategory.Message, "Export_0_from_module_1_90059", "Export '{0}' from module '{1}'"), Export_all_referenced_locals: t3(90060, e.DiagnosticCategory.Message, "Export_all_referenced_locals_90060", "Export all referenced locals"), Convert_function_to_an_ES2015_class: t3(95001, e.DiagnosticCategory.Message, "Convert_function_to_an_ES2015_class_95001", "Convert function to an ES2015 class"), Convert_0_to_1_in_0: t3(95003, e.DiagnosticCategory.Message, "Convert_0_to_1_in_0_95003", "Convert '{0}' to '{1} in {0}'"), Extract_to_0_in_1: t3(95004, e.DiagnosticCategory.Message, "Extract_to_0_in_1_95004", "Extract to {0} in {1}"), Extract_function: t3(95005, e.DiagnosticCategory.Message, "Extract_function_95005", "Extract function"), Extract_constant: t3(95006, e.DiagnosticCategory.Message, "Extract_constant_95006", "Extract constant"), Extract_to_0_in_enclosing_scope: t3(95007, e.DiagnosticCategory.Message, "Extract_to_0_in_enclosing_scope_95007", "Extract to {0} in enclosing scope"), Extract_to_0_in_1_scope: t3(95008, e.DiagnosticCategory.Message, "Extract_to_0_in_1_scope_95008", "Extract to {0} in {1} scope"), Annotate_with_type_from_JSDoc: t3(95009, e.DiagnosticCategory.Message, "Annotate_with_type_from_JSDoc_95009", "Annotate with type from JSDoc"), Infer_type_of_0_from_usage: t3(95011, e.DiagnosticCategory.Message, "Infer_type_of_0_from_usage_95011", "Infer type of '{0}' from usage"), Infer_parameter_types_from_usage: t3(95012, e.DiagnosticCategory.Message, "Infer_parameter_types_from_usage_95012", "Infer parameter types from usage"), Convert_to_default_import: t3(95013, e.DiagnosticCategory.Message, "Convert_to_default_import_95013", "Convert to default import"), Install_0: t3(95014, e.DiagnosticCategory.Message, "Install_0_95014", "Install '{0}'"), Replace_import_with_0: t3(95015, e.DiagnosticCategory.Message, "Replace_import_with_0_95015", "Replace import with '{0}'."), Use_synthetic_default_member: t3(95016, e.DiagnosticCategory.Message, "Use_synthetic_default_member_95016", "Use synthetic 'default' member."), Convert_to_ES_module: t3(95017, e.DiagnosticCategory.Message, "Convert_to_ES_module_95017", "Convert to ES module"), Add_undefined_type_to_property_0: t3(95018, e.DiagnosticCategory.Message, "Add_undefined_type_to_property_0_95018", "Add 'undefined' type to property '{0}'"), Add_initializer_to_property_0: t3(95019, e.DiagnosticCategory.Message, "Add_initializer_to_property_0_95019", "Add initializer to property '{0}'"), Add_definite_assignment_assertion_to_property_0: t3(95020, e.DiagnosticCategory.Message, "Add_definite_assignment_assertion_to_property_0_95020", "Add definite assignment assertion to property '{0}'"), Convert_all_type_literals_to_mapped_type: t3(95021, e.DiagnosticCategory.Message, "Convert_all_type_literals_to_mapped_type_95021", "Convert all type literals to mapped type"), Add_all_missing_members: t3(95022, e.DiagnosticCategory.Message, "Add_all_missing_members_95022", "Add all missing members"), Infer_all_types_from_usage: t3(95023, e.DiagnosticCategory.Message, "Infer_all_types_from_usage_95023", "Infer all types from usage"), Delete_all_unused_declarations: t3(95024, e.DiagnosticCategory.Message, "Delete_all_unused_declarations_95024", "Delete all unused declarations"), Prefix_all_unused_declarations_with_where_possible: t3(95025, e.DiagnosticCategory.Message, "Prefix_all_unused_declarations_with_where_possible_95025", "Prefix all unused declarations with '_' where possible"), Fix_all_detected_spelling_errors: t3(95026, e.DiagnosticCategory.Message, "Fix_all_detected_spelling_errors_95026", "Fix all detected spelling errors"), Add_initializers_to_all_uninitialized_properties: t3(95027, e.DiagnosticCategory.Message, "Add_initializers_to_all_uninitialized_properties_95027", "Add initializers to all uninitialized properties"), Add_definite_assignment_assertions_to_all_uninitialized_properties: t3(95028, e.DiagnosticCategory.Message, "Add_definite_assignment_assertions_to_all_uninitialized_properties_95028", "Add definite assignment assertions to all uninitialized properties"), Add_undefined_type_to_all_uninitialized_properties: t3(95029, e.DiagnosticCategory.Message, "Add_undefined_type_to_all_uninitialized_properties_95029", "Add undefined type to all uninitialized properties"), Change_all_jsdoc_style_types_to_TypeScript: t3(95030, e.DiagnosticCategory.Message, "Change_all_jsdoc_style_types_to_TypeScript_95030", "Change all jsdoc-style types to TypeScript"), Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types: t3(95031, e.DiagnosticCategory.Message, "Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types_95031", "Change all jsdoc-style types to TypeScript (and add '| undefined' to nullable types)"), Implement_all_unimplemented_interfaces: t3(95032, e.DiagnosticCategory.Message, "Implement_all_unimplemented_interfaces_95032", "Implement all unimplemented interfaces"), Install_all_missing_types_packages: t3(95033, e.DiagnosticCategory.Message, "Install_all_missing_types_packages_95033", "Install all missing types packages"), Rewrite_all_as_indexed_access_types: t3(95034, e.DiagnosticCategory.Message, "Rewrite_all_as_indexed_access_types_95034", "Rewrite all as indexed access types"), Convert_all_to_default_imports: t3(95035, e.DiagnosticCategory.Message, "Convert_all_to_default_imports_95035", "Convert all to default imports"), Make_all_super_calls_the_first_statement_in_their_constructor: t3(95036, e.DiagnosticCategory.Message, "Make_all_super_calls_the_first_statement_in_their_constructor_95036", "Make all 'super()' calls the first statement in their constructor"), Add_qualifier_to_all_unresolved_variables_matching_a_member_name: t3(95037, e.DiagnosticCategory.Message, "Add_qualifier_to_all_unresolved_variables_matching_a_member_name_95037", "Add qualifier to all unresolved variables matching a member name"), Change_all_extended_interfaces_to_implements: t3(95038, e.DiagnosticCategory.Message, "Change_all_extended_interfaces_to_implements_95038", "Change all extended interfaces to 'implements'"), Add_all_missing_super_calls: t3(95039, e.DiagnosticCategory.Message, "Add_all_missing_super_calls_95039", "Add all missing super calls"), Implement_all_inherited_abstract_classes: t3(95040, e.DiagnosticCategory.Message, "Implement_all_inherited_abstract_classes_95040", "Implement all inherited abstract classes"), Add_all_missing_async_modifiers: t3(95041, e.DiagnosticCategory.Message, "Add_all_missing_async_modifiers_95041", "Add all missing 'async' modifiers"), Add_ts_ignore_to_all_error_messages: t3(95042, e.DiagnosticCategory.Message, "Add_ts_ignore_to_all_error_messages_95042", "Add '@ts-ignore' to all error messages"), Annotate_everything_with_types_from_JSDoc: t3(95043, e.DiagnosticCategory.Message, "Annotate_everything_with_types_from_JSDoc_95043", "Annotate everything with types from JSDoc"), Add_to_all_uncalled_decorators: t3(95044, e.DiagnosticCategory.Message, "Add_to_all_uncalled_decorators_95044", "Add '()' to all uncalled decorators"), Convert_all_constructor_functions_to_classes: t3(95045, e.DiagnosticCategory.Message, "Convert_all_constructor_functions_to_classes_95045", "Convert all constructor functions to classes"), Generate_get_and_set_accessors: t3(95046, e.DiagnosticCategory.Message, "Generate_get_and_set_accessors_95046", "Generate 'get' and 'set' accessors"), Convert_require_to_import: t3(95047, e.DiagnosticCategory.Message, "Convert_require_to_import_95047", "Convert 'require' to 'import'"), Convert_all_require_to_import: t3(95048, e.DiagnosticCategory.Message, "Convert_all_require_to_import_95048", "Convert all 'require' to 'import'"), Move_to_a_new_file: t3(95049, e.DiagnosticCategory.Message, "Move_to_a_new_file_95049", "Move to a new file"), Remove_unreachable_code: t3(95050, e.DiagnosticCategory.Message, "Remove_unreachable_code_95050", "Remove unreachable code"), Remove_all_unreachable_code: t3(95051, e.DiagnosticCategory.Message, "Remove_all_unreachable_code_95051", "Remove all unreachable code"), Add_missing_typeof: t3(95052, e.DiagnosticCategory.Message, "Add_missing_typeof_95052", "Add missing 'typeof'"), Remove_unused_label: t3(95053, e.DiagnosticCategory.Message, "Remove_unused_label_95053", "Remove unused label"), Remove_all_unused_labels: t3(95054, e.DiagnosticCategory.Message, "Remove_all_unused_labels_95054", "Remove all unused labels"), Convert_0_to_mapped_object_type: t3(95055, e.DiagnosticCategory.Message, "Convert_0_to_mapped_object_type_95055", "Convert '{0}' to mapped object type"), Convert_namespace_import_to_named_imports: t3(95056, e.DiagnosticCategory.Message, "Convert_namespace_import_to_named_imports_95056", "Convert namespace import to named imports"), Convert_named_imports_to_namespace_import: t3(95057, e.DiagnosticCategory.Message, "Convert_named_imports_to_namespace_import_95057", "Convert named imports to namespace import"), Add_or_remove_braces_in_an_arrow_function: t3(95058, e.DiagnosticCategory.Message, "Add_or_remove_braces_in_an_arrow_function_95058", "Add or remove braces in an arrow function"), Add_braces_to_arrow_function: t3(95059, e.DiagnosticCategory.Message, "Add_braces_to_arrow_function_95059", "Add braces to arrow function"), Remove_braces_from_arrow_function: t3(95060, e.DiagnosticCategory.Message, "Remove_braces_from_arrow_function_95060", "Remove braces from arrow function"), Convert_default_export_to_named_export: t3(95061, e.DiagnosticCategory.Message, "Convert_default_export_to_named_export_95061", "Convert default export to named export"), Convert_named_export_to_default_export: t3(95062, e.DiagnosticCategory.Message, "Convert_named_export_to_default_export_95062", "Convert named export to default export"), Add_missing_enum_member_0: t3(95063, e.DiagnosticCategory.Message, "Add_missing_enum_member_0_95063", "Add missing enum member '{0}'"), Add_all_missing_imports: t3(95064, e.DiagnosticCategory.Message, "Add_all_missing_imports_95064", "Add all missing imports"), Convert_to_async_function: t3(95065, e.DiagnosticCategory.Message, "Convert_to_async_function_95065", "Convert to async function"), Convert_all_to_async_functions: t3(95066, e.DiagnosticCategory.Message, "Convert_all_to_async_functions_95066", "Convert all to async functions"), Add_missing_call_parentheses: t3(95067, e.DiagnosticCategory.Message, "Add_missing_call_parentheses_95067", "Add missing call parentheses"), Add_all_missing_call_parentheses: t3(95068, e.DiagnosticCategory.Message, "Add_all_missing_call_parentheses_95068", "Add all missing call parentheses"), Add_unknown_conversion_for_non_overlapping_types: t3(95069, e.DiagnosticCategory.Message, "Add_unknown_conversion_for_non_overlapping_types_95069", "Add 'unknown' conversion for non-overlapping types"), Add_unknown_to_all_conversions_of_non_overlapping_types: t3(95070, e.DiagnosticCategory.Message, "Add_unknown_to_all_conversions_of_non_overlapping_types_95070", "Add 'unknown' to all conversions of non-overlapping types"), Add_missing_new_operator_to_call: t3(95071, e.DiagnosticCategory.Message, "Add_missing_new_operator_to_call_95071", "Add missing 'new' operator to call"), Add_missing_new_operator_to_all_calls: t3(95072, e.DiagnosticCategory.Message, "Add_missing_new_operator_to_all_calls_95072", "Add missing 'new' operator to all calls"), Add_names_to_all_parameters_without_names: t3(95073, e.DiagnosticCategory.Message, "Add_names_to_all_parameters_without_names_95073", "Add names to all parameters without names"), Enable_the_experimentalDecorators_option_in_your_configuration_file: t3(95074, e.DiagnosticCategory.Message, "Enable_the_experimentalDecorators_option_in_your_configuration_file_95074", "Enable the 'experimentalDecorators' option in your configuration file"), Convert_parameters_to_destructured_object: t3(95075, e.DiagnosticCategory.Message, "Convert_parameters_to_destructured_object_95075", "Convert parameters to destructured object"), Extract_type: t3(95077, e.DiagnosticCategory.Message, "Extract_type_95077", "Extract type"), Extract_to_type_alias: t3(95078, e.DiagnosticCategory.Message, "Extract_to_type_alias_95078", "Extract to type alias"), Extract_to_typedef: t3(95079, e.DiagnosticCategory.Message, "Extract_to_typedef_95079", "Extract to typedef"), Infer_this_type_of_0_from_usage: t3(95080, e.DiagnosticCategory.Message, "Infer_this_type_of_0_from_usage_95080", "Infer 'this' type of '{0}' from usage"), Add_const_to_unresolved_variable: t3(95081, e.DiagnosticCategory.Message, "Add_const_to_unresolved_variable_95081", "Add 'const' to unresolved variable"), Add_const_to_all_unresolved_variables: t3(95082, e.DiagnosticCategory.Message, "Add_const_to_all_unresolved_variables_95082", "Add 'const' to all unresolved variables"), Add_await: t3(95083, e.DiagnosticCategory.Message, "Add_await_95083", "Add 'await'"), Add_await_to_initializer_for_0: t3(95084, e.DiagnosticCategory.Message, "Add_await_to_initializer_for_0_95084", "Add 'await' to initializer for '{0}'"), Fix_all_expressions_possibly_missing_await: t3(95085, e.DiagnosticCategory.Message, "Fix_all_expressions_possibly_missing_await_95085", "Fix all expressions possibly missing 'await'"), Remove_unnecessary_await: t3(95086, e.DiagnosticCategory.Message, "Remove_unnecessary_await_95086", "Remove unnecessary 'await'"), Remove_all_unnecessary_uses_of_await: t3(95087, e.DiagnosticCategory.Message, "Remove_all_unnecessary_uses_of_await_95087", "Remove all unnecessary uses of 'await'"), Enable_the_jsx_flag_in_your_configuration_file: t3(95088, e.DiagnosticCategory.Message, "Enable_the_jsx_flag_in_your_configuration_file_95088", "Enable the '--jsx' flag in your configuration file"), Add_await_to_initializers: t3(95089, e.DiagnosticCategory.Message, "Add_await_to_initializers_95089", "Add 'await' to initializers"), Extract_to_interface: t3(95090, e.DiagnosticCategory.Message, "Extract_to_interface_95090", "Extract to interface"), Convert_to_a_bigint_numeric_literal: t3(95091, e.DiagnosticCategory.Message, "Convert_to_a_bigint_numeric_literal_95091", "Convert to a bigint numeric literal"), Convert_all_to_bigint_numeric_literals: t3(95092, e.DiagnosticCategory.Message, "Convert_all_to_bigint_numeric_literals_95092", "Convert all to bigint numeric literals"), Convert_const_to_let: t3(95093, e.DiagnosticCategory.Message, "Convert_const_to_let_95093", "Convert 'const' to 'let'"), Prefix_with_declare: t3(95094, e.DiagnosticCategory.Message, "Prefix_with_declare_95094", "Prefix with 'declare'"), Prefix_all_incorrect_property_declarations_with_declare: t3(95095, e.DiagnosticCategory.Message, "Prefix_all_incorrect_property_declarations_with_declare_95095", "Prefix all incorrect property declarations with 'declare'"), Convert_to_template_string: t3(95096, e.DiagnosticCategory.Message, "Convert_to_template_string_95096", "Convert to template string"), Add_export_to_make_this_file_into_a_module: t3(95097, e.DiagnosticCategory.Message, "Add_export_to_make_this_file_into_a_module_95097", "Add 'export {}' to make this file into a module"), Set_the_target_option_in_your_configuration_file_to_0: t3(95098, e.DiagnosticCategory.Message, "Set_the_target_option_in_your_configuration_file_to_0_95098", "Set the 'target' option in your configuration file to '{0}'"), Set_the_module_option_in_your_configuration_file_to_0: t3(95099, e.DiagnosticCategory.Message, "Set_the_module_option_in_your_configuration_file_to_0_95099", "Set the 'module' option in your configuration file to '{0}'"), Convert_invalid_character_to_its_html_entity_code: t3(95100, e.DiagnosticCategory.Message, "Convert_invalid_character_to_its_html_entity_code_95100", "Convert invalid character to its html entity code"), Convert_all_invalid_characters_to_HTML_entity_code: t3(95101, e.DiagnosticCategory.Message, "Convert_all_invalid_characters_to_HTML_entity_code_95101", "Convert all invalid characters to HTML entity code"), Convert_all_const_to_let: t3(95102, e.DiagnosticCategory.Message, "Convert_all_const_to_let_95102", "Convert all 'const' to 'let'"), Convert_function_expression_0_to_arrow_function: t3(95105, e.DiagnosticCategory.Message, "Convert_function_expression_0_to_arrow_function_95105", "Convert function expression '{0}' to arrow function"), Convert_function_declaration_0_to_arrow_function: t3(95106, e.DiagnosticCategory.Message, "Convert_function_declaration_0_to_arrow_function_95106", "Convert function declaration '{0}' to arrow function"), Fix_all_implicit_this_errors: t3(95107, e.DiagnosticCategory.Message, "Fix_all_implicit_this_errors_95107", "Fix all implicit-'this' errors"), Wrap_invalid_character_in_an_expression_container: t3(95108, e.DiagnosticCategory.Message, "Wrap_invalid_character_in_an_expression_container_95108", "Wrap invalid character in an expression container"), Wrap_all_invalid_characters_in_an_expression_container: t3(95109, e.DiagnosticCategory.Message, "Wrap_all_invalid_characters_in_an_expression_container_95109", "Wrap all invalid characters in an expression container"), Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file: t3(95110, e.DiagnosticCategory.Message, "Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file_95110", "Visit https://aka.ms/tsconfig to read more about this file"), Add_a_return_statement: t3(95111, e.DiagnosticCategory.Message, "Add_a_return_statement_95111", "Add a return statement"), Remove_braces_from_arrow_function_body: t3(95112, e.DiagnosticCategory.Message, "Remove_braces_from_arrow_function_body_95112", "Remove braces from arrow function body"), Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal: t3(95113, e.DiagnosticCategory.Message, "Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal_95113", "Wrap the following body with parentheses which should be an object literal"), Add_all_missing_return_statement: t3(95114, e.DiagnosticCategory.Message, "Add_all_missing_return_statement_95114", "Add all missing return statement"), Remove_braces_from_all_arrow_function_bodies_with_relevant_issues: t3(95115, e.DiagnosticCategory.Message, "Remove_braces_from_all_arrow_function_bodies_with_relevant_issues_95115", "Remove braces from all arrow function bodies with relevant issues"), Wrap_all_object_literal_with_parentheses: t3(95116, e.DiagnosticCategory.Message, "Wrap_all_object_literal_with_parentheses_95116", "Wrap all object literal with parentheses"), Move_labeled_tuple_element_modifiers_to_labels: t3(95117, e.DiagnosticCategory.Message, "Move_labeled_tuple_element_modifiers_to_labels_95117", "Move labeled tuple element modifiers to labels"), Convert_overload_list_to_single_signature: t3(95118, e.DiagnosticCategory.Message, "Convert_overload_list_to_single_signature_95118", "Convert overload list to single signature"), Generate_get_and_set_accessors_for_all_overriding_properties: t3(95119, e.DiagnosticCategory.Message, "Generate_get_and_set_accessors_for_all_overriding_properties_95119", "Generate 'get' and 'set' accessors for all overriding properties"), Wrap_in_JSX_fragment: t3(95120, e.DiagnosticCategory.Message, "Wrap_in_JSX_fragment_95120", "Wrap in JSX fragment"), Wrap_all_unparented_JSX_in_JSX_fragment: t3(95121, e.DiagnosticCategory.Message, "Wrap_all_unparented_JSX_in_JSX_fragment_95121", "Wrap all unparented JSX in JSX fragment"), Convert_arrow_function_or_function_expression: t3(95122, e.DiagnosticCategory.Message, "Convert_arrow_function_or_function_expression_95122", "Convert arrow function or function expression"), Convert_to_anonymous_function: t3(95123, e.DiagnosticCategory.Message, "Convert_to_anonymous_function_95123", "Convert to anonymous function"), Convert_to_named_function: t3(95124, e.DiagnosticCategory.Message, "Convert_to_named_function_95124", "Convert to named function"), Convert_to_arrow_function: t3(95125, e.DiagnosticCategory.Message, "Convert_to_arrow_function_95125", "Convert to arrow function"), Remove_parentheses: t3(95126, e.DiagnosticCategory.Message, "Remove_parentheses_95126", "Remove parentheses"), Could_not_find_a_containing_arrow_function: t3(95127, e.DiagnosticCategory.Message, "Could_not_find_a_containing_arrow_function_95127", "Could not find a containing arrow function"), Containing_function_is_not_an_arrow_function: t3(95128, e.DiagnosticCategory.Message, "Containing_function_is_not_an_arrow_function_95128", "Containing function is not an arrow function"), Could_not_find_export_statement: t3(95129, e.DiagnosticCategory.Message, "Could_not_find_export_statement_95129", "Could not find export statement"), This_file_already_has_a_default_export: t3(95130, e.DiagnosticCategory.Message, "This_file_already_has_a_default_export_95130", "This file already has a default export"), Could_not_find_import_clause: t3(95131, e.DiagnosticCategory.Message, "Could_not_find_import_clause_95131", "Could not find import clause"), Could_not_find_namespace_import_or_named_imports: t3(95132, e.DiagnosticCategory.Message, "Could_not_find_namespace_import_or_named_imports_95132", "Could not find namespace import or named imports"), Selection_is_not_a_valid_type_node: t3(95133, e.DiagnosticCategory.Message, "Selection_is_not_a_valid_type_node_95133", "Selection is not a valid type node"), No_type_could_be_extracted_from_this_type_node: t3(95134, e.DiagnosticCategory.Message, "No_type_could_be_extracted_from_this_type_node_95134", "No type could be extracted from this type node"), Could_not_find_property_for_which_to_generate_accessor: t3(95135, e.DiagnosticCategory.Message, "Could_not_find_property_for_which_to_generate_accessor_95135", "Could not find property for which to generate accessor"), Name_is_not_valid: t3(95136, e.DiagnosticCategory.Message, "Name_is_not_valid_95136", "Name is not valid"), Can_only_convert_property_with_modifier: t3(95137, e.DiagnosticCategory.Message, "Can_only_convert_property_with_modifier_95137", "Can only convert property with modifier"), Switch_each_misused_0_to_1: t3(95138, e.DiagnosticCategory.Message, "Switch_each_misused_0_to_1_95138", "Switch each misused '{0}' to '{1}'"), Convert_to_optional_chain_expression: t3(95139, e.DiagnosticCategory.Message, "Convert_to_optional_chain_expression_95139", "Convert to optional chain expression"), Could_not_find_convertible_access_expression: t3(95140, e.DiagnosticCategory.Message, "Could_not_find_convertible_access_expression_95140", "Could not find convertible access expression"), Could_not_find_matching_access_expressions: t3(95141, e.DiagnosticCategory.Message, "Could_not_find_matching_access_expressions_95141", "Could not find matching access expressions"), Can_only_convert_logical_AND_access_chains: t3(95142, e.DiagnosticCategory.Message, "Can_only_convert_logical_AND_access_chains_95142", "Can only convert logical AND access chains"), Add_void_to_Promise_resolved_without_a_value: t3(95143, e.DiagnosticCategory.Message, "Add_void_to_Promise_resolved_without_a_value_95143", "Add 'void' to Promise resolved without a value"), Add_void_to_all_Promises_resolved_without_a_value: t3(95144, e.DiagnosticCategory.Message, "Add_void_to_all_Promises_resolved_without_a_value_95144", "Add 'void' to all Promises resolved without a value"), Use_element_access_for_0: t3(95145, e.DiagnosticCategory.Message, "Use_element_access_for_0_95145", "Use element access for '{0}'"), Use_element_access_for_all_undeclared_properties: t3(95146, e.DiagnosticCategory.Message, "Use_element_access_for_all_undeclared_properties_95146", "Use element access for all undeclared properties."), Delete_all_unused_imports: t3(95147, e.DiagnosticCategory.Message, "Delete_all_unused_imports_95147", "Delete all unused imports"), Infer_function_return_type: t3(95148, e.DiagnosticCategory.Message, "Infer_function_return_type_95148", "Infer function return type"), Return_type_must_be_inferred_from_a_function: t3(95149, e.DiagnosticCategory.Message, "Return_type_must_be_inferred_from_a_function_95149", "Return type must be inferred from a function"), Could_not_determine_function_return_type: t3(95150, e.DiagnosticCategory.Message, "Could_not_determine_function_return_type_95150", "Could not determine function return type"), Could_not_convert_to_arrow_function: t3(95151, e.DiagnosticCategory.Message, "Could_not_convert_to_arrow_function_95151", "Could not convert to arrow function"), Could_not_convert_to_named_function: t3(95152, e.DiagnosticCategory.Message, "Could_not_convert_to_named_function_95152", "Could not convert to named function"), Could_not_convert_to_anonymous_function: t3(95153, e.DiagnosticCategory.Message, "Could_not_convert_to_anonymous_function_95153", "Could not convert to anonymous function"), Can_only_convert_string_concatenation: t3(95154, e.DiagnosticCategory.Message, "Can_only_convert_string_concatenation_95154", "Can only convert string concatenation"), Selection_is_not_a_valid_statement_or_statements: t3(95155, e.DiagnosticCategory.Message, "Selection_is_not_a_valid_statement_or_statements_95155", "Selection is not a valid statement or statements"), Add_missing_function_declaration_0: t3(95156, e.DiagnosticCategory.Message, "Add_missing_function_declaration_0_95156", "Add missing function declaration '{0}'"), Add_all_missing_function_declarations: t3(95157, e.DiagnosticCategory.Message, "Add_all_missing_function_declarations_95157", "Add all missing function declarations"), Method_not_implemented: t3(95158, e.DiagnosticCategory.Message, "Method_not_implemented_95158", "Method not implemented."), Function_not_implemented: t3(95159, e.DiagnosticCategory.Message, "Function_not_implemented_95159", "Function not implemented."), Add_override_modifier: t3(95160, e.DiagnosticCategory.Message, "Add_override_modifier_95160", "Add 'override' modifier"), Remove_override_modifier: t3(95161, e.DiagnosticCategory.Message, "Remove_override_modifier_95161", "Remove 'override' modifier"), Add_all_missing_override_modifiers: t3(95162, e.DiagnosticCategory.Message, "Add_all_missing_override_modifiers_95162", "Add all missing 'override' modifiers"), Remove_all_unnecessary_override_modifiers: t3(95163, e.DiagnosticCategory.Message, "Remove_all_unnecessary_override_modifiers_95163", "Remove all unnecessary 'override' modifiers"), Can_only_convert_named_export: t3(95164, e.DiagnosticCategory.Message, "Can_only_convert_named_export_95164", "Can only convert named export"), Add_missing_properties: t3(95165, e.DiagnosticCategory.Message, "Add_missing_properties_95165", "Add missing properties"), Add_all_missing_properties: t3(95166, e.DiagnosticCategory.Message, "Add_all_missing_properties_95166", "Add all missing properties"), Add_missing_attributes: t3(95167, e.DiagnosticCategory.Message, "Add_missing_attributes_95167", "Add missing attributes"), Add_all_missing_attributes: t3(95168, e.DiagnosticCategory.Message, "Add_all_missing_attributes_95168", "Add all missing attributes"), Add_undefined_to_optional_property_type: t3(95169, e.DiagnosticCategory.Message, "Add_undefined_to_optional_property_type_95169", "Add 'undefined' to optional property type"), Convert_named_imports_to_default_import: t3(95170, e.DiagnosticCategory.Message, "Convert_named_imports_to_default_import_95170", "Convert named imports to default import"), Delete_unused_param_tag_0: t3(95171, e.DiagnosticCategory.Message, "Delete_unused_param_tag_0_95171", "Delete unused '@param' tag '{0}'"), Delete_all_unused_param_tags: t3(95172, e.DiagnosticCategory.Message, "Delete_all_unused_param_tags_95172", "Delete all unused '@param' tags"), Rename_param_tag_name_0_to_1: t3(95173, e.DiagnosticCategory.Message, "Rename_param_tag_name_0_to_1_95173", "Rename '@param' tag name '{0}' to '{1}'"), Use_0: t3(95174, e.DiagnosticCategory.Message, "Use_0_95174", "Use `{0}`."), Use_Number_isNaN_in_all_conditions: t3(95175, e.DiagnosticCategory.Message, "Use_Number_isNaN_in_all_conditions_95175", "Use `Number.isNaN` in all conditions."), No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer: t3(18004, e.DiagnosticCategory.Error, "No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer_18004", "No value exists in scope for the shorthand property '{0}'. Either declare one or provide an initializer."), Classes_may_not_have_a_field_named_constructor: t3(18006, e.DiagnosticCategory.Error, "Classes_may_not_have_a_field_named_constructor_18006", "Classes may not have a field named 'constructor'."), JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array: t3(18007, e.DiagnosticCategory.Error, "JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array_18007", "JSX expressions may not use the comma operator. Did you mean to write an array?"), Private_identifiers_cannot_be_used_as_parameters: t3(18009, e.DiagnosticCategory.Error, "Private_identifiers_cannot_be_used_as_parameters_18009", "Private identifiers cannot be used as parameters."), An_accessibility_modifier_cannot_be_used_with_a_private_identifier: t3(18010, e.DiagnosticCategory.Error, "An_accessibility_modifier_cannot_be_used_with_a_private_identifier_18010", "An accessibility modifier cannot be used with a private identifier."), The_operand_of_a_delete_operator_cannot_be_a_private_identifier: t3(18011, e.DiagnosticCategory.Error, "The_operand_of_a_delete_operator_cannot_be_a_private_identifier_18011", "The operand of a 'delete' operator cannot be a private identifier."), constructor_is_a_reserved_word: t3(18012, e.DiagnosticCategory.Error, "constructor_is_a_reserved_word_18012", "'#constructor' is a reserved word."), Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier: t3(18013, e.DiagnosticCategory.Error, "Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier_18013", "Property '{0}' is not accessible outside class '{1}' because it has a private identifier."), The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling: t3(18014, e.DiagnosticCategory.Error, "The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_priv_18014", "The property '{0}' cannot be accessed on type '{1}' within this class because it is shadowed by another private identifier with the same spelling."), Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2: t3(18015, e.DiagnosticCategory.Error, "Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2_18015", "Property '{0}' in type '{1}' refers to a different member that cannot be accessed from within type '{2}'."), Private_identifiers_are_not_allowed_outside_class_bodies: t3(18016, e.DiagnosticCategory.Error, "Private_identifiers_are_not_allowed_outside_class_bodies_18016", "Private identifiers are not allowed outside class bodies."), The_shadowing_declaration_of_0_is_defined_here: t3(18017, e.DiagnosticCategory.Error, "The_shadowing_declaration_of_0_is_defined_here_18017", "The shadowing declaration of '{0}' is defined here"), The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here: t3(18018, e.DiagnosticCategory.Error, "The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here_18018", "The declaration of '{0}' that you probably intended to use is defined here"), _0_modifier_cannot_be_used_with_a_private_identifier: t3(18019, e.DiagnosticCategory.Error, "_0_modifier_cannot_be_used_with_a_private_identifier_18019", "'{0}' modifier cannot be used with a private identifier."), An_enum_member_cannot_be_named_with_a_private_identifier: t3(18024, e.DiagnosticCategory.Error, "An_enum_member_cannot_be_named_with_a_private_identifier_18024", "An enum member cannot be named with a private identifier."), can_only_be_used_at_the_start_of_a_file: t3(18026, e.DiagnosticCategory.Error, "can_only_be_used_at_the_start_of_a_file_18026", "'#!' can only be used at the start of a file."), Compiler_reserves_name_0_when_emitting_private_identifier_downlevel: t3(18027, e.DiagnosticCategory.Error, "Compiler_reserves_name_0_when_emitting_private_identifier_downlevel_18027", "Compiler reserves name '{0}' when emitting private identifier downlevel."), Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher: t3(18028, e.DiagnosticCategory.Error, "Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher_18028", "Private identifiers are only available when targeting ECMAScript 2015 and higher."), Private_identifiers_are_not_allowed_in_variable_declarations: t3(18029, e.DiagnosticCategory.Error, "Private_identifiers_are_not_allowed_in_variable_declarations_18029", "Private identifiers are not allowed in variable declarations."), An_optional_chain_cannot_contain_private_identifiers: t3(18030, e.DiagnosticCategory.Error, "An_optional_chain_cannot_contain_private_identifiers_18030", "An optional chain cannot contain private identifiers."), The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents: t3(18031, e.DiagnosticCategory.Error, "The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituent_18031", "The intersection '{0}' was reduced to 'never' because property '{1}' has conflicting types in some constituents."), The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some: t3(18032, e.DiagnosticCategory.Error, "The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_pr_18032", "The intersection '{0}' was reduced to 'never' because property '{1}' exists in multiple constituents and is private in some."), Only_numeric_enums_can_have_computed_members_but_this_expression_has_type_0_If_you_do_not_need_exhaustiveness_checks_consider_using_an_object_literal_instead: t3(18033, e.DiagnosticCategory.Error, "Only_numeric_enums_can_have_computed_members_but_this_expression_has_type_0_If_you_do_not_need_exhau_18033", "Only numeric enums can have computed members, but this expression has type '{0}'. If you do not need exhaustiveness checks, consider using an object literal instead."), Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment: t3(18034, e.DiagnosticCategory.Message, "Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compi_18034", "Specify the JSX fragment factory function to use when targeting 'react' JSX emit with 'jsxFactory' compiler option is specified, e.g. 'Fragment'."), Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name: t3(18035, e.DiagnosticCategory.Error, "Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name_18035", "Invalid value for 'jsxFragmentFactory'. '{0}' is not a valid identifier or qualified-name."), Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator: t3(18036, e.DiagnosticCategory.Error, "Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_dec_18036", "Class decorators can't be used with static private identifier. Consider removing the experimental decorator."), Await_expression_cannot_be_used_inside_a_class_static_block: t3(18037, e.DiagnosticCategory.Error, "Await_expression_cannot_be_used_inside_a_class_static_block_18037", "Await expression cannot be used inside a class static block."), For_await_loops_cannot_be_used_inside_a_class_static_block: t3(18038, e.DiagnosticCategory.Error, "For_await_loops_cannot_be_used_inside_a_class_static_block_18038", "'For await' loops cannot be used inside a class static block."), Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block: t3(18039, e.DiagnosticCategory.Error, "Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block_18039", "Invalid use of '{0}'. It cannot be used inside a class static block."), A_return_statement_cannot_be_used_inside_a_class_static_block: t3(18041, e.DiagnosticCategory.Error, "A_return_statement_cannot_be_used_inside_a_class_static_block_18041", "A 'return' statement cannot be used inside a class static block."), _0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation: t3(18042, e.DiagnosticCategory.Error, "_0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation_18042", "'{0}' is a type and cannot be imported in JavaScript files. Use '{1}' in a JSDoc type annotation."), Types_cannot_appear_in_export_declarations_in_JavaScript_files: t3(18043, e.DiagnosticCategory.Error, "Types_cannot_appear_in_export_declarations_in_JavaScript_files_18043", "Types cannot appear in export declarations in JavaScript files."), _0_is_automatically_exported_here: t3(18044, e.DiagnosticCategory.Message, "_0_is_automatically_exported_here_18044", "'{0}' is automatically exported here."), Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher: t3(18045, e.DiagnosticCategory.Error, "Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher_18045", "Properties with the 'accessor' modifier are only available when targeting ECMAScript 2015 and higher."), _0_is_of_type_unknown: t3(18046, e.DiagnosticCategory.Error, "_0_is_of_type_unknown_18046", "'{0}' is of type 'unknown'."), _0_is_possibly_null: t3(18047, e.DiagnosticCategory.Error, "_0_is_possibly_null_18047", "'{0}' is possibly 'null'."), _0_is_possibly_undefined: t3(18048, e.DiagnosticCategory.Error, "_0_is_possibly_undefined_18048", "'{0}' is possibly 'undefined'."), _0_is_possibly_null_or_undefined: t3(18049, e.DiagnosticCategory.Error, "_0_is_possibly_null_or_undefined_18049", "'{0}' is possibly 'null' or 'undefined'."), The_value_0_cannot_be_used_here: t3(18050, e.DiagnosticCategory.Error, "The_value_0_cannot_be_used_here_18050", "The value '{0}' cannot be used here.") };
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            function w(f) {
              return f >= 79;
            }
            e.tokenIsIdentifierOrKeyword = w;
            function s(f) {
              return f === 31 || w(f);
            }
            e.tokenIsIdentifierOrKeywordOrGreaterThan = s, e.textToKeywordObj = (t3 = { abstract: 126, accessor: 127, any: 131, as: 128, asserts: 129, assert: 130, bigint: 160, boolean: 134, break: 81, case: 82, catch: 83, class: 84, continue: 86, const: 85 }, t3.constructor = 135, t3.debugger = 87, t3.declare = 136, t3.default = 88, t3.delete = 89, t3.do = 90, t3.else = 91, t3.enum = 92, t3.export = 93, t3.extends = 94, t3.false = 95, t3.finally = 96, t3.for = 97, t3.from = 158, t3.function = 98, t3.get = 137, t3.if = 99, t3.implements = 117, t3.import = 100, t3.in = 101, t3.infer = 138, t3.instanceof = 102, t3.interface = 118, t3.intrinsic = 139, t3.is = 140, t3.keyof = 141, t3.let = 119, t3.module = 142, t3.namespace = 143, t3.never = 144, t3.new = 103, t3.null = 104, t3.number = 148, t3.object = 149, t3.package = 120, t3.private = 121, t3.protected = 122, t3.public = 123, t3.override = 161, t3.out = 145, t3.readonly = 146, t3.require = 147, t3.global = 159, t3.return = 105, t3.satisfies = 150, t3.set = 151, t3.static = 124, t3.string = 152, t3.super = 106, t3.switch = 107, t3.symbol = 153, t3.this = 108, t3.throw = 109, t3.true = 110, t3.try = 111, t3.type = 154, t3.typeof = 112, t3.undefined = 155, t3.unique = 156, t3.unknown = 157, t3.var = 113, t3.void = 114, t3.while = 115, t3.with = 116, t3.yield = 125, t3.async = 132, t3.await = 133, t3.of = 162, t3);
            var q = new e.Map(e.getEntries(e.textToKeywordObj)), F = new e.Map(e.getEntries(T(T({}, e.textToKeywordObj), { "{": 18, "}": 19, "(": 20, ")": 21, "[": 22, "]": 23, ".": 24, "...": 25, ";": 26, ",": 27, "<": 29, ">": 31, "<=": 32, ">=": 33, "==": 34, "!=": 35, "===": 36, "!==": 37, "=>": 38, "+": 39, "-": 40, "**": 42, "*": 41, "/": 43, "%": 44, "++": 45, "--": 46, "<<": 47, "</": 30, ">>": 48, ">>>": 49, "&": 50, "|": 51, "^": 52, "!": 53, "~": 54, "&&": 55, "||": 56, "?": 57, "??": 60, "?.": 28, ":": 58, "=": 63, "+=": 64, "-=": 65, "*=": 66, "**=": 67, "/=": 68, "%=": 69, "<<=": 70, ">>=": 71, ">>>=": 72, "&=": 73, "|=": 74, "^=": 78, "||=": 75, "&&=": 76, "??=": 77, "@": 59, "#": 62, "`": 61 }))), fe = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1610, 1649, 1747, 1749, 1749, 1765, 1766, 1786, 1788, 1808, 1808, 1810, 1836, 1920, 1957, 2309, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2784, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3294, 3294, 3296, 3297, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3424, 3425, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3805, 3840, 3840, 3904, 3911, 3913, 3946, 3976, 3979, 4096, 4129, 4131, 4135, 4137, 4138, 4176, 4181, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6067, 6176, 6263, 6272, 6312, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8319, 8319, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12346, 12353, 12436, 12445, 12446, 12449, 12538, 12540, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65138, 65140, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500], Ee = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 768, 846, 864, 866, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1155, 1158, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1441, 1443, 1465, 1467, 1469, 1471, 1471, 1473, 1474, 1476, 1476, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1621, 1632, 1641, 1648, 1747, 1749, 1756, 1759, 1768, 1770, 1773, 1776, 1788, 1808, 1836, 1840, 1866, 1920, 1968, 2305, 2307, 2309, 2361, 2364, 2381, 2384, 2388, 2392, 2403, 2406, 2415, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2492, 2494, 2500, 2503, 2504, 2507, 2509, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2562, 2562, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2649, 2652, 2654, 2654, 2662, 2676, 2689, 2691, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2784, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2876, 2883, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2913, 2918, 2927, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3031, 3031, 3047, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3134, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3168, 3169, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3262, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3297, 3302, 3311, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3390, 3395, 3398, 3400, 3402, 3405, 3415, 3415, 3424, 3425, 3430, 3439, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3805, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3946, 3953, 3972, 3974, 3979, 3984, 3991, 3993, 4028, 4038, 4038, 4096, 4129, 4131, 4135, 4137, 4138, 4140, 4146, 4150, 4153, 4160, 4169, 4176, 4185, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 4969, 4977, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6099, 6112, 6121, 6160, 6169, 6176, 6263, 6272, 6313, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8319, 8319, 8400, 8412, 8417, 8417, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12346, 12353, 12436, 12441, 12442, 12445, 12446, 12449, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65056, 65059, 65075, 65076, 65101, 65103, 65136, 65138, 65140, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65381, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500], Se = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2208, 2208, 2210, 2220, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2423, 2425, 2431, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3133, 3160, 3161, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3424, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6263, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6428, 6480, 6509, 6512, 6516, 6528, 6571, 6593, 6599, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7401, 7404, 7406, 7409, 7413, 7414, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11823, 11823, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42647, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43648, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500], J = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1520, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2048, 2093, 2112, 2139, 2208, 2208, 2210, 2220, 2276, 2302, 2304, 2403, 2406, 2415, 2417, 2423, 2425, 2431, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3161, 3168, 3171, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3396, 3398, 3400, 3402, 3406, 3415, 3415, 3424, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6263, 6272, 6314, 6320, 6389, 6400, 6428, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6617, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7376, 7378, 7380, 7414, 7424, 7654, 7676, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8204, 8205, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 11823, 11823, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12442, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42647, 42655, 42737, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43047, 43072, 43123, 43136, 43204, 43216, 43225, 43232, 43255, 43259, 43259, 43264, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43643, 43648, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65062, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500], se = [65, 90, 97, 122, 170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 895, 895, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1488, 1514, 1519, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2144, 2154, 2208, 2228, 2230, 2237, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2432, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2556, 2556, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2809, 2809, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3133, 3160, 3162, 3168, 3169, 3200, 3200, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3412, 3414, 3423, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6264, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6430, 6480, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7401, 7404, 7406, 7411, 7413, 7414, 7418, 7418, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12443, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42653, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43261, 43262, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43488, 43492, 43494, 43503, 43514, 43518, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43646, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66176, 66204, 66208, 66256, 66304, 66335, 66349, 66378, 66384, 66421, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68096, 68112, 68115, 68117, 68119, 68121, 68149, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68324, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68899, 69376, 69404, 69415, 69415, 69424, 69445, 69600, 69622, 69635, 69687, 69763, 69807, 69840, 69864, 69891, 69926, 69956, 69956, 69968, 70002, 70006, 70006, 70019, 70066, 70081, 70084, 70106, 70106, 70108, 70108, 70144, 70161, 70163, 70187, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70366, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70461, 70461, 70480, 70480, 70493, 70497, 70656, 70708, 70727, 70730, 70751, 70751, 70784, 70831, 70852, 70853, 70855, 70855, 71040, 71086, 71128, 71131, 71168, 71215, 71236, 71236, 71296, 71338, 71352, 71352, 71424, 71450, 71680, 71723, 71840, 71903, 71935, 71935, 72096, 72103, 72106, 72144, 72161, 72161, 72163, 72163, 72192, 72192, 72203, 72242, 72250, 72250, 72272, 72272, 72284, 72329, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72750, 72768, 72768, 72818, 72847, 72960, 72966, 72968, 72969, 72971, 73008, 73030, 73030, 73056, 73061, 73063, 73064, 73066, 73097, 73112, 73112, 73440, 73458, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92880, 92909, 92928, 92975, 92992, 92995, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94032, 94032, 94099, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 123136, 123180, 123191, 123197, 123214, 123214, 123584, 123627, 124928, 125124, 125184, 125251, 125259, 125259, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101], Me = [48, 57, 65, 90, 95, 95, 97, 122, 170, 170, 181, 181, 183, 183, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 895, 895, 902, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1519, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2045, 2045, 2048, 2093, 2112, 2139, 2144, 2154, 2208, 2228, 2230, 2237, 2259, 2273, 2275, 2403, 2406, 2415, 2417, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2556, 2556, 2558, 2558, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2809, 2815, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3072, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3162, 3168, 3171, 3174, 3183, 3200, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3328, 3331, 3333, 3340, 3342, 3344, 3346, 3396, 3398, 3400, 3402, 3406, 3412, 3415, 3423, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3558, 3567, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4969, 4977, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6264, 6272, 6314, 6320, 6389, 6400, 6430, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6618, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6832, 6845, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7376, 7378, 7380, 7418, 7424, 7673, 7675, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42737, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43047, 43072, 43123, 43136, 43205, 43216, 43225, 43232, 43255, 43259, 43259, 43261, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43488, 43518, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65071, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66045, 66045, 66176, 66204, 66208, 66256, 66272, 66272, 66304, 66335, 66349, 66378, 66384, 66426, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66720, 66729, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68099, 68101, 68102, 68108, 68115, 68117, 68119, 68121, 68149, 68152, 68154, 68159, 68159, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68326, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68903, 68912, 68921, 69376, 69404, 69415, 69415, 69424, 69456, 69600, 69622, 69632, 69702, 69734, 69743, 69759, 69818, 69840, 69864, 69872, 69881, 69888, 69940, 69942, 69951, 69956, 69958, 69968, 70003, 70006, 70006, 70016, 70084, 70089, 70092, 70096, 70106, 70108, 70108, 70144, 70161, 70163, 70199, 70206, 70206, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70378, 70384, 70393, 70400, 70403, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70459, 70468, 70471, 70472, 70475, 70477, 70480, 70480, 70487, 70487, 70493, 70499, 70502, 70508, 70512, 70516, 70656, 70730, 70736, 70745, 70750, 70751, 70784, 70853, 70855, 70855, 70864, 70873, 71040, 71093, 71096, 71104, 71128, 71133, 71168, 71232, 71236, 71236, 71248, 71257, 71296, 71352, 71360, 71369, 71424, 71450, 71453, 71467, 71472, 71481, 71680, 71738, 71840, 71913, 71935, 71935, 72096, 72103, 72106, 72151, 72154, 72161, 72163, 72164, 72192, 72254, 72263, 72263, 72272, 72345, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72758, 72760, 72768, 72784, 72793, 72818, 72847, 72850, 72871, 72873, 72886, 72960, 72966, 72968, 72969, 72971, 73014, 73018, 73018, 73020, 73021, 73023, 73031, 73040, 73049, 73056, 73061, 73063, 73064, 73066, 73102, 73104, 73105, 73107, 73112, 73120, 73129, 73440, 73462, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92768, 92777, 92880, 92909, 92912, 92916, 92928, 92982, 92992, 92995, 93008, 93017, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94031, 94087, 94095, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 113821, 113822, 119141, 119145, 119149, 119154, 119163, 119170, 119173, 119179, 119210, 119213, 119362, 119364, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 120782, 120831, 121344, 121398, 121403, 121452, 121461, 121461, 121476, 121476, 121499, 121503, 121505, 121519, 122880, 122886, 122888, 122904, 122907, 122913, 122915, 122916, 122918, 122922, 123136, 123180, 123184, 123197, 123200, 123209, 123214, 123214, 123584, 123641, 124928, 125124, 125136, 125142, 125184, 125259, 125264, 125273, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101, 917760, 917999], Q = /^\/\/\/?\s*@(ts-expect-error|ts-ignore)/, Be = /^(?:\/|\*)*\s*@(ts-expect-error|ts-ignore)/;
            function je(f, h) {
              if (f < h[0])
                return false;
              for (var oe = 0, xr = h.length, jr; oe + 1 < xr; ) {
                if (jr = oe + (xr - oe) / 2, jr -= jr % 2, h[jr] <= f && f <= h[jr + 1])
                  return true;
                f < h[jr] ? xr = jr : oe = jr + 2;
              }
              return false;
            }
            function V(f, h) {
              return h >= 2 ? je(f, se) : h === 1 ? je(f, Se) : je(f, fe);
            }
            e.isUnicodeIdentifierStart = V;
            function B(f, h) {
              return h >= 2 ? je(f, Me) : h === 1 ? je(f, J) : je(f, Ee);
            }
            function U(f) {
              var h = [];
              return f.forEach(function(oe, xr) {
                h[oe] = xr;
              }), h;
            }
            var m = U(F);
            function v(f) {
              return m[f];
            }
            e.tokenToString = v;
            function g(f) {
              return F.get(f);
            }
            e.stringToToken = g;
            function O(f) {
              for (var h = [], oe = 0, xr = 0; oe < f.length; ) {
                var jr = f.charCodeAt(oe);
                switch (oe++, jr) {
                  case 13:
                    f.charCodeAt(oe) === 10 && oe++;
                  case 10:
                    h.push(xr), xr = oe;
                    break;
                  default:
                    jr > 127 && be(jr) && (h.push(xr), xr = oe);
                    break;
                }
              }
              return h.push(xr), h;
            }
            e.computeLineStarts = O;
            function S(f, h, oe, xr) {
              return f.getPositionOfLineAndCharacter ? f.getPositionOfLineAndCharacter(h, oe, xr) : te(Je(f), h, oe, f.text, xr);
            }
            e.getPositionOfLineAndCharacter = S;
            function te(f, h, oe, xr, jr) {
              (h < 0 || h >= f.length) && (jr ? h = h < 0 ? 0 : h >= f.length ? f.length - 1 : h : e.Debug.fail("Bad line number. Line: ".concat(h, ", lineStarts.length: ").concat(f.length, " , line map is correct? ").concat(xr !== void 0 ? e.arraysEqual(f, O(xr)) : "unknown")));
              var qr = f[h] + oe;
              return jr ? qr > f[h + 1] ? f[h + 1] : typeof xr == "string" && qr > xr.length ? xr.length : qr : (h < f.length - 1 ? e.Debug.assert(qr < f[h + 1]) : xr !== void 0 && e.Debug.assert(qr <= xr.length), qr);
            }
            e.computePositionOfLineAndCharacter = te;
            function Je(f) {
              return f.lineMap || (f.lineMap = O(f.text));
            }
            e.getLineStarts = Je;
            function qe(f, h) {
              var oe = ge(f, h);
              return { line: oe, character: h - f[oe] };
            }
            e.computeLineAndCharacterOfPosition = qe;
            function ge(f, h, oe) {
              var xr = e.binarySearch(f, h, e.identity, e.compareValues, oe);
              return xr < 0 && (xr = ~xr - 1, e.Debug.assert(xr !== -1, "position cannot precede the beginning of the file")), xr;
            }
            e.computeLineOfPosition = ge;
            function ie(f, h, oe) {
              if (h === oe)
                return 0;
              var xr = Je(f), jr = Math.min(h, oe), qr = jr === oe, pt = qr ? h : oe, Ge = ge(xr, jr), K = ge(xr, pt, Ge);
              return qr ? Ge - K : K - Ge;
            }
            e.getLinesBetweenPositions = ie;
            function H(f, h) {
              return qe(Je(f), h);
            }
            e.getLineAndCharacterOfPosition = H;
            function pe(f) {
              return j(f) || be(f);
            }
            e.isWhiteSpaceLike = pe;
            function j(f) {
              return f === 32 || f === 9 || f === 11 || f === 12 || f === 160 || f === 133 || f === 5760 || f >= 8192 && f <= 8203 || f === 8239 || f === 8287 || f === 12288 || f === 65279;
            }
            e.isWhiteSpaceSingleLine = j;
            function be(f) {
              return f === 10 || f === 13 || f === 8232 || f === 8233;
            }
            e.isLineBreak = be;
            function Xe(f) {
              return f >= 48 && f <= 57;
            }
            function Re(f) {
              return Xe(f) || f >= 65 && f <= 70 || f >= 97 && f <= 102;
            }
            function Fe(f) {
              return f <= 1114111;
            }
            function dr(f) {
              return f >= 48 && f <= 55;
            }
            e.isOctalDigit = dr;
            function ze(f, h) {
              var oe = f.charCodeAt(h);
              switch (oe) {
                case 13:
                case 10:
                case 9:
                case 11:
                case 12:
                case 32:
                case 47:
                case 60:
                case 124:
                case 61:
                case 62:
                  return true;
                case 35:
                  return h === 0;
                default:
                  return oe > 127;
              }
            }
            e.couldStartTrivia = ze;
            function ve(f, h, oe, xr, jr) {
              if (e.positionIsSynthesized(h))
                return h;
              for (var qr = false; ; ) {
                var pt = f.charCodeAt(h);
                switch (pt) {
                  case 13:
                    f.charCodeAt(h + 1) === 10 && h++;
                  case 10:
                    if (h++, oe)
                      return h;
                    qr = !!jr;
                    continue;
                  case 9:
                  case 11:
                  case 12:
                  case 32:
                    h++;
                    continue;
                  case 47:
                    if (xr)
                      break;
                    if (f.charCodeAt(h + 1) === 47) {
                      for (h += 2; h < f.length && !be(f.charCodeAt(h)); )
                        h++;
                      qr = false;
                      continue;
                    }
                    if (f.charCodeAt(h + 1) === 42) {
                      for (h += 2; h < f.length; ) {
                        if (f.charCodeAt(h) === 42 && f.charCodeAt(h + 1) === 47) {
                          h += 2;
                          break;
                        }
                        h++;
                      }
                      qr = false;
                      continue;
                    }
                    break;
                  case 60:
                  case 124:
                  case 61:
                  case 62:
                    if (ar(f, h)) {
                      h = Cr(f, h), qr = false;
                      continue;
                    }
                    break;
                  case 35:
                    if (h === 0 && $e(f, h)) {
                      h = gr(f, h), qr = false;
                      continue;
                    }
                    break;
                  case 42:
                    if (qr) {
                      h++, qr = false;
                      continue;
                    }
                    break;
                  default:
                    if (pt > 127 && pe(pt)) {
                      h++;
                      continue;
                    }
                    break;
                }
                return h;
              }
            }
            e.skipTrivia = ve;
            var er = 7;
            function ar(f, h) {
              if (e.Debug.assert(h >= 0), h === 0 || be(f.charCodeAt(h - 1))) {
                var oe = f.charCodeAt(h);
                if (h + er < f.length) {
                  for (var xr = 0; xr < er; xr++)
                    if (f.charCodeAt(h + xr) !== oe)
                      return false;
                  return oe === 61 || f.charCodeAt(h + er) === 32;
                }
              }
              return false;
            }
            function Cr(f, h, oe) {
              oe && oe(e.Diagnostics.Merge_conflict_marker_encountered, h, er);
              var xr = f.charCodeAt(h), jr = f.length;
              if (xr === 60 || xr === 62)
                for (; h < jr && !be(f.charCodeAt(h)); )
                  h++;
              else
                for (e.Debug.assert(xr === 124 || xr === 61); h < jr; ) {
                  var qr = f.charCodeAt(h);
                  if ((qr === 61 || qr === 62) && qr !== xr && ar(f, h))
                    break;
                  h++;
                }
              return h;
            }
            var Ce = /^#!.*/;
            function $e(f, h) {
              return e.Debug.assert(h === 0), Ce.test(f);
            }
            e.isShebangTrivia = $e;
            function gr(f, h) {
              var oe = Ce.exec(f)[0];
              return h = h + oe.length, h;
            }
            e.scanShebangTrivia = gr;
            function X(f, h, oe, xr, jr, qr, pt) {
              var Ge, K, r, ct, ft = false, Ie = xr, me = pt;
              if (oe === 0) {
                Ie = true;
                var xe = Lr(h);
                xe && (oe = xe.length);
              }
              e:
                for (; oe >= 0 && oe < h.length; ) {
                  var Ye = h.charCodeAt(oe);
                  switch (Ye) {
                    case 13:
                      h.charCodeAt(oe + 1) === 10 && oe++;
                    case 10:
                      if (oe++, xr)
                        break e;
                      Ie = true, ft && (ct = true);
                      continue;
                    case 9:
                    case 11:
                    case 12:
                    case 32:
                      oe++;
                      continue;
                    case 47:
                      var vr = h.charCodeAt(oe + 1), nt = false;
                      if (vr === 47 || vr === 42) {
                        var pr = vr === 47 ? 2 : 3, Mr = oe;
                        if (oe += 2, vr === 47)
                          for (; oe < h.length; ) {
                            if (be(h.charCodeAt(oe))) {
                              nt = true;
                              break;
                            }
                            oe++;
                          }
                        else
                          for (; oe < h.length; ) {
                            if (h.charCodeAt(oe) === 42 && h.charCodeAt(oe + 1) === 47) {
                              oe += 2;
                              break;
                            }
                            oe++;
                          }
                        if (Ie) {
                          if (ft && (me = jr(Ge, K, r, ct, qr, me), !f && me))
                            return me;
                          Ge = Mr, K = oe, r = pr, ct = nt, ft = true;
                        }
                        continue;
                      }
                      break e;
                    default:
                      if (Ye > 127 && pe(Ye)) {
                        ft && be(Ye) && (ct = true), oe++;
                        continue;
                      }
                      break e;
                  }
                }
              return ft && (me = jr(Ge, K, r, ct, qr, me)), me;
            }
            function Te(f, h, oe, xr) {
              return X(false, f, h, false, oe, xr);
            }
            e.forEachLeadingCommentRange = Te;
            function we(f, h, oe, xr) {
              return X(false, f, h, true, oe, xr);
            }
            e.forEachTrailingCommentRange = we;
            function he(f, h, oe, xr, jr) {
              return X(true, f, h, false, oe, xr, jr);
            }
            e.reduceEachLeadingCommentRange = he;
            function yr(f, h, oe, xr, jr) {
              return X(true, f, h, true, oe, xr, jr);
            }
            e.reduceEachTrailingCommentRange = yr;
            function kr(f, h, oe, xr, jr, qr) {
              return qr || (qr = []), qr.push({ kind: oe, pos: f, end: h, hasTrailingNewLine: xr }), qr;
            }
            function nr(f, h) {
              return he(f, h, kr, void 0, void 0);
            }
            e.getLeadingCommentRanges = nr;
            function tr(f, h) {
              return yr(f, h, kr, void 0, void 0);
            }
            e.getTrailingCommentRanges = tr;
            function Lr(f) {
              var h = Ce.exec(f);
              if (h)
                return h[0];
            }
            e.getShebang = Lr;
            function zr(f, h) {
              return f >= 65 && f <= 90 || f >= 97 && f <= 122 || f === 36 || f === 95 || f > 127 && V(f, h);
            }
            e.isIdentifierStart = zr;
            function ye(f, h, oe) {
              return f >= 65 && f <= 90 || f >= 97 && f <= 122 || f >= 48 && f <= 57 || f === 36 || f === 95 || (oe === 1 ? f === 45 || f === 58 : false) || f > 127 && B(f, h);
            }
            e.isIdentifierPart = ye;
            function ir(f, h, oe) {
              var xr = Pr(f, 0);
              if (!zr(xr, h))
                return false;
              for (var jr = Br(xr); jr < f.length; jr += Br(xr))
                if (!ye(xr = Pr(f, jr), h, oe))
                  return false;
              return true;
            }
            e.isIdentifierText = ir;
            function Dr(f, h, oe, xr, jr, qr, pt) {
              oe === void 0 && (oe = 0);
              var Ge = xr, K, r, ct, ft, Ie, me, xe, Ye, vr = 0;
              Zn(Ge, qr, pt);
              var nt = { getStartPos: function() {
                return ct;
              }, getTextPos: function() {
                return K;
              }, getToken: function() {
                return Ie;
              }, getTokenPos: function() {
                return ft;
              }, getTokenText: function() {
                return Ge.substring(ft, K);
              }, getTokenValue: function() {
                return me;
              }, hasUnicodeEscape: function() {
                return (xe & 1024) !== 0;
              }, hasExtendedUnicodeEscape: function() {
                return (xe & 8) !== 0;
              }, hasPrecedingLineBreak: function() {
                return (xe & 1) !== 0;
              }, hasPrecedingJSDocComment: function() {
                return (xe & 2) !== 0;
              }, isIdentifier: function() {
                return Ie === 79 || Ie > 116;
              }, isReservedWord: function() {
                return Ie >= 81 && Ie <= 116;
              }, isUnterminated: function() {
                return (xe & 4) !== 0;
              }, getCommentDirectives: function() {
                return Ye;
              }, getNumericLiteralFlags: function() {
                return xe & 1008;
              }, getTokenFlags: function() {
                return xe;
              }, reScanGreaterToken: Dt, reScanAsteriskEqualsToken: Xt, reScanSlashToken: cn, reScanTemplateToken: hn, reScanTemplateHeadOrNoSubstitutionTemplate: ln, scanJsxIdentifier: ri, scanJsxAttributeValue: vi, reScanJsxAttributeValue: Qn, reScanJsxToken: En, reScanLessThanToken: Vt, reScanHashToken: ui, reScanQuestionToken: ei, reScanInvalidIdentifier: Kr, scanJsxToken: hi, scanJsDocToken: Yn, scan: Sr, getText: si, clearCommentDirectives: di, setText: Zn, setScriptTarget: gt, setLanguageVariant: mi, setOnError: Fn, setTextPos: dn, setInJSDocType: On, tryScan: Kn, lookAhead: Dn, scanRange: bi };
              return e.Debug.isDebugging && Object.defineProperty(nt, "__debugShowCurrentPositionInText", { get: function() {
                var br = nt.getText();
                return br.slice(0, nt.getStartPos()) + "\u2551" + br.slice(nt.getStartPos());
              } }), nt;
              function pr(br, Ae, ur) {
                if (Ae === void 0 && (Ae = K), jr) {
                  var L = K;
                  K = Ae, jr(br, ur || 0), K = L;
                }
              }
              function Mr() {
                for (var br = K, Ae = false, ur = false, L = ""; ; ) {
                  var qt = Ge.charCodeAt(K);
                  if (qt === 95) {
                    xe |= 512, Ae ? (Ae = false, ur = true, L += Ge.substring(br, K)) : pr(ur ? e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted : e.Diagnostics.Numeric_separators_are_not_allowed_here, K, 1), K++, br = K;
                    continue;
                  }
                  if (Xe(qt)) {
                    Ae = true, ur = false, K++;
                    continue;
                  }
                  break;
                }
                return Ge.charCodeAt(K - 1) === 95 && pr(e.Diagnostics.Numeric_separators_are_not_allowed_here, K - 1, 1), L + Ge.substring(br, K);
              }
              function ot() {
                var br = K, Ae = Mr(), ur, L;
                Ge.charCodeAt(K) === 46 && (K++, ur = Mr());
                var qt = K;
                if (Ge.charCodeAt(K) === 69 || Ge.charCodeAt(K) === 101) {
                  K++, xe |= 16, (Ge.charCodeAt(K) === 43 || Ge.charCodeAt(K) === 45) && K++;
                  var nn = K, fr = Mr();
                  fr ? (L = Ge.substring(qt, nn) + fr, qt = K) : pr(e.Diagnostics.Digit_expected);
                }
                var Le;
                if (xe & 512 ? (Le = Ae, ur && (Le += "." + ur), L && (Le += L)) : Le = Ge.substring(br, qt), ur !== void 0 || xe & 16)
                  return At(br, ur === void 0 && !!(xe & 16)), { type: 8, value: "" + +Le };
                me = Le;
                var Ve = Qe();
                return At(br), { type: Ve, value: me };
              }
              function At(br, Ae) {
                if (zr(Pr(Ge, K), f)) {
                  var ur = K, L = at().length;
                  L === 1 && Ge[ur] === "n" ? pr(Ae ? e.Diagnostics.A_bigint_literal_cannot_use_exponential_notation : e.Diagnostics.A_bigint_literal_must_be_an_integer, br, ur - br + 1) : (pr(e.Diagnostics.An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal, ur, L), K = ur);
                }
              }
              function re() {
                for (var br = K; dr(Ge.charCodeAt(K)); )
                  K++;
                return +Ge.substring(br, K);
              }
              function de(br, Ae) {
                var ur = Nr(br, false, Ae);
                return ur ? parseInt(ur, 16) : -1;
              }
              function He(br, Ae) {
                return Nr(br, true, Ae);
              }
              function Nr(br, Ae, ur) {
                for (var L = [], qt = false, nn = false; L.length < br || Ae; ) {
                  var fr = Ge.charCodeAt(K);
                  if (ur && fr === 95) {
                    xe |= 512, qt ? (qt = false, nn = true) : pr(nn ? e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted : e.Diagnostics.Numeric_separators_are_not_allowed_here, K, 1), K++;
                    continue;
                  }
                  if (qt = ur, fr >= 65 && fr <= 70)
                    fr += 97 - 65;
                  else if (!(fr >= 48 && fr <= 57 || fr >= 97 && fr <= 102))
                    break;
                  L.push(fr), K++, nn = false;
                }
                return L.length < br && (L = []), Ge.charCodeAt(K - 1) === 95 && pr(e.Diagnostics.Numeric_separators_are_not_allowed_here, K - 1, 1), String.fromCharCode.apply(String, L);
              }
              function Yr(br) {
                br === void 0 && (br = false);
                var Ae = Ge.charCodeAt(K);
                K++;
                for (var ur = "", L = K; ; ) {
                  if (K >= r) {
                    ur += Ge.substring(L, K), xe |= 4, pr(e.Diagnostics.Unterminated_string_literal);
                    break;
                  }
                  var qt = Ge.charCodeAt(K);
                  if (qt === Ae) {
                    ur += Ge.substring(L, K), K++;
                    break;
                  }
                  if (qt === 92 && !br) {
                    ur += Ge.substring(L, K), ur += xt(), L = K;
                    continue;
                  }
                  if (be(qt) && !br) {
                    ur += Ge.substring(L, K), xe |= 4, pr(e.Diagnostics.Unterminated_string_literal);
                    break;
                  }
                  K++;
                }
                return ur;
              }
              function Ct(br) {
                var Ae = Ge.charCodeAt(K) === 96;
                K++;
                for (var ur = K, L = "", qt; ; ) {
                  if (K >= r) {
                    L += Ge.substring(ur, K), xe |= 4, pr(e.Diagnostics.Unterminated_template_literal), qt = Ae ? 14 : 17;
                    break;
                  }
                  var nn = Ge.charCodeAt(K);
                  if (nn === 96) {
                    L += Ge.substring(ur, K), K++, qt = Ae ? 14 : 17;
                    break;
                  }
                  if (nn === 36 && K + 1 < r && Ge.charCodeAt(K + 1) === 123) {
                    L += Ge.substring(ur, K), K += 2, qt = Ae ? 15 : 16;
                    break;
                  }
                  if (nn === 92) {
                    L += Ge.substring(ur, K), L += xt(br), ur = K;
                    continue;
                  }
                  if (nn === 13) {
                    L += Ge.substring(ur, K), K++, K < r && Ge.charCodeAt(K) === 10 && K++, L += `
`, ur = K;
                    continue;
                  }
                  K++;
                }
                return e.Debug.assert(qt !== void 0), me = L, qt;
              }
              function xt(br) {
                var Ae = K;
                if (K++, K >= r)
                  return pr(e.Diagnostics.Unexpected_end_of_text), "";
                var ur = Ge.charCodeAt(K);
                switch (K++, ur) {
                  case 48:
                    return br && K < r && Xe(Ge.charCodeAt(K)) ? (K++, xe |= 2048, Ge.substring(Ae, K)) : "\0";
                  case 98:
                    return "\b";
                  case 116:
                    return "	";
                  case 110:
                    return `
`;
                  case 118:
                    return "\v";
                  case 102:
                    return "\f";
                  case 114:
                    return "\r";
                  case 39:
                    return "'";
                  case 34:
                    return '"';
                  case 117:
                    if (br) {
                      for (var L = K; L < K + 4; L++)
                        if (L < r && !Re(Ge.charCodeAt(L)) && Ge.charCodeAt(L) !== 123)
                          return K = L, xe |= 2048, Ge.substring(Ae, K);
                    }
                    if (K < r && Ge.charCodeAt(K) === 123) {
                      if (K++, br && !Re(Ge.charCodeAt(K)))
                        return xe |= 2048, Ge.substring(Ae, K);
                      if (br) {
                        var qt = K, nn = He(1, false), fr = nn ? parseInt(nn, 16) : -1;
                        if (!Fe(fr) || Ge.charCodeAt(K) !== 125)
                          return xe |= 2048, Ge.substring(Ae, K);
                        K = qt;
                      }
                      return xe |= 8, zt();
                    }
                    return xe |= 1024, Lt(4);
                  case 120:
                    if (br)
                      if (Re(Ge.charCodeAt(K))) {
                        if (!Re(Ge.charCodeAt(K + 1)))
                          return K++, xe |= 2048, Ge.substring(Ae, K);
                      } else
                        return xe |= 2048, Ge.substring(Ae, K);
                    return Lt(2);
                  case 13:
                    K < r && Ge.charCodeAt(K) === 10 && K++;
                  case 10:
                  case 8232:
                  case 8233:
                    return "";
                  default:
                    return String.fromCharCode(ur);
                }
              }
              function Lt(br) {
                var Ae = de(br, false);
                return Ae >= 0 ? String.fromCharCode(Ae) : (pr(e.Diagnostics.Hexadecimal_digit_expected), "");
              }
              function zt() {
                var br = He(1, false), Ae = br ? parseInt(br, 16) : -1, ur = false;
                return Ae < 0 ? (pr(e.Diagnostics.Hexadecimal_digit_expected), ur = true) : Ae > 1114111 && (pr(e.Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive), ur = true), K >= r ? (pr(e.Diagnostics.Unexpected_end_of_text), ur = true) : Ge.charCodeAt(K) === 125 ? K++ : (pr(e.Diagnostics.Unterminated_Unicode_escape_sequence), ur = true), ur ? "" : Z(Ae);
              }
              function Zt() {
                if (K + 5 < r && Ge.charCodeAt(K + 1) === 117) {
                  var br = K;
                  K += 2;
                  var Ae = de(4, false);
                  return K = br, Ae;
                }
                return -1;
              }
              function mt() {
                if (Pr(Ge, K + 1) === 117 && Pr(Ge, K + 2) === 123) {
                  var br = K;
                  K += 3;
                  var Ae = He(1, false), ur = Ae ? parseInt(Ae, 16) : -1;
                  return K = br, ur;
                }
                return -1;
              }
              function at() {
                for (var br = "", Ae = K; K < r; ) {
                  var ur = Pr(Ge, K);
                  if (ye(ur, f))
                    K += Br(ur);
                  else if (ur === 92) {
                    if (ur = mt(), ur >= 0 && ye(ur, f)) {
                      K += 3, xe |= 8, br += zt(), Ae = K;
                      continue;
                    }
                    if (ur = Zt(), !(ur >= 0 && ye(ur, f)))
                      break;
                    xe |= 1024, br += Ge.substring(Ae, K), br += Z(ur), K += 6, Ae = K;
                  } else
                    break;
                }
                return br += Ge.substring(Ae, K), br;
              }
              function k() {
                var br = me.length;
                if (br >= 2 && br <= 12) {
                  var Ae = me.charCodeAt(0);
                  if (Ae >= 97 && Ae <= 122) {
                    var ur = q.get(me);
                    if (ur !== void 0)
                      return Ie = ur;
                  }
                }
                return Ie = 79;
              }
              function ue(br) {
                for (var Ae = "", ur = false, L = false; ; ) {
                  var qt = Ge.charCodeAt(K);
                  if (qt === 95) {
                    xe |= 512, ur ? (ur = false, L = true) : pr(L ? e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted : e.Diagnostics.Numeric_separators_are_not_allowed_here, K, 1), K++;
                    continue;
                  }
                  if (ur = true, !Xe(qt) || qt - 48 >= br)
                    break;
                  Ae += Ge[K], K++, L = false;
                }
                return Ge.charCodeAt(K - 1) === 95 && pr(e.Diagnostics.Numeric_separators_are_not_allowed_here, K - 1, 1), Ae;
              }
              function Qe() {
                if (Ge.charCodeAt(K) === 110)
                  return me += "n", xe & 384 && (me = e.parsePseudoBigInt(me) + "n"), K++, 9;
                var br = xe & 128 ? parseInt(me.slice(2), 2) : xe & 256 ? parseInt(me.slice(2), 8) : +me;
                return me = "" + br, 8;
              }
              function Sr() {
                var br;
                ct = K, xe = 0;
                for (var Ae = false; ; ) {
                  if (ft = K, K >= r)
                    return Ie = 1;
                  var ur = Pr(Ge, K);
                  if (ur === 35 && K === 0 && $e(Ge, K)) {
                    if (K = gr(Ge, K), h)
                      continue;
                    return Ie = 6;
                  }
                  switch (ur) {
                    case 10:
                    case 13:
                      if (xe |= 1, h) {
                        K++;
                        continue;
                      } else
                        return ur === 13 && K + 1 < r && Ge.charCodeAt(K + 1) === 10 ? K += 2 : K++, Ie = 4;
                    case 9:
                    case 11:
                    case 12:
                    case 32:
                    case 160:
                    case 5760:
                    case 8192:
                    case 8193:
                    case 8194:
                    case 8195:
                    case 8196:
                    case 8197:
                    case 8198:
                    case 8199:
                    case 8200:
                    case 8201:
                    case 8202:
                    case 8203:
                    case 8239:
                    case 8287:
                    case 12288:
                    case 65279:
                      if (h) {
                        K++;
                        continue;
                      } else {
                        for (; K < r && j(Ge.charCodeAt(K)); )
                          K++;
                        return Ie = 5;
                      }
                    case 33:
                      return Ge.charCodeAt(K + 1) === 61 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 37) : (K += 2, Ie = 35) : (K++, Ie = 53);
                    case 34:
                    case 39:
                      return me = Yr(), Ie = 10;
                    case 96:
                      return Ie = Ct(false);
                    case 37:
                      return Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 69) : (K++, Ie = 44);
                    case 38:
                      return Ge.charCodeAt(K + 1) === 38 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 76) : (K += 2, Ie = 55) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 73) : (K++, Ie = 50);
                    case 40:
                      return K++, Ie = 20;
                    case 41:
                      return K++, Ie = 21;
                    case 42:
                      if (Ge.charCodeAt(K + 1) === 61)
                        return K += 2, Ie = 66;
                      if (Ge.charCodeAt(K + 1) === 42)
                        return Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 67) : (K += 2, Ie = 42);
                      if (K++, vr && !Ae && xe & 1) {
                        Ae = true;
                        continue;
                      }
                      return Ie = 41;
                    case 43:
                      return Ge.charCodeAt(K + 1) === 43 ? (K += 2, Ie = 45) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 64) : (K++, Ie = 39);
                    case 44:
                      return K++, Ie = 27;
                    case 45:
                      return Ge.charCodeAt(K + 1) === 45 ? (K += 2, Ie = 46) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 65) : (K++, Ie = 40);
                    case 46:
                      return Xe(Ge.charCodeAt(K + 1)) ? (me = ot().value, Ie = 8) : Ge.charCodeAt(K + 1) === 46 && Ge.charCodeAt(K + 2) === 46 ? (K += 3, Ie = 25) : (K++, Ie = 24);
                    case 47:
                      if (Ge.charCodeAt(K + 1) === 47) {
                        for (K += 2; K < r && !be(Ge.charCodeAt(K)); )
                          K++;
                        if (Ye = In(Ye, Ge.slice(ft, K), Q, ft), h)
                          continue;
                        return Ie = 2;
                      }
                      if (Ge.charCodeAt(K + 1) === 42) {
                        K += 2, Ge.charCodeAt(K) === 42 && Ge.charCodeAt(K + 1) !== 47 && (xe |= 2);
                        for (var L = false, qt = ft; K < r; ) {
                          var nn = Ge.charCodeAt(K);
                          if (nn === 42 && Ge.charCodeAt(K + 1) === 47) {
                            K += 2, L = true;
                            break;
                          }
                          K++, be(nn) && (qt = K, xe |= 1);
                        }
                        if (Ye = In(Ye, Ge.slice(qt, K), Be, qt), L || pr(e.Diagnostics.Asterisk_Slash_expected), h)
                          continue;
                        return L || (xe |= 4), Ie = 3;
                      }
                      return Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 68) : (K++, Ie = 43);
                    case 48:
                      if (K + 2 < r && (Ge.charCodeAt(K + 1) === 88 || Ge.charCodeAt(K + 1) === 120))
                        return K += 2, me = He(1, true), me || (pr(e.Diagnostics.Hexadecimal_digit_expected), me = "0"), me = "0x" + me, xe |= 64, Ie = Qe();
                      if (K + 2 < r && (Ge.charCodeAt(K + 1) === 66 || Ge.charCodeAt(K + 1) === 98))
                        return K += 2, me = ue(2), me || (pr(e.Diagnostics.Binary_digit_expected), me = "0"), me = "0b" + me, xe |= 128, Ie = Qe();
                      if (K + 2 < r && (Ge.charCodeAt(K + 1) === 79 || Ge.charCodeAt(K + 1) === 111))
                        return K += 2, me = ue(8), me || (pr(e.Diagnostics.Octal_digit_expected), me = "0"), me = "0o" + me, xe |= 256, Ie = Qe();
                      if (K + 1 < r && dr(Ge.charCodeAt(K + 1)))
                        return me = "" + re(), xe |= 32, Ie = 8;
                    case 49:
                    case 50:
                    case 51:
                    case 52:
                    case 53:
                    case 54:
                    case 55:
                    case 56:
                    case 57:
                      return br = ot(), Ie = br.type, me = br.value, Ie;
                    case 58:
                      return K++, Ie = 58;
                    case 59:
                      return K++, Ie = 26;
                    case 60:
                      if (ar(Ge, K)) {
                        if (K = Cr(Ge, K, pr), h)
                          continue;
                        return Ie = 7;
                      }
                      return Ge.charCodeAt(K + 1) === 60 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 70) : (K += 2, Ie = 47) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 32) : oe === 1 && Ge.charCodeAt(K + 1) === 47 && Ge.charCodeAt(K + 2) !== 42 ? (K += 2, Ie = 30) : (K++, Ie = 29);
                    case 61:
                      if (ar(Ge, K)) {
                        if (K = Cr(Ge, K, pr), h)
                          continue;
                        return Ie = 7;
                      }
                      return Ge.charCodeAt(K + 1) === 61 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 36) : (K += 2, Ie = 34) : Ge.charCodeAt(K + 1) === 62 ? (K += 2, Ie = 38) : (K++, Ie = 63);
                    case 62:
                      if (ar(Ge, K)) {
                        if (K = Cr(Ge, K, pr), h)
                          continue;
                        return Ie = 7;
                      }
                      return K++, Ie = 31;
                    case 63:
                      return Ge.charCodeAt(K + 1) === 46 && !Xe(Ge.charCodeAt(K + 2)) ? (K += 2, Ie = 28) : Ge.charCodeAt(K + 1) === 63 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 77) : (K += 2, Ie = 60) : (K++, Ie = 57);
                    case 91:
                      return K++, Ie = 22;
                    case 93:
                      return K++, Ie = 23;
                    case 94:
                      return Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 78) : (K++, Ie = 52);
                    case 123:
                      return K++, Ie = 18;
                    case 124:
                      if (ar(Ge, K)) {
                        if (K = Cr(Ge, K, pr), h)
                          continue;
                        return Ie = 7;
                      }
                      return Ge.charCodeAt(K + 1) === 124 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 75) : (K += 2, Ie = 56) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 74) : (K++, Ie = 51);
                    case 125:
                      return K++, Ie = 19;
                    case 126:
                      return K++, Ie = 54;
                    case 64:
                      return K++, Ie = 59;
                    case 92:
                      var fr = mt();
                      if (fr >= 0 && zr(fr, f))
                        return K += 3, xe |= 8, me = zt() + at(), Ie = k();
                      var Le = Zt();
                      return Le >= 0 && zr(Le, f) ? (K += 6, xe |= 1024, me = String.fromCharCode(Le) + at(), Ie = k()) : (pr(e.Diagnostics.Invalid_character), K++, Ie = 0);
                    case 35:
                      if (K !== 0 && Ge[K + 1] === "!")
                        return pr(e.Diagnostics.can_only_be_used_at_the_start_of_a_file), K++, Ie = 0;
                      var Ve = Pr(Ge, K + 1);
                      if (Ve === 92) {
                        K++;
                        var _r = mt();
                        if (_r >= 0 && zr(_r, f))
                          return K += 3, xe |= 8, me = "#" + zt() + at(), Ie = 80;
                        var lr = Zt();
                        if (lr >= 0 && zr(lr, f))
                          return K += 6, xe |= 1024, me = "#" + String.fromCharCode(lr) + at(), Ie = 80;
                        K--;
                      }
                      return zr(Ve, f) ? (K++, Hr(Ve, f)) : (me = "#", pr(e.Diagnostics.Invalid_character, K++, Br(ur))), Ie = 80;
                    default:
                      var Vr = Hr(ur, f);
                      if (Vr)
                        return Ie = Vr;
                      if (j(ur)) {
                        K += Br(ur);
                        continue;
                      } else if (be(ur)) {
                        xe |= 1, K += Br(ur);
                        continue;
                      }
                      var tt = Br(ur);
                      return pr(e.Diagnostics.Invalid_character, K, tt), K += tt, Ie = 0;
                  }
                }
              }
              function Kr() {
                e.Debug.assert(Ie === 0, "'reScanInvalidIdentifier' should only be called when the current token is 'SyntaxKind.Unknown'."), K = ft = ct, xe = 0;
                var br = Pr(Ge, K), Ae = Hr(br, 99);
                return Ae ? Ie = Ae : (K += Br(br), Ie);
              }
              function Hr(br, Ae) {
                var ur = br;
                if (zr(ur, Ae)) {
                  for (K += Br(ur); K < r && ye(ur = Pr(Ge, K), Ae); )
                    K += Br(ur);
                  return me = Ge.substring(ft, K), ur === 92 && (me += at()), k();
                }
              }
              function Dt() {
                if (Ie === 31) {
                  if (Ge.charCodeAt(K) === 62)
                    return Ge.charCodeAt(K + 1) === 62 ? Ge.charCodeAt(K + 2) === 61 ? (K += 3, Ie = 72) : (K += 2, Ie = 49) : Ge.charCodeAt(K + 1) === 61 ? (K += 2, Ie = 71) : (K++, Ie = 48);
                  if (Ge.charCodeAt(K) === 61)
                    return K++, Ie = 33;
                }
                return Ie;
              }
              function Xt() {
                return e.Debug.assert(Ie === 66, "'reScanAsteriskEqualsToken' should only be called on a '*='"), K = ft + 1, Ie = 63;
              }
              function cn() {
                if (Ie === 43 || Ie === 68) {
                  for (var br = ft + 1, Ae = false, ur = false; ; ) {
                    if (br >= r) {
                      xe |= 4, pr(e.Diagnostics.Unterminated_regular_expression_literal);
                      break;
                    }
                    var L = Ge.charCodeAt(br);
                    if (be(L)) {
                      xe |= 4, pr(e.Diagnostics.Unterminated_regular_expression_literal);
                      break;
                    }
                    if (Ae)
                      Ae = false;
                    else if (L === 47 && !ur) {
                      br++;
                      break;
                    } else
                      L === 91 ? ur = true : L === 92 ? Ae = true : L === 93 && (ur = false);
                    br++;
                  }
                  for (; br < r && ye(Ge.charCodeAt(br), f); )
                    br++;
                  K = br, me = Ge.substring(ft, K), Ie = 13;
                }
                return Ie;
              }
              function In(br, Ae, ur, L) {
                var qt = yn(e.trimStringStart(Ae), ur);
                return qt === void 0 ? br : e.append(br, { range: { pos: L, end: K }, type: qt });
              }
              function yn(br, Ae) {
                var ur = Ae.exec(br);
                if (ur)
                  switch (ur[1]) {
                    case "ts-expect-error":
                      return 0;
                    case "ts-ignore":
                      return 1;
                  }
              }
              function hn(br) {
                return e.Debug.assert(Ie === 19, "'reScanTemplateToken' should only be called on a '}'"), K = ft, Ie = Ct(br);
              }
              function ln() {
                return K = ft, Ie = Ct(true);
              }
              function En(br) {
                return br === void 0 && (br = true), K = ft = ct, Ie = hi(br);
              }
              function Vt() {
                return Ie === 47 ? (K = ft + 1, Ie = 29) : Ie;
              }
              function ui() {
                return Ie === 80 ? (K = ft + 1, Ie = 62) : Ie;
              }
              function ei() {
                return e.Debug.assert(Ie === 60, "'reScanQuestionToken' should only be called on a '??'"), K = ft + 1, Ie = 57;
              }
              function hi(br) {
                if (br === void 0 && (br = true), ct = ft = K, K >= r)
                  return Ie = 1;
                var Ae = Ge.charCodeAt(K);
                if (Ae === 60)
                  return Ge.charCodeAt(K + 1) === 47 ? (K += 2, Ie = 30) : (K++, Ie = 29);
                if (Ae === 123)
                  return K++, Ie = 18;
                for (var ur = 0; K < r && (Ae = Ge.charCodeAt(K), Ae !== 123); ) {
                  if (Ae === 60) {
                    if (ar(Ge, K))
                      return K = Cr(Ge, K, pr), Ie = 7;
                    break;
                  }
                  if (Ae === 62 && pr(e.Diagnostics.Unexpected_token_Did_you_mean_or_gt, K, 1), Ae === 125 && pr(e.Diagnostics.Unexpected_token_Did_you_mean_or_rbrace, K, 1), be(Ae) && ur === 0)
                    ur = -1;
                  else {
                    if (!br && be(Ae) && ur > 0)
                      break;
                    pe(Ae) || (ur = K);
                  }
                  K++;
                }
                return me = Ge.substring(ct, K), ur === -1 ? 12 : 11;
              }
              function ri() {
                if (w(Ie)) {
                  for (var br = false; K < r; ) {
                    var Ae = Ge.charCodeAt(K);
                    if (Ae === 45) {
                      me += "-", K++;
                      continue;
                    } else if (Ae === 58 && !br) {
                      me += ":", K++, br = true, Ie = 79;
                      continue;
                    }
                    var ur = K;
                    if (me += at(), K === ur)
                      break;
                  }
                  return me.slice(-1) === ":" && (me = me.slice(0, -1), K--), k();
                }
                return Ie;
              }
              function vi() {
                switch (ct = K, Ge.charCodeAt(K)) {
                  case 34:
                  case 39:
                    return me = Yr(true), Ie = 10;
                  default:
                    return Sr();
                }
              }
              function Qn() {
                return K = ft = ct, vi();
              }
              function Yn() {
                if (ct = ft = K, xe = 0, K >= r)
                  return Ie = 1;
                var br = Pr(Ge, K);
                switch (K += Br(br), br) {
                  case 9:
                  case 11:
                  case 12:
                  case 32:
                    for (; K < r && j(Ge.charCodeAt(K)); )
                      K++;
                    return Ie = 5;
                  case 64:
                    return Ie = 59;
                  case 13:
                    Ge.charCodeAt(K) === 10 && K++;
                  case 10:
                    return xe |= 1, Ie = 4;
                  case 42:
                    return Ie = 41;
                  case 123:
                    return Ie = 18;
                  case 125:
                    return Ie = 19;
                  case 91:
                    return Ie = 22;
                  case 93:
                    return Ie = 23;
                  case 60:
                    return Ie = 29;
                  case 62:
                    return Ie = 31;
                  case 61:
                    return Ie = 63;
                  case 44:
                    return Ie = 27;
                  case 46:
                    return Ie = 24;
                  case 96:
                    return Ie = 61;
                  case 35:
                    return Ie = 62;
                  case 92:
                    K--;
                    var Ae = mt();
                    if (Ae >= 0 && zr(Ae, f))
                      return K += 3, xe |= 8, me = zt() + at(), Ie = k();
                    var ur = Zt();
                    return ur >= 0 && zr(ur, f) ? (K += 6, xe |= 1024, me = String.fromCharCode(ur) + at(), Ie = k()) : (K++, Ie = 0);
                }
                if (zr(br, f)) {
                  for (var L = br; K < r && ye(L = Pr(Ge, K), f) || Ge.charCodeAt(K) === 45; )
                    K += Br(L);
                  return me = Ge.substring(ft, K), L === 92 && (me += at()), Ie = k();
                } else
                  return Ie = 0;
              }
              function oi(br, Ae) {
                var ur = K, L = ct, qt = ft, nn = Ie, fr = me, Le = xe, Ve = br();
                return (!Ve || Ae) && (K = ur, ct = L, ft = qt, Ie = nn, me = fr, xe = Le), Ve;
              }
              function bi(br, Ae, ur) {
                var L = r, qt = K, nn = ct, fr = ft, Le = Ie, Ve = me, _r = xe, lr = Ye;
                Zn(Ge, br, Ae);
                var Vr = ur();
                return r = L, K = qt, ct = nn, ft = fr, Ie = Le, me = Ve, xe = _r, Ye = lr, Vr;
              }
              function Dn(br) {
                return oi(br, true);
              }
              function Kn(br) {
                return oi(br, false);
              }
              function si() {
                return Ge;
              }
              function di() {
                Ye = void 0;
              }
              function Zn(br, Ae, ur) {
                Ge = br || "", r = ur === void 0 ? Ge.length : Ae + ur, dn(Ae || 0);
              }
              function Fn(br) {
                jr = br;
              }
              function gt(br) {
                f = br;
              }
              function mi(br) {
                oe = br;
              }
              function dn(br) {
                e.Debug.assert(br >= 0), K = br, ct = br, ft = br, Ie = 0, me = void 0, xe = 0;
              }
              function On(br) {
                vr += br ? 1 : -1;
              }
            }
            e.createScanner = Dr;
            var Pr = String.prototype.codePointAt ? function(f, h) {
              return f.codePointAt(h);
            } : function(h, oe) {
              var xr = h.length;
              if (!(oe < 0 || oe >= xr)) {
                var jr = h.charCodeAt(oe);
                if (jr >= 55296 && jr <= 56319 && xr > oe + 1) {
                  var qr = h.charCodeAt(oe + 1);
                  if (qr >= 56320 && qr <= 57343)
                    return (jr - 55296) * 1024 + qr - 56320 + 65536;
                }
                return jr;
              }
            };
            function Br(f) {
              return f >= 65536 ? 2 : 1;
            }
            function ut(f) {
              if (e.Debug.assert(0 <= f && f <= 1114111), f <= 65535)
                return String.fromCharCode(f);
              var h = Math.floor((f - 65536) / 1024) + 55296, oe = (f - 65536) % 1024 + 56320;
              return String.fromCharCode(h, oe);
            }
            var rt = String.fromCodePoint ? function(f) {
              return String.fromCodePoint(f);
            } : ut;
            function Z(f) {
              return rt(f);
            }
            e.utf16EncodeAsString = Z;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(y) {
              return e.pathIsRelative(y) || e.isRootedDiskPath(y);
            }
            e.isExternalModuleNameRelative = t3;
            function w(y) {
              return e.sortAndDeduplicate(y, e.compareDiagnostics);
            }
            e.sortAndDeduplicateDiagnostics = w;
            function s(y) {
              switch (e.getEmitScriptTarget(y)) {
                case 99:
                  return "lib.esnext.full.d.ts";
                case 9:
                  return "lib.es2022.full.d.ts";
                case 8:
                  return "lib.es2021.full.d.ts";
                case 7:
                  return "lib.es2020.full.d.ts";
                case 6:
                  return "lib.es2019.full.d.ts";
                case 5:
                  return "lib.es2018.full.d.ts";
                case 4:
                  return "lib.es2017.full.d.ts";
                case 3:
                  return "lib.es2016.full.d.ts";
                case 2:
                  return "lib.es6.d.ts";
                default:
                  return "lib.d.ts";
              }
            }
            e.getDefaultLibFileName = s;
            function q(y) {
              return y.start + y.length;
            }
            e.textSpanEnd = q;
            function F(y) {
              return y.length === 0;
            }
            e.textSpanIsEmpty = F;
            function fe(y, De) {
              return De >= y.start && De < q(y);
            }
            e.textSpanContainsPosition = fe;
            function Ee(y, De) {
              return De >= y.pos && De <= y.end;
            }
            e.textRangeContainsPositionInclusive = Ee;
            function Se(y, De) {
              return De.start >= y.start && q(De) <= q(y);
            }
            e.textSpanContainsTextSpan = Se;
            function J(y, De) {
              return se(y, De) !== void 0;
            }
            e.textSpanOverlapsWith = J;
            function se(y, De) {
              var R = V(y, De);
              return R && R.length === 0 ? void 0 : R;
            }
            e.textSpanOverlap = se;
            function Me(y, De) {
              return Be(y.start, y.length, De.start, De.length);
            }
            e.textSpanIntersectsWithTextSpan = Me;
            function Q(y, De, R) {
              return Be(y.start, y.length, De, R);
            }
            e.textSpanIntersectsWith = Q;
            function Be(y, De, R, Jt) {
              var Qt = y + De, qn = R + Jt;
              return R <= Qt && qn >= y;
            }
            e.decodedTextSpanIntersectsWith = Be;
            function je(y, De) {
              return De <= q(y) && De >= y.start;
            }
            e.textSpanIntersectsWithPosition = je;
            function V(y, De) {
              var R = Math.max(y.start, De.start), Jt = Math.min(q(y), q(De));
              return R <= Jt ? U(R, Jt) : void 0;
            }
            e.textSpanIntersection = V;
            function B(y, De) {
              if (y < 0)
                throw new Error("start < 0");
              if (De < 0)
                throw new Error("length < 0");
              return { start: y, length: De };
            }
            e.createTextSpan = B;
            function U(y, De) {
              return B(y, De - y);
            }
            e.createTextSpanFromBounds = U;
            function m(y) {
              return B(y.span.start, y.newLength);
            }
            e.textChangeRangeNewSpan = m;
            function v(y) {
              return F(y.span) && y.newLength === 0;
            }
            e.textChangeRangeIsUnchanged = v;
            function g(y, De) {
              if (De < 0)
                throw new Error("newLength < 0");
              return { span: y, newLength: De };
            }
            e.createTextChangeRange = g, e.unchangedTextChangeRange = g(B(0, 0), 0);
            function O(y) {
              if (y.length === 0)
                return e.unchangedTextChangeRange;
              if (y.length === 1)
                return y[0];
              for (var De = y[0], R = De.span.start, Jt = q(De.span), Qt = R + De.newLength, qn = 1; qn < y.length; qn++) {
                var Ni = y[qn], _a = R, Ri = Jt, ca = Qt, $i = Ni.span.start, ra = q(Ni.span), Ea = $i + Ni.newLength;
                R = Math.min(_a, $i), Jt = Math.max(Ri, Ri + (ra - ca)), Qt = Math.max(Ea, Ea + (ca - ra));
              }
              return g(U(R, Jt), Qt - R);
            }
            e.collapseTextChangeRangesAcrossMultipleVersions = O;
            function S(y) {
              if (y && y.kind === 165) {
                for (var De = y; De; De = De.parent)
                  if (ur(De) || lr(De) || De.kind === 261)
                    return De;
              }
            }
            e.getTypeParameterOwner = S;
            function te(y, De) {
              return e.hasSyntacticModifier(y, 16476) && De.kind === 173;
            }
            e.isParameterPropertyDeclaration = te;
            function Je(y) {
              return Ot(y) ? e.every(y.elements, qe) : false;
            }
            e.isEmptyBindingPattern = Je;
            function qe(y) {
              return e.isOmittedExpression(y) ? true : Je(y.name);
            }
            e.isEmptyBindingElement = qe;
            function ge(y) {
              for (var De = y.parent; e.isBindingElement(De.parent); )
                De = De.parent.parent;
              return De.parent;
            }
            e.walkUpBindingElementsAndPatterns = ge;
            function ie(y, De) {
              e.isBindingElement(y) && (y = ge(y));
              var R = De(y);
              return y.kind === 257 && (y = y.parent), y && y.kind === 258 && (R |= De(y), y = y.parent), y && y.kind === 240 && (R |= De(y)), R;
            }
            function H(y) {
              return ie(y, e.getEffectiveModifierFlags);
            }
            e.getCombinedModifierFlags = H;
            function pe(y) {
              return ie(y, e.getEffectiveModifierFlagsAlwaysIncludeJSDoc);
            }
            e.getCombinedNodeFlagsAlwaysIncludeJSDoc = pe;
            function j(y) {
              return ie(y, function(De) {
                return De.flags;
              });
            }
            e.getCombinedNodeFlags = j, e.supportedLocaleDirectories = ["cs", "de", "es", "fr", "it", "ja", "ko", "pl", "pt-br", "ru", "tr", "zh-cn", "zh-tw"];
            function be(y, De, R) {
              var Jt = y.toLowerCase(), Qt = /^([a-z]+)([_\-]([a-z]+))?$/.exec(Jt);
              if (!Qt) {
                R && R.push(e.createCompilerDiagnostic(e.Diagnostics.Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1, "en", "ja-jp"));
                return;
              }
              var qn = Qt[1], Ni = Qt[3];
              e.contains(e.supportedLocaleDirectories, Jt) && !_a(qn, Ni, R) && _a(qn, void 0, R), e.setUILocale(y);
              function _a(Ri, ca, $i) {
                var ra = e.normalizePath(De.getExecutingFilePath()), Ea = e.getDirectoryPath(ra), Ui = e.combinePaths(Ea, Ri);
                if (ca && (Ui = Ui + "-" + ca), Ui = De.resolvePath(e.combinePaths(Ui, "diagnosticMessages.generated.json")), !De.fileExists(Ui))
                  return false;
                var ji = "";
                try {
                  ji = De.readFile(Ui);
                } catch {
                  return $i && $i.push(e.createCompilerDiagnostic(e.Diagnostics.Unable_to_open_file_0, Ui)), false;
                }
                try {
                  e.setLocalizedDiagnosticMessages(JSON.parse(ji));
                } catch {
                  return $i && $i.push(e.createCompilerDiagnostic(e.Diagnostics.Corrupted_locale_file_0, Ui)), false;
                }
                return true;
              }
            }
            e.validateLocaleAndSetLanguage = be;
            function Xe(y, De) {
              if (y)
                for (; y.original !== void 0; )
                  y = y.original;
              return !De || De(y) ? y : void 0;
            }
            e.getOriginalNode = Xe;
            function Re(y, De) {
              for (; y; ) {
                var R = De(y);
                if (R === "quit")
                  return;
                if (R)
                  return y;
                y = y.parent;
              }
            }
            e.findAncestor = Re;
            function Fe(y) {
              return (y.flags & 8) === 0;
            }
            e.isParseTreeNode = Fe;
            function dr(y, De) {
              if (y === void 0 || Fe(y))
                return y;
              for (y = y.original; y; ) {
                if (Fe(y))
                  return !De || De(y) ? y : void 0;
                y = y.original;
              }
            }
            e.getParseTreeNode = dr;
            function ze(y) {
              return y.length >= 2 && y.charCodeAt(0) === 95 && y.charCodeAt(1) === 95 ? "_" + y : y;
            }
            e.escapeLeadingUnderscores = ze;
            function ve(y) {
              var De = y;
              return De.length >= 3 && De.charCodeAt(0) === 95 && De.charCodeAt(1) === 95 && De.charCodeAt(2) === 95 ? De.substr(1) : De;
            }
            e.unescapeLeadingUnderscores = ve;
            function er(y) {
              return ve(y.escapedText);
            }
            e.idText = er;
            function ar(y) {
              return y.valueDeclaration && di(y.valueDeclaration) ? er(y.valueDeclaration.name) : ve(y.escapedName);
            }
            e.symbolName = ar;
            function Cr(y) {
              var De = y.parent.parent;
              if (De) {
                if (Ut(De))
                  return Ce(De);
                switch (De.kind) {
                  case 240:
                    if (De.declarationList && De.declarationList.declarations[0])
                      return Ce(De.declarationList.declarations[0]);
                    break;
                  case 241:
                    var R = De.expression;
                    switch (R.kind === 223 && R.operatorToken.kind === 63 && (R = R.left), R.kind) {
                      case 208:
                        return R.name;
                      case 209:
                        var Jt = R.argumentExpression;
                        if (e.isIdentifier(Jt))
                          return Jt;
                    }
                    break;
                  case 214:
                    return Ce(De.expression);
                  case 253: {
                    if (Ut(De.statement) || Bn(De.statement))
                      return Ce(De.statement);
                    break;
                  }
                }
              }
            }
            function Ce(y) {
              var De = we(y);
              return De && e.isIdentifier(De) ? De : void 0;
            }
            function $e(y, De) {
              return !!(X(y) && e.isIdentifier(y.name) && er(y.name) === er(De) || e.isVariableStatement(y) && e.some(y.declarationList.declarations, function(R) {
                return $e(R, De);
              }));
            }
            e.nodeHasName = $e;
            function gr(y) {
              return y.name || Cr(y);
            }
            e.getNameOfJSDocTypedef = gr;
            function X(y) {
              return !!y.name;
            }
            e.isNamedDeclaration = X;
            function Te(y) {
              switch (y.kind) {
                case 79:
                  return y;
                case 350:
                case 343: {
                  var De = y.name;
                  if (De.kind === 163)
                    return De.right;
                  break;
                }
                case 210:
                case 223: {
                  var R = y;
                  switch (e.getAssignmentDeclarationKind(R)) {
                    case 1:
                    case 4:
                    case 5:
                    case 3:
                      return e.getElementOrPropertyAccessArgumentExpressionOrName(R.left);
                    case 7:
                    case 8:
                    case 9:
                      return R.arguments[1];
                    default:
                      return;
                  }
                }
                case 348:
                  return gr(y);
                case 342:
                  return Cr(y);
                case 274: {
                  var Jt = y.expression;
                  return e.isIdentifier(Jt) ? Jt : void 0;
                }
                case 209:
                  var Qt = y;
                  if (e.isBindableStaticElementAccessExpression(Qt))
                    return Qt.argumentExpression;
              }
              return y.name;
            }
            e.getNonAssignedNameOfDeclaration = Te;
            function we(y) {
              if (y !== void 0)
                return Te(y) || (e.isFunctionExpression(y) || e.isArrowFunction(y) || e.isClassExpression(y) ? he(y) : void 0);
            }
            e.getNameOfDeclaration = we;
            function he(y) {
              if (y.parent) {
                if (e.isPropertyAssignment(y.parent) || e.isBindingElement(y.parent))
                  return y.parent.name;
                if (e.isBinaryExpression(y.parent) && y === y.parent.right) {
                  if (e.isIdentifier(y.parent.left))
                    return y.parent.left;
                  if (e.isAccessExpression(y.parent.left))
                    return e.getElementOrPropertyAccessArgumentExpressionOrName(y.parent.left);
                } else if (e.isVariableDeclaration(y.parent) && e.isIdentifier(y.parent.name))
                  return y.parent.name;
              } else
                return;
            }
            e.getAssignedName = he;
            function yr(y) {
              if (e.hasDecorators(y))
                return e.filter(y.modifiers, e.isDecorator);
            }
            e.getDecorators = yr;
            function kr(y) {
              if (e.hasSyntacticModifier(y, 126975))
                return e.filter(y.modifiers, dn);
            }
            e.getModifiers = kr;
            function nr(y, De) {
              if (y.name)
                if (e.isIdentifier(y.name)) {
                  var R = y.name.escapedText;
                  return vr(y.parent, De).filter(function(qn) {
                    return e.isJSDocParameterTag(qn) && e.isIdentifier(qn.name) && qn.name.escapedText === R;
                  });
                } else {
                  var Jt = y.parent.parameters.indexOf(y);
                  e.Debug.assert(Jt > -1, "Parameters should always be in their parents' parameter list");
                  var Qt = vr(y.parent, De).filter(e.isJSDocParameterTag);
                  if (Jt < Qt.length)
                    return [Qt[Jt]];
                }
              return e.emptyArray;
            }
            function tr(y) {
              return nr(y, false);
            }
            e.getJSDocParameterTags = tr;
            function Lr(y) {
              return nr(y, true);
            }
            e.getJSDocParameterTagsNoCache = Lr;
            function zr(y, De) {
              var R = y.name.escapedText;
              return vr(y.parent, De).filter(function(Jt) {
                return e.isJSDocTemplateTag(Jt) && Jt.typeParameters.some(function(Qt) {
                  return Qt.name.escapedText === R;
                });
              });
            }
            function ye(y) {
              return zr(y, false);
            }
            e.getJSDocTypeParameterTags = ye;
            function ir(y) {
              return zr(y, true);
            }
            e.getJSDocTypeParameterTagsNoCache = ir;
            function Dr(y) {
              return !!Mr(y, e.isJSDocParameterTag);
            }
            e.hasJSDocParameterTags = Dr;
            function Pr(y) {
              return Mr(y, e.isJSDocAugmentsTag);
            }
            e.getJSDocAugmentsTag = Pr;
            function Br(y) {
              return ot(y, e.isJSDocImplementsTag);
            }
            e.getJSDocImplementsTags = Br;
            function ut(y) {
              return Mr(y, e.isJSDocClassTag);
            }
            e.getJSDocClassTag = ut;
            function rt(y) {
              return Mr(y, e.isJSDocPublicTag);
            }
            e.getJSDocPublicTag = rt;
            function Z(y) {
              return Mr(y, e.isJSDocPublicTag, true);
            }
            e.getJSDocPublicTagNoCache = Z;
            function f(y) {
              return Mr(y, e.isJSDocPrivateTag);
            }
            e.getJSDocPrivateTag = f;
            function h(y) {
              return Mr(y, e.isJSDocPrivateTag, true);
            }
            e.getJSDocPrivateTagNoCache = h;
            function oe(y) {
              return Mr(y, e.isJSDocProtectedTag);
            }
            e.getJSDocProtectedTag = oe;
            function xr(y) {
              return Mr(y, e.isJSDocProtectedTag, true);
            }
            e.getJSDocProtectedTagNoCache = xr;
            function jr(y) {
              return Mr(y, e.isJSDocReadonlyTag);
            }
            e.getJSDocReadonlyTag = jr;
            function qr(y) {
              return Mr(y, e.isJSDocReadonlyTag, true);
            }
            e.getJSDocReadonlyTagNoCache = qr;
            function pt(y) {
              return Mr(y, e.isJSDocOverrideTag, true);
            }
            e.getJSDocOverrideTagNoCache = pt;
            function Ge(y) {
              return Mr(y, e.isJSDocDeprecatedTag);
            }
            e.getJSDocDeprecatedTag = Ge;
            function K(y) {
              return Mr(y, e.isJSDocDeprecatedTag, true);
            }
            e.getJSDocDeprecatedTagNoCache = K;
            function r(y) {
              return Mr(y, e.isJSDocEnumTag);
            }
            e.getJSDocEnumTag = r;
            function ct(y) {
              return Mr(y, e.isJSDocThisTag);
            }
            e.getJSDocThisTag = ct;
            function ft(y) {
              return Mr(y, e.isJSDocReturnTag);
            }
            e.getJSDocReturnTag = ft;
            function Ie(y) {
              return Mr(y, e.isJSDocTemplateTag);
            }
            e.getJSDocTemplateTag = Ie;
            function me(y) {
              var De = Mr(y, e.isJSDocTypeTag);
              if (De && De.typeExpression && De.typeExpression.type)
                return De;
            }
            e.getJSDocTypeTag = me;
            function xe(y) {
              var De = Mr(y, e.isJSDocTypeTag);
              return !De && e.isParameter(y) && (De = e.find(tr(y), function(R) {
                return !!R.typeExpression;
              })), De && De.typeExpression && De.typeExpression.type;
            }
            e.getJSDocType = xe;
            function Ye(y) {
              var De = ft(y);
              if (De && De.typeExpression)
                return De.typeExpression.type;
              var R = me(y);
              if (R && R.typeExpression) {
                var Jt = R.typeExpression.type;
                if (e.isTypeLiteralNode(Jt)) {
                  var Qt = e.find(Jt.members, e.isCallSignatureDeclaration);
                  return Qt && Qt.type;
                }
                if (e.isFunctionTypeNode(Jt) || e.isJSDocFunctionType(Jt))
                  return Jt.type;
              }
            }
            e.getJSDocReturnType = Ye;
            function vr(y, De) {
              var R = y.jsDocCache;
              if (R === void 0 || De) {
                var Jt = e.getJSDocCommentsAndTags(y, De);
                e.Debug.assert(Jt.length < 2 || Jt[0] !== Jt[1]), R = e.flatMap(Jt, function(Qt) {
                  return e.isJSDoc(Qt) ? Qt.tags : Qt;
                }), De || (y.jsDocCache = R);
              }
              return R;
            }
            function nt(y) {
              return vr(y, false);
            }
            e.getJSDocTags = nt;
            function pr(y) {
              return vr(y, true);
            }
            e.getJSDocTagsNoCache = pr;
            function Mr(y, De, R) {
              return e.find(vr(y, R), De);
            }
            function ot(y, De) {
              return nt(y).filter(De);
            }
            e.getAllJSDocTags = ot;
            function At(y, De) {
              return nt(y).filter(function(R) {
                return R.kind === De;
              });
            }
            e.getAllJSDocTagsOfKind = At;
            function re(y) {
              return typeof y == "string" ? y : y == null ? void 0 : y.map(function(De) {
                return De.kind === 324 ? De.text : de(De);
              }).join("");
            }
            e.getTextOfJSDocComment = re;
            function de(y) {
              var De = y.kind === 327 ? "link" : y.kind === 328 ? "linkcode" : "linkplain", R = y.name ? e.entityNameToString(y.name) : "", Jt = y.name && y.text.startsWith("://") ? "" : " ";
              return "{@".concat(De, " ").concat(R).concat(Jt).concat(y.text, "}");
            }
            function He(y) {
              if (e.isJSDocSignature(y))
                return e.emptyArray;
              if (e.isJSDocTypeAlias(y))
                return e.Debug.assert(y.parent.kind === 323), e.flatMap(y.parent.tags, function(Jt) {
                  return e.isJSDocTemplateTag(Jt) ? Jt.typeParameters : void 0;
                });
              if (y.typeParameters || e.canHaveIllegalTypeParameters(y) && y.typeParameters)
                return y.typeParameters;
              if (e.isInJSFile(y)) {
                var De = e.getJSDocTypeParameterDeclarations(y);
                if (De.length)
                  return De;
                var R = xe(y);
                if (R && e.isFunctionTypeNode(R) && R.typeParameters)
                  return R.typeParameters;
              }
              return e.emptyArray;
            }
            e.getEffectiveTypeParameterDeclarations = He;
            function Nr(y) {
              return y.constraint ? y.constraint : e.isJSDocTemplateTag(y.parent) && y === y.parent.typeParameters[0] ? y.parent.constraint : void 0;
            }
            e.getEffectiveConstraintOfTypeParameter = Nr;
            function Yr(y) {
              return y.kind === 79 || y.kind === 80;
            }
            e.isMemberName = Yr;
            function Ct(y) {
              return y.kind === 175 || y.kind === 174;
            }
            e.isGetOrSetAccessorDeclaration = Ct;
            function xt(y) {
              return e.isPropertyAccessExpression(y) && !!(y.flags & 32);
            }
            e.isPropertyAccessChain = xt;
            function Lt(y) {
              return e.isElementAccessExpression(y) && !!(y.flags & 32);
            }
            e.isElementAccessChain = Lt;
            function zt(y) {
              return e.isCallExpression(y) && !!(y.flags & 32);
            }
            e.isCallChain = zt;
            function Zt(y) {
              var De = y.kind;
              return !!(y.flags & 32) && (De === 208 || De === 209 || De === 210 || De === 232);
            }
            e.isOptionalChain = Zt;
            function mt(y) {
              return Zt(y) && !e.isNonNullExpression(y) && !!y.questionDotToken;
            }
            e.isOptionalChainRoot = mt;
            function at(y) {
              return mt(y.parent) && y.parent.expression === y;
            }
            e.isExpressionOfOptionalChainRoot = at;
            function k(y) {
              return !Zt(y.parent) || mt(y.parent) || y !== y.parent.expression;
            }
            e.isOutermostOptionalChain = k;
            function ue(y) {
              return y.kind === 223 && y.operatorToken.kind === 60;
            }
            e.isNullishCoalesce = ue;
            function Qe(y) {
              return e.isTypeReferenceNode(y) && e.isIdentifier(y.typeName) && y.typeName.escapedText === "const" && !y.typeArguments;
            }
            e.isConstTypeReference = Qe;
            function Sr(y) {
              return e.skipOuterExpressions(y, 8);
            }
            e.skipPartiallyEmittedExpressions = Sr;
            function Kr(y) {
              return e.isNonNullExpression(y) && !!(y.flags & 32);
            }
            e.isNonNullChain = Kr;
            function Hr(y) {
              return y.kind === 249 || y.kind === 248;
            }
            e.isBreakOrContinueStatement = Hr;
            function Dt(y) {
              return y.kind === 277 || y.kind === 276;
            }
            e.isNamedExportBindings = Dt;
            function Xt(y) {
              switch (y.kind) {
                case 305:
                case 306:
                  return true;
                default:
                  return false;
              }
            }
            e.isUnparsedTextLike = Xt;
            function cn(y) {
              return Xt(y) || y.kind === 303 || y.kind === 307;
            }
            e.isUnparsedNode = cn;
            function In(y) {
              return y.kind === 350 || y.kind === 343;
            }
            e.isJSDocPropertyLikeTag = In;
            function yn(y) {
              return hn(y.kind);
            }
            e.isNode = yn;
            function hn(y) {
              return y >= 163;
            }
            e.isNodeKind = hn;
            function ln(y) {
              return y >= 0 && y <= 162;
            }
            e.isTokenKind = ln;
            function En(y) {
              return ln(y.kind);
            }
            e.isToken = En;
            function Vt(y) {
              return e.hasProperty(y, "pos") && e.hasProperty(y, "end");
            }
            e.isNodeArray = Vt;
            function ui(y) {
              return 8 <= y && y <= 14;
            }
            e.isLiteralKind = ui;
            function ei(y) {
              return ui(y.kind);
            }
            e.isLiteralExpression = ei;
            function hi(y) {
              switch (y.kind) {
                case 207:
                case 206:
                case 13:
                case 215:
                case 228:
                  return true;
              }
              return false;
            }
            e.isLiteralExpressionOfObject = hi;
            function ri(y) {
              return 14 <= y && y <= 17;
            }
            e.isTemplateLiteralKind = ri;
            function vi(y) {
              return ri(y.kind);
            }
            e.isTemplateLiteralToken = vi;
            function Qn(y) {
              var De = y.kind;
              return De === 16 || De === 17;
            }
            e.isTemplateMiddleOrTemplateTail = Qn;
            function Yn(y) {
              return e.isImportSpecifier(y) || e.isExportSpecifier(y);
            }
            e.isImportOrExportSpecifier = Yn;
            function oi(y) {
              switch (y.kind) {
                case 273:
                case 278:
                  return y.isTypeOnly || y.parent.parent.isTypeOnly;
                case 271:
                  return y.parent.isTypeOnly;
                case 270:
                case 268:
                  return y.isTypeOnly;
                default:
                  return false;
              }
            }
            e.isTypeOnlyImportOrExportDeclaration = oi;
            function bi(y) {
              return e.isStringLiteral(y) || e.isIdentifier(y);
            }
            e.isAssertionKey = bi;
            function Dn(y) {
              return y.kind === 10 || ri(y.kind);
            }
            e.isStringTextContainingNode = Dn;
            function Kn(y) {
              return e.isIdentifier(y) && (y.autoGenerateFlags & 7) > 0;
            }
            e.isGeneratedIdentifier = Kn;
            function si(y) {
              return e.isPrivateIdentifier(y) && (y.autoGenerateFlags & 7) > 0;
            }
            e.isGeneratedPrivateIdentifier = si;
            function di(y) {
              return (e.isPropertyDeclaration(y) || dt(y)) && e.isPrivateIdentifier(y.name);
            }
            e.isPrivateIdentifierClassElementDeclaration = di;
            function Zn(y) {
              return e.isPropertyAccessExpression(y) && e.isPrivateIdentifier(y.name);
            }
            e.isPrivateIdentifierPropertyAccessExpression = Zn;
            function Fn(y) {
              switch (y) {
                case 126:
                case 127:
                case 132:
                case 85:
                case 136:
                case 88:
                case 93:
                case 101:
                case 123:
                case 121:
                case 122:
                case 146:
                case 124:
                case 145:
                case 161:
                  return true;
              }
              return false;
            }
            e.isModifierKind = Fn;
            function gt(y) {
              return !!(e.modifierToFlag(y) & 16476);
            }
            e.isParameterPropertyModifier = gt;
            function mi(y) {
              return gt(y) || y === 124 || y === 161 || y === 127;
            }
            e.isClassMemberModifier = mi;
            function dn(y) {
              return Fn(y.kind);
            }
            e.isModifier = dn;
            function On(y) {
              var De = y.kind;
              return De === 163 || De === 79;
            }
            e.isEntityName = On;
            function br(y) {
              var De = y.kind;
              return De === 79 || De === 80 || De === 10 || De === 8 || De === 164;
            }
            e.isPropertyName = br;
            function Ae(y) {
              var De = y.kind;
              return De === 79 || De === 203 || De === 204;
            }
            e.isBindingName = Ae;
            function ur(y) {
              return !!y && Le(y.kind);
            }
            e.isFunctionLike = ur;
            function L(y) {
              return !!y && (Le(y.kind) || e.isClassStaticBlockDeclaration(y));
            }
            e.isFunctionLikeOrClassStaticBlockDeclaration = L;
            function qt(y) {
              return y && fr(y.kind);
            }
            e.isFunctionLikeDeclaration = qt;
            function nn(y) {
              return y.kind === 110 || y.kind === 95;
            }
            e.isBooleanLiteral = nn;
            function fr(y) {
              switch (y) {
                case 259:
                case 171:
                case 173:
                case 174:
                case 175:
                case 215:
                case 216:
                  return true;
                default:
                  return false;
              }
            }
            function Le(y) {
              switch (y) {
                case 170:
                case 176:
                case 326:
                case 177:
                case 178:
                case 181:
                case 320:
                case 182:
                  return true;
                default:
                  return fr(y);
              }
            }
            e.isFunctionLikeKind = Le;
            function Ve(y) {
              return e.isSourceFile(y) || e.isModuleBlock(y) || e.isBlock(y) && ur(y.parent);
            }
            e.isFunctionOrModuleBlock = Ve;
            function _r(y) {
              var De = y.kind;
              return De === 173 || De === 169 || De === 171 || De === 174 || De === 175 || De === 178 || De === 172 || De === 237;
            }
            e.isClassElement = _r;
            function lr(y) {
              return y && (y.kind === 260 || y.kind === 228);
            }
            e.isClassLike = lr;
            function Vr(y) {
              return y && (y.kind === 174 || y.kind === 175);
            }
            e.isAccessor = Vr;
            function tt(y) {
              return e.isPropertyDeclaration(y) && e.hasAccessorModifier(y);
            }
            e.isAutoAccessorPropertyDeclaration = tt;
            function dt(y) {
              switch (y.kind) {
                case 171:
                case 174:
                case 175:
                  return true;
                default:
                  return false;
              }
            }
            e.isMethodOrAccessor = dt;
            function It(y) {
              switch (y.kind) {
                case 171:
                case 174:
                case 175:
                case 169:
                  return true;
                default:
                  return false;
              }
            }
            e.isNamedClassElement = It;
            function an(y) {
              return dn(y) || e.isDecorator(y);
            }
            e.isModifierLike = an;
            function sn(y) {
              var De = y.kind;
              return De === 177 || De === 176 || De === 168 || De === 170 || De === 178 || De === 174 || De === 175;
            }
            e.isTypeElement = sn;
            function _e(y) {
              return sn(y) || _r(y);
            }
            e.isClassOrTypeElement = _e;
            function Gr(y) {
              var De = y.kind;
              return De === 299 || De === 300 || De === 301 || De === 171 || De === 174 || De === 175;
            }
            e.isObjectLiteralElementLike = Gr;
            function Kt(y) {
              return e.isTypeNodeKind(y.kind);
            }
            e.isTypeNode = Kt;
            function en(y) {
              switch (y.kind) {
                case 181:
                case 182:
                  return true;
              }
              return false;
            }
            e.isFunctionOrConstructorTypeNode = en;
            function Ot(y) {
              if (y) {
                var De = y.kind;
                return De === 204 || De === 203;
              }
              return false;
            }
            e.isBindingPattern = Ot;
            function rr(y) {
              var De = y.kind;
              return De === 206 || De === 207;
            }
            e.isAssignmentPattern = rr;
            function Hn(y) {
              var De = y.kind;
              return De === 205 || De === 229;
            }
            e.isArrayBindingElement = Hn;
            function rn(y) {
              switch (y.kind) {
                case 257:
                case 166:
                case 205:
                  return true;
              }
              return false;
            }
            e.isDeclarationBindingElement = rn;
            function xn(y) {
              return Mn(y) || kn(y);
            }
            e.isBindingOrAssignmentPattern = xn;
            function Mn(y) {
              switch (y.kind) {
                case 203:
                case 207:
                  return true;
              }
              return false;
            }
            e.isObjectBindingOrAssignmentPattern = Mn;
            function Rn(y) {
              switch (y.kind) {
                case 205:
                case 299:
                case 300:
                case 301:
                  return true;
              }
              return false;
            }
            e.isObjectBindingOrAssignmentElement = Rn;
            function kn(y) {
              switch (y.kind) {
                case 204:
                case 206:
                  return true;
              }
              return false;
            }
            e.isArrayBindingOrAssignmentPattern = kn;
            function on(y) {
              var De = y.kind;
              return De === 208 || De === 163 || De === 202;
            }
            e.isPropertyAccessOrQualifiedNameOrImportTypeNode = on;
            function Xr(y) {
              var De = y.kind;
              return De === 208 || De === 163;
            }
            e.isPropertyAccessOrQualifiedName = Xr;
            function wr(y) {
              switch (y.kind) {
                case 283:
                case 282:
                case 210:
                case 211:
                case 212:
                case 167:
                  return true;
                default:
                  return false;
              }
            }
            e.isCallLikeExpression = wr;
            function fn(y) {
              return y.kind === 210 || y.kind === 211;
            }
            e.isCallOrNewExpression = fn;
            function mn(y) {
              var De = y.kind;
              return De === 225 || De === 14;
            }
            e.isTemplateLiteral = mn;
            function Mi(y) {
              return An(Sr(y).kind);
            }
            e.isLeftHandSideExpression = Mi;
            function An(y) {
              switch (y) {
                case 208:
                case 209:
                case 211:
                case 210:
                case 281:
                case 282:
                case 285:
                case 212:
                case 206:
                case 214:
                case 207:
                case 228:
                case 215:
                case 79:
                case 80:
                case 13:
                case 8:
                case 9:
                case 10:
                case 14:
                case 225:
                case 95:
                case 104:
                case 108:
                case 110:
                case 106:
                case 232:
                case 230:
                case 233:
                case 100:
                  return true;
                default:
                  return false;
              }
            }
            function xi(y) {
              return ti(Sr(y).kind);
            }
            e.isUnaryExpression = xi;
            function ti(y) {
              switch (y) {
                case 221:
                case 222:
                case 217:
                case 218:
                case 219:
                case 220:
                case 213:
                  return true;
                default:
                  return An(y);
              }
            }
            function li(y) {
              switch (y.kind) {
                case 222:
                  return true;
                case 221:
                  return y.operator === 45 || y.operator === 46;
                default:
                  return false;
              }
            }
            e.isUnaryExpressionWithWrite = li;
            function Bn(y) {
              return vn(Sr(y).kind);
            }
            e.isExpression = Bn;
            function vn(y) {
              switch (y) {
                case 224:
                case 226:
                case 216:
                case 223:
                case 227:
                case 231:
                case 229:
                case 354:
                case 353:
                case 235:
                  return true;
                default:
                  return ti(y);
              }
            }
            function Ue(y) {
              var De = y.kind;
              return De === 213 || De === 231;
            }
            e.isAssertionExpression = Ue;
            function Vn(y) {
              return e.isNotEmittedStatement(y) || e.isPartiallyEmittedExpression(y);
            }
            e.isNotEmittedOrPartiallyEmittedNode = Vn;
            function Ei(y, De) {
              switch (y.kind) {
                case 245:
                case 246:
                case 247:
                case 243:
                case 244:
                  return true;
                case 253:
                  return De && Ei(y.statement, De);
              }
              return false;
            }
            e.isIterationStatement = Ei;
            function ni(y) {
              return e.isExportAssignment(y) || e.isExportDeclaration(y);
            }
            e.isScopeMarker = ni;
            function Fi(y) {
              return e.some(y, ni);
            }
            e.hasScopeMarker = Fi;
            function Tn(y) {
              return !e.isAnyImportOrReExport(y) && !e.isExportAssignment(y) && !e.hasSyntacticModifier(y, 1) && !e.isAmbientModule(y);
            }
            e.needsScopeMarker = Tn;
            function jn(y) {
              return e.isAnyImportOrReExport(y) || e.isExportAssignment(y) || e.hasSyntacticModifier(y, 1);
            }
            e.isExternalModuleIndicator = jn;
            function Ti(y) {
              return y.kind === 246 || y.kind === 247;
            }
            e.isForInOrOfStatement = Ti;
            function Si(y) {
              return e.isBlock(y) || Bn(y);
            }
            e.isConciseBody = Si;
            function C(y) {
              return e.isBlock(y);
            }
            e.isFunctionBody = C;
            function W(y) {
              return e.isVariableDeclarationList(y) || Bn(y);
            }
            e.isForInitializer = W;
            function ee(y) {
              var De = y.kind;
              return De === 265 || De === 264 || De === 79;
            }
            e.isModuleBody = ee;
            function le(y) {
              var De = y.kind;
              return De === 265 || De === 264;
            }
            e.isNamespaceBody = le;
            function Ze(y) {
              var De = y.kind;
              return De === 79 || De === 264;
            }
            e.isJSDocNamespaceBody = Ze;
            function Ir(y) {
              var De = y.kind;
              return De === 272 || De === 271;
            }
            e.isNamedImportBindings = Ir;
            function Ar(y) {
              return y.kind === 264 || y.kind === 263;
            }
            e.isModuleOrEnumDeclaration = Ar;
            function hr(y) {
              return y === 216 || y === 205 || y === 260 || y === 228 || y === 172 || y === 173 || y === 263 || y === 302 || y === 278 || y === 259 || y === 215 || y === 174 || y === 270 || y === 268 || y === 273 || y === 261 || y === 288 || y === 171 || y === 170 || y === 264 || y === 267 || y === 271 || y === 277 || y === 166 || y === 299 || y === 169 || y === 168 || y === 175 || y === 300 || y === 262 || y === 165 || y === 257 || y === 348 || y === 341 || y === 350;
            }
            function yt(y) {
              return y === 259 || y === 279 || y === 260 || y === 261 || y === 262 || y === 263 || y === 264 || y === 269 || y === 268 || y === 275 || y === 274 || y === 267;
            }
            function Pt(y) {
              return y === 249 || y === 248 || y === 256 || y === 243 || y === 241 || y === 239 || y === 246 || y === 247 || y === 245 || y === 242 || y === 253 || y === 250 || y === 252 || y === 254 || y === 255 || y === 240 || y === 244 || y === 251 || y === 352 || y === 356 || y === 355;
            }
            function Ut(y) {
              return y.kind === 165 ? y.parent && y.parent.kind !== 347 || e.isInJSFile(y) : hr(y.kind);
            }
            e.isDeclaration = Ut;
            function jt(y) {
              return yt(y.kind);
            }
            e.isDeclarationStatement = jt;
            function Ht(y) {
              return Pt(y.kind);
            }
            e.isStatementButNotDeclaration = Ht;
            function gi(y) {
              var De = y.kind;
              return Pt(De) || yt(De) || Pi(y);
            }
            e.isStatement = gi;
            function Pi(y) {
              return y.kind !== 238 || y.parent !== void 0 && (y.parent.kind === 255 || y.parent.kind === 295) ? false : !e.isFunctionBlock(y);
            }
            function Gn(y) {
              var De = y.kind;
              return Pt(De) || yt(De) || De === 238;
            }
            e.isStatementOrBlock = Gn;
            function Bi(y) {
              var De = y.kind;
              return De === 280 || De === 163 || De === 79;
            }
            e.isModuleReference = Bi;
            function oa(y) {
              var De = y.kind;
              return De === 108 || De === 79 || De === 208;
            }
            e.isJsxTagNameExpression = oa;
            function Zi(y) {
              var De = y.kind;
              return De === 281 || De === 291 || De === 282 || De === 11 || De === 285;
            }
            e.isJsxChild = Zi;
            function Ki(y) {
              var De = y.kind;
              return De === 288 || De === 290;
            }
            e.isJsxAttributeLike = Ki;
            function qi(y) {
              var De = y.kind;
              return De === 10 || De === 291;
            }
            e.isStringLiteralOrJsxExpression = qi;
            function Hi(y) {
              var De = y.kind;
              return De === 283 || De === 282;
            }
            e.isJsxOpeningLikeElement = Hi;
            function Gi(y) {
              var De = y.kind;
              return De === 292 || De === 293;
            }
            e.isCaseOrDefaultClause = Gi;
            function da(y) {
              return y.kind >= 312 && y.kind <= 350;
            }
            e.isJSDocNode = da;
            function Jn(y) {
              return y.kind === 323 || y.kind === 322 || y.kind === 324 || tn(y) || ea(y) || e.isJSDocTypeLiteral(y) || e.isJSDocSignature(y);
            }
            e.isJSDocCommentContainingNode = Jn;
            function ea(y) {
              return y.kind >= 330 && y.kind <= 350;
            }
            e.isJSDocTag = ea;
            function Xi(y) {
              return y.kind === 175;
            }
            e.isSetAccessor = Xi;
            function sa(y) {
              return y.kind === 174;
            }
            e.isGetAccessor = sa;
            function Li(y) {
              var De = y.jsDoc;
              return !!De && De.length > 0;
            }
            e.hasJSDocNodes = Li;
            function p(y) {
              return !!y.type;
            }
            e.hasType = p;
            function ne(y) {
              return !!y.initializer;
            }
            e.hasInitializer = ne;
            function Ne(y) {
              switch (y.kind) {
                case 257:
                case 166:
                case 205:
                case 169:
                case 299:
                case 302:
                  return true;
                default:
                  return false;
              }
            }
            e.hasOnlyExpressionInitializer = Ne;
            function or(y) {
              return y.kind === 288 || y.kind === 290 || Gr(y);
            }
            e.isObjectLiteralElement = or;
            function it2(y) {
              return y.kind === 180 || y.kind === 230;
            }
            e.isTypeReferenceType = it2;
            var vt = 1073741823;
            function Tt(y) {
              for (var De = vt, R = 0, Jt = y; R < Jt.length; R++) {
                var Qt = Jt[R];
                if (Qt.length) {
                  for (var qn = 0; qn < Qt.length && qn < De && e.isWhiteSpaceLike(Qt.charCodeAt(qn)); qn++)
                    ;
                  if (qn < De && (De = qn), De === 0)
                    return 0;
                }
              }
              return De === vt ? void 0 : De;
            }
            e.guessIndentation = Tt;
            function St(y) {
              return y.kind === 10 || y.kind === 14;
            }
            e.isStringLiteralLike = St;
            function tn(y) {
              return y.kind === 327 || y.kind === 328 || y.kind === 329;
            }
            e.isJSDocLinkLike = tn;
            function Mt(y) {
              var De = e.lastOrUndefined(y.parameters);
              return !!De && $t(De);
            }
            e.hasRestParameter = Mt;
            function $t(y) {
              var De = e.isJSDocParameterTag(y) ? y.typeExpression && y.typeExpression.type : y.type;
              return y.dotDotDotToken !== void 0 || !!De && De.kind === 321;
            }
            e.isRestParameter = $t;
          })(N || (N = {}));
          var N;
          (function(e) {
            e.resolvingEmptyArray = [], e.externalHelpersModuleNameText = "tslib", e.defaultMaximumTruncationLength = 160, e.noTruncationMaximumTruncationLength = 1e6;
            function t3(n, c) {
              var x = n.declarations;
              if (x)
                for (var G = 0, Oe = x; G < Oe.length; G++) {
                  var mr = Oe[G];
                  if (mr.kind === c)
                    return mr;
                }
            }
            e.getDeclarationOfKind = t3;
            function w(n, c) {
              return e.filter(n.declarations || e.emptyArray, function(x) {
                return x.kind === c;
              });
            }
            e.getDeclarationsOfKind = w;
            function s(n) {
              var c = new e.Map();
              if (n)
                for (var x = 0, G = n; x < G.length; x++) {
                  var Oe = G[x];
                  c.set(Oe.escapedName, Oe);
                }
              return c;
            }
            e.createSymbolTable = s;
            function q(n) {
              return (n.flags & 33554432) !== 0;
            }
            e.isTransientSymbol = q;
            var F = fe();
            function fe() {
              var n = "", c = function(x) {
                return n += x;
              };
              return { getText: function() {
                return n;
              }, write: c, rawWrite: c, writeKeyword: c, writeOperator: c, writePunctuation: c, writeSpace: c, writeStringLiteral: c, writeLiteral: c, writeParameter: c, writeProperty: c, writeSymbol: function(x, G) {
                return c(x);
              }, writeTrailingSemicolon: c, writeComment: c, getTextPos: function() {
                return n.length;
              }, getLine: function() {
                return 0;
              }, getColumn: function() {
                return 0;
              }, getIndent: function() {
                return 0;
              }, isAtStartOfLine: function() {
                return false;
              }, hasTrailingComment: function() {
                return false;
              }, hasTrailingWhitespace: function() {
                return !!n.length && e.isWhiteSpaceLike(n.charCodeAt(n.length - 1));
              }, writeLine: function() {
                return n += " ";
              }, increaseIndent: e.noop, decreaseIndent: e.noop, clear: function() {
                return n = "";
              }, trackSymbol: function() {
                return false;
              }, reportInaccessibleThisError: e.noop, reportInaccessibleUniqueSymbolError: e.noop, reportPrivateInBaseOfClassExpression: e.noop };
            }
            function Ee(n, c) {
              return n.configFilePath !== c.configFilePath || Se(n, c);
            }
            e.changesAffectModuleResolution = Ee;
            function Se(n, c) {
              return se(n, c, e.moduleResolutionOptionDeclarations);
            }
            e.optionsHaveModuleResolutionChanges = Se;
            function J(n, c) {
              return se(n, c, e.optionsAffectingProgramStructure);
            }
            e.changesAffectingProgramStructure = J;
            function se(n, c, x) {
              return n !== c && x.some(function(G) {
                return !Hl($r(n, G), $r(c, G));
              });
            }
            e.optionsHaveChanges = se;
            function Me(n, c) {
              for (; ; ) {
                var x = c(n);
                if (x === "quit")
                  return;
                if (x !== void 0)
                  return x;
                if (e.isSourceFile(n))
                  return;
                n = n.parent;
              }
            }
            e.forEachAncestor = Me;
            function Q(n, c) {
              for (var x = n.entries(), G = x.next(); !G.done; G = x.next()) {
                var Oe = G.value, mr = Oe[0], Tr = Oe[1], Qr = c(Tr, mr);
                if (Qr)
                  return Qr;
              }
            }
            e.forEachEntry = Q;
            function Be(n, c) {
              for (var x = n.keys(), G = x.next(); !G.done; G = x.next()) {
                var Oe = c(G.value);
                if (Oe)
                  return Oe;
              }
            }
            e.forEachKey = Be;
            function je(n, c) {
              n.forEach(function(x, G) {
                c.set(G, x);
              });
            }
            e.copyEntries = je;
            function V(n) {
              var c = F.getText();
              try {
                return n(F), F.getText();
              } finally {
                F.clear(), F.writeKeyword(c);
              }
            }
            e.usingSingleLineStringWriter = V;
            function B(n) {
              return n.end - n.pos;
            }
            e.getFullWidth = B;
            function U(n, c, x) {
              return n && n.resolvedModules && n.resolvedModules.get(c, x);
            }
            e.getResolvedModule = U;
            function m(n, c, x, G) {
              n.resolvedModules || (n.resolvedModules = e.createModeAwareCache()), n.resolvedModules.set(c, G, x);
            }
            e.setResolvedModule = m;
            function v(n, c, x) {
              n.resolvedTypeReferenceDirectiveNames || (n.resolvedTypeReferenceDirectiveNames = e.createModeAwareCache()), n.resolvedTypeReferenceDirectiveNames.set(c, void 0, x);
            }
            e.setResolvedTypeReferenceDirective = v;
            function g(n, c) {
              return n.path === c.path && !n.prepend == !c.prepend && !n.circular == !c.circular;
            }
            e.projectReferenceIsEqualTo = g;
            function O(n, c) {
              return n.isExternalLibraryImport === c.isExternalLibraryImport && n.extension === c.extension && n.resolvedFileName === c.resolvedFileName && n.originalPath === c.originalPath && S(n.packageId, c.packageId);
            }
            e.moduleResolutionIsEqualTo = O;
            function S(n, c) {
              return n === c || !!n && !!c && n.name === c.name && n.subModuleName === c.subModuleName && n.version === c.version;
            }
            function te(n) {
              var c = n.name, x = n.subModuleName;
              return x ? "".concat(c, "/").concat(x) : c;
            }
            e.packageIdToPackageName = te;
            function Je(n) {
              return "".concat(te(n), "@").concat(n.version);
            }
            e.packageIdToString = Je;
            function qe(n, c) {
              return n.resolvedFileName === c.resolvedFileName && n.primary === c.primary && n.originalPath === c.originalPath;
            }
            e.typeDirectiveIsEqualTo = qe;
            function ge(n, c, x, G, Oe) {
              e.Debug.assert(n.length === c.length);
              for (var mr = 0; mr < n.length; mr++) {
                var Tr = c[mr], Qr = n[mr], bt = e.isString(Qr) ? Qr : Qr.fileName.toLowerCase(), lt = e.isString(Qr) ? G && e.getModeForResolutionAtIndex(G, mr) : e.getModeForFileReference(Qr, G == null ? void 0 : G.impliedNodeFormat), Yt = x && x.get(bt, lt), gn = Yt ? !Tr || !Oe(Yt, Tr) : Tr;
                if (gn)
                  return true;
              }
              return false;
            }
            e.hasChangesInResolutions = ge;
            function ie(n) {
              return H(n), (n.flags & 524288) !== 0;
            }
            e.containsParseError = ie;
            function H(n) {
              if (!(n.flags & 1048576)) {
                var c = (n.flags & 131072) !== 0 || e.forEachChild(n, ie);
                c && (n.flags |= 524288), n.flags |= 1048576;
              }
            }
            function pe(n) {
              for (; n && n.kind !== 308; )
                n = n.parent;
              return n;
            }
            e.getSourceFileOfNode = pe;
            function j(n) {
              return pe(n.valueDeclaration || Ye(n));
            }
            e.getSourceFileOfModule = j;
            function be(n, c) {
              return !!n && (n.scriptKind === 1 || n.scriptKind === 2) && !n.checkJsDirective && c === void 0;
            }
            e.isPlainJsFile = be;
            function Xe(n) {
              switch (n.kind) {
                case 238:
                case 266:
                case 245:
                case 246:
                case 247:
                  return true;
              }
              return false;
            }
            e.isStatementWithLocals = Xe;
            function Re(n, c) {
              return e.Debug.assert(n >= 0), e.getLineStarts(c)[n];
            }
            e.getStartPositionOfLine = Re;
            function Fe(n) {
              var c = pe(n), x = e.getLineAndCharacterOfPosition(c, n.pos);
              return "".concat(c.fileName, "(").concat(x.line + 1, ",").concat(x.character + 1, ")");
            }
            e.nodePosToString = Fe;
            function dr(n, c) {
              e.Debug.assert(n >= 0);
              var x = e.getLineStarts(c), G = n, Oe = c.text;
              if (G + 1 === x.length)
                return Oe.length - 1;
              var mr = x[G], Tr = x[G + 1] - 1;
              for (e.Debug.assert(e.isLineBreak(Oe.charCodeAt(Tr))); mr <= Tr && e.isLineBreak(Oe.charCodeAt(Tr)); )
                Tr--;
              return Tr;
            }
            e.getEndLinePosition = dr;
            function ze(n, c, x) {
              return !(x && x(c)) && !n.identifiers.has(c);
            }
            e.isFileLevelUniqueName = ze;
            function ve(n) {
              return n === void 0 ? true : n.pos === n.end && n.pos >= 0 && n.kind !== 1;
            }
            e.nodeIsMissing = ve;
            function er(n) {
              return !ve(n);
            }
            e.nodeIsPresent = er;
            function ar(n, c, x) {
              if (c === void 0 || c.length === 0)
                return n;
              for (var G = 0; G < n.length && x(n[G]); ++G)
                ;
              return n.splice.apply(n, D([G, 0], c, false)), n;
            }
            function Cr(n, c, x) {
              if (c === void 0)
                return n;
              for (var G = 0; G < n.length && x(n[G]); ++G)
                ;
              return n.splice(G, 0, c), n;
            }
            function Ce(n) {
              return Dn(n) || !!(Br(n) & 1048576);
            }
            function $e(n, c) {
              return ar(n, c, Dn);
            }
            e.insertStatementsAfterStandardPrologue = $e;
            function gr(n, c) {
              return ar(n, c, Ce);
            }
            e.insertStatementsAfterCustomPrologue = gr;
            function X(n, c) {
              return Cr(n, c, Dn);
            }
            e.insertStatementAfterStandardPrologue = X;
            function Te(n, c) {
              return Cr(n, c, Ce);
            }
            e.insertStatementAfterCustomPrologue = Te;
            function we(n, c, x) {
              if (n.charCodeAt(c + 1) === 47 && c + 2 < x && n.charCodeAt(c + 2) === 47) {
                var G = n.substring(c, x);
                return !!(e.fullTripleSlashReferencePathRegEx.test(G) || e.fullTripleSlashAMDReferencePathRegEx.test(G) || mi.test(G) || dn.test(G));
              }
              return false;
            }
            e.isRecognizedTripleSlashComment = we;
            function he(n, c) {
              return n.charCodeAt(c + 1) === 42 && n.charCodeAt(c + 2) === 33;
            }
            e.isPinnedComment = he;
            function yr(n, c) {
              var x = new e.Map(c.map(function(Tr) {
                return ["".concat(e.getLineAndCharacterOfPosition(n, Tr.range.end).line), Tr];
              })), G = new e.Map();
              return { getUnusedExpectations: Oe, markUsed: mr };
              function Oe() {
                return e.arrayFrom(x.entries()).filter(function(Tr) {
                  var Qr = Tr[0], bt = Tr[1];
                  return bt.type === 0 && !G.get(Qr);
                }).map(function(Tr) {
                  var Qr = Tr[0], bt = Tr[1];
                  return bt;
                });
              }
              function mr(Tr) {
                return x.has("".concat(Tr)) ? (G.set("".concat(Tr), true), true) : false;
              }
            }
            e.createCommentDirectivesMap = yr;
            function kr(n, c, x) {
              return ve(n) ? n.pos : e.isJSDocNode(n) || n.kind === 11 ? e.skipTrivia((c || pe(n)).text, n.pos, false, true) : x && e.hasJSDocNodes(n) ? kr(n.jsDoc[0], c) : n.kind === 351 && n._children.length > 0 ? kr(n._children[0], c, x) : e.skipTrivia((c || pe(n)).text, n.pos, false, false, Ut(n));
            }
            e.getTokenPosOfNode = kr;
            function nr(n, c) {
              var x = !ve(n) && e.canHaveModifiers(n) ? e.findLast(n.modifiers, e.isDecorator) : void 0;
              return x ? e.skipTrivia((c || pe(n)).text, x.end) : kr(n, c);
            }
            e.getNonDecoratorTokenPosOfNode = nr;
            function tr(n, c, x) {
              return x === void 0 && (x = false), ye(n.text, c, x);
            }
            e.getSourceTextOfNodeFromSourceFile = tr;
            function Lr(n) {
              return !!e.findAncestor(n, e.isJSDocTypeExpression);
            }
            function zr(n) {
              return !!(e.isExportDeclaration(n) && n.exportClause && e.isNamespaceExport(n.exportClause) && n.exportClause.name.escapedText === "default");
            }
            e.isExportNamespaceAsDefaultDeclaration = zr;
            function ye(n, c, x) {
              if (x === void 0 && (x = false), ve(c))
                return "";
              var G = n.substring(x ? c.pos : e.skipTrivia(n, c.pos), c.end);
              return Lr(c) && (G = G.split(/\r\n|\n|\r/).map(function(Oe) {
                return e.trimStringStart(Oe.replace(/^\s*\*/, ""));
              }).join(`
`)), G;
            }
            e.getTextOfNodeFromSourceText = ye;
            function ir(n, c) {
              return c === void 0 && (c = false), tr(pe(n), n, c);
            }
            e.getTextOfNode = ir;
            function Dr(n) {
              return n.pos;
            }
            function Pr(n, c) {
              return e.binarySearch(n, c, Dr, e.compareValues);
            }
            e.indexOfNode = Pr;
            function Br(n) {
              var c = n.emitNode;
              return c && c.flags || 0;
            }
            e.getEmitFlags = Br;
            function ut() {
              return { es2015: { Array: ["find", "findIndex", "fill", "copyWithin", "entries", "keys", "values"], RegExp: ["flags", "sticky", "unicode"], Reflect: ["apply", "construct", "defineProperty", "deleteProperty", "get", " getOwnPropertyDescriptor", "getPrototypeOf", "has", "isExtensible", "ownKeys", "preventExtensions", "set", "setPrototypeOf"], ArrayConstructor: ["from", "of"], ObjectConstructor: ["assign", "getOwnPropertySymbols", "keys", "is", "setPrototypeOf"], NumberConstructor: ["isFinite", "isInteger", "isNaN", "isSafeInteger", "parseFloat", "parseInt"], Math: ["clz32", "imul", "sign", "log10", "log2", "log1p", "expm1", "cosh", "sinh", "tanh", "acosh", "asinh", "atanh", "hypot", "trunc", "fround", "cbrt"], Map: ["entries", "keys", "values"], Set: ["entries", "keys", "values"], Promise: e.emptyArray, PromiseConstructor: ["all", "race", "reject", "resolve"], Symbol: ["for", "keyFor"], WeakMap: ["entries", "keys", "values"], WeakSet: ["entries", "keys", "values"], Iterator: e.emptyArray, AsyncIterator: e.emptyArray, String: ["codePointAt", "includes", "endsWith", "normalize", "repeat", "startsWith", "anchor", "big", "blink", "bold", "fixed", "fontcolor", "fontsize", "italics", "link", "small", "strike", "sub", "sup"], StringConstructor: ["fromCodePoint", "raw"] }, es2016: { Array: ["includes"] }, es2017: { Atomics: e.emptyArray, SharedArrayBuffer: e.emptyArray, String: ["padStart", "padEnd"], ObjectConstructor: ["values", "entries", "getOwnPropertyDescriptors"], DateTimeFormat: ["formatToParts"] }, es2018: { Promise: ["finally"], RegExpMatchArray: ["groups"], RegExpExecArray: ["groups"], RegExp: ["dotAll"], Intl: ["PluralRules"], AsyncIterable: e.emptyArray, AsyncIterableIterator: e.emptyArray, AsyncGenerator: e.emptyArray, AsyncGeneratorFunction: e.emptyArray, NumberFormat: ["formatToParts"] }, es2019: { Array: ["flat", "flatMap"], ObjectConstructor: ["fromEntries"], String: ["trimStart", "trimEnd", "trimLeft", "trimRight"], Symbol: ["description"] }, es2020: { BigInt: e.emptyArray, BigInt64Array: e.emptyArray, BigUint64Array: e.emptyArray, PromiseConstructor: ["allSettled"], SymbolConstructor: ["matchAll"], String: ["matchAll"], DataView: ["setBigInt64", "setBigUint64", "getBigInt64", "getBigUint64"], RelativeTimeFormat: ["format", "formatToParts", "resolvedOptions"] }, es2021: { PromiseConstructor: ["any"], String: ["replaceAll"] }, es2022: { Array: ["at"], String: ["at"], Int8Array: ["at"], Uint8Array: ["at"], Uint8ClampedArray: ["at"], Int16Array: ["at"], Uint16Array: ["at"], Int32Array: ["at"], Uint32Array: ["at"], Float32Array: ["at"], Float64Array: ["at"], BigInt64Array: ["at"], BigUint64Array: ["at"], ObjectConstructor: ["hasOwn"], Error: ["cause"] } };
            }
            e.getScriptTargetFeatures = ut;
            var rt;
            (function(n) {
              n[n.None = 0] = "None", n[n.NeverAsciiEscape = 1] = "NeverAsciiEscape", n[n.JsxAttributeEscape = 2] = "JsxAttributeEscape", n[n.TerminateUnterminatedLiterals = 4] = "TerminateUnterminatedLiterals", n[n.AllowNumericSeparator = 8] = "AllowNumericSeparator";
            })(rt = e.GetLiteralTextFlags || (e.GetLiteralTextFlags = {}));
            function Z(n, c, x) {
              var G;
              if (c && f(n, x))
                return tr(c, n);
              switch (n.kind) {
                case 10: {
                  var Oe = x & 2 ? K_ : x & 1 || Br(n) & 16777216 ? Lo : _o;
                  return n.singleQuote ? "'" + Oe(n.text, 39) + "'" : '"' + Oe(n.text, 34) + '"';
                }
                case 14:
                case 15:
                case 16:
                case 17: {
                  var Oe = x & 1 || Br(n) & 16777216 ? Lo : _o, mr = (G = n.rawText) !== null && G !== void 0 ? G : F_(Oe(n.text, 96));
                  switch (n.kind) {
                    case 14:
                      return "`" + mr + "`";
                    case 15:
                      return "`" + mr + "${";
                    case 16:
                      return "}" + mr + "${";
                    case 17:
                      return "}" + mr + "`";
                  }
                  break;
                }
                case 8:
                case 9:
                  return n.text;
                case 13:
                  return x & 4 && n.isUnterminated ? n.text + (n.text.charCodeAt(n.text.length - 1) === 92 ? " /" : "/") : n.text;
              }
              return e.Debug.fail("Literal kind '".concat(n.kind, "' not accounted for."));
            }
            e.getLiteralText = Z;
            function f(n, c) {
              return Sa(n) || !n.parent || c & 4 && n.isUnterminated ? false : e.isNumericLiteral(n) && n.numericLiteralFlags & 512 ? !!(c & 8) : !e.isBigIntLiteral(n);
            }
            function h(n) {
              return e.isString(n) ? '"' + _o(n) + '"' : "" + n;
            }
            e.getTextOfConstantValue = h;
            function oe(n) {
              return e.getBaseFileName(n).replace(/^(\d)/, "_$1").replace(/\W/g, "_");
            }
            e.makeIdentifierFromModuleName = oe;
            function xr(n) {
              return (e.getCombinedNodeFlags(n) & 3) !== 0 || jr(n);
            }
            e.isBlockOrCatchScoped = xr;
            function jr(n) {
              var c = ua(n);
              return c.kind === 257 && c.parent.kind === 295;
            }
            e.isCatchClauseVariableDeclarationOrBindingElement = jr;
            function qr(n) {
              return e.isModuleDeclaration(n) && (n.name.kind === 10 || Ie(n));
            }
            e.isAmbientModule = qr;
            function pt(n) {
              return e.isModuleDeclaration(n) && n.name.kind === 10;
            }
            e.isModuleWithStringLiteralName = pt;
            function Ge(n) {
              return e.isModuleDeclaration(n) && e.isStringLiteral(n.name);
            }
            e.isNonGlobalAmbientModule = Ge;
            function K(n) {
              return e.isModuleDeclaration(n) || e.isIdentifier(n);
            }
            e.isEffectiveModuleDeclaration = K;
            function r(n) {
              return ct(n.valueDeclaration);
            }
            e.isShorthandAmbientModuleSymbol = r;
            function ct(n) {
              return !!n && n.kind === 264 && !n.body;
            }
            function ft(n) {
              return n.kind === 308 || n.kind === 264 || e.isFunctionLikeOrClassStaticBlockDeclaration(n);
            }
            e.isBlockScopedContainerTopLevel = ft;
            function Ie(n) {
              return !!(n.flags & 1024);
            }
            e.isGlobalScopeAugmentation = Ie;
            function me(n) {
              return qr(n) && xe(n);
            }
            e.isExternalModuleAugmentation = me;
            function xe(n) {
              switch (n.parent.kind) {
                case 308:
                  return e.isExternalModule(n.parent);
                case 265:
                  return qr(n.parent.parent) && e.isSourceFile(n.parent.parent.parent) && !e.isExternalModule(n.parent.parent.parent);
              }
              return false;
            }
            e.isModuleAugmentationExternal = xe;
            function Ye(n) {
              var c;
              return (c = n.declarations) === null || c === void 0 ? void 0 : c.find(function(x) {
                return !me(x) && !(e.isModuleDeclaration(x) && Ie(x));
              });
            }
            e.getNonAugmentationDeclaration = Ye;
            function vr(n) {
              return n === e.ModuleKind.CommonJS || n === e.ModuleKind.Node16 || n === e.ModuleKind.NodeNext;
            }
            function nt(n, c) {
              return e.isExternalModule(n) || c.isolatedModules || vr(Vi(c)) && !!n.commonJsModuleIndicator;
            }
            e.isEffectiveExternalModule = nt;
            function pr(n, c) {
              switch (n.scriptKind) {
                case 1:
                case 3:
                case 2:
                case 4:
                  break;
                default:
                  return false;
              }
              return n.isDeclarationFile ? false : ku(c, "alwaysStrict") || e.startsWithUseStrict(n.statements) ? true : e.isExternalModule(n) || c.isolatedModules ? Vi(c) >= e.ModuleKind.ES2015 ? true : !c.noImplicitUseStrict : false;
            }
            e.isEffectiveStrictModeSourceFile = pr;
            function Mr(n) {
              return !!(n.flags & 16777216) || ia(n, 2);
            }
            e.isAmbientPropertyDeclaration = Mr;
            function ot(n, c) {
              switch (n.kind) {
                case 308:
                case 266:
                case 295:
                case 264:
                case 245:
                case 246:
                case 247:
                case 173:
                case 171:
                case 174:
                case 175:
                case 259:
                case 215:
                case 216:
                case 169:
                case 172:
                  return true;
                case 238:
                  return !e.isFunctionLikeOrClassStaticBlockDeclaration(c);
              }
              return false;
            }
            e.isBlockScope = ot;
            function At(n) {
              switch (n.kind) {
                case 341:
                case 348:
                case 326:
                  return true;
                default:
                  return e.assertType(n), re(n);
              }
            }
            e.isDeclarationWithTypeParameters = At;
            function re(n) {
              switch (n.kind) {
                case 176:
                case 177:
                case 170:
                case 178:
                case 181:
                case 182:
                case 320:
                case 260:
                case 228:
                case 261:
                case 262:
                case 347:
                case 259:
                case 171:
                case 173:
                case 174:
                case 175:
                case 215:
                case 216:
                  return true;
                default:
                  return e.assertType(n), false;
              }
            }
            e.isDeclarationWithTypeParameterChildren = re;
            function de(n) {
              switch (n.kind) {
                case 269:
                case 268:
                  return true;
                default:
                  return false;
              }
            }
            e.isAnyImportSyntax = de;
            function He(n) {
              return de(n) || Pi(n);
            }
            e.isAnyImportOrBareOrAccessedRequire = He;
            function Nr(n) {
              switch (n.kind) {
                case 269:
                case 268:
                case 240:
                case 260:
                case 259:
                case 264:
                case 262:
                case 261:
                case 263:
                  return true;
                default:
                  return false;
              }
            }
            e.isLateVisibilityPaintedStatement = Nr;
            function Yr(n) {
              return Ct(n) || e.isModuleDeclaration(n) || e.isImportTypeNode(n) || Yn(n);
            }
            e.hasPossibleExternalModuleReference = Yr;
            function Ct(n) {
              return de(n) || e.isExportDeclaration(n);
            }
            e.isAnyImportOrReExport = Ct;
            function xt(n) {
              return e.findAncestor(n.parent, function(c) {
                return ot(c, c.parent);
              });
            }
            e.getEnclosingBlockScopeContainer = xt;
            function Lt(n, c) {
              for (var x = xt(n); x; )
                c(x), x = xt(x);
            }
            e.forEachEnclosingBlockScopeContainer = Lt;
            function zt(n) {
              return !n || B(n) === 0 ? "(Missing)" : ir(n);
            }
            e.declarationNameToString = zt;
            function Zt(n) {
              return n.declaration ? zt(n.declaration.parameters[0].name) : void 0;
            }
            e.getNameFromIndexInfo = Zt;
            function mt(n) {
              return n.kind === 164 && !Pa(n.expression);
            }
            e.isComputedNonLiteralName = mt;
            function at(n) {
              switch (n.kind) {
                case 79:
                case 80:
                  return n.autoGenerateFlags ? void 0 : n.escapedText;
                case 10:
                case 8:
                case 14:
                  return e.escapeLeadingUnderscores(n.text);
                case 164:
                  return Pa(n.expression) ? e.escapeLeadingUnderscores(n.expression.text) : void 0;
                default:
                  return e.Debug.assertNever(n);
              }
            }
            e.tryGetTextOfPropertyName = at;
            function k(n) {
              return e.Debug.checkDefined(at(n));
            }
            e.getTextOfPropertyName = k;
            function ue(n) {
              switch (n.kind) {
                case 108:
                  return "this";
                case 80:
                case 79:
                  return B(n) === 0 ? e.idText(n) : ir(n);
                case 163:
                  return ue(n.left) + "." + ue(n.right);
                case 208:
                  return e.isIdentifier(n.name) || e.isPrivateIdentifier(n.name) ? ue(n.expression) + "." + ue(n.name) : e.Debug.assertNever(n.name);
                case 314:
                  return ue(n.left) + ue(n.right);
                default:
                  return e.Debug.assertNever(n);
              }
            }
            e.entityNameToString = ue;
            function Qe(n, c, x, G, Oe, mr) {
              var Tr = pe(n);
              return Kr(Tr, n, c, x, G, Oe, mr);
            }
            e.createDiagnosticForNode = Qe;
            function Sr(n, c, x, G, Oe, mr, Tr) {
              var Qr = e.skipTrivia(n.text, c.pos);
              return kt(n, Qr, c.end - Qr, x, G, Oe, mr, Tr);
            }
            e.createDiagnosticForNodeArray = Sr;
            function Kr(n, c, x, G, Oe, mr, Tr) {
              var Qr = En(n, c);
              return kt(n, Qr.start, Qr.length, x, G, Oe, mr, Tr);
            }
            e.createDiagnosticForNodeInSourceFile = Kr;
            function Hr(n, c, x) {
              var G = pe(n), Oe = En(G, n);
              return Xt(G, Oe.start, Oe.length, c, x);
            }
            e.createDiagnosticForNodeFromMessageChain = Hr;
            function Dt(n, c, x) {
              e.Debug.assertGreaterThanOrEqual(c, 0), e.Debug.assertGreaterThanOrEqual(x, 0), n && (e.Debug.assertLessThanOrEqual(c, n.text.length), e.Debug.assertLessThanOrEqual(c + x, n.text.length));
            }
            function Xt(n, c, x, G, Oe) {
              return Dt(n, c, x), { file: n, start: c, length: x, code: G.code, category: G.category, messageText: G.next ? G : G.messageText, relatedInformation: Oe };
            }
            e.createFileDiagnosticFromMessageChain = Xt;
            function cn(n, c, x) {
              return { file: n, start: 0, length: 0, code: c.code, category: c.category, messageText: c.next ? c : c.messageText, relatedInformation: x };
            }
            e.createDiagnosticForFileFromMessageChain = cn;
            function In(n) {
              return typeof n.messageText == "string" ? { code: n.code, category: n.category, messageText: n.messageText, next: n.next } : n.messageText;
            }
            e.createDiagnosticMessageChainFromDiagnostic = In;
            function yn(n, c, x) {
              return { file: n, start: c.pos, length: c.end - c.pos, code: x.code, category: x.category, messageText: x.message };
            }
            e.createDiagnosticForRange = yn;
            function hn(n, c) {
              var x = e.createScanner(n.languageVersion, true, n.languageVariant, n.text, void 0, c);
              x.scan();
              var G = x.getTokenPos();
              return e.createTextSpanFromBounds(G, x.getTextPos());
            }
            e.getSpanOfTokenAtPosition = hn;
            function ln(n, c) {
              var x = e.skipTrivia(n.text, c.pos);
              if (c.body && c.body.kind === 238) {
                var G = e.getLineAndCharacterOfPosition(n, c.body.pos).line, Oe = e.getLineAndCharacterOfPosition(n, c.body.end).line;
                if (G < Oe)
                  return e.createTextSpan(x, dr(G, n) - x + 1);
              }
              return e.createTextSpanFromBounds(x, c.end);
            }
            function En(n, c) {
              var x = c;
              switch (c.kind) {
                case 308:
                  var G = e.skipTrivia(n.text, 0, false);
                  return G === n.text.length ? e.createTextSpan(0, 0) : hn(n, G);
                case 257:
                case 205:
                case 260:
                case 228:
                case 261:
                case 264:
                case 263:
                case 302:
                case 259:
                case 215:
                case 171:
                case 174:
                case 175:
                case 262:
                case 169:
                case 168:
                case 271:
                  x = c.name;
                  break;
                case 216:
                  return ln(n, c);
                case 292:
                case 293:
                  var Oe = e.skipTrivia(n.text, c.pos), mr = c.statements.length > 0 ? c.statements[0].pos : c.end;
                  return e.createTextSpanFromBounds(Oe, mr);
              }
              if (x === void 0)
                return hn(n, c.pos);
              e.Debug.assert(!e.isJSDoc(x));
              var Tr = ve(x), Qr = Tr || e.isJsxText(c) ? x.pos : e.skipTrivia(n.text, x.pos);
              return Tr ? (e.Debug.assert(Qr === x.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809"), e.Debug.assert(Qr === x.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809")) : (e.Debug.assert(Qr >= x.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809"), e.Debug.assert(Qr <= x.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809")), e.createTextSpanFromBounds(Qr, x.end);
            }
            e.getErrorSpanForNode = En;
            function Vt(n) {
              return (n.externalModuleIndicator || n.commonJsModuleIndicator) !== void 0;
            }
            e.isExternalOrCommonJsModule = Vt;
            function ui(n) {
              return n.scriptKind === 6;
            }
            e.isJsonSourceFile = ui;
            function ei(n) {
              return !!(e.getCombinedModifierFlags(n) & 2048);
            }
            e.isEnumConst = ei;
            function hi(n) {
              return !!(e.getCombinedModifierFlags(n) & 64 && !e.isParameterPropertyDeclaration(n, n.parent));
            }
            e.isDeclarationReadonly = hi;
            function ri(n) {
              return !!(e.getCombinedNodeFlags(n) & 2);
            }
            e.isVarConst = ri;
            function vi(n) {
              return !!(e.getCombinedNodeFlags(n) & 1);
            }
            e.isLet = vi;
            function Qn(n) {
              return n.kind === 210 && n.expression.kind === 106;
            }
            e.isSuperCall = Qn;
            function Yn(n) {
              return n.kind === 210 && n.expression.kind === 100;
            }
            e.isImportCall = Yn;
            function oi(n) {
              return e.isMetaProperty(n) && n.keywordToken === 100 && n.name.escapedText === "meta";
            }
            e.isImportMeta = oi;
            function bi(n) {
              return e.isImportTypeNode(n) && e.isLiteralTypeNode(n.argument) && e.isStringLiteral(n.argument.literal);
            }
            e.isLiteralImportTypeNode = bi;
            function Dn(n) {
              return n.kind === 241 && n.expression.kind === 10;
            }
            e.isPrologueDirective = Dn;
            function Kn(n) {
              return !!(Br(n) & 1048576);
            }
            e.isCustomPrologue = Kn;
            function si(n) {
              return Kn(n) && e.isFunctionDeclaration(n);
            }
            e.isHoistedFunction = si;
            function di(n) {
              return e.isIdentifier(n.name) && !n.initializer;
            }
            function Zn(n) {
              return Kn(n) && e.isVariableStatement(n) && e.every(n.declarationList.declarations, di);
            }
            e.isHoistedVariableStatement = Zn;
            function Fn(n, c) {
              return n.kind !== 11 ? e.getLeadingCommentRanges(c.text, n.pos) : void 0;
            }
            e.getLeadingCommentRangesOfNode = Fn;
            function gt(n, c) {
              var x = n.kind === 166 || n.kind === 165 || n.kind === 215 || n.kind === 216 || n.kind === 214 || n.kind === 257 || n.kind === 278 ? e.concatenate(e.getTrailingCommentRanges(c, n.pos), e.getLeadingCommentRanges(c, n.pos)) : e.getLeadingCommentRanges(c, n.pos);
              return e.filter(x, function(G) {
                return c.charCodeAt(G.pos + 1) === 42 && c.charCodeAt(G.pos + 2) === 42 && c.charCodeAt(G.pos + 3) !== 47;
              });
            }
            e.getJSDocCommentRanges = gt, e.fullTripleSlashReferencePathRegEx = /^(\/\/\/\s*<reference\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
            var mi = /^(\/\/\/\s*<reference\s+types\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
            e.fullTripleSlashAMDReferencePathRegEx = /^(\/\/\/\s*<amd-dependency\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
            var dn = /^(\/\/\/\s*<reference\s+no-default-lib\s*=\s*)(('[^']*')|("[^"]*"))\s*\/>/;
            function On(n) {
              if (179 <= n.kind && n.kind <= 202)
                return true;
              switch (n.kind) {
                case 131:
                case 157:
                case 148:
                case 160:
                case 152:
                case 134:
                case 153:
                case 149:
                case 155:
                case 144:
                  return true;
                case 114:
                  return n.parent.kind !== 219;
                case 230:
                  return e.isHeritageClause(n.parent) && !Oa(n);
                case 165:
                  return n.parent.kind === 197 || n.parent.kind === 192;
                case 79:
                  (n.parent.kind === 163 && n.parent.right === n || n.parent.kind === 208 && n.parent.name === n) && (n = n.parent), e.Debug.assert(n.kind === 79 || n.kind === 163 || n.kind === 208, "'node' was expected to be a qualified name, identifier or property access in 'isPartOfTypeNode'.");
                case 163:
                case 208:
                case 108: {
                  var c = n.parent;
                  if (c.kind === 183)
                    return false;
                  if (c.kind === 202)
                    return !c.isTypeOf;
                  if (179 <= c.kind && c.kind <= 202)
                    return true;
                  switch (c.kind) {
                    case 230:
                      return e.isHeritageClause(c.parent) && !Oa(c);
                    case 165:
                      return n === c.constraint;
                    case 347:
                      return n === c.constraint;
                    case 169:
                    case 168:
                    case 166:
                    case 257:
                      return n === c.type;
                    case 259:
                    case 215:
                    case 216:
                    case 173:
                    case 171:
                    case 170:
                    case 174:
                    case 175:
                      return n === c.type;
                    case 176:
                    case 177:
                    case 178:
                      return n === c.type;
                    case 213:
                      return n === c.type;
                    case 210:
                    case 211:
                      return e.contains(c.typeArguments, n);
                    case 212:
                      return false;
                  }
                }
              }
              return false;
            }
            e.isPartOfTypeNode = On;
            function br(n, c) {
              for (; n; ) {
                if (n.kind === c)
                  return true;
                n = n.parent;
              }
              return false;
            }
            e.isChildOfNodeWithKind = br;
            function Ae(n, c) {
              return x(n);
              function x(G) {
                switch (G.kind) {
                  case 250:
                    return c(G);
                  case 266:
                  case 238:
                  case 242:
                  case 243:
                  case 244:
                  case 245:
                  case 246:
                  case 247:
                  case 251:
                  case 252:
                  case 292:
                  case 293:
                  case 253:
                  case 255:
                  case 295:
                    return e.forEachChild(G, x);
                }
              }
            }
            e.forEachReturnStatement = Ae;
            function ur(n, c) {
              return x(n);
              function x(G) {
                switch (G.kind) {
                  case 226:
                    c(G);
                    var Oe = G.expression;
                    Oe && x(Oe);
                    return;
                  case 263:
                  case 261:
                  case 264:
                  case 262:
                    return;
                  default:
                    if (e.isFunctionLike(G)) {
                      if (G.name && G.name.kind === 164) {
                        x(G.name.expression);
                        return;
                      }
                    } else
                      On(G) || e.forEachChild(G, x);
                }
              }
            }
            e.forEachYieldExpression = ur;
            function L(n) {
              return n && n.kind === 185 ? n.elementType : n && n.kind === 180 ? e.singleOrUndefined(n.typeArguments) : void 0;
            }
            e.getRestParameterElementType = L;
            function qt(n) {
              switch (n.kind) {
                case 261:
                case 260:
                case 228:
                case 184:
                  return n.members;
                case 207:
                  return n.properties;
              }
            }
            e.getMembersOfDeclaration = qt;
            function nn(n) {
              if (n)
                switch (n.kind) {
                  case 205:
                  case 302:
                  case 166:
                  case 299:
                  case 169:
                  case 168:
                  case 300:
                  case 257:
                    return true;
                }
              return false;
            }
            e.isVariableLike = nn;
            function fr(n) {
              return nn(n) || e.isAccessor(n);
            }
            e.isVariableLikeOrAccessor = fr;
            function Le(n) {
              return n.parent.kind === 258 && n.parent.parent.kind === 240;
            }
            e.isVariableDeclarationInVariableStatement = Le;
            function Ve(n) {
              return hr(n) ? e.isObjectLiteralExpression(n.parent) && e.isBinaryExpression(n.parent.parent) && it2(n.parent.parent) === 2 || _r(n.parent) : false;
            }
            e.isCommonJsExportedExpression = Ve;
            function _r(n) {
              return hr(n) ? e.isBinaryExpression(n) && it2(n) === 1 : false;
            }
            e.isCommonJsExportPropertyAssignment = _r;
            function lr(n) {
              return (e.isVariableDeclaration(n) ? ri(n) && e.isIdentifier(n.name) && Le(n) : e.isPropertyDeclaration(n) ? _s(n) && l_(n) : e.isPropertySignature(n) && _s(n)) || _r(n);
            }
            e.isValidESSymbolDeclaration = lr;
            function Vr(n) {
              switch (n.kind) {
                case 171:
                case 170:
                case 173:
                case 174:
                case 175:
                case 259:
                case 215:
                  return true;
              }
              return false;
            }
            e.introducesArgumentsExoticObject = Vr;
            function tt(n, c) {
              for (; ; ) {
                if (c && c(n), n.statement.kind !== 253)
                  return n.statement;
                n = n.statement;
              }
            }
            e.unwrapInnermostStatementOfLabel = tt;
            function dt(n) {
              return n && n.kind === 238 && e.isFunctionLike(n.parent);
            }
            e.isFunctionBlock = dt;
            function It(n) {
              return n && n.kind === 171 && n.parent.kind === 207;
            }
            e.isObjectLiteralMethod = It;
            function an(n) {
              return (n.kind === 171 || n.kind === 174 || n.kind === 175) && (n.parent.kind === 207 || n.parent.kind === 228);
            }
            e.isObjectLiteralOrClassExpressionMethodOrAccessor = an;
            function sn(n) {
              return n && n.kind === 1;
            }
            e.isIdentifierTypePredicate = sn;
            function _e(n) {
              return n && n.kind === 0;
            }
            e.isThisTypePredicate = _e;
            function Gr(n, c, x) {
              return n.properties.filter(function(G) {
                if (G.kind === 299) {
                  var Oe = at(G.name);
                  return c === Oe || !!x && x === Oe;
                }
                return false;
              });
            }
            e.getPropertyAssignment = Gr;
            function Kt(n, c, x) {
              return e.firstDefined(Gr(n, c), function(G) {
                return e.isArrayLiteralExpression(G.initializer) ? e.find(G.initializer.elements, function(Oe) {
                  return e.isStringLiteral(Oe) && Oe.text === x;
                }) : void 0;
              });
            }
            e.getPropertyArrayElementValue = Kt;
            function en(n) {
              if (n && n.statements.length) {
                var c = n.statements[0].expression;
                return e.tryCast(c, e.isObjectLiteralExpression);
              }
            }
            e.getTsConfigObjectLiteralExpression = en;
            function Ot(n, c, x) {
              return e.firstDefined(rr(n, c), function(G) {
                return e.isArrayLiteralExpression(G.initializer) ? e.find(G.initializer.elements, function(Oe) {
                  return e.isStringLiteral(Oe) && Oe.text === x;
                }) : void 0;
              });
            }
            e.getTsConfigPropArrayElementValue = Ot;
            function rr(n, c) {
              var x = en(n);
              return x ? Gr(x, c) : e.emptyArray;
            }
            e.getTsConfigPropArray = rr;
            function Hn(n) {
              return e.findAncestor(n.parent, e.isFunctionLike);
            }
            e.getContainingFunction = Hn;
            function rn(n) {
              return e.findAncestor(n.parent, e.isFunctionLikeDeclaration);
            }
            e.getContainingFunctionDeclaration = rn;
            function xn(n) {
              return e.findAncestor(n.parent, e.isClassLike);
            }
            e.getContainingClass = xn;
            function Mn(n) {
              return e.findAncestor(n.parent, function(c) {
                return e.isClassLike(c) || e.isFunctionLike(c) ? "quit" : e.isClassStaticBlockDeclaration(c);
              });
            }
            e.getContainingClassStaticBlock = Mn;
            function Rn(n) {
              return e.findAncestor(n.parent, e.isFunctionLikeOrClassStaticBlockDeclaration);
            }
            e.getContainingFunctionOrClassStaticBlock = Rn;
            function kn(n, c) {
              for (e.Debug.assert(n.kind !== 308); ; ) {
                if (n = n.parent, !n)
                  return e.Debug.fail();
                switch (n.kind) {
                  case 164:
                    if (e.isClassLike(n.parent.parent))
                      return n;
                    n = n.parent;
                    break;
                  case 167:
                    n.parent.kind === 166 && e.isClassElement(n.parent.parent) ? n = n.parent.parent : e.isClassElement(n.parent) && (n = n.parent);
                    break;
                  case 216:
                    if (!c)
                      continue;
                  case 259:
                  case 215:
                  case 264:
                  case 172:
                  case 169:
                  case 168:
                  case 171:
                  case 170:
                  case 173:
                  case 174:
                  case 175:
                  case 176:
                  case 177:
                  case 178:
                  case 263:
                  case 308:
                    return n;
                }
              }
            }
            e.getThisContainer = kn;
            function on(n) {
              switch (n.kind) {
                case 216:
                case 259:
                case 215:
                case 169:
                  return true;
                case 238:
                  switch (n.parent.kind) {
                    case 173:
                    case 171:
                    case 174:
                    case 175:
                      return true;
                    default:
                      return false;
                  }
                default:
                  return false;
              }
            }
            e.isThisContainerOrFunctionBlock = on;
            function Xr(n) {
              e.isIdentifier(n) && (e.isClassDeclaration(n.parent) || e.isFunctionDeclaration(n.parent)) && n.parent.name === n && (n = n.parent);
              var c = kn(n, true);
              return e.isSourceFile(c);
            }
            e.isInTopLevelContext = Xr;
            function wr(n) {
              var c = kn(n, false);
              if (c)
                switch (c.kind) {
                  case 173:
                  case 259:
                  case 215:
                    return c;
                }
            }
            e.getNewTargetContainer = wr;
            function fn(n, c) {
              for (; ; ) {
                if (n = n.parent, !n)
                  return n;
                switch (n.kind) {
                  case 164:
                    n = n.parent;
                    break;
                  case 259:
                  case 215:
                  case 216:
                    if (!c)
                      continue;
                  case 169:
                  case 168:
                  case 171:
                  case 170:
                  case 173:
                  case 174:
                  case 175:
                  case 172:
                    return n;
                  case 167:
                    n.parent.kind === 166 && e.isClassElement(n.parent.parent) ? n = n.parent.parent : e.isClassElement(n.parent) && (n = n.parent);
                    break;
                }
              }
            }
            e.getSuperContainer = fn;
            function mn(n) {
              if (n.kind === 215 || n.kind === 216) {
                for (var c = n, x = n.parent; x.kind === 214; )
                  c = x, x = x.parent;
                if (x.kind === 210 && x.expression === c)
                  return x;
              }
            }
            e.getImmediatelyInvokedFunctionExpression = mn;
            function Mi(n) {
              return n.kind === 106 || An(n);
            }
            e.isSuperOrSuperProperty = Mi;
            function An(n) {
              var c = n.kind;
              return (c === 208 || c === 209) && n.expression.kind === 106;
            }
            e.isSuperProperty = An;
            function xi(n) {
              var c = n.kind;
              return (c === 208 || c === 209) && n.expression.kind === 108;
            }
            e.isThisProperty = xi;
            function ti(n) {
              var c;
              return !!n && e.isVariableDeclaration(n) && ((c = n.initializer) === null || c === void 0 ? void 0 : c.kind) === 108;
            }
            e.isThisInitializedDeclaration = ti;
            function li(n) {
              return !!n && (e.isShorthandPropertyAssignment(n) || e.isPropertyAssignment(n)) && e.isBinaryExpression(n.parent.parent) && n.parent.parent.operatorToken.kind === 63 && n.parent.parent.right.kind === 108;
            }
            e.isThisInitializedObjectBindingExpression = li;
            function Bn(n) {
              switch (n.kind) {
                case 180:
                  return n.typeName;
                case 230:
                  return Ma(n.expression) ? n.expression : void 0;
                case 79:
                case 163:
                  return n;
              }
            }
            e.getEntityNameFromTypeNode = Bn;
            function vn(n) {
              switch (n.kind) {
                case 212:
                  return n.tag;
                case 283:
                case 282:
                  return n.tagName;
                default:
                  return n.expression;
              }
            }
            e.getInvokedExpression = vn;
            function Ue(n, c, x) {
              if (e.isNamedDeclaration(n) && e.isPrivateIdentifier(n.name))
                return false;
              switch (n.kind) {
                case 260:
                  return true;
                case 169:
                  return c.kind === 260;
                case 174:
                case 175:
                case 171:
                  return n.body !== void 0 && c.kind === 260;
                case 166:
                  return c.body !== void 0 && (c.kind === 173 || c.kind === 171 || c.kind === 175) && x.kind === 260;
              }
              return false;
            }
            e.nodeCanBeDecorated = Ue;
            function Vn(n, c, x) {
              return cs(n) && Ue(n, c, x);
            }
            e.nodeIsDecorated = Vn;
            function Ei(n, c, x) {
              return Vn(n, c, x) || ni(n, c);
            }
            e.nodeOrChildIsDecorated = Ei;
            function ni(n, c) {
              switch (n.kind) {
                case 260:
                  return e.some(n.members, function(x) {
                    return Ei(x, n, c);
                  });
                case 171:
                case 175:
                case 173:
                  return e.some(n.parameters, function(x) {
                    return Vn(x, n, c);
                  });
                default:
                  return false;
              }
            }
            e.childIsDecorated = ni;
            function Fi(n) {
              if (Vn(n))
                return true;
              var c = n_(n);
              return !!c && ni(c, n);
            }
            e.classOrConstructorParameterIsDecorated = Fi;
            function Tn(n) {
              var c = n.parent;
              return c.kind === 283 || c.kind === 282 || c.kind === 284 ? c.tagName === n : false;
            }
            e.isJSXTagName = Tn;
            function jn(n) {
              switch (n.kind) {
                case 106:
                case 104:
                case 110:
                case 95:
                case 13:
                case 206:
                case 207:
                case 208:
                case 209:
                case 210:
                case 211:
                case 212:
                case 231:
                case 213:
                case 235:
                case 232:
                case 214:
                case 215:
                case 228:
                case 216:
                case 219:
                case 217:
                case 218:
                case 221:
                case 222:
                case 223:
                case 224:
                case 227:
                case 225:
                case 229:
                case 281:
                case 282:
                case 285:
                case 226:
                case 220:
                case 233:
                  return true;
                case 230:
                  return !e.isHeritageClause(n.parent);
                case 163:
                  for (; n.parent.kind === 163; )
                    n = n.parent;
                  return n.parent.kind === 183 || e.isJSDocLinkLike(n.parent) || e.isJSDocNameReference(n.parent) || e.isJSDocMemberName(n.parent) || Tn(n);
                case 314:
                  for (; e.isJSDocMemberName(n.parent); )
                    n = n.parent;
                  return n.parent.kind === 183 || e.isJSDocLinkLike(n.parent) || e.isJSDocNameReference(n.parent) || e.isJSDocMemberName(n.parent) || Tn(n);
                case 80:
                  return e.isBinaryExpression(n.parent) && n.parent.left === n && n.parent.operatorToken.kind === 101;
                case 79:
                  if (n.parent.kind === 183 || e.isJSDocLinkLike(n.parent) || e.isJSDocNameReference(n.parent) || e.isJSDocMemberName(n.parent) || Tn(n))
                    return true;
                case 8:
                case 9:
                case 10:
                case 14:
                case 108:
                  return Ti(n);
                default:
                  return false;
              }
            }
            e.isExpressionNode = jn;
            function Ti(n) {
              var c = n.parent;
              switch (c.kind) {
                case 257:
                case 166:
                case 169:
                case 168:
                case 302:
                case 299:
                case 205:
                  return c.initializer === n;
                case 241:
                case 242:
                case 243:
                case 244:
                case 250:
                case 251:
                case 252:
                case 292:
                case 254:
                  return c.expression === n;
                case 245:
                  var x = c;
                  return x.initializer === n && x.initializer.kind !== 258 || x.condition === n || x.incrementor === n;
                case 246:
                case 247:
                  var G = c;
                  return G.initializer === n && G.initializer.kind !== 258 || G.expression === n;
                case 213:
                case 231:
                  return n === c.expression;
                case 236:
                  return n === c.expression;
                case 164:
                  return n === c.expression;
                case 167:
                case 291:
                case 290:
                case 301:
                  return true;
                case 230:
                  return c.expression === n && !On(c);
                case 300:
                  return c.objectAssignmentInitializer === n;
                case 235:
                  return n === c.expression;
                default:
                  return jn(c);
              }
            }
            e.isInExpressionContext = Ti;
            function Si(n) {
              for (; n.kind === 163 || n.kind === 79; )
                n = n.parent;
              return n.kind === 183;
            }
            e.isPartOfTypeQuery = Si;
            function C(n) {
              return e.isNamespaceExport(n) && !!n.parent.moduleSpecifier;
            }
            e.isNamespaceReexportDeclaration = C;
            function W(n) {
              return n.kind === 268 && n.moduleReference.kind === 280;
            }
            e.isExternalModuleImportEqualsDeclaration = W;
            function ee(n) {
              return e.Debug.assert(W(n)), n.moduleReference.expression;
            }
            e.getExternalModuleImportEqualsDeclarationExpression = ee;
            function le(n) {
              return Pi(n) && Gt(n.initializer).arguments[0];
            }
            e.getExternalModuleRequireArgument = le;
            function Ze(n) {
              return n.kind === 268 && n.moduleReference.kind !== 280;
            }
            e.isInternalModuleImportEqualsDeclaration = Ze;
            function Ir(n) {
              return hr(n);
            }
            e.isSourceFileJS = Ir;
            function Ar(n) {
              return !hr(n);
            }
            e.isSourceFileNotJS = Ar;
            function hr(n) {
              return !!n && !!(n.flags & 262144);
            }
            e.isInJSFile = hr;
            function yt(n) {
              return !!n && !!(n.flags & 67108864);
            }
            e.isInJsonFile = yt;
            function Pt(n) {
              return !ui(n);
            }
            e.isSourceFileNotJson = Pt;
            function Ut(n) {
              return !!n && !!(n.flags & 8388608);
            }
            e.isInJSDoc = Ut;
            function jt(n) {
              return e.isTypeReferenceNode(n) && e.isIdentifier(n.typeName) && n.typeName.escapedText === "Object" && n.typeArguments && n.typeArguments.length === 2 && (n.typeArguments[0].kind === 152 || n.typeArguments[0].kind === 148);
            }
            e.isJSDocIndexSignature = jt;
            function Ht(n, c) {
              if (n.kind !== 210)
                return false;
              var x = n, G = x.expression, Oe = x.arguments;
              if (G.kind !== 79 || G.escapedText !== "require" || Oe.length !== 1)
                return false;
              var mr = Oe[0];
              return !c || e.isStringLiteralLike(mr);
            }
            e.isRequireCall = Ht;
            function gi(n) {
              return Gn(n, false);
            }
            e.isVariableDeclarationInitializedToRequire = gi;
            function Pi(n) {
              return Gn(n, true);
            }
            e.isVariableDeclarationInitializedToBareOrAccessedRequire = Pi;
            function Gn(n, c) {
              return e.isVariableDeclaration(n) && !!n.initializer && Ht(c ? Gt(n.initializer) : n.initializer, true);
            }
            function Bi(n) {
              return e.isVariableStatement(n) && n.declarationList.declarations.length > 0 && e.every(n.declarationList.declarations, function(c) {
                return gi(c);
              });
            }
            e.isRequireVariableStatement = Bi;
            function oa(n) {
              return n === 39 || n === 34;
            }
            e.isSingleOrDoubleQuote = oa;
            function Zi(n, c) {
              return tr(c, n).charCodeAt(0) === 34;
            }
            e.isStringDoubleQuoted = Zi;
            function Ki(n) {
              return e.isBinaryExpression(n) || Rr(n) || e.isIdentifier(n) || e.isCallExpression(n);
            }
            e.isAssignmentDeclaration = Ki;
            function qi(n) {
              return hr(n) && n.initializer && e.isBinaryExpression(n.initializer) && (n.initializer.operatorToken.kind === 56 || n.initializer.operatorToken.kind === 60) && n.name && Ma(n.name) && Li(n.name, n.initializer.left) ? n.initializer.right : n.initializer;
            }
            e.getEffectiveInitializer = qi;
            function Hi(n) {
              var c = qi(n);
              return c && Jn(c, za(n.name));
            }
            e.getDeclaredExpandoInitializer = Hi;
            function Gi(n, c) {
              return e.forEach(n.properties, function(x) {
                return e.isPropertyAssignment(x) && e.isIdentifier(x.name) && x.name.escapedText === "value" && x.initializer && Jn(x.initializer, c);
              });
            }
            function da(n) {
              if (n && n.parent && e.isBinaryExpression(n.parent) && n.parent.operatorToken.kind === 63) {
                var c = za(n.parent.left);
                return Jn(n.parent.right, c) || ea(n.parent.left, n.parent.right, c);
              }
              if (n && e.isCallExpression(n) && vt(n)) {
                var x = Gi(n.arguments[2], n.arguments[1].text === "prototype");
                if (x)
                  return x;
              }
            }
            e.getAssignedExpandoInitializer = da;
            function Jn(n, c) {
              if (e.isCallExpression(n)) {
                var x = _t(n.expression);
                return x.kind === 215 || x.kind === 216 ? n : void 0;
              }
              if (n.kind === 215 || n.kind === 228 || n.kind === 216 || e.isObjectLiteralExpression(n) && (n.properties.length === 0 || c))
                return n;
            }
            e.getExpandoInitializer = Jn;
            function ea(n, c, x) {
              var G = e.isBinaryExpression(c) && (c.operatorToken.kind === 56 || c.operatorToken.kind === 60) && Jn(c.right, x);
              if (G && Li(n, c.left))
                return G;
            }
            function Xi(n) {
              var c = e.isVariableDeclaration(n.parent) ? n.parent.name : e.isBinaryExpression(n.parent) && n.parent.operatorToken.kind === 63 ? n.parent.left : void 0;
              return c && Jn(n.right, za(c)) && Ma(c) && Li(c, n.left);
            }
            e.isDefaultedExpandoInitializer = Xi;
            function sa(n) {
              if (e.isBinaryExpression(n.parent)) {
                var c = (n.parent.operatorToken.kind === 56 || n.parent.operatorToken.kind === 60) && e.isBinaryExpression(n.parent.parent) ? n.parent.parent : n.parent;
                if (c.operatorToken.kind === 63 && e.isIdentifier(c.left))
                  return c.left;
              } else if (e.isVariableDeclaration(n.parent))
                return n.parent.name;
            }
            e.getNameOfExpando = sa;
            function Li(n, c) {
              return Us(n) && Us(c) ? Zo(n) === Zo(c) : e.isMemberName(n) && Tt(c) && (c.expression.kind === 108 || e.isIdentifier(c.expression) && (c.expression.escapedText === "window" || c.expression.escapedText === "self" || c.expression.escapedText === "global")) ? Li(n, y(c)) : Tt(n) && Tt(c) ? Qt(n) === Qt(c) && Li(n.expression, c.expression) : false;
            }
            e.isSameEntityName = Li;
            function p(n) {
              for (; ps(n, true); )
                n = n.right;
              return n;
            }
            e.getRightMostAssignedExpression = p;
            function ne(n) {
              return e.isIdentifier(n) && n.escapedText === "exports";
            }
            e.isExportsIdentifier = ne;
            function Ne(n) {
              return e.isIdentifier(n) && n.escapedText === "module";
            }
            e.isModuleIdentifier = Ne;
            function or(n) {
              return (e.isPropertyAccessExpression(n) || St(n)) && Ne(n.expression) && Qt(n) === "exports";
            }
            e.isModuleExportsAccessExpression = or;
            function it2(n) {
              var c = De(n);
              return c === 5 || hr(n) ? c : 0;
            }
            e.getAssignmentDeclarationKind = it2;
            function vt(n) {
              return e.length(n.arguments) === 3 && e.isPropertyAccessExpression(n.expression) && e.isIdentifier(n.expression.expression) && e.idText(n.expression.expression) === "Object" && e.idText(n.expression.name) === "defineProperty" && Pa(n.arguments[1]) && $t(n.arguments[0], true);
            }
            e.isBindableObjectDefinePropertyCall = vt;
            function Tt(n) {
              return e.isPropertyAccessExpression(n) || St(n);
            }
            e.isLiteralLikeAccess = Tt;
            function St(n) {
              return e.isElementAccessExpression(n) && Pa(n.argumentExpression);
            }
            e.isLiteralLikeElementAccess = St;
            function tn(n, c) {
              return e.isPropertyAccessExpression(n) && (!c && n.expression.kind === 108 || e.isIdentifier(n.name) && $t(n.expression, true)) || Mt(n, c);
            }
            e.isBindableStaticAccessExpression = tn;
            function Mt(n, c) {
              return St(n) && (!c && n.expression.kind === 108 || Ma(n.expression) || tn(n.expression, true));
            }
            e.isBindableStaticElementAccessExpression = Mt;
            function $t(n, c) {
              return Ma(n) || tn(n, c);
            }
            e.isBindableStaticNameExpression = $t;
            function y(n) {
              return e.isPropertyAccessExpression(n) ? n.name : n.argumentExpression;
            }
            e.getNameOrArgument = y;
            function De(n) {
              if (e.isCallExpression(n)) {
                if (!vt(n))
                  return 0;
                var c = n.arguments[0];
                return ne(c) || or(c) ? 8 : tn(c) && Qt(c) === "prototype" ? 9 : 7;
              }
              return n.operatorToken.kind !== 63 || !Rr(n.left) || R(p(n)) ? 0 : $t(n.left.expression, true) && Qt(n.left) === "prototype" && e.isObjectLiteralExpression(Ni(n)) ? 6 : qn(n.left);
            }
            function R(n) {
              return e.isVoidExpression(n) && e.isNumericLiteral(n.expression) && n.expression.text === "0";
            }
            function Jt(n) {
              if (e.isPropertyAccessExpression(n))
                return n.name;
              var c = _t(n.argumentExpression);
              return e.isNumericLiteral(c) || e.isStringLiteralLike(c) ? c : n;
            }
            e.getElementOrPropertyAccessArgumentExpressionOrName = Jt;
            function Qt(n) {
              var c = Jt(n);
              if (c) {
                if (e.isIdentifier(c))
                  return c.escapedText;
                if (e.isStringLiteralLike(c) || e.isNumericLiteral(c))
                  return e.escapeLeadingUnderscores(c.text);
              }
            }
            e.getElementOrPropertyAccessName = Qt;
            function qn(n) {
              if (n.expression.kind === 108)
                return 4;
              if (or(n))
                return 2;
              if ($t(n.expression, true)) {
                if (za(n.expression))
                  return 3;
                for (var c = n; !e.isIdentifier(c.expression); )
                  c = c.expression;
                var x = c.expression;
                if ((x.escapedText === "exports" || x.escapedText === "module" && Qt(c) === "exports") && tn(n))
                  return 1;
                if ($t(n, true) || e.isElementAccessExpression(n) && Oo(n))
                  return 5;
              }
              return 0;
            }
            e.getAssignmentDeclarationPropertyAccessKind = qn;
            function Ni(n) {
              for (; e.isBinaryExpression(n.right); )
                n = n.right;
              return n.right;
            }
            e.getInitializerOfBinaryExpression = Ni;
            function _a(n) {
              return e.isBinaryExpression(n) && it2(n) === 3;
            }
            e.isPrototypePropertyAssignment = _a;
            function Ri(n) {
              return hr(n) && n.parent && n.parent.kind === 241 && (!e.isElementAccessExpression(n) || St(n)) && !!e.getJSDocTypeTag(n.parent);
            }
            e.isSpecialPropertyDeclaration = Ri;
            function ca(n, c) {
              var x = n.valueDeclaration;
              (!x || !(c.flags & 16777216 && !(x.flags & 16777216)) && Ki(x) && !Ki(c) || x.kind !== c.kind && K(x)) && (n.valueDeclaration = c);
            }
            e.setValueDeclaration = ca;
            function $i(n) {
              if (!n || !n.valueDeclaration)
                return false;
              var c = n.valueDeclaration;
              return c.kind === 259 || e.isVariableDeclaration(c) && c.initializer && e.isFunctionLike(c.initializer);
            }
            e.isFunctionSymbol = $i;
            function ra(n) {
              var c, x;
              switch (n.kind) {
                case 257:
                  return (c = e.findAncestor(n.initializer, function(G) {
                    return Ht(G, true);
                  })) === null || c === void 0 ? void 0 : c.arguments[0];
                case 269:
                  return e.tryCast(n.moduleSpecifier, e.isStringLiteralLike);
                case 268:
                  return e.tryCast((x = e.tryCast(n.moduleReference, e.isExternalModuleReference)) === null || x === void 0 ? void 0 : x.expression, e.isStringLiteralLike);
                default:
                  e.Debug.assertNever(n);
              }
            }
            e.tryGetModuleSpecifierFromDeclaration = ra;
            function Ea(n) {
              return Ui(n) || e.Debug.failBadSyntaxKind(n.parent);
            }
            e.importFromModuleSpecifier = Ea;
            function Ui(n) {
              switch (n.parent.kind) {
                case 269:
                case 275:
                  return n.parent;
                case 280:
                  return n.parent.parent;
                case 210:
                  return Yn(n.parent) || Ht(n.parent, false) ? n.parent : void 0;
                case 198:
                  return e.Debug.assert(e.isStringLiteral(n)), e.tryCast(n.parent.parent, e.isImportTypeNode);
                default:
                  return;
              }
            }
            e.tryGetImportFromModuleSpecifier = Ui;
            function ji(n) {
              switch (n.kind) {
                case 269:
                case 275:
                  return n.moduleSpecifier;
                case 268:
                  return n.moduleReference.kind === 280 ? n.moduleReference.expression : void 0;
                case 202:
                  return bi(n) ? n.argument.literal : void 0;
                case 210:
                  return n.arguments[0];
                case 264:
                  return n.name.kind === 10 ? n.name : void 0;
                default:
                  return e.Debug.assertNever(n);
              }
            }
            e.getExternalModuleName = ji;
            function ma(n) {
              switch (n.kind) {
                case 269:
                  return n.importClause && e.tryCast(n.importClause.namedBindings, e.isNamespaceImport);
                case 268:
                  return n;
                case 275:
                  return n.exportClause && e.tryCast(n.exportClause, e.isNamespaceExport);
                default:
                  return e.Debug.assertNever(n);
              }
            }
            e.getNamespaceDeclarationNode = ma;
            function vo(n) {
              return n.kind === 269 && !!n.importClause && !!n.importClause.name;
            }
            e.isDefaultImport = vo;
            function Is(n, c) {
              if (n.name) {
                var x = c(n);
                if (x)
                  return x;
              }
              if (n.namedBindings) {
                var x = e.isNamespaceImport(n.namedBindings) ? c(n.namedBindings) : e.forEach(n.namedBindings.elements, c);
                if (x)
                  return x;
              }
            }
            e.forEachImportClauseDeclaration = Is;
            function wa(n) {
              if (n)
                switch (n.kind) {
                  case 166:
                  case 171:
                  case 170:
                  case 300:
                  case 299:
                  case 169:
                  case 168:
                    return n.questionToken !== void 0;
                }
              return false;
            }
            e.hasQuestionToken = wa;
            function Ho(n) {
              var c = e.isJSDocFunctionType(n) ? e.firstOrUndefined(n.parameters) : void 0, x = e.tryCast(c && c.name, e.isIdentifier);
              return !!x && x.escapedText === "new";
            }
            e.isJSDocConstructSignature = Ho;
            function Ta(n) {
              return n.kind === 348 || n.kind === 341 || n.kind === 342;
            }
            e.isJSDocTypeAlias = Ta;
            function Ja(n) {
              return Ta(n) || e.isTypeAliasDeclaration(n);
            }
            e.isTypeAlias = Ja;
            function bo(n) {
              return e.isExpressionStatement(n) && e.isBinaryExpression(n.expression) && n.expression.operatorToken.kind === 63 ? p(n.expression) : void 0;
            }
            function Eo(n) {
              return e.isExpressionStatement(n) && e.isBinaryExpression(n.expression) && it2(n.expression) !== 0 && e.isBinaryExpression(n.expression.right) && (n.expression.right.operatorToken.kind === 56 || n.expression.right.operatorToken.kind === 60) ? n.expression.right.right : void 0;
            }
            function to(n) {
              switch (n.kind) {
                case 240:
                  var c = Aa(n);
                  return c && c.initializer;
                case 169:
                  return n.initializer;
                case 299:
                  return n.initializer;
              }
            }
            e.getSingleInitializerOfVariableStatementOrPropertyDeclaration = to;
            function Aa(n) {
              return e.isVariableStatement(n) ? e.firstOrUndefined(n.declarationList.declarations) : void 0;
            }
            e.getSingleVariableOfVariableStatement = Aa;
            function To(n) {
              return e.isModuleDeclaration(n) && n.body && n.body.kind === 264 ? n.body : void 0;
            }
            function Os(n, c) {
              var x;
              nn(n) && e.hasInitializer(n) && e.hasJSDocNodes(n.initializer) && (x = e.addRange(x, So(n, e.last(n.initializer.jsDoc))));
              for (var G = n; G && G.parent; ) {
                if (e.hasJSDocNodes(G) && (x = e.addRange(x, So(n, e.last(G.jsDoc)))), G.kind === 166) {
                  x = e.addRange(x, (c ? e.getJSDocParameterTagsNoCache : e.getJSDocParameterTags)(G));
                  break;
                }
                if (G.kind === 165) {
                  x = e.addRange(x, (c ? e.getJSDocTypeParameterTagsNoCache : e.getJSDocTypeParameterTags)(G));
                  break;
                }
                G = ka(G);
              }
              return x || e.emptyArray;
            }
            e.getJSDocCommentsAndTags = Os;
            function So(n, c) {
              if (e.isJSDoc(c)) {
                var x = e.filter(c.tags, function(G) {
                  return Co(n, G);
                });
                return c.tags === x ? [c] : x;
              }
              return Co(n, c) ? [c] : void 0;
            }
            function Co(n, c) {
              return !e.isJSDocTypeTag(c) || !c.parent || !e.isJSDoc(c.parent) || !e.isParenthesizedExpression(c.parent.parent) || c.parent.parent === n;
            }
            function ka(n) {
              var c = n.parent;
              if (c.kind === 299 || c.kind === 274 || c.kind === 169 || c.kind === 241 && n.kind === 208 || c.kind === 250 || To(c) || e.isBinaryExpression(n) && n.operatorToken.kind === 63)
                return c;
              if (c.parent && (Aa(c.parent) === n || e.isBinaryExpression(c) && c.operatorToken.kind === 63))
                return c.parent;
              if (c.parent && c.parent.parent && (Aa(c.parent.parent) || to(c.parent.parent) === n || Eo(c.parent.parent)))
                return c.parent.parent;
            }
            e.getNextJSDocCommentLocation = ka;
            function no(n) {
              if (n.symbol)
                return n.symbol;
              if (e.isIdentifier(n.name)) {
                var c = n.name.escapedText, x = Ii(n);
                if (x) {
                  var G = e.find(x.parameters, function(Oe) {
                    return Oe.name.kind === 79 && Oe.name.escapedText === c;
                  });
                  return G && G.symbol;
                }
              }
            }
            e.getParameterSymbolFromJSDoc = no;
            function Go(n) {
              if (e.isJSDoc(n.parent) && n.parent.tags) {
                var c = e.find(n.parent.tags, Ta);
                if (c)
                  return c;
              }
              return Ii(n);
            }
            e.getEffectiveContainerForJSDocTemplateTag = Go;
            function Ii(n) {
              var c = Fa(n);
              if (c)
                return e.isPropertySignature(c) && c.type && e.isFunctionLike(c.type) ? c.type : e.isFunctionLike(c) ? c : void 0;
            }
            e.getHostSignatureFromJSDoc = Ii;
            function Fa(n) {
              var c = io(n);
              if (c)
                return Eo(c) || bo(c) || to(c) || Aa(c) || To(c) || c;
            }
            e.getEffectiveJSDocHost = Fa;
            function io(n) {
              var c = Do(n);
              if (c) {
                var x = c.parent;
                if (x && x.jsDoc && c === e.lastOrUndefined(x.jsDoc))
                  return x;
              }
            }
            e.getJSDocHost = io;
            function Do(n) {
              return e.findAncestor(n.parent, e.isJSDoc);
            }
            e.getJSDocRoot = Do;
            function xo(n) {
              var c = n.name.escapedText, x = n.parent.parent.parent.typeParameters;
              return x && e.find(x, function(G) {
                return G.name.escapedText === c;
              });
            }
            e.getTypeParameterFromJsDoc = xo;
            function Xo(n) {
              return !!n.typeArguments;
            }
            e.hasTypeArguments = Xo;
            var $o;
            (function(n) {
              n[n.None = 0] = "None", n[n.Definite = 1] = "Definite", n[n.Compound = 2] = "Compound";
            })($o = e.AssignmentKind || (e.AssignmentKind = {}));
            function zi(n) {
              for (var c = n.parent; ; ) {
                switch (c.kind) {
                  case 223:
                    var x = c.operatorToken.kind;
                    return Ia(x) && c.left === n ? x === 63 || ls(x) ? 1 : 2 : 0;
                  case 221:
                  case 222:
                    var G = c.operator;
                    return G === 45 || G === 46 ? 2 : 0;
                  case 246:
                  case 247:
                    return c.initializer === n ? 1 : 0;
                  case 214:
                  case 206:
                  case 227:
                  case 232:
                    n = c;
                    break;
                  case 301:
                    n = c.parent;
                    break;
                  case 300:
                    if (c.name !== n)
                      return 0;
                    n = c.parent;
                    break;
                  case 299:
                    if (c.name === n)
                      return 0;
                    n = c.parent;
                    break;
                  default:
                    return 0;
                }
                c = n.parent;
              }
            }
            e.getAssignmentTargetKind = zi;
            function Ms(n) {
              return zi(n) !== 0;
            }
            e.isAssignmentTarget = Ms;
            function wo(n) {
              switch (n.kind) {
                case 238:
                case 240:
                case 251:
                case 242:
                case 252:
                case 266:
                case 292:
                case 293:
                case 253:
                case 245:
                case 246:
                case 247:
                case 243:
                case 244:
                case 255:
                case 295:
                  return true;
              }
              return false;
            }
            e.isNodeWithPossibleHoistedDeclaration = wo;
            function l(n) {
              return e.isFunctionExpression(n) || e.isArrowFunction(n) || e.isMethodOrAccessor(n) || e.isFunctionDeclaration(n) || e.isConstructorDeclaration(n);
            }
            e.isValueSignatureDeclaration = l;
            function A(n, c) {
              for (; n && n.kind === c; )
                n = n.parent;
              return n;
            }
            function M(n) {
              return A(n, 193);
            }
            e.walkUpParenthesizedTypes = M;
            function ke(n) {
              return A(n, 214);
            }
            e.walkUpParenthesizedExpressions = ke;
            function cr(n) {
              for (var c; n && n.kind === 193; )
                c = n, n = n.parent;
              return [c, n];
            }
            e.walkUpParenthesizedTypesAndGetParentAndChild = cr;
            function Zr(n) {
              for (; e.isParenthesizedTypeNode(n); )
                n = n.type;
              return n;
            }
            e.skipTypeParentheses = Zr;
            function _t(n, c) {
              var x = c ? 17 : 1;
              return e.skipOuterExpressions(n, x);
            }
            e.skipParentheses = _t;
            function Rt(n) {
              return n.kind !== 208 && n.kind !== 209 ? false : (n = ke(n.parent), n && n.kind === 217);
            }
            e.isDeleteTarget = Rt;
            function un(n, c) {
              for (; n; ) {
                if (n === c)
                  return true;
                n = n.parent;
              }
              return false;
            }
            e.isNodeDescendantOf = un;
            function bn(n) {
              return !e.isSourceFile(n) && !e.isBindingPattern(n) && e.isDeclaration(n.parent) && n.parent.name === n;
            }
            e.isDeclarationName = bn;
            function _n(n) {
              var c = n.parent;
              switch (n.kind) {
                case 10:
                case 14:
                case 8:
                  if (e.isComputedPropertyName(c))
                    return c.parent;
                case 79:
                  if (e.isDeclaration(c))
                    return c.name === n ? c : void 0;
                  if (e.isQualifiedName(c)) {
                    var x = c.parent;
                    return e.isJSDocParameterTag(x) && x.name === c ? x : void 0;
                  } else {
                    var G = c.parent;
                    return e.isBinaryExpression(G) && it2(G) !== 0 && (G.left.symbol || G.symbol) && e.getNameOfDeclaration(G) === n ? G : void 0;
                  }
                case 80:
                  return e.isDeclaration(c) && c.name === n ? c : void 0;
                default:
                  return;
              }
            }
            e.getDeclarationFromName = _n;
            function Nt(n) {
              return Pa(n) && n.parent.kind === 164 && e.isDeclaration(n.parent.parent);
            }
            e.isLiteralComputedPropertyDeclarationName = Nt;
            function Ft(n) {
              var c = n.parent;
              switch (c.kind) {
                case 169:
                case 168:
                case 171:
                case 170:
                case 174:
                case 175:
                case 302:
                case 299:
                case 208:
                  return c.name === n;
                case 163:
                  return c.right === n;
                case 205:
                case 273:
                  return c.propertyName === n;
                case 278:
                case 288:
                case 282:
                case 283:
                case 284:
                  return true;
              }
              return false;
            }
            e.isIdentifierName = Ft;
            function Sn(n) {
              return n.kind === 268 || n.kind === 267 || n.kind === 270 && n.name || n.kind === 271 || n.kind === 277 || n.kind === 273 || n.kind === 278 || n.kind === 274 && Ji(n) ? true : hr(n) && (e.isBinaryExpression(n) && it2(n) === 2 && Ji(n) || e.isPropertyAccessExpression(n) && e.isBinaryExpression(n.parent) && n.parent.left === n && n.parent.operatorToken.kind === 63 && Wn(n.parent.right));
            }
            e.isAliasSymbolDeclaration = Sn;
            function wn(n) {
              switch (n.parent.kind) {
                case 270:
                case 273:
                case 271:
                case 278:
                case 274:
                case 268:
                case 277:
                  return n.parent;
                case 163:
                  do
                    n = n.parent;
                  while (n.parent.kind === 163);
                  return wn(n);
              }
            }
            e.getAliasDeclarationFromName = wn;
            function Wn(n) {
              return Ma(n) || e.isClassExpression(n);
            }
            e.isAliasableExpression = Wn;
            function Ji(n) {
              var c = Ba(n);
              return Wn(c);
            }
            e.exportAssignmentIsAlias = Ji;
            function Ba(n) {
              return e.isExportAssignment(n) ? n.expression : n.right;
            }
            e.getExportAssignmentExpression = Ba;
            function Ao(n) {
              return n.kind === 300 ? n.name : n.kind === 299 ? n.initializer : n.parent.right;
            }
            e.getPropertyAssignmentAliasLikeExpression = Ao;
            function ko(n) {
              var c = Po(n);
              if (c && hr(n)) {
                var x = e.getJSDocAugmentsTag(n);
                if (x)
                  return x.class;
              }
              return c;
            }
            e.getEffectiveBaseTypeNode = ko;
            function Po(n) {
              var c = No(n.heritageClauses, 94);
              return c && c.types.length > 0 ? c.types[0] : void 0;
            }
            e.getClassExtendsHeritageElement = Po;
            function ao(n) {
              if (hr(n))
                return e.getJSDocImplementsTags(n).map(function(x) {
                  return x.class;
                });
              var c = No(n.heritageClauses, 117);
              return c == null ? void 0 : c.types;
            }
            e.getEffectiveImplementsTypeNodes = ao;
            function Vc(n) {
              return e.isInterfaceDeclaration(n) ? Ls(n) || e.emptyArray : e.isClassLike(n) && e.concatenate(e.singleElementArray(ko(n)), ao(n)) || e.emptyArray;
            }
            e.getAllSuperTypeNodes = Vc;
            function Ls(n) {
              var c = No(n.heritageClauses, 94);
              return c ? c.types : void 0;
            }
            e.getInterfaceBaseTypeNodes = Ls;
            function No(n, c) {
              if (n)
                for (var x = 0, G = n; x < G.length; x++) {
                  var Oe = G[x];
                  if (Oe.token === c)
                    return Oe;
                }
            }
            e.getHeritageClause = No;
            function Rs(n, c) {
              for (; n; ) {
                if (n.kind === c)
                  return n;
                n = n.parent;
              }
            }
            e.getAncestor = Rs;
            function Qo(n) {
              return 81 <= n && n <= 162;
            }
            e.isKeyword = Qo;
            function Yo(n) {
              return 126 <= n && n <= 162;
            }
            e.isContextualKeyword = Yo;
            function w_(n) {
              return Qo(n) && !Yo(n);
            }
            e.isNonContextualKeyword = w_;
            function js(n) {
              return 117 <= n && n <= 125;
            }
            e.isFutureReservedKeyword = js;
            function Js(n) {
              var c = e.stringToToken(n);
              return c !== void 0 && w_(c);
            }
            e.isStringANonContextualKeyword = Js;
            function Fs(n) {
              var c = e.stringToToken(n);
              return c !== void 0 && Qo(c);
            }
            e.isStringAKeyword = Fs;
            function oo(n) {
              var c = n.originalKeywordKind;
              return !!c && !Yo(c);
            }
            e.isIdentifierANonContextualKeyword = oo;
            function A_(n) {
              return 2 <= n && n <= 7;
            }
            e.isTrivia = A_;
            var Wc;
            (function(n) {
              n[n.Normal = 0] = "Normal", n[n.Generator = 1] = "Generator", n[n.Async = 2] = "Async", n[n.Invalid = 4] = "Invalid", n[n.AsyncGenerator = 3] = "AsyncGenerator";
            })(Wc = e.FunctionFlags || (e.FunctionFlags = {}));
            function Kc(n) {
              if (!n)
                return 4;
              var c = 0;
              switch (n.kind) {
                case 259:
                case 215:
                case 171:
                  n.asteriskToken && (c |= 1);
                case 216:
                  ia(n, 512) && (c |= 2);
                  break;
              }
              return n.body || (c |= 4), c;
            }
            e.getFunctionFlags = Kc;
            function Bs(n) {
              switch (n.kind) {
                case 259:
                case 215:
                case 216:
                case 171:
                  return n.body !== void 0 && n.asteriskToken === void 0 && ia(n, 512);
              }
              return false;
            }
            e.isAsyncFunction = Bs;
            function Pa(n) {
              return e.isStringLiteralLike(n) || e.isNumericLiteral(n);
            }
            e.isStringOrNumericLiteralLike = Pa;
            function Io(n) {
              return e.isPrefixUnaryExpression(n) && (n.operator === 39 || n.operator === 40) && e.isNumericLiteral(n.operand);
            }
            e.isSignedNumericLiteral = Io;
            function qs(n) {
              var c = e.getNameOfDeclaration(n);
              return !!c && Oo(c);
            }
            e.hasDynamicName = qs;
            function Oo(n) {
              if (!(n.kind === 164 || n.kind === 209))
                return false;
              var c = e.isElementAccessExpression(n) ? _t(n.argumentExpression) : n.expression;
              return !Pa(c) && !Io(c);
            }
            e.isDynamicName = Oo;
            function so(n) {
              switch (n.kind) {
                case 79:
                case 80:
                  return n.escapedText;
                case 10:
                case 8:
                  return e.escapeLeadingUnderscores(n.text);
                case 164:
                  var c = n.expression;
                  return Pa(c) ? e.escapeLeadingUnderscores(c.text) : Io(c) ? c.operator === 40 ? e.tokenToString(c.operator) + c.operand.text : c.operand.text : void 0;
                default:
                  return e.Debug.assertNever(n);
              }
            }
            e.getPropertyNameForPropertyNameNode = so;
            function Us(n) {
              switch (n.kind) {
                case 79:
                case 10:
                case 14:
                case 8:
                  return true;
                default:
                  return false;
              }
            }
            e.isPropertyNameLiteral = Us;
            function Zo(n) {
              return e.isMemberName(n) ? e.idText(n) : n.text;
            }
            e.getTextOfIdentifierOrLiteral = Zo;
            function k_(n) {
              return e.isMemberName(n) ? n.escapedText : e.escapeLeadingUnderscores(n.text);
            }
            e.getEscapedTextOfIdentifierOrLiteral = k_;
            function zs(n) {
              return "__@".concat(e.getSymbolId(n), "@").concat(n.escapedName);
            }
            e.getPropertyNameForUniqueESSymbol = zs;
            function P_(n, c) {
              return "__#".concat(e.getSymbolId(n), "@").concat(c);
            }
            e.getSymbolNameForPrivateIdentifier = P_;
            function Hc(n) {
              return e.startsWith(n.escapedName, "__@");
            }
            e.isKnownSymbol = Hc;
            function Vs(n) {
              return e.startsWith(n.escapedName, "__#");
            }
            e.isPrivateIdentifierSymbol = Vs;
            function N_(n) {
              return n.kind === 79 && n.escapedText === "Symbol";
            }
            e.isESSymbolIdentifier = N_;
            function Gc(n) {
              return n.escapedText === "push" || n.escapedText === "unshift";
            }
            e.isPushOrUnshiftIdentifier = Gc;
            function Un(n) {
              var c = ua(n);
              return c.kind === 166;
            }
            e.isParameterDeclaration = Un;
            function ua(n) {
              for (; n.kind === 205; )
                n = n.parent.parent;
              return n;
            }
            e.getRootDeclaration = ua;
            function I_(n) {
              var c = n.kind;
              return c === 173 || c === 215 || c === 259 || c === 216 || c === 171 || c === 174 || c === 175 || c === 264 || c === 308;
            }
            e.nodeStartsNewLexicalEnvironment = I_;
            function Sa(n) {
              return Jc(n.pos) || Jc(n.end);
            }
            e.nodeIsSynthesized = Sa;
            function O_(n) {
              return e.getParseTreeNode(n, e.isSourceFile) || n;
            }
            e.getOriginalSourceFile = O_;
            var pi;
            (function(n) {
              n[n.Left = 0] = "Left", n[n.Right = 1] = "Right";
            })(pi = e.Associativity || (e.Associativity = {}));
            function Na(n) {
              var c = Ws(n), x = n.kind === 211 && n.arguments !== void 0;
              return wi(n.kind, c, x);
            }
            e.getExpressionAssociativity = Na;
            function wi(n, c, x) {
              switch (n) {
                case 211:
                  return x ? 0 : 1;
                case 221:
                case 218:
                case 219:
                case 217:
                case 220:
                case 224:
                case 226:
                  return 1;
                case 223:
                  switch (c) {
                    case 42:
                    case 63:
                    case 64:
                    case 65:
                    case 67:
                    case 66:
                    case 68:
                    case 69:
                    case 70:
                    case 71:
                    case 72:
                    case 73:
                    case 78:
                    case 74:
                    case 75:
                    case 76:
                    case 77:
                      return 1;
                  }
              }
              return 0;
            }
            e.getOperatorAssociativity = wi;
            function M_(n) {
              var c = Ws(n), x = n.kind === 211 && n.arguments !== void 0;
              return Ks(n.kind, c, x);
            }
            e.getExpressionPrecedence = M_;
            function Ws(n) {
              return n.kind === 223 ? n.operatorToken.kind : n.kind === 221 || n.kind === 222 ? n.operator : n.kind;
            }
            e.getOperator = Ws;
            var L_;
            (function(n) {
              n[n.Comma = 0] = "Comma", n[n.Spread = 1] = "Spread", n[n.Yield = 2] = "Yield", n[n.Assignment = 3] = "Assignment", n[n.Conditional = 4] = "Conditional", n[n.Coalesce = 4] = "Coalesce", n[n.LogicalOR = 5] = "LogicalOR", n[n.LogicalAND = 6] = "LogicalAND", n[n.BitwiseOR = 7] = "BitwiseOR", n[n.BitwiseXOR = 8] = "BitwiseXOR", n[n.BitwiseAND = 9] = "BitwiseAND", n[n.Equality = 10] = "Equality", n[n.Relational = 11] = "Relational", n[n.Shift = 12] = "Shift", n[n.Additive = 13] = "Additive", n[n.Multiplicative = 14] = "Multiplicative", n[n.Exponentiation = 15] = "Exponentiation", n[n.Unary = 16] = "Unary", n[n.Update = 17] = "Update", n[n.LeftHandSide = 18] = "LeftHandSide", n[n.Member = 19] = "Member", n[n.Primary = 20] = "Primary", n[n.Highest = 20] = "Highest", n[n.Lowest = 0] = "Lowest", n[n.Invalid = -1] = "Invalid";
            })(L_ = e.OperatorPrecedence || (e.OperatorPrecedence = {}));
            function Ks(n, c, x) {
              switch (n) {
                case 354:
                  return 0;
                case 227:
                  return 1;
                case 226:
                  return 2;
                case 224:
                  return 4;
                case 223:
                  switch (c) {
                    case 27:
                      return 0;
                    case 63:
                    case 64:
                    case 65:
                    case 67:
                    case 66:
                    case 68:
                    case 69:
                    case 70:
                    case 71:
                    case 72:
                    case 73:
                    case 78:
                    case 74:
                    case 75:
                    case 76:
                    case 77:
                      return 3;
                    default:
                      return R_(c);
                  }
                case 213:
                case 232:
                case 221:
                case 218:
                case 219:
                case 217:
                case 220:
                  return 16;
                case 222:
                  return 17;
                case 210:
                  return 18;
                case 211:
                  return x ? 19 : 18;
                case 212:
                case 208:
                case 209:
                case 233:
                  return 19;
                case 231:
                case 235:
                  return 11;
                case 108:
                case 106:
                case 79:
                case 80:
                case 104:
                case 110:
                case 95:
                case 8:
                case 9:
                case 10:
                case 206:
                case 207:
                case 215:
                case 216:
                case 228:
                case 13:
                case 14:
                case 225:
                case 214:
                case 229:
                case 281:
                case 282:
                case 285:
                  return 20;
                default:
                  return -1;
              }
            }
            e.getOperatorPrecedence = Ks;
            function R_(n) {
              switch (n) {
                case 60:
                  return 4;
                case 56:
                  return 5;
                case 55:
                  return 6;
                case 51:
                  return 7;
                case 52:
                  return 8;
                case 50:
                  return 9;
                case 34:
                case 35:
                case 36:
                case 37:
                  return 10;
                case 29:
                case 31:
                case 32:
                case 33:
                case 102:
                case 101:
                case 128:
                case 150:
                  return 11;
                case 47:
                case 48:
                case 49:
                  return 12;
                case 39:
                case 40:
                  return 13;
                case 41:
                case 43:
                case 44:
                  return 14;
                case 42:
                  return 15;
              }
              return -1;
            }
            e.getBinaryOperatorPrecedence = R_;
            function j_(n) {
              return e.filter(n, function(c) {
                switch (c.kind) {
                  case 291:
                    return !!c.expression;
                  case 11:
                    return !c.containsOnlyTriviaWhiteSpaces;
                  default:
                    return true;
                }
              });
            }
            e.getSemanticJsxChildren = j_;
            function J_() {
              var n = [], c = [], x = new e.Map(), G = false;
              return { add: mr, lookup: Oe, getGlobalDiagnostics: Tr, getDiagnostics: Qr };
              function Oe(bt) {
                var lt;
                if (bt.file ? lt = x.get(bt.file.fileName) : lt = n, !!lt) {
                  var Yt = e.binarySearch(lt, bt, e.identity, Mc);
                  if (Yt >= 0)
                    return lt[Yt];
                }
              }
              function mr(bt) {
                var lt;
                bt.file ? (lt = x.get(bt.file.fileName), lt || (lt = [], x.set(bt.file.fileName, lt), e.insertSorted(c, bt.file.fileName, e.compareStringsCaseSensitive))) : (G && (G = false, n = n.slice()), lt = n), e.insertSorted(lt, bt, Mc);
              }
              function Tr() {
                return G = true, n;
              }
              function Qr(bt) {
                if (bt)
                  return x.get(bt) || [];
                var lt = e.flatMapToMutable(c, function(Yt) {
                  return x.get(Yt);
                });
                return n.length && lt.unshift.apply(lt, n), lt;
              }
            }
            e.createDiagnosticCollection = J_;
            var Xc = /\$\{/g;
            function F_(n) {
              return n.replace(Xc, "\\${");
            }
            function B_(n) {
              return n && !!(e.isNoSubstitutionTemplateLiteral(n) ? n.templateFlags : n.head.templateFlags || e.some(n.templateSpans, function(c) {
                return !!c.literal.templateFlags;
              }));
            }
            e.hasInvalidEscape = B_;
            var q_ = /[\\\"\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g, Hs = /[\\\'\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g, $c = /\r\n|[\\\`\u0000-\u001f\t\v\f\b\r\u2028\u2029\u0085]/g, Mo = new e.Map(e.getEntries({ "	": "\\t", "\v": "\\v", "\f": "\\f", "\b": "\\b", "\r": "\\r", "\n": "\\n", "\\": "\\\\", '"': '\\"', "'": "\\'", "`": "\\`", "\u2028": "\\u2028", "\u2029": "\\u2029", "\x85": "\\u0085", "\r\n": "\\r\\n" }));
            function Gs(n) {
              var c = n.toString(16).toUpperCase(), x = ("0000" + c).slice(-4);
              return "\\u" + x;
            }
            function Xs(n, c, x) {
              if (n.charCodeAt(0) === 0) {
                var G = x.charCodeAt(c + n.length);
                return G >= 48 && G <= 57 ? "\\x00" : "\\0";
              }
              return Mo.get(n) || Gs(n.charCodeAt(0));
            }
            function Lo(n, c) {
              var x = c === 96 ? $c : c === 39 ? Hs : q_;
              return n.replace(x, Xs);
            }
            e.escapeString = Lo;
            var $s = /[^\u0000-\u007F]/g;
            function _o(n, c) {
              return n = Lo(n, c), $s.test(n) ? n.replace($s, function(x) {
                return Gs(x.charCodeAt(0));
              }) : n;
            }
            e.escapeNonAsciiString = _o;
            var U_ = /[\"\u0000-\u001f\u2028\u2029\u0085]/g, z_ = /[\'\u0000-\u001f\u2028\u2029\u0085]/g, V_ = new e.Map(e.getEntries({ '"': "&quot;", "'": "&apos;" }));
            function Qc(n) {
              var c = n.toString(16).toUpperCase();
              return "&#x" + c + ";";
            }
            function W_(n) {
              return n.charCodeAt(0) === 0 ? "&#0;" : V_.get(n) || Qc(n.charCodeAt(0));
            }
            function K_(n, c) {
              var x = c === 39 ? z_ : U_;
              return n.replace(x, W_);
            }
            e.escapeJsxAttributeString = K_;
            function H_(n) {
              var c = n.length;
              return c >= 2 && n.charCodeAt(0) === n.charCodeAt(c - 1) && G_(n.charCodeAt(0)) ? n.substring(1, c - 1) : n;
            }
            e.stripQuotes = H_;
            function G_(n) {
              return n === 39 || n === 34 || n === 96;
            }
            function Ca(n) {
              var c = n.charCodeAt(0);
              return c >= 97 && c <= 122 || e.stringContains(n, "-") || e.stringContains(n, ":");
            }
            e.isIntrinsicJsxName = Ca;
            var qa = ["", "    "];
            function es(n) {
              for (var c = qa[1], x = qa.length; x <= n; x++)
                qa.push(qa[x - 1] + c);
              return qa[n];
            }
            e.getIndentString = es;
            function ta() {
              return qa[1].length;
            }
            e.getIndentSize = ta;
            function Qs() {
              return e.stringContains(e.version, "-dev") || e.stringContains(e.version, "-insiders");
            }
            e.isNightly = Qs;
            function Yc(n) {
              var c, x, G, Oe, mr, Tr = false;
              function Qr(Nn) {
                var va = e.computeLineStarts(Nn);
                va.length > 1 ? (Oe = Oe + va.length - 1, mr = c.length - Nn.length + e.last(va), G = mr - c.length === 0) : G = false;
              }
              function bt(Nn) {
                Nn && Nn.length && (G && (Nn = es(x) + Nn, G = false), c += Nn, Qr(Nn));
              }
              function lt(Nn) {
                Nn && (Tr = false), bt(Nn);
              }
              function Yt(Nn) {
                Nn && (Tr = true), bt(Nn);
              }
              function gn() {
                c = "", x = 0, G = true, Oe = 0, mr = 0, Tr = false;
              }
              function ci(Nn) {
                Nn !== void 0 && (c += Nn, Qr(Nn), Tr = false);
              }
              function ai(Nn) {
                Nn && Nn.length && lt(Nn);
              }
              function zn(Nn) {
                (!G || Nn) && (c += n, Oe++, mr = c.length, G = true, Tr = false);
              }
              function Yi() {
                return G ? c.length : c.length + n.length;
              }
              return gn(), { write: lt, rawWrite: ci, writeLiteral: ai, writeLine: zn, increaseIndent: function() {
                x++;
              }, decreaseIndent: function() {
                x--;
              }, getIndent: function() {
                return x;
              }, getTextPos: function() {
                return c.length;
              }, getLine: function() {
                return Oe;
              }, getColumn: function() {
                return G ? x * ta() : c.length - mr;
              }, getText: function() {
                return c;
              }, isAtStartOfLine: function() {
                return G;
              }, hasTrailingComment: function() {
                return Tr;
              }, hasTrailingWhitespace: function() {
                return !!c.length && e.isWhiteSpaceLike(c.charCodeAt(c.length - 1));
              }, clear: gn, reportInaccessibleThisError: e.noop, reportPrivateInBaseOfClassExpression: e.noop, reportInaccessibleUniqueSymbolError: e.noop, trackSymbol: function() {
                return false;
              }, writeKeyword: lt, writeOperator: lt, writeParameter: lt, writeProperty: lt, writePunctuation: lt, writeSpace: lt, writeStringLiteral: lt, writeSymbol: function(Nn, va) {
                return lt(Nn);
              }, writeTrailingSemicolon: lt, writeComment: Yt, getTextPosWithWriteLine: Yi };
            }
            e.createTextWriter = Yc;
            function co(n) {
              var c = false;
              function x() {
                c && (n.writeTrailingSemicolon(";"), c = false);
              }
              return T(T({}, n), { writeTrailingSemicolon: function() {
                c = true;
              }, writeLiteral: function(G) {
                x(), n.writeLiteral(G);
              }, writeStringLiteral: function(G) {
                x(), n.writeStringLiteral(G);
              }, writeSymbol: function(G, Oe) {
                x(), n.writeSymbol(G, Oe);
              }, writePunctuation: function(G) {
                x(), n.writePunctuation(G);
              }, writeKeyword: function(G) {
                x(), n.writeKeyword(G);
              }, writeOperator: function(G) {
                x(), n.writeOperator(G);
              }, writeParameter: function(G) {
                x(), n.writeParameter(G);
              }, writeSpace: function(G) {
                x(), n.writeSpace(G);
              }, writeProperty: function(G) {
                x(), n.writeProperty(G);
              }, writeComment: function(G) {
                x(), n.writeComment(G);
              }, writeLine: function() {
                x(), n.writeLine();
              }, increaseIndent: function() {
                x(), n.increaseIndent();
              }, decreaseIndent: function() {
                x(), n.decreaseIndent();
              } });
            }
            e.getTrailingSemicolonDeferringWriter = co;
            function X_(n) {
              return n.useCaseSensitiveFileNames ? n.useCaseSensitiveFileNames() : false;
            }
            e.hostUsesCaseSensitiveFileNames = X_;
            function Ys(n) {
              return e.createGetCanonicalFileName(X_(n));
            }
            e.hostGetCanonicalFileName = Ys;
            function Zs(n, c, x) {
              return c.moduleName || rs(n, c.fileName, x && x.fileName);
            }
            e.getResolvedExternalModuleName = Zs;
            function $_(n, c) {
              return n.getCanonicalFileName(e.getNormalizedAbsolutePath(c, n.getCurrentDirectory()));
            }
            function Q_(n, c, x) {
              var G = c.getExternalModuleFileFromDeclaration(x);
              if (!(!G || G.isDeclarationFile)) {
                var Oe = ji(x);
                if (!(Oe && e.isStringLiteralLike(Oe) && !e.pathIsRelative(Oe.text) && $_(n, G.path).indexOf($_(n, e.ensureTrailingDirectorySeparator(n.getCommonSourceDirectory()))) === -1))
                  return Zs(n, G);
              }
            }
            e.getExternalModuleNameFromDeclaration = Q_;
            function rs(n, c, x) {
              var G = function(bt) {
                return n.getCanonicalFileName(bt);
              }, Oe = e.toPath(x ? e.getDirectoryPath(x) : n.getCommonSourceDirectory(), n.getCurrentDirectory(), G), mr = e.getNormalizedAbsolutePath(c, n.getCurrentDirectory()), Tr = e.getRelativePathToDirectoryOrUrl(Oe, mr, Oe, G, false), Qr = Pu(Tr);
              return x ? e.ensurePathIsNonModuleName(Qr) : Qr;
            }
            e.getExternalModuleNameFromPath = rs;
            function Y_(n, c, x) {
              var G = c.getCompilerOptions(), Oe;
              return G.outDir ? Oe = Pu(Ro(n, c, G.outDir)) : Oe = Pu(n), Oe + x;
            }
            e.getOwnEmitOutputFilePath = Y_;
            function Z_(n, c) {
              return ts(n, c.getCompilerOptions(), c.getCurrentDirectory(), c.getCommonSourceDirectory(), function(x) {
                return c.getCanonicalFileName(x);
              });
            }
            e.getDeclarationEmitOutputFilePath = Z_;
            function ts(n, c, x, G, Oe) {
              var mr = c.declarationDir || c.outDir, Tr = mr ? t_(n, mr, x, G, Oe) : n, Qr = ec(Tr);
              return Pu(Tr) + Qr;
            }
            e.getDeclarationEmitOutputFilePathWorker = ts;
            function ec(n) {
              return e.fileExtensionIsOneOf(n, [".mjs", ".mts"]) ? ".d.mts" : e.fileExtensionIsOneOf(n, [".cjs", ".cts"]) ? ".d.cts" : e.fileExtensionIsOneOf(n, [".json"]) ? ".json.d.ts" : ".d.ts";
            }
            e.getDeclarationEmitExtensionForPath = ec;
            function Zc(n) {
              return e.fileExtensionIsOneOf(n, [".d.mts", ".mjs", ".mts"]) ? [".mts", ".mjs"] : e.fileExtensionIsOneOf(n, [".d.cts", ".cjs", ".cts"]) ? [".cts", ".cjs"] : e.fileExtensionIsOneOf(n, [".json.d.ts"]) ? [".json"] : [".tsx", ".ts", ".jsx", ".js"];
            }
            e.getPossibleOriginalInputExtensionForExtension = Zc;
            function e_(n) {
              return n.outFile || n.out;
            }
            e.outFile = e_;
            function eu(n, c) {
              var x, G;
              if (n.paths)
                return (x = n.baseUrl) !== null && x !== void 0 ? x : e.Debug.checkDefined(n.pathsBasePath || ((G = c.getCurrentDirectory) === null || G === void 0 ? void 0 : G.call(c)), "Encountered 'paths' without a 'baseUrl', config file, or host 'getCurrentDirectory'.");
            }
            e.getPathsBasePath = eu;
            function rc(n, c, x) {
              var G = n.getCompilerOptions();
              if (e_(G)) {
                var Oe = Vi(G), mr = G.emitDeclarationOnly || Oe === e.ModuleKind.AMD || Oe === e.ModuleKind.System;
                return e.filter(n.getSourceFiles(), function(Qr) {
                  return (mr || !e.isExternalModule(Qr)) && r_(Qr, n, x);
                });
              } else {
                var Tr = c === void 0 ? n.getSourceFiles() : [c];
                return e.filter(Tr, function(Qr) {
                  return r_(Qr, n, x);
                });
              }
            }
            e.getSourceFilesToEmit = rc;
            function r_(n, c, x) {
              var G = c.getCompilerOptions();
              return !(G.noEmitForJsFiles && Ir(n)) && !n.isDeclarationFile && !c.isSourceFileFromExternalLibrary(n) && (x || !(ui(n) && c.getResolvedProjectReferenceToRedirect(n.fileName)) && !c.isSourceOfProjectReferenceRedirect(n.fileName));
            }
            e.sourceFileMayBeEmitted = r_;
            function Ro(n, c, x) {
              return t_(n, x, c.getCurrentDirectory(), c.getCommonSourceDirectory(), function(G) {
                return c.getCanonicalFileName(G);
              });
            }
            e.getSourceFilePathInNewDir = Ro;
            function t_(n, c, x, G, Oe) {
              var mr = e.getNormalizedAbsolutePath(n, x), Tr = Oe(mr).indexOf(Oe(G)) === 0;
              return mr = Tr ? mr.substring(G.length) : mr, e.combinePaths(c, mr);
            }
            e.getSourceFilePathInNewDirWorker = t_;
            function tc(n, c, x, G, Oe, mr, Tr) {
              n.writeFile(x, G, Oe, function(Qr) {
                c.add(pa(e.Diagnostics.Could_not_write_file_0_Colon_1, x, Qr));
              }, mr, Tr);
            }
            e.writeFile = tc;
            function jo(n, c, x) {
              if (n.length > e.getRootLength(n) && !x(n)) {
                var G = e.getDirectoryPath(n);
                jo(G, c, x), c(n);
              }
            }
            function na(n, c, x, G, Oe, mr) {
              try {
                G(n, c, x);
              } catch {
                jo(e.getDirectoryPath(e.normalizePath(n)), Oe, mr), G(n, c, x);
              }
            }
            e.writeFileEnsuringDirectories = na;
            function Qi(n, c) {
              var x = e.getLineStarts(n);
              return e.computeLineOfPosition(x, c);
            }
            e.getLineOfLocalPosition = Qi;
            function la(n, c) {
              return e.computeLineOfPosition(n, c);
            }
            e.getLineOfLocalPositionFromLineMap = la;
            function n_(n) {
              return e.find(n.members, function(c) {
                return e.isConstructorDeclaration(c) && er(c.body);
              });
            }
            e.getFirstConstructorWithBody = n_;
            function uo(n) {
              if (n && n.parameters.length > 0) {
                var c = n.parameters.length === 2 && ns(n.parameters[0]);
                return n.parameters[c ? 1 : 0];
              }
            }
            e.getSetAccessorValueParameter = uo;
            function ru(n) {
              var c = uo(n);
              return c && c.type;
            }
            e.getSetAccessorTypeAnnotationNode = ru;
            function i_(n) {
              if (n.parameters.length && !e.isJSDocSignature(n)) {
                var c = n.parameters[0];
                if (ns(c))
                  return c;
              }
            }
            e.getThisParameter = i_;
            function ns(n) {
              return is(n.name);
            }
            e.parameterIsThisKeyword = ns;
            function is(n) {
              return !!n && n.kind === 79 && a_(n);
            }
            e.isThisIdentifier = is;
            function nc(n) {
              if (!is(n))
                return false;
              for (; e.isQualifiedName(n.parent) && n.parent.left === n; )
                n = n.parent;
              return n.parent.kind === 183;
            }
            e.isThisInTypeQuery = nc;
            function a_(n) {
              return n.originalKeywordKind === 108;
            }
            e.identifierIsThisKeyword = a_;
            function ic(n, c) {
              var x, G, Oe, mr;
              return qs(c) ? (x = c, c.kind === 174 ? Oe = c : c.kind === 175 ? mr = c : e.Debug.fail("Accessor has wrong kind")) : e.forEach(n, function(Tr) {
                if (e.isAccessor(Tr) && ss(Tr) === ss(c)) {
                  var Qr = so(Tr.name), bt = so(c.name);
                  Qr === bt && (x ? G || (G = Tr) : x = Tr, Tr.kind === 174 && !Oe && (Oe = Tr), Tr.kind === 175 && !mr && (mr = Tr));
                }
              }), { firstAccessor: x, secondAccessor: G, getAccessor: Oe, setAccessor: mr };
            }
            e.getAllAccessorDeclarations = ic;
            function as(n) {
              if (!(!hr(n) && e.isFunctionDeclaration(n))) {
                var c = n.type;
                return c || !hr(n) ? c : e.isJSDocPropertyLikeTag(n) ? n.typeExpression && n.typeExpression.type : e.getJSDocType(n);
              }
            }
            e.getEffectiveTypeAnnotationNode = as;
            function o_(n) {
              return n.type;
            }
            e.getTypeAnnotationNode = o_;
            function s_(n) {
              return e.isJSDocSignature(n) ? n.type && n.type.typeExpression && n.type.typeExpression.type : n.type || (hr(n) ? e.getJSDocReturnType(n) : void 0);
            }
            e.getEffectiveReturnTypeNode = s_;
            function lo(n) {
              return e.flatMap(e.getJSDocTags(n), function(c) {
                return tu(c) ? c.typeParameters : void 0;
              });
            }
            e.getJSDocTypeParameterDeclarations = lo;
            function tu(n) {
              return e.isJSDocTemplateTag(n) && !(n.parent.kind === 323 && n.parent.tags.some(Ta));
            }
            function Ua(n) {
              var c = uo(n);
              return c && as(c);
            }
            e.getEffectiveSetAccessorTypeAnnotationNode = Ua;
            function Jo(n, c, x, G) {
              __(n, c, x.pos, G);
            }
            e.emitNewLineBeforeLeadingComments = Jo;
            function __(n, c, x, G) {
              G && G.length && x !== G[0].pos && la(n, x) !== la(n, G[0].pos) && c.writeLine();
            }
            e.emitNewLineBeforeLeadingCommentsOfPosition = __;
            function nu(n, c, x, G) {
              x !== G && la(n, x) !== la(n, G) && c.writeLine();
            }
            e.emitNewLineBeforeLeadingCommentOfPosition = nu;
            function c_(n, c, x, G, Oe, mr, Tr, Qr) {
              if (G && G.length > 0) {
                Oe && x.writeSpace(" ");
                for (var bt = false, lt = 0, Yt = G; lt < Yt.length; lt++) {
                  var gn = Yt[lt];
                  bt && (x.writeSpace(" "), bt = false), Qr(n, c, x, gn.pos, gn.end, Tr), gn.hasTrailingNewLine ? x.writeLine() : bt = true;
                }
                bt && mr && x.writeSpace(" ");
              }
            }
            e.emitComments = c_;
            function iu(n, c, x, G, Oe, mr, Tr) {
              var Qr, bt;
              if (Tr ? Oe.pos === 0 && (Qr = e.filter(e.getLeadingCommentRanges(n, Oe.pos), va)) : Qr = e.getLeadingCommentRanges(n, Oe.pos), Qr) {
                for (var lt = [], Yt = void 0, gn = 0, ci = Qr; gn < ci.length; gn++) {
                  var ai = ci[gn];
                  if (Yt) {
                    var zn = la(c, Yt.end), Yi = la(c, ai.pos);
                    if (Yi >= zn + 2)
                      break;
                  }
                  lt.push(ai), Yt = ai;
                }
                if (lt.length) {
                  var zn = la(c, e.last(lt).end), Nn = la(c, e.skipTrivia(n, Oe.pos));
                  Nn >= zn + 2 && (Jo(c, x, Oe, Qr), c_(n, c, x, lt, false, true, mr, G), bt = { nodePos: Oe.pos, detachedCommentEndPos: e.last(lt).end });
                }
              }
              return bt;
              function va(ks) {
                return he(n, ks.pos);
              }
            }
            e.emitDetachedComments = iu;
            function ac(n, c, x, G, Oe, mr) {
              if (n.charCodeAt(G + 1) === 42)
                for (var Tr = e.computeLineAndCharacterOfPosition(c, G), Qr = c.length, bt = void 0, lt = G, Yt = Tr.line; lt < Oe; Yt++) {
                  var gn = Yt + 1 === Qr ? n.length + 1 : c[Yt + 1];
                  if (lt !== G) {
                    bt === void 0 && (bt = u_(n, c[Tr.line], G));
                    var ci = x.getIndent() * ta(), ai = ci - bt + u_(n, lt, gn);
                    if (ai > 0) {
                      var zn = ai % ta(), Yi = es((ai - zn) / ta());
                      for (x.rawWrite(Yi); zn; )
                        x.rawWrite(" "), zn--;
                    } else
                      x.rawWrite("");
                  }
                  oc(n, Oe, x, mr, lt, gn), lt = gn;
                }
              else
                x.writeComment(n.substring(G, Oe));
            }
            e.writeCommentRange = ac;
            function oc(n, c, x, G, Oe, mr) {
              var Tr = Math.min(c, mr - 1), Qr = e.trimString(n.substring(Oe, Tr));
              Qr ? (x.writeComment(Qr), Tr !== c && x.writeLine()) : x.rawWrite(G);
            }
            function u_(n, c, x) {
              for (var G = 0; c < x && e.isWhiteSpaceSingleLine(n.charCodeAt(c)); c++)
                n.charCodeAt(c) === 9 ? G += ta() - G % ta() : G++;
              return G;
            }
            function au(n) {
              return d_(n) !== 0;
            }
            e.hasEffectiveModifiers = au;
            function ou(n) {
              return us(n) !== 0;
            }
            e.hasSyntacticModifiers = ou;
            function os(n, c) {
              return !!p_(n, c);
            }
            e.hasEffectiveModifier = os;
            function ia(n, c) {
              return !!f_(n, c);
            }
            e.hasSyntacticModifier = ia;
            function ss(n) {
              return e.isClassElement(n) && l_(n) || e.isClassStaticBlockDeclaration(n);
            }
            e.isStatic = ss;
            function l_(n) {
              return ia(n, 32);
            }
            e.hasStaticModifier = l_;
            function sc(n) {
              return os(n, 16384);
            }
            e.hasOverrideModifier = sc;
            function su(n) {
              return ia(n, 256);
            }
            e.hasAbstractModifier = su;
            function _c(n) {
              return ia(n, 2);
            }
            e.hasAmbientModifier = _c;
            function _u(n) {
              return ia(n, 128);
            }
            e.hasAccessorModifier = _u;
            function _s(n) {
              return os(n, 64);
            }
            e.hasEffectiveReadonlyModifier = _s;
            function cs(n) {
              return ia(n, 131072);
            }
            e.hasDecorators = cs;
            function p_(n, c) {
              return d_(n) & c;
            }
            e.getSelectedEffectiveModifierFlags = p_;
            function f_(n, c) {
              return us(n) & c;
            }
            e.getSelectedSyntacticModifierFlags = f_;
            function Fo(n, c, x) {
              return n.kind >= 0 && n.kind <= 162 ? 0 : (n.modifierFlagsCache & 536870912 || (n.modifierFlagsCache = Ai(n) | 536870912), c && !(n.modifierFlagsCache & 4096) && (x || hr(n)) && n.parent && (n.modifierFlagsCache |= m_(n) | 4096), n.modifierFlagsCache & -536875009);
            }
            function d_(n) {
              return Fo(n, true);
            }
            e.getEffectiveModifierFlags = d_;
            function Bo(n) {
              return Fo(n, true, true);
            }
            e.getEffectiveModifierFlagsAlwaysIncludeJSDoc = Bo;
            function us(n) {
              return Fo(n, false);
            }
            e.getSyntacticModifierFlags = us;
            function m_(n) {
              var c = 0;
              return n.parent && !e.isParameter(n) && (hr(n) && (e.getJSDocPublicTagNoCache(n) && (c |= 4), e.getJSDocPrivateTagNoCache(n) && (c |= 8), e.getJSDocProtectedTagNoCache(n) && (c |= 16), e.getJSDocReadonlyTagNoCache(n) && (c |= 64), e.getJSDocOverrideTagNoCache(n) && (c |= 16384)), e.getJSDocDeprecatedTagNoCache(n) && (c |= 8192)), c;
            }
            function cu(n) {
              return Ai(n) | m_(n);
            }
            e.getEffectiveModifierFlagsNoCache = cu;
            function Ai(n) {
              var c = e.canHaveModifiers(n) ? g_(n.modifiers) : 0;
              return (n.flags & 4 || n.kind === 79 && n.isInJSDocNamespace) && (c |= 1), c;
            }
            e.getSyntacticModifierFlagsNoCache = Ai;
            function g_(n) {
              var c = 0;
              if (n)
                for (var x = 0, G = n; x < G.length; x++) {
                  var Oe = G[x];
                  c |= po(Oe.kind);
                }
              return c;
            }
            e.modifiersToFlags = g_;
            function po(n) {
              switch (n) {
                case 124:
                  return 32;
                case 123:
                  return 4;
                case 122:
                  return 16;
                case 121:
                  return 8;
                case 126:
                  return 256;
                case 127:
                  return 128;
                case 93:
                  return 1;
                case 136:
                  return 2;
                case 85:
                  return 2048;
                case 88:
                  return 1024;
                case 132:
                  return 512;
                case 146:
                  return 64;
                case 161:
                  return 16384;
                case 101:
                  return 32768;
                case 145:
                  return 65536;
                case 167:
                  return 131072;
              }
              return 0;
            }
            e.modifierToFlag = po;
            function uu(n) {
              return n === 56 || n === 55 || n === 53;
            }
            e.isLogicalOperator = uu;
            function ls(n) {
              return n === 75 || n === 76 || n === 77;
            }
            e.isLogicalOrCoalescingAssignmentOperator = ls;
            function lu(n) {
              return ls(n.operatorToken.kind);
            }
            e.isLogicalOrCoalescingAssignmentExpression = lu;
            function Ia(n) {
              return n >= 63 && n <= 78;
            }
            e.isAssignmentOperator = Ia;
            function cc(n) {
              var c = y_(n);
              return c && !c.isImplements ? c.class : void 0;
            }
            e.tryGetClassExtendingExpressionWithTypeArguments = cc;
            function y_(n) {
              return e.isExpressionWithTypeArguments(n) && e.isHeritageClause(n.parent) && e.isClassLike(n.parent.parent) ? { class: n.parent.parent, isImplements: n.parent.token === 117 } : void 0;
            }
            e.tryGetClassImplementingOrExtendingExpressionWithTypeArguments = y_;
            function ps(n, c) {
              return e.isBinaryExpression(n) && (c ? n.operatorToken.kind === 63 : Ia(n.operatorToken.kind)) && e.isLeftHandSideExpression(n.left);
            }
            e.isAssignmentExpression = ps;
            function uc(n) {
              return ps(n.parent) && n.parent.left === n;
            }
            e.isLeftHandSideOfAssignment = uc;
            function h_(n) {
              if (ps(n, true)) {
                var c = n.left.kind;
                return c === 207 || c === 206;
              }
              return false;
            }
            e.isDestructuringAssignment = h_;
            function Oa(n) {
              return cc(n) !== void 0;
            }
            e.isExpressionWithTypeArgumentsInClassExtendsClause = Oa;
            function Ma(n) {
              return n.kind === 79 || v_(n);
            }
            e.isEntityNameExpression = Ma;
            function fs2(n) {
              switch (n.kind) {
                case 79:
                  return n;
                case 163:
                  do
                    n = n.left;
                  while (n.kind !== 79);
                  return n;
                case 208:
                  do
                    n = n.expression;
                  while (n.kind !== 79);
                  return n;
              }
            }
            e.getFirstIdentifier = fs2;
            function ds(n) {
              return n.kind === 79 || n.kind === 108 || n.kind === 106 || n.kind === 233 || n.kind === 208 && ds(n.expression) || n.kind === 214 && ds(n.expression);
            }
            e.isDottedName = ds;
            function v_(n) {
              return e.isPropertyAccessExpression(n) && e.isIdentifier(n.name) && Ma(n.expression);
            }
            e.isPropertyAccessEntityNameExpression = v_;
            function qo(n) {
              if (e.isPropertyAccessExpression(n)) {
                var c = qo(n.expression);
                if (c !== void 0)
                  return c + "." + ue(n.name);
              } else if (e.isElementAccessExpression(n)) {
                var c = qo(n.expression);
                if (c !== void 0 && e.isPropertyName(n.argumentExpression))
                  return c + "." + so(n.argumentExpression);
              } else if (e.isIdentifier(n))
                return e.unescapeLeadingUnderscores(n.escapedText);
            }
            e.tryGetPropertyAccessOrIdentifierToString = qo;
            function za(n) {
              return tn(n) && Qt(n) === "prototype";
            }
            e.isPrototypeAccess = za;
            function pu(n) {
              return n.parent.kind === 163 && n.parent.right === n || n.parent.kind === 208 && n.parent.name === n;
            }
            e.isRightSideOfQualifiedNameOrPropertyAccess = pu;
            function b_(n) {
              return e.isPropertyAccessExpression(n.parent) && n.parent.name === n || e.isElementAccessExpression(n.parent) && n.parent.argumentExpression === n;
            }
            e.isRightSideOfAccessExpression = b_;
            function lc(n) {
              return e.isQualifiedName(n.parent) && n.parent.right === n || e.isPropertyAccessExpression(n.parent) && n.parent.name === n || e.isJSDocMemberName(n.parent) && n.parent.right === n;
            }
            e.isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName = lc;
            function ms(n) {
              return n.kind === 207 && n.properties.length === 0;
            }
            e.isEmptyObjectLiteral = ms;
            function pc(n) {
              return n.kind === 206 && n.elements.length === 0;
            }
            e.isEmptyArrayLiteral = pc;
            function fo(n) {
              if (!(!fc(n) || !n.declarations))
                for (var c = 0, x = n.declarations; c < x.length; c++) {
                  var G = x[c];
                  if (G.localSymbol)
                    return G.localSymbol;
                }
            }
            e.getLocalSymbolForExportDefault = fo;
            function fc(n) {
              return n && e.length(n.declarations) > 0 && ia(n.declarations[0], 1024);
            }
            function fu(n) {
              return e.find(Hy, function(c) {
                return e.fileExtensionIs(n, c);
              });
            }
            e.tryExtractTSExtension = fu;
            function du(n) {
              for (var c = [], x = n.length, G = 0; G < x; G++) {
                var Oe = n.charCodeAt(G);
                Oe < 128 ? c.push(Oe) : Oe < 2048 ? (c.push(Oe >> 6 | 192), c.push(Oe & 63 | 128)) : Oe < 65536 ? (c.push(Oe >> 12 | 224), c.push(Oe >> 6 & 63 | 128), c.push(Oe & 63 | 128)) : Oe < 131072 ? (c.push(Oe >> 18 | 240), c.push(Oe >> 12 & 63 | 128), c.push(Oe >> 6 & 63 | 128), c.push(Oe & 63 | 128)) : e.Debug.assert(false, "Unexpected code point");
              }
              return c;
            }
            var ga = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
            function dc(n) {
              for (var c = "", x = du(n), G = 0, Oe = x.length, mr, Tr, Qr, bt; G < Oe; )
                mr = x[G] >> 2, Tr = (x[G] & 3) << 4 | x[G + 1] >> 4, Qr = (x[G + 1] & 15) << 2 | x[G + 2] >> 6, bt = x[G + 2] & 63, G + 1 >= Oe ? Qr = bt = 64 : G + 2 >= Oe && (bt = 64), c += ga.charAt(mr) + ga.charAt(Tr) + ga.charAt(Qr) + ga.charAt(bt), G += 3;
              return c;
            }
            e.convertToBase64 = dc;
            function mo(n) {
              for (var c = "", x = 0, G = n.length; x < G; ) {
                var Oe = n[x];
                if (Oe < 128)
                  c += String.fromCharCode(Oe), x++;
                else if ((Oe & 192) === 192) {
                  var mr = Oe & 63;
                  x++;
                  for (var Tr = n[x]; (Tr & 192) === 128; )
                    mr = mr << 6 | Tr & 63, x++, Tr = n[x];
                  c += String.fromCharCode(mr);
                } else
                  c += String.fromCharCode(Oe), x++;
              }
              return c;
            }
            function mu(n, c) {
              return n && n.base64encode ? n.base64encode(c) : dc(c);
            }
            e.base64encode = mu;
            function Va(n, c) {
              if (n && n.base64decode)
                return n.base64decode(c);
              for (var x = c.length, G = [], Oe = 0; Oe < x && c.charCodeAt(Oe) !== ga.charCodeAt(64); ) {
                var mr = ga.indexOf(c[Oe]), Tr = ga.indexOf(c[Oe + 1]), Qr = ga.indexOf(c[Oe + 2]), bt = ga.indexOf(c[Oe + 3]), lt = (mr & 63) << 2 | Tr >> 4 & 3, Yt = (Tr & 15) << 4 | Qr >> 2 & 15, gn = (Qr & 3) << 6 | bt & 63;
                Yt === 0 && Qr !== 0 ? G.push(lt) : gn === 0 && bt !== 0 ? G.push(lt, Yt) : G.push(lt, Yt, gn), Oe += 4;
              }
              return mo(G);
            }
            e.base64decode = Va;
            function Da(n, c) {
              var x = e.isString(c) ? c : c.readFile(n);
              if (x) {
                var G = e.parseConfigFileTextToJson(n, x);
                return G.error ? void 0 : G.config;
              }
            }
            e.readJsonOrUndefined = Da;
            function mc(n, c) {
              return Da(n, c) || {};
            }
            e.readJson = mc;
            function gc(n, c) {
              return !c.directoryExists || c.directoryExists(n);
            }
            e.directoryProbablyExists = gc;
            var yc = `\r
`, hc = `
`;
            function gs(n, c) {
              switch (n.newLine) {
                case 0:
                  return yc;
                case 1:
                  return hc;
              }
              return c ? c() : e.sys ? e.sys.newLine : yc;
            }
            e.getNewLineCharacter = gs;
            function ys(n, c) {
              return c === void 0 && (c = n), e.Debug.assert(c >= n || c === -1), { pos: n, end: c };
            }
            e.createRange = ys;
            function gu(n, c) {
              return ys(n.pos, c);
            }
            e.moveRangeEnd = gu;
            function hs(n, c) {
              return ys(c, n.end);
            }
            e.moveRangePos = hs;
            function vc(n) {
              var c = e.canHaveModifiers(n) ? e.findLast(n.modifiers, e.isDecorator) : void 0;
              return c && !Jc(c.end) ? hs(n, c.end) : n;
            }
            e.moveRangePastDecorators = vc;
            function yu(n) {
              var c = e.canHaveModifiers(n) ? e.lastOrUndefined(n.modifiers) : void 0;
              return c && !Jc(c.end) ? hs(n, c.end) : vc(n);
            }
            e.moveRangePastModifiers = yu;
            function vs(n) {
              return n.pos === n.end;
            }
            e.isCollapsedRange = vs;
            function bc(n, c) {
              return ys(n, n + e.tokenToString(c).length);
            }
            e.createTokenRange = bc;
            function hu(n, c) {
              return Sc(n, n, c);
            }
            e.rangeIsOnSingleLine = hu;
            function Ec(n, c, x) {
              return Wa(go(n, x, false), go(c, x, false), x);
            }
            e.rangeStartPositionsAreOnSameLine = Ec;
            function Tc(n, c, x) {
              return Wa(n.end, c.end, x);
            }
            e.rangeEndPositionsAreOnSameLine = Tc;
            function Sc(n, c, x) {
              return Wa(go(n, x, false), c.end, x);
            }
            e.rangeStartIsOnSameLineAsRangeEnd = Sc;
            function E_(n, c, x) {
              return Wa(n.end, go(c, x, false), x);
            }
            e.rangeEndIsOnSameLineAsRangeStart = E_;
            function Cc(n, c, x, G) {
              var Oe = go(c, x, G);
              return e.getLinesBetweenPositions(x, n.end, Oe);
            }
            e.getLinesBetweenRangeEndAndRangeStart = Cc;
            function Dc(n, c, x) {
              return e.getLinesBetweenPositions(x, n.end, c.end);
            }
            e.getLinesBetweenRangeEndPositions = Dc;
            function xc(n, c) {
              return !Wa(n.pos, n.end, c);
            }
            e.isNodeArrayMultiLine = xc;
            function Wa(n, c, x) {
              return e.getLinesBetweenPositions(x, n, c) === 0;
            }
            e.positionsAreOnSameLine = Wa;
            function go(n, c, x) {
              return Jc(n.pos) ? -1 : e.skipTrivia(c.text, n.pos, false, x);
            }
            e.getStartPositionOfRange = go;
            function bs(n, c, x, G) {
              var Oe = e.skipTrivia(x.text, n, false, G), mr = vu(Oe, c, x);
              return e.getLinesBetweenPositions(x, mr != null ? mr : c, Oe);
            }
            e.getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter = bs;
            function wc(n, c, x, G) {
              var Oe = e.skipTrivia(x.text, n, false, G);
              return e.getLinesBetweenPositions(x, n, Math.min(c, Oe));
            }
            e.getLinesBetweenPositionAndNextNonWhitespaceCharacter = wc;
            function vu(n, c, x) {
              for (c === void 0 && (c = 0); n-- > c; )
                if (!e.isWhiteSpaceLike(x.text.charCodeAt(n)))
                  return n;
            }
            function Es(n) {
              var c = e.getParseTreeNode(n);
              if (c)
                switch (c.parent.kind) {
                  case 263:
                  case 264:
                    return c === c.parent.name;
                }
              return false;
            }
            e.isDeclarationNameOfEnumOrNamespace = Es;
            function bu(n) {
              return e.filter(n.declarations, Eu);
            }
            e.getInitializedVariables = bu;
            function Eu(n) {
              return n.initializer !== void 0;
            }
            function T_(n) {
              return n.watch && e.hasProperty(n, "watch");
            }
            e.isWatchSet = T_;
            function Ka(n) {
              n.close();
            }
            e.closeFileWatcher = Ka;
            function Ac(n) {
              return n.flags & 33554432 ? n.checkFlags : 0;
            }
            e.getCheckFlags = Ac;
            function Tu(n, c) {
              if (c === void 0 && (c = false), n.valueDeclaration) {
                var x = c && n.declarations && e.find(n.declarations, e.isSetAccessorDeclaration) || n.flags & 32768 && e.find(n.declarations, e.isGetAccessorDeclaration) || n.valueDeclaration, G = e.getCombinedModifierFlags(x);
                return n.parent && n.parent.flags & 32 ? G : G & -29;
              }
              if (Ac(n) & 6) {
                var Oe = n.checkFlags, mr = Oe & 1024 ? 8 : Oe & 256 ? 4 : 16, Tr = Oe & 2048 ? 32 : 0;
                return mr | Tr;
              }
              return n.flags & 4194304 ? 36 : 0;
            }
            e.getDeclarationModifierFlagsFromSymbol = Tu;
            function Su(n, c) {
              return n.flags & 2097152 ? c.getAliasedSymbol(n) : n;
            }
            e.skipAlias = Su;
            function Ts(n) {
              return n.exportSymbol ? n.exportSymbol.flags | n.flags : n.flags;
            }
            e.getCombinedLocalAndExportSymbolFlags = Ts;
            function Cu(n) {
              return La(n) === 1;
            }
            e.isWriteOnlyAccess = Cu;
            function Ss(n) {
              return La(n) !== 0;
            }
            e.isWriteAccess = Ss;
            var kc;
            (function(n) {
              n[n.Read = 0] = "Read", n[n.Write = 1] = "Write", n[n.ReadWrite = 2] = "ReadWrite";
            })(kc || (kc = {}));
            function La(n) {
              var c = n.parent;
              if (!c)
                return 0;
              switch (c.kind) {
                case 214:
                  return La(c);
                case 222:
                case 221:
                  var x = c.operator;
                  return x === 45 || x === 46 ? Qr() : 0;
                case 223:
                  var G = c, Oe = G.left, mr = G.operatorToken;
                  return Oe === n && Ia(mr.kind) ? mr.kind === 63 ? 1 : Qr() : 0;
                case 208:
                  return c.name !== n ? 0 : La(c);
                case 299: {
                  var Tr = La(c.parent);
                  return n === c.name ? Du(Tr) : Tr;
                }
                case 300:
                  return n === c.objectAssignmentInitializer ? 0 : La(c.parent);
                case 206:
                  return La(c);
                default:
                  return 0;
              }
              function Qr() {
                return c.parent && ke(c.parent).kind === 241 ? 1 : 2;
              }
            }
            function Du(n) {
              switch (n) {
                case 0:
                  return 1;
                case 1:
                  return 0;
                case 2:
                  return 2;
                default:
                  return e.Debug.assertNever(n);
              }
            }
            function Ha(n, c) {
              if (!n || !c || Object.keys(n).length !== Object.keys(c).length)
                return false;
              for (var x in n)
                if (typeof n[x] == "object") {
                  if (!Ha(n[x], c[x]))
                    return false;
                } else if (typeof n[x] != "function" && n[x] !== c[x])
                  return false;
              return true;
            }
            e.compareDataObjects = Ha;
            function Pc(n, c) {
              n.forEach(c), n.clear();
            }
            e.clearMap = Pc;
            function Nc(n, c, x) {
              var G = x.onDeleteValue, Oe = x.onExistingValue;
              n.forEach(function(mr, Tr) {
                var Qr = c.get(Tr);
                Qr === void 0 ? (n.delete(Tr), G(mr, Tr)) : Oe && Oe(mr, Qr, Tr);
              });
            }
            e.mutateMapSkippingNewValues = Nc;
            function xu(n, c, x) {
              Nc(n, c, x);
              var G = x.createNewValue;
              c.forEach(function(Oe, mr) {
                n.has(mr) || n.set(mr, G(mr, Oe));
              });
            }
            e.mutateMap = xu;
            function Ic(n) {
              if (n.flags & 32) {
                var c = Cs(n);
                return !!c && ia(c, 256);
              }
              return false;
            }
            e.isAbstractConstructorSymbol = Ic;
            function Cs(n) {
              var c;
              return (c = n.declarations) === null || c === void 0 ? void 0 : c.find(e.isClassLike);
            }
            e.getClassLikeDeclarationOfSymbol = Cs;
            function S_(n) {
              return n.flags & 3899393 ? n.objectFlags : 0;
            }
            e.getObjectFlags = S_;
            function Oc(n, c) {
              return c.getSignaturesOfType(n, 0).length !== 0 || c.getSignaturesOfType(n, 1).length !== 0;
            }
            e.typeHasCallOrConstructSignatures = Oc;
            function d(n, c) {
              return !!e.forEachAncestorDirectory(n, function(x) {
                return c(x) ? true : void 0;
              });
            }
            e.forSomeAncestorDirectory = d;
            function P(n) {
              return !!n && !!n.declarations && !!n.declarations[0] && e.isNamespaceExportDeclaration(n.declarations[0]);
            }
            e.isUMDExportSymbol = P;
            function $2(n) {
              var c = n.moduleSpecifier;
              return e.isStringLiteral(c) ? c.text : ir(c);
            }
            e.showModuleSpecifier = $2;
            function ce(n) {
              var c;
              return e.forEachChild(n, function(x) {
                er(x) && (c = x);
              }, function(x) {
                for (var G = x.length - 1; G >= 0; G--)
                  if (er(x[G])) {
                    c = x[G];
                    break;
                  }
              }), c;
            }
            e.getLastChild = ce;
            function Pe(n, c, x) {
              return x === void 0 && (x = true), n.has(c) ? false : (n.set(c, x), true);
            }
            e.addToSeen = Pe;
            function We(n) {
              return e.isClassLike(n) || e.isInterfaceDeclaration(n) || e.isTypeLiteralNode(n);
            }
            e.isObjectTypeDeclaration = We;
            function Er(n) {
              return n >= 179 && n <= 202 || n === 131 || n === 157 || n === 148 || n === 160 || n === 149 || n === 134 || n === 152 || n === 153 || n === 114 || n === 155 || n === 144 || n === 230 || n === 315 || n === 316 || n === 317 || n === 318 || n === 319 || n === 320 || n === 321;
            }
            e.isTypeNodeKind = Er;
            function Rr(n) {
              return n.kind === 208 || n.kind === 209;
            }
            e.isAccessExpression = Rr;
            function Fr(n) {
              return n.kind === 208 ? n.name : (e.Debug.assert(n.kind === 209), n.argumentExpression);
            }
            e.getNameOfAccessExpression = Fr;
            function et(n) {
              switch (n.kind) {
                case "text":
                case "internal":
                  return true;
                default:
                  return false;
              }
            }
            e.isBundleFileTextLike = et;
            function wt(n) {
              return n.kind === 272 || n.kind === 276;
            }
            e.isNamedImportsOrExports = wt;
            function Gt(n) {
              for (; Rr(n); )
                n = n.expression;
              return n;
            }
            e.getLeftmostAccessExpression = Gt;
            function Wt(n, c) {
              if (Rr(n.parent) && b_(n))
                return x(n.parent);
              function x(G) {
                if (G.kind === 208) {
                  var Oe = c(G.name);
                  if (Oe !== void 0)
                    return Oe;
                } else if (G.kind === 209)
                  if (e.isIdentifier(G.argumentExpression) || e.isStringLiteralLike(G.argumentExpression)) {
                    var Oe = c(G.argumentExpression);
                    if (Oe !== void 0)
                      return Oe;
                  } else
                    return;
                if (Rr(G.expression))
                  return x(G.expression);
                if (e.isIdentifier(G.expression))
                  return c(G.expression);
              }
            }
            e.forEachNameInAccessChainWalkingLeft = Wt;
            function pn(n, c) {
              for (; ; ) {
                switch (n.kind) {
                  case 222:
                    n = n.operand;
                    continue;
                  case 223:
                    n = n.left;
                    continue;
                  case 224:
                    n = n.condition;
                    continue;
                  case 212:
                    n = n.tag;
                    continue;
                  case 210:
                    if (c)
                      return n;
                  case 231:
                  case 209:
                  case 208:
                  case 232:
                  case 353:
                  case 235:
                    n = n.expression;
                    continue;
                }
                return n;
              }
            }
            e.getLeftmostExpression = pn;
            function Pn(n, c) {
              this.flags = n, this.escapedName = c, this.declarations = void 0, this.valueDeclaration = void 0, this.id = void 0, this.mergeId = void 0, this.parent = void 0;
            }
            function _i(n, c) {
              this.flags = c, (e.Debug.isDebugging || e.tracing) && (this.checker = n);
            }
            function Ln(n, c) {
              this.flags = c, e.Debug.isDebugging && (this.checker = n);
            }
            function ya(n, c, x) {
              this.pos = c, this.end = x, this.kind = n, this.id = 0, this.flags = 0, this.modifierFlagsCache = 0, this.transformFlags = 0, this.parent = void 0, this.original = void 0;
            }
            function Ci(n, c, x) {
              this.pos = c, this.end = x, this.kind = n, this.id = 0, this.flags = 0, this.transformFlags = 0, this.parent = void 0;
            }
            function Xn(n, c, x) {
              this.pos = c, this.end = x, this.kind = n, this.id = 0, this.flags = 0, this.transformFlags = 0, this.parent = void 0, this.original = void 0, this.flowNode = void 0;
            }
            function ki(n, c, x) {
              this.fileName = n, this.text = c, this.skipTrivia = x || function(G) {
                return G;
              };
            }
            e.objectAllocator = { getNodeConstructor: function() {
              return ya;
            }, getTokenConstructor: function() {
              return Ci;
            }, getIdentifierConstructor: function() {
              return Xn;
            }, getPrivateIdentifierConstructor: function() {
              return ya;
            }, getSourceFileConstructor: function() {
              return ya;
            }, getSymbolConstructor: function() {
              return Pn;
            }, getTypeConstructor: function() {
              return _i;
            }, getSignatureConstructor: function() {
              return Ln;
            }, getSourceMapSourceConstructor: function() {
              return ki;
            } };
            function aa(n) {
              Object.assign(e.objectAllocator, n);
            }
            e.setObjectAllocator = aa;
            function Ga(n, c, x) {
              return x === void 0 && (x = 0), n.replace(/{(\d+)}/g, function(G, Oe) {
                return "" + e.Debug.checkDefined(c[+Oe + x]);
              });
            }
            e.formatStringFromArgs = Ga;
            var ii;
            function i(n) {
              ii = n;
            }
            e.setLocalizedDiagnosticMessages = i;
            function o(n) {
              !ii && n && (ii = n());
            }
            e.maybeSetLocalizedDiagnosticMessages = o;
            function u(n) {
              return ii && ii[n.key] || n.message;
            }
            e.getLocaleSpecificMessage = u;
            function b(n, c, x, G) {
              Dt(void 0, c, x);
              var Oe = u(G);
              return arguments.length > 4 && (Oe = Ga(Oe, arguments, 4)), { file: void 0, start: c, length: x, messageText: Oe, category: G.category, code: G.code, reportsUnnecessary: G.reportsUnnecessary, fileName: n };
            }
            e.createDetachedDiagnostic = b;
            function Y(n) {
              return n.file === void 0 && n.start !== void 0 && n.length !== void 0 && typeof n.fileName == "string";
            }
            function Ke(n, c) {
              var x = c.fileName || "", G = c.text.length;
              e.Debug.assertEqual(n.fileName, x), e.Debug.assertLessThanOrEqual(n.start, G), e.Debug.assertLessThanOrEqual(n.start + n.length, G);
              var Oe = { file: c, start: n.start, length: n.length, messageText: n.messageText, category: n.category, code: n.code, reportsUnnecessary: n.reportsUnnecessary };
              if (n.relatedInformation) {
                Oe.relatedInformation = [];
                for (var mr = 0, Tr = n.relatedInformation; mr < Tr.length; mr++) {
                  var Qr = Tr[mr];
                  Y(Qr) && Qr.fileName === x ? (e.Debug.assertLessThanOrEqual(Qr.start, G), e.Debug.assertLessThanOrEqual(Qr.start + Qr.length, G), Oe.relatedInformation.push(Ke(Qr, c))) : Oe.relatedInformation.push(Qr);
                }
              }
              return Oe;
            }
            function Or(n, c) {
              for (var x = [], G = 0, Oe = n; G < Oe.length; G++) {
                var mr = Oe[G];
                x.push(Ke(mr, c));
              }
              return x;
            }
            e.attachFileToDiagnostics = Or;
            function kt(n, c, x, G) {
              Dt(n, c, x);
              var Oe = u(G);
              return arguments.length > 4 && (Oe = Ga(Oe, arguments, 4)), { file: n, start: c, length: x, messageText: Oe, category: G.category, code: G.code, reportsUnnecessary: G.reportsUnnecessary, reportsDeprecated: G.reportsDeprecated };
            }
            e.createFileDiagnostic = kt;
            function $n(n, c) {
              var x = u(c);
              return arguments.length > 2 && (x = Ga(x, arguments, 2)), x;
            }
            e.formatMessage = $n;
            function pa(n) {
              var c = u(n);
              return arguments.length > 1 && (c = Ga(c, arguments, 1)), { file: void 0, start: void 0, length: void 0, messageText: c, category: n.category, code: n.code, reportsUnnecessary: n.reportsUnnecessary, reportsDeprecated: n.reportsDeprecated };
            }
            e.createCompilerDiagnostic = pa;
            function Uo(n, c) {
              return { file: void 0, start: void 0, length: void 0, code: n.code, category: n.category, messageText: n.next ? n : n.messageText, relatedInformation: c };
            }
            e.createCompilerDiagnosticFromMessageChain = Uo;
            function Xa(n, c) {
              var x = u(c);
              return arguments.length > 2 && (x = Ga(x, arguments, 2)), { messageText: x, category: c.category, code: c.code, next: n === void 0 || Array.isArray(n) ? n : [n] };
            }
            e.chainDiagnosticMessages = Xa;
            function Ds(n, c) {
              for (var x = n; x.next; )
                x = x.next[0];
              x.next = [c];
            }
            e.concatenateDiagnosticMessageChains = Ds;
            function xs(n) {
              return n.file ? n.file.path : void 0;
            }
            function qu(n, c) {
              return Mc(n, c) || Uu(n, c) || 0;
            }
            e.compareDiagnostics = qu;
            function Mc(n, c) {
              return e.compareStringsCaseSensitive(xs(n), xs(c)) || e.compareValues(n.start, c.start) || e.compareValues(n.length, c.length) || e.compareValues(n.code, c.code) || zu(n.messageText, c.messageText) || 0;
            }
            e.compareDiagnosticsSkipRelatedInformation = Mc;
            function Uu(n, c) {
              return !n.relatedInformation && !c.relatedInformation ? 0 : n.relatedInformation && c.relatedInformation ? e.compareValues(n.relatedInformation.length, c.relatedInformation.length) || e.forEach(n.relatedInformation, function(x, G) {
                var Oe = c.relatedInformation[G];
                return qu(x, Oe);
              }) || 0 : n.relatedInformation ? -1 : 1;
            }
            function zu(n, c) {
              if (typeof n == "string" && typeof c == "string")
                return e.compareStringsCaseSensitive(n, c);
              if (typeof n == "string")
                return -1;
              if (typeof c == "string")
                return 1;
              var x = e.compareStringsCaseSensitive(n.messageText, c.messageText);
              if (x)
                return x;
              if (!n.next && !c.next)
                return 0;
              if (!n.next)
                return -1;
              if (!c.next)
                return 1;
              for (var G = Math.min(n.next.length, c.next.length), Oe = 0; Oe < G; Oe++)
                if (x = zu(n.next[Oe], c.next[Oe]), x)
                  return x;
              return n.next.length < c.next.length ? -1 : n.next.length > c.next.length ? 1 : 0;
            }
            function Il(n) {
              return n === 4 || n === 2 || n === 1 || n === 6 ? 1 : 0;
            }
            e.getLanguageVariant = Il;
            function Vu(n) {
              if (n.transformFlags & 2)
                return e.isJsxOpeningLikeElement(n) || e.isJsxFragment(n) ? n : e.forEachChild(n, Vu);
            }
            function Ol(n) {
              return n.isDeclarationFile ? void 0 : Vu(n);
            }
            function Ml(n) {
              return (n.impliedNodeFormat === e.ModuleKind.ESNext || e.fileExtensionIsOneOf(n.fileName, [".cjs", ".cts", ".mjs", ".mts"])) && !n.isDeclarationFile ? true : void 0;
            }
            function Wu(n) {
              switch (Ku(n)) {
                case e.ModuleDetectionKind.Force:
                  return function(Oe) {
                    Oe.externalModuleIndicator = e.isFileProbablyExternalModule(Oe) || !Oe.isDeclarationFile || void 0;
                  };
                case e.ModuleDetectionKind.Legacy:
                  return function(Oe) {
                    Oe.externalModuleIndicator = e.isFileProbablyExternalModule(Oe);
                  };
                case e.ModuleDetectionKind.Auto:
                  var c = [e.isFileProbablyExternalModule];
                  (n.jsx === 4 || n.jsx === 5) && c.push(Ol), c.push(Ml);
                  var x = e.or.apply(void 0, c), G = function(Oe) {
                    return void (Oe.externalModuleIndicator = x(Oe));
                  };
                  return G;
              }
            }
            e.getSetExternalModuleIndicator = Wu;
            function wu(n) {
              return n.target || n.module === e.ModuleKind.Node16 && 9 || n.module === e.ModuleKind.NodeNext && 99 || 0;
            }
            e.getEmitScriptTarget = wu;
            function Vi(n) {
              return typeof n.module == "number" ? n.module : wu(n) >= 2 ? e.ModuleKind.ES2015 : e.ModuleKind.CommonJS;
            }
            e.getEmitModuleKind = Vi;
            function Ll(n) {
              var c = n.moduleResolution;
              if (c === void 0)
                switch (Vi(n)) {
                  case e.ModuleKind.CommonJS:
                    c = e.ModuleResolutionKind.NodeJs;
                    break;
                  case e.ModuleKind.Node16:
                    c = e.ModuleResolutionKind.Node16;
                    break;
                  case e.ModuleKind.NodeNext:
                    c = e.ModuleResolutionKind.NodeNext;
                    break;
                  default:
                    c = e.ModuleResolutionKind.Classic;
                    break;
                }
              return c;
            }
            e.getEmitModuleResolutionKind = Ll;
            function Ku(n) {
              return n.moduleDetection || (Vi(n) === e.ModuleKind.Node16 || Vi(n) === e.ModuleKind.NodeNext ? e.ModuleDetectionKind.Force : e.ModuleDetectionKind.Auto);
            }
            e.getEmitModuleDetectionKind = Ku;
            function Rl(n) {
              switch (Vi(n)) {
                case e.ModuleKind.CommonJS:
                case e.ModuleKind.AMD:
                case e.ModuleKind.ES2015:
                case e.ModuleKind.ES2020:
                case e.ModuleKind.ES2022:
                case e.ModuleKind.ESNext:
                case e.ModuleKind.Node16:
                case e.ModuleKind.NodeNext:
                  return true;
                default:
                  return false;
              }
            }
            e.hasJsonModuleEmitEnabled = Rl;
            function Au(n) {
              return n.allowUnreachableCode === false;
            }
            e.unreachableCodeIsError = Au;
            function jl(n) {
              return n.allowUnusedLabels === false;
            }
            e.unusedLabelIsError = jl;
            function Jl(n) {
              return !!(Lc(n) && n.declarationMap);
            }
            e.getAreDeclarationMapsEnabled = Jl;
            function Hu(n) {
              if (n.esModuleInterop !== void 0)
                return n.esModuleInterop;
              switch (Vi(n)) {
                case e.ModuleKind.Node16:
                case e.ModuleKind.NodeNext:
                  return true;
              }
            }
            e.getESModuleInterop = Hu;
            function Fl(n) {
              var c = Vi(n);
              return n.allowSyntheticDefaultImports !== void 0 ? n.allowSyntheticDefaultImports : Hu(n) || c === e.ModuleKind.System;
            }
            e.getAllowSyntheticDefaultImports = Fl;
            function Lc(n) {
              return !!(n.declaration || n.composite);
            }
            e.getEmitDeclarations = Lc;
            function Bl(n) {
              return !!(n.preserveConstEnums || n.isolatedModules);
            }
            e.shouldPreserveConstEnums = Bl;
            function ql(n) {
              return !!(n.incremental || n.composite);
            }
            e.isIncrementalCompilation = ql;
            function ku(n, c) {
              return n[c] === void 0 ? !!n.strict : !!n[c];
            }
            e.getStrictOptionValue = ku;
            function Gu(n) {
              return n.allowJs === void 0 ? !!n.checkJs : n.allowJs;
            }
            e.getAllowJSCompilerOption = Gu;
            function zo(n) {
              return n.useDefineForClassFields === void 0 ? wu(n) >= 9 : n.useDefineForClassFields;
            }
            e.getUseDefineForClassFields = zo;
            function Ul(n, c) {
              return se(c, n, e.semanticDiagnosticsOptionDeclarations);
            }
            e.compilerOptionsAffectSemanticDiagnostics = Ul;
            function yo(n, c) {
              return se(c, n, e.affectsEmitOptionDeclarations);
            }
            e.compilerOptionsAffectEmit = yo;
            function sr(n, c) {
              return se(c, n, e.affectsDeclarationPathOptionDeclarations);
            }
            e.compilerOptionsAffectDeclarationPath = sr;
            function $r(n, c) {
              return c.strictFlag ? ku(n, c.name) : n[c.name];
            }
            e.getCompilerOptionValue = $r;
            function Wr(n) {
              var c = n.jsx;
              return c === 2 || c === 4 || c === 5;
            }
            e.getJSXTransformEnabled = Wr;
            function st(n, c) {
              var x = c == null ? void 0 : c.pragmas.get("jsximportsource"), G = e.isArray(x) ? x[x.length - 1] : x;
              return n.jsx === 4 || n.jsx === 5 || n.jsxImportSource || G ? (G == null ? void 0 : G.arguments.factory) || n.jsxImportSource || "react" : void 0;
            }
            e.getJSXImplicitImportBase = st;
            function ht(n, c) {
              return n ? "".concat(n, "/").concat(c.jsx === 5 ? "jsx-dev-runtime" : "jsx-runtime") : void 0;
            }
            e.getJSXRuntimeImport = ht;
            function Bt(n) {
              for (var c = false, x = 0; x < n.length; x++)
                if (n.charCodeAt(x) === 42)
                  if (!c)
                    c = true;
                  else
                    return false;
              return true;
            }
            e.hasZeroOrOneAsteriskCharacter = Bt;
            function Cn(n, c) {
              var x, G, Oe, mr = false;
              return { getSymlinkedFiles: function() {
                return Oe;
              }, getSymlinkedDirectories: function() {
                return x;
              }, getSymlinkedDirectoriesByRealpath: function() {
                return G;
              }, setSymlinkedFile: function(Qr, bt) {
                return (Oe || (Oe = new e.Map())).set(Qr, bt);
              }, setSymlinkedDirectory: function(Qr, bt) {
                var lt = e.toPath(Qr, n, c);
                kf(lt) || (lt = e.ensureTrailingDirectorySeparator(lt), bt !== false && !(x != null && x.has(lt)) && (G || (G = e.createMultiMap())).add(e.ensureTrailingDirectorySeparator(bt.realPath), Qr), (x || (x = new e.Map())).set(lt, bt));
              }, setSymlinksFromResolutions: function(Qr, bt) {
                var lt = this, Yt;
                e.Debug.assert(!mr), mr = true;
                for (var gn = 0, ci = Qr; gn < ci.length; gn++) {
                  var ai = ci[gn];
                  (Yt = ai.resolvedModules) === null || Yt === void 0 || Yt.forEach(function(zn) {
                    return Tr(lt, zn);
                  });
                }
                bt == null || bt.forEach(function(zn) {
                  return Tr(lt, zn);
                });
              }, hasProcessedResolutions: function() {
                return mr;
              } };
              function Tr(Qr, bt) {
                if (!(!bt || !bt.originalPath || !bt.resolvedFileName)) {
                  var lt = bt.resolvedFileName, Yt = bt.originalPath;
                  Qr.setSymlinkedFile(e.toPath(Yt, n, c), lt);
                  var gn = yi(lt, Yt, n, c) || e.emptyArray, ci = gn[0], ai = gn[1];
                  ci && ai && Qr.setSymlinkedDirectory(ai, { real: ci, realPath: e.toPath(ci, n, c) });
                }
              }
            }
            e.createSymlinkCache = Cn;
            function yi(n, c, x, G) {
              for (var Oe = e.getPathComponents(e.getNormalizedAbsolutePath(n, x)), mr = e.getPathComponents(e.getNormalizedAbsolutePath(c, x)), Tr = false; Oe.length >= 2 && mr.length >= 2 && !fi(Oe[Oe.length - 2], G) && !fi(mr[mr.length - 2], G) && G(Oe[Oe.length - 1]) === G(mr[mr.length - 1]); )
                Oe.pop(), mr.pop(), Tr = true;
              return Tr ? [e.getPathFromPathComponents(Oe), e.getPathFromPathComponents(mr)] : void 0;
            }
            function fi(n, c) {
              return n !== void 0 && (c(n) === "node_modules" || e.startsWith(n, "@"));
            }
            function Wi(n) {
              return e.isAnyDirectorySeparator(n.charCodeAt(0)) ? n.slice(1) : void 0;
            }
            function Oi(n, c, x) {
              var G = e.tryRemovePrefix(n, c, x);
              return G === void 0 ? void 0 : Wi(G);
            }
            e.tryRemoveDirectoryPrefix = Oi;
            var ha = /[^\w\s\/]/g;
            function ws(n) {
              return n.replace(ha, Rc);
            }
            e.regExpEscape = ws;
            function Rc(n) {
              return "\\" + n;
            }
            var jc = [42, 63];
            e.commonPackageFolders = ["node_modules", "bower_components", "jspm_packages"];
            var As = "(?!(".concat(e.commonPackageFolders.join("|"), ")(/|$))"), Xu = { singleAsteriskRegexFragment: "([^./]|(\\.(?!min\\.js$))?)*", doubleAsteriskRegexFragment: "(/".concat(As, "[^/.][^/]*)*?"), replaceWildcardCharacter: function(n) {
              return Vl(n, Xu.singleAsteriskRegexFragment);
            } }, pf = { singleAsteriskRegexFragment: "[^/]*", doubleAsteriskRegexFragment: "(/".concat(As, "[^/.][^/]*)*?"), replaceWildcardCharacter: function(n) {
              return Vl(n, pf.singleAsteriskRegexFragment);
            } }, ff = { singleAsteriskRegexFragment: "[^/]*", doubleAsteriskRegexFragment: "(/.+?)?", replaceWildcardCharacter: function(n) {
              return Vl(n, ff.singleAsteriskRegexFragment);
            } }, df = { files: Xu, directories: pf, exclude: ff };
            function $u(n, c, x) {
              var G = zl(n, c, x);
              if (!(!G || !G.length)) {
                var Oe = G.map(function(Tr) {
                  return "(".concat(Tr, ")");
                }).join("|"), mr = x === "exclude" ? "($|/)" : "$";
                return "^(".concat(Oe, ")").concat(mr);
              }
            }
            e.getRegularExpressionForWildcard = $u;
            function zl(n, c, x) {
              if (!(n === void 0 || n.length === 0))
                return e.flatMap(n, function(G) {
                  return G && gf(G, c, x, df[x]);
                });
            }
            e.getRegularExpressionsForWildcards = zl;
            function mf(n) {
              return !/[.*?]/.test(n);
            }
            e.isImplicitGlob = mf;
            function qy(n, c, x) {
              var G = n && gf(n, c, x, df[x]);
              return G && "^(".concat(G, ")").concat(x === "exclude" ? "($|/)" : "$");
            }
            e.getPatternFromSpec = qy;
            function gf(n, c, x, G) {
              var Oe = G.singleAsteriskRegexFragment, mr = G.doubleAsteriskRegexFragment, Tr = G.replaceWildcardCharacter, Qr = "", bt = false, lt = e.getNormalizedPathComponents(n, c), Yt = e.last(lt);
              if (!(x !== "exclude" && Yt === "**")) {
                lt[0] = e.removeTrailingDirectorySeparator(lt[0]), mf(Yt) && lt.push("**", "*");
                for (var gn = 0, ci = 0, ai = lt; ci < ai.length; ci++) {
                  var zn = ai[ci];
                  if (zn === "**")
                    Qr += mr;
                  else if (x === "directories" && (Qr += "(", gn++), bt && (Qr += e.directorySeparator), x !== "exclude") {
                    var Yi = "";
                    zn.charCodeAt(0) === 42 ? (Yi += "([^./]" + Oe + ")?", zn = zn.substr(1)) : zn.charCodeAt(0) === 63 && (Yi += "[^./]", zn = zn.substr(1)), Yi += zn.replace(ha, Tr), Yi !== zn && (Qr += As), Qr += Yi;
                  } else
                    Qr += zn.replace(ha, Tr);
                  bt = true;
                }
                for (; gn > 0; )
                  Qr += ")?", gn--;
                return Qr;
              }
            }
            function Vl(n, c) {
              return n === "*" ? c : n === "?" ? "[^/]" : "\\" + n;
            }
            function yf(n, c, x, G, Oe) {
              n = e.normalizePath(n), Oe = e.normalizePath(Oe);
              var mr = e.combinePaths(Oe, n);
              return { includeFilePatterns: e.map(zl(x, mr, "files"), function(Tr) {
                return "^".concat(Tr, "$");
              }), includeFilePattern: $u(x, mr, "files"), includeDirectoryPattern: $u(x, mr, "directories"), excludePattern: $u(c, mr, "exclude"), basePaths: zy(n, x, G) };
            }
            e.getFileMatcherPatterns = yf;
            function Qu(n, c) {
              return new RegExp(n, c ? "" : "i");
            }
            e.getRegexFromPattern = Qu;
            function Uy(n, c, x, G, Oe, mr, Tr, Qr, bt) {
              n = e.normalizePath(n), mr = e.normalizePath(mr);
              for (var lt = yf(n, x, G, Oe, mr), Yt = lt.includeFilePatterns && lt.includeFilePatterns.map(function(Vo) {
                return Qu(Vo, Oe);
              }), gn = lt.includeDirectoryPattern && Qu(lt.includeDirectoryPattern, Oe), ci = lt.excludePattern && Qu(lt.excludePattern, Oe), ai = Yt ? Yt.map(function() {
                return [];
              }) : [[]], zn = new e.Map(), Yi = e.createGetCanonicalFileName(Oe), Nn = 0, va = lt.basePaths; Nn < va.length; Nn++) {
                var ks = va[Nn];
                Nu(ks, e.combinePaths(mr, ks), Tr);
              }
              return e.flatten(ai);
              function Nu(Vo, Xl, Zu) {
                var Of = Yi(bt(Xl));
                if (!zn.has(Of)) {
                  zn.set(Of, true);
                  for (var Mf = Qr(Vo), Fh = Mf.files, Bh = Mf.directories, qh = function(jf) {
                    var Zl = e.combinePaths(Vo, jf), Jf = e.combinePaths(Xl, jf);
                    if (c && !e.fileExtensionIsOneOf(Zl, c) || ci && ci.test(Jf))
                      return "continue";
                    if (!Yt)
                      ai[0].push(Zl);
                    else {
                      var Ff = e.findIndex(Yt, function(zh) {
                        return zh.test(Jf);
                      });
                      Ff !== -1 && ai[Ff].push(Zl);
                    }
                  }, $l = 0, Lf = e.sort(Fh, e.compareStringsCaseSensitive); $l < Lf.length; $l++) {
                    var el = Lf[$l];
                    qh(el);
                  }
                  if (!(Zu !== void 0 && (Zu--, Zu === 0)))
                    for (var Ql = 0, Rf = e.sort(Bh, e.compareStringsCaseSensitive); Ql < Rf.length; Ql++) {
                      var el = Rf[Ql], Uh = e.combinePaths(Vo, el), Yl = e.combinePaths(Xl, el);
                      (!gn || gn.test(Yl)) && (!ci || !ci.test(Yl)) && Nu(Uh, Yl, Zu);
                    }
                }
              }
            }
            e.matchFiles = Uy;
            function zy(n, c, x) {
              var G = [n];
              if (c) {
                for (var Oe = [], mr = 0, Tr = c; mr < Tr.length; mr++) {
                  var Qr = Tr[mr], bt = e.isRootedDiskPath(Qr) ? Qr : e.normalizePath(e.combinePaths(n, Qr));
                  Oe.push(Vy(bt));
                }
                Oe.sort(e.getStringComparer(!x));
                for (var lt = function(ai) {
                  e.every(G, function(zn) {
                    return !e.containsPath(zn, ai, n, !x);
                  }) && G.push(ai);
                }, Yt = 0, gn = Oe; Yt < gn.length; Yt++) {
                  var ci = gn[Yt];
                  lt(ci);
                }
              }
              return G;
            }
            function Vy(n) {
              var c = e.indexOfAnyCharCode(n, jc);
              return c < 0 ? e.hasExtension(n) ? e.removeTrailingDirectorySeparator(e.getDirectoryPath(n)) : n : n.substring(0, n.lastIndexOf(e.directorySeparator, c));
            }
            function Wy(n, c) {
              return c || hf(n) || 3;
            }
            e.ensureScriptKind = Wy;
            function hf(n) {
              var c = n.substr(n.lastIndexOf("."));
              switch (c.toLowerCase()) {
                case ".js":
                case ".cjs":
                case ".mjs":
                  return 1;
                case ".jsx":
                  return 2;
                case ".ts":
                case ".cts":
                case ".mts":
                  return 3;
                case ".tsx":
                  return 4;
                case ".json":
                  return 6;
                default:
                  return 0;
              }
            }
            e.getScriptKindFromFileName = hf, e.supportedTSExtensions = [[".ts", ".tsx", ".d.ts"], [".cts", ".d.cts"], [".mts", ".d.mts"]], e.supportedTSExtensionsFlat = e.flatten(e.supportedTSExtensions);
            var Ky = D(D([], e.supportedTSExtensions, true), [[".json"]], false), Hy = [".d.ts", ".d.cts", ".d.mts", ".cts", ".mts", ".ts", ".tsx", ".cts", ".mts"];
            e.supportedJSExtensions = [[".js", ".jsx"], [".mjs"], [".cjs"]], e.supportedJSExtensionsFlat = e.flatten(e.supportedJSExtensions);
            var Yu = [[".ts", ".tsx", ".d.ts", ".js", ".jsx"], [".cts", ".d.cts", ".cjs"], [".mts", ".d.mts", ".mjs"]], Gy = D(D([], Yu, true), [[".json"]], false);
            e.supportedDeclarationExtensions = [".d.ts", ".d.cts", ".d.mts"];
            function vf(n, c) {
              var x = n && Gu(n);
              if (!c || c.length === 0)
                return x ? Yu : e.supportedTSExtensions;
              var G = x ? Yu : e.supportedTSExtensions, Oe = e.flatten(G), mr = D(D([], G, true), e.mapDefined(c, function(Tr) {
                return Tr.scriptKind === 7 || x && Xy(Tr.scriptKind) && Oe.indexOf(Tr.extension) === -1 ? [Tr.extension] : void 0;
              }), true);
              return mr;
            }
            e.getSupportedExtensions = vf;
            function bf(n, c) {
              return !n || !n.resolveJsonModule ? c : c === Yu ? Gy : c === e.supportedTSExtensions ? Ky : D(D([], c, true), [[".json"]], false);
            }
            e.getSupportedExtensionsWithJsonIfResolveJsonModule = bf;
            function Xy(n) {
              return n === 1 || n === 2;
            }
            function $y(n) {
              return e.some(e.supportedJSExtensionsFlat, function(c) {
                return e.fileExtensionIs(n, c);
              });
            }
            e.hasJSFileExtension = $y;
            function Qy(n) {
              return e.some(e.supportedTSExtensionsFlat, function(c) {
                return e.fileExtensionIs(n, c);
              });
            }
            e.hasTSFileExtension = Qy;
            function Yy(n, c, x) {
              if (!n)
                return false;
              for (var G = vf(c, x), Oe = 0, mr = e.flatten(bf(c, G)); Oe < mr.length; Oe++) {
                var Tr = mr[Oe];
                if (e.fileExtensionIs(n, Tr))
                  return true;
              }
              return false;
            }
            e.isSupportedSourceFileName = Yy;
            function Ef(n) {
              var c = n.match(/\//g);
              return c ? c.length : 0;
            }
            function Zy(n, c) {
              return e.compareValues(Ef(n), Ef(c));
            }
            e.compareNumberOfDirectorySeparators = Zy;
            var Wl = [".d.ts", ".d.mts", ".d.cts", ".mjs", ".mts", ".cjs", ".cts", ".ts", ".js", ".tsx", ".jsx", ".json"];
            function Pu(n) {
              for (var c = 0, x = Wl; c < x.length; c++) {
                var G = x[c], Oe = Tf(n, G);
                if (Oe !== void 0)
                  return Oe;
              }
              return n;
            }
            e.removeFileExtension = Pu;
            function Tf(n, c) {
              return e.fileExtensionIs(n, c) ? Sf(n, c) : void 0;
            }
            e.tryRemoveExtension = Tf;
            function Sf(n, c) {
              return n.substring(0, n.length - c.length);
            }
            e.removeExtension = Sf;
            function eh(n, c) {
              return e.changeAnyExtension(n, c, Wl, false);
            }
            e.changeExtension = eh;
            function Cf(n) {
              var c = n.indexOf("*");
              return c === -1 ? n : n.indexOf("*", c + 1) !== -1 ? void 0 : { prefix: n.substr(0, c), suffix: n.substr(c + 1) };
            }
            e.tryParsePattern = Cf;
            function rh(n) {
              return e.mapDefined(e.getOwnKeys(n), function(c) {
                return Cf(c);
              });
            }
            e.tryParsePatterns = rh;
            function Jc(n) {
              return !(n >= 0);
            }
            e.positionIsSynthesized = Jc;
            function Df(n) {
              return n === ".ts" || n === ".tsx" || n === ".d.ts" || n === ".cts" || n === ".mts" || n === ".d.mts" || n === ".d.cts";
            }
            e.extensionIsTS = Df;
            function th(n) {
              return Df(n) || n === ".json";
            }
            e.resolutionExtensionIsTSOrJson = th;
            function nh(n) {
              var c = Kl(n);
              return c !== void 0 ? c : e.Debug.fail("File ".concat(n, " has unknown extension."));
            }
            e.extensionFromPath = nh;
            function ih(n) {
              return Kl(n) !== void 0;
            }
            e.isAnySupportedFileExtension = ih;
            function Kl(n) {
              return e.find(Wl, function(c) {
                return e.fileExtensionIs(n, c);
              });
            }
            e.tryGetExtensionFromPath = Kl;
            function ah(n, c) {
              return n.checkJsDirective ? n.checkJsDirective.enabled : c.checkJs;
            }
            e.isCheckJsEnabledForFile = ah, e.emptyFileSystemEntries = { files: e.emptyArray, directories: e.emptyArray };
            function oh(n, c) {
              for (var x = [], G = 0, Oe = n; G < Oe.length; G++) {
                var mr = Oe[G];
                if (mr === c)
                  return c;
                e.isString(mr) || x.push(mr);
              }
              return e.findBestPatternMatch(x, function(Tr) {
                return Tr;
              }, c);
            }
            e.matchPatternOrExact = oh;
            function sh(n, c) {
              var x = n.indexOf(c);
              return e.Debug.assert(x !== -1), n.slice(x);
            }
            e.sliceAfter = sh;
            function _h(n) {
              for (var c, x = [], G = 1; G < arguments.length; G++)
                x[G - 1] = arguments[G];
              return x.length && (n.relatedInformation || (n.relatedInformation = []), e.Debug.assert(n.relatedInformation !== e.emptyArray, "Diagnostic had empty array singleton for related info, but is still being constructed!"), (c = n.relatedInformation).push.apply(c, x)), n;
            }
            e.addRelatedInfo = _h;
            function ch(n, c) {
              e.Debug.assert(n.length !== 0);
              for (var x = c(n[0]), G = x, Oe = 1; Oe < n.length; Oe++) {
                var mr = c(n[Oe]);
                mr < x ? x = mr : mr > G && (G = mr);
              }
              return { min: x, max: G };
            }
            e.minAndMax = ch;
            function uh(n) {
              return { pos: kr(n), end: n.end };
            }
            e.rangeOfNode = uh;
            function lh(n, c) {
              var x = c.pos - 1, G = e.skipTrivia(n.text, c.end) + 1;
              return { pos: x, end: G };
            }
            e.rangeOfTypeParameters = lh;
            function ph(n, c, x) {
              return c.skipLibCheck && n.isDeclarationFile || c.skipDefaultLibCheck && n.hasNoDefaultLib || x.isSourceOfProjectReferenceRedirect(n.fileName);
            }
            e.skipTypeChecking = ph;
            function Hl(n, c) {
              return n === c || typeof n == "object" && n !== null && typeof c == "object" && c !== null && e.equalOwnProperties(n, c, Hl);
            }
            e.isJsonEqual = Hl;
            function fh(n) {
              var c;
              switch (n.charCodeAt(1)) {
                case 98:
                case 66:
                  c = 1;
                  break;
                case 111:
                case 79:
                  c = 3;
                  break;
                case 120:
                case 88:
                  c = 4;
                  break;
                default:
                  for (var x = n.length - 1, G = 0; n.charCodeAt(G) === 48; )
                    G++;
                  return n.slice(G, x) || "0";
              }
              for (var Oe = 2, mr = n.length - 1, Tr = (mr - Oe) * c, Qr = new Uint16Array((Tr >>> 4) + (Tr & 15 ? 1 : 0)), bt = mr - 1, lt = 0; bt >= Oe; bt--, lt += c) {
                var Yt = lt >>> 4, gn = n.charCodeAt(bt), ci = gn <= 57 ? gn - 48 : 10 + gn - (gn <= 70 ? 65 : 97), ai = ci << (lt & 15);
                Qr[Yt] |= ai;
                var zn = ai >>> 16;
                zn && (Qr[Yt + 1] |= zn);
              }
              for (var Yi = "", Nn = Qr.length - 1, va = true; va; ) {
                var ks = 0;
                va = false;
                for (var Yt = Nn; Yt >= 0; Yt--) {
                  var Nu = ks << 16 | Qr[Yt], Vo = Nu / 10 | 0;
                  Qr[Yt] = Vo, ks = Nu - Vo * 10, Vo && !va && (Nn = Yt, va = true);
                }
                Yi = ks + Yi;
              }
              return Yi;
            }
            e.parsePseudoBigInt = fh;
            function dh(n) {
              var c = n.negative, x = n.base10Value;
              return (c && x !== "0" ? "-" : "") + x;
            }
            e.pseudoBigIntToString = dh;
            function mh(n) {
              return !!(n.flags & 16777216) || Si(n) || hh(n) || yh(n) || !(jn(n) || gh(n));
            }
            e.isValidTypeOnlyAliasUseSite = mh;
            function gh(n) {
              return e.isIdentifier(n) && e.isShorthandPropertyAssignment(n.parent) && n.parent.name === n;
            }
            function yh(n) {
              for (; n.kind === 79 || n.kind === 208; )
                n = n.parent;
              if (n.kind !== 164)
                return false;
              if (ia(n.parent, 256))
                return true;
              var c = n.parent.parent.kind;
              return c === 261 || c === 184;
            }
            function hh(n) {
              if (n.kind !== 79)
                return false;
              var c = e.findAncestor(n.parent, function(x) {
                switch (x.kind) {
                  case 294:
                    return true;
                  case 208:
                  case 230:
                    return false;
                  default:
                    return "quit";
                }
              });
              return (c == null ? void 0 : c.token) === 117 || (c == null ? void 0 : c.parent.kind) === 261;
            }
            function vh(n) {
              return e.isTypeReferenceNode(n) && e.isIdentifier(n.typeName);
            }
            e.isIdentifierTypeReference = vh;
            function bh(n, c) {
              if (c === void 0 && (c = e.equateValues), n.length < 2)
                return true;
              for (var x = n[0], G = 1, Oe = n.length; G < Oe; G++) {
                var mr = n[G];
                if (!c(x, mr))
                  return false;
              }
              return true;
            }
            e.arrayIsHomogeneous = bh;
            function xf(n, c) {
              return n.pos = c, n;
            }
            e.setTextRangePos = xf;
            function wf(n, c) {
              return n.end = c, n;
            }
            e.setTextRangeEnd = wf;
            function Af(n, c, x) {
              return wf(xf(n, c), x);
            }
            e.setTextRangePosEnd = Af;
            function Eh(n, c, x) {
              return Af(n, c, c + x);
            }
            e.setTextRangePosWidth = Eh;
            function Th(n, c) {
              return n && (n.flags = c), n;
            }
            e.setNodeFlags = Th;
            function Gl(n, c) {
              return n && c && (n.parent = c), n;
            }
            e.setParent = Gl;
            function Sh(n, c) {
              if (n)
                for (var x = 0, G = n; x < G.length; x++) {
                  var Oe = G[x];
                  Gl(Oe, c);
                }
              return n;
            }
            e.setEachParent = Sh;
            function Ch(n, c) {
              if (!n)
                return n;
              return e.forEachChildRecursively(n, e.isJSDocNode(n) ? x : Oe), n;
              function x(mr, Tr) {
                if (c && mr.parent === Tr)
                  return "skip";
                Gl(mr, Tr);
              }
              function G(mr) {
                if (e.hasJSDocNodes(mr))
                  for (var Tr = 0, Qr = mr.jsDoc; Tr < Qr.length; Tr++) {
                    var bt = Qr[Tr];
                    x(bt, mr), e.forEachChildRecursively(bt, x);
                  }
              }
              function Oe(mr, Tr) {
                return x(mr, Tr) || G(mr);
              }
            }
            e.setParentRecursive = Ch;
            function Dh(n) {
              return !e.isOmittedExpression(n);
            }
            function xh(n) {
              return e.isArrayLiteralExpression(n) && e.every(n.elements, Dh);
            }
            e.isPackedArrayLiteral = xh;
            function wh(n) {
              for (e.Debug.assertIsDefined(n.parent); ; ) {
                var c = n.parent;
                if (e.isParenthesizedExpression(c)) {
                  n = c;
                  continue;
                }
                if (e.isExpressionStatement(c) || e.isVoidExpression(c) || e.isForStatement(c) && (c.initializer === n || c.incrementor === n))
                  return true;
                if (e.isCommaListExpression(c)) {
                  if (n !== e.last(c.elements))
                    return true;
                  n = c;
                  continue;
                }
                if (e.isBinaryExpression(c) && c.operatorToken.kind === 27) {
                  if (n === c.left)
                    return true;
                  n = c;
                  continue;
                }
                return false;
              }
            }
            e.expressionResultIsUnused = wh;
            function kf(n) {
              return e.some(e.ignoredPaths, function(c) {
                return e.stringContains(n, c);
              });
            }
            e.containsIgnoredPath = kf;
            function Ah(n) {
              if (n.parent) {
                switch (n.kind) {
                  case 165:
                    var c = n.parent;
                    return c.kind === 192 ? void 0 : c.typeParameters;
                  case 166:
                    return n.parent.parameters;
                  case 201:
                    return n.parent.templateSpans;
                  case 236:
                    return n.parent.templateSpans;
                  case 167: {
                    var x = n.parent;
                    return e.canHaveDecorators(x) ? x.modifiers : e.canHaveIllegalDecorators(x) ? x.illegalDecorators : void 0;
                  }
                  case 294:
                    return n.parent.heritageClauses;
                }
                var G = n.parent;
                if (e.isJSDocTag(n))
                  return e.isJSDocTypeLiteral(n.parent) ? void 0 : n.parent.tags;
                switch (G.kind) {
                  case 184:
                  case 261:
                    return e.isTypeElement(n) ? G.members : void 0;
                  case 189:
                  case 190:
                    return G.types;
                  case 186:
                  case 206:
                  case 354:
                  case 272:
                  case 276:
                    return G.elements;
                  case 207:
                  case 289:
                    return G.properties;
                  case 210:
                  case 211:
                    return e.isTypeNode(n) ? G.typeArguments : G.expression === n ? void 0 : G.arguments;
                  case 281:
                  case 285:
                    return e.isJsxChild(n) ? G.children : void 0;
                  case 283:
                  case 282:
                    return e.isTypeNode(n) ? G.typeArguments : void 0;
                  case 238:
                  case 292:
                  case 293:
                  case 265:
                    return G.statements;
                  case 266:
                    return G.clauses;
                  case 260:
                  case 228:
                    return e.isClassElement(n) ? G.members : void 0;
                  case 263:
                    return e.isEnumMember(n) ? G.members : void 0;
                  case 308:
                    return G.statements;
                }
              }
            }
            e.getContainingNodeArray = Ah;
            function kh(n) {
              if (!n.typeParameters) {
                if (e.some(n.parameters, function(x) {
                  return !as(x);
                }))
                  return true;
                if (n.kind !== 216) {
                  var c = e.firstOrUndefined(n.parameters);
                  if (!(c && ns(c)))
                    return true;
                }
              }
              return false;
            }
            e.hasContextSensitiveParameters = kh;
            function Ph(n) {
              return n === "Infinity" || n === "-Infinity" || n === "NaN";
            }
            e.isInfinityOrNaNString = Ph;
            function Pf(n) {
              return n.kind === 257 && n.parent.kind === 295;
            }
            e.isCatchClauseVariableDeclaration = Pf;
            function Nh(n) {
              var c = n.valueDeclaration && ua(n.valueDeclaration);
              return !!c && (e.isParameter(c) || Pf(c));
            }
            e.isParameterOrCatchClauseVariable = Nh;
            function Ih(n) {
              return n.kind === 215 || n.kind === 216;
            }
            e.isFunctionExpressionOrArrowFunction = Ih;
            function Oh(n) {
              return n.replace(/\$/gm, function() {
                return "\\$";
              });
            }
            e.escapeSnippetText = Oh;
            function Nf(n) {
              return (+n).toString() === n;
            }
            e.isNumericLiteralName = Nf;
            function Mh(n, c, x, G) {
              return e.isIdentifierText(n, c) ? e.factory.createIdentifier(n) : !G && Nf(n) && +n >= 0 ? e.factory.createNumericLiteral(+n) : e.factory.createStringLiteral(n, !!x);
            }
            e.createPropertyNameNodeForIdentifierOrLiteral = Mh;
            function Lh(n) {
              return !!(n.flags & 262144 && n.isThisType);
            }
            e.isThisTypeParameter = Lh;
            function Rh(n) {
              var c = 0, x = 0, G = 0, Oe = 0, mr;
              (function(lt) {
                lt[lt.BeforeNodeModules = 0] = "BeforeNodeModules", lt[lt.NodeModules = 1] = "NodeModules", lt[lt.Scope = 2] = "Scope", lt[lt.PackageContent = 3] = "PackageContent";
              })(mr || (mr = {}));
              for (var Tr = 0, Qr = 0, bt = 0; Qr >= 0; )
                switch (Tr = Qr, Qr = n.indexOf("/", Tr + 1), bt) {
                  case 0:
                    n.indexOf(e.nodeModulesPathPart, Tr) === Tr && (c = Tr, x = Qr, bt = 1);
                    break;
                  case 1:
                  case 2:
                    bt === 1 && n.charAt(Tr + 1) === "@" ? bt = 2 : (G = Qr, bt = 3);
                    break;
                  case 3:
                    n.indexOf(e.nodeModulesPathPart, Tr) === Tr ? bt = 1 : bt = 3;
                    break;
                }
              return Oe = Tr, bt > 1 ? { topLevelNodeModulesIndex: c, topLevelPackageNameIndex: x, packageRootIndex: G, fileNameIndex: Oe } : void 0;
            }
            e.getNodeModulePathParts = Rh;
            function jh(n) {
              var c;
              return n.kind === 343 ? (c = n.typeExpression) === null || c === void 0 ? void 0 : c.type : n.type;
            }
            e.getParameterTypeNode = jh;
            function If(n) {
              switch (n.kind) {
                case 165:
                case 260:
                case 261:
                case 262:
                case 263:
                case 348:
                case 341:
                case 342:
                  return true;
                case 270:
                  return n.isTypeOnly;
                case 273:
                case 278:
                  return n.parent.parent.isTypeOnly;
                default:
                  return false;
              }
            }
            e.isTypeDeclaration = If;
            function Jh(n) {
              return e.isEnumDeclaration(n) || e.isVariableStatement(n) || e.isFunctionDeclaration(n) || e.isClassDeclaration(n) || e.isInterfaceDeclaration(n) || If(n) || e.isModuleDeclaration(n) && !me(n) && !Ie(n);
            }
            e.canHaveExportModifier = Jh;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3() {
              var w, s, q, F, fe;
              return { createBaseSourceFileNode: Ee, createBaseIdentifierNode: Se, createBasePrivateIdentifierNode: J, createBaseTokenNode: se, createBaseNode: Me };
              function Ee(Q) {
                return new (fe || (fe = e.objectAllocator.getSourceFileConstructor()))(Q, -1, -1);
              }
              function Se(Q) {
                return new (q || (q = e.objectAllocator.getIdentifierConstructor()))(Q, -1, -1);
              }
              function J(Q) {
                return new (F || (F = e.objectAllocator.getPrivateIdentifierConstructor()))(Q, -1, -1);
              }
              function se(Q) {
                return new (s || (s = e.objectAllocator.getTokenConstructor()))(Q, -1, -1);
              }
              function Me(Q) {
                return new (w || (w = e.objectAllocator.getNodeConstructor()))(Q, -1, -1);
              }
            }
            e.createBaseNodeFactory = t3;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(w) {
              var s, q;
              return { getParenthesizeLeftSideOfBinaryForOperator: F, getParenthesizeRightSideOfBinaryForOperator: fe, parenthesizeLeftSideOfBinary: Me, parenthesizeRightSideOfBinary: Q, parenthesizeExpressionOfComputedPropertyName: Be, parenthesizeConditionOfConditionalExpression: je, parenthesizeBranchOfConditionalExpression: V, parenthesizeExpressionOfExportDefault: B, parenthesizeExpressionOfNew: U, parenthesizeLeftSideOfAccess: m, parenthesizeOperandOfPostfixUnary: v, parenthesizeOperandOfPrefixUnary: g, parenthesizeExpressionsOfCommaDelimitedList: O, parenthesizeExpressionForDisallowedComma: S, parenthesizeExpressionOfExpressionStatement: te, parenthesizeConciseBodyOfArrowFunction: Je, parenthesizeCheckTypeOfConditionalType: qe, parenthesizeExtendsTypeOfConditionalType: ge, parenthesizeConstituentTypesOfUnionType: H, parenthesizeConstituentTypeOfUnionType: ie, parenthesizeConstituentTypesOfIntersectionType: j, parenthesizeConstituentTypeOfIntersectionType: pe, parenthesizeOperandOfTypeOperator: be, parenthesizeOperandOfReadonlyTypeOperator: Xe, parenthesizeNonArrayTypeOfPostfixType: Re, parenthesizeElementTypesOfTupleType: Fe, parenthesizeElementTypeOfTupleType: dr, parenthesizeTypeOfOptionalType: ve, parenthesizeTypeArguments: Cr, parenthesizeLeadingTypeArgument: er };
              function F(Ce) {
                s || (s = new e.Map());
                var $e = s.get(Ce);
                return $e || ($e = function(gr) {
                  return Me(Ce, gr);
                }, s.set(Ce, $e)), $e;
              }
              function fe(Ce) {
                q || (q = new e.Map());
                var $e = q.get(Ce);
                return $e || ($e = function(gr) {
                  return Q(Ce, void 0, gr);
                }, q.set(Ce, $e)), $e;
              }
              function Ee(Ce, $e, gr, X) {
                var Te = e.getOperatorPrecedence(223, Ce), we = e.getOperatorAssociativity(223, Ce), he = e.skipPartiallyEmittedExpressions($e);
                if (!gr && $e.kind === 216 && Te > 3)
                  return true;
                var yr = e.getExpressionPrecedence(he);
                switch (e.compareValues(yr, Te)) {
                  case -1:
                    return !(!gr && we === 1 && $e.kind === 226);
                  case 1:
                    return false;
                  case 0:
                    if (gr)
                      return we === 1;
                    if (e.isBinaryExpression(he) && he.operatorToken.kind === Ce) {
                      if (Se(Ce))
                        return false;
                      if (Ce === 39) {
                        var kr = X ? J(X) : 0;
                        if (e.isLiteralKind(kr) && kr === J(he))
                          return false;
                      }
                    }
                    var nr = e.getExpressionAssociativity(he);
                    return nr === 0;
                }
              }
              function Se(Ce) {
                return Ce === 41 || Ce === 51 || Ce === 50 || Ce === 52 || Ce === 27;
              }
              function J(Ce) {
                if (Ce = e.skipPartiallyEmittedExpressions(Ce), e.isLiteralKind(Ce.kind))
                  return Ce.kind;
                if (Ce.kind === 223 && Ce.operatorToken.kind === 39) {
                  if (Ce.cachedLiteralKind !== void 0)
                    return Ce.cachedLiteralKind;
                  var $e = J(Ce.left), gr = e.isLiteralKind($e) && $e === J(Ce.right) ? $e : 0;
                  return Ce.cachedLiteralKind = gr, gr;
                }
                return 0;
              }
              function se(Ce, $e, gr, X) {
                var Te = e.skipPartiallyEmittedExpressions($e);
                return Te.kind === 214 ? $e : Ee(Ce, $e, gr, X) ? w.createParenthesizedExpression($e) : $e;
              }
              function Me(Ce, $e) {
                return se(Ce, $e, true);
              }
              function Q(Ce, $e, gr) {
                return se(Ce, gr, false, $e);
              }
              function Be(Ce) {
                return e.isCommaSequence(Ce) ? w.createParenthesizedExpression(Ce) : Ce;
              }
              function je(Ce) {
                var $e = e.getOperatorPrecedence(224, 57), gr = e.skipPartiallyEmittedExpressions(Ce), X = e.getExpressionPrecedence(gr);
                return e.compareValues(X, $e) !== 1 ? w.createParenthesizedExpression(Ce) : Ce;
              }
              function V(Ce) {
                var $e = e.skipPartiallyEmittedExpressions(Ce);
                return e.isCommaSequence($e) ? w.createParenthesizedExpression(Ce) : Ce;
              }
              function B(Ce) {
                var $e = e.skipPartiallyEmittedExpressions(Ce), gr = e.isCommaSequence($e);
                if (!gr)
                  switch (e.getLeftmostExpression($e, false).kind) {
                    case 228:
                    case 215:
                      gr = true;
                  }
                return gr ? w.createParenthesizedExpression(Ce) : Ce;
              }
              function U(Ce) {
                var $e = e.getLeftmostExpression(Ce, true);
                switch ($e.kind) {
                  case 210:
                    return w.createParenthesizedExpression(Ce);
                  case 211:
                    return $e.arguments ? Ce : w.createParenthesizedExpression(Ce);
                }
                return m(Ce);
              }
              function m(Ce, $e) {
                var gr = e.skipPartiallyEmittedExpressions(Ce);
                return e.isLeftHandSideExpression(gr) && (gr.kind !== 211 || gr.arguments) && ($e || !e.isOptionalChain(gr)) ? Ce : e.setTextRange(w.createParenthesizedExpression(Ce), Ce);
              }
              function v(Ce) {
                return e.isLeftHandSideExpression(Ce) ? Ce : e.setTextRange(w.createParenthesizedExpression(Ce), Ce);
              }
              function g(Ce) {
                return e.isUnaryExpression(Ce) ? Ce : e.setTextRange(w.createParenthesizedExpression(Ce), Ce);
              }
              function O(Ce) {
                var $e = e.sameMap(Ce, S);
                return e.setTextRange(w.createNodeArray($e, Ce.hasTrailingComma), Ce);
              }
              function S(Ce) {
                var $e = e.skipPartiallyEmittedExpressions(Ce), gr = e.getExpressionPrecedence($e), X = e.getOperatorPrecedence(223, 27);
                return gr > X ? Ce : e.setTextRange(w.createParenthesizedExpression(Ce), Ce);
              }
              function te(Ce) {
                var $e = e.skipPartiallyEmittedExpressions(Ce);
                if (e.isCallExpression($e)) {
                  var gr = $e.expression, X = e.skipPartiallyEmittedExpressions(gr).kind;
                  if (X === 215 || X === 216) {
                    var Te = w.updateCallExpression($e, e.setTextRange(w.createParenthesizedExpression(gr), gr), $e.typeArguments, $e.arguments);
                    return w.restoreOuterExpressions(Ce, Te, 8);
                  }
                }
                var we = e.getLeftmostExpression($e, false).kind;
                return we === 207 || we === 215 ? e.setTextRange(w.createParenthesizedExpression(Ce), Ce) : Ce;
              }
              function Je(Ce) {
                return !e.isBlock(Ce) && (e.isCommaSequence(Ce) || e.getLeftmostExpression(Ce, false).kind === 207) ? e.setTextRange(w.createParenthesizedExpression(Ce), Ce) : Ce;
              }
              function qe(Ce) {
                switch (Ce.kind) {
                  case 181:
                  case 182:
                  case 191:
                    return w.createParenthesizedType(Ce);
                }
                return Ce;
              }
              function ge(Ce) {
                switch (Ce.kind) {
                  case 191:
                    return w.createParenthesizedType(Ce);
                }
                return Ce;
              }
              function ie(Ce) {
                switch (Ce.kind) {
                  case 189:
                  case 190:
                    return w.createParenthesizedType(Ce);
                }
                return qe(Ce);
              }
              function H(Ce) {
                return w.createNodeArray(e.sameMap(Ce, ie));
              }
              function pe(Ce) {
                switch (Ce.kind) {
                  case 189:
                  case 190:
                    return w.createParenthesizedType(Ce);
                }
                return ie(Ce);
              }
              function j(Ce) {
                return w.createNodeArray(e.sameMap(Ce, pe));
              }
              function be(Ce) {
                switch (Ce.kind) {
                  case 190:
                    return w.createParenthesizedType(Ce);
                }
                return pe(Ce);
              }
              function Xe(Ce) {
                switch (Ce.kind) {
                  case 195:
                    return w.createParenthesizedType(Ce);
                }
                return be(Ce);
              }
              function Re(Ce) {
                switch (Ce.kind) {
                  case 192:
                  case 195:
                  case 183:
                    return w.createParenthesizedType(Ce);
                }
                return be(Ce);
              }
              function Fe(Ce) {
                return w.createNodeArray(e.sameMap(Ce, dr));
              }
              function dr(Ce) {
                return ze(Ce) ? w.createParenthesizedType(Ce) : Ce;
              }
              function ze(Ce) {
                return e.isJSDocNullableType(Ce) ? Ce.postfix : e.isNamedTupleMember(Ce) || e.isFunctionTypeNode(Ce) || e.isConstructorTypeNode(Ce) || e.isTypeOperatorNode(Ce) ? ze(Ce.type) : e.isConditionalTypeNode(Ce) ? ze(Ce.falseType) : e.isUnionTypeNode(Ce) || e.isIntersectionTypeNode(Ce) ? ze(e.last(Ce.types)) : e.isInferTypeNode(Ce) ? !!Ce.typeParameter.constraint && ze(Ce.typeParameter.constraint) : false;
              }
              function ve(Ce) {
                return ze(Ce) ? w.createParenthesizedType(Ce) : Re(Ce);
              }
              function er(Ce) {
                return e.isFunctionOrConstructorTypeNode(Ce) && Ce.typeParameters ? w.createParenthesizedType(Ce) : Ce;
              }
              function ar(Ce, $e) {
                return $e === 0 ? er(Ce) : Ce;
              }
              function Cr(Ce) {
                if (e.some(Ce))
                  return w.createNodeArray(e.sameMap(Ce, ar));
              }
            }
            e.createParenthesizerRules = t3, e.nullParenthesizerRules = { getParenthesizeLeftSideOfBinaryForOperator: function(w) {
              return e.identity;
            }, getParenthesizeRightSideOfBinaryForOperator: function(w) {
              return e.identity;
            }, parenthesizeLeftSideOfBinary: function(w, s) {
              return s;
            }, parenthesizeRightSideOfBinary: function(w, s, q) {
              return q;
            }, parenthesizeExpressionOfComputedPropertyName: e.identity, parenthesizeConditionOfConditionalExpression: e.identity, parenthesizeBranchOfConditionalExpression: e.identity, parenthesizeExpressionOfExportDefault: e.identity, parenthesizeExpressionOfNew: function(w) {
              return e.cast(w, e.isLeftHandSideExpression);
            }, parenthesizeLeftSideOfAccess: function(w) {
              return e.cast(w, e.isLeftHandSideExpression);
            }, parenthesizeOperandOfPostfixUnary: function(w) {
              return e.cast(w, e.isLeftHandSideExpression);
            }, parenthesizeOperandOfPrefixUnary: function(w) {
              return e.cast(w, e.isUnaryExpression);
            }, parenthesizeExpressionsOfCommaDelimitedList: function(w) {
              return e.cast(w, e.isNodeArray);
            }, parenthesizeExpressionForDisallowedComma: e.identity, parenthesizeExpressionOfExpressionStatement: e.identity, parenthesizeConciseBodyOfArrowFunction: e.identity, parenthesizeCheckTypeOfConditionalType: e.identity, parenthesizeExtendsTypeOfConditionalType: e.identity, parenthesizeConstituentTypesOfUnionType: function(w) {
              return e.cast(w, e.isNodeArray);
            }, parenthesizeConstituentTypeOfUnionType: e.identity, parenthesizeConstituentTypesOfIntersectionType: function(w) {
              return e.cast(w, e.isNodeArray);
            }, parenthesizeConstituentTypeOfIntersectionType: e.identity, parenthesizeOperandOfTypeOperator: e.identity, parenthesizeOperandOfReadonlyTypeOperator: e.identity, parenthesizeNonArrayTypeOfPostfixType: e.identity, parenthesizeElementTypesOfTupleType: function(w) {
              return e.cast(w, e.isNodeArray);
            }, parenthesizeElementTypeOfTupleType: e.identity, parenthesizeTypeOfOptionalType: e.identity, parenthesizeTypeArguments: function(w) {
              return w && e.cast(w, e.isNodeArray);
            }, parenthesizeLeadingTypeArgument: e.identity };
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(w) {
              return { convertToFunctionBlock: s, convertToFunctionExpression: q, convertToArrayAssignmentElement: F, convertToObjectAssignmentElement: fe, convertToAssignmentPattern: Ee, convertToObjectAssignmentPattern: Se, convertToArrayAssignmentPattern: J, convertToAssignmentElementTarget: se };
              function s(Me, Q) {
                if (e.isBlock(Me))
                  return Me;
                var Be = w.createReturnStatement(Me);
                e.setTextRange(Be, Me);
                var je = w.createBlock([Be], Q);
                return e.setTextRange(je, Me), je;
              }
              function q(Me) {
                if (!Me.body)
                  return e.Debug.fail("Cannot convert a FunctionDeclaration without a body");
                var Q = w.createFunctionExpression(Me.modifiers, Me.asteriskToken, Me.name, Me.typeParameters, Me.parameters, Me.type, Me.body);
                return e.setOriginalNode(Q, Me), e.setTextRange(Q, Me), e.getStartsOnNewLine(Me) && e.setStartsOnNewLine(Q, true), Q;
              }
              function F(Me) {
                if (e.isBindingElement(Me)) {
                  if (Me.dotDotDotToken)
                    return e.Debug.assertNode(Me.name, e.isIdentifier), e.setOriginalNode(e.setTextRange(w.createSpreadElement(Me.name), Me), Me);
                  var Q = se(Me.name);
                  return Me.initializer ? e.setOriginalNode(e.setTextRange(w.createAssignment(Q, Me.initializer), Me), Me) : Q;
                }
                return e.cast(Me, e.isExpression);
              }
              function fe(Me) {
                if (e.isBindingElement(Me)) {
                  if (Me.dotDotDotToken)
                    return e.Debug.assertNode(Me.name, e.isIdentifier), e.setOriginalNode(e.setTextRange(w.createSpreadAssignment(Me.name), Me), Me);
                  if (Me.propertyName) {
                    var Q = se(Me.name);
                    return e.setOriginalNode(e.setTextRange(w.createPropertyAssignment(Me.propertyName, Me.initializer ? w.createAssignment(Q, Me.initializer) : Q), Me), Me);
                  }
                  return e.Debug.assertNode(Me.name, e.isIdentifier), e.setOriginalNode(e.setTextRange(w.createShorthandPropertyAssignment(Me.name, Me.initializer), Me), Me);
                }
                return e.cast(Me, e.isObjectLiteralElementLike);
              }
              function Ee(Me) {
                switch (Me.kind) {
                  case 204:
                  case 206:
                    return J(Me);
                  case 203:
                  case 207:
                    return Se(Me);
                }
              }
              function Se(Me) {
                return e.isObjectBindingPattern(Me) ? e.setOriginalNode(e.setTextRange(w.createObjectLiteralExpression(e.map(Me.elements, fe)), Me), Me) : e.cast(Me, e.isObjectLiteralExpression);
              }
              function J(Me) {
                return e.isArrayBindingPattern(Me) ? e.setOriginalNode(e.setTextRange(w.createArrayLiteralExpression(e.map(Me.elements, F)), Me), Me) : e.cast(Me, e.isArrayLiteralExpression);
              }
              function se(Me) {
                return e.isBindingPattern(Me) ? Ee(Me) : e.cast(Me, e.isExpression);
              }
            }
            e.createNodeConverters = t3, e.nullNodeConverters = { convertToFunctionBlock: e.notImplemented, convertToFunctionExpression: e.notImplemented, convertToArrayAssignmentElement: e.notImplemented, convertToObjectAssignmentElement: e.notImplemented, convertToAssignmentPattern: e.notImplemented, convertToObjectAssignmentPattern: e.notImplemented, convertToArrayAssignmentPattern: e.notImplemented, convertToAssignmentElementTarget: e.notImplemented };
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3 = 0, w;
            (function(H) {
              H[H.None = 0] = "None", H[H.NoParenthesizerRules = 1] = "NoParenthesizerRules", H[H.NoNodeConverters = 2] = "NoNodeConverters", H[H.NoIndentationOnFreshPropertyAccess = 4] = "NoIndentationOnFreshPropertyAccess", H[H.NoOriginalNode = 8] = "NoOriginalNode";
            })(w = e.NodeFactoryFlags || (e.NodeFactoryFlags = {}));
            function s(H, pe) {
              var j = H & 8 ? q : F, be = e.memoize(function() {
                return H & 1 ? e.nullParenthesizerRules : e.createParenthesizerRules(Te);
              }), Xe = e.memoize(function() {
                return H & 2 ? e.nullNodeConverters : e.createNodeConverters(Te);
              }), Re = e.memoizeOne(function(i) {
                return function(o, u) {
                  return Ri(o, i, u);
                };
              }), Fe = e.memoizeOne(function(i) {
                return function(o) {
                  return Qt(i, o);
                };
              }), dr = e.memoizeOne(function(i) {
                return function(o) {
                  return Ni(o, i);
                };
              }), ze = e.memoizeOne(function(i) {
                return function() {
                  return Y_(i);
                };
              }), ve = e.memoizeOne(function(i) {
                return function(o) {
                  return ts(i, o);
                };
              }), er = e.memoizeOne(function(i) {
                return function(o, u) {
                  return Zc(i, o, u);
                };
              }), ar = e.memoizeOne(function(i) {
                return function(o, u) {
                  return Z_(i, o, u);
                };
              }), Cr = e.memoizeOne(function(i) {
                return function(o, u) {
                  return ec(i, o, u);
                };
              }), Ce = e.memoizeOne(function(i) {
                return function(o, u) {
                  return os(i, o, u);
                };
              }), $e = e.memoizeOne(function(i) {
                return function(o, u, b) {
                  return ia(i, o, u, b);
                };
              }), gr = e.memoizeOne(function(i) {
                return function(o, u, b) {
                  return ss(i, o, u, b);
                };
              }), X = e.memoizeOne(function(i) {
                return function(o, u, b, Y) {
                  return l_(i, o, u, b, Y);
                };
              }), Te = { get parenthesizer() {
                return be();
              }, get converters() {
                return Xe();
              }, baseFactory: pe, flags: H, createNodeArray: we, createNumericLiteral: ut, createBigIntLiteral: rt, createStringLiteral: f, createStringLiteralFromNode: h, createRegularExpressionLiteral: oe, createLiteralLikeNode: xr, createIdentifier: pt, updateIdentifier: Ge, createTempVariable: K, createLoopVariable: r, createUniqueName: ct, getGeneratedNameForNode: ft, createPrivateIdentifier: me, createUniquePrivateName: Ye, getGeneratedPrivateNameForNode: vr, createToken: pr, createSuper: Mr, createThis: ot, createNull: At, createTrue: re, createFalse: de, createModifier: He, createModifiersFromModifierFlags: Nr, createQualifiedName: Yr, updateQualifiedName: Ct, createComputedPropertyName: xt, updateComputedPropertyName: Lt, createTypeParameterDeclaration: zt, updateTypeParameterDeclaration: Zt, createParameterDeclaration: mt, updateParameterDeclaration: at, createDecorator: k, updateDecorator: ue, createPropertySignature: Qe, updatePropertySignature: Sr, createPropertyDeclaration: Hr, updatePropertyDeclaration: Dt, createMethodSignature: Xt, updateMethodSignature: cn, createMethodDeclaration: In, updateMethodDeclaration: yn, createConstructorDeclaration: ui, updateConstructorDeclaration: ei, createGetAccessorDeclaration: ri, updateGetAccessorDeclaration: vi, createSetAccessorDeclaration: Yn, updateSetAccessorDeclaration: oi, createCallSignature: Dn, updateCallSignature: Kn, createConstructSignature: si, updateConstructSignature: di, createIndexSignature: Zn, updateIndexSignature: Fn, createClassStaticBlockDeclaration: ln, updateClassStaticBlockDeclaration: En, createTemplateLiteralTypeSpan: gt, updateTemplateLiteralTypeSpan: mi, createKeywordTypeNode: dn, createTypePredicateNode: On, updateTypePredicateNode: br, createTypeReferenceNode: Ae, updateTypeReferenceNode: ur, createFunctionTypeNode: L, updateFunctionTypeNode: qt, createConstructorTypeNode: fr, updateConstructorTypeNode: _r, createTypeQueryNode: tt, updateTypeQueryNode: dt, createTypeLiteralNode: It, updateTypeLiteralNode: an, createArrayTypeNode: sn, updateArrayTypeNode: _e, createTupleTypeNode: Gr, updateTupleTypeNode: Kt, createNamedTupleMember: en, updateNamedTupleMember: Ot, createOptionalTypeNode: rr, updateOptionalTypeNode: Hn, createRestTypeNode: rn, updateRestTypeNode: xn, createUnionTypeNode: kn, updateUnionTypeNode: on, createIntersectionTypeNode: Xr, updateIntersectionTypeNode: wr, createConditionalTypeNode: fn, updateConditionalTypeNode: mn, createInferTypeNode: Mi, updateInferTypeNode: An, createImportTypeNode: li, updateImportTypeNode: Bn, createParenthesizedType: vn, updateParenthesizedType: Ue, createThisTypeNode: Vn, createTypeOperatorNode: Ei, updateTypeOperatorNode: ni, createIndexedAccessTypeNode: Fi, updateIndexedAccessTypeNode: Tn, createMappedTypeNode: jn, updateMappedTypeNode: Ti, createLiteralTypeNode: Si, updateLiteralTypeNode: C, createTemplateLiteralType: xi, updateTemplateLiteralType: ti, createObjectBindingPattern: W, updateObjectBindingPattern: ee, createArrayBindingPattern: le, updateArrayBindingPattern: Ze, createBindingElement: Ir, updateBindingElement: Ar, createArrayLiteralExpression: yt, updateArrayLiteralExpression: Pt, createObjectLiteralExpression: Ut, updateObjectLiteralExpression: jt, createPropertyAccessExpression: H & 4 ? function(i, o) {
                return e.setEmitFlags(Ht(i, o), 131072);
              } : Ht, updatePropertyAccessExpression: gi, createPropertyAccessChain: H & 4 ? function(i, o, u) {
                return e.setEmitFlags(Pi(i, o, u), 131072);
              } : Pi, updatePropertyAccessChain: Gn, createElementAccessExpression: Bi, updateElementAccessExpression: oa, createElementAccessChain: Zi, updateElementAccessChain: Ki, createCallExpression: qi, updateCallExpression: Hi, createCallChain: Gi, updateCallChain: da, createNewExpression: Jn, updateNewExpression: ea, createTaggedTemplateExpression: Xi, updateTaggedTemplateExpression: sa, createTypeAssertion: Li, updateTypeAssertion: p, createParenthesizedExpression: ne, updateParenthesizedExpression: Ne, createFunctionExpression: or, updateFunctionExpression: it2, createArrowFunction: vt, updateArrowFunction: Tt, createDeleteExpression: St, updateDeleteExpression: tn, createTypeOfExpression: Mt, updateTypeOfExpression: $t, createVoidExpression: y, updateVoidExpression: De, createAwaitExpression: R, updateAwaitExpression: Jt, createPrefixUnaryExpression: Qt, updatePrefixUnaryExpression: qn, createPostfixUnaryExpression: Ni, updatePostfixUnaryExpression: _a, createBinaryExpression: Ri, updateBinaryExpression: $i, createConditionalExpression: ra, updateConditionalExpression: Ea, createTemplateExpression: Ui, updateTemplateExpression: ji, createTemplateHead: Is, createTemplateMiddle: wa, createTemplateTail: Ho, createNoSubstitutionTemplateLiteral: Ta, createTemplateLiteralLikeNode: vo, createYieldExpression: Ja, updateYieldExpression: bo, createSpreadElement: Eo, updateSpreadElement: to, createClassExpression: Aa, updateClassExpression: To, createOmittedExpression: Os, createExpressionWithTypeArguments: So, updateExpressionWithTypeArguments: Co, createAsExpression: ka, updateAsExpression: no, createNonNullExpression: Go, updateNonNullExpression: Ii, createSatisfiesExpression: Fa, updateSatisfiesExpression: io, createNonNullChain: Do, updateNonNullChain: xo, createMetaProperty: Xo, updateMetaProperty: $o, createTemplateSpan: zi, updateTemplateSpan: Ms, createSemicolonClassElement: wo, createBlock: l, updateBlock: A, createVariableStatement: M, updateVariableStatement: ke, createEmptyStatement: cr, createExpressionStatement: Zr, updateExpressionStatement: _t, createIfStatement: Rt, updateIfStatement: un, createDoStatement: bn, updateDoStatement: _n, createWhileStatement: Nt, updateWhileStatement: Ft, createForStatement: Sn, updateForStatement: wn, createForInStatement: Wn, updateForInStatement: Ji, createForOfStatement: Ba, updateForOfStatement: Ao, createContinueStatement: ko, updateContinueStatement: Po, createBreakStatement: ao, updateBreakStatement: Vc, createReturnStatement: Ls, updateReturnStatement: No, createWithStatement: Rs, updateWithStatement: Qo, createSwitchStatement: Yo, updateSwitchStatement: w_, createLabeledStatement: js, updateLabeledStatement: Js, createThrowStatement: Fs, updateThrowStatement: oo, createTryStatement: A_, updateTryStatement: Wc, createDebuggerStatement: Kc, createVariableDeclaration: Bs, updateVariableDeclaration: Pa, createVariableDeclarationList: Io, updateVariableDeclarationList: qs, createFunctionDeclaration: Oo, updateFunctionDeclaration: so, createClassDeclaration: Zo, updateClassDeclaration: k_, createInterfaceDeclaration: zs, updateInterfaceDeclaration: P_, createTypeAliasDeclaration: Vs, updateTypeAliasDeclaration: N_, createEnumDeclaration: Un, updateEnumDeclaration: ua, createModuleDeclaration: Sa, updateModuleDeclaration: O_, createModuleBlock: Na, updateModuleBlock: wi, createCaseBlock: M_, updateCaseBlock: Ws, createNamespaceExportDeclaration: L_, updateNamespaceExportDeclaration: Ks, createImportEqualsDeclaration: j_, updateImportEqualsDeclaration: J_, createImportDeclaration: F_, updateImportDeclaration: B_, createImportClause: Hs, updateImportClause: $c, createAssertClause: Mo, updateAssertClause: Gs, createAssertEntry: Xs, updateAssertEntry: Lo, createImportTypeAssertionContainer: $s, updateImportTypeAssertionContainer: _o, createNamespaceImport: U_, updateNamespaceImport: z_, createNamespaceExport: V_, updateNamespaceExport: Qc, createNamedImports: W_, updateNamedImports: K_, createImportSpecifier: H_, updateImportSpecifier: G_, createExportAssignment: Ca, updateExportAssignment: qa, createExportDeclaration: ta, updateExportDeclaration: Qs, createNamedExports: co, updateNamedExports: X_, createExportSpecifier: Ys, updateExportSpecifier: Zs, createMissingDeclaration: $_, createExternalModuleReference: Q_, updateExternalModuleReference: rs, get createJSDocAllType() {
                return ze(315);
              }, get createJSDocUnknownType() {
                return ze(316);
              }, get createJSDocNonNullableType() {
                return ar(318);
              }, get updateJSDocNonNullableType() {
                return Cr(318);
              }, get createJSDocNullableType() {
                return ar(317);
              }, get updateJSDocNullableType() {
                return Cr(317);
              }, get createJSDocOptionalType() {
                return ve(319);
              }, get updateJSDocOptionalType() {
                return er(319);
              }, get createJSDocVariadicType() {
                return ve(321);
              }, get updateJSDocVariadicType() {
                return er(321);
              }, get createJSDocNamepathType() {
                return ve(322);
              }, get updateJSDocNamepathType() {
                return er(322);
              }, createJSDocFunctionType: e_, updateJSDocFunctionType: eu, createJSDocTypeLiteral: rc, updateJSDocTypeLiteral: r_, createJSDocTypeExpression: Ro, updateJSDocTypeExpression: t_, createJSDocSignature: tc, updateJSDocSignature: jo, createJSDocTemplateTag: la, updateJSDocTemplateTag: n_, createJSDocTypedefTag: uo, updateJSDocTypedefTag: ru, createJSDocParameterTag: i_, updateJSDocParameterTag: ns, createJSDocPropertyTag: is, updateJSDocPropertyTag: nc, createJSDocCallbackTag: a_, updateJSDocCallbackTag: ic, createJSDocAugmentsTag: as, updateJSDocAugmentsTag: o_, createJSDocImplementsTag: s_, updateJSDocImplementsTag: ou, createJSDocSeeTag: lo, updateJSDocSeeTag: tu, createJSDocNameReference: Ua, updateJSDocNameReference: Jo, createJSDocMemberName: __, updateJSDocMemberName: nu, createJSDocLink: c_, updateJSDocLink: iu, createJSDocLinkCode: ac, updateJSDocLinkCode: oc, createJSDocLinkPlain: u_, updateJSDocLinkPlain: au, get createJSDocTypeTag() {
                return gr(346);
              }, get updateJSDocTypeTag() {
                return X(346);
              }, get createJSDocReturnTag() {
                return gr(344);
              }, get updateJSDocReturnTag() {
                return X(344);
              }, get createJSDocThisTag() {
                return gr(345);
              }, get updateJSDocThisTag() {
                return X(345);
              }, get createJSDocEnumTag() {
                return gr(342);
              }, get updateJSDocEnumTag() {
                return X(342);
              }, get createJSDocAuthorTag() {
                return Ce(333);
              }, get updateJSDocAuthorTag() {
                return $e(333);
              }, get createJSDocClassTag() {
                return Ce(335);
              }, get updateJSDocClassTag() {
                return $e(335);
              }, get createJSDocPublicTag() {
                return Ce(336);
              }, get updateJSDocPublicTag() {
                return $e(336);
              }, get createJSDocPrivateTag() {
                return Ce(337);
              }, get updateJSDocPrivateTag() {
                return $e(337);
              }, get createJSDocProtectedTag() {
                return Ce(338);
              }, get updateJSDocProtectedTag() {
                return $e(338);
              }, get createJSDocReadonlyTag() {
                return Ce(339);
              }, get updateJSDocReadonlyTag() {
                return $e(339);
              }, get createJSDocOverrideTag() {
                return Ce(340);
              }, get updateJSDocOverrideTag() {
                return $e(340);
              }, get createJSDocDeprecatedTag() {
                return Ce(334);
              }, get updateJSDocDeprecatedTag() {
                return $e(334);
              }, createJSDocUnknownTag: sc, updateJSDocUnknownTag: su, createJSDocText: _c, updateJSDocText: _u, createJSDocComment: _s, updateJSDocComment: cs, createJsxElement: p_, updateJsxElement: f_, createJsxSelfClosingElement: Fo, updateJsxSelfClosingElement: d_, createJsxOpeningElement: Bo, updateJsxOpeningElement: us, createJsxClosingElement: m_, updateJsxClosingElement: cu, createJsxFragment: Ai, createJsxText: po, updateJsxText: uu, createJsxOpeningFragment: ls, createJsxJsxClosingFragment: lu, updateJsxFragment: g_, createJsxAttribute: Ia, updateJsxAttribute: cc, createJsxAttributes: y_, updateJsxAttributes: ps, createJsxSpreadAttribute: uc, updateJsxSpreadAttribute: h_, createJsxExpression: Oa, updateJsxExpression: Ma, createCaseClause: fs2, updateCaseClause: ds, createDefaultClause: v_, updateDefaultClause: qo, createHeritageClause: za, updateHeritageClause: pu, createCatchClause: b_, updateCatchClause: lc, createPropertyAssignment: ms, updatePropertyAssignment: pc, createShorthandPropertyAssignment: fc, updateShorthandPropertyAssignment: fu, createSpreadAssignment: ga, updateSpreadAssignment: dc, createEnumMember: mo, updateEnumMember: mu, createSourceFile: Va, updateSourceFile: mc, createBundle: gc, updateBundle: yc, createUnparsedSource: hc, createUnparsedPrologue: ys, createUnparsedPrepend: gu, createUnparsedTextLike: hs, createUnparsedSyntheticReference: vc, createInputFiles: yu, createSyntheticExpression: vs, createSyntaxList: bc, createNotEmittedStatement: hu, createPartiallyEmittedExpression: Ec, updatePartiallyEmittedExpression: Tc, createCommaListExpression: E_, updateCommaListExpression: Cc, createEndOfDeclarationMarker: Dc, createMergeDeclarationMarker: xc, createSyntheticReferenceExpression: Wa, updateSyntheticReferenceExpression: go, cloneNode: bs, get createComma() {
                return Re(27);
              }, get createAssignment() {
                return Re(63);
              }, get createLogicalOr() {
                return Re(56);
              }, get createLogicalAnd() {
                return Re(55);
              }, get createBitwiseOr() {
                return Re(51);
              }, get createBitwiseXor() {
                return Re(52);
              }, get createBitwiseAnd() {
                return Re(50);
              }, get createStrictEquality() {
                return Re(36);
              }, get createStrictInequality() {
                return Re(37);
              }, get createEquality() {
                return Re(34);
              }, get createInequality() {
                return Re(35);
              }, get createLessThan() {
                return Re(29);
              }, get createLessThanEquals() {
                return Re(32);
              }, get createGreaterThan() {
                return Re(31);
              }, get createGreaterThanEquals() {
                return Re(33);
              }, get createLeftShift() {
                return Re(47);
              }, get createRightShift() {
                return Re(48);
              }, get createUnsignedRightShift() {
                return Re(49);
              }, get createAdd() {
                return Re(39);
              }, get createSubtract() {
                return Re(40);
              }, get createMultiply() {
                return Re(41);
              }, get createDivide() {
                return Re(43);
              }, get createModulo() {
                return Re(44);
              }, get createExponent() {
                return Re(42);
              }, get createPrefixPlus() {
                return Fe(39);
              }, get createPrefixMinus() {
                return Fe(40);
              }, get createPrefixIncrement() {
                return Fe(45);
              }, get createPrefixDecrement() {
                return Fe(46);
              }, get createBitwiseNot() {
                return Fe(54);
              }, get createLogicalNot() {
                return Fe(53);
              }, get createPostfixIncrement() {
                return dr(45);
              }, get createPostfixDecrement() {
                return dr(46);
              }, createImmediatelyInvokedFunctionExpression: wc, createImmediatelyInvokedArrowFunction: vu, createVoidZero: Es, createExportDefault: bu, createExternalModuleExport: Eu, createTypeCheck: T_, createMethodCall: Ka, createGlobalMethodCall: Ts, createFunctionBindCall: Ac, createFunctionCallCall: Tu, createFunctionApplyCall: Su, createArraySliceCall: Cu, createArrayConcatCall: Ss, createObjectDefinePropertyCall: kc, createReflectGetCall: La, createReflectSetCall: Du, createPropertyDescriptor: Pc, createCallBinding: Oc, createAssignmentTargetWrapper: d, inlineExpressions: P, getInternalName: ce, getLocalName: Pe, getExportName: We, getDeclarationName: Er, getNamespaceMemberName: Rr, getExternalModuleOrNamespaceExportName: Fr, restoreOuterExpressions: Ic, restoreEnclosingLabel: Cs, createUseStrictPrologue: Gt, copyPrologue: et, copyStandardPrologue: Wt, copyCustomPrologue: pn, ensureUseStrict: Pn, liftToBlock: _i, mergeLexicalEnvironment: ya, updateModifiers: Ci };
              return Te;
              function we(i, o) {
                if (i === void 0 || i === e.emptyArray)
                  i = [];
                else if (e.isNodeArray(i)) {
                  if (o === void 0 || i.hasTrailingComma === o)
                    return i.transformFlags === void 0 && je(i), e.Debug.attachNodeArrayDebugInfo(i), i;
                  var u = i.slice();
                  return u.pos = i.pos, u.end = i.end, u.hasTrailingComma = o, u.transformFlags = i.transformFlags, e.Debug.attachNodeArrayDebugInfo(u), u;
                }
                var b = i.length, Y = b >= 1 && b <= 4 ? i.slice() : i;
                return e.setTextRangePosEnd(Y, -1, -1), Y.hasTrailingComma = !!o, je(Y), e.Debug.attachNodeArrayDebugInfo(Y), Y;
              }
              function he(i) {
                return pe.createBaseNode(i);
              }
              function yr(i) {
                var o = he(i);
                return o.symbol = void 0, o.localSymbol = void 0, o.locals = void 0, o.nextContainer = void 0, o;
              }
              function kr(i, o, u) {
                var b = yr(i);
                if (u = ki(u), b.name = u, e.canHaveModifiers(b) && (b.modifiers = Xn(o), b.transformFlags |= Be(b.modifiers)), u)
                  switch (b.kind) {
                    case 171:
                    case 174:
                    case 175:
                    case 169:
                    case 299:
                      if (e.isIdentifier(u)) {
                        b.transformFlags |= se(u);
                        break;
                      }
                    default:
                      b.transformFlags |= Q(u);
                      break;
                  }
                return b;
              }
              function nr(i, o, u, b) {
                var Y = kr(i, o, u);
                return Y.typeParameters = Xn(b), Y.transformFlags |= Be(Y.typeParameters), b && (Y.transformFlags |= 1), Y;
              }
              function tr(i, o, u, b, Y, Ke) {
                var Or = nr(i, o, u, b);
                return Or.parameters = we(Y), Or.type = Ke, Or.transformFlags |= Be(Or.parameters) | Q(Or.type), Ke && (Or.transformFlags |= 1), Or.typeArguments = void 0, Or;
              }
              function Lr(i, o) {
                return i !== o && (i.typeArguments = o.typeArguments), j(i, o);
              }
              function zr(i, o, u, b, Y, Ke, Or) {
                var kt = tr(i, o, u, b, Y, Ke);
                return kt.body = Or, kt.transformFlags |= Q(kt.body) & -67108865, Or || (kt.transformFlags |= 1), kt;
              }
              function ye(i, o, u, b, Y) {
                var Ke = nr(i, o, u, b);
                return Ke.heritageClauses = Xn(Y), Ke.transformFlags |= Be(Ke.heritageClauses), Ke;
              }
              function ir(i, o, u, b, Y, Ke) {
                var Or = ye(i, o, u, b, Y);
                return Or.members = we(Ke), Or.transformFlags |= Be(Or.members), Or;
              }
              function Dr(i, o, u, b) {
                var Y = kr(i, o, u);
                return Y.initializer = b, Y.transformFlags |= Q(Y.initializer), Y;
              }
              function Pr(i, o, u, b, Y) {
                var Ke = Dr(i, o, u, Y);
                return Ke.type = b, Ke.transformFlags |= Q(b), b && (Ke.transformFlags |= 1), Ke;
              }
              function Br(i, o) {
                var u = nt(i);
                return u.text = o, u;
              }
              function ut(i, o) {
                o === void 0 && (o = 0);
                var u = Br(8, typeof i == "number" ? i + "" : i);
                return u.numericLiteralFlags = o, o & 384 && (u.transformFlags |= 1024), u;
              }
              function rt(i) {
                var o = Br(9, typeof i == "string" ? i : e.pseudoBigIntToString(i) + "n");
                return o.transformFlags |= 4, o;
              }
              function Z(i, o) {
                var u = Br(10, i);
                return u.singleQuote = o, u;
              }
              function f(i, o, u) {
                var b = Z(i, o);
                return b.hasExtendedUnicodeEscape = u, u && (b.transformFlags |= 1024), b;
              }
              function h(i) {
                var o = Z(e.getTextOfIdentifierOrLiteral(i), void 0);
                return o.textSourceNode = i, o;
              }
              function oe(i) {
                var o = Br(13, i);
                return o;
              }
              function xr(i, o) {
                switch (i) {
                  case 8:
                    return ut(o, 0);
                  case 9:
                    return rt(o);
                  case 10:
                    return f(o, void 0);
                  case 11:
                    return po(o, false);
                  case 12:
                    return po(o, true);
                  case 13:
                    return oe(o);
                  case 14:
                    return vo(i, o, void 0, 0);
                }
              }
              function jr(i, o) {
                o === void 0 && i && (o = e.stringToToken(i)), o === 79 && (o = void 0);
                var u = pe.createBaseIdentifierNode(79);
                return u.originalKeywordKind = o, u.escapedText = e.escapeLeadingUnderscores(i), u;
              }
              function qr(i, o, u, b) {
                var Y = jr(i, void 0);
                return Y.autoGenerateFlags = o, Y.autoGenerateId = t3, Y.autoGeneratePrefix = u, Y.autoGenerateSuffix = b, t3++, Y;
              }
              function pt(i, o, u, b) {
                var Y = jr(i, u);
                return o && (Y.typeArguments = we(o)), Y.originalKeywordKind === 133 && (Y.transformFlags |= 67108864), b && (Y.hasExtendedUnicodeEscape = b, Y.transformFlags |= 1024), Y;
              }
              function Ge(i, o) {
                return i.typeArguments !== o ? j(pt(e.idText(i), o), i) : i;
              }
              function K(i, o, u, b) {
                var Y = 1;
                o && (Y |= 8);
                var Ke = qr("", Y, u, b);
                return i && i(Ke), Ke;
              }
              function r(i) {
                var o = 2;
                return i && (o |= 8), qr("", o, void 0, void 0);
              }
              function ct(i, o, u, b) {
                return o === void 0 && (o = 0), e.Debug.assert(!(o & 7), "Argument out of range: flags"), e.Debug.assert((o & 48) !== 32, "GeneratedIdentifierFlags.FileLevel cannot be set without also setting GeneratedIdentifierFlags.Optimistic"), qr(i, 3 | o, u, b);
              }
              function ft(i, o, u, b) {
                o === void 0 && (o = 0), e.Debug.assert(!(o & 7), "Argument out of range: flags");
                var Y = i ? e.isMemberName(i) ? e.formatGeneratedName(false, u, i, b, e.idText) : "generated@".concat(e.getNodeId(i)) : "";
                (u || b) && (o |= 16);
                var Ke = qr(Y, 4 | o, u, b);
                return Ke.original = i, Ke;
              }
              function Ie(i) {
                var o = pe.createBasePrivateIdentifierNode(80);
                return o.escapedText = e.escapeLeadingUnderscores(i), o.transformFlags |= 16777216, o;
              }
              function me(i) {
                return e.startsWith(i, "#") || e.Debug.fail("First character of private identifier must be #: " + i), Ie(i);
              }
              function xe(i, o, u, b) {
                var Y = Ie(i);
                return Y.autoGenerateFlags = o, Y.autoGenerateId = t3, Y.autoGeneratePrefix = u, Y.autoGenerateSuffix = b, t3++, Y;
              }
              function Ye(i, o, u) {
                i && !e.startsWith(i, "#") && e.Debug.fail("First character of private identifier must be #: " + i);
                var b = 8 | (i ? 3 : 1);
                return xe(i != null ? i : "", b, o, u);
              }
              function vr(i, o, u) {
                var b = e.isMemberName(i) ? e.formatGeneratedName(true, o, i, u, e.idText) : "#generated@".concat(e.getNodeId(i)), Y = o || u ? 16 : 0, Ke = xe(b, 4 | Y, o, u);
                return Ke.original = i, Ke;
              }
              function nt(i) {
                return pe.createBaseTokenNode(i);
              }
              function pr(i) {
                e.Debug.assert(i >= 0 && i <= 162, "Invalid token"), e.Debug.assert(i <= 14 || i >= 17, "Invalid token. Use 'createTemplateLiteralLikeNode' to create template literals."), e.Debug.assert(i <= 8 || i >= 14, "Invalid token. Use 'createLiteralLikeNode' to create literals."), e.Debug.assert(i !== 79, "Invalid token. Use 'createIdentifier' to create identifiers");
                var o = nt(i), u = 0;
                switch (i) {
                  case 132:
                    u = 384;
                    break;
                  case 123:
                  case 121:
                  case 122:
                  case 146:
                  case 126:
                  case 136:
                  case 85:
                  case 131:
                  case 148:
                  case 160:
                  case 144:
                  case 149:
                  case 101:
                  case 145:
                  case 161:
                  case 152:
                  case 134:
                  case 153:
                  case 114:
                  case 157:
                  case 155:
                    u = 1;
                    break;
                  case 106:
                    u = 134218752;
                    break;
                  case 124:
                    u = 1024;
                    break;
                  case 127:
                    u = 16777216;
                    break;
                  case 108:
                    u = 16384;
                    break;
                }
                return u && (o.transformFlags |= u), o;
              }
              function Mr() {
                return pr(106);
              }
              function ot() {
                return pr(108);
              }
              function At() {
                return pr(104);
              }
              function re() {
                return pr(110);
              }
              function de() {
                return pr(95);
              }
              function He(i) {
                return pr(i);
              }
              function Nr(i) {
                var o = [];
                return i & 1 && o.push(He(93)), i & 2 && o.push(He(136)), i & 1024 && o.push(He(88)), i & 2048 && o.push(He(85)), i & 4 && o.push(He(123)), i & 8 && o.push(He(121)), i & 16 && o.push(He(122)), i & 256 && o.push(He(126)), i & 32 && o.push(He(124)), i & 16384 && o.push(He(161)), i & 64 && o.push(He(146)), i & 128 && o.push(He(127)), i & 512 && o.push(He(132)), i & 32768 && o.push(He(101)), i & 65536 && o.push(He(145)), o.length ? o : void 0;
              }
              function Yr(i, o) {
                var u = he(163);
                return u.left = i, u.right = ki(o), u.transformFlags |= Q(u.left) | se(u.right), u;
              }
              function Ct(i, o, u) {
                return i.left !== o || i.right !== u ? j(Yr(o, u), i) : i;
              }
              function xt(i) {
                var o = he(164);
                return o.expression = be().parenthesizeExpressionOfComputedPropertyName(i), o.transformFlags |= Q(o.expression) | 1024 | 131072, o;
              }
              function Lt(i, o) {
                return i.expression !== o ? j(xt(o), i) : i;
              }
              function zt(i, o, u, b) {
                var Y = kr(165, i, o);
                return Y.constraint = u, Y.default = b, Y.transformFlags = 1, Y;
              }
              function Zt(i, o, u, b, Y) {
                return i.modifiers !== o || i.name !== u || i.constraint !== b || i.default !== Y ? j(zt(o, u, b, Y), i) : i;
              }
              function mt(i, o, u, b, Y, Ke) {
                var Or = Pr(166, i, u, Y, Ke && be().parenthesizeExpressionForDisallowedComma(Ke));
                return Or.dotDotDotToken = o, Or.questionToken = b, e.isThisIdentifier(Or.name) ? Or.transformFlags = 1 : (Or.transformFlags |= Q(Or.dotDotDotToken) | Q(Or.questionToken), b && (Or.transformFlags |= 1), e.modifiersToFlags(Or.modifiers) & 16476 && (Or.transformFlags |= 8192), (Ke || o) && (Or.transformFlags |= 1024)), Or;
              }
              function at(i, o, u, b, Y, Ke, Or) {
                return i.modifiers !== o || i.dotDotDotToken !== u || i.name !== b || i.questionToken !== Y || i.type !== Ke || i.initializer !== Or ? j(mt(o, u, b, Y, Ke, Or), i) : i;
              }
              function k(i) {
                var o = he(167);
                return o.expression = be().parenthesizeLeftSideOfAccess(i, false), o.transformFlags |= Q(o.expression) | 1 | 8192 | 33554432, o;
              }
              function ue(i, o) {
                return i.expression !== o ? j(k(o), i) : i;
              }
              function Qe(i, o, u, b) {
                var Y = kr(168, i, o);
                return Y.type = b, Y.questionToken = u, Y.transformFlags = 1, Y.initializer = void 0, Y;
              }
              function Sr(i, o, u, b, Y) {
                return i.modifiers !== o || i.name !== u || i.questionToken !== b || i.type !== Y ? Kr(Qe(o, u, b, Y), i) : i;
              }
              function Kr(i, o) {
                return i !== o && (i.initializer = o.initializer), j(i, o);
              }
              function Hr(i, o, u, b, Y) {
                var Ke = Pr(169, i, o, b, Y);
                return Ke.questionToken = u && e.isQuestionToken(u) ? u : void 0, Ke.exclamationToken = u && e.isExclamationToken(u) ? u : void 0, Ke.transformFlags |= Q(Ke.questionToken) | Q(Ke.exclamationToken) | 16777216, (e.isComputedPropertyName(Ke.name) || e.hasStaticModifier(Ke) && Ke.initializer) && (Ke.transformFlags |= 8192), (u || e.modifiersToFlags(Ke.modifiers) & 2) && (Ke.transformFlags |= 1), Ke;
              }
              function Dt(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.name !== u || i.questionToken !== (b !== void 0 && e.isQuestionToken(b) ? b : void 0) || i.exclamationToken !== (b !== void 0 && e.isExclamationToken(b) ? b : void 0) || i.type !== Y || i.initializer !== Ke ? j(Hr(o, u, b, Y, Ke), i) : i;
              }
              function Xt(i, o, u, b, Y, Ke) {
                var Or = tr(170, i, o, b, Y, Ke);
                return Or.questionToken = u, Or.transformFlags = 1, Or;
              }
              function cn(i, o, u, b, Y, Ke, Or) {
                return i.modifiers !== o || i.name !== u || i.questionToken !== b || i.typeParameters !== Y || i.parameters !== Ke || i.type !== Or ? Lr(Xt(o, u, b, Y, Ke, Or), i) : i;
              }
              function In(i, o, u, b, Y, Ke, Or, kt) {
                var $n = zr(171, i, u, Y, Ke, Or, kt);
                return $n.asteriskToken = o, $n.questionToken = b, $n.transformFlags |= Q($n.asteriskToken) | Q($n.questionToken) | 1024, b && ($n.transformFlags |= 1), e.modifiersToFlags($n.modifiers) & 512 ? o ? $n.transformFlags |= 128 : $n.transformFlags |= 256 : o && ($n.transformFlags |= 2048), $n.exclamationToken = void 0, $n;
              }
              function yn(i, o, u, b, Y, Ke, Or, kt, $n) {
                return i.modifiers !== o || i.asteriskToken !== u || i.name !== b || i.questionToken !== Y || i.typeParameters !== Ke || i.parameters !== Or || i.type !== kt || i.body !== $n ? hn(In(o, u, b, Y, Ke, Or, kt, $n), i) : i;
              }
              function hn(i, o) {
                return i !== o && (i.exclamationToken = o.exclamationToken), j(i, o);
              }
              function ln(i) {
                var o = nr(172, void 0, void 0, void 0);
                return o.body = i, o.transformFlags = Q(i) | 16777216, o.illegalDecorators = void 0, o.modifiers = void 0, o;
              }
              function En(i, o) {
                return i.body !== o ? Vt(ln(o), i) : i;
              }
              function Vt(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators, i.modifiers = o.modifiers), j(i, o);
              }
              function ui(i, o, u) {
                var b = zr(173, i, void 0, void 0, o, void 0, u);
                return b.transformFlags |= 1024, b.illegalDecorators = void 0, b.typeParameters = void 0, b.type = void 0, b;
              }
              function ei(i, o, u, b) {
                return i.modifiers !== o || i.parameters !== u || i.body !== b ? hi(ui(o, u, b), i) : i;
              }
              function hi(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators, i.typeParameters = o.typeParameters, i.type = o.type), Lr(i, o);
              }
              function ri(i, o, u, b, Y) {
                var Ke = zr(174, i, o, void 0, u, b, Y);
                return Ke.typeParameters = void 0, Ke;
              }
              function vi(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.name !== u || i.parameters !== b || i.type !== Y || i.body !== Ke ? Qn(ri(o, u, b, Y, Ke), i) : i;
              }
              function Qn(i, o) {
                return i !== o && (i.typeParameters = o.typeParameters), Lr(i, o);
              }
              function Yn(i, o, u, b) {
                var Y = zr(175, i, o, void 0, u, void 0, b);
                return Y.typeParameters = void 0, Y.type = void 0, Y;
              }
              function oi(i, o, u, b, Y) {
                return i.modifiers !== o || i.name !== u || i.parameters !== b || i.body !== Y ? bi(Yn(o, u, b, Y), i) : i;
              }
              function bi(i, o) {
                return i !== o && (i.typeParameters = o.typeParameters, i.type = o.type), Lr(i, o);
              }
              function Dn(i, o, u) {
                var b = tr(176, void 0, void 0, i, o, u);
                return b.transformFlags = 1, b;
              }
              function Kn(i, o, u, b) {
                return i.typeParameters !== o || i.parameters !== u || i.type !== b ? Lr(Dn(o, u, b), i) : i;
              }
              function si(i, o, u) {
                var b = tr(177, void 0, void 0, i, o, u);
                return b.transformFlags = 1, b;
              }
              function di(i, o, u, b) {
                return i.typeParameters !== o || i.parameters !== u || i.type !== b ? Lr(si(o, u, b), i) : i;
              }
              function Zn(i, o, u) {
                var b = tr(178, i, void 0, void 0, o, u);
                return b.transformFlags = 1, b;
              }
              function Fn(i, o, u, b) {
                return i.parameters !== u || i.type !== b || i.modifiers !== o ? Lr(Zn(o, u, b), i) : i;
              }
              function gt(i, o) {
                var u = he(201);
                return u.type = i, u.literal = o, u.transformFlags = 1, u;
              }
              function mi(i, o, u) {
                return i.type !== o || i.literal !== u ? j(gt(o, u), i) : i;
              }
              function dn(i) {
                return pr(i);
              }
              function On(i, o, u) {
                var b = he(179);
                return b.assertsModifier = i, b.parameterName = ki(o), b.type = u, b.transformFlags = 1, b;
              }
              function br(i, o, u, b) {
                return i.assertsModifier !== o || i.parameterName !== u || i.type !== b ? j(On(o, u, b), i) : i;
              }
              function Ae(i, o) {
                var u = he(180);
                return u.typeName = ki(i), u.typeArguments = o && be().parenthesizeTypeArguments(we(o)), u.transformFlags = 1, u;
              }
              function ur(i, o, u) {
                return i.typeName !== o || i.typeArguments !== u ? j(Ae(o, u), i) : i;
              }
              function L(i, o, u) {
                var b = tr(181, void 0, void 0, i, o, u);
                return b.transformFlags = 1, b.modifiers = void 0, b;
              }
              function qt(i, o, u, b) {
                return i.typeParameters !== o || i.parameters !== u || i.type !== b ? nn(L(o, u, b), i) : i;
              }
              function nn(i, o) {
                return i !== o && (i.modifiers = o.modifiers), Lr(i, o);
              }
              function fr() {
                for (var i = [], o = 0; o < arguments.length; o++)
                  i[o] = arguments[o];
                return i.length === 4 ? Le.apply(void 0, i) : i.length === 3 ? Ve.apply(void 0, i) : e.Debug.fail("Incorrect number of arguments specified.");
              }
              function Le(i, o, u, b) {
                var Y = tr(182, i, void 0, o, u, b);
                return Y.transformFlags = 1, Y;
              }
              function Ve(i, o, u) {
                return Le(void 0, i, o, u);
              }
              function _r() {
                for (var i = [], o = 0; o < arguments.length; o++)
                  i[o] = arguments[o];
                return i.length === 5 ? lr.apply(void 0, i) : i.length === 4 ? Vr.apply(void 0, i) : e.Debug.fail("Incorrect number of arguments specified.");
              }
              function lr(i, o, u, b, Y) {
                return i.modifiers !== o || i.typeParameters !== u || i.parameters !== b || i.type !== Y ? Lr(fr(o, u, b, Y), i) : i;
              }
              function Vr(i, o, u, b) {
                return lr(i, i.modifiers, o, u, b);
              }
              function tt(i, o) {
                var u = he(183);
                return u.exprName = i, u.typeArguments = o && be().parenthesizeTypeArguments(o), u.transformFlags = 1, u;
              }
              function dt(i, o, u) {
                return i.exprName !== o || i.typeArguments !== u ? j(tt(o, u), i) : i;
              }
              function It(i) {
                var o = he(184);
                return o.members = we(i), o.transformFlags = 1, o;
              }
              function an(i, o) {
                return i.members !== o ? j(It(o), i) : i;
              }
              function sn(i) {
                var o = he(185);
                return o.elementType = be().parenthesizeNonArrayTypeOfPostfixType(i), o.transformFlags = 1, o;
              }
              function _e(i, o) {
                return i.elementType !== o ? j(sn(o), i) : i;
              }
              function Gr(i) {
                var o = he(186);
                return o.elements = we(be().parenthesizeElementTypesOfTupleType(i)), o.transformFlags = 1, o;
              }
              function Kt(i, o) {
                return i.elements !== o ? j(Gr(o), i) : i;
              }
              function en(i, o, u, b) {
                var Y = he(199);
                return Y.dotDotDotToken = i, Y.name = o, Y.questionToken = u, Y.type = b, Y.transformFlags = 1, Y;
              }
              function Ot(i, o, u, b, Y) {
                return i.dotDotDotToken !== o || i.name !== u || i.questionToken !== b || i.type !== Y ? j(en(o, u, b, Y), i) : i;
              }
              function rr(i) {
                var o = he(187);
                return o.type = be().parenthesizeTypeOfOptionalType(i), o.transformFlags = 1, o;
              }
              function Hn(i, o) {
                return i.type !== o ? j(rr(o), i) : i;
              }
              function rn(i) {
                var o = he(188);
                return o.type = i, o.transformFlags = 1, o;
              }
              function xn(i, o) {
                return i.type !== o ? j(rn(o), i) : i;
              }
              function Mn(i, o, u) {
                var b = he(i);
                return b.types = Te.createNodeArray(u(o)), b.transformFlags = 1, b;
              }
              function Rn(i, o, u) {
                return i.types !== o ? j(Mn(i.kind, o, u), i) : i;
              }
              function kn(i) {
                return Mn(189, i, be().parenthesizeConstituentTypesOfUnionType);
              }
              function on(i, o) {
                return Rn(i, o, be().parenthesizeConstituentTypesOfUnionType);
              }
              function Xr(i) {
                return Mn(190, i, be().parenthesizeConstituentTypesOfIntersectionType);
              }
              function wr(i, o) {
                return Rn(i, o, be().parenthesizeConstituentTypesOfIntersectionType);
              }
              function fn(i, o, u, b) {
                var Y = he(191);
                return Y.checkType = be().parenthesizeCheckTypeOfConditionalType(i), Y.extendsType = be().parenthesizeExtendsTypeOfConditionalType(o), Y.trueType = u, Y.falseType = b, Y.transformFlags = 1, Y;
              }
              function mn(i, o, u, b, Y) {
                return i.checkType !== o || i.extendsType !== u || i.trueType !== b || i.falseType !== Y ? j(fn(o, u, b, Y), i) : i;
              }
              function Mi(i) {
                var o = he(192);
                return o.typeParameter = i, o.transformFlags = 1, o;
              }
              function An(i, o) {
                return i.typeParameter !== o ? j(Mi(o), i) : i;
              }
              function xi(i, o) {
                var u = he(200);
                return u.head = i, u.templateSpans = we(o), u.transformFlags = 1, u;
              }
              function ti(i, o, u) {
                return i.head !== o || i.templateSpans !== u ? j(xi(o, u), i) : i;
              }
              function li(i, o, u, b, Y) {
                Y === void 0 && (Y = false);
                var Ke = he(202);
                return Ke.argument = i, Ke.assertions = o, Ke.qualifier = u, Ke.typeArguments = b && be().parenthesizeTypeArguments(b), Ke.isTypeOf = Y, Ke.transformFlags = 1, Ke;
              }
              function Bn(i, o, u, b, Y, Ke) {
                return Ke === void 0 && (Ke = i.isTypeOf), i.argument !== o || i.assertions !== u || i.qualifier !== b || i.typeArguments !== Y || i.isTypeOf !== Ke ? j(li(o, u, b, Y, Ke), i) : i;
              }
              function vn(i) {
                var o = he(193);
                return o.type = i, o.transformFlags = 1, o;
              }
              function Ue(i, o) {
                return i.type !== o ? j(vn(o), i) : i;
              }
              function Vn() {
                var i = he(194);
                return i.transformFlags = 1, i;
              }
              function Ei(i, o) {
                var u = he(195);
                return u.operator = i, u.type = i === 146 ? be().parenthesizeOperandOfReadonlyTypeOperator(o) : be().parenthesizeOperandOfTypeOperator(o), u.transformFlags = 1, u;
              }
              function ni(i, o) {
                return i.type !== o ? j(Ei(i.operator, o), i) : i;
              }
              function Fi(i, o) {
                var u = he(196);
                return u.objectType = be().parenthesizeNonArrayTypeOfPostfixType(i), u.indexType = o, u.transformFlags = 1, u;
              }
              function Tn(i, o, u) {
                return i.objectType !== o || i.indexType !== u ? j(Fi(o, u), i) : i;
              }
              function jn(i, o, u, b, Y, Ke) {
                var Or = he(197);
                return Or.readonlyToken = i, Or.typeParameter = o, Or.nameType = u, Or.questionToken = b, Or.type = Y, Or.members = Ke && we(Ke), Or.transformFlags = 1, Or;
              }
              function Ti(i, o, u, b, Y, Ke, Or) {
                return i.readonlyToken !== o || i.typeParameter !== u || i.nameType !== b || i.questionToken !== Y || i.type !== Ke || i.members !== Or ? j(jn(o, u, b, Y, Ke, Or), i) : i;
              }
              function Si(i) {
                var o = he(198);
                return o.literal = i, o.transformFlags = 1, o;
              }
              function C(i, o) {
                return i.literal !== o ? j(Si(o), i) : i;
              }
              function W(i) {
                var o = he(203);
                return o.elements = we(i), o.transformFlags |= Be(o.elements) | 1024 | 524288, o.transformFlags & 32768 && (o.transformFlags |= 65664), o;
              }
              function ee(i, o) {
                return i.elements !== o ? j(W(o), i) : i;
              }
              function le(i) {
                var o = he(204);
                return o.elements = we(i), o.transformFlags |= Be(o.elements) | 1024 | 524288, o;
              }
              function Ze(i, o) {
                return i.elements !== o ? j(le(o), i) : i;
              }
              function Ir(i, o, u, b) {
                var Y = Dr(205, void 0, u, b && be().parenthesizeExpressionForDisallowedComma(b));
                return Y.propertyName = ki(o), Y.dotDotDotToken = i, Y.transformFlags |= Q(Y.dotDotDotToken) | 1024, Y.propertyName && (Y.transformFlags |= e.isIdentifier(Y.propertyName) ? se(Y.propertyName) : Q(Y.propertyName)), i && (Y.transformFlags |= 32768), Y;
              }
              function Ar(i, o, u, b, Y) {
                return i.propertyName !== u || i.dotDotDotToken !== o || i.name !== b || i.initializer !== Y ? j(Ir(o, u, b, Y), i) : i;
              }
              function hr(i) {
                var o = he(i);
                return o;
              }
              function yt(i, o) {
                var u = hr(206), b = i && e.lastOrUndefined(i), Y = we(i, b && e.isOmittedExpression(b) ? true : void 0);
                return u.elements = be().parenthesizeExpressionsOfCommaDelimitedList(Y), u.multiLine = o, u.transformFlags |= Be(u.elements), u;
              }
              function Pt(i, o) {
                return i.elements !== o ? j(yt(o, i.multiLine), i) : i;
              }
              function Ut(i, o) {
                var u = hr(207);
                return u.properties = we(i), u.multiLine = o, u.transformFlags |= Be(u.properties), u;
              }
              function jt(i, o) {
                return i.properties !== o ? j(Ut(o, i.multiLine), i) : i;
              }
              function Ht(i, o) {
                var u = hr(208);
                return u.expression = be().parenthesizeLeftSideOfAccess(i, false), u.name = ki(o), u.transformFlags = Q(u.expression) | (e.isIdentifier(u.name) ? se(u.name) : Q(u.name) | 536870912), e.isSuperKeyword(i) && (u.transformFlags |= 384), u;
              }
              function gi(i, o, u) {
                return e.isPropertyAccessChain(i) ? Gn(i, o, i.questionDotToken, e.cast(u, e.isIdentifier)) : i.expression !== o || i.name !== u ? j(Ht(o, u), i) : i;
              }
              function Pi(i, o, u) {
                var b = hr(208);
                return b.flags |= 32, b.expression = be().parenthesizeLeftSideOfAccess(i, true), b.questionDotToken = o, b.name = ki(u), b.transformFlags |= 32 | Q(b.expression) | Q(b.questionDotToken) | (e.isIdentifier(b.name) ? se(b.name) : Q(b.name) | 536870912), b;
              }
              function Gn(i, o, u, b) {
                return e.Debug.assert(!!(i.flags & 32), "Cannot update a PropertyAccessExpression using updatePropertyAccessChain. Use updatePropertyAccess instead."), i.expression !== o || i.questionDotToken !== u || i.name !== b ? j(Pi(o, u, b), i) : i;
              }
              function Bi(i, o) {
                var u = hr(209);
                return u.expression = be().parenthesizeLeftSideOfAccess(i, false), u.argumentExpression = aa(o), u.transformFlags |= Q(u.expression) | Q(u.argumentExpression), e.isSuperKeyword(i) && (u.transformFlags |= 384), u;
              }
              function oa(i, o, u) {
                return e.isElementAccessChain(i) ? Ki(i, o, i.questionDotToken, u) : i.expression !== o || i.argumentExpression !== u ? j(Bi(o, u), i) : i;
              }
              function Zi(i, o, u) {
                var b = hr(209);
                return b.flags |= 32, b.expression = be().parenthesizeLeftSideOfAccess(i, true), b.questionDotToken = o, b.argumentExpression = aa(u), b.transformFlags |= Q(b.expression) | Q(b.questionDotToken) | Q(b.argumentExpression) | 32, b;
              }
              function Ki(i, o, u, b) {
                return e.Debug.assert(!!(i.flags & 32), "Cannot update a ElementAccessExpression using updateElementAccessChain. Use updateElementAccess instead."), i.expression !== o || i.questionDotToken !== u || i.argumentExpression !== b ? j(Zi(o, u, b), i) : i;
              }
              function qi(i, o, u) {
                var b = hr(210);
                return b.expression = be().parenthesizeLeftSideOfAccess(i, false), b.typeArguments = Xn(o), b.arguments = be().parenthesizeExpressionsOfCommaDelimitedList(we(u)), b.transformFlags |= Q(b.expression) | Be(b.typeArguments) | Be(b.arguments), b.typeArguments && (b.transformFlags |= 1), e.isImportKeyword(b.expression) ? b.transformFlags |= 8388608 : e.isSuperProperty(b.expression) && (b.transformFlags |= 16384), b;
              }
              function Hi(i, o, u, b) {
                return e.isCallChain(i) ? da(i, o, i.questionDotToken, u, b) : i.expression !== o || i.typeArguments !== u || i.arguments !== b ? j(qi(o, u, b), i) : i;
              }
              function Gi(i, o, u, b) {
                var Y = hr(210);
                return Y.flags |= 32, Y.expression = be().parenthesizeLeftSideOfAccess(i, true), Y.questionDotToken = o, Y.typeArguments = Xn(u), Y.arguments = be().parenthesizeExpressionsOfCommaDelimitedList(we(b)), Y.transformFlags |= Q(Y.expression) | Q(Y.questionDotToken) | Be(Y.typeArguments) | Be(Y.arguments) | 32, Y.typeArguments && (Y.transformFlags |= 1), e.isSuperProperty(Y.expression) && (Y.transformFlags |= 16384), Y;
              }
              function da(i, o, u, b, Y) {
                return e.Debug.assert(!!(i.flags & 32), "Cannot update a CallExpression using updateCallChain. Use updateCall instead."), i.expression !== o || i.questionDotToken !== u || i.typeArguments !== b || i.arguments !== Y ? j(Gi(o, u, b, Y), i) : i;
              }
              function Jn(i, o, u) {
                var b = hr(211);
                return b.expression = be().parenthesizeExpressionOfNew(i), b.typeArguments = Xn(o), b.arguments = u ? be().parenthesizeExpressionsOfCommaDelimitedList(u) : void 0, b.transformFlags |= Q(b.expression) | Be(b.typeArguments) | Be(b.arguments) | 32, b.typeArguments && (b.transformFlags |= 1), b;
              }
              function ea(i, o, u, b) {
                return i.expression !== o || i.typeArguments !== u || i.arguments !== b ? j(Jn(o, u, b), i) : i;
              }
              function Xi(i, o, u) {
                var b = hr(212);
                return b.tag = be().parenthesizeLeftSideOfAccess(i, false), b.typeArguments = Xn(o), b.template = u, b.transformFlags |= Q(b.tag) | Be(b.typeArguments) | Q(b.template) | 1024, b.typeArguments && (b.transformFlags |= 1), e.hasInvalidEscape(b.template) && (b.transformFlags |= 128), b;
              }
              function sa(i, o, u, b) {
                return i.tag !== o || i.typeArguments !== u || i.template !== b ? j(Xi(o, u, b), i) : i;
              }
              function Li(i, o) {
                var u = hr(213);
                return u.expression = be().parenthesizeOperandOfPrefixUnary(o), u.type = i, u.transformFlags |= Q(u.expression) | Q(u.type) | 1, u;
              }
              function p(i, o, u) {
                return i.type !== o || i.expression !== u ? j(Li(o, u), i) : i;
              }
              function ne(i) {
                var o = hr(214);
                return o.expression = i, o.transformFlags = Q(o.expression), o;
              }
              function Ne(i, o) {
                return i.expression !== o ? j(ne(o), i) : i;
              }
              function or(i, o, u, b, Y, Ke, Or) {
                var kt = zr(215, i, u, b, Y, Ke, Or);
                return kt.asteriskToken = o, kt.transformFlags |= Q(kt.asteriskToken), kt.typeParameters && (kt.transformFlags |= 1), e.modifiersToFlags(kt.modifiers) & 512 ? kt.asteriskToken ? kt.transformFlags |= 128 : kt.transformFlags |= 256 : kt.asteriskToken && (kt.transformFlags |= 2048), kt;
              }
              function it2(i, o, u, b, Y, Ke, Or, kt) {
                return i.name !== b || i.modifiers !== o || i.asteriskToken !== u || i.typeParameters !== Y || i.parameters !== Ke || i.type !== Or || i.body !== kt ? Lr(or(o, u, b, Y, Ke, Or, kt), i) : i;
              }
              function vt(i, o, u, b, Y, Ke) {
                var Or = zr(216, i, void 0, o, u, b, be().parenthesizeConciseBodyOfArrowFunction(Ke));
                return Or.equalsGreaterThanToken = Y != null ? Y : pr(38), Or.transformFlags |= Q(Or.equalsGreaterThanToken) | 1024, e.modifiersToFlags(Or.modifiers) & 512 && (Or.transformFlags |= 16640), Or;
              }
              function Tt(i, o, u, b, Y, Ke, Or) {
                return i.modifiers !== o || i.typeParameters !== u || i.parameters !== b || i.type !== Y || i.equalsGreaterThanToken !== Ke || i.body !== Or ? Lr(vt(o, u, b, Y, Ke, Or), i) : i;
              }
              function St(i) {
                var o = hr(217);
                return o.expression = be().parenthesizeOperandOfPrefixUnary(i), o.transformFlags |= Q(o.expression), o;
              }
              function tn(i, o) {
                return i.expression !== o ? j(St(o), i) : i;
              }
              function Mt(i) {
                var o = hr(218);
                return o.expression = be().parenthesizeOperandOfPrefixUnary(i), o.transformFlags |= Q(o.expression), o;
              }
              function $t(i, o) {
                return i.expression !== o ? j(Mt(o), i) : i;
              }
              function y(i) {
                var o = hr(219);
                return o.expression = be().parenthesizeOperandOfPrefixUnary(i), o.transformFlags |= Q(o.expression), o;
              }
              function De(i, o) {
                return i.expression !== o ? j(y(o), i) : i;
              }
              function R(i) {
                var o = hr(220);
                return o.expression = be().parenthesizeOperandOfPrefixUnary(i), o.transformFlags |= Q(o.expression) | 256 | 128 | 2097152, o;
              }
              function Jt(i, o) {
                return i.expression !== o ? j(R(o), i) : i;
              }
              function Qt(i, o) {
                var u = hr(221);
                return u.operator = i, u.operand = be().parenthesizeOperandOfPrefixUnary(o), u.transformFlags |= Q(u.operand), (i === 45 || i === 46) && e.isIdentifier(u.operand) && !e.isGeneratedIdentifier(u.operand) && !e.isLocalName(u.operand) && (u.transformFlags |= 268435456), u;
              }
              function qn(i, o) {
                return i.operand !== o ? j(Qt(i.operator, o), i) : i;
              }
              function Ni(i, o) {
                var u = hr(222);
                return u.operator = o, u.operand = be().parenthesizeOperandOfPostfixUnary(i), u.transformFlags |= Q(u.operand), e.isIdentifier(u.operand) && !e.isGeneratedIdentifier(u.operand) && !e.isLocalName(u.operand) && (u.transformFlags |= 268435456), u;
              }
              function _a(i, o) {
                return i.operand !== o ? j(Ni(o, i.operator), i) : i;
              }
              function Ri(i, o, u) {
                var b = hr(223), Y = Ga(o), Ke = Y.kind;
                return b.left = be().parenthesizeLeftSideOfBinary(Ke, i), b.operatorToken = Y, b.right = be().parenthesizeRightSideOfBinary(Ke, b.left, u), b.transformFlags |= Q(b.left) | Q(b.operatorToken) | Q(b.right), Ke === 60 ? b.transformFlags |= 32 : Ke === 63 ? e.isObjectLiteralExpression(b.left) ? b.transformFlags |= 5248 | ca(b.left) : e.isArrayLiteralExpression(b.left) && (b.transformFlags |= 5120 | ca(b.left)) : Ke === 42 || Ke === 67 ? b.transformFlags |= 512 : e.isLogicalOrCoalescingAssignmentOperator(Ke) && (b.transformFlags |= 16), Ke === 101 && e.isPrivateIdentifier(b.left) && (b.transformFlags |= 536870912), b;
              }
              function ca(i) {
                if (i.transformFlags & 65536)
                  return 65536;
                if (i.transformFlags & 128)
                  for (var o = 0, u = e.getElementsOfBindingOrAssignmentPattern(i); o < u.length; o++) {
                    var b = u[o], Y = e.getTargetOfBindingOrAssignmentElement(b);
                    if (Y && e.isAssignmentPattern(Y)) {
                      if (Y.transformFlags & 65536)
                        return 65536;
                      if (Y.transformFlags & 128) {
                        var Ke = ca(Y);
                        if (Ke)
                          return Ke;
                      }
                    }
                  }
                return 0;
              }
              function $i(i, o, u, b) {
                return i.left !== o || i.operatorToken !== u || i.right !== b ? j(Ri(o, u, b), i) : i;
              }
              function ra(i, o, u, b, Y) {
                var Ke = hr(224);
                return Ke.condition = be().parenthesizeConditionOfConditionalExpression(i), Ke.questionToken = o != null ? o : pr(57), Ke.whenTrue = be().parenthesizeBranchOfConditionalExpression(u), Ke.colonToken = b != null ? b : pr(58), Ke.whenFalse = be().parenthesizeBranchOfConditionalExpression(Y), Ke.transformFlags |= Q(Ke.condition) | Q(Ke.questionToken) | Q(Ke.whenTrue) | Q(Ke.colonToken) | Q(Ke.whenFalse), Ke;
              }
              function Ea(i, o, u, b, Y, Ke) {
                return i.condition !== o || i.questionToken !== u || i.whenTrue !== b || i.colonToken !== Y || i.whenFalse !== Ke ? j(ra(o, u, b, Y, Ke), i) : i;
              }
              function Ui(i, o) {
                var u = hr(225);
                return u.head = i, u.templateSpans = we(o), u.transformFlags |= Q(u.head) | Be(u.templateSpans) | 1024, u;
              }
              function ji(i, o, u) {
                return i.head !== o || i.templateSpans !== u ? j(Ui(o, u), i) : i;
              }
              function ma(i, o, u, b) {
                b === void 0 && (b = 0), e.Debug.assert(!(b & -2049), "Unsupported template flags.");
                var Y = void 0;
                if (u !== void 0 && u !== o && (Y = J(i, u), typeof Y == "object"))
                  return e.Debug.fail("Invalid raw text");
                if (o === void 0) {
                  if (Y === void 0)
                    return e.Debug.fail("Arguments 'text' and 'rawText' may not both be undefined.");
                  o = Y;
                } else
                  Y !== void 0 && e.Debug.assert(o === Y, "Expected argument 'text' to be the normalized (i.e. 'cooked') version of argument 'rawText'.");
                return vo(i, o, u, b);
              }
              function vo(i, o, u, b) {
                var Y = nt(i);
                return Y.text = o, Y.rawText = u, Y.templateFlags = b & 2048, Y.transformFlags |= 1024, Y.templateFlags && (Y.transformFlags |= 128), Y;
              }
              function Is(i, o, u) {
                return ma(15, i, o, u);
              }
              function wa(i, o, u) {
                return ma(16, i, o, u);
              }
              function Ho(i, o, u) {
                return ma(17, i, o, u);
              }
              function Ta(i, o, u) {
                return ma(14, i, o, u);
              }
              function Ja(i, o) {
                e.Debug.assert(!i || !!o, "A `YieldExpression` with an asteriskToken must have an expression.");
                var u = hr(226);
                return u.expression = o && be().parenthesizeExpressionForDisallowedComma(o), u.asteriskToken = i, u.transformFlags |= Q(u.expression) | Q(u.asteriskToken) | 1024 | 128 | 1048576, u;
              }
              function bo(i, o, u) {
                return i.expression !== u || i.asteriskToken !== o ? j(Ja(o, u), i) : i;
              }
              function Eo(i) {
                var o = hr(227);
                return o.expression = be().parenthesizeExpressionForDisallowedComma(i), o.transformFlags |= Q(o.expression) | 1024 | 32768, o;
              }
              function to(i, o) {
                return i.expression !== o ? j(Eo(o), i) : i;
              }
              function Aa(i, o, u, b, Y) {
                var Ke = ir(228, i, o, u, b, Y);
                return Ke.transformFlags |= 1024, Ke;
              }
              function To(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.name !== u || i.typeParameters !== b || i.heritageClauses !== Y || i.members !== Ke ? j(Aa(o, u, b, Y, Ke), i) : i;
              }
              function Os() {
                return hr(229);
              }
              function So(i, o) {
                var u = he(230);
                return u.expression = be().parenthesizeLeftSideOfAccess(i, false), u.typeArguments = o && be().parenthesizeTypeArguments(o), u.transformFlags |= Q(u.expression) | Be(u.typeArguments) | 1024, u;
              }
              function Co(i, o, u) {
                return i.expression !== o || i.typeArguments !== u ? j(So(o, u), i) : i;
              }
              function ka(i, o) {
                var u = hr(231);
                return u.expression = i, u.type = o, u.transformFlags |= Q(u.expression) | Q(u.type) | 1, u;
              }
              function no(i, o, u) {
                return i.expression !== o || i.type !== u ? j(ka(o, u), i) : i;
              }
              function Go(i) {
                var o = hr(232);
                return o.expression = be().parenthesizeLeftSideOfAccess(i, false), o.transformFlags |= Q(o.expression) | 1, o;
              }
              function Ii(i, o) {
                return e.isNonNullChain(i) ? xo(i, o) : i.expression !== o ? j(Go(o), i) : i;
              }
              function Fa(i, o) {
                var u = hr(235);
                return u.expression = i, u.type = o, u.transformFlags |= Q(u.expression) | Q(u.type) | 1, u;
              }
              function io(i, o, u) {
                return i.expression !== o || i.type !== u ? j(Fa(o, u), i) : i;
              }
              function Do(i) {
                var o = hr(232);
                return o.flags |= 32, o.expression = be().parenthesizeLeftSideOfAccess(i, true), o.transformFlags |= Q(o.expression) | 1, o;
              }
              function xo(i, o) {
                return e.Debug.assert(!!(i.flags & 32), "Cannot update a NonNullExpression using updateNonNullChain. Use updateNonNullExpression instead."), i.expression !== o ? j(Do(o), i) : i;
              }
              function Xo(i, o) {
                var u = hr(233);
                switch (u.keywordToken = i, u.name = o, u.transformFlags |= Q(u.name), i) {
                  case 103:
                    u.transformFlags |= 1024;
                    break;
                  case 100:
                    u.transformFlags |= 4;
                    break;
                  default:
                    return e.Debug.assertNever(i);
                }
                return u;
              }
              function $o(i, o) {
                return i.name !== o ? j(Xo(i.keywordToken, o), i) : i;
              }
              function zi(i, o) {
                var u = he(236);
                return u.expression = i, u.literal = o, u.transformFlags |= Q(u.expression) | Q(u.literal) | 1024, u;
              }
              function Ms(i, o, u) {
                return i.expression !== o || i.literal !== u ? j(zi(o, u), i) : i;
              }
              function wo() {
                var i = he(237);
                return i.transformFlags |= 1024, i;
              }
              function l(i, o) {
                var u = he(238);
                return u.statements = we(i), u.multiLine = o, u.transformFlags |= Be(u.statements), u;
              }
              function A(i, o) {
                return i.statements !== o ? j(l(o, i.multiLine), i) : i;
              }
              function M(i, o) {
                var u = yr(240);
                return u.modifiers = Xn(i), u.declarationList = e.isArray(o) ? Io(o) : o, u.transformFlags |= Be(u.modifiers) | Q(u.declarationList), e.modifiersToFlags(u.modifiers) & 2 && (u.transformFlags = 1), u;
              }
              function ke(i, o, u) {
                return i.modifiers !== o || i.declarationList !== u ? j(M(o, u), i) : i;
              }
              function cr() {
                return he(239);
              }
              function Zr(i) {
                var o = he(241);
                return o.expression = be().parenthesizeExpressionOfExpressionStatement(i), o.transformFlags |= Q(o.expression), o;
              }
              function _t(i, o) {
                return i.expression !== o ? j(Zr(o), i) : i;
              }
              function Rt(i, o, u) {
                var b = he(242);
                return b.expression = i, b.thenStatement = ii(o), b.elseStatement = ii(u), b.transformFlags |= Q(b.expression) | Q(b.thenStatement) | Q(b.elseStatement), b;
              }
              function un(i, o, u, b) {
                return i.expression !== o || i.thenStatement !== u || i.elseStatement !== b ? j(Rt(o, u, b), i) : i;
              }
              function bn(i, o) {
                var u = he(243);
                return u.statement = ii(i), u.expression = o, u.transformFlags |= Q(u.statement) | Q(u.expression), u;
              }
              function _n(i, o, u) {
                return i.statement !== o || i.expression !== u ? j(bn(o, u), i) : i;
              }
              function Nt(i, o) {
                var u = he(244);
                return u.expression = i, u.statement = ii(o), u.transformFlags |= Q(u.expression) | Q(u.statement), u;
              }
              function Ft(i, o, u) {
                return i.expression !== o || i.statement !== u ? j(Nt(o, u), i) : i;
              }
              function Sn(i, o, u, b) {
                var Y = he(245);
                return Y.initializer = i, Y.condition = o, Y.incrementor = u, Y.statement = ii(b), Y.transformFlags |= Q(Y.initializer) | Q(Y.condition) | Q(Y.incrementor) | Q(Y.statement), Y;
              }
              function wn(i, o, u, b, Y) {
                return i.initializer !== o || i.condition !== u || i.incrementor !== b || i.statement !== Y ? j(Sn(o, u, b, Y), i) : i;
              }
              function Wn(i, o, u) {
                var b = he(246);
                return b.initializer = i, b.expression = o, b.statement = ii(u), b.transformFlags |= Q(b.initializer) | Q(b.expression) | Q(b.statement), b;
              }
              function Ji(i, o, u, b) {
                return i.initializer !== o || i.expression !== u || i.statement !== b ? j(Wn(o, u, b), i) : i;
              }
              function Ba(i, o, u, b) {
                var Y = he(247);
                return Y.awaitModifier = i, Y.initializer = o, Y.expression = be().parenthesizeExpressionForDisallowedComma(u), Y.statement = ii(b), Y.transformFlags |= Q(Y.awaitModifier) | Q(Y.initializer) | Q(Y.expression) | Q(Y.statement) | 1024, i && (Y.transformFlags |= 128), Y;
              }
              function Ao(i, o, u, b, Y) {
                return i.awaitModifier !== o || i.initializer !== u || i.expression !== b || i.statement !== Y ? j(Ba(o, u, b, Y), i) : i;
              }
              function ko(i) {
                var o = he(248);
                return o.label = ki(i), o.transformFlags |= Q(o.label) | 4194304, o;
              }
              function Po(i, o) {
                return i.label !== o ? j(ko(o), i) : i;
              }
              function ao(i) {
                var o = he(249);
                return o.label = ki(i), o.transformFlags |= Q(o.label) | 4194304, o;
              }
              function Vc(i, o) {
                return i.label !== o ? j(ao(o), i) : i;
              }
              function Ls(i) {
                var o = he(250);
                return o.expression = i, o.transformFlags |= Q(o.expression) | 128 | 4194304, o;
              }
              function No(i, o) {
                return i.expression !== o ? j(Ls(o), i) : i;
              }
              function Rs(i, o) {
                var u = he(251);
                return u.expression = i, u.statement = ii(o), u.transformFlags |= Q(u.expression) | Q(u.statement), u;
              }
              function Qo(i, o, u) {
                return i.expression !== o || i.statement !== u ? j(Rs(o, u), i) : i;
              }
              function Yo(i, o) {
                var u = he(252);
                return u.expression = be().parenthesizeExpressionForDisallowedComma(i), u.caseBlock = o, u.transformFlags |= Q(u.expression) | Q(u.caseBlock), u;
              }
              function w_(i, o, u) {
                return i.expression !== o || i.caseBlock !== u ? j(Yo(o, u), i) : i;
              }
              function js(i, o) {
                var u = he(253);
                return u.label = ki(i), u.statement = ii(o), u.transformFlags |= Q(u.label) | Q(u.statement), u;
              }
              function Js(i, o, u) {
                return i.label !== o || i.statement !== u ? j(js(o, u), i) : i;
              }
              function Fs(i) {
                var o = he(254);
                return o.expression = i, o.transformFlags |= Q(o.expression), o;
              }
              function oo(i, o) {
                return i.expression !== o ? j(Fs(o), i) : i;
              }
              function A_(i, o, u) {
                var b = he(255);
                return b.tryBlock = i, b.catchClause = o, b.finallyBlock = u, b.transformFlags |= Q(b.tryBlock) | Q(b.catchClause) | Q(b.finallyBlock), b;
              }
              function Wc(i, o, u, b) {
                return i.tryBlock !== o || i.catchClause !== u || i.finallyBlock !== b ? j(A_(o, u, b), i) : i;
              }
              function Kc() {
                return he(256);
              }
              function Bs(i, o, u, b) {
                var Y = Pr(257, void 0, i, u, b && be().parenthesizeExpressionForDisallowedComma(b));
                return Y.exclamationToken = o, Y.transformFlags |= Q(Y.exclamationToken), o && (Y.transformFlags |= 1), Y;
              }
              function Pa(i, o, u, b, Y) {
                return i.name !== o || i.type !== b || i.exclamationToken !== u || i.initializer !== Y ? j(Bs(o, u, b, Y), i) : i;
              }
              function Io(i, o) {
                o === void 0 && (o = 0);
                var u = he(258);
                return u.flags |= o & 3, u.declarations = we(i), u.transformFlags |= Be(u.declarations) | 4194304, o & 3 && (u.transformFlags |= 263168), u;
              }
              function qs(i, o) {
                return i.declarations !== o ? j(Io(o, i.flags), i) : i;
              }
              function Oo(i, o, u, b, Y, Ke, Or) {
                var kt = zr(259, i, u, b, Y, Ke, Or);
                return kt.asteriskToken = o, !kt.body || e.modifiersToFlags(kt.modifiers) & 2 ? kt.transformFlags = 1 : (kt.transformFlags |= Q(kt.asteriskToken) | 4194304, e.modifiersToFlags(kt.modifiers) & 512 ? kt.asteriskToken ? kt.transformFlags |= 128 : kt.transformFlags |= 256 : kt.asteriskToken && (kt.transformFlags |= 2048)), kt.illegalDecorators = void 0, kt;
              }
              function so(i, o, u, b, Y, Ke, Or, kt) {
                return i.modifiers !== o || i.asteriskToken !== u || i.name !== b || i.typeParameters !== Y || i.parameters !== Ke || i.type !== Or || i.body !== kt ? Us(Oo(o, u, b, Y, Ke, Or, kt), i) : i;
              }
              function Us(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), Lr(i, o);
              }
              function Zo(i, o, u, b, Y) {
                var Ke = ir(260, i, o, u, b, Y);
                return e.modifiersToFlags(Ke.modifiers) & 2 ? Ke.transformFlags = 1 : (Ke.transformFlags |= 1024, Ke.transformFlags & 8192 && (Ke.transformFlags |= 1)), Ke;
              }
              function k_(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.name !== u || i.typeParameters !== b || i.heritageClauses !== Y || i.members !== Ke ? j(Zo(o, u, b, Y, Ke), i) : i;
              }
              function zs(i, o, u, b, Y) {
                var Ke = ye(261, i, o, u, b);
                return Ke.members = we(Y), Ke.transformFlags = 1, Ke.illegalDecorators = void 0, Ke;
              }
              function P_(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.name !== u || i.typeParameters !== b || i.heritageClauses !== Y || i.members !== Ke ? Hc(zs(o, u, b, Y, Ke), i) : i;
              }
              function Hc(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function Vs(i, o, u, b) {
                var Y = nr(262, i, o, u);
                return Y.type = b, Y.transformFlags = 1, Y.illegalDecorators = void 0, Y;
              }
              function N_(i, o, u, b, Y) {
                return i.modifiers !== o || i.name !== u || i.typeParameters !== b || i.type !== Y ? Gc(Vs(o, u, b, Y), i) : i;
              }
              function Gc(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function Un(i, o, u) {
                var b = kr(263, i, o);
                return b.members = we(u), b.transformFlags |= Be(b.members) | 1, b.transformFlags &= -67108865, b.illegalDecorators = void 0, b;
              }
              function ua(i, o, u, b) {
                return i.modifiers !== o || i.name !== u || i.members !== b ? I_(Un(o, u, b), i) : i;
              }
              function I_(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function Sa(i, o, u, b) {
                b === void 0 && (b = 0);
                var Y = yr(264);
                return Y.modifiers = Xn(i), Y.flags |= b & 1044, Y.name = o, Y.body = u, e.modifiersToFlags(Y.modifiers) & 2 ? Y.transformFlags = 1 : Y.transformFlags |= Be(Y.modifiers) | Q(Y.name) | Q(Y.body) | 1, Y.transformFlags &= -67108865, Y.illegalDecorators = void 0, Y;
              }
              function O_(i, o, u, b) {
                return i.modifiers !== o || i.name !== u || i.body !== b ? pi(Sa(o, u, b, i.flags), i) : i;
              }
              function pi(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function Na(i) {
                var o = he(265);
                return o.statements = we(i), o.transformFlags |= Be(o.statements), o;
              }
              function wi(i, o) {
                return i.statements !== o ? j(Na(o), i) : i;
              }
              function M_(i) {
                var o = he(266);
                return o.clauses = we(i), o.transformFlags |= Be(o.clauses), o;
              }
              function Ws(i, o) {
                return i.clauses !== o ? j(M_(o), i) : i;
              }
              function L_(i) {
                var o = kr(267, void 0, i);
                return o.transformFlags = 1, o.illegalDecorators = void 0, o.modifiers = void 0, o;
              }
              function Ks(i, o) {
                return i.name !== o ? R_(L_(o), i) : i;
              }
              function R_(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators, i.modifiers = o.modifiers), j(i, o);
              }
              function j_(i, o, u, b) {
                var Y = kr(268, i, u);
                return Y.isTypeOnly = o, Y.moduleReference = b, Y.transformFlags |= Q(Y.moduleReference), e.isExternalModuleReference(Y.moduleReference) || (Y.transformFlags |= 1), Y.transformFlags &= -67108865, Y.illegalDecorators = void 0, Y;
              }
              function J_(i, o, u, b, Y) {
                return i.modifiers !== o || i.isTypeOnly !== u || i.name !== b || i.moduleReference !== Y ? Xc(j_(o, u, b, Y), i) : i;
              }
              function Xc(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function F_(i, o, u, b) {
                var Y = yr(269);
                return Y.modifiers = Xn(i), Y.importClause = o, Y.moduleSpecifier = u, Y.assertClause = b, Y.transformFlags |= Q(Y.importClause) | Q(Y.moduleSpecifier), Y.transformFlags &= -67108865, Y.illegalDecorators = void 0, Y;
              }
              function B_(i, o, u, b, Y) {
                return i.modifiers !== o || i.importClause !== u || i.moduleSpecifier !== b || i.assertClause !== Y ? q_(F_(o, u, b, Y), i) : i;
              }
              function q_(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function Hs(i, o, u) {
                var b = he(270);
                return b.isTypeOnly = i, b.name = o, b.namedBindings = u, b.transformFlags |= Q(b.name) | Q(b.namedBindings), i && (b.transformFlags |= 1), b.transformFlags &= -67108865, b;
              }
              function $c(i, o, u, b) {
                return i.isTypeOnly !== o || i.name !== u || i.namedBindings !== b ? j(Hs(o, u, b), i) : i;
              }
              function Mo(i, o) {
                var u = he(296);
                return u.elements = we(i), u.multiLine = o, u.transformFlags |= 4, u;
              }
              function Gs(i, o, u) {
                return i.elements !== o || i.multiLine !== u ? j(Mo(o, u), i) : i;
              }
              function Xs(i, o) {
                var u = he(297);
                return u.name = i, u.value = o, u.transformFlags |= 4, u;
              }
              function Lo(i, o, u) {
                return i.name !== o || i.value !== u ? j(Xs(o, u), i) : i;
              }
              function $s(i, o) {
                var u = he(298);
                return u.assertClause = i, u.multiLine = o, u;
              }
              function _o(i, o, u) {
                return i.assertClause !== o || i.multiLine !== u ? j($s(o, u), i) : i;
              }
              function U_(i) {
                var o = he(271);
                return o.name = i, o.transformFlags |= Q(o.name), o.transformFlags &= -67108865, o;
              }
              function z_(i, o) {
                return i.name !== o ? j(U_(o), i) : i;
              }
              function V_(i) {
                var o = he(277);
                return o.name = i, o.transformFlags |= Q(o.name) | 4, o.transformFlags &= -67108865, o;
              }
              function Qc(i, o) {
                return i.name !== o ? j(V_(o), i) : i;
              }
              function W_(i) {
                var o = he(272);
                return o.elements = we(i), o.transformFlags |= Be(o.elements), o.transformFlags &= -67108865, o;
              }
              function K_(i, o) {
                return i.elements !== o ? j(W_(o), i) : i;
              }
              function H_(i, o, u) {
                var b = he(273);
                return b.isTypeOnly = i, b.propertyName = o, b.name = u, b.transformFlags |= Q(b.propertyName) | Q(b.name), b.transformFlags &= -67108865, b;
              }
              function G_(i, o, u, b) {
                return i.isTypeOnly !== o || i.propertyName !== u || i.name !== b ? j(H_(o, u, b), i) : i;
              }
              function Ca(i, o, u) {
                var b = yr(274);
                return b.modifiers = Xn(i), b.isExportEquals = o, b.expression = o ? be().parenthesizeRightSideOfBinary(63, void 0, u) : be().parenthesizeExpressionOfExportDefault(u), b.transformFlags |= Be(b.modifiers) | Q(b.expression), b.transformFlags &= -67108865, b.illegalDecorators = void 0, b;
              }
              function qa(i, o, u) {
                return i.modifiers !== o || i.expression !== u ? es(Ca(o, i.isExportEquals, u), i) : i;
              }
              function es(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function ta(i, o, u, b, Y) {
                var Ke = yr(275);
                return Ke.modifiers = Xn(i), Ke.isTypeOnly = o, Ke.exportClause = u, Ke.moduleSpecifier = b, Ke.assertClause = Y, Ke.transformFlags |= Be(Ke.modifiers) | Q(Ke.exportClause) | Q(Ke.moduleSpecifier), Ke.transformFlags &= -67108865, Ke.illegalDecorators = void 0, Ke;
              }
              function Qs(i, o, u, b, Y, Ke) {
                return i.modifiers !== o || i.isTypeOnly !== u || i.exportClause !== b || i.moduleSpecifier !== Y || i.assertClause !== Ke ? Yc(ta(o, u, b, Y, Ke), i) : i;
              }
              function Yc(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators), j(i, o);
              }
              function co(i) {
                var o = he(276);
                return o.elements = we(i), o.transformFlags |= Be(o.elements), o.transformFlags &= -67108865, o;
              }
              function X_(i, o) {
                return i.elements !== o ? j(co(o), i) : i;
              }
              function Ys(i, o, u) {
                var b = he(278);
                return b.isTypeOnly = i, b.propertyName = ki(o), b.name = ki(u), b.transformFlags |= Q(b.propertyName) | Q(b.name), b.transformFlags &= -67108865, b;
              }
              function Zs(i, o, u, b) {
                return i.isTypeOnly !== o || i.propertyName !== u || i.name !== b ? j(Ys(o, u, b), i) : i;
              }
              function $_() {
                var i = yr(279);
                return i;
              }
              function Q_(i) {
                var o = he(280);
                return o.expression = i, o.transformFlags |= Q(o.expression), o.transformFlags &= -67108865, o;
              }
              function rs(i, o) {
                return i.expression !== o ? j(Q_(o), i) : i;
              }
              function Y_(i) {
                return he(i);
              }
              function Z_(i, o, u) {
                u === void 0 && (u = false);
                var b = ts(i, u ? o && be().parenthesizeNonArrayTypeOfPostfixType(o) : o);
                return b.postfix = u, b;
              }
              function ts(i, o) {
                var u = he(i);
                return u.type = o, u;
              }
              function ec(i, o, u) {
                return o.type !== u ? j(Z_(i, u, o.postfix), o) : o;
              }
              function Zc(i, o, u) {
                return o.type !== u ? j(ts(i, u), o) : o;
              }
              function e_(i, o) {
                var u = tr(320, void 0, void 0, void 0, i, o);
                return u;
              }
              function eu(i, o, u) {
                return i.parameters !== o || i.type !== u ? j(e_(o, u), i) : i;
              }
              function rc(i, o) {
                o === void 0 && (o = false);
                var u = he(325);
                return u.jsDocPropertyTags = Xn(i), u.isArrayType = o, u;
              }
              function r_(i, o, u) {
                return i.jsDocPropertyTags !== o || i.isArrayType !== u ? j(rc(o, u), i) : i;
              }
              function Ro(i) {
                var o = he(312);
                return o.type = i, o;
              }
              function t_(i, o) {
                return i.type !== o ? j(Ro(o), i) : i;
              }
              function tc(i, o, u) {
                var b = he(326);
                return b.typeParameters = Xn(i), b.parameters = we(o), b.type = u, b;
              }
              function jo(i, o, u, b) {
                return i.typeParameters !== o || i.parameters !== u || i.type !== b ? j(tc(o, u, b), i) : i;
              }
              function na(i) {
                var o = fe(i.kind);
                return i.tagName.escapedText === e.escapeLeadingUnderscores(o) ? i.tagName : pt(o);
              }
              function Qi(i, o, u) {
                var b = he(i);
                return b.tagName = o, b.comment = u, b;
              }
              function la(i, o, u, b) {
                var Y = Qi(347, i != null ? i : pt("template"), b);
                return Y.constraint = o, Y.typeParameters = we(u), Y;
              }
              function n_(i, o, u, b, Y) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.constraint !== u || i.typeParameters !== b || i.comment !== Y ? j(la(o, u, b, Y), i) : i;
              }
              function uo(i, o, u, b) {
                var Y = Qi(348, i != null ? i : pt("typedef"), b);
                return Y.typeExpression = o, Y.fullName = u, Y.name = e.getJSDocTypeAliasName(u), Y;
              }
              function ru(i, o, u, b, Y) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.typeExpression !== u || i.fullName !== b || i.comment !== Y ? j(uo(o, u, b, Y), i) : i;
              }
              function i_(i, o, u, b, Y, Ke) {
                var Or = Qi(343, i != null ? i : pt("param"), Ke);
                return Or.typeExpression = b, Or.name = o, Or.isNameFirst = !!Y, Or.isBracketed = u, Or;
              }
              function ns(i, o, u, b, Y, Ke, Or) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.name !== u || i.isBracketed !== b || i.typeExpression !== Y || i.isNameFirst !== Ke || i.comment !== Or ? j(i_(o, u, b, Y, Ke, Or), i) : i;
              }
              function is(i, o, u, b, Y, Ke) {
                var Or = Qi(350, i != null ? i : pt("prop"), Ke);
                return Or.typeExpression = b, Or.name = o, Or.isNameFirst = !!Y, Or.isBracketed = u, Or;
              }
              function nc(i, o, u, b, Y, Ke, Or) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.name !== u || i.isBracketed !== b || i.typeExpression !== Y || i.isNameFirst !== Ke || i.comment !== Or ? j(is(o, u, b, Y, Ke, Or), i) : i;
              }
              function a_(i, o, u, b) {
                var Y = Qi(341, i != null ? i : pt("callback"), b);
                return Y.typeExpression = o, Y.fullName = u, Y.name = e.getJSDocTypeAliasName(u), Y;
              }
              function ic(i, o, u, b, Y) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.typeExpression !== u || i.fullName !== b || i.comment !== Y ? j(a_(o, u, b, Y), i) : i;
              }
              function as(i, o, u) {
                var b = Qi(331, i != null ? i : pt("augments"), u);
                return b.class = o, b;
              }
              function o_(i, o, u, b) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.class !== u || i.comment !== b ? j(as(o, u, b), i) : i;
              }
              function s_(i, o, u) {
                var b = Qi(332, i != null ? i : pt("implements"), u);
                return b.class = o, b;
              }
              function lo(i, o, u) {
                var b = Qi(349, i != null ? i : pt("see"), u);
                return b.name = o, b;
              }
              function tu(i, o, u, b) {
                return i.tagName !== o || i.name !== u || i.comment !== b ? j(lo(o, u, b), i) : i;
              }
              function Ua(i) {
                var o = he(313);
                return o.name = i, o;
              }
              function Jo(i, o) {
                return i.name !== o ? j(Ua(o), i) : i;
              }
              function __(i, o) {
                var u = he(314);
                return u.left = i, u.right = o, u.transformFlags |= Q(u.left) | Q(u.right), u;
              }
              function nu(i, o, u) {
                return i.left !== o || i.right !== u ? j(__(o, u), i) : i;
              }
              function c_(i, o) {
                var u = he(327);
                return u.name = i, u.text = o, u;
              }
              function iu(i, o, u) {
                return i.name !== o ? j(c_(o, u), i) : i;
              }
              function ac(i, o) {
                var u = he(328);
                return u.name = i, u.text = o, u;
              }
              function oc(i, o, u) {
                return i.name !== o ? j(ac(o, u), i) : i;
              }
              function u_(i, o) {
                var u = he(329);
                return u.name = i, u.text = o, u;
              }
              function au(i, o, u) {
                return i.name !== o ? j(u_(o, u), i) : i;
              }
              function ou(i, o, u, b) {
                return o === void 0 && (o = na(i)), i.tagName !== o || i.class !== u || i.comment !== b ? j(s_(o, u, b), i) : i;
              }
              function os(i, o, u) {
                var b = Qi(i, o != null ? o : pt(fe(i)), u);
                return b;
              }
              function ia(i, o, u, b) {
                return u === void 0 && (u = na(o)), o.tagName !== u || o.comment !== b ? j(os(i, u, b), o) : o;
              }
              function ss(i, o, u, b) {
                var Y = Qi(i, o != null ? o : pt(fe(i)), b);
                return Y.typeExpression = u, Y;
              }
              function l_(i, o, u, b, Y) {
                return u === void 0 && (u = na(o)), o.tagName !== u || o.typeExpression !== b || o.comment !== Y ? j(ss(i, u, b, Y), o) : o;
              }
              function sc(i, o) {
                var u = Qi(330, i, o);
                return u;
              }
              function su(i, o, u) {
                return i.tagName !== o || i.comment !== u ? j(sc(o, u), i) : i;
              }
              function _c(i) {
                var o = he(324);
                return o.text = i, o;
              }
              function _u(i, o) {
                return i.text !== o ? j(_c(o), i) : i;
              }
              function _s(i, o) {
                var u = he(323);
                return u.comment = i, u.tags = Xn(o), u;
              }
              function cs(i, o, u) {
                return i.comment !== o || i.tags !== u ? j(_s(o, u), i) : i;
              }
              function p_(i, o, u) {
                var b = he(281);
                return b.openingElement = i, b.children = we(o), b.closingElement = u, b.transformFlags |= Q(b.openingElement) | Be(b.children) | Q(b.closingElement) | 2, b;
              }
              function f_(i, o, u, b) {
                return i.openingElement !== o || i.children !== u || i.closingElement !== b ? j(p_(o, u, b), i) : i;
              }
              function Fo(i, o, u) {
                var b = he(282);
                return b.tagName = i, b.typeArguments = Xn(o), b.attributes = u, b.transformFlags |= Q(b.tagName) | Be(b.typeArguments) | Q(b.attributes) | 2, b.typeArguments && (b.transformFlags |= 1), b;
              }
              function d_(i, o, u, b) {
                return i.tagName !== o || i.typeArguments !== u || i.attributes !== b ? j(Fo(o, u, b), i) : i;
              }
              function Bo(i, o, u) {
                var b = he(283);
                return b.tagName = i, b.typeArguments = Xn(o), b.attributes = u, b.transformFlags |= Q(b.tagName) | Be(b.typeArguments) | Q(b.attributes) | 2, o && (b.transformFlags |= 1), b;
              }
              function us(i, o, u, b) {
                return i.tagName !== o || i.typeArguments !== u || i.attributes !== b ? j(Bo(o, u, b), i) : i;
              }
              function m_(i) {
                var o = he(284);
                return o.tagName = i, o.transformFlags |= Q(o.tagName) | 2, o;
              }
              function cu(i, o) {
                return i.tagName !== o ? j(m_(o), i) : i;
              }
              function Ai(i, o, u) {
                var b = he(285);
                return b.openingFragment = i, b.children = we(o), b.closingFragment = u, b.transformFlags |= Q(b.openingFragment) | Be(b.children) | Q(b.closingFragment) | 2, b;
              }
              function g_(i, o, u, b) {
                return i.openingFragment !== o || i.children !== u || i.closingFragment !== b ? j(Ai(o, u, b), i) : i;
              }
              function po(i, o) {
                var u = he(11);
                return u.text = i, u.containsOnlyTriviaWhiteSpaces = !!o, u.transformFlags |= 2, u;
              }
              function uu(i, o, u) {
                return i.text !== o || i.containsOnlyTriviaWhiteSpaces !== u ? j(po(o, u), i) : i;
              }
              function ls() {
                var i = he(286);
                return i.transformFlags |= 2, i;
              }
              function lu() {
                var i = he(287);
                return i.transformFlags |= 2, i;
              }
              function Ia(i, o) {
                var u = he(288);
                return u.name = i, u.initializer = o, u.transformFlags |= Q(u.name) | Q(u.initializer) | 2, u;
              }
              function cc(i, o, u) {
                return i.name !== o || i.initializer !== u ? j(Ia(o, u), i) : i;
              }
              function y_(i) {
                var o = he(289);
                return o.properties = we(i), o.transformFlags |= Be(o.properties) | 2, o;
              }
              function ps(i, o) {
                return i.properties !== o ? j(y_(o), i) : i;
              }
              function uc(i) {
                var o = he(290);
                return o.expression = i, o.transformFlags |= Q(o.expression) | 2, o;
              }
              function h_(i, o) {
                return i.expression !== o ? j(uc(o), i) : i;
              }
              function Oa(i, o) {
                var u = he(291);
                return u.dotDotDotToken = i, u.expression = o, u.transformFlags |= Q(u.dotDotDotToken) | Q(u.expression) | 2, u;
              }
              function Ma(i, o) {
                return i.expression !== o ? j(Oa(i.dotDotDotToken, o), i) : i;
              }
              function fs2(i, o) {
                var u = he(292);
                return u.expression = be().parenthesizeExpressionForDisallowedComma(i), u.statements = we(o), u.transformFlags |= Q(u.expression) | Be(u.statements), u;
              }
              function ds(i, o, u) {
                return i.expression !== o || i.statements !== u ? j(fs2(o, u), i) : i;
              }
              function v_(i) {
                var o = he(293);
                return o.statements = we(i), o.transformFlags = Be(o.statements), o;
              }
              function qo(i, o) {
                return i.statements !== o ? j(v_(o), i) : i;
              }
              function za(i, o) {
                var u = he(294);
                switch (u.token = i, u.types = we(o), u.transformFlags |= Be(u.types), i) {
                  case 94:
                    u.transformFlags |= 1024;
                    break;
                  case 117:
                    u.transformFlags |= 1;
                    break;
                  default:
                    return e.Debug.assertNever(i);
                }
                return u;
              }
              function pu(i, o) {
                return i.types !== o ? j(za(i.token, o), i) : i;
              }
              function b_(i, o) {
                var u = he(295);
                return (typeof i == "string" || i && !e.isVariableDeclaration(i)) && (i = Bs(i, void 0, void 0, void 0)), u.variableDeclaration = i, u.block = o, u.transformFlags |= Q(u.variableDeclaration) | Q(u.block), i || (u.transformFlags |= 64), u;
              }
              function lc(i, o, u) {
                return i.variableDeclaration !== o || i.block !== u ? j(b_(o, u), i) : i;
              }
              function ms(i, o) {
                var u = kr(299, void 0, i);
                return u.initializer = be().parenthesizeExpressionForDisallowedComma(o), u.transformFlags |= Q(u.name) | Q(u.initializer), u.illegalDecorators = void 0, u.modifiers = void 0, u.questionToken = void 0, u.exclamationToken = void 0, u;
              }
              function pc(i, o, u) {
                return i.name !== o || i.initializer !== u ? fo(ms(o, u), i) : i;
              }
              function fo(i, o) {
                return i !== o && (i.illegalDecorators = o.illegalDecorators, i.modifiers = o.modifiers, i.questionToken = o.questionToken, i.exclamationToken = o.exclamationToken), j(i, o);
              }
              function fc(i, o) {
                var u = kr(300, void 0, i);
                return u.objectAssignmentInitializer = o && be().parenthesizeExpressionForDisallowedComma(o), u.transformFlags |= Q(u.objectAssignmentInitializer) | 1024, u.equalsToken = void 0, u.illegalDecorators = void 0, u.modifiers = void 0, u.questionToken = void 0, u.exclamationToken = void 0, u;
              }
              function fu(i, o, u) {
                return i.name !== o || i.objectAssignmentInitializer !== u ? du(fc(o, u), i) : i;
              }
              function du(i, o) {
                return i !== o && (i.equalsToken = o.equalsToken, i.illegalDecorators = o.illegalDecorators, i.modifiers = o.modifiers, i.questionToken = o.questionToken, i.exclamationToken = o.exclamationToken), j(i, o);
              }
              function ga(i) {
                var o = he(301);
                return o.expression = be().parenthesizeExpressionForDisallowedComma(i), o.transformFlags |= Q(o.expression) | 128 | 65536, o;
              }
              function dc(i, o) {
                return i.expression !== o ? j(ga(o), i) : i;
              }
              function mo(i, o) {
                var u = he(302);
                return u.name = ki(i), u.initializer = o && be().parenthesizeExpressionForDisallowedComma(o), u.transformFlags |= Q(u.name) | Q(u.initializer) | 1, u;
              }
              function mu(i, o, u) {
                return i.name !== o || i.initializer !== u ? j(mo(o, u), i) : i;
              }
              function Va(i, o, u) {
                var b = pe.createBaseSourceFileNode(308);
                return b.statements = we(i), b.endOfFileToken = o, b.flags |= u, b.fileName = "", b.text = "", b.languageVersion = 0, b.languageVariant = 0, b.scriptKind = 0, b.isDeclarationFile = false, b.hasNoDefaultLib = false, b.transformFlags |= Be(b.statements) | Q(b.endOfFileToken), b;
              }
              function Da(i, o, u, b, Y, Ke, Or) {
                var kt = i.redirectInfo ? Object.create(i.redirectInfo.redirectTarget) : pe.createBaseSourceFileNode(308);
                for (var $n in i)
                  $n === "emitNode" || e.hasProperty(kt, $n) || !e.hasProperty(i, $n) || (kt[$n] = i[$n]);
                return kt.flags |= i.flags, kt.statements = we(o), kt.endOfFileToken = i.endOfFileToken, kt.isDeclarationFile = u, kt.referencedFiles = b, kt.typeReferenceDirectives = Y, kt.hasNoDefaultLib = Ke, kt.libReferenceDirectives = Or, kt.transformFlags = Be(kt.statements) | Q(kt.endOfFileToken), kt.impliedNodeFormat = i.impliedNodeFormat, kt;
              }
              function mc(i, o, u, b, Y, Ke, Or) {
                return u === void 0 && (u = i.isDeclarationFile), b === void 0 && (b = i.referencedFiles), Y === void 0 && (Y = i.typeReferenceDirectives), Ke === void 0 && (Ke = i.hasNoDefaultLib), Or === void 0 && (Or = i.libReferenceDirectives), i.statements !== o || i.isDeclarationFile !== u || i.referencedFiles !== b || i.typeReferenceDirectives !== Y || i.hasNoDefaultLib !== Ke || i.libReferenceDirectives !== Or ? j(Da(i, o, u, b, Y, Ke, Or), i) : i;
              }
              function gc(i, o) {
                o === void 0 && (o = e.emptyArray);
                var u = he(309);
                return u.prepends = o, u.sourceFiles = i, u;
              }
              function yc(i, o, u) {
                return u === void 0 && (u = e.emptyArray), i.sourceFiles !== o || i.prepends !== u ? j(gc(o, u), i) : i;
              }
              function hc(i, o, u) {
                var b = he(310);
                return b.prologues = i, b.syntheticReferences = o, b.texts = u, b.fileName = "", b.text = "", b.referencedFiles = e.emptyArray, b.libReferenceDirectives = e.emptyArray, b.getLineAndCharacterOfPosition = function(Y) {
                  return e.getLineAndCharacterOfPosition(b, Y);
                }, b;
              }
              function gs(i, o) {
                var u = he(i);
                return u.data = o, u;
              }
              function ys(i) {
                return gs(303, i);
              }
              function gu(i, o) {
                var u = gs(304, i);
                return u.texts = o, u;
              }
              function hs(i, o) {
                return gs(o ? 306 : 305, i);
              }
              function vc(i) {
                var o = he(307);
                return o.data = i.data, o.section = i, o;
              }
              function yu() {
                var i = he(311);
                return i.javascriptText = "", i.declarationText = "", i;
              }
              function vs(i, o, u) {
                o === void 0 && (o = false);
                var b = he(234);
                return b.type = i, b.isSpread = o, b.tupleNameSource = u, b;
              }
              function bc(i) {
                var o = he(351);
                return o._children = i, o;
              }
              function hu(i) {
                var o = he(352);
                return o.original = i, e.setTextRange(o, i), o;
              }
              function Ec(i, o) {
                var u = he(353);
                return u.expression = i, u.original = o, u.transformFlags |= Q(u.expression) | 1, e.setTextRange(u, o), u;
              }
              function Tc(i, o) {
                return i.expression !== o ? j(Ec(o, i.original), i) : i;
              }
              function Sc(i) {
                if (e.nodeIsSynthesized(i) && !e.isParseTreeNode(i) && !i.original && !i.emitNode && !i.id) {
                  if (e.isCommaListExpression(i))
                    return i.elements;
                  if (e.isBinaryExpression(i) && e.isCommaToken(i.operatorToken))
                    return [i.left, i.right];
                }
                return i;
              }
              function E_(i) {
                var o = he(354);
                return o.elements = we(e.sameFlatMap(i, Sc)), o.transformFlags |= Be(o.elements), o;
              }
              function Cc(i, o) {
                return i.elements !== o ? j(E_(o), i) : i;
              }
              function Dc(i) {
                var o = he(356);
                return o.emitNode = {}, o.original = i, o;
              }
              function xc(i) {
                var o = he(355);
                return o.emitNode = {}, o.original = i, o;
              }
              function Wa(i, o) {
                var u = he(357);
                return u.expression = i, u.thisArg = o, u.transformFlags |= Q(u.expression) | Q(u.thisArg), u;
              }
              function go(i, o, u) {
                return i.expression !== o || i.thisArg !== u ? j(Wa(o, u), i) : i;
              }
              function bs(i) {
                if (i === void 0)
                  return i;
                var o = e.isSourceFile(i) ? pe.createBaseSourceFileNode(308) : e.isIdentifier(i) ? pe.createBaseIdentifierNode(79) : e.isPrivateIdentifier(i) ? pe.createBasePrivateIdentifierNode(80) : e.isNodeKind(i.kind) ? pe.createBaseNode(i.kind) : pe.createBaseTokenNode(i.kind);
                o.flags |= i.flags & -9, o.transformFlags = i.transformFlags, qe(o, i);
                for (var u in i)
                  e.hasProperty(o, u) || !e.hasProperty(i, u) || (o[u] = i[u]);
                return o;
              }
              function wc(i, o, u) {
                return qi(or(void 0, void 0, void 0, void 0, o ? [o] : [], void 0, l(i, true)), void 0, u ? [u] : []);
              }
              function vu(i, o, u) {
                return qi(vt(void 0, void 0, o ? [o] : [], void 0, void 0, l(i, true)), void 0, u ? [u] : []);
              }
              function Es() {
                return y(ut("0"));
              }
              function bu(i) {
                return Ca(void 0, false, i);
              }
              function Eu(i) {
                return ta(void 0, false, co([Ys(false, void 0, i)]));
              }
              function T_(i, o) {
                return o === "undefined" ? Te.createStrictEquality(i, Es()) : Te.createStrictEquality(Mt(i), f(o));
              }
              function Ka(i, o, u) {
                return e.isCallChain(i) ? Gi(Pi(i, void 0, o), void 0, void 0, u) : qi(Ht(i, o), void 0, u);
              }
              function Ac(i, o, u) {
                return Ka(i, "bind", D([o], u, true));
              }
              function Tu(i, o, u) {
                return Ka(i, "call", D([o], u, true));
              }
              function Su(i, o, u) {
                return Ka(i, "apply", [o, u]);
              }
              function Ts(i, o, u) {
                return Ka(pt(i), o, u);
              }
              function Cu(i, o) {
                return Ka(i, "slice", o === void 0 ? [] : [aa(o)]);
              }
              function Ss(i, o) {
                return Ka(i, "concat", o);
              }
              function kc(i, o, u) {
                return Ts("Object", "defineProperty", [i, aa(o), u]);
              }
              function La(i, o, u) {
                return Ts("Reflect", "get", u ? [i, o, u] : [i, o]);
              }
              function Du(i, o, u, b) {
                return Ts("Reflect", "set", b ? [i, o, u, b] : [i, o, u]);
              }
              function Ha(i, o, u) {
                return u ? (i.push(ms(o, u)), true) : false;
              }
              function Pc(i, o) {
                var u = [];
                Ha(u, "enumerable", aa(i.enumerable)), Ha(u, "configurable", aa(i.configurable));
                var b = Ha(u, "writable", aa(i.writable));
                b = Ha(u, "value", i.value) || b;
                var Y = Ha(u, "get", i.get);
                return Y = Ha(u, "set", i.set) || Y, e.Debug.assert(!(b && Y), "A PropertyDescriptor may not be both an accessor descriptor and a data descriptor."), Ut(u, !o);
              }
              function Nc(i, o) {
                switch (i.kind) {
                  case 214:
                    return Ne(i, o);
                  case 213:
                    return p(i, i.type, o);
                  case 231:
                    return no(i, o, i.type);
                  case 235:
                    return io(i, o, i.type);
                  case 232:
                    return Ii(i, o);
                  case 353:
                    return Tc(i, o);
                }
              }
              function xu(i) {
                return e.isParenthesizedExpression(i) && e.nodeIsSynthesized(i) && e.nodeIsSynthesized(e.getSourceMapRange(i)) && e.nodeIsSynthesized(e.getCommentRange(i)) && !e.some(e.getSyntheticLeadingComments(i)) && !e.some(e.getSyntheticTrailingComments(i));
              }
              function Ic(i, o, u) {
                return u === void 0 && (u = 15), i && e.isOuterExpression(i, u) && !xu(i) ? Nc(i, Ic(i.expression, o)) : o;
              }
              function Cs(i, o, u) {
                if (!o)
                  return i;
                var b = Js(o, o.label, e.isLabeledStatement(o.statement) ? Cs(i, o.statement) : i);
                return u && u(o), b;
              }
              function S_(i, o) {
                var u = e.skipParentheses(i);
                switch (u.kind) {
                  case 79:
                    return o;
                  case 108:
                  case 8:
                  case 9:
                  case 10:
                    return false;
                  case 206:
                    var b = u.elements;
                    return b.length !== 0;
                  case 207:
                    return u.properties.length > 0;
                  default:
                    return true;
                }
              }
              function Oc(i, o, u, b) {
                b === void 0 && (b = false);
                var Y = e.skipOuterExpressions(i, 15), Ke, Or;
                return e.isSuperProperty(Y) ? (Ke = ot(), Or = Y) : e.isSuperKeyword(Y) ? (Ke = ot(), Or = u !== void 0 && u < 2 ? e.setTextRange(pt("_super"), Y) : Y) : e.getEmitFlags(Y) & 4096 ? (Ke = Es(), Or = be().parenthesizeLeftSideOfAccess(Y, false)) : e.isPropertyAccessExpression(Y) ? S_(Y.expression, b) ? (Ke = K(o), Or = Ht(e.setTextRange(Te.createAssignment(Ke, Y.expression), Y.expression), Y.name), e.setTextRange(Or, Y)) : (Ke = Y.expression, Or = Y) : e.isElementAccessExpression(Y) ? S_(Y.expression, b) ? (Ke = K(o), Or = Bi(e.setTextRange(Te.createAssignment(Ke, Y.expression), Y.expression), Y.argumentExpression), e.setTextRange(Or, Y)) : (Ke = Y.expression, Or = Y) : (Ke = Es(), Or = be().parenthesizeLeftSideOfAccess(i, false)), { target: Or, thisArg: Ke };
              }
              function d(i, o) {
                return Ht(ne(Ut([Yn(void 0, "value", [mt(void 0, void 0, i, void 0, void 0, void 0)], l([Zr(o)]))])), "value");
              }
              function P(i) {
                return i.length > 10 ? E_(i) : e.reduceLeft(i, Te.createComma);
              }
              function $2(i, o, u, b) {
                b === void 0 && (b = 0);
                var Y = e.getNameOfDeclaration(i);
                if (Y && e.isIdentifier(Y) && !e.isGeneratedIdentifier(Y)) {
                  var Ke = e.setParent(e.setTextRange(bs(Y), Y), Y.parent);
                  return b |= e.getEmitFlags(Y), u || (b |= 48), o || (b |= 1536), b && e.setEmitFlags(Ke, b), Ke;
                }
                return ft(i);
              }
              function ce(i, o, u) {
                return $2(i, o, u, 49152);
              }
              function Pe(i, o, u) {
                return $2(i, o, u, 16384);
              }
              function We(i, o, u) {
                return $2(i, o, u, 8192);
              }
              function Er(i, o, u) {
                return $2(i, o, u);
              }
              function Rr(i, o, u, b) {
                var Y = Ht(i, e.nodeIsSynthesized(o) ? o : bs(o));
                e.setTextRange(Y, o);
                var Ke = 0;
                return b || (Ke |= 48), u || (Ke |= 1536), Ke && e.setEmitFlags(Y, Ke), Y;
              }
              function Fr(i, o, u, b) {
                return i && e.hasSyntacticModifier(o, 1) ? Rr(i, $2(o), u, b) : We(o, u, b);
              }
              function et(i, o, u, b) {
                var Y = Wt(i, o, 0, u);
                return pn(i, o, Y, b);
              }
              function wt(i) {
                return e.isStringLiteral(i.expression) && i.expression.text === "use strict";
              }
              function Gt() {
                return e.startOnNewLine(Zr(f("use strict")));
              }
              function Wt(i, o, u, b) {
                u === void 0 && (u = 0), e.Debug.assert(o.length === 0, "Prologue directives should be at the first statement in the target statements array");
                for (var Y = false, Ke = i.length; u < Ke; ) {
                  var Or = i[u];
                  if (e.isPrologueDirective(Or))
                    wt(Or) && (Y = true), o.push(Or);
                  else
                    break;
                  u++;
                }
                return b && !Y && o.push(Gt()), u;
              }
              function pn(i, o, u, b, Y) {
                Y === void 0 && (Y = e.returnTrue);
                for (var Ke = i.length; u !== void 0 && u < Ke; ) {
                  var Or = i[u];
                  if (e.getEmitFlags(Or) & 1048576 && Y(Or))
                    e.append(o, b ? e.visitNode(Or, b, e.isStatement) : Or);
                  else
                    break;
                  u++;
                }
                return u;
              }
              function Pn(i) {
                var o = e.findUseStrictPrologue(i);
                return o ? i : e.setTextRange(we(D([Gt()], i, true)), i);
              }
              function _i(i) {
                return e.Debug.assert(e.every(i, e.isStatementOrBlock), "Cannot lift nodes to a Block."), e.singleOrUndefined(i) || l(i);
              }
              function Ln(i, o, u) {
                for (var b = u; b < i.length && o(i[b]); )
                  b++;
                return b;
              }
              function ya(i, o) {
                if (!e.some(o))
                  return i;
                var u = Ln(i, e.isPrologueDirective, 0), b = Ln(i, e.isHoistedFunction, u), Y = Ln(i, e.isHoistedVariableStatement, b), Ke = Ln(o, e.isPrologueDirective, 0), Or = Ln(o, e.isHoistedFunction, Ke), kt = Ln(o, e.isHoistedVariableStatement, Or), $n = Ln(o, e.isCustomPrologue, kt);
                e.Debug.assert($n === o.length, "Expected declarations to be valid standard or custom prologues");
                var pa = e.isNodeArray(i) ? i.slice() : i;
                if ($n > kt && pa.splice.apply(pa, D([Y, 0], o.slice(kt, $n), false)), kt > Or && pa.splice.apply(pa, D([b, 0], o.slice(Or, kt), false)), Or > Ke && pa.splice.apply(pa, D([u, 0], o.slice(Ke, Or), false)), Ke > 0)
                  if (u === 0)
                    pa.splice.apply(pa, D([0, 0], o.slice(0, Ke), false));
                  else {
                    for (var Uo = new e.Map(), Xa = 0; Xa < u; Xa++) {
                      var Ds = i[Xa];
                      Uo.set(Ds.expression.text, true);
                    }
                    for (var Xa = Ke - 1; Xa >= 0; Xa--) {
                      var xs = o[Xa];
                      Uo.has(xs.expression.text) || pa.unshift(xs);
                    }
                  }
                return e.isNodeArray(i) ? e.setTextRange(we(pa, i.hasTrailingComma), i) : i;
              }
              function Ci(i, o) {
                var u, b;
                return typeof o == "number" ? b = Nr(o) : b = o, e.isTypeParameterDeclaration(i) ? Zt(i, b, i.name, i.constraint, i.default) : e.isParameter(i) ? at(i, b, i.dotDotDotToken, i.name, i.questionToken, i.type, i.initializer) : e.isConstructorTypeNode(i) ? lr(i, b, i.typeParameters, i.parameters, i.type) : e.isPropertySignature(i) ? Sr(i, b, i.name, i.questionToken, i.type) : e.isPropertyDeclaration(i) ? Dt(i, b, i.name, (u = i.questionToken) !== null && u !== void 0 ? u : i.exclamationToken, i.type, i.initializer) : e.isMethodSignature(i) ? cn(i, b, i.name, i.questionToken, i.typeParameters, i.parameters, i.type) : e.isMethodDeclaration(i) ? yn(i, b, i.asteriskToken, i.name, i.questionToken, i.typeParameters, i.parameters, i.type, i.body) : e.isConstructorDeclaration(i) ? ei(i, b, i.parameters, i.body) : e.isGetAccessorDeclaration(i) ? vi(i, b, i.name, i.parameters, i.type, i.body) : e.isSetAccessorDeclaration(i) ? oi(i, b, i.name, i.parameters, i.body) : e.isIndexSignatureDeclaration(i) ? Fn(i, b, i.parameters, i.type) : e.isFunctionExpression(i) ? it2(i, b, i.asteriskToken, i.name, i.typeParameters, i.parameters, i.type, i.body) : e.isArrowFunction(i) ? Tt(i, b, i.typeParameters, i.parameters, i.type, i.equalsGreaterThanToken, i.body) : e.isClassExpression(i) ? To(i, b, i.name, i.typeParameters, i.heritageClauses, i.members) : e.isVariableStatement(i) ? ke(i, b, i.declarationList) : e.isFunctionDeclaration(i) ? so(i, b, i.asteriskToken, i.name, i.typeParameters, i.parameters, i.type, i.body) : e.isClassDeclaration(i) ? k_(i, b, i.name, i.typeParameters, i.heritageClauses, i.members) : e.isInterfaceDeclaration(i) ? P_(i, b, i.name, i.typeParameters, i.heritageClauses, i.members) : e.isTypeAliasDeclaration(i) ? N_(i, b, i.name, i.typeParameters, i.type) : e.isEnumDeclaration(i) ? ua(i, b, i.name, i.members) : e.isModuleDeclaration(i) ? O_(i, b, i.name, i.body) : e.isImportEqualsDeclaration(i) ? J_(i, b, i.isTypeOnly, i.name, i.moduleReference) : e.isImportDeclaration(i) ? B_(i, b, i.importClause, i.moduleSpecifier, i.assertClause) : e.isExportAssignment(i) ? qa(i, b, i.expression) : e.isExportDeclaration(i) ? Qs(i, b, i.isTypeOnly, i.exportClause, i.moduleSpecifier, i.assertClause) : e.Debug.assertNever(i);
              }
              function Xn(i) {
                return i ? we(i) : void 0;
              }
              function ki(i) {
                return typeof i == "string" ? pt(i) : i;
              }
              function aa(i) {
                return typeof i == "string" ? f(i) : typeof i == "number" ? ut(i) : typeof i == "boolean" ? i ? re() : de() : i;
              }
              function Ga(i) {
                return typeof i == "number" ? pr(i) : i;
              }
              function ii(i) {
                return i && e.isNotEmittedStatement(i) ? e.setTextRange(qe(cr(), i), i) : i;
              }
            }
            e.createNodeFactory = s;
            function q(H, pe) {
              return H !== pe && e.setTextRange(H, pe), H;
            }
            function F(H, pe) {
              return H !== pe && (qe(H, pe), e.setTextRange(H, pe)), H;
            }
            function fe(H) {
              switch (H) {
                case 346:
                  return "type";
                case 344:
                  return "returns";
                case 345:
                  return "this";
                case 342:
                  return "enum";
                case 333:
                  return "author";
                case 335:
                  return "class";
                case 336:
                  return "public";
                case 337:
                  return "private";
                case 338:
                  return "protected";
                case 339:
                  return "readonly";
                case 340:
                  return "override";
                case 347:
                  return "template";
                case 348:
                  return "typedef";
                case 343:
                  return "param";
                case 350:
                  return "prop";
                case 341:
                  return "callback";
                case 331:
                  return "augments";
                case 332:
                  return "implements";
                default:
                  return e.Debug.fail("Unsupported kind: ".concat(e.Debug.formatSyntaxKind(H)));
              }
            }
            var Ee, Se = {};
            function J(H, pe) {
              switch (Ee || (Ee = e.createScanner(99, false, 0)), H) {
                case 14:
                  Ee.setText("`" + pe + "`");
                  break;
                case 15:
                  Ee.setText("`" + pe + "${");
                  break;
                case 16:
                  Ee.setText("}" + pe + "${");
                  break;
                case 17:
                  Ee.setText("}" + pe + "`");
                  break;
              }
              var j = Ee.scan();
              if (j === 19 && (j = Ee.reScanTemplateToken(false)), Ee.isUnterminated())
                return Ee.setText(void 0), Se;
              var be;
              switch (j) {
                case 14:
                case 15:
                case 16:
                case 17:
                  be = Ee.getTokenValue();
                  break;
              }
              return be === void 0 || Ee.scan() !== 1 ? (Ee.setText(void 0), Se) : (Ee.setText(void 0), be);
            }
            function se(H) {
              return Q(H) & -67108865;
            }
            function Me(H, pe) {
              return pe | H.transformFlags & 134234112;
            }
            function Q(H) {
              if (!H)
                return 0;
              var pe = H.transformFlags & ~V(H.kind);
              return e.isNamedDeclaration(H) && e.isPropertyName(H.name) ? Me(H.name, pe) : pe;
            }
            function Be(H) {
              return H ? H.transformFlags : 0;
            }
            function je(H) {
              for (var pe = 0, j = 0, be = H; j < be.length; j++) {
                var Xe = be[j];
                pe |= Q(Xe);
              }
              H.transformFlags = pe;
            }
            function V(H) {
              if (H >= 179 && H <= 202)
                return -2;
              switch (H) {
                case 210:
                case 211:
                case 206:
                  return -2147450880;
                case 264:
                  return -1941676032;
                case 166:
                  return -2147483648;
                case 216:
                  return -2072174592;
                case 215:
                case 259:
                  return -1937940480;
                case 258:
                  return -2146893824;
                case 260:
                case 228:
                  return -2147344384;
                case 173:
                  return -1937948672;
                case 169:
                  return -2013249536;
                case 171:
                case 174:
                case 175:
                  return -2005057536;
                case 131:
                case 148:
                case 160:
                case 144:
                case 152:
                case 149:
                case 134:
                case 153:
                case 114:
                case 165:
                case 168:
                case 170:
                case 176:
                case 177:
                case 178:
                case 261:
                case 262:
                  return -2;
                case 207:
                  return -2147278848;
                case 295:
                  return -2147418112;
                case 203:
                case 204:
                  return -2147450880;
                case 213:
                case 235:
                case 231:
                case 353:
                case 214:
                case 106:
                  return -2147483648;
                case 208:
                case 209:
                  return -2147483648;
                default:
                  return -2147483648;
              }
            }
            e.getTransformFlagsSubtreeExclusions = V;
            var B = e.createBaseNodeFactory();
            function U(H) {
              return H.flags |= 8, H;
            }
            var m = { createBaseSourceFileNode: function(H) {
              return U(B.createBaseSourceFileNode(H));
            }, createBaseIdentifierNode: function(H) {
              return U(B.createBaseIdentifierNode(H));
            }, createBasePrivateIdentifierNode: function(H) {
              return U(B.createBasePrivateIdentifierNode(H));
            }, createBaseTokenNode: function(H) {
              return U(B.createBaseTokenNode(H));
            }, createBaseNode: function(H) {
              return U(B.createBaseNode(H));
            } };
            e.factory = s(4, m);
            function v(H, pe, j) {
              var be, Xe, Re, Fe, dr, ze, ve, er, ar, Cr;
              e.isString(H) ? (Re = "", Fe = H, dr = H.length, ze = pe, ve = j) : (e.Debug.assert(pe === "js" || pe === "dts"), Re = (pe === "js" ? H.javascriptPath : H.declarationPath) || "", ze = pe === "js" ? H.javascriptMapPath : H.declarationMapPath, er = function() {
                return pe === "js" ? H.javascriptText : H.declarationText;
              }, ar = function() {
                return pe === "js" ? H.javascriptMapText : H.declarationMapText;
              }, dr = function() {
                return er().length;
              }, H.buildInfo && H.buildInfo.bundle && (e.Debug.assert(j === void 0 || typeof j == "boolean"), be = j, Xe = pe === "js" ? H.buildInfo.bundle.js : H.buildInfo.bundle.dts, Cr = H.oldFileOfCurrentEmit));
              var Ce = Cr ? O(e.Debug.checkDefined(Xe)) : g(Xe, be, dr);
              return Ce.fileName = Re, Ce.sourceMapPath = ze, Ce.oldFileOfCurrentEmit = Cr, er && ar ? (Object.defineProperty(Ce, "text", { get: er }), Object.defineProperty(Ce, "sourceMapText", { get: ar })) : (e.Debug.assert(!Cr), Ce.text = Fe != null ? Fe : "", Ce.sourceMapText = ve), Ce;
            }
            e.createUnparsedSourceFile = v;
            function g(H, pe, j) {
              for (var be, Xe, Re, Fe, dr, ze, ve, er, ar = 0, Cr = H ? H.sections : e.emptyArray; ar < Cr.length; ar++) {
                var Ce = Cr[ar];
                switch (Ce.kind) {
                  case "prologue":
                    be = e.append(be, e.setTextRange(e.factory.createUnparsedPrologue(Ce.data), Ce));
                    break;
                  case "emitHelpers":
                    Xe = e.append(Xe, e.getAllUnscopedEmitHelpers().get(Ce.data));
                    break;
                  case "no-default-lib":
                    er = true;
                    break;
                  case "reference":
                    Re = e.append(Re, { pos: -1, end: -1, fileName: Ce.data });
                    break;
                  case "type":
                    Fe = e.append(Fe, { pos: -1, end: -1, fileName: Ce.data });
                    break;
                  case "type-import":
                    Fe = e.append(Fe, { pos: -1, end: -1, fileName: Ce.data, resolutionMode: e.ModuleKind.ESNext });
                    break;
                  case "type-require":
                    Fe = e.append(Fe, { pos: -1, end: -1, fileName: Ce.data, resolutionMode: e.ModuleKind.CommonJS });
                    break;
                  case "lib":
                    dr = e.append(dr, { pos: -1, end: -1, fileName: Ce.data });
                    break;
                  case "prepend":
                    for (var $e = void 0, gr = 0, X = Ce.texts; gr < X.length; gr++) {
                      var Te = X[gr];
                      (!pe || Te.kind !== "internal") && ($e = e.append($e, e.setTextRange(e.factory.createUnparsedTextLike(Te.data, Te.kind === "internal"), Te)));
                    }
                    ze = e.addRange(ze, $e), ve = e.append(ve, e.factory.createUnparsedPrepend(Ce.data, $e != null ? $e : e.emptyArray));
                    break;
                  case "internal":
                    if (pe) {
                      ve || (ve = []);
                      break;
                    }
                  case "text":
                    ve = e.append(ve, e.setTextRange(e.factory.createUnparsedTextLike(Ce.data, Ce.kind === "internal"), Ce));
                    break;
                  default:
                    e.Debug.assertNever(Ce);
                }
              }
              if (!ve) {
                var we = e.factory.createUnparsedTextLike(void 0, false);
                e.setTextRangePosWidth(we, 0, typeof j == "function" ? j() : j), ve = [we];
              }
              var he = e.parseNodeFactory.createUnparsedSource(be != null ? be : e.emptyArray, void 0, ve);
              return e.setEachParent(be, he), e.setEachParent(ve, he), e.setEachParent(ze, he), he.hasNoDefaultLib = er, he.helpers = Xe, he.referencedFiles = Re || e.emptyArray, he.typeReferenceDirectives = Fe, he.libReferenceDirectives = dr || e.emptyArray, he;
            }
            function O(H) {
              for (var pe, j, be = 0, Xe = H.sections; be < Xe.length; be++) {
                var Re = Xe[be];
                switch (Re.kind) {
                  case "internal":
                  case "text":
                    pe = e.append(pe, e.setTextRange(e.factory.createUnparsedTextLike(Re.data, Re.kind === "internal"), Re));
                    break;
                  case "no-default-lib":
                  case "reference":
                  case "type":
                  case "type-import":
                  case "type-require":
                  case "lib":
                    j = e.append(j, e.setTextRange(e.factory.createUnparsedSyntheticReference(Re), Re));
                    break;
                  case "prologue":
                  case "emitHelpers":
                  case "prepend":
                    break;
                  default:
                    e.Debug.assertNever(Re);
                }
              }
              var Fe = e.factory.createUnparsedSource(e.emptyArray, j, pe != null ? pe : e.emptyArray);
              return e.setEachParent(j, Fe), e.setEachParent(pe, Fe), Fe.helpers = e.map(H.sources && H.sources.helpers, function(dr) {
                return e.getAllUnscopedEmitHelpers().get(dr);
              }), Fe;
            }
            function S(H, pe, j, be, Xe, Re, Fe, dr, ze, ve, er) {
              var ar = e.parseNodeFactory.createInputFiles();
              if (e.isString(H))
                ar.javascriptText = H, ar.javascriptMapPath = j, ar.javascriptMapText = be, ar.declarationText = pe, ar.declarationMapPath = Xe, ar.declarationMapText = Re, ar.javascriptPath = Fe, ar.declarationPath = dr, ar.buildInfoPath = ze, ar.buildInfo = ve, ar.oldFileOfCurrentEmit = er;
              else {
                var Cr = new e.Map(), Ce = function(Te) {
                  if (Te !== void 0) {
                    var we = Cr.get(Te);
                    return we === void 0 && (we = H(Te), Cr.set(Te, we !== void 0 ? we : false)), we !== false ? we : void 0;
                  }
                }, $e = function(Te) {
                  var we = Ce(Te);
                  return we !== void 0 ? we : "/* Input file ".concat(Te, ` was missing */\r
`);
                }, gr, X = function(Te) {
                  var we;
                  if (gr === void 0) {
                    var he = Te();
                    gr = he !== void 0 && (we = e.getBuildInfo(ar.buildInfoPath, he)) !== null && we !== void 0 ? we : false;
                  }
                  return gr || void 0;
                };
                ar.javascriptPath = pe, ar.javascriptMapPath = j, ar.declarationPath = e.Debug.checkDefined(be), ar.declarationMapPath = Xe, ar.buildInfoPath = Re, Object.defineProperties(ar, { javascriptText: { get: function() {
                  return $e(pe);
                } }, javascriptMapText: { get: function() {
                  return Ce(j);
                } }, declarationText: { get: function() {
                  return $e(e.Debug.checkDefined(be));
                } }, declarationMapText: { get: function() {
                  return Ce(Xe);
                } }, buildInfo: { get: function() {
                  return X(function() {
                    return Ce(Re);
                  });
                } } });
              }
              return ar;
            }
            e.createInputFiles = S;
            var te;
            function Je(H, pe, j) {
              return new (te || (te = e.objectAllocator.getSourceMapSourceConstructor()))(H, pe, j);
            }
            e.createSourceMapSource = Je;
            function qe(H, pe) {
              if (H.original = pe, pe) {
                var j = pe.emitNode;
                j && (H.emitNode = ge(j, H.emitNode));
              }
              return H;
            }
            e.setOriginalNode = qe;
            function ge(H, pe) {
              var j = H.flags, be = H.leadingComments, Xe = H.trailingComments, Re = H.commentRange, Fe = H.sourceMapRange, dr = H.tokenSourceMapRanges, ze = H.constantValue, ve = H.helpers, er = H.startsOnNewLine, ar = H.snippetElement;
              if (pe || (pe = {}), be && (pe.leadingComments = e.addRange(be.slice(), pe.leadingComments)), Xe && (pe.trailingComments = e.addRange(Xe.slice(), pe.trailingComments)), j && (pe.flags = j & -268435457), Re && (pe.commentRange = Re), Fe && (pe.sourceMapRange = Fe), dr && (pe.tokenSourceMapRanges = ie(dr, pe.tokenSourceMapRanges)), ze !== void 0 && (pe.constantValue = ze), ve)
                for (var Cr = 0, Ce = ve; Cr < Ce.length; Cr++) {
                  var $e = Ce[Cr];
                  pe.helpers = e.appendIfUnique(pe.helpers, $e);
                }
              return er !== void 0 && (pe.startsOnNewLine = er), ar !== void 0 && (pe.snippetElement = ar), pe;
            }
            function ie(H, pe) {
              pe || (pe = []);
              for (var j in H)
                pe[j] = H[j];
              return pe;
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(Re) {
              var Fe;
              if (Re.emitNode)
                e.Debug.assert(!(Re.emitNode.flags & 268435456), "Invalid attempt to mutate an immutable node.");
              else {
                if (e.isParseTreeNode(Re)) {
                  if (Re.kind === 308)
                    return Re.emitNode = { annotatedNodes: [Re] };
                  var dr = (Fe = e.getSourceFileOfNode(e.getParseTreeNode(e.getSourceFileOfNode(Re)))) !== null && Fe !== void 0 ? Fe : e.Debug.fail("Could not determine parsed source file.");
                  t3(dr).annotatedNodes.push(Re);
                }
                Re.emitNode = {};
              }
              return Re.emitNode;
            }
            e.getOrCreateEmitNode = t3;
            function w(Re) {
              var Fe, dr, ze = (dr = (Fe = e.getSourceFileOfNode(e.getParseTreeNode(Re))) === null || Fe === void 0 ? void 0 : Fe.emitNode) === null || dr === void 0 ? void 0 : dr.annotatedNodes;
              if (ze)
                for (var ve = 0, er = ze; ve < er.length; ve++) {
                  var ar = er[ve];
                  ar.emitNode = void 0;
                }
            }
            e.disposeEmitNodes = w;
            function s(Re) {
              var Fe = t3(Re);
              return Fe.flags |= 1536, Fe.leadingComments = void 0, Fe.trailingComments = void 0, Re;
            }
            e.removeAllComments = s;
            function q(Re, Fe) {
              return t3(Re).flags = Fe, Re;
            }
            e.setEmitFlags = q;
            function F(Re, Fe) {
              var dr = t3(Re);
              return dr.flags = dr.flags | Fe, Re;
            }
            e.addEmitFlags = F;
            function fe(Re) {
              var Fe, dr;
              return (dr = (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.sourceMapRange) !== null && dr !== void 0 ? dr : Re;
            }
            e.getSourceMapRange = fe;
            function Ee(Re, Fe) {
              return t3(Re).sourceMapRange = Fe, Re;
            }
            e.setSourceMapRange = Ee;
            function Se(Re, Fe) {
              var dr, ze;
              return (ze = (dr = Re.emitNode) === null || dr === void 0 ? void 0 : dr.tokenSourceMapRanges) === null || ze === void 0 ? void 0 : ze[Fe];
            }
            e.getTokenSourceMapRange = Se;
            function J(Re, Fe, dr) {
              var ze, ve = t3(Re), er = (ze = ve.tokenSourceMapRanges) !== null && ze !== void 0 ? ze : ve.tokenSourceMapRanges = [];
              return er[Fe] = dr, Re;
            }
            e.setTokenSourceMapRange = J;
            function se(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.startsOnNewLine;
            }
            e.getStartsOnNewLine = se;
            function Me(Re, Fe) {
              return t3(Re).startsOnNewLine = Fe, Re;
            }
            e.setStartsOnNewLine = Me;
            function Q(Re) {
              var Fe, dr;
              return (dr = (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.commentRange) !== null && dr !== void 0 ? dr : Re;
            }
            e.getCommentRange = Q;
            function Be(Re, Fe) {
              return t3(Re).commentRange = Fe, Re;
            }
            e.setCommentRange = Be;
            function je(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.leadingComments;
            }
            e.getSyntheticLeadingComments = je;
            function V(Re, Fe) {
              return t3(Re).leadingComments = Fe, Re;
            }
            e.setSyntheticLeadingComments = V;
            function B(Re, Fe, dr, ze) {
              return V(Re, e.append(je(Re), { kind: Fe, pos: -1, end: -1, hasTrailingNewLine: ze, text: dr }));
            }
            e.addSyntheticLeadingComment = B;
            function U(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.trailingComments;
            }
            e.getSyntheticTrailingComments = U;
            function m(Re, Fe) {
              return t3(Re).trailingComments = Fe, Re;
            }
            e.setSyntheticTrailingComments = m;
            function v(Re, Fe, dr, ze) {
              return m(Re, e.append(U(Re), { kind: Fe, pos: -1, end: -1, hasTrailingNewLine: ze, text: dr }));
            }
            e.addSyntheticTrailingComment = v;
            function g(Re, Fe) {
              V(Re, je(Fe)), m(Re, U(Fe));
              var dr = t3(Fe);
              return dr.leadingComments = void 0, dr.trailingComments = void 0, Re;
            }
            e.moveSyntheticComments = g;
            function O(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.constantValue;
            }
            e.getConstantValue = O;
            function S(Re, Fe) {
              var dr = t3(Re);
              return dr.constantValue = Fe, Re;
            }
            e.setConstantValue = S;
            function te(Re, Fe) {
              var dr = t3(Re);
              return dr.helpers = e.append(dr.helpers, Fe), Re;
            }
            e.addEmitHelper = te;
            function Je(Re, Fe) {
              if (e.some(Fe))
                for (var dr = t3(Re), ze = 0, ve = Fe; ze < ve.length; ze++) {
                  var er = ve[ze];
                  dr.helpers = e.appendIfUnique(dr.helpers, er);
                }
              return Re;
            }
            e.addEmitHelpers = Je;
            function qe(Re, Fe) {
              var dr, ze = (dr = Re.emitNode) === null || dr === void 0 ? void 0 : dr.helpers;
              return ze ? e.orderedRemoveItem(ze, Fe) : false;
            }
            e.removeEmitHelper = qe;
            function ge(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.helpers;
            }
            e.getEmitHelpers = ge;
            function ie(Re, Fe, dr) {
              var ze = Re.emitNode, ve = ze && ze.helpers;
              if (e.some(ve)) {
                for (var er = t3(Fe), ar = 0, Cr = 0; Cr < ve.length; Cr++) {
                  var Ce = ve[Cr];
                  dr(Ce) ? (ar++, er.helpers = e.appendIfUnique(er.helpers, Ce)) : ar > 0 && (ve[Cr - ar] = Ce);
                }
                ar > 0 && (ve.length -= ar);
              }
            }
            e.moveEmitHelpers = ie;
            function H(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.snippetElement;
            }
            e.getSnippetElement = H;
            function pe(Re, Fe) {
              var dr = t3(Re);
              return dr.snippetElement = Fe, Re;
            }
            e.setSnippetElement = pe;
            function j(Re) {
              return t3(Re).flags |= 134217728, Re;
            }
            e.ignoreSourceNewlines = j;
            function be(Re, Fe) {
              var dr = t3(Re);
              return dr.typeNode = Fe, Re;
            }
            e.setTypeNode = be;
            function Xe(Re) {
              var Fe;
              return (Fe = Re.emitNode) === null || Fe === void 0 ? void 0 : Fe.typeNode;
            }
            e.getTypeNode = Xe;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(Ee) {
              var Se = Ee.factory, J = e.memoize(function() {
                return e.setEmitFlags(Se.createTrue(), 268435456);
              }), se = e.memoize(function() {
                return e.setEmitFlags(Se.createFalse(), 268435456);
              });
              return { getUnscopedHelperName: Me, createDecorateHelper: Q, createMetadataHelper: Be, createParamHelper: je, createAssignHelper: V, createAwaitHelper: B, createAsyncGeneratorHelper: U, createAsyncDelegatorHelper: m, createAsyncValuesHelper: v, createRestHelper: g, createAwaiterHelper: O, createExtendsHelper: S, createTemplateObjectHelper: te, createSpreadArrayHelper: Je, createValuesHelper: qe, createReadHelper: ge, createGeneratorHelper: ie, createCreateBindingHelper: H, createImportStarHelper: pe, createImportStarCallbackHelper: j, createImportDefaultHelper: be, createExportStarHelper: Xe, createClassPrivateFieldGetHelper: Re, createClassPrivateFieldSetHelper: Fe, createClassPrivateFieldInHelper: dr };
              function Me(ze) {
                return e.setEmitFlags(Se.createIdentifier(ze), 4098);
              }
              function Q(ze, ve, er, ar) {
                Ee.requestEmitHelper(e.decorateHelper);
                var Cr = [];
                return Cr.push(Se.createArrayLiteralExpression(ze, true)), Cr.push(ve), er && (Cr.push(er), ar && Cr.push(ar)), Se.createCallExpression(Me("__decorate"), void 0, Cr);
              }
              function Be(ze, ve) {
                return Ee.requestEmitHelper(e.metadataHelper), Se.createCallExpression(Me("__metadata"), void 0, [Se.createStringLiteral(ze), ve]);
              }
              function je(ze, ve, er) {
                return Ee.requestEmitHelper(e.paramHelper), e.setTextRange(Se.createCallExpression(Me("__param"), void 0, [Se.createNumericLiteral(ve + ""), ze]), er);
              }
              function V(ze) {
                return e.getEmitScriptTarget(Ee.getCompilerOptions()) >= 2 ? Se.createCallExpression(Se.createPropertyAccessExpression(Se.createIdentifier("Object"), "assign"), void 0, ze) : (Ee.requestEmitHelper(e.assignHelper), Se.createCallExpression(Me("__assign"), void 0, ze));
              }
              function B(ze) {
                return Ee.requestEmitHelper(e.awaitHelper), Se.createCallExpression(Me("__await"), void 0, [ze]);
              }
              function U(ze, ve) {
                return Ee.requestEmitHelper(e.awaitHelper), Ee.requestEmitHelper(e.asyncGeneratorHelper), (ze.emitNode || (ze.emitNode = {})).flags |= 786432, Se.createCallExpression(Me("__asyncGenerator"), void 0, [ve ? Se.createThis() : Se.createVoidZero(), Se.createIdentifier("arguments"), ze]);
              }
              function m(ze) {
                return Ee.requestEmitHelper(e.awaitHelper), Ee.requestEmitHelper(e.asyncDelegator), Se.createCallExpression(Me("__asyncDelegator"), void 0, [ze]);
              }
              function v(ze) {
                return Ee.requestEmitHelper(e.asyncValues), Se.createCallExpression(Me("__asyncValues"), void 0, [ze]);
              }
              function g(ze, ve, er, ar) {
                Ee.requestEmitHelper(e.restHelper);
                for (var Cr = [], Ce = 0, $e = 0; $e < ve.length - 1; $e++) {
                  var gr = e.getPropertyNameOfBindingOrAssignmentElement(ve[$e]);
                  if (gr)
                    if (e.isComputedPropertyName(gr)) {
                      e.Debug.assertIsDefined(er, "Encountered computed property name but 'computedTempVariables' argument was not provided.");
                      var X = er[Ce];
                      Ce++, Cr.push(Se.createConditionalExpression(Se.createTypeCheck(X, "symbol"), void 0, X, void 0, Se.createAdd(X, Se.createStringLiteral(""))));
                    } else
                      Cr.push(Se.createStringLiteralFromNode(gr));
                }
                return Se.createCallExpression(Me("__rest"), void 0, [ze, e.setTextRange(Se.createArrayLiteralExpression(Cr), ar)]);
              }
              function O(ze, ve, er, ar) {
                Ee.requestEmitHelper(e.awaiterHelper);
                var Cr = Se.createFunctionExpression(void 0, Se.createToken(41), void 0, void 0, [], void 0, ar);
                return (Cr.emitNode || (Cr.emitNode = {})).flags |= 786432, Se.createCallExpression(Me("__awaiter"), void 0, [ze ? Se.createThis() : Se.createVoidZero(), ve ? Se.createIdentifier("arguments") : Se.createVoidZero(), er ? e.createExpressionFromEntityName(Se, er) : Se.createVoidZero(), Cr]);
              }
              function S(ze) {
                return Ee.requestEmitHelper(e.extendsHelper), Se.createCallExpression(Me("__extends"), void 0, [ze, Se.createUniqueName("_super", 48)]);
              }
              function te(ze, ve) {
                return Ee.requestEmitHelper(e.templateObjectHelper), Se.createCallExpression(Me("__makeTemplateObject"), void 0, [ze, ve]);
              }
              function Je(ze, ve, er) {
                return Ee.requestEmitHelper(e.spreadArrayHelper), Se.createCallExpression(Me("__spreadArray"), void 0, [ze, ve, er ? J() : se()]);
              }
              function qe(ze) {
                return Ee.requestEmitHelper(e.valuesHelper), Se.createCallExpression(Me("__values"), void 0, [ze]);
              }
              function ge(ze, ve) {
                return Ee.requestEmitHelper(e.readHelper), Se.createCallExpression(Me("__read"), void 0, ve !== void 0 ? [ze, Se.createNumericLiteral(ve + "")] : [ze]);
              }
              function ie(ze) {
                return Ee.requestEmitHelper(e.generatorHelper), Se.createCallExpression(Me("__generator"), void 0, [Se.createThis(), ze]);
              }
              function H(ze, ve, er) {
                return Ee.requestEmitHelper(e.createBindingHelper), Se.createCallExpression(Me("__createBinding"), void 0, D([Se.createIdentifier("exports"), ze, ve], er ? [er] : [], true));
              }
              function pe(ze) {
                return Ee.requestEmitHelper(e.importStarHelper), Se.createCallExpression(Me("__importStar"), void 0, [ze]);
              }
              function j() {
                return Ee.requestEmitHelper(e.importStarHelper), Me("__importStar");
              }
              function be(ze) {
                return Ee.requestEmitHelper(e.importDefaultHelper), Se.createCallExpression(Me("__importDefault"), void 0, [ze]);
              }
              function Xe(ze, ve) {
                return ve === void 0 && (ve = Se.createIdentifier("exports")), Ee.requestEmitHelper(e.exportStarHelper), Ee.requestEmitHelper(e.createBindingHelper), Se.createCallExpression(Me("__exportStar"), void 0, [ze, ve]);
              }
              function Re(ze, ve, er, ar) {
                Ee.requestEmitHelper(e.classPrivateFieldGetHelper);
                var Cr;
                return ar ? Cr = [ze, ve, Se.createStringLiteral(er), ar] : Cr = [ze, ve, Se.createStringLiteral(er)], Se.createCallExpression(Me("__classPrivateFieldGet"), void 0, Cr);
              }
              function Fe(ze, ve, er, ar, Cr) {
                Ee.requestEmitHelper(e.classPrivateFieldSetHelper);
                var Ce;
                return Cr ? Ce = [ze, ve, er, Se.createStringLiteral(ar), Cr] : Ce = [ze, ve, er, Se.createStringLiteral(ar)], Se.createCallExpression(Me("__classPrivateFieldSet"), void 0, Ce);
              }
              function dr(ze, ve) {
                return Ee.requestEmitHelper(e.classPrivateFieldInHelper), Se.createCallExpression(Me("__classPrivateFieldIn"), void 0, [ze, ve]);
              }
            }
            e.createEmitHelperFactory = t3;
            function w(Ee, Se) {
              return Ee === Se || Ee.priority === Se.priority ? 0 : Ee.priority === void 0 ? 1 : Se.priority === void 0 ? -1 : e.compareValues(Ee.priority, Se.priority);
            }
            e.compareEmitHelpers = w;
            function s(Ee) {
              for (var Se = [], J = 1; J < arguments.length; J++)
                Se[J - 1] = arguments[J];
              return function(se) {
                for (var Me = "", Q = 0; Q < Se.length; Q++)
                  Me += Ee[Q], Me += se(Se[Q]);
                return Me += Ee[Ee.length - 1], Me;
              };
            }
            e.helperString = s, e.decorateHelper = { name: "typescript:decorate", importName: "__decorate", scoped: false, priority: 2, text: `
            var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
                var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
                if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
                else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
                return c > 3 && r && Object.defineProperty(target, key, r), r;
            };` }, e.metadataHelper = { name: "typescript:metadata", importName: "__metadata", scoped: false, priority: 3, text: `
            var __metadata = (this && this.__metadata) || function (k, v) {
                if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
            };` }, e.paramHelper = { name: "typescript:param", importName: "__param", scoped: false, priority: 4, text: `
            var __param = (this && this.__param) || function (paramIndex, decorator) {
                return function (target, key) { decorator(target, key, paramIndex); }
            };` }, e.assignHelper = { name: "typescript:assign", importName: "__assign", scoped: false, priority: 1, text: `
            var __assign = (this && this.__assign) || function () {
                __assign = Object.assign || function(t) {
                    for (var s, i = 1, n = arguments.length; i < n; i++) {
                        s = arguments[i];
                        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                            t[p] = s[p];
                    }
                    return t;
                };
                return __assign.apply(this, arguments);
            };` }, e.awaitHelper = { name: "typescript:await", importName: "__await", scoped: false, text: `
            var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }` }, e.asyncGeneratorHelper = { name: "typescript:asyncGenerator", importName: "__asyncGenerator", scoped: false, dependencies: [e.awaitHelper], text: `
            var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {
                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
                var g = generator.apply(thisArg, _arguments || []), i, q = [];
                return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
                function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
                function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
                function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
                function fulfill(value) { resume("next", value); }
                function reject(value) { resume("throw", value); }
                function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
            };` }, e.asyncDelegator = { name: "typescript:asyncDelegator", importName: "__asyncDelegator", scoped: false, dependencies: [e.awaitHelper], text: `
            var __asyncDelegator = (this && this.__asyncDelegator) || function (o) {
                var i, p;
                return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
                function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
            };` }, e.asyncValues = { name: "typescript:asyncValues", importName: "__asyncValues", scoped: false, text: `
            var __asyncValues = (this && this.__asyncValues) || function (o) {
                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
                var m = o[Symbol.asyncIterator], i;
                return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
                function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
                function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
            };` }, e.restHelper = { name: "typescript:rest", importName: "__rest", scoped: false, text: `
            var __rest = (this && this.__rest) || function (s, e) {
                var t = {};
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
                if (s != null && typeof Object.getOwnPropertySymbols === "function")
                    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                        if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                            t[p[i]] = s[p[i]];
                    }
                return t;
            };` }, e.awaiterHelper = { name: "typescript:awaiter", importName: "__awaiter", scoped: false, priority: 5, text: `
            var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
                function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            };` }, e.extendsHelper = { name: "typescript:extends", importName: "__extends", scoped: false, priority: 0, text: `
            var __extends = (this && this.__extends) || (function () {
                var extendStatics = function (d, b) {
                    extendStatics = Object.setPrototypeOf ||
                        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
                    return extendStatics(d, b);
                };

                return function (d, b) {
                    if (typeof b !== "function" && b !== null)
                        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
                    extendStatics(d, b);
                    function __() { this.constructor = d; }
                    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
                };
            })();` }, e.templateObjectHelper = { name: "typescript:makeTemplateObject", importName: "__makeTemplateObject", scoped: false, priority: 0, text: `
            var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
                if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
                return cooked;
            };` }, e.readHelper = { name: "typescript:read", importName: "__read", scoped: false, text: `
            var __read = (this && this.__read) || function (o, n) {
                var m = typeof Symbol === "function" && o[Symbol.iterator];
                if (!m) return o;
                var i = m.call(o), r, ar = [], e;
                try {
                    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
                }
                catch (error) { e = { error: error }; }
                finally {
                    try {
                        if (r && !r.done && (m = i["return"])) m.call(i);
                    }
                    finally { if (e) throw e.error; }
                }
                return ar;
            };` }, e.spreadArrayHelper = { name: "typescript:spreadArray", importName: "__spreadArray", scoped: false, text: `
            var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
                if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
                    if (ar || !(i in from)) {
                        if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                        ar[i] = from[i];
                    }
                }
                return to.concat(ar || Array.prototype.slice.call(from));
            };` }, e.valuesHelper = { name: "typescript:values", importName: "__values", scoped: false, text: `
            var __values = (this && this.__values) || function(o) {
                var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
                if (m) return m.call(o);
                if (o && typeof o.length === "number") return {
                    next: function () {
                        if (o && i >= o.length) o = void 0;
                        return { value: o && o[i++], done: !o };
                    }
                };
                throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
            };` }, e.generatorHelper = { name: "typescript:generator", importName: "__generator", scoped: false, priority: 6, text: `
            var __generator = (this && this.__generator) || function (thisArg, body) {
                var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
                return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
                function verb(n) { return function (v) { return step([n, v]); }; }
                function step(op) {
                    if (f) throw new TypeError("Generator is already executing.");
                    while (g && (g = 0, op[0] && (_ = 0)), _) try {
                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                        if (y = 0, t) op = [op[0] & 2, t.value];
                        switch (op[0]) {
                            case 0: case 1: t = op; break;
                            case 4: _.label++; return { value: op[1], done: false };
                            case 5: _.label++; y = op[1]; op = [0]; continue;
                            case 7: op = _.ops.pop(); _.trys.pop(); continue;
                            default:
                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                                if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                                if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                                if (t[2]) _.ops.pop();
                                _.trys.pop(); continue;
                        }
                        op = body.call(thisArg, _);
                    } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
                    if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
                }
            };` }, e.createBindingHelper = { name: "typescript:commonjscreatebinding", importName: "__createBinding", scoped: false, priority: 1, text: `
            var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                var desc = Object.getOwnPropertyDescriptor(m, k);
                if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
                  desc = { enumerable: true, get: function() { return m[k]; } };
                }
                Object.defineProperty(o, k2, desc);
            }) : (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                o[k2] = m[k];
            }));` }, e.setModuleDefaultHelper = { name: "typescript:commonjscreatevalue", importName: "__setModuleDefault", scoped: false, priority: 1, text: `
            var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
                Object.defineProperty(o, "default", { enumerable: true, value: v });
            }) : function(o, v) {
                o["default"] = v;
            });` }, e.importStarHelper = { name: "typescript:commonjsimportstar", importName: "__importStar", scoped: false, dependencies: [e.createBindingHelper, e.setModuleDefaultHelper], priority: 2, text: `
            var __importStar = (this && this.__importStar) || function (mod) {
                if (mod && mod.__esModule) return mod;
                var result = {};
                if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
                __setModuleDefault(result, mod);
                return result;
            };` }, e.importDefaultHelper = { name: "typescript:commonjsimportdefault", importName: "__importDefault", scoped: false, text: `
            var __importDefault = (this && this.__importDefault) || function (mod) {
                return (mod && mod.__esModule) ? mod : { "default": mod };
            };` }, e.exportStarHelper = { name: "typescript:export-star", importName: "__exportStar", scoped: false, dependencies: [e.createBindingHelper], priority: 2, text: `
            var __exportStar = (this && this.__exportStar) || function(m, exports) {
                for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
            };` }, e.classPrivateFieldGetHelper = { name: "typescript:classPrivateFieldGet", importName: "__classPrivateFieldGet", scoped: false, text: `
            var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
                return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
            };` }, e.classPrivateFieldSetHelper = { name: "typescript:classPrivateFieldSet", importName: "__classPrivateFieldSet", scoped: false, text: `
            var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
                if (kind === "m") throw new TypeError("Private method is not writable");
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
                return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
            };` }, e.classPrivateFieldInHelper = { name: "typescript:classPrivateFieldIn", importName: "__classPrivateFieldIn", scoped: false, text: `
            var __classPrivateFieldIn = (this && this.__classPrivateFieldIn) || function(state, receiver) {
                if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function")) throw new TypeError("Cannot use 'in' operator on non-object");
                return typeof state === "function" ? receiver === state : state.has(receiver);
            };` };
            var q;
            function F() {
              return q || (q = e.arrayToMap([e.decorateHelper, e.metadataHelper, e.paramHelper, e.assignHelper, e.awaitHelper, e.asyncGeneratorHelper, e.asyncDelegator, e.asyncValues, e.restHelper, e.awaiterHelper, e.extendsHelper, e.templateObjectHelper, e.spreadArrayHelper, e.valuesHelper, e.readHelper, e.generatorHelper, e.importStarHelper, e.importDefaultHelper, e.exportStarHelper, e.classPrivateFieldGetHelper, e.classPrivateFieldSetHelper, e.classPrivateFieldInHelper, e.createBindingHelper, e.setModuleDefaultHelper], function(Ee) {
                return Ee.name;
              }));
            }
            e.getAllUnscopedEmitHelpers = F, e.asyncSuperHelper = { name: "typescript:async-super", scoped: true, text: s(ae([`
            const `, " = name => super[name];"], [`
            const `, " = name => super[name];"]), "_superIndex") }, e.advancedAsyncSuperHelper = { name: "typescript:advanced-async-super", scoped: true, text: s(ae([`
            const `, ` = (function (geti, seti) {
                const cache = Object.create(null);
                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });
            })(name => super[name], (name, value) => super[name] = value);`], [`
            const `, ` = (function (geti, seti) {
                const cache = Object.create(null);
                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });
            })(name => super[name], (name, value) => super[name] = value);`]), "_superIndex") };
            function fe(Ee, Se) {
              return e.isCallExpression(Ee) && e.isIdentifier(Ee.expression) && (e.getEmitFlags(Ee.expression) & 4096) !== 0 && Ee.expression.escapedText === Se;
            }
            e.isCallToHelper = fe;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(R) {
              return R.kind === 8;
            }
            e.isNumericLiteral = t3;
            function w(R) {
              return R.kind === 9;
            }
            e.isBigIntLiteral = w;
            function s(R) {
              return R.kind === 10;
            }
            e.isStringLiteral = s;
            function q(R) {
              return R.kind === 11;
            }
            e.isJsxText = q;
            function F(R) {
              return R.kind === 13;
            }
            e.isRegularExpressionLiteral = F;
            function fe(R) {
              return R.kind === 14;
            }
            e.isNoSubstitutionTemplateLiteral = fe;
            function Ee(R) {
              return R.kind === 15;
            }
            e.isTemplateHead = Ee;
            function Se(R) {
              return R.kind === 16;
            }
            e.isTemplateMiddle = Se;
            function J(R) {
              return R.kind === 17;
            }
            e.isTemplateTail = J;
            function se(R) {
              return R.kind === 25;
            }
            e.isDotDotDotToken = se;
            function Me(R) {
              return R.kind === 27;
            }
            e.isCommaToken = Me;
            function Q(R) {
              return R.kind === 39;
            }
            e.isPlusToken = Q;
            function Be(R) {
              return R.kind === 40;
            }
            e.isMinusToken = Be;
            function je(R) {
              return R.kind === 41;
            }
            e.isAsteriskToken = je;
            function V(R) {
              return R.kind === 53;
            }
            e.isExclamationToken = V;
            function B(R) {
              return R.kind === 57;
            }
            e.isQuestionToken = B;
            function U(R) {
              return R.kind === 58;
            }
            e.isColonToken = U;
            function m(R) {
              return R.kind === 28;
            }
            e.isQuestionDotToken = m;
            function v(R) {
              return R.kind === 38;
            }
            e.isEqualsGreaterThanToken = v;
            function g(R) {
              return R.kind === 79;
            }
            e.isIdentifier = g;
            function O(R) {
              return R.kind === 80;
            }
            e.isPrivateIdentifier = O;
            function S(R) {
              return R.kind === 93;
            }
            e.isExportModifier = S;
            function te(R) {
              return R.kind === 132;
            }
            e.isAsyncModifier = te;
            function Je(R) {
              return R.kind === 129;
            }
            e.isAssertsKeyword = Je;
            function qe(R) {
              return R.kind === 133;
            }
            e.isAwaitKeyword = qe;
            function ge(R) {
              return R.kind === 146;
            }
            e.isReadonlyKeyword = ge;
            function ie(R) {
              return R.kind === 124;
            }
            e.isStaticModifier = ie;
            function H(R) {
              return R.kind === 126;
            }
            e.isAbstractModifier = H;
            function pe(R) {
              return R.kind === 161;
            }
            e.isOverrideModifier = pe;
            function j(R) {
              return R.kind === 127;
            }
            e.isAccessorModifier = j;
            function be(R) {
              return R.kind === 106;
            }
            e.isSuperKeyword = be;
            function Xe(R) {
              return R.kind === 100;
            }
            e.isImportKeyword = Xe;
            function Re(R) {
              return R.kind === 163;
            }
            e.isQualifiedName = Re;
            function Fe(R) {
              return R.kind === 164;
            }
            e.isComputedPropertyName = Fe;
            function dr(R) {
              return R.kind === 165;
            }
            e.isTypeParameterDeclaration = dr;
            function ze(R) {
              return R.kind === 166;
            }
            e.isParameter = ze;
            function ve(R) {
              return R.kind === 167;
            }
            e.isDecorator = ve;
            function er(R) {
              return R.kind === 168;
            }
            e.isPropertySignature = er;
            function ar(R) {
              return R.kind === 169;
            }
            e.isPropertyDeclaration = ar;
            function Cr(R) {
              return R.kind === 170;
            }
            e.isMethodSignature = Cr;
            function Ce(R) {
              return R.kind === 171;
            }
            e.isMethodDeclaration = Ce;
            function $e(R) {
              return R.kind === 172;
            }
            e.isClassStaticBlockDeclaration = $e;
            function gr(R) {
              return R.kind === 173;
            }
            e.isConstructorDeclaration = gr;
            function X(R) {
              return R.kind === 174;
            }
            e.isGetAccessorDeclaration = X;
            function Te(R) {
              return R.kind === 175;
            }
            e.isSetAccessorDeclaration = Te;
            function we(R) {
              return R.kind === 176;
            }
            e.isCallSignatureDeclaration = we;
            function he(R) {
              return R.kind === 177;
            }
            e.isConstructSignatureDeclaration = he;
            function yr(R) {
              return R.kind === 178;
            }
            e.isIndexSignatureDeclaration = yr;
            function kr(R) {
              return R.kind === 179;
            }
            e.isTypePredicateNode = kr;
            function nr(R) {
              return R.kind === 180;
            }
            e.isTypeReferenceNode = nr;
            function tr(R) {
              return R.kind === 181;
            }
            e.isFunctionTypeNode = tr;
            function Lr(R) {
              return R.kind === 182;
            }
            e.isConstructorTypeNode = Lr;
            function zr(R) {
              return R.kind === 183;
            }
            e.isTypeQueryNode = zr;
            function ye(R) {
              return R.kind === 184;
            }
            e.isTypeLiteralNode = ye;
            function ir(R) {
              return R.kind === 185;
            }
            e.isArrayTypeNode = ir;
            function Dr(R) {
              return R.kind === 186;
            }
            e.isTupleTypeNode = Dr;
            function Pr(R) {
              return R.kind === 199;
            }
            e.isNamedTupleMember = Pr;
            function Br(R) {
              return R.kind === 187;
            }
            e.isOptionalTypeNode = Br;
            function ut(R) {
              return R.kind === 188;
            }
            e.isRestTypeNode = ut;
            function rt(R) {
              return R.kind === 189;
            }
            e.isUnionTypeNode = rt;
            function Z(R) {
              return R.kind === 190;
            }
            e.isIntersectionTypeNode = Z;
            function f(R) {
              return R.kind === 191;
            }
            e.isConditionalTypeNode = f;
            function h(R) {
              return R.kind === 192;
            }
            e.isInferTypeNode = h;
            function oe(R) {
              return R.kind === 193;
            }
            e.isParenthesizedTypeNode = oe;
            function xr(R) {
              return R.kind === 194;
            }
            e.isThisTypeNode = xr;
            function jr(R) {
              return R.kind === 195;
            }
            e.isTypeOperatorNode = jr;
            function qr(R) {
              return R.kind === 196;
            }
            e.isIndexedAccessTypeNode = qr;
            function pt(R) {
              return R.kind === 197;
            }
            e.isMappedTypeNode = pt;
            function Ge(R) {
              return R.kind === 198;
            }
            e.isLiteralTypeNode = Ge;
            function K(R) {
              return R.kind === 202;
            }
            e.isImportTypeNode = K;
            function r(R) {
              return R.kind === 201;
            }
            e.isTemplateLiteralTypeSpan = r;
            function ct(R) {
              return R.kind === 200;
            }
            e.isTemplateLiteralTypeNode = ct;
            function ft(R) {
              return R.kind === 203;
            }
            e.isObjectBindingPattern = ft;
            function Ie(R) {
              return R.kind === 204;
            }
            e.isArrayBindingPattern = Ie;
            function me(R) {
              return R.kind === 205;
            }
            e.isBindingElement = me;
            function xe(R) {
              return R.kind === 206;
            }
            e.isArrayLiteralExpression = xe;
            function Ye(R) {
              return R.kind === 207;
            }
            e.isObjectLiteralExpression = Ye;
            function vr(R) {
              return R.kind === 208;
            }
            e.isPropertyAccessExpression = vr;
            function nt(R) {
              return R.kind === 209;
            }
            e.isElementAccessExpression = nt;
            function pr(R) {
              return R.kind === 210;
            }
            e.isCallExpression = pr;
            function Mr(R) {
              return R.kind === 211;
            }
            e.isNewExpression = Mr;
            function ot(R) {
              return R.kind === 212;
            }
            e.isTaggedTemplateExpression = ot;
            function At(R) {
              return R.kind === 213;
            }
            e.isTypeAssertionExpression = At;
            function re(R) {
              return R.kind === 214;
            }
            e.isParenthesizedExpression = re;
            function de(R) {
              return R.kind === 215;
            }
            e.isFunctionExpression = de;
            function He(R) {
              return R.kind === 216;
            }
            e.isArrowFunction = He;
            function Nr(R) {
              return R.kind === 217;
            }
            e.isDeleteExpression = Nr;
            function Yr(R) {
              return R.kind === 218;
            }
            e.isTypeOfExpression = Yr;
            function Ct(R) {
              return R.kind === 219;
            }
            e.isVoidExpression = Ct;
            function xt(R) {
              return R.kind === 220;
            }
            e.isAwaitExpression = xt;
            function Lt(R) {
              return R.kind === 221;
            }
            e.isPrefixUnaryExpression = Lt;
            function zt(R) {
              return R.kind === 222;
            }
            e.isPostfixUnaryExpression = zt;
            function Zt(R) {
              return R.kind === 223;
            }
            e.isBinaryExpression = Zt;
            function mt(R) {
              return R.kind === 224;
            }
            e.isConditionalExpression = mt;
            function at(R) {
              return R.kind === 225;
            }
            e.isTemplateExpression = at;
            function k(R) {
              return R.kind === 226;
            }
            e.isYieldExpression = k;
            function ue(R) {
              return R.kind === 227;
            }
            e.isSpreadElement = ue;
            function Qe(R) {
              return R.kind === 228;
            }
            e.isClassExpression = Qe;
            function Sr(R) {
              return R.kind === 229;
            }
            e.isOmittedExpression = Sr;
            function Kr(R) {
              return R.kind === 230;
            }
            e.isExpressionWithTypeArguments = Kr;
            function Hr(R) {
              return R.kind === 231;
            }
            e.isAsExpression = Hr;
            function Dt(R) {
              return R.kind === 235;
            }
            e.isSatisfiesExpression = Dt;
            function Xt(R) {
              return R.kind === 232;
            }
            e.isNonNullExpression = Xt;
            function cn(R) {
              return R.kind === 233;
            }
            e.isMetaProperty = cn;
            function In(R) {
              return R.kind === 234;
            }
            e.isSyntheticExpression = In;
            function yn(R) {
              return R.kind === 353;
            }
            e.isPartiallyEmittedExpression = yn;
            function hn(R) {
              return R.kind === 354;
            }
            e.isCommaListExpression = hn;
            function ln(R) {
              return R.kind === 236;
            }
            e.isTemplateSpan = ln;
            function En(R) {
              return R.kind === 237;
            }
            e.isSemicolonClassElement = En;
            function Vt(R) {
              return R.kind === 238;
            }
            e.isBlock = Vt;
            function ui(R) {
              return R.kind === 240;
            }
            e.isVariableStatement = ui;
            function ei(R) {
              return R.kind === 239;
            }
            e.isEmptyStatement = ei;
            function hi(R) {
              return R.kind === 241;
            }
            e.isExpressionStatement = hi;
            function ri(R) {
              return R.kind === 242;
            }
            e.isIfStatement = ri;
            function vi(R) {
              return R.kind === 243;
            }
            e.isDoStatement = vi;
            function Qn(R) {
              return R.kind === 244;
            }
            e.isWhileStatement = Qn;
            function Yn(R) {
              return R.kind === 245;
            }
            e.isForStatement = Yn;
            function oi(R) {
              return R.kind === 246;
            }
            e.isForInStatement = oi;
            function bi(R) {
              return R.kind === 247;
            }
            e.isForOfStatement = bi;
            function Dn(R) {
              return R.kind === 248;
            }
            e.isContinueStatement = Dn;
            function Kn(R) {
              return R.kind === 249;
            }
            e.isBreakStatement = Kn;
            function si(R) {
              return R.kind === 250;
            }
            e.isReturnStatement = si;
            function di(R) {
              return R.kind === 251;
            }
            e.isWithStatement = di;
            function Zn(R) {
              return R.kind === 252;
            }
            e.isSwitchStatement = Zn;
            function Fn(R) {
              return R.kind === 253;
            }
            e.isLabeledStatement = Fn;
            function gt(R) {
              return R.kind === 254;
            }
            e.isThrowStatement = gt;
            function mi(R) {
              return R.kind === 255;
            }
            e.isTryStatement = mi;
            function dn(R) {
              return R.kind === 256;
            }
            e.isDebuggerStatement = dn;
            function On(R) {
              return R.kind === 257;
            }
            e.isVariableDeclaration = On;
            function br(R) {
              return R.kind === 258;
            }
            e.isVariableDeclarationList = br;
            function Ae(R) {
              return R.kind === 259;
            }
            e.isFunctionDeclaration = Ae;
            function ur(R) {
              return R.kind === 260;
            }
            e.isClassDeclaration = ur;
            function L(R) {
              return R.kind === 261;
            }
            e.isInterfaceDeclaration = L;
            function qt(R) {
              return R.kind === 262;
            }
            e.isTypeAliasDeclaration = qt;
            function nn(R) {
              return R.kind === 263;
            }
            e.isEnumDeclaration = nn;
            function fr(R) {
              return R.kind === 264;
            }
            e.isModuleDeclaration = fr;
            function Le(R) {
              return R.kind === 265;
            }
            e.isModuleBlock = Le;
            function Ve(R) {
              return R.kind === 266;
            }
            e.isCaseBlock = Ve;
            function _r(R) {
              return R.kind === 267;
            }
            e.isNamespaceExportDeclaration = _r;
            function lr(R) {
              return R.kind === 268;
            }
            e.isImportEqualsDeclaration = lr;
            function Vr(R) {
              return R.kind === 269;
            }
            e.isImportDeclaration = Vr;
            function tt(R) {
              return R.kind === 270;
            }
            e.isImportClause = tt;
            function dt(R) {
              return R.kind === 298;
            }
            e.isImportTypeAssertionContainer = dt;
            function It(R) {
              return R.kind === 296;
            }
            e.isAssertClause = It;
            function an(R) {
              return R.kind === 297;
            }
            e.isAssertEntry = an;
            function sn(R) {
              return R.kind === 271;
            }
            e.isNamespaceImport = sn;
            function _e(R) {
              return R.kind === 277;
            }
            e.isNamespaceExport = _e;
            function Gr(R) {
              return R.kind === 272;
            }
            e.isNamedImports = Gr;
            function Kt(R) {
              return R.kind === 273;
            }
            e.isImportSpecifier = Kt;
            function en(R) {
              return R.kind === 274;
            }
            e.isExportAssignment = en;
            function Ot(R) {
              return R.kind === 275;
            }
            e.isExportDeclaration = Ot;
            function rr(R) {
              return R.kind === 276;
            }
            e.isNamedExports = rr;
            function Hn(R) {
              return R.kind === 278;
            }
            e.isExportSpecifier = Hn;
            function rn(R) {
              return R.kind === 279;
            }
            e.isMissingDeclaration = rn;
            function xn(R) {
              return R.kind === 352;
            }
            e.isNotEmittedStatement = xn;
            function Mn(R) {
              return R.kind === 357;
            }
            e.isSyntheticReference = Mn;
            function Rn(R) {
              return R.kind === 355;
            }
            e.isMergeDeclarationMarker = Rn;
            function kn(R) {
              return R.kind === 356;
            }
            e.isEndOfDeclarationMarker = kn;
            function on(R) {
              return R.kind === 280;
            }
            e.isExternalModuleReference = on;
            function Xr(R) {
              return R.kind === 281;
            }
            e.isJsxElement = Xr;
            function wr(R) {
              return R.kind === 282;
            }
            e.isJsxSelfClosingElement = wr;
            function fn(R) {
              return R.kind === 283;
            }
            e.isJsxOpeningElement = fn;
            function mn(R) {
              return R.kind === 284;
            }
            e.isJsxClosingElement = mn;
            function Mi(R) {
              return R.kind === 285;
            }
            e.isJsxFragment = Mi;
            function An(R) {
              return R.kind === 286;
            }
            e.isJsxOpeningFragment = An;
            function xi(R) {
              return R.kind === 287;
            }
            e.isJsxClosingFragment = xi;
            function ti(R) {
              return R.kind === 288;
            }
            e.isJsxAttribute = ti;
            function li(R) {
              return R.kind === 289;
            }
            e.isJsxAttributes = li;
            function Bn(R) {
              return R.kind === 290;
            }
            e.isJsxSpreadAttribute = Bn;
            function vn(R) {
              return R.kind === 291;
            }
            e.isJsxExpression = vn;
            function Ue(R) {
              return R.kind === 292;
            }
            e.isCaseClause = Ue;
            function Vn(R) {
              return R.kind === 293;
            }
            e.isDefaultClause = Vn;
            function Ei(R) {
              return R.kind === 294;
            }
            e.isHeritageClause = Ei;
            function ni(R) {
              return R.kind === 295;
            }
            e.isCatchClause = ni;
            function Fi(R) {
              return R.kind === 299;
            }
            e.isPropertyAssignment = Fi;
            function Tn(R) {
              return R.kind === 300;
            }
            e.isShorthandPropertyAssignment = Tn;
            function jn(R) {
              return R.kind === 301;
            }
            e.isSpreadAssignment = jn;
            function Ti(R) {
              return R.kind === 302;
            }
            e.isEnumMember = Ti;
            function Si(R) {
              return R.kind === 304;
            }
            e.isUnparsedPrepend = Si;
            function C(R) {
              return R.kind === 308;
            }
            e.isSourceFile = C;
            function W(R) {
              return R.kind === 309;
            }
            e.isBundle = W;
            function ee(R) {
              return R.kind === 310;
            }
            e.isUnparsedSource = ee;
            function le(R) {
              return R.kind === 312;
            }
            e.isJSDocTypeExpression = le;
            function Ze(R) {
              return R.kind === 313;
            }
            e.isJSDocNameReference = Ze;
            function Ir(R) {
              return R.kind === 314;
            }
            e.isJSDocMemberName = Ir;
            function Ar(R) {
              return R.kind === 327;
            }
            e.isJSDocLink = Ar;
            function hr(R) {
              return R.kind === 328;
            }
            e.isJSDocLinkCode = hr;
            function yt(R) {
              return R.kind === 329;
            }
            e.isJSDocLinkPlain = yt;
            function Pt(R) {
              return R.kind === 315;
            }
            e.isJSDocAllType = Pt;
            function Ut(R) {
              return R.kind === 316;
            }
            e.isJSDocUnknownType = Ut;
            function jt(R) {
              return R.kind === 317;
            }
            e.isJSDocNullableType = jt;
            function Ht(R) {
              return R.kind === 318;
            }
            e.isJSDocNonNullableType = Ht;
            function gi(R) {
              return R.kind === 319;
            }
            e.isJSDocOptionalType = gi;
            function Pi(R) {
              return R.kind === 320;
            }
            e.isJSDocFunctionType = Pi;
            function Gn(R) {
              return R.kind === 321;
            }
            e.isJSDocVariadicType = Gn;
            function Bi(R) {
              return R.kind === 322;
            }
            e.isJSDocNamepathType = Bi;
            function oa(R) {
              return R.kind === 323;
            }
            e.isJSDoc = oa;
            function Zi(R) {
              return R.kind === 325;
            }
            e.isJSDocTypeLiteral = Zi;
            function Ki(R) {
              return R.kind === 326;
            }
            e.isJSDocSignature = Ki;
            function qi(R) {
              return R.kind === 331;
            }
            e.isJSDocAugmentsTag = qi;
            function Hi(R) {
              return R.kind === 333;
            }
            e.isJSDocAuthorTag = Hi;
            function Gi(R) {
              return R.kind === 335;
            }
            e.isJSDocClassTag = Gi;
            function da(R) {
              return R.kind === 341;
            }
            e.isJSDocCallbackTag = da;
            function Jn(R) {
              return R.kind === 336;
            }
            e.isJSDocPublicTag = Jn;
            function ea(R) {
              return R.kind === 337;
            }
            e.isJSDocPrivateTag = ea;
            function Xi(R) {
              return R.kind === 338;
            }
            e.isJSDocProtectedTag = Xi;
            function sa(R) {
              return R.kind === 339;
            }
            e.isJSDocReadonlyTag = sa;
            function Li(R) {
              return R.kind === 340;
            }
            e.isJSDocOverrideTag = Li;
            function p(R) {
              return R.kind === 334;
            }
            e.isJSDocDeprecatedTag = p;
            function ne(R) {
              return R.kind === 349;
            }
            e.isJSDocSeeTag = ne;
            function Ne(R) {
              return R.kind === 342;
            }
            e.isJSDocEnumTag = Ne;
            function or(R) {
              return R.kind === 343;
            }
            e.isJSDocParameterTag = or;
            function it2(R) {
              return R.kind === 344;
            }
            e.isJSDocReturnTag = it2;
            function vt(R) {
              return R.kind === 345;
            }
            e.isJSDocThisTag = vt;
            function Tt(R) {
              return R.kind === 346;
            }
            e.isJSDocTypeTag = Tt;
            function St(R) {
              return R.kind === 347;
            }
            e.isJSDocTemplateTag = St;
            function tn(R) {
              return R.kind === 348;
            }
            e.isJSDocTypedefTag = tn;
            function Mt(R) {
              return R.kind === 330;
            }
            e.isJSDocUnknownTag = Mt;
            function $t(R) {
              return R.kind === 350;
            }
            e.isJSDocPropertyTag = $t;
            function y(R) {
              return R.kind === 332;
            }
            e.isJSDocImplementsTag = y;
            function De(R) {
              return R.kind === 351;
            }
            e.isSyntaxList = De;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(re) {
              return re.createExportDeclaration(void 0, false, re.createNamedExports([]), void 0);
            }
            e.createEmptyExports = t3;
            function w(re, de, He, Nr) {
              if (e.isComputedPropertyName(He))
                return e.setTextRange(re.createElementAccessExpression(de, He.expression), Nr);
              var Yr = e.setTextRange(e.isMemberName(He) ? re.createPropertyAccessExpression(de, He) : re.createElementAccessExpression(de, He), He);
              return e.getOrCreateEmitNode(Yr).flags |= 64, Yr;
            }
            e.createMemberAccessForPropertyName = w;
            function s(re, de) {
              var He = e.parseNodeFactory.createIdentifier(re || "React");
              return e.setParent(He, e.getParseTreeNode(de)), He;
            }
            function q(re, de, He) {
              if (e.isQualifiedName(de)) {
                var Nr = q(re, de.left, He), Yr = re.createIdentifier(e.idText(de.right));
                return Yr.escapedText = de.right.escapedText, re.createPropertyAccessExpression(Nr, Yr);
              } else
                return s(e.idText(de), He);
            }
            function F(re, de, He, Nr) {
              return de ? q(re, de, Nr) : re.createPropertyAccessExpression(s(He, Nr), "createElement");
            }
            e.createJsxFactoryExpression = F;
            function fe(re, de, He, Nr) {
              return de ? q(re, de, Nr) : re.createPropertyAccessExpression(s(He, Nr), "Fragment");
            }
            function Ee(re, de, He, Nr, Yr, Ct) {
              var xt = [He];
              if (Nr && xt.push(Nr), Yr && Yr.length > 0)
                if (Nr || xt.push(re.createNull()), Yr.length > 1)
                  for (var Lt = 0, zt = Yr; Lt < zt.length; Lt++) {
                    var Zt = zt[Lt];
                    be(Zt), xt.push(Zt);
                  }
                else
                  xt.push(Yr[0]);
              return e.setTextRange(re.createCallExpression(de, void 0, xt), Ct);
            }
            e.createExpressionForJsxElement = Ee;
            function Se(re, de, He, Nr, Yr, Ct, xt) {
              var Lt = fe(re, He, Nr, Ct), zt = [Lt, re.createNull()];
              if (Yr && Yr.length > 0)
                if (Yr.length > 1)
                  for (var Zt = 0, mt = Yr; Zt < mt.length; Zt++) {
                    var at = mt[Zt];
                    be(at), zt.push(at);
                  }
                else
                  zt.push(Yr[0]);
              return e.setTextRange(re.createCallExpression(F(re, de, Nr, Ct), void 0, zt), xt);
            }
            e.createExpressionForJsxFragment = Se;
            function J(re, de, He) {
              if (e.isVariableDeclarationList(de)) {
                var Nr = e.first(de.declarations), Yr = re.updateVariableDeclaration(Nr, Nr.name, void 0, void 0, He);
                return e.setTextRange(re.createVariableStatement(void 0, re.updateVariableDeclarationList(de, [Yr])), de);
              } else {
                var Ct = e.setTextRange(re.createAssignment(de, He), de);
                return e.setTextRange(re.createExpressionStatement(Ct), de);
              }
            }
            e.createForOfBindingStatement = J;
            function se(re, de, He) {
              return e.isBlock(de) ? re.updateBlock(de, e.setTextRange(re.createNodeArray(D([He], de.statements, true)), de.statements)) : re.createBlock(re.createNodeArray([de, He]), true);
            }
            e.insertLeadingStatement = se;
            function Me(re, de) {
              if (e.isQualifiedName(de)) {
                var He = Me(re, de.left), Nr = e.setParent(e.setTextRange(re.cloneNode(de.right), de.right), de.right.parent);
                return e.setTextRange(re.createPropertyAccessExpression(He, Nr), de);
              } else
                return e.setParent(e.setTextRange(re.cloneNode(de), de), de.parent);
            }
            e.createExpressionFromEntityName = Me;
            function Q(re, de) {
              return e.isIdentifier(de) ? re.createStringLiteralFromNode(de) : e.isComputedPropertyName(de) ? e.setParent(e.setTextRange(re.cloneNode(de.expression), de.expression), de.expression.parent) : e.setParent(e.setTextRange(re.cloneNode(de), de), de.parent);
            }
            e.createExpressionForPropertyName = Q;
            function Be(re, de, He, Nr, Yr) {
              var Ct = e.getAllAccessorDeclarations(de, He), xt = Ct.firstAccessor, Lt = Ct.getAccessor, zt = Ct.setAccessor;
              if (He === xt)
                return e.setTextRange(re.createObjectDefinePropertyCall(Nr, Q(re, He.name), re.createPropertyDescriptor({ enumerable: re.createFalse(), configurable: true, get: Lt && e.setTextRange(e.setOriginalNode(re.createFunctionExpression(e.getModifiers(Lt), void 0, void 0, void 0, Lt.parameters, void 0, Lt.body), Lt), Lt), set: zt && e.setTextRange(e.setOriginalNode(re.createFunctionExpression(e.getModifiers(zt), void 0, void 0, void 0, zt.parameters, void 0, zt.body), zt), zt) }, !Yr)), xt);
            }
            function je(re, de, He) {
              return e.setOriginalNode(e.setTextRange(re.createAssignment(w(re, He, de.name, de.name), de.initializer), de), de);
            }
            function V(re, de, He) {
              return e.setOriginalNode(e.setTextRange(re.createAssignment(w(re, He, de.name, de.name), re.cloneNode(de.name)), de), de);
            }
            function B(re, de, He) {
              return e.setOriginalNode(e.setTextRange(re.createAssignment(w(re, He, de.name, de.name), e.setOriginalNode(e.setTextRange(re.createFunctionExpression(e.getModifiers(de), de.asteriskToken, void 0, void 0, de.parameters, void 0, de.body), de), de)), de), de);
            }
            function U(re, de, He, Nr) {
              switch (He.name && e.isPrivateIdentifier(He.name) && e.Debug.failBadSyntaxKind(He.name, "Private identifiers are not allowed in object literals."), He.kind) {
                case 174:
                case 175:
                  return Be(re, de.properties, He, Nr, !!de.multiLine);
                case 299:
                  return je(re, He, Nr);
                case 300:
                  return V(re, He, Nr);
                case 171:
                  return B(re, He, Nr);
              }
            }
            e.createExpressionForObjectLiteralElementLike = U;
            function m(re, de, He, Nr, Yr) {
              var Ct = de.operator;
              e.Debug.assert(Ct === 45 || Ct === 46, "Expected 'node' to be a pre- or post-increment or pre- or post-decrement expression");
              var xt = re.createTempVariable(Nr);
              He = re.createAssignment(xt, He), e.setTextRange(He, de.operand);
              var Lt = e.isPrefixUnaryExpression(de) ? re.createPrefixUnaryExpression(Ct, xt) : re.createPostfixUnaryExpression(xt, Ct);
              return e.setTextRange(Lt, de), Yr && (Lt = re.createAssignment(Yr, Lt), e.setTextRange(Lt, de)), He = re.createComma(He, Lt), e.setTextRange(He, de), e.isPostfixUnaryExpression(de) && (He = re.createComma(He, xt), e.setTextRange(He, de)), He;
            }
            e.expandPreOrPostfixIncrementOrDecrementExpression = m;
            function v(re) {
              return (e.getEmitFlags(re) & 32768) !== 0;
            }
            e.isInternalName = v;
            function g(re) {
              return (e.getEmitFlags(re) & 16384) !== 0;
            }
            e.isLocalName = g;
            function O(re) {
              return (e.getEmitFlags(re) & 8192) !== 0;
            }
            e.isExportName = O;
            function S(re) {
              return e.isStringLiteral(re.expression) && re.expression.text === "use strict";
            }
            function te(re) {
              for (var de = 0, He = re; de < He.length; de++) {
                var Nr = He[de];
                if (e.isPrologueDirective(Nr)) {
                  if (S(Nr))
                    return Nr;
                } else
                  break;
              }
            }
            e.findUseStrictPrologue = te;
            function Je(re) {
              var de = e.firstOrUndefined(re);
              return de !== void 0 && e.isPrologueDirective(de) && S(de);
            }
            e.startsWithUseStrict = Je;
            function qe(re) {
              return re.kind === 223 && re.operatorToken.kind === 27 || re.kind === 354;
            }
            e.isCommaSequence = qe;
            function ge(re) {
              return e.isParenthesizedExpression(re) && e.isInJSFile(re) && !!e.getJSDocTypeTag(re);
            }
            e.isJSDocTypeAssertion = ge;
            function ie(re) {
              var de = e.getJSDocType(re);
              return e.Debug.assertIsDefined(de), de;
            }
            e.getJSDocTypeAssertionType = ie;
            function H(re, de) {
              switch (de === void 0 && (de = 15), re.kind) {
                case 214:
                  return de & 16 && ge(re) ? false : (de & 1) !== 0;
                case 213:
                case 231:
                case 235:
                  return (de & 2) !== 0;
                case 232:
                  return (de & 4) !== 0;
                case 353:
                  return (de & 8) !== 0;
              }
              return false;
            }
            e.isOuterExpression = H;
            function pe(re, de) {
              for (de === void 0 && (de = 15); H(re, de); )
                re = re.expression;
              return re;
            }
            e.skipOuterExpressions = pe;
            function j(re) {
              return pe(re, 6);
            }
            e.skipAssertions = j;
            function be(re) {
              return e.setStartsOnNewLine(re, true);
            }
            e.startOnNewLine = be;
            function Xe(re) {
              var de = e.getOriginalNode(re, e.isSourceFile), He = de && de.emitNode;
              return He && He.externalHelpersModuleName;
            }
            e.getExternalHelpersModuleName = Xe;
            function Re(re) {
              var de = e.getOriginalNode(re, e.isSourceFile), He = de && de.emitNode;
              return !!He && (!!He.externalHelpersModuleName || !!He.externalHelpers);
            }
            e.hasRecordedExternalHelpers = Re;
            function Fe(re, de, He, Nr, Yr, Ct, xt) {
              if (Nr.importHelpers && e.isEffectiveExternalModule(He, Nr)) {
                var Lt = void 0, zt = e.getEmitModuleKind(Nr);
                if (zt >= e.ModuleKind.ES2015 && zt <= e.ModuleKind.ESNext || He.impliedNodeFormat === e.ModuleKind.ESNext) {
                  var Zt = e.getEmitHelpers(He);
                  if (Zt) {
                    for (var mt = [], at = 0, k = Zt; at < k.length; at++) {
                      var ue = k[at];
                      if (!ue.scoped) {
                        var Qe = ue.importName;
                        Qe && e.pushIfUnique(mt, Qe);
                      }
                    }
                    if (e.some(mt)) {
                      mt.sort(e.compareStringsCaseSensitive), Lt = re.createNamedImports(e.map(mt, function(Xt) {
                        return e.isFileLevelUniqueName(He, Xt) ? re.createImportSpecifier(false, void 0, re.createIdentifier(Xt)) : re.createImportSpecifier(false, re.createIdentifier(Xt), de.getUnscopedHelperName(Xt));
                      }));
                      var Sr = e.getOriginalNode(He, e.isSourceFile), Kr = e.getOrCreateEmitNode(Sr);
                      Kr.externalHelpers = true;
                    }
                  }
                } else {
                  var Hr = dr(re, He, Nr, Yr, Ct || xt);
                  Hr && (Lt = re.createNamespaceImport(Hr));
                }
                if (Lt) {
                  var Dt = re.createImportDeclaration(void 0, re.createImportClause(false, void 0, Lt), re.createStringLiteral(e.externalHelpersModuleNameText), void 0);
                  return e.addEmitFlags(Dt, 67108864), Dt;
                }
              }
            }
            e.createExternalHelpersImportDeclarationIfNeeded = Fe;
            function dr(re, de, He, Nr, Yr) {
              if (He.importHelpers && e.isEffectiveExternalModule(de, He)) {
                var Ct = Xe(de);
                if (Ct)
                  return Ct;
                var xt = e.getEmitModuleKind(He), Lt = (Nr || e.getESModuleInterop(He) && Yr) && xt !== e.ModuleKind.System && (xt < e.ModuleKind.ES2015 || de.impliedNodeFormat === e.ModuleKind.CommonJS);
                if (!Lt) {
                  var zt = e.getEmitHelpers(de);
                  if (zt)
                    for (var Zt = 0, mt = zt; Zt < mt.length; Zt++) {
                      var at = mt[Zt];
                      if (!at.scoped) {
                        Lt = true;
                        break;
                      }
                    }
                }
                if (Lt) {
                  var k = e.getOriginalNode(de, e.isSourceFile), ue = e.getOrCreateEmitNode(k);
                  return ue.externalHelpersModuleName || (ue.externalHelpersModuleName = re.createUniqueName(e.externalHelpersModuleNameText));
                }
              }
            }
            e.getOrCreateExternalHelpersModuleNameIfNeeded = dr;
            function ze(re, de, He) {
              var Nr = e.getNamespaceDeclarationNode(de);
              if (Nr && !e.isDefaultImport(de) && !e.isExportNamespaceAsDefaultDeclaration(de)) {
                var Yr = Nr.name;
                return e.isGeneratedIdentifier(Yr) ? Yr : re.createIdentifier(e.getSourceTextOfNodeFromSourceFile(He, Yr) || e.idText(Yr));
              }
              if (de.kind === 269 && de.importClause || de.kind === 275 && de.moduleSpecifier)
                return re.getGeneratedNameForNode(de);
            }
            e.getLocalNameForExternalImport = ze;
            function ve(re, de, He, Nr, Yr, Ct) {
              var xt = e.getExternalModuleName(de);
              if (xt && e.isStringLiteral(xt))
                return Cr(de, Nr, re, Yr, Ct) || er(re, xt, He) || re.cloneNode(xt);
            }
            e.getExternalModuleNameLiteral = ve;
            function er(re, de, He) {
              var Nr = He.renamedDependencies && He.renamedDependencies.get(de.text);
              return Nr ? re.createStringLiteral(Nr) : void 0;
            }
            function ar(re, de, He, Nr) {
              if (de) {
                if (de.moduleName)
                  return re.createStringLiteral(de.moduleName);
                if (!de.isDeclarationFile && e.outFile(Nr))
                  return re.createStringLiteral(e.getExternalModuleNameFromPath(He, de.fileName));
              }
            }
            e.tryGetModuleNameFromFile = ar;
            function Cr(re, de, He, Nr, Yr) {
              return ar(He, Nr.getExternalModuleFileFromDeclaration(re), de, Yr);
            }
            function Ce(re) {
              if (e.isDeclarationBindingElement(re))
                return re.initializer;
              if (e.isPropertyAssignment(re)) {
                var de = re.initializer;
                return e.isAssignmentExpression(de, true) ? de.right : void 0;
              }
              if (e.isShorthandPropertyAssignment(re))
                return re.objectAssignmentInitializer;
              if (e.isAssignmentExpression(re, true))
                return re.right;
              if (e.isSpreadElement(re))
                return Ce(re.expression);
            }
            e.getInitializerOfBindingOrAssignmentElement = Ce;
            function $e(re) {
              if (e.isDeclarationBindingElement(re))
                return re.name;
              if (e.isObjectLiteralElementLike(re)) {
                switch (re.kind) {
                  case 299:
                    return $e(re.initializer);
                  case 300:
                    return re.name;
                  case 301:
                    return $e(re.expression);
                }
                return;
              }
              return e.isAssignmentExpression(re, true) ? $e(re.left) : e.isSpreadElement(re) ? $e(re.expression) : re;
            }
            e.getTargetOfBindingOrAssignmentElement = $e;
            function gr(re) {
              switch (re.kind) {
                case 166:
                case 205:
                  return re.dotDotDotToken;
                case 227:
                case 301:
                  return re;
              }
            }
            e.getRestIndicatorOfBindingOrAssignmentElement = gr;
            function X(re) {
              var de = Te(re);
              return e.Debug.assert(!!de || e.isSpreadAssignment(re), "Invalid property name for binding element."), de;
            }
            e.getPropertyNameOfBindingOrAssignmentElement = X;
            function Te(re) {
              switch (re.kind) {
                case 205:
                  if (re.propertyName) {
                    var de = re.propertyName;
                    return e.isPrivateIdentifier(de) ? e.Debug.failBadSyntaxKind(de) : e.isComputedPropertyName(de) && we(de.expression) ? de.expression : de;
                  }
                  break;
                case 299:
                  if (re.name) {
                    var de = re.name;
                    return e.isPrivateIdentifier(de) ? e.Debug.failBadSyntaxKind(de) : e.isComputedPropertyName(de) && we(de.expression) ? de.expression : de;
                  }
                  break;
                case 301:
                  return re.name && e.isPrivateIdentifier(re.name) ? e.Debug.failBadSyntaxKind(re.name) : re.name;
              }
              var He = $e(re);
              if (He && e.isPropertyName(He))
                return He;
            }
            e.tryGetPropertyNameOfBindingOrAssignmentElement = Te;
            function we(re) {
              var de = re.kind;
              return de === 10 || de === 8;
            }
            function he(re) {
              switch (re.kind) {
                case 203:
                case 204:
                case 206:
                  return re.elements;
                case 207:
                  return re.properties;
              }
            }
            e.getElementsOfBindingOrAssignmentPattern = he;
            function yr(re) {
              if (re)
                for (var de = re; ; ) {
                  if (e.isIdentifier(de) || !de.body)
                    return e.isIdentifier(de) ? de : de.name;
                  de = de.body;
                }
            }
            e.getJSDocTypeAliasName = yr;
            function kr(re) {
              var de = re.kind;
              return de === 173 || de === 175;
            }
            e.canHaveIllegalType = kr;
            function nr(re) {
              var de = re.kind;
              return de === 173 || de === 174 || de === 175;
            }
            e.canHaveIllegalTypeParameters = nr;
            function tr(re) {
              var de = re.kind;
              return de === 299 || de === 300 || de === 259 || de === 173 || de === 178 || de === 172 || de === 279 || de === 240 || de === 261 || de === 262 || de === 263 || de === 264 || de === 268 || de === 269 || de === 267 || de === 275 || de === 274;
            }
            e.canHaveIllegalDecorators = tr;
            function Lr(re) {
              var de = re.kind;
              return de === 172 || de === 299 || de === 300 || de === 181 || de === 279 || de === 267;
            }
            e.canHaveIllegalModifiers = Lr, e.isTypeNodeOrTypeParameterDeclaration = e.or(e.isTypeNode, e.isTypeParameterDeclaration), e.isQuestionOrExclamationToken = e.or(e.isQuestionToken, e.isExclamationToken), e.isIdentifierOrThisTypeNode = e.or(e.isIdentifier, e.isThisTypeNode), e.isReadonlyKeywordOrPlusOrMinusToken = e.or(e.isReadonlyKeyword, e.isPlusToken, e.isMinusToken), e.isQuestionOrPlusOrMinusToken = e.or(e.isQuestionToken, e.isPlusToken, e.isMinusToken), e.isModuleName = e.or(e.isIdentifier, e.isStringLiteral);
            function zr(re) {
              var de = re.kind;
              return de === 104 || de === 110 || de === 95 || e.isLiteralExpression(re) || e.isPrefixUnaryExpression(re);
            }
            e.isLiteralTypeLikeExpression = zr;
            function ye(re) {
              return re === 42;
            }
            function ir(re) {
              return re === 41 || re === 43 || re === 44;
            }
            function Dr(re) {
              return ye(re) || ir(re);
            }
            function Pr(re) {
              return re === 39 || re === 40;
            }
            function Br(re) {
              return Pr(re) || Dr(re);
            }
            function ut(re) {
              return re === 47 || re === 48 || re === 49;
            }
            function rt(re) {
              return ut(re) || Br(re);
            }
            function Z(re) {
              return re === 29 || re === 32 || re === 31 || re === 33 || re === 102 || re === 101;
            }
            function f(re) {
              return Z(re) || rt(re);
            }
            function h(re) {
              return re === 34 || re === 36 || re === 35 || re === 37;
            }
            function oe(re) {
              return h(re) || f(re);
            }
            function xr(re) {
              return re === 50 || re === 51 || re === 52;
            }
            function jr(re) {
              return xr(re) || oe(re);
            }
            function qr(re) {
              return re === 55 || re === 56;
            }
            function pt(re) {
              return qr(re) || jr(re);
            }
            function Ge(re) {
              return re === 60 || pt(re) || e.isAssignmentOperator(re);
            }
            function K(re) {
              return Ge(re) || re === 27;
            }
            function r(re) {
              return K(re.kind);
            }
            e.isBinaryOperatorToken = r;
            var ct;
            (function(re) {
              function de(mt, at, k, ue, Qe, Sr, Kr) {
                var Hr = at > 0 ? Qe[at - 1] : void 0;
                return e.Debug.assertEqual(k[at], de), Qe[at] = mt.onEnter(ue[at], Hr, Kr), k[at] = Lt(mt, de), at;
              }
              re.enter = de;
              function He(mt, at, k, ue, Qe, Sr, Kr) {
                e.Debug.assertEqual(k[at], He), e.Debug.assertIsDefined(mt.onLeft), k[at] = Lt(mt, He);
                var Hr = mt.onLeft(ue[at].left, Qe[at], ue[at]);
                return Hr ? (Zt(at, ue, Hr), zt(at, k, ue, Qe, Hr)) : at;
              }
              re.left = He;
              function Nr(mt, at, k, ue, Qe, Sr, Kr) {
                return e.Debug.assertEqual(k[at], Nr), e.Debug.assertIsDefined(mt.onOperator), k[at] = Lt(mt, Nr), mt.onOperator(ue[at].operatorToken, Qe[at], ue[at]), at;
              }
              re.operator = Nr;
              function Yr(mt, at, k, ue, Qe, Sr, Kr) {
                e.Debug.assertEqual(k[at], Yr), e.Debug.assertIsDefined(mt.onRight), k[at] = Lt(mt, Yr);
                var Hr = mt.onRight(ue[at].right, Qe[at], ue[at]);
                return Hr ? (Zt(at, ue, Hr), zt(at, k, ue, Qe, Hr)) : at;
              }
              re.right = Yr;
              function Ct(mt, at, k, ue, Qe, Sr, Kr) {
                e.Debug.assertEqual(k[at], Ct), k[at] = Lt(mt, Ct);
                var Hr = mt.onExit(ue[at], Qe[at]);
                if (at > 0) {
                  if (at--, mt.foldState) {
                    var Dt = k[at] === Ct ? "right" : "left";
                    Qe[at] = mt.foldState(Qe[at], Hr, Dt);
                  }
                } else
                  Sr.value = Hr;
                return at;
              }
              re.exit = Ct;
              function xt(mt, at, k, ue, Qe, Sr, Kr) {
                return e.Debug.assertEqual(k[at], xt), at;
              }
              re.done = xt;
              function Lt(mt, at) {
                switch (at) {
                  case de:
                    if (mt.onLeft)
                      return He;
                  case He:
                    if (mt.onOperator)
                      return Nr;
                  case Nr:
                    if (mt.onRight)
                      return Yr;
                  case Yr:
                    return Ct;
                  case Ct:
                    return xt;
                  case xt:
                    return xt;
                  default:
                    e.Debug.fail("Invalid state");
                }
              }
              re.nextState = Lt;
              function zt(mt, at, k, ue, Qe) {
                return mt++, at[mt] = de, k[mt] = Qe, ue[mt] = void 0, mt;
              }
              function Zt(mt, at, k) {
                if (e.Debug.shouldAssert(2))
                  for (; mt >= 0; )
                    e.Debug.assert(at[mt] !== k, "Circular traversal detected."), mt--;
              }
            })(ct || (ct = {}));
            var ft = function() {
              function re(de, He, Nr, Yr, Ct, xt) {
                this.onEnter = de, this.onLeft = He, this.onOperator = Nr, this.onRight = Yr, this.onExit = Ct, this.foldState = xt;
              }
              return re;
            }();
            function Ie(re, de, He, Nr, Yr, Ct) {
              var xt = new ft(re, de, He, Nr, Yr, Ct);
              return Lt;
              function Lt(zt, Zt) {
                for (var mt = { value: void 0 }, at = [ct.enter], k = [zt], ue = [void 0], Qe = 0; at[Qe] !== ct.done; )
                  Qe = at[Qe](xt, Qe, at, k, ue, mt, Zt);
                return e.Debug.assertEqual(Qe, 0), mt.value;
              }
            }
            e.createBinaryExpressionTrampoline = Ie;
            function me(re, de) {
              if (de !== void 0)
                return de.length === 0 ? de : e.setTextRange(re.createNodeArray([], de.hasTrailingComma), de);
            }
            e.elideNodes = me;
            function xe(re) {
              if (re.autoGenerateFlags & 4) {
                for (var de = re.autoGenerateId, He = re, Nr = He.original; Nr && (He = Nr, !(e.isMemberName(He) && He.autoGenerateFlags & 4 && He.autoGenerateId !== de)); )
                  Nr = He.original;
                return He;
              }
              return re;
            }
            e.getNodeForGeneratedName = xe;
            function Ye(re, de) {
              return typeof re == "object" ? pr(false, re.prefix, re.node, re.suffix, de) : typeof re == "string" ? re.length > 0 && re.charCodeAt(0) === 35 ? re.slice(1) : re : "";
            }
            e.formatGeneratedNamePart = Ye;
            function vr(re, de) {
              return typeof re == "string" ? re : nt(re, e.Debug.checkDefined(de));
            }
            function nt(re, de) {
              return e.isGeneratedPrivateIdentifier(re) ? de(re).slice(1) : e.isGeneratedIdentifier(re) ? de(re) : e.isPrivateIdentifier(re) ? re.escapedText.slice(1) : e.idText(re);
            }
            function pr(re, de, He, Nr, Yr) {
              return de = Ye(de, Yr), Nr = Ye(Nr, Yr), He = vr(He, Yr), "".concat(re ? "#" : "").concat(de).concat(He).concat(Nr);
            }
            e.formatGeneratedName = pr;
            function Mr(re, de, He, Nr) {
              return re.updatePropertyDeclaration(de, He, re.getGeneratedPrivateNameForNode(de.name, void 0, "_accessor_storage"), void 0, void 0, Nr);
            }
            e.createAccessorPropertyBackingField = Mr;
            function ot(re, de, He, Nr) {
              return re.createGetAccessorDeclaration(He, Nr, [], void 0, re.createBlock([re.createReturnStatement(re.createPropertyAccessExpression(re.createThis(), re.getGeneratedPrivateNameForNode(de.name, void 0, "_accessor_storage")))]));
            }
            e.createAccessorPropertyGetRedirector = ot;
            function At(re, de, He, Nr) {
              return re.createSetAccessorDeclaration(He, Nr, [re.createParameterDeclaration(void 0, void 0, "value")], re.createBlock([re.createExpressionStatement(re.createAssignment(re.createPropertyAccessExpression(re.createThis(), re.getGeneratedPrivateNameForNode(de.name, void 0, "_accessor_storage")), re.createIdentifier("value")))]));
            }
            e.createAccessorPropertySetRedirector = At;
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(q, F) {
              return F ? e.setTextRangePosEnd(q, F.pos, F.end) : q;
            }
            e.setTextRange = t3;
            function w(q) {
              var F = q.kind;
              return F === 165 || F === 166 || F === 168 || F === 169 || F === 170 || F === 171 || F === 173 || F === 174 || F === 175 || F === 178 || F === 182 || F === 215 || F === 216 || F === 228 || F === 240 || F === 259 || F === 260 || F === 261 || F === 262 || F === 263 || F === 264 || F === 268 || F === 269 || F === 274 || F === 275;
            }
            e.canHaveModifiers = w;
            function s(q) {
              var F = q.kind;
              return F === 166 || F === 169 || F === 171 || F === 174 || F === 175 || F === 228 || F === 260;
            }
            e.canHaveDecorators = s;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3, w;
            (function(Z) {
              Z[Z.None = 0] = "None", Z[Z.Yield = 1] = "Yield", Z[Z.Await = 2] = "Await", Z[Z.Type = 4] = "Type", Z[Z.IgnoreMissingOpenBrace = 16] = "IgnoreMissingOpenBrace", Z[Z.JSDoc = 32] = "JSDoc";
            })(w || (w = {}));
            var s;
            (function(Z) {
              Z[Z.TryParse = 0] = "TryParse", Z[Z.Lookahead = 1] = "Lookahead", Z[Z.Reparse = 2] = "Reparse";
            })(s || (s = {}));
            var q, F, fe, Ee, Se;
            e.parseBaseNodeFactory = { createBaseSourceFileNode: function(Z) {
              return new (Se || (Se = e.objectAllocator.getSourceFileConstructor()))(Z, -1, -1);
            }, createBaseIdentifierNode: function(Z) {
              return new (fe || (fe = e.objectAllocator.getIdentifierConstructor()))(Z, -1, -1);
            }, createBasePrivateIdentifierNode: function(Z) {
              return new (Ee || (Ee = e.objectAllocator.getPrivateIdentifierConstructor()))(Z, -1, -1);
            }, createBaseTokenNode: function(Z) {
              return new (F || (F = e.objectAllocator.getTokenConstructor()))(Z, -1, -1);
            }, createBaseNode: function(Z) {
              return new (q || (q = e.objectAllocator.getNodeConstructor()))(Z, -1, -1);
            } }, e.parseNodeFactory = e.createNodeFactory(1, e.parseBaseNodeFactory);
            function J(Z, f) {
              return f && Z(f);
            }
            function se(Z, f, h) {
              if (h) {
                if (f)
                  return f(h);
                for (var oe = 0, xr = h; oe < xr.length; oe++) {
                  var jr = xr[oe], qr = Z(jr);
                  if (qr)
                    return qr;
                }
              }
            }
            function Me(Z, f) {
              return Z.charCodeAt(f + 1) === 42 && Z.charCodeAt(f + 2) === 42 && Z.charCodeAt(f + 3) !== 47;
            }
            e.isJSDocLikeText = Me;
            function Q(Z) {
              return e.forEach(Z.statements, Be) || je(Z);
            }
            e.isFileProbablyExternalModule = Q;
            function Be(Z) {
              return e.canHaveModifiers(Z) && B(Z, 93) || e.isImportEqualsDeclaration(Z) && e.isExternalModuleReference(Z.moduleReference) || e.isImportDeclaration(Z) || e.isExportAssignment(Z) || e.isExportDeclaration(Z) ? Z : void 0;
            }
            function je(Z) {
              return Z.flags & 4194304 ? V(Z) : void 0;
            }
            function V(Z) {
              return U(Z) ? Z : ze(Z, V);
            }
            function B(Z, f) {
              return e.some(Z.modifiers, function(h) {
                return h.kind === f;
              });
            }
            function U(Z) {
              return e.isMetaProperty(Z) && Z.keywordToken === 100 && Z.name.escapedText === "meta";
            }
            var m = (t3 = {}, t3[163] = function(f, h, oe) {
              return J(h, f.left) || J(h, f.right);
            }, t3[165] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.constraint) || J(h, f.default) || J(h, f.expression);
            }, t3[300] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.questionToken) || J(h, f.exclamationToken) || J(h, f.equalsToken) || J(h, f.objectAssignmentInitializer);
            }, t3[301] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[166] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.dotDotDotToken) || J(h, f.name) || J(h, f.questionToken) || J(h, f.type) || J(h, f.initializer);
            }, t3[169] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.questionToken) || J(h, f.exclamationToken) || J(h, f.type) || J(h, f.initializer);
            }, t3[168] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.questionToken) || J(h, f.type) || J(h, f.initializer);
            }, t3[299] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.questionToken) || J(h, f.exclamationToken) || J(h, f.initializer);
            }, t3[257] = function(f, h, oe) {
              return J(h, f.name) || J(h, f.exclamationToken) || J(h, f.type) || J(h, f.initializer);
            }, t3[205] = function(f, h, oe) {
              return J(h, f.dotDotDotToken) || J(h, f.propertyName) || J(h, f.name) || J(h, f.initializer);
            }, t3[178] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type);
            }, t3[182] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type);
            }, t3[181] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type);
            }, t3[176] = v, t3[177] = v, t3[171] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.asteriskToken) || J(h, f.name) || J(h, f.questionToken) || J(h, f.exclamationToken) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[170] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.questionToken) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type);
            }, t3[173] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[174] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[175] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[259] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.asteriskToken) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[215] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || J(h, f.asteriskToken) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.body);
            }, t3[216] = function(f, h, oe) {
              return se(h, oe, f.modifiers) || se(h, oe, f.typeParameters) || se(h, oe, f.parameters) || J(h, f.type) || J(h, f.equalsGreaterThanToken) || J(h, f.body);
            }, t3[172] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.body);
            }, t3[180] = function(f, h, oe) {
              return J(h, f.typeName) || se(h, oe, f.typeArguments);
            }, t3[179] = function(f, h, oe) {
              return J(h, f.assertsModifier) || J(h, f.parameterName) || J(h, f.type);
            }, t3[183] = function(f, h, oe) {
              return J(h, f.exprName) || se(h, oe, f.typeArguments);
            }, t3[184] = function(f, h, oe) {
              return se(h, oe, f.members);
            }, t3[185] = function(f, h, oe) {
              return J(h, f.elementType);
            }, t3[186] = function(f, h, oe) {
              return se(h, oe, f.elements);
            }, t3[189] = g, t3[190] = g, t3[191] = function(f, h, oe) {
              return J(h, f.checkType) || J(h, f.extendsType) || J(h, f.trueType) || J(h, f.falseType);
            }, t3[192] = function(f, h, oe) {
              return J(h, f.typeParameter);
            }, t3[202] = function(f, h, oe) {
              return J(h, f.argument) || J(h, f.assertions) || J(h, f.qualifier) || se(h, oe, f.typeArguments);
            }, t3[298] = function(f, h, oe) {
              return J(h, f.assertClause);
            }, t3[193] = O, t3[195] = O, t3[196] = function(f, h, oe) {
              return J(h, f.objectType) || J(h, f.indexType);
            }, t3[197] = function(f, h, oe) {
              return J(h, f.readonlyToken) || J(h, f.typeParameter) || J(h, f.nameType) || J(h, f.questionToken) || J(h, f.type) || se(h, oe, f.members);
            }, t3[198] = function(f, h, oe) {
              return J(h, f.literal);
            }, t3[199] = function(f, h, oe) {
              return J(h, f.dotDotDotToken) || J(h, f.name) || J(h, f.questionToken) || J(h, f.type);
            }, t3[203] = S, t3[204] = S, t3[206] = function(f, h, oe) {
              return se(h, oe, f.elements);
            }, t3[207] = function(f, h, oe) {
              return se(h, oe, f.properties);
            }, t3[208] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.questionDotToken) || J(h, f.name);
            }, t3[209] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.questionDotToken) || J(h, f.argumentExpression);
            }, t3[210] = te, t3[211] = te, t3[212] = function(f, h, oe) {
              return J(h, f.tag) || J(h, f.questionDotToken) || se(h, oe, f.typeArguments) || J(h, f.template);
            }, t3[213] = function(f, h, oe) {
              return J(h, f.type) || J(h, f.expression);
            }, t3[214] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[217] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[218] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[219] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[221] = function(f, h, oe) {
              return J(h, f.operand);
            }, t3[226] = function(f, h, oe) {
              return J(h, f.asteriskToken) || J(h, f.expression);
            }, t3[220] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[222] = function(f, h, oe) {
              return J(h, f.operand);
            }, t3[223] = function(f, h, oe) {
              return J(h, f.left) || J(h, f.operatorToken) || J(h, f.right);
            }, t3[231] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.type);
            }, t3[232] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[235] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.type);
            }, t3[233] = function(f, h, oe) {
              return J(h, f.name);
            }, t3[224] = function(f, h, oe) {
              return J(h, f.condition) || J(h, f.questionToken) || J(h, f.whenTrue) || J(h, f.colonToken) || J(h, f.whenFalse);
            }, t3[227] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[238] = Je, t3[265] = Je, t3[308] = function(f, h, oe) {
              return se(h, oe, f.statements) || J(h, f.endOfFileToken);
            }, t3[240] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.declarationList);
            }, t3[258] = function(f, h, oe) {
              return se(h, oe, f.declarations);
            }, t3[241] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[242] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.thenStatement) || J(h, f.elseStatement);
            }, t3[243] = function(f, h, oe) {
              return J(h, f.statement) || J(h, f.expression);
            }, t3[244] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.statement);
            }, t3[245] = function(f, h, oe) {
              return J(h, f.initializer) || J(h, f.condition) || J(h, f.incrementor) || J(h, f.statement);
            }, t3[246] = function(f, h, oe) {
              return J(h, f.initializer) || J(h, f.expression) || J(h, f.statement);
            }, t3[247] = function(f, h, oe) {
              return J(h, f.awaitModifier) || J(h, f.initializer) || J(h, f.expression) || J(h, f.statement);
            }, t3[248] = qe, t3[249] = qe, t3[250] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[251] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.statement);
            }, t3[252] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.caseBlock);
            }, t3[266] = function(f, h, oe) {
              return se(h, oe, f.clauses);
            }, t3[292] = function(f, h, oe) {
              return J(h, f.expression) || se(h, oe, f.statements);
            }, t3[293] = function(f, h, oe) {
              return se(h, oe, f.statements);
            }, t3[253] = function(f, h, oe) {
              return J(h, f.label) || J(h, f.statement);
            }, t3[254] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[255] = function(f, h, oe) {
              return J(h, f.tryBlock) || J(h, f.catchClause) || J(h, f.finallyBlock);
            }, t3[295] = function(f, h, oe) {
              return J(h, f.variableDeclaration) || J(h, f.block);
            }, t3[167] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[260] = ge, t3[228] = ge, t3[261] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.typeParameters) || se(h, oe, f.heritageClauses) || se(h, oe, f.members);
            }, t3[262] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.typeParameters) || J(h, f.type);
            }, t3[263] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || se(h, oe, f.members);
            }, t3[302] = function(f, h, oe) {
              return J(h, f.name) || J(h, f.initializer);
            }, t3[264] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.body);
            }, t3[268] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.name) || J(h, f.moduleReference);
            }, t3[269] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.importClause) || J(h, f.moduleSpecifier) || J(h, f.assertClause);
            }, t3[270] = function(f, h, oe) {
              return J(h, f.name) || J(h, f.namedBindings);
            }, t3[296] = function(f, h, oe) {
              return se(h, oe, f.elements);
            }, t3[297] = function(f, h, oe) {
              return J(h, f.name) || J(h, f.value);
            }, t3[267] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || J(h, f.name);
            }, t3[271] = function(f, h, oe) {
              return J(h, f.name);
            }, t3[277] = function(f, h, oe) {
              return J(h, f.name);
            }, t3[272] = ie, t3[276] = ie, t3[275] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.exportClause) || J(h, f.moduleSpecifier) || J(h, f.assertClause);
            }, t3[273] = H, t3[278] = H, t3[274] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers) || J(h, f.expression);
            }, t3[225] = function(f, h, oe) {
              return J(h, f.head) || se(h, oe, f.templateSpans);
            }, t3[236] = function(f, h, oe) {
              return J(h, f.expression) || J(h, f.literal);
            }, t3[200] = function(f, h, oe) {
              return J(h, f.head) || se(h, oe, f.templateSpans);
            }, t3[201] = function(f, h, oe) {
              return J(h, f.type) || J(h, f.literal);
            }, t3[164] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[294] = function(f, h, oe) {
              return se(h, oe, f.types);
            }, t3[230] = function(f, h, oe) {
              return J(h, f.expression) || se(h, oe, f.typeArguments);
            }, t3[280] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[279] = function(f, h, oe) {
              return se(h, oe, f.illegalDecorators) || se(h, oe, f.modifiers);
            }, t3[354] = function(f, h, oe) {
              return se(h, oe, f.elements);
            }, t3[281] = function(f, h, oe) {
              return J(h, f.openingElement) || se(h, oe, f.children) || J(h, f.closingElement);
            }, t3[285] = function(f, h, oe) {
              return J(h, f.openingFragment) || se(h, oe, f.children) || J(h, f.closingFragment);
            }, t3[282] = pe, t3[283] = pe, t3[289] = function(f, h, oe) {
              return se(h, oe, f.properties);
            }, t3[288] = function(f, h, oe) {
              return J(h, f.name) || J(h, f.initializer);
            }, t3[290] = function(f, h, oe) {
              return J(h, f.expression);
            }, t3[291] = function(f, h, oe) {
              return J(h, f.dotDotDotToken) || J(h, f.expression);
            }, t3[284] = function(f, h, oe) {
              return J(h, f.tagName);
            }, t3[187] = j, t3[188] = j, t3[312] = j, t3[318] = j, t3[317] = j, t3[319] = j, t3[321] = j, t3[320] = function(f, h, oe) {
              return se(h, oe, f.parameters) || J(h, f.type);
            }, t3[323] = function(f, h, oe) {
              return (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment)) || se(h, oe, f.tags);
            }, t3[349] = function(f, h, oe) {
              return J(h, f.tagName) || J(h, f.name) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[313] = function(f, h, oe) {
              return J(h, f.name);
            }, t3[314] = function(f, h, oe) {
              return J(h, f.left) || J(h, f.right);
            }, t3[343] = be, t3[350] = be, t3[333] = function(f, h, oe) {
              return J(h, f.tagName) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[332] = function(f, h, oe) {
              return J(h, f.tagName) || J(h, f.class) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[331] = function(f, h, oe) {
              return J(h, f.tagName) || J(h, f.class) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[347] = function(f, h, oe) {
              return J(h, f.tagName) || J(h, f.constraint) || se(h, oe, f.typeParameters) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[348] = function(f, h, oe) {
              return J(h, f.tagName) || (f.typeExpression && f.typeExpression.kind === 312 ? J(h, f.typeExpression) || J(h, f.fullName) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment)) : J(h, f.fullName) || J(h, f.typeExpression) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment)));
            }, t3[341] = function(f, h, oe) {
              return J(h, f.tagName) || J(h, f.fullName) || J(h, f.typeExpression) || (typeof f.comment == "string" ? void 0 : se(h, oe, f.comment));
            }, t3[344] = Xe, t3[346] = Xe, t3[345] = Xe, t3[342] = Xe, t3[326] = function(f, h, oe) {
              return e.forEach(f.typeParameters, h) || e.forEach(f.parameters, h) || J(h, f.type);
            }, t3[327] = Re, t3[328] = Re, t3[329] = Re, t3[325] = function(f, h, oe) {
              return e.forEach(f.jsDocPropertyTags, h);
            }, t3[330] = Fe, t3[335] = Fe, t3[336] = Fe, t3[337] = Fe, t3[338] = Fe, t3[339] = Fe, t3[334] = Fe, t3[340] = Fe, t3[353] = dr, t3);
            function v(Z, f, h) {
              return se(f, h, Z.typeParameters) || se(f, h, Z.parameters) || J(f, Z.type);
            }
            function g(Z, f, h) {
              return se(f, h, Z.types);
            }
            function O(Z, f, h) {
              return J(f, Z.type);
            }
            function S(Z, f, h) {
              return se(f, h, Z.elements);
            }
            function te(Z, f, h) {
              return J(f, Z.expression) || J(f, Z.questionDotToken) || se(f, h, Z.typeArguments) || se(f, h, Z.arguments);
            }
            function Je(Z, f, h) {
              return se(f, h, Z.statements);
            }
            function qe(Z, f, h) {
              return J(f, Z.label);
            }
            function ge(Z, f, h) {
              return se(f, h, Z.modifiers) || J(f, Z.name) || se(f, h, Z.typeParameters) || se(f, h, Z.heritageClauses) || se(f, h, Z.members);
            }
            function ie(Z, f, h) {
              return se(f, h, Z.elements);
            }
            function H(Z, f, h) {
              return J(f, Z.propertyName) || J(f, Z.name);
            }
            function pe(Z, f, h) {
              return J(f, Z.tagName) || se(f, h, Z.typeArguments) || J(f, Z.attributes);
            }
            function j(Z, f, h) {
              return J(f, Z.type);
            }
            function be(Z, f, h) {
              return J(f, Z.tagName) || (Z.isNameFirst ? J(f, Z.name) || J(f, Z.typeExpression) : J(f, Z.typeExpression) || J(f, Z.name)) || (typeof Z.comment == "string" ? void 0 : se(f, h, Z.comment));
            }
            function Xe(Z, f, h) {
              return J(f, Z.tagName) || J(f, Z.typeExpression) || (typeof Z.comment == "string" ? void 0 : se(f, h, Z.comment));
            }
            function Re(Z, f, h) {
              return J(f, Z.name);
            }
            function Fe(Z, f, h) {
              return J(f, Z.tagName) || (typeof Z.comment == "string" ? void 0 : se(f, h, Z.comment));
            }
            function dr(Z, f, h) {
              return J(f, Z.expression);
            }
            function ze(Z, f, h) {
              if (!(Z === void 0 || Z.kind <= 162)) {
                var oe = m[Z.kind];
                return oe === void 0 ? void 0 : oe(Z, f, h);
              }
            }
            e.forEachChild = ze;
            function ve(Z, f, h) {
              for (var oe = er(Z), xr = []; xr.length < oe.length; )
                xr.push(Z);
              for (; oe.length !== 0; ) {
                var jr = oe.pop(), qr = xr.pop();
                if (e.isArray(jr)) {
                  if (h) {
                    var pt = h(jr, qr);
                    if (pt) {
                      if (pt === "skip")
                        continue;
                      return pt;
                    }
                  }
                  for (var Ge = jr.length - 1; Ge >= 0; --Ge)
                    oe.push(jr[Ge]), xr.push(qr);
                } else {
                  var pt = f(jr, qr);
                  if (pt) {
                    if (pt === "skip")
                      continue;
                    return pt;
                  }
                  if (jr.kind >= 163)
                    for (var K = 0, r = er(jr); K < r.length; K++) {
                      var ct = r[K];
                      oe.push(ct), xr.push(jr);
                    }
                }
              }
            }
            e.forEachChildRecursively = ve;
            function er(Z) {
              var f = [];
              return ze(Z, h, h), f;
              function h(oe) {
                f.unshift(oe);
              }
            }
            function ar(Z) {
              Z.externalModuleIndicator = Q(Z);
            }
            function Cr(Z, f, h, oe, xr) {
              oe === void 0 && (oe = false), e.tracing === null || e.tracing === void 0 || e.tracing.push("parse", "createSourceFile", { path: Z }, true), e.performance.mark("beforeParse");
              var jr;
              e.perfLogger.logStartParseSourceFile(Z);
              var qr = typeof h == "object" ? h : { languageVersion: h }, pt = qr.languageVersion, Ge = qr.setExternalModuleIndicator, K = qr.impliedNodeFormat;
              if (pt === 100)
                jr = he.parseSourceFile(Z, f, pt, void 0, oe, 6, e.noop);
              else {
                var r = K === void 0 ? Ge : function(ct) {
                  return ct.impliedNodeFormat = K, (Ge || ar)(ct);
                };
                jr = he.parseSourceFile(Z, f, pt, void 0, oe, xr, r);
              }
              return e.perfLogger.logStopParseSourceFile(), e.performance.mark("afterParse"), e.performance.measure("Parse", "beforeParse", "afterParse"), e.tracing === null || e.tracing === void 0 || e.tracing.pop(), jr;
            }
            e.createSourceFile = Cr;
            function Ce(Z, f) {
              return he.parseIsolatedEntityName(Z, f);
            }
            e.parseIsolatedEntityName = Ce;
            function $e(Z, f) {
              return he.parseJsonText(Z, f);
            }
            e.parseJsonText = $e;
            function gr(Z) {
              return Z.externalModuleIndicator !== void 0;
            }
            e.isExternalModule = gr;
            function X(Z, f, h, oe) {
              oe === void 0 && (oe = false);
              var xr = yr.updateSourceFile(Z, f, h, oe);
              return xr.flags |= Z.flags & 6291456, xr;
            }
            e.updateSourceFile = X;
            function Te(Z, f, h) {
              var oe = he.JSDocParser.parseIsolatedJSDocComment(Z, f, h);
              return oe && oe.jsDoc && he.fixupParentReferences(oe.jsDoc), oe;
            }
            e.parseIsolatedJSDocComment = Te;
            function we(Z, f, h) {
              return he.JSDocParser.parseJSDocTypeExpressionForTests(Z, f, h);
            }
            e.parseJSDocTypeExpressionForTests = we;
            var he;
            (function(Z) {
              var f = e.createScanner(99, true), h = 20480, oe, xr, jr, qr, pt;
              function Ge(d) {
                return ot++, d;
              }
              var K = { createBaseSourceFileNode: function(d) {
                return Ge(new pt(d, 0, 0));
              }, createBaseIdentifierNode: function(d) {
                return Ge(new jr(d, 0, 0));
              }, createBasePrivateIdentifierNode: function(d) {
                return Ge(new qr(d, 0, 0));
              }, createBaseTokenNode: function(d) {
                return Ge(new xr(d, 0, 0));
              }, createBaseNode: function(d) {
                return Ge(new oe(d, 0, 0));
              } }, r = e.createNodeFactory(11, K), ct, ft, Ie, me, xe, Ye, vr, nt, pr, Mr, ot, At, re, de, He, Nr, Yr, Ct = true, xt = false;
              function Lt(d, P, $2, ce, Pe, We, Er) {
                var Rr;
                if (Pe === void 0 && (Pe = false), We = e.ensureScriptKind(d, We), We === 6) {
                  var Fr = Zt(d, P, $2, ce, Pe);
                  return e.convertToObjectWorker(Fr, (Rr = Fr.statements[0]) === null || Rr === void 0 ? void 0 : Rr.expression, Fr.parseDiagnostics, false, void 0, void 0), Fr.referencedFiles = e.emptyArray, Fr.typeReferenceDirectives = e.emptyArray, Fr.libReferenceDirectives = e.emptyArray, Fr.amdDependencies = e.emptyArray, Fr.hasNoDefaultLib = false, Fr.pragmas = e.emptyMap, Fr;
                }
                mt(d, P, $2, ce, We);
                var et = k($2, Pe, We, Er || ar);
                return at(), et;
              }
              Z.parseSourceFile = Lt;
              function zt(d, P) {
                mt("", d, P, void 0, 1), fr();
                var $2 = Qt(true), ce = L() === 1 && !vr.length;
                return at(), ce ? $2 : void 0;
              }
              Z.parseIsolatedEntityName = zt;
              function Zt(d, P, $2, ce, Pe) {
                $2 === void 0 && ($2 = 2), Pe === void 0 && (Pe = false), mt(d, P, $2, ce, 6), ft = Yr, fr();
                var We = Ae(), Er, Rr;
                if (L() === 1)
                  Er = vn([], We, We), Rr = An();
                else {
                  for (var Fr = void 0; L() !== 1; ) {
                    var et = void 0;
                    switch (L()) {
                      case 22:
                        et = ic();
                        break;
                      case 110:
                      case 95:
                      case 104:
                        et = An();
                        break;
                      case 40:
                        Gr(function() {
                          return fr() === 8 && fr() !== 58;
                        }) ? et = z_() : et = o_();
                        break;
                      case 8:
                      case 10:
                        if (Gr(function() {
                          return fr() !== 58;
                        })) {
                          et = ji();
                          break;
                        }
                      default:
                        et = o_();
                        break;
                    }
                    Fr && e.isArray(Fr) ? Fr.push(et) : Fr ? Fr = [Fr, et] : (Fr = et, L() !== 1 && gt(e.Diagnostics.Unexpected_token));
                  }
                  var wt = e.isArray(Fr) ? Ue(r.createArrayLiteralExpression(Fr), We) : e.Debug.checkDefined(Fr), Gt = r.createExpressionStatement(wt);
                  Ue(Gt, We), Er = vn([Gt], We), Rr = mn(1, e.Diagnostics.Unexpected_token);
                }
                var Wt = Dt(d, 2, 6, false, Er, Rr, ft, e.noop);
                Pe && Hr(Wt), Wt.nodeCount = ot, Wt.identifierCount = de, Wt.identifiers = At, Wt.parseDiagnostics = e.attachFileToDiagnostics(vr, Wt), nt && (Wt.jsDocDiagnostics = e.attachFileToDiagnostics(nt, Wt));
                var pn = Wt;
                return at(), pn;
              }
              Z.parseJsonText = Zt;
              function mt(d, P, $2, ce, Pe) {
                switch (oe = e.objectAllocator.getNodeConstructor(), xr = e.objectAllocator.getTokenConstructor(), jr = e.objectAllocator.getIdentifierConstructor(), qr = e.objectAllocator.getPrivateIdentifierConstructor(), pt = e.objectAllocator.getSourceFileConstructor(), ct = e.normalizePath(d), Ie = P, me = $2, pr = ce, xe = Pe, Ye = e.getLanguageVariant(Pe), vr = [], He = 0, At = new e.Map(), re = new e.Map(), de = 0, ot = 0, ft = 0, Ct = true, xe) {
                  case 1:
                  case 2:
                    Yr = 262144;
                    break;
                  case 6:
                    Yr = 67371008;
                    break;
                  default:
                    Yr = 0;
                    break;
                }
                xt = false, f.setText(Ie), f.setOnError(br), f.setScriptTarget(me), f.setLanguageVariant(Ye);
              }
              function at() {
                f.clearCommentDirectives(), f.setText(""), f.setOnError(void 0), Ie = void 0, me = void 0, pr = void 0, xe = void 0, Ye = void 0, ft = 0, vr = void 0, nt = void 0, He = 0, At = void 0, Nr = void 0, Ct = true;
              }
              function k(d, P, $2, ce) {
                var Pe = kr(ct);
                Pe && (Yr |= 16777216), ft = Yr, fr();
                var We = Jn(0, Ai);
                e.Debug.assert(L() === 1);
                var Er = Sr(An()), Rr = Dt(ct, d, $2, Pe, We, Er, ft, ce);
                return tr(Rr, Ie), Lr(Rr, Fr), Rr.commentDirectives = f.getCommentDirectives(), Rr.nodeCount = ot, Rr.identifierCount = de, Rr.identifiers = At, Rr.parseDiagnostics = e.attachFileToDiagnostics(vr, Rr), nt && (Rr.jsDocDiagnostics = e.attachFileToDiagnostics(nt, Rr)), P && Hr(Rr), Rr;
                function Fr(et, wt, Gt) {
                  vr.push(e.createDetachedDiagnostic(ct, et, wt, Gt));
                }
              }
              function ue(d, P) {
                return P ? Sr(d) : d;
              }
              var Qe = false;
              function Sr(d) {
                e.Debug.assert(!d.jsDoc);
                var P = e.mapDefined(e.getJSDocCommentRanges(d, Ie), function($2) {
                  return Oc.parseJSDocComment(d, $2.pos, $2.end - $2.pos);
                });
                return P.length && (d.jsDoc = P), Qe && (Qe = false, d.flags |= 268435456), d;
              }
              function Kr(d) {
                var P = pr, $2 = yr.createSyntaxCursor(d);
                pr = { currentNode: pn };
                var ce = [], Pe = vr;
                vr = [];
                for (var We = 0, Er = Gt(d.statements, 0), Rr = function() {
                  var Pn = d.statements[We], _i = d.statements[Er];
                  e.addRange(ce, d.statements, We, Er), We = Wt(d.statements, Er);
                  var Ln = e.findIndex(Pe, function(Ci) {
                    return Ci.start >= Pn.pos;
                  }), ya = Ln >= 0 ? e.findIndex(Pe, function(Ci) {
                    return Ci.start >= _i.pos;
                  }, Ln) : -1;
                  Ln >= 0 && e.addRange(vr, Pe, Ln, ya >= 0 ? ya : void 0), _e(function() {
                    var Ci = Yr;
                    for (Yr |= 32768, f.setTextPos(_i.pos), fr(); L() !== 1; ) {
                      var Xn = f.getStartPos(), ki = ea(0, Ai);
                      if (ce.push(ki), Xn === f.getStartPos() && fr(), We >= 0) {
                        var aa = d.statements[We];
                        if (ki.end === aa.pos)
                          break;
                        ki.end > aa.pos && (We = Wt(d.statements, We + 1));
                      }
                    }
                    Yr = Ci;
                  }, 2), Er = We >= 0 ? Gt(d.statements, We) : -1;
                }; Er !== -1; )
                  Rr();
                if (We >= 0) {
                  var Fr = d.statements[We];
                  e.addRange(ce, d.statements, We);
                  var et = e.findIndex(Pe, function(Pn) {
                    return Pn.start >= Fr.pos;
                  });
                  et >= 0 && e.addRange(vr, Pe, et);
                }
                return pr = P, r.updateSourceFile(d, e.setTextRange(r.createNodeArray(ce), d.statements));
                function wt(Pn) {
                  return !(Pn.flags & 32768) && !!(Pn.transformFlags & 67108864);
                }
                function Gt(Pn, _i) {
                  for (var Ln = _i; Ln < Pn.length; Ln++)
                    if (wt(Pn[Ln]))
                      return Ln;
                  return -1;
                }
                function Wt(Pn, _i) {
                  for (var Ln = _i; Ln < Pn.length; Ln++)
                    if (!wt(Pn[Ln]))
                      return Ln;
                  return -1;
                }
                function pn(Pn) {
                  var _i = $2.currentNode(Pn);
                  return Ct && _i && wt(_i) && (_i.intersectsChange = true), _i;
                }
              }
              function Hr(d) {
                e.setParentRecursive(d, true);
              }
              Z.fixupParentReferences = Hr;
              function Dt(d, P, $2, ce, Pe, We, Er, Rr) {
                var Fr = r.createSourceFile(Pe, We, Er);
                return e.setTextRangePosWidth(Fr, 0, Ie.length), et(Fr), !ce && gr(Fr) && Fr.transformFlags & 67108864 && (Fr = Kr(Fr), et(Fr)), Fr;
                function et(wt) {
                  wt.text = Ie, wt.bindDiagnostics = [], wt.bindSuggestionDiagnostics = void 0, wt.languageVersion = P, wt.fileName = d, wt.languageVariant = e.getLanguageVariant($2), wt.isDeclarationFile = ce, wt.scriptKind = $2, Rr(wt), wt.setExternalModuleIndicator = Rr;
                }
              }
              function Xt(d, P) {
                d ? Yr |= P : Yr &= ~P;
              }
              function cn(d) {
                Xt(d, 4096);
              }
              function In(d) {
                Xt(d, 8192);
              }
              function yn(d) {
                Xt(d, 16384);
              }
              function hn(d) {
                Xt(d, 32768);
              }
              function ln(d, P) {
                var $2 = d & Yr;
                if ($2) {
                  Xt(false, $2);
                  var ce = P();
                  return Xt(true, $2), ce;
                }
                return P();
              }
              function En(d, P) {
                var $2 = d & ~Yr;
                if ($2) {
                  Xt(true, $2);
                  var ce = P();
                  return Xt(false, $2), ce;
                }
                return P();
              }
              function Vt(d) {
                return ln(4096, d);
              }
              function ui(d) {
                return En(4096, d);
              }
              function ei(d) {
                return ln(65536, d);
              }
              function hi(d) {
                return En(65536, d);
              }
              function ri(d) {
                return En(8192, d);
              }
              function vi(d) {
                return En(16384, d);
              }
              function Qn(d) {
                return En(32768, d);
              }
              function Yn(d) {
                return ln(32768, d);
              }
              function oi(d) {
                return En(40960, d);
              }
              function bi(d) {
                return ln(40960, d);
              }
              function Dn(d) {
                return (Yr & d) !== 0;
              }
              function Kn() {
                return Dn(8192);
              }
              function si() {
                return Dn(4096);
              }
              function di() {
                return Dn(65536);
              }
              function Zn() {
                return Dn(16384);
              }
              function Fn() {
                return Dn(32768);
              }
              function gt(d, P) {
                return dn(f.getTokenPos(), f.getTextPos(), d, P);
              }
              function mi(d, P, $2, ce) {
                var Pe = e.lastOrUndefined(vr), We;
                return (!Pe || d !== Pe.start) && (We = e.createDetachedDiagnostic(ct, d, P, $2, ce), vr.push(We)), xt = true, We;
              }
              function dn(d, P, $2, ce) {
                return mi(d, P - d, $2, ce);
              }
              function On(d, P, $2) {
                dn(d.pos, d.end, P, $2);
              }
              function br(d, P) {
                mi(f.getTextPos(), P, d);
              }
              function Ae() {
                return f.getStartPos();
              }
              function ur() {
                return f.hasPrecedingJSDocComment();
              }
              function L() {
                return Mr;
              }
              function qt() {
                return Mr = f.scan();
              }
              function nn(d) {
                return fr(), d();
              }
              function fr() {
                return e.isKeyword(Mr) && (f.hasUnicodeEscape() || f.hasExtendedUnicodeEscape()) && dn(f.getTokenPos(), f.getTextPos(), e.Diagnostics.Keywords_cannot_contain_escape_characters), qt();
              }
              function Le() {
                return Mr = f.scanJsDocToken();
              }
              function Ve() {
                return Mr = f.reScanGreaterToken();
              }
              function _r() {
                return Mr = f.reScanSlashToken();
              }
              function lr(d) {
                return Mr = f.reScanTemplateToken(d);
              }
              function Vr() {
                return Mr = f.reScanTemplateHeadOrNoSubstitutionTemplate();
              }
              function tt() {
                return Mr = f.reScanLessThanToken();
              }
              function dt() {
                return Mr = f.reScanHashToken();
              }
              function It() {
                return Mr = f.scanJsxIdentifier();
              }
              function an() {
                return Mr = f.scanJsxToken();
              }
              function sn() {
                return Mr = f.scanJsxAttributeValue();
              }
              function _e(d, P) {
                var $2 = Mr, ce = vr.length, Pe = xt, We = Yr, Er = P !== 0 ? f.lookAhead(d) : f.tryScan(d);
                return e.Debug.assert(We === Yr), (!Er || P !== 0) && (Mr = $2, P !== 2 && (vr.length = ce), xt = Pe), Er;
              }
              function Gr(d) {
                return _e(d, 1);
              }
              function Kt(d) {
                return _e(d, 0);
              }
              function en() {
                return L() === 79 ? true : L() > 116;
              }
              function Ot() {
                return L() === 79 ? true : L() === 125 && Kn() || L() === 133 && Fn() ? false : L() > 116;
              }
              function rr(d, P, $2) {
                return $2 === void 0 && ($2 = true), L() === d ? ($2 && fr(), true) : (P ? gt(P) : gt(e.Diagnostics._0_expected, e.tokenToString(d)), false);
              }
              var Hn = Object.keys(e.textToKeywordObj).filter(function(d) {
                return d.length > 2;
              });
              function rn(d) {
                var P;
                if (e.isTaggedTemplateExpression(d)) {
                  dn(e.skipTrivia(Ie, d.template.pos), d.template.end, e.Diagnostics.Module_declaration_names_may_only_use_or_quoted_strings);
                  return;
                }
                var $2 = e.isIdentifier(d) ? e.idText(d) : void 0;
                if (!$2 || !e.isIdentifierText($2, me)) {
                  gt(e.Diagnostics._0_expected, e.tokenToString(26));
                  return;
                }
                var ce = e.skipTrivia(Ie, d.pos);
                switch ($2) {
                  case "const":
                  case "let":
                  case "var":
                    dn(ce, d.end, e.Diagnostics.Variable_declaration_not_allowed_at_this_location);
                    return;
                  case "declare":
                    return;
                  case "interface":
                    xn(e.Diagnostics.Interface_name_cannot_be_0, e.Diagnostics.Interface_must_be_given_a_name, 18);
                    return;
                  case "is":
                    dn(ce, f.getTextPos(), e.Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
                    return;
                  case "module":
                  case "namespace":
                    xn(e.Diagnostics.Namespace_name_cannot_be_0, e.Diagnostics.Namespace_must_be_given_a_name, 18);
                    return;
                  case "type":
                    xn(e.Diagnostics.Type_alias_name_cannot_be_0, e.Diagnostics.Type_alias_must_be_given_a_name, 63);
                    return;
                }
                var Pe = (P = e.getSpellingSuggestion($2, Hn, function(We) {
                  return We;
                })) !== null && P !== void 0 ? P : Mn($2);
                if (Pe) {
                  dn(ce, d.end, e.Diagnostics.Unknown_keyword_or_identifier_Did_you_mean_0, Pe);
                  return;
                }
                L() !== 0 && dn(ce, d.end, e.Diagnostics.Unexpected_keyword_or_identifier);
              }
              function xn(d, P, $2) {
                L() === $2 ? gt(P) : gt(d, f.getTokenValue());
              }
              function Mn(d) {
                for (var P = 0, $2 = Hn; P < $2.length; P++) {
                  var ce = $2[P];
                  if (d.length > ce.length + 2 && e.startsWith(d, ce))
                    return "".concat(ce, " ").concat(d.slice(ce.length));
                }
              }
              function Rn(d, P, $2) {
                if (L() === 59 && !f.hasPrecedingLineBreak()) {
                  gt(e.Diagnostics.Decorators_must_precede_the_name_and_all_keywords_of_property_declarations);
                  return;
                }
                if (L() === 20) {
                  gt(e.Diagnostics.Cannot_start_a_function_call_in_a_type_annotation), fr();
                  return;
                }
                if (P && !ti()) {
                  $2 ? gt(e.Diagnostics._0_expected, e.tokenToString(26)) : gt(e.Diagnostics.Expected_for_property_initializer);
                  return;
                }
                if (!li()) {
                  if ($2) {
                    gt(e.Diagnostics._0_expected, e.tokenToString(26));
                    return;
                  }
                  rn(d);
                }
              }
              function kn(d) {
                return L() === d ? (Le(), true) : (gt(e.Diagnostics._0_expected, e.tokenToString(d)), false);
              }
              function on(d, P, $2, ce) {
                if (L() === P) {
                  fr();
                  return;
                }
                var Pe = gt(e.Diagnostics._0_expected, e.tokenToString(P));
                $2 && Pe && e.addRelatedInfo(Pe, e.createDetachedDiagnostic(ct, ce, 1, e.Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, e.tokenToString(d), e.tokenToString(P)));
              }
              function Xr(d) {
                return L() === d ? (fr(), true) : false;
              }
              function wr(d) {
                if (L() === d)
                  return An();
              }
              function fn(d) {
                if (L() === d)
                  return xi();
              }
              function mn(d, P, $2) {
                return wr(d) || Vn(d, false, P || e.Diagnostics._0_expected, $2 || e.tokenToString(d));
              }
              function Mi(d) {
                return fn(d) || Vn(d, false, e.Diagnostics._0_expected, e.tokenToString(d));
              }
              function An() {
                var d = Ae(), P = L();
                return fr(), Ue(r.createToken(P), d);
              }
              function xi() {
                var d = Ae(), P = L();
                return Le(), Ue(r.createToken(P), d);
              }
              function ti() {
                return L() === 26 ? true : L() === 19 || L() === 1 || f.hasPrecedingLineBreak();
              }
              function li() {
                return ti() ? (L() === 26 && fr(), true) : false;
              }
              function Bn() {
                return li() || rr(26);
              }
              function vn(d, P, $2, ce) {
                var Pe = r.createNodeArray(d, ce);
                return e.setTextRangePosEnd(Pe, P, $2 != null ? $2 : f.getStartPos()), Pe;
              }
              function Ue(d, P, $2) {
                return e.setTextRangePosEnd(d, P, $2 != null ? $2 : f.getStartPos()), Yr && (d.flags |= Yr), xt && (xt = false, d.flags |= 131072), d;
              }
              function Vn(d, P, $2, ce) {
                P ? mi(f.getStartPos(), 0, $2, ce) : $2 && gt($2, ce);
                var Pe = Ae(), We = d === 79 ? r.createIdentifier("", void 0, void 0) : e.isTemplateLiteralKind(d) ? r.createTemplateLiteralLikeNode(d, "", "", void 0) : d === 8 ? r.createNumericLiteral("", void 0) : d === 10 ? r.createStringLiteral("", void 0) : d === 279 ? r.createMissingDeclaration() : r.createToken(d);
                return Ue(We, Pe);
              }
              function Ei(d) {
                var P = At.get(d);
                return P === void 0 && At.set(d, P = d), P;
              }
              function ni(d, P, $2) {
                if (d) {
                  de++;
                  var ce = Ae(), Pe = L(), We = Ei(f.getTokenValue()), Er = f.hasExtendedUnicodeEscape();
                  return qt(), Ue(r.createIdentifier(We, void 0, Pe, Er), ce);
                }
                if (L() === 80)
                  return gt($2 || e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies), ni(true);
                if (L() === 0 && f.tryScan(function() {
                  return f.reScanInvalidIdentifier() === 79;
                }))
                  return ni(true);
                de++;
                var Rr = L() === 1, Fr = f.isReservedWord(), et = f.getTokenText(), wt = Fr ? e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here : e.Diagnostics.Identifier_expected;
                return Vn(79, Rr, P || wt, et);
              }
              function Fi(d) {
                return ni(en(), void 0, d);
              }
              function Tn(d, P) {
                return ni(Ot(), d, P);
              }
              function jn(d) {
                return ni(e.tokenIsIdentifierOrKeyword(L()), d);
              }
              function Ti() {
                return e.tokenIsIdentifierOrKeyword(L()) || L() === 10 || L() === 8;
              }
              function Si() {
                return e.tokenIsIdentifierOrKeyword(L()) || L() === 10;
              }
              function C(d) {
                if (L() === 10 || L() === 8) {
                  var P = ji();
                  return P.text = Ei(P.text), P;
                }
                return d && L() === 22 ? ee() : L() === 80 ? Ze() : jn();
              }
              function W() {
                return C(true);
              }
              function ee() {
                var d = Ae();
                rr(22);
                var P = Vt(pi);
                return rr(23), Ue(r.createComputedPropertyName(P), d);
              }
              function le(d) {
                var P = re.get(d);
                return P === void 0 && re.set(d, P = d), P;
              }
              function Ze() {
                var d = Ae(), P = r.createPrivateIdentifier(le(f.getTokenValue()));
                return fr(), Ue(P, d);
              }
              function Ir(d) {
                return L() === d && Kt(hr);
              }
              function Ar() {
                return fr(), f.hasPrecedingLineBreak() ? false : jt();
              }
              function hr() {
                switch (L()) {
                  case 85:
                    return fr() === 92;
                  case 93:
                    return fr(), L() === 88 ? Gr(Ht) : L() === 154 ? Gr(Pt) : yt();
                  case 88:
                    return Ht();
                  case 127:
                  case 124:
                  case 137:
                  case 151:
                    return fr(), jt();
                  default:
                    return Ar();
                }
              }
              function yt() {
                return L() !== 41 && L() !== 128 && L() !== 18 && jt();
              }
              function Pt() {
                return fr(), yt();
              }
              function Ut() {
                return e.isModifierKind(L()) && Kt(hr);
              }
              function jt() {
                return L() === 22 || L() === 18 || L() === 41 || L() === 25 || Ti();
              }
              function Ht() {
                return fr(), L() === 84 || L() === 98 || L() === 118 || L() === 126 && Gr(p_) || L() === 132 && Gr(f_);
              }
              function gi(d, P) {
                var $2 = Xi(d);
                if ($2)
                  return true;
                switch (d) {
                  case 0:
                  case 1:
                  case 3:
                    return !(L() === 26 && P) && us();
                  case 2:
                    return L() === 82 || L() === 88;
                  case 4:
                    return Gr(Rt);
                  case 5:
                    return Gr(fc) || L() === 26 && !P;
                  case 6:
                    return L() === 22 || Ti();
                  case 12:
                    switch (L()) {
                      case 22:
                      case 41:
                      case 25:
                      case 24:
                        return true;
                      default:
                        return Ti();
                    }
                  case 18:
                    return Ti();
                  case 9:
                    return L() === 22 || L() === 25 || Ti();
                  case 24:
                    return Si();
                  case 7:
                    return L() === 18 ? Gr(Pi) : P ? Ot() && !Zi() : I_() && !Zi();
                  case 8:
                    return h_();
                  case 10:
                    return L() === 27 || L() === 25 || h_();
                  case 19:
                    return L() === 101 || Ot();
                  case 15:
                    switch (L()) {
                      case 27:
                      case 24:
                        return true;
                    }
                  case 11:
                    return L() === 25 || Sa();
                  case 16:
                    return Fa(false);
                  case 17:
                    return Fa(true);
                  case 20:
                  case 21:
                    return L() === 27 || oo();
                  case 22:
                    return bc();
                  case 23:
                    return e.tokenIsIdentifierOrKeyword(L());
                  case 13:
                    return e.tokenIsIdentifierOrKeyword(L()) || L() === 18;
                  case 14:
                    return true;
                }
                return e.Debug.fail("Non-exhaustive case in 'isListElement'.");
              }
              function Pi() {
                if (e.Debug.assert(L() === 18), fr() === 19) {
                  var d = fr();
                  return d === 27 || d === 18 || d === 94 || d === 117;
                }
                return true;
              }
              function Gn() {
                return fr(), Ot();
              }
              function Bi() {
                return fr(), e.tokenIsIdentifierOrKeyword(L());
              }
              function oa() {
                return fr(), e.tokenIsIdentifierOrKeywordOrGreaterThan(L());
              }
              function Zi() {
                return L() === 117 || L() === 94 ? Gr(Ki) : false;
              }
              function Ki() {
                return fr(), Sa();
              }
              function qi() {
                return fr(), oo();
              }
              function Hi(d) {
                if (L() === 1)
                  return true;
                switch (d) {
                  case 1:
                  case 2:
                  case 4:
                  case 5:
                  case 6:
                  case 12:
                  case 9:
                  case 23:
                  case 24:
                    return L() === 19;
                  case 3:
                    return L() === 19 || L() === 82 || L() === 88;
                  case 7:
                    return L() === 18 || L() === 94 || L() === 117;
                  case 8:
                    return Gi();
                  case 19:
                    return L() === 31 || L() === 20 || L() === 18 || L() === 94 || L() === 117;
                  case 11:
                    return L() === 21 || L() === 26;
                  case 15:
                  case 21:
                  case 10:
                    return L() === 23;
                  case 17:
                  case 16:
                  case 18:
                    return L() === 21 || L() === 23;
                  case 20:
                    return L() !== 27;
                  case 22:
                    return L() === 18 || L() === 19;
                  case 13:
                    return L() === 31 || L() === 43;
                  case 14:
                    return L() === 29 && Gr(vu);
                  default:
                    return false;
                }
              }
              function Gi() {
                return !!(ti() || Gs(L()) || L() === 38);
              }
              function da() {
                for (var d = 0; d < 25; d++)
                  if (He & 1 << d && (gi(d, true) || Hi(d)))
                    return true;
                return false;
              }
              function Jn(d, P) {
                var $2 = He;
                He |= 1 << d;
                for (var ce = [], Pe = Ae(); !Hi(d); ) {
                  if (gi(d, false)) {
                    ce.push(ea(d, P));
                    continue;
                  }
                  if (tn(d))
                    break;
                }
                return He = $2, vn(ce, Pe);
              }
              function ea(d, P) {
                var $2 = Xi(d);
                return $2 ? sa($2) : P();
              }
              function Xi(d, P) {
                if (!(!pr || !Li(d) || xt)) {
                  var $2 = pr.currentNode(P != null ? P : f.getStartPos());
                  if (!(e.nodeIsMissing($2) || $2.intersectsChange || e.containsParseError($2))) {
                    var ce = $2.flags & 50720768;
                    if (ce === Yr && p($2, d))
                      return $2.jsDocCache && ($2.jsDocCache = void 0), $2;
                  }
                }
              }
              function sa(d) {
                return f.setTextPos(d.end), fr(), d;
              }
              function Li(d) {
                switch (d) {
                  case 5:
                  case 2:
                  case 0:
                  case 1:
                  case 3:
                  case 6:
                  case 4:
                  case 8:
                  case 17:
                  case 16:
                    return true;
                }
                return false;
              }
              function p(d, P) {
                switch (P) {
                  case 5:
                    return ne(d);
                  case 2:
                    return Ne(d);
                  case 0:
                  case 1:
                  case 3:
                    return or(d);
                  case 6:
                    return it2(d);
                  case 4:
                    return vt(d);
                  case 8:
                    return Tt(d);
                  case 17:
                  case 16:
                    return St(d);
                }
                return false;
              }
              function ne(d) {
                if (d)
                  switch (d.kind) {
                    case 173:
                    case 178:
                    case 174:
                    case 175:
                    case 169:
                    case 237:
                      return true;
                    case 171:
                      var P = d, $2 = P.name.kind === 79 && P.name.originalKeywordKind === 135;
                      return !$2;
                  }
                return false;
              }
              function Ne(d) {
                if (d)
                  switch (d.kind) {
                    case 292:
                    case 293:
                      return true;
                  }
                return false;
              }
              function or(d) {
                if (d)
                  switch (d.kind) {
                    case 259:
                    case 240:
                    case 238:
                    case 242:
                    case 241:
                    case 254:
                    case 250:
                    case 252:
                    case 249:
                    case 248:
                    case 246:
                    case 247:
                    case 245:
                    case 244:
                    case 251:
                    case 239:
                    case 255:
                    case 253:
                    case 243:
                    case 256:
                    case 269:
                    case 268:
                    case 275:
                    case 274:
                    case 264:
                    case 260:
                    case 261:
                    case 263:
                    case 262:
                      return true;
                  }
                return false;
              }
              function it2(d) {
                return d.kind === 302;
              }
              function vt(d) {
                if (d)
                  switch (d.kind) {
                    case 177:
                    case 170:
                    case 178:
                    case 168:
                    case 176:
                      return true;
                  }
                return false;
              }
              function Tt(d) {
                if (d.kind !== 257)
                  return false;
                var P = d;
                return P.initializer === void 0;
              }
              function St(d) {
                if (d.kind !== 166)
                  return false;
                var P = d;
                return P.initializer === void 0;
              }
              function tn(d) {
                return Mt(d), da() ? true : (fr(), false);
              }
              function Mt(d) {
                switch (d) {
                  case 0:
                    return L() === 88 ? gt(e.Diagnostics._0_expected, e.tokenToString(93)) : gt(e.Diagnostics.Declaration_or_statement_expected);
                  case 1:
                    return gt(e.Diagnostics.Declaration_or_statement_expected);
                  case 2:
                    return gt(e.Diagnostics.case_or_default_expected);
                  case 3:
                    return gt(e.Diagnostics.Statement_expected);
                  case 18:
                  case 4:
                    return gt(e.Diagnostics.Property_or_signature_expected);
                  case 5:
                    return gt(e.Diagnostics.Unexpected_token_A_constructor_method_accessor_or_property_was_expected);
                  case 6:
                    return gt(e.Diagnostics.Enum_member_expected);
                  case 7:
                    return gt(e.Diagnostics.Expression_expected);
                  case 8:
                    return e.isKeyword(L()) ? gt(e.Diagnostics._0_is_not_allowed_as_a_variable_declaration_name, e.tokenToString(L())) : gt(e.Diagnostics.Variable_declaration_expected);
                  case 9:
                    return gt(e.Diagnostics.Property_destructuring_pattern_expected);
                  case 10:
                    return gt(e.Diagnostics.Array_element_destructuring_pattern_expected);
                  case 11:
                    return gt(e.Diagnostics.Argument_expression_expected);
                  case 12:
                    return gt(e.Diagnostics.Property_assignment_expected);
                  case 15:
                    return gt(e.Diagnostics.Expression_or_comma_expected);
                  case 17:
                    return gt(e.Diagnostics.Parameter_declaration_expected);
                  case 16:
                    return e.isKeyword(L()) ? gt(e.Diagnostics._0_is_not_allowed_as_a_parameter_name, e.tokenToString(L())) : gt(e.Diagnostics.Parameter_declaration_expected);
                  case 19:
                    return gt(e.Diagnostics.Type_parameter_declaration_expected);
                  case 20:
                    return gt(e.Diagnostics.Type_argument_expected);
                  case 21:
                    return gt(e.Diagnostics.Type_expected);
                  case 22:
                    return gt(e.Diagnostics.Unexpected_token_expected);
                  case 23:
                    return gt(e.Diagnostics.Identifier_expected);
                  case 13:
                    return gt(e.Diagnostics.Identifier_expected);
                  case 14:
                    return gt(e.Diagnostics.Identifier_expected);
                  case 24:
                    return gt(e.Diagnostics.Identifier_or_string_literal_expected);
                  case 25:
                    return e.Debug.fail("ParsingContext.Count used as a context");
                  default:
                    e.Debug.assertNever(d);
                }
              }
              function $t(d, P, $2) {
                var ce = He;
                He |= 1 << d;
                for (var Pe = [], We = Ae(), Er = -1; ; ) {
                  if (gi(d, false)) {
                    var Rr = f.getStartPos(), Fr = ea(d, P);
                    if (!Fr) {
                      He = ce;
                      return;
                    }
                    if (Pe.push(Fr), Er = f.getTokenPos(), Xr(27))
                      continue;
                    if (Er = -1, Hi(d))
                      break;
                    rr(27, y(d)), $2 && L() === 26 && !f.hasPrecedingLineBreak() && fr(), Rr === f.getStartPos() && fr();
                    continue;
                  }
                  if (Hi(d) || tn(d))
                    break;
                }
                return He = ce, vn(Pe, We, void 0, Er >= 0);
              }
              function y(d) {
                return d === 6 ? e.Diagnostics.An_enum_member_name_must_be_followed_by_a_or : void 0;
              }
              function De() {
                var d = vn([], Ae());
                return d.isMissingList = true, d;
              }
              function R(d) {
                return !!d.isMissingList;
              }
              function Jt(d, P, $2, ce) {
                if (rr($2)) {
                  var Pe = $t(d, P);
                  return rr(ce), Pe;
                }
                return De();
              }
              function Qt(d, P) {
                for (var $2 = Ae(), ce = d ? jn(P) : Tn(P), Pe = Ae(); Xr(24); ) {
                  if (L() === 29) {
                    ce.jsdocDotPos = Pe;
                    break;
                  }
                  Pe = Ae(), ce = Ue(r.createQualifiedName(ce, Ni(d, false)), $2);
                }
                return ce;
              }
              function qn(d, P) {
                return Ue(r.createQualifiedName(d, P), d.pos);
              }
              function Ni(d, P) {
                if (f.hasPrecedingLineBreak() && e.tokenIsIdentifierOrKeyword(L())) {
                  var $2 = Gr(cs);
                  if ($2)
                    return Vn(79, true, e.Diagnostics.Identifier_expected);
                }
                if (L() === 80) {
                  var ce = Ze();
                  return P ? ce : Vn(79, true, e.Diagnostics.Identifier_expected);
                }
                return d ? jn() : Tn();
              }
              function _a(d) {
                var P = Ae(), $2 = [], ce;
                do
                  ce = Ui(d), $2.push(ce);
                while (ce.literal.kind === 16);
                return vn($2, P);
              }
              function Ri(d) {
                var P = Ae();
                return Ue(r.createTemplateExpression(ma(d), _a(d)), P);
              }
              function ca() {
                var d = Ae();
                return Ue(r.createTemplateLiteralType(ma(false), $i()), d);
              }
              function $i() {
                var d = Ae(), P = [], $2;
                do
                  $2 = ra(), P.push($2);
                while ($2.literal.kind === 16);
                return vn(P, d);
              }
              function ra() {
                var d = Ae();
                return Ue(r.createTemplateLiteralTypeSpan(Un(), Ea(false)), d);
              }
              function Ea(d) {
                return L() === 19 ? (lr(d), vo()) : mn(17, e.Diagnostics._0_expected, e.tokenToString(19));
              }
              function Ui(d) {
                var P = Ae();
                return Ue(r.createTemplateSpan(Vt(pi), Ea(d)), P);
              }
              function ji() {
                return wa(L());
              }
              function ma(d) {
                d && Vr();
                var P = wa(L());
                return e.Debug.assert(P.kind === 15, "Template head has wrong token kind"), P;
              }
              function vo() {
                var d = wa(L());
                return e.Debug.assert(d.kind === 16 || d.kind === 17, "Template fragment has wrong token kind"), d;
              }
              function Is(d) {
                var P = d === 14 || d === 17, $2 = f.getTokenText();
                return $2.substring(1, $2.length - (f.isUnterminated() ? 0 : P ? 1 : 2));
              }
              function wa(d) {
                var P = Ae(), $2 = e.isTemplateLiteralKind(d) ? r.createTemplateLiteralLikeNode(d, f.getTokenValue(), Is(d), f.getTokenFlags() & 2048) : d === 8 ? r.createNumericLiteral(f.getTokenValue(), f.getNumericLiteralFlags()) : d === 10 ? r.createStringLiteral(f.getTokenValue(), void 0, f.hasExtendedUnicodeEscape()) : e.isLiteralKind(d) ? r.createLiteralLikeNode(d, f.getTokenValue()) : e.Debug.fail();
                return f.hasExtendedUnicodeEscape() && ($2.hasExtendedUnicodeEscape = true), f.isUnterminated() && ($2.isUnterminated = true), fr(), Ue($2, P);
              }
              function Ho() {
                return Qt(true, e.Diagnostics.Type_expected);
              }
              function Ta() {
                if (!f.hasPrecedingLineBreak() && tt() === 29)
                  return Jt(20, Un, 29, 31);
              }
              function Ja() {
                var d = Ae();
                return Ue(r.createTypeReferenceNode(Ho(), Ta()), d);
              }
              function bo(d) {
                switch (d.kind) {
                  case 180:
                    return e.nodeIsMissing(d.typeName);
                  case 181:
                  case 182: {
                    var P = d, $2 = P.parameters, ce = P.type;
                    return R($2) || bo(ce);
                  }
                  case 193:
                    return bo(d.type);
                  default:
                    return false;
                }
              }
              function Eo(d) {
                return fr(), Ue(r.createTypePredicateNode(void 0, d, Un()), d.pos);
              }
              function to() {
                var d = Ae();
                return fr(), Ue(r.createThisTypeNode(), d);
              }
              function Aa() {
                var d = Ae();
                return fr(), Ue(r.createJSDocAllType(), d);
              }
              function To() {
                var d = Ae();
                return fr(), Ue(r.createJSDocNonNullableType(Fs(), false), d);
              }
              function Os() {
                var d = Ae();
                return fr(), L() === 27 || L() === 19 || L() === 21 || L() === 31 || L() === 63 || L() === 51 ? Ue(r.createJSDocUnknownType(), d) : Ue(r.createJSDocNullableType(Un(), false), d);
              }
              function So() {
                var d = Ae(), P = ur();
                if (Gr(bs)) {
                  fr();
                  var $2 = l(36), ce = zi(58, false);
                  return ue(Ue(r.createJSDocFunctionType($2, ce), d), P);
                }
                return Ue(r.createTypeReferenceNode(jn(), void 0), d);
              }
              function Co() {
                var d = Ae(), P;
                return (L() === 108 || L() === 103) && (P = jn(), rr(58)), Ue(r.createParameterDeclaration(void 0, void 0, P, void 0, ka(), void 0), d);
              }
              function ka() {
                f.setInJSDocType(true);
                var d = Ae();
                if (Xr(142)) {
                  var P = r.createJSDocNamepathType(void 0);
                  e:
                    for (; ; )
                      switch (L()) {
                        case 19:
                        case 1:
                        case 27:
                        case 5:
                          break e;
                        default:
                          Le();
                      }
                  return f.setInJSDocType(false), Ue(P, d);
                }
                var $2 = Xr(25), ce = Vs();
                return f.setInJSDocType(false), $2 && (ce = Ue(r.createJSDocVariadicType(ce), d)), L() === 63 ? (fr(), Ue(r.createJSDocOptionalType(ce), d)) : ce;
              }
              function no() {
                var d = Ae();
                rr(112);
                var P = Qt(true), $2 = f.hasPrecedingLineBreak() ? void 0 : vs();
                return Ue(r.createTypeQueryNode(P, $2), d);
              }
              function Go() {
                var d = Ae(), P = Da(), $2 = Tn(), ce, Pe;
                Xr(94) && (oo() || !Sa() ? ce = Un() : Pe = G_());
                var We = Xr(63) ? Un() : void 0, Er = r.createTypeParameterDeclaration(P, $2, ce, We);
                return Er.expression = Pe, Ue(Er, d);
              }
              function Ii() {
                if (L() === 29)
                  return Jt(19, Go, 29, 31);
              }
              function Fa(d) {
                return L() === 25 || h_() || e.isModifierKind(L()) || L() === 59 || oo(!d);
              }
              function io(d) {
                var P = Oa(e.Diagnostics.Private_identifiers_cannot_be_used_as_parameters);
                return e.getFullWidth(P) === 0 && !e.some(d) && e.isModifierKind(L()) && fr(), P;
              }
              function Do() {
                return en() || L() === 22 || L() === 18;
              }
              function xo(d) {
                return $o(d);
              }
              function Xo(d) {
                return $o(d, false);
              }
              function $o(d, P) {
                P === void 0 && (P = true);
                var $2 = Ae(), ce = ur(), Pe = d ? Qn(mo) : Yn(mo);
                if (L() === 108) {
                  var We = r.createParameterDeclaration(Pe, void 0, ni(true), void 0, ua(), void 0);
                  return Pe && On(Pe[0], e.Diagnostics.Decorators_may_not_be_applied_to_this_parameters), ue(Ue(We, $2), ce);
                }
                var Er = Ct;
                Ct = false;
                var Rr = Va(Pe, Da()), Fr = wr(25);
                if (!(!P && !Do())) {
                  var et = ue(Ue(r.createParameterDeclaration(Rr, Fr, io(Rr), wr(57), ua(), Na()), $2), ce);
                  return Ct = Er, et;
                }
              }
              function zi(d, P) {
                if (Ms(d, P))
                  return ei(Vs);
              }
              function Ms(d, P) {
                return d === 38 ? (rr(d), true) : Xr(58) ? true : P && L() === 38 ? (gt(e.Diagnostics._0_expected, e.tokenToString(58)), fr(), true) : false;
              }
              function wo(d, P) {
                var $2 = Kn(), ce = Fn();
                In(!!(d & 1)), hn(!!(d & 2));
                var Pe = d & 32 ? $t(17, Co) : $t(16, function() {
                  return P ? xo(ce) : Xo(ce);
                });
                return In($2), hn(ce), Pe;
              }
              function l(d) {
                if (!rr(20))
                  return De();
                var P = wo(d, true);
                return rr(21), P;
              }
              function A() {
                Xr(27) || Bn();
              }
              function M(d) {
                var P = Ae(), $2 = ur();
                d === 177 && rr(103);
                var ce = Ii(), Pe = l(4), We = zi(58, true);
                A();
                var Er = d === 176 ? r.createCallSignature(ce, Pe, We) : r.createConstructSignature(ce, Pe, We);
                return ue(Ue(Er, P), $2);
              }
              function ke() {
                return L() === 22 && Gr(cr);
              }
              function cr() {
                if (fr(), L() === 25 || L() === 23)
                  return true;
                if (e.isModifierKind(L())) {
                  if (fr(), Ot())
                    return true;
                } else if (Ot())
                  fr();
                else
                  return false;
                return L() === 58 || L() === 27 ? true : L() !== 57 ? false : (fr(), L() === 58 || L() === 27 || L() === 23);
              }
              function Zr(d, P, $2, ce) {
                var Pe = Jt(16, function() {
                  return xo(false);
                }, 22, 23), We = ua();
                A();
                var Er = r.createIndexSignature(ce, Pe, We);
                return Er.illegalDecorators = $2, ue(Ue(Er, d), P);
              }
              function _t(d, P, $2) {
                var ce = W(), Pe = wr(57), We;
                if (L() === 20 || L() === 29) {
                  var Er = Ii(), Rr = l(4), Fr = zi(58, true);
                  We = r.createMethodSignature($2, ce, Pe, Er, Rr, Fr);
                } else {
                  var Fr = ua();
                  We = r.createPropertySignature($2, ce, Pe, Fr), L() === 63 && (We.initializer = Na());
                }
                return A(), ue(Ue(We, d), P);
              }
              function Rt() {
                if (L() === 20 || L() === 29 || L() === 137 || L() === 151)
                  return true;
                for (var d = false; e.isModifierKind(L()); )
                  d = true, fr();
                return L() === 22 ? true : (Ti() && (d = true, fr()), d ? L() === 20 || L() === 29 || L() === 57 || L() === 58 || L() === 27 || ti() : false);
              }
              function un() {
                if (L() === 20 || L() === 29)
                  return M(176);
                if (L() === 103 && Gr(bn))
                  return M(177);
                var d = Ae(), P = ur(), $2 = Da();
                return Ir(137) ? fo(d, P, void 0, $2, 174, 4) : Ir(151) ? fo(d, P, void 0, $2, 175, 4) : ke() ? Zr(d, P, void 0, $2) : _t(d, P, $2);
              }
              function bn() {
                return fr(), L() === 20 || L() === 29;
              }
              function _n() {
                return fr() === 24;
              }
              function Nt() {
                switch (fr()) {
                  case 20:
                  case 29:
                  case 24:
                    return true;
                }
                return false;
              }
              function Ft() {
                var d = Ae();
                return Ue(r.createTypeLiteralNode(Sn()), d);
              }
              function Sn() {
                var d;
                return rr(18) ? (d = Jn(4, un), rr(19)) : d = De(), d;
              }
              function wn() {
                return fr(), L() === 39 || L() === 40 ? fr() === 146 : (L() === 146 && fr(), L() === 22 && Gn() && fr() === 101);
              }
              function Wn() {
                var d = Ae(), P = jn();
                rr(101);
                var $2 = Un();
                return Ue(r.createTypeParameterDeclaration(void 0, P, $2, void 0), d);
              }
              function Ji() {
                var d = Ae();
                rr(18);
                var P;
                (L() === 146 || L() === 39 || L() === 40) && (P = An(), P.kind !== 146 && rr(146)), rr(22);
                var $2 = Wn(), ce = Xr(128) ? Un() : void 0;
                rr(23);
                var Pe;
                (L() === 57 || L() === 39 || L() === 40) && (Pe = An(), Pe.kind !== 57 && rr(57));
                var We = ua();
                Bn();
                var Er = Jn(4, un);
                return rr(19), Ue(r.createMappedTypeNode(P, $2, ce, Pe, We, Er), d);
              }
              function Ba() {
                var d = Ae();
                if (Xr(25))
                  return Ue(r.createRestTypeNode(Un()), d);
                var P = Un();
                if (e.isJSDocNullableType(P) && P.pos === P.type.pos) {
                  var $2 = r.createOptionalTypeNode(P.type);
                  return e.setTextRange($2, P), $2.flags = P.flags, $2;
                }
                return P;
              }
              function Ao() {
                return fr() === 58 || L() === 57 && fr() === 58;
              }
              function ko() {
                return L() === 25 ? e.tokenIsIdentifierOrKeyword(fr()) && Ao() : e.tokenIsIdentifierOrKeyword(L()) && Ao();
              }
              function Po() {
                if (Gr(ko)) {
                  var d = Ae(), P = ur(), $2 = wr(25), ce = jn(), Pe = wr(57);
                  rr(58);
                  var We = Ba(), Er = r.createNamedTupleMember($2, ce, Pe, We);
                  return ue(Ue(Er, d), P);
                }
                return Ba();
              }
              function ao() {
                var d = Ae();
                return Ue(r.createTupleTypeNode(Jt(21, Po, 22, 23)), d);
              }
              function Vc() {
                var d = Ae();
                rr(20);
                var P = Un();
                return rr(21), Ue(r.createParenthesizedType(P), d);
              }
              function Ls() {
                var d;
                if (L() === 126) {
                  var P = Ae();
                  fr();
                  var $2 = Ue(r.createToken(126), P);
                  d = vn([$2], P);
                }
                return d;
              }
              function No() {
                var d = Ae(), P = ur(), $2 = Ls(), ce = Xr(103), Pe = Ii(), We = l(4), Er = zi(38, false), Rr = ce ? r.createConstructorTypeNode($2, Pe, We, Er) : r.createFunctionTypeNode(Pe, We, Er);
                return ce || (Rr.modifiers = $2), ue(Ue(Rr, d), P);
              }
              function Rs() {
                var d = An();
                return L() === 24 ? void 0 : d;
              }
              function Qo(d) {
                var P = Ae();
                d && fr();
                var $2 = L() === 110 || L() === 95 || L() === 104 ? An() : wa(L());
                return d && ($2 = Ue(r.createPrefixUnaryExpression(40, $2), P)), Ue(r.createLiteralTypeNode($2), P);
              }
              function Yo() {
                return fr(), L() === 100;
              }
              function w_() {
                var d = Ae(), P = f.getTokenPos();
                rr(18);
                var $2 = f.hasPrecedingLineBreak();
                rr(130), rr(58);
                var ce = T_(true);
                if (!rr(19)) {
                  var Pe = e.lastOrUndefined(vr);
                  Pe && Pe.code === e.Diagnostics._0_expected.code && e.addRelatedInfo(Pe, e.createDetachedDiagnostic(ct, P, 1, e.Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                }
                return Ue(r.createImportTypeAssertionContainer(ce, $2), d);
              }
              function js() {
                ft |= 2097152;
                var d = Ae(), P = Xr(112);
                rr(100), rr(20);
                var $2 = Un(), ce;
                Xr(27) && (ce = w_()), rr(21);
                var Pe = Xr(24) ? Ho() : void 0, We = Ta();
                return Ue(r.createImportTypeNode($2, ce, Pe, We, P), d);
              }
              function Js() {
                return fr(), L() === 8 || L() === 9;
              }
              function Fs() {
                switch (L()) {
                  case 131:
                  case 157:
                  case 152:
                  case 148:
                  case 160:
                  case 153:
                  case 134:
                  case 155:
                  case 144:
                  case 149:
                    return Kt(Rs) || Ja();
                  case 66:
                    f.reScanAsteriskEqualsToken();
                  case 41:
                    return Aa();
                  case 60:
                    f.reScanQuestionToken();
                  case 57:
                    return Os();
                  case 98:
                    return So();
                  case 53:
                    return To();
                  case 14:
                  case 10:
                  case 8:
                  case 9:
                  case 110:
                  case 95:
                  case 104:
                    return Qo();
                  case 40:
                    return Gr(Js) ? Qo(true) : Ja();
                  case 114:
                    return An();
                  case 108: {
                    var d = to();
                    return L() === 140 && !f.hasPrecedingLineBreak() ? Eo(d) : d;
                  }
                  case 112:
                    return Gr(Yo) ? js() : no();
                  case 18:
                    return Gr(wn) ? Ji() : Ft();
                  case 22:
                    return ao();
                  case 20:
                    return Vc();
                  case 100:
                    return js();
                  case 129:
                    return Gr(cs) ? Gc() : Ja();
                  case 15:
                    return ca();
                  default:
                    return Ja();
                }
              }
              function oo(d) {
                switch (L()) {
                  case 131:
                  case 157:
                  case 152:
                  case 148:
                  case 160:
                  case 134:
                  case 146:
                  case 153:
                  case 156:
                  case 114:
                  case 155:
                  case 104:
                  case 108:
                  case 112:
                  case 144:
                  case 18:
                  case 22:
                  case 29:
                  case 51:
                  case 50:
                  case 103:
                  case 10:
                  case 8:
                  case 9:
                  case 110:
                  case 95:
                  case 149:
                  case 41:
                  case 57:
                  case 53:
                  case 25:
                  case 138:
                  case 100:
                  case 129:
                  case 14:
                  case 15:
                    return true;
                  case 98:
                    return !d;
                  case 40:
                    return !d && Gr(Js);
                  case 20:
                    return !d && Gr(A_);
                  default:
                    return Ot();
                }
              }
              function A_() {
                return fr(), L() === 21 || Fa(false) || oo();
              }
              function Wc() {
                for (var d = Ae(), P = Fs(); !f.hasPrecedingLineBreak(); )
                  switch (L()) {
                    case 53:
                      fr(), P = Ue(r.createJSDocNonNullableType(P, true), d);
                      break;
                    case 57:
                      if (Gr(qi))
                        return P;
                      fr(), P = Ue(r.createJSDocNullableType(P, true), d);
                      break;
                    case 22:
                      if (rr(22), oo()) {
                        var $2 = Un();
                        rr(23), P = Ue(r.createIndexedAccessTypeNode(P, $2), d);
                      } else
                        rr(23), P = Ue(r.createArrayTypeNode(P), d);
                      break;
                    default:
                      return P;
                  }
                return P;
              }
              function Kc(d) {
                var P = Ae();
                return rr(d), Ue(r.createTypeOperatorNode(d, qs()), P);
              }
              function Bs() {
                if (Xr(94)) {
                  var d = hi(Un);
                  if (di() || L() !== 57)
                    return d;
                }
              }
              function Pa() {
                var d = Ae(), P = Tn(), $2 = Kt(Bs), ce = r.createTypeParameterDeclaration(void 0, P, $2);
                return Ue(ce, d);
              }
              function Io() {
                var d = Ae();
                return rr(138), Ue(r.createInferTypeNode(Pa()), d);
              }
              function qs() {
                var d = L();
                switch (d) {
                  case 141:
                  case 156:
                  case 146:
                    return Kc(d);
                  case 138:
                    return Io();
                }
                return ei(Wc);
              }
              function Oo(d) {
                if (zs()) {
                  var P = No(), $2 = void 0;
                  return e.isFunctionTypeNode(P) ? $2 = d ? e.Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_a_union_type : e.Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type : $2 = d ? e.Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type : e.Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type, On(P, $2), P;
                }
              }
              function so(d, P, $2) {
                var ce = Ae(), Pe = d === 51, We = Xr(d), Er = We && Oo(Pe) || P();
                if (L() === d || We) {
                  for (var Rr = [Er]; Xr(d); )
                    Rr.push(Oo(Pe) || P());
                  Er = Ue($2(vn(Rr, ce)), ce);
                }
                return Er;
              }
              function Us() {
                return so(50, qs, r.createIntersectionTypeNode);
              }
              function Zo() {
                return so(51, Us, r.createUnionTypeNode);
              }
              function k_() {
                return fr(), L() === 103;
              }
              function zs() {
                return L() === 29 || L() === 20 && Gr(Hc) ? true : L() === 103 || L() === 126 && Gr(k_);
              }
              function P_() {
                if (e.isModifierKind(L()) && Da(), Ot() || L() === 108)
                  return fr(), true;
                if (L() === 22 || L() === 18) {
                  var d = vr.length;
                  return Oa(), d === vr.length;
                }
                return false;
              }
              function Hc() {
                return fr(), !!(L() === 21 || L() === 25 || P_() && (L() === 58 || L() === 27 || L() === 57 || L() === 63 || L() === 21 && (fr(), L() === 38)));
              }
              function Vs() {
                var d = Ae(), P = Ot() && Kt(N_), $2 = Un();
                return P ? Ue(r.createTypePredicateNode(void 0, P, $2), d) : $2;
              }
              function N_() {
                var d = Tn();
                if (L() === 140 && !f.hasPrecedingLineBreak())
                  return fr(), d;
              }
              function Gc() {
                var d = Ae(), P = mn(129), $2 = L() === 108 ? to() : Tn(), ce = Xr(140) ? Un() : void 0;
                return Ue(r.createTypePredicateNode(P, $2, ce), d);
              }
              function Un() {
                if (Yr & 40960)
                  return ln(40960, Un);
                if (zs())
                  return No();
                var d = Ae(), P = Zo();
                if (!di() && !f.hasPrecedingLineBreak() && Xr(94)) {
                  var $2 = hi(Un);
                  rr(57);
                  var ce = ei(Un);
                  rr(58);
                  var Pe = ei(Un);
                  return Ue(r.createConditionalTypeNode(P, $2, ce, Pe), d);
                }
                return P;
              }
              function ua() {
                return Xr(58) ? Un() : void 0;
              }
              function I_() {
                switch (L()) {
                  case 108:
                  case 106:
                  case 104:
                  case 110:
                  case 95:
                  case 8:
                  case 9:
                  case 10:
                  case 14:
                  case 15:
                  case 20:
                  case 22:
                  case 18:
                  case 98:
                  case 84:
                  case 103:
                  case 43:
                  case 68:
                  case 79:
                    return true;
                  case 100:
                    return Gr(Nt);
                  default:
                    return Ot();
                }
              }
              function Sa() {
                if (I_())
                  return true;
                switch (L()) {
                  case 39:
                  case 40:
                  case 54:
                  case 53:
                  case 89:
                  case 112:
                  case 114:
                  case 45:
                  case 46:
                  case 29:
                  case 133:
                  case 125:
                  case 80:
                    return true;
                  default:
                    return Lo() ? true : Ot();
                }
              }
              function O_() {
                return L() !== 18 && L() !== 98 && L() !== 84 && L() !== 59 && Sa();
              }
              function pi() {
                var d = Zn();
                d && yn(false);
                for (var P = Ae(), $2 = wi(true), ce; ce = wr(27); )
                  $2 = _o($2, ce, wi(true), P);
                return d && yn(true), $2;
              }
              function Na() {
                return Xr(63) ? wi(true) : void 0;
              }
              function wi(d) {
                if (M_())
                  return L_();
                var P = R_(d) || F_(d);
                if (P)
                  return P;
                var $2 = Ae(), ce = Mo(0);
                return ce.kind === 79 && L() === 38 ? Ks($2, ce, d, void 0) : e.isLeftHandSideExpression(ce) && e.isAssignmentOperator(Ve()) ? _o(ce, An(), wi(d), $2) : $c(ce, $2, d);
              }
              function M_() {
                return L() === 125 ? Kn() ? true : Gr(Fo) : false;
              }
              function Ws() {
                return fr(), !f.hasPrecedingLineBreak() && Ot();
              }
              function L_() {
                var d = Ae();
                return fr(), !f.hasPrecedingLineBreak() && (L() === 41 || Sa()) ? Ue(r.createYieldExpression(wr(41), wi(true)), d) : Ue(r.createYieldExpression(void 0, void 0), d);
              }
              function Ks(d, P, $2, ce) {
                e.Debug.assert(L() === 38, "parseSimpleArrowFunctionExpression should only have been called if we had a =>");
                var Pe = r.createParameterDeclaration(void 0, void 0, P, void 0, void 0, void 0);
                Ue(Pe, P.pos);
                var We = vn([Pe], Pe.pos, Pe.end), Er = mn(38), Rr = Hs(!!ce, $2), Fr = r.createArrowFunction(ce, void 0, We, void 0, Er, Rr);
                return Sr(Ue(Fr, d));
              }
              function R_(d) {
                var P = j_();
                if (P !== 0)
                  return P === 1 ? q_(true, true) : Kt(function() {
                    return Xc(d);
                  });
              }
              function j_() {
                return L() === 20 || L() === 29 || L() === 132 ? Gr(J_) : L() === 38 ? 1 : 0;
              }
              function J_() {
                if (L() === 132 && (fr(), f.hasPrecedingLineBreak() || L() !== 20 && L() !== 29))
                  return 0;
                var d = L(), P = fr();
                if (d === 20) {
                  if (P === 21) {
                    var $2 = fr();
                    switch ($2) {
                      case 38:
                      case 58:
                      case 18:
                        return 1;
                      default:
                        return 0;
                    }
                  }
                  if (P === 22 || P === 18)
                    return 2;
                  if (P === 25)
                    return 1;
                  if (e.isModifierKind(P) && P !== 132 && Gr(Gn))
                    return fr() === 128 ? 0 : 1;
                  if (!Ot() && P !== 108)
                    return 0;
                  switch (fr()) {
                    case 58:
                      return 1;
                    case 57:
                      return fr(), L() === 58 || L() === 27 || L() === 63 || L() === 21 ? 1 : 0;
                    case 27:
                    case 63:
                    case 21:
                      return 2;
                  }
                  return 0;
                } else {
                  if (e.Debug.assert(d === 29), !Ot())
                    return 0;
                  if (Ye === 1) {
                    var ce = Gr(function() {
                      var Pe = fr();
                      if (Pe === 94) {
                        var We = fr();
                        switch (We) {
                          case 63:
                          case 31:
                            return false;
                          default:
                            return true;
                        }
                      } else if (Pe === 27 || Pe === 63)
                        return true;
                      return false;
                    });
                    return ce ? 1 : 0;
                  }
                  return 2;
                }
              }
              function Xc(d) {
                var P = f.getTokenPos();
                if (!(Nr != null && Nr.has(P))) {
                  var $2 = q_(false, d);
                  return $2 || (Nr || (Nr = new e.Set())).add(P), $2;
                }
              }
              function F_(d) {
                if (L() === 132 && Gr(B_) === 1) {
                  var P = Ae(), $2 = mc(), ce = Mo(0);
                  return Ks(P, ce, d, $2);
                }
              }
              function B_() {
                if (L() === 132) {
                  if (fr(), f.hasPrecedingLineBreak() || L() === 38)
                    return 0;
                  var d = Mo(0);
                  if (!f.hasPrecedingLineBreak() && d.kind === 79 && L() === 38)
                    return 1;
                }
                return 0;
              }
              function q_(d, P) {
                var $2 = Ae(), ce = ur(), Pe = mc(), We = e.some(Pe, e.isAsyncModifier) ? 2 : 0, Er = Ii(), Rr;
                if (rr(20)) {
                  if (d)
                    Rr = wo(We, d);
                  else {
                    var Fr = wo(We, d);
                    if (!Fr)
                      return;
                    Rr = Fr;
                  }
                  if (!rr(21) && !d)
                    return;
                } else {
                  if (!d)
                    return;
                  Rr = De();
                }
                var et = L() === 58, wt = zi(58, false);
                if (!(wt && !d && bo(wt))) {
                  for (var Gt = wt; (Gt == null ? void 0 : Gt.kind) === 193; )
                    Gt = Gt.type;
                  var Wt = Gt && e.isJSDocFunctionType(Gt);
                  if (!(!d && L() !== 38 && (Wt || L() !== 18))) {
                    var pn = L(), Pn = mn(38), _i = pn === 38 || pn === 18 ? Hs(e.some(Pe, e.isAsyncModifier), P) : Tn();
                    if (!(!P && et && L() !== 58)) {
                      var Ln = r.createArrowFunction(Pe, Er, Rr, wt, Pn, _i);
                      return ue(Ue(Ln, $2), ce);
                    }
                  }
                }
              }
              function Hs(d, P) {
                if (L() === 18)
                  return Jo(d ? 2 : 0);
                if (L() !== 26 && L() !== 98 && L() !== 84 && us() && !O_())
                  return Jo(16 | (d ? 2 : 0));
                var $2 = Ct;
                Ct = false;
                var ce = d ? Qn(function() {
                  return wi(P);
                }) : Yn(function() {
                  return wi(P);
                });
                return Ct = $2, ce;
              }
              function $c(d, P, $2) {
                var ce = wr(57);
                if (!ce)
                  return d;
                var Pe;
                return Ue(r.createConditionalExpression(d, ce, ln(h, function() {
                  return wi(false);
                }), Pe = mn(58), e.nodeIsPresent(Pe) ? wi($2) : Vn(79, false, e.Diagnostics._0_expected, e.tokenToString(58))), P);
              }
              function Mo(d) {
                var P = Ae(), $2 = G_();
                return Xs(d, $2, P);
              }
              function Gs(d) {
                return d === 101 || d === 162;
              }
              function Xs(d, P, $2) {
                for (; ; ) {
                  Ve();
                  var ce = e.getBinaryOperatorPrecedence(L()), Pe = L() === 42 ? ce >= d : ce > d;
                  if (!Pe || L() === 101 && si())
                    break;
                  if (L() === 128 || L() === 150) {
                    if (f.hasPrecedingLineBreak())
                      break;
                    var We = L();
                    fr(), P = We === 150 ? $s(P, Un()) : U_(P, Un());
                  } else
                    P = _o(P, An(), Mo(ce), $2);
                }
                return P;
              }
              function Lo() {
                return si() && L() === 101 ? false : e.getBinaryOperatorPrecedence(L()) > 0;
              }
              function $s(d, P) {
                return Ue(r.createSatisfiesExpression(d, P), d.pos);
              }
              function _o(d, P, $2, ce) {
                return Ue(r.createBinaryExpression(d, P, $2), ce);
              }
              function U_(d, P) {
                return Ue(r.createAsExpression(d, P), d.pos);
              }
              function z_() {
                var d = Ae();
                return Ue(r.createPrefixUnaryExpression(L(), nn(Ca)), d);
              }
              function V_() {
                var d = Ae();
                return Ue(r.createDeleteExpression(nn(Ca)), d);
              }
              function Qc() {
                var d = Ae();
                return Ue(r.createTypeOfExpression(nn(Ca)), d);
              }
              function W_() {
                var d = Ae();
                return Ue(r.createVoidExpression(nn(Ca)), d);
              }
              function K_() {
                return L() === 133 ? Fn() ? true : Gr(Fo) : false;
              }
              function H_() {
                var d = Ae();
                return Ue(r.createAwaitExpression(nn(Ca)), d);
              }
              function G_() {
                if (qa()) {
                  var d = Ae(), P = es();
                  return L() === 42 ? Xs(e.getBinaryOperatorPrecedence(L()), P, d) : P;
                }
                var $2 = L(), ce = Ca();
                if (L() === 42) {
                  var d = e.skipTrivia(Ie, ce.pos), Pe = ce.end;
                  ce.kind === 213 ? dn(d, Pe, e.Diagnostics.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses) : dn(d, Pe, e.Diagnostics.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses, e.tokenToString($2));
                }
                return ce;
              }
              function Ca() {
                switch (L()) {
                  case 39:
                  case 40:
                  case 54:
                  case 53:
                    return z_();
                  case 89:
                    return V_();
                  case 112:
                    return Qc();
                  case 114:
                    return W_();
                  case 29:
                    return eu();
                  case 133:
                    if (K_())
                      return H_();
                  default:
                    return es();
                }
              }
              function qa() {
                switch (L()) {
                  case 39:
                  case 40:
                  case 54:
                  case 53:
                  case 89:
                  case 112:
                  case 114:
                  case 133:
                    return false;
                  case 29:
                    if (Ye !== 1)
                      return false;
                  default:
                    return true;
                }
              }
              function es() {
                if (L() === 45 || L() === 46) {
                  var d = Ae();
                  return Ue(r.createPrefixUnaryExpression(L(), nn(ta)), d);
                } else if (Ye === 1 && L() === 29 && Gr(oa))
                  return co(true);
                var P = ta();
                if (e.Debug.assert(e.isLeftHandSideExpression(P)), (L() === 45 || L() === 46) && !f.hasPrecedingLineBreak()) {
                  var $2 = L();
                  return fr(), Ue(r.createPostfixUnaryExpression(P, $2), P.pos);
                }
                return P;
              }
              function ta() {
                var d = Ae(), P;
                return L() === 100 ? Gr(bn) ? (ft |= 2097152, P = An()) : Gr(_n) ? (fr(), fr(), P = Ue(r.createMetaProperty(100, jn()), d), ft |= 4194304) : P = Qs() : P = L() === 106 ? Yc() : Qs(), la(d, P);
              }
              function Qs() {
                var d = Ae(), P = i_();
                return jo(d, P, true);
              }
              function Yc() {
                var d = Ae(), P = An();
                if (L() === 29) {
                  var $2 = Ae(), ce = Kt(uo);
                  ce !== void 0 && (dn($2, Ae(), e.Diagnostics.super_may_not_use_type_arguments), na() || (P = r.createExpressionWithTypeArguments(P, ce)));
                }
                return L() === 20 || L() === 24 || L() === 22 ? P : (mn(24, e.Diagnostics.super_must_be_followed_by_an_argument_list_or_member_access), Ue(r.createPropertyAccessExpression(P, Ni(true, true)), d));
              }
              function co(d, P, $2) {
                var ce = Ae(), Pe = Q_(d), We;
                if (Pe.kind === 283) {
                  var Er = Zs(Pe), Rr = void 0, Fr = Er[Er.length - 1];
                  if ((Fr == null ? void 0 : Fr.kind) === 281 && !rt(Fr.openingElement.tagName, Fr.closingElement.tagName) && rt(Pe.tagName, Fr.closingElement.tagName)) {
                    var et = Fr.children.end, wt = Ue(r.createJsxElement(Fr.openingElement, Fr.children, Ue(r.createJsxClosingElement(Ue(r.createIdentifier(""), et, et)), et, et)), Fr.openingElement.pos, et);
                    Er = vn(D(D([], Er.slice(0, Er.length - 1), true), [wt], false), Er.pos, et), Rr = Fr.closingElement;
                  } else
                    Rr = Zc(Pe, d), rt(Pe.tagName, Rr.tagName) || ($2 && e.isJsxOpeningElement($2) && rt(Rr.tagName, $2.tagName) ? On(Pe.tagName, e.Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, e.getTextOfNodeFromSourceText(Ie, Pe.tagName)) : On(Rr.tagName, e.Diagnostics.Expected_corresponding_JSX_closing_tag_for_0, e.getTextOfNodeFromSourceText(Ie, Pe.tagName)));
                  We = Ue(r.createJsxElement(Pe, Er, Rr), ce);
                } else
                  Pe.kind === 286 ? We = Ue(r.createJsxFragment(Pe, Zs(Pe), e_(d)), ce) : (e.Debug.assert(Pe.kind === 282), We = Pe);
                if (d && L() === 29) {
                  var Gt = typeof P > "u" ? We.pos : P, Wt = Kt(function() {
                    return co(true, Gt);
                  });
                  if (Wt) {
                    var pn = Vn(27, false);
                    return e.setTextRangePosWidth(pn, Wt.pos, 0), dn(e.skipTrivia(Ie, Gt), Wt.end, e.Diagnostics.JSX_expressions_must_have_one_parent_element), Ue(r.createBinaryExpression(We, pn, Wt), ce);
                  }
                }
                return We;
              }
              function X_() {
                var d = Ae(), P = r.createJsxText(f.getTokenValue(), Mr === 12);
                return Mr = f.scanJsxToken(), Ue(P, d);
              }
              function Ys(d, P) {
                switch (P) {
                  case 1:
                    if (e.isJsxOpeningFragment(d))
                      On(d, e.Diagnostics.JSX_fragment_has_no_corresponding_closing_tag);
                    else {
                      var $2 = d.tagName, ce = e.skipTrivia(Ie, $2.pos);
                      dn(ce, $2.end, e.Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, e.getTextOfNodeFromSourceText(Ie, d.tagName));
                    }
                    return;
                  case 30:
                  case 7:
                    return;
                  case 11:
                  case 12:
                    return X_();
                  case 18:
                    return Y_(false);
                  case 29:
                    return co(false, void 0, d);
                  default:
                    return e.Debug.assertNever(P);
                }
              }
              function Zs(d) {
                var P = [], $2 = Ae(), ce = He;
                for (He |= 1 << 14; ; ) {
                  var Pe = Ys(d, Mr = f.reScanJsxToken());
                  if (!Pe || (P.push(Pe), e.isJsxOpeningElement(d) && (Pe == null ? void 0 : Pe.kind) === 281 && !rt(Pe.openingElement.tagName, Pe.closingElement.tagName) && rt(d.tagName, Pe.closingElement.tagName)))
                    break;
                }
                return He = ce, vn(P, $2);
              }
              function $_() {
                var d = Ae();
                return Ue(r.createJsxAttributes(Jn(13, Z_)), d);
              }
              function Q_(d) {
                var P = Ae();
                if (rr(29), L() === 31)
                  return an(), Ue(r.createJsxOpeningFragment(), P);
                var $2 = rs(), ce = Yr & 262144 ? void 0 : vs(), Pe = $_(), We;
                return L() === 31 ? (an(), We = r.createJsxOpeningElement($2, ce, Pe)) : (rr(43), rr(31, void 0, false) && (d ? fr() : an()), We = r.createJsxSelfClosingElement($2, ce, Pe)), Ue(We, P);
              }
              function rs() {
                var d = Ae();
                It();
                for (var P = L() === 108 ? An() : jn(); Xr(24); )
                  P = Ue(r.createPropertyAccessExpression(P, Ni(true, false)), d);
                return P;
              }
              function Y_(d) {
                var P = Ae();
                if (rr(18)) {
                  var $2, ce;
                  return L() !== 19 && ($2 = wr(25), ce = pi()), d ? rr(19) : rr(19, void 0, false) && an(), Ue(r.createJsxExpression($2, ce), P);
                }
              }
              function Z_() {
                if (L() === 18)
                  return ec();
                It();
                var d = Ae();
                return Ue(r.createJsxAttribute(jn(), ts()), d);
              }
              function ts() {
                if (L() === 63) {
                  if (sn() === 10)
                    return ji();
                  if (L() === 18)
                    return Y_(true);
                  if (L() === 29)
                    return co(true);
                  gt(e.Diagnostics.or_JSX_element_expected);
                }
              }
              function ec() {
                var d = Ae();
                rr(18), rr(25);
                var P = pi();
                return rr(19), Ue(r.createJsxSpreadAttribute(P), d);
              }
              function Zc(d, P) {
                var $2 = Ae();
                rr(30);
                var ce = rs();
                return rr(31, void 0, false) && (P || !rt(d.tagName, ce) ? fr() : an()), Ue(r.createJsxClosingElement(ce), $2);
              }
              function e_(d) {
                var P = Ae();
                return rr(30), e.tokenIsIdentifierOrKeyword(L()) && On(rs(), e.Diagnostics.Expected_corresponding_closing_tag_for_JSX_fragment), rr(31, void 0, false) && (d ? fr() : an()), Ue(r.createJsxJsxClosingFragment(), P);
              }
              function eu() {
                var d = Ae();
                rr(29);
                var P = Un();
                rr(31);
                var $2 = Ca();
                return Ue(r.createTypeAssertion(P, $2), d);
              }
              function rc() {
                return fr(), e.tokenIsIdentifierOrKeyword(L()) || L() === 22 || na();
              }
              function r_() {
                return L() === 28 && Gr(rc);
              }
              function Ro(d) {
                if (d.flags & 32)
                  return true;
                if (e.isNonNullExpression(d)) {
                  for (var P = d.expression; e.isNonNullExpression(P) && !(P.flags & 32); )
                    P = P.expression;
                  if (P.flags & 32) {
                    for (; e.isNonNullExpression(d); )
                      d.flags |= 32, d = d.expression;
                    return true;
                  }
                }
                return false;
              }
              function t_(d, P, $2) {
                var ce = Ni(true, true), Pe = $2 || Ro(P), We = Pe ? r.createPropertyAccessChain(P, $2, ce) : r.createPropertyAccessExpression(P, ce);
                if (Pe && e.isPrivateIdentifier(We.name) && On(We.name, e.Diagnostics.An_optional_chain_cannot_contain_private_identifiers), e.isExpressionWithTypeArguments(P) && P.typeArguments) {
                  var Er = P.typeArguments.pos - 1, Rr = e.skipTrivia(Ie, P.typeArguments.end) + 1;
                  dn(Er, Rr, e.Diagnostics.An_instantiation_expression_cannot_be_followed_by_a_property_access);
                }
                return Ue(We, d);
              }
              function tc(d, P, $2) {
                var ce;
                if (L() === 23)
                  ce = Vn(79, true, e.Diagnostics.An_element_access_expression_should_take_an_argument);
                else {
                  var Pe = Vt(pi);
                  e.isStringOrNumericLiteralLike(Pe) && (Pe.text = Ei(Pe.text)), ce = Pe;
                }
                rr(23);
                var We = $2 || Ro(P) ? r.createElementAccessChain(P, $2, ce) : r.createElementAccessExpression(P, ce);
                return Ue(We, d);
              }
              function jo(d, P, $2) {
                for (; ; ) {
                  var ce = void 0, Pe = false;
                  if ($2 && r_() ? (ce = mn(28), Pe = e.tokenIsIdentifierOrKeyword(L())) : Pe = Xr(24), Pe) {
                    P = t_(d, P, ce);
                    continue;
                  }
                  if ((ce || !Zn()) && Xr(22)) {
                    P = tc(d, P, ce);
                    continue;
                  }
                  if (na()) {
                    P = !ce && P.kind === 230 ? Qi(d, P.expression, ce, P.typeArguments) : Qi(d, P, ce, void 0);
                    continue;
                  }
                  if (!ce) {
                    if (L() === 53 && !f.hasPrecedingLineBreak()) {
                      fr(), P = Ue(r.createNonNullExpression(P), d);
                      continue;
                    }
                    var We = Kt(uo);
                    if (We) {
                      P = Ue(r.createExpressionWithTypeArguments(P, We), d);
                      continue;
                    }
                  }
                  return P;
                }
              }
              function na() {
                return L() === 14 || L() === 15;
              }
              function Qi(d, P, $2, ce) {
                var Pe = r.createTaggedTemplateExpression(P, ce, L() === 14 ? (Vr(), ji()) : Ri(true));
                return ($2 || P.flags & 32) && (Pe.flags |= 32), Pe.questionDotToken = $2, Ue(Pe, d);
              }
              function la(d, P) {
                for (; ; ) {
                  P = jo(d, P, true);
                  var $2 = void 0, ce = wr(28);
                  if (ce && ($2 = Kt(uo), na())) {
                    P = Qi(d, P, ce, $2);
                    continue;
                  }
                  if ($2 || L() === 20) {
                    !ce && P.kind === 230 && ($2 = P.typeArguments, P = P.expression);
                    var Pe = n_(), We = ce || Ro(P) ? r.createCallChain(P, ce, $2, Pe) : r.createCallExpression(P, $2, Pe);
                    P = Ue(We, d);
                    continue;
                  }
                  if (ce) {
                    var Er = Vn(79, false, e.Diagnostics.Identifier_expected);
                    P = Ue(r.createPropertyAccessChain(P, ce, Er), d);
                  }
                  break;
                }
                return P;
              }
              function n_() {
                rr(20);
                var d = $t(11, a_);
                return rr(21), d;
              }
              function uo() {
                if (!(Yr & 262144) && tt() === 29) {
                  fr();
                  var d = $t(20, Un);
                  if (Ve() === 31)
                    return fr(), d && ru() ? d : void 0;
                }
              }
              function ru() {
                switch (L()) {
                  case 20:
                  case 14:
                  case 15:
                    return true;
                  case 29:
                  case 31:
                  case 39:
                  case 40:
                    return false;
                }
                return f.hasPrecedingLineBreak() || Lo() || !Sa();
              }
              function i_() {
                switch (L()) {
                  case 8:
                  case 9:
                  case 10:
                  case 14:
                    return ji();
                  case 108:
                  case 106:
                  case 104:
                  case 110:
                  case 95:
                    return An();
                  case 20:
                    return ns();
                  case 22:
                    return ic();
                  case 18:
                    return o_();
                  case 132:
                    if (!Gr(f_))
                      break;
                    return s_();
                  case 84:
                    return yc();
                  case 98:
                    return s_();
                  case 103:
                    return tu();
                  case 43:
                  case 68:
                    if (_r() === 13)
                      return ji();
                    break;
                  case 15:
                    return Ri(false);
                  case 80:
                    return Ze();
                }
                return Tn(e.Diagnostics.Expression_expected);
              }
              function ns() {
                var d = Ae(), P = ur();
                rr(20);
                var $2 = Vt(pi);
                return rr(21), ue(Ue(r.createParenthesizedExpression($2), d), P);
              }
              function is() {
                var d = Ae();
                rr(25);
                var P = wi(true);
                return Ue(r.createSpreadElement(P), d);
              }
              function nc() {
                return L() === 25 ? is() : L() === 27 ? Ue(r.createOmittedExpression(), Ae()) : wi(true);
              }
              function a_() {
                return ln(h, nc);
              }
              function ic() {
                var d = Ae(), P = f.getTokenPos(), $2 = rr(22), ce = f.hasPrecedingLineBreak(), Pe = $t(15, nc);
                return on(22, 23, $2, P), Ue(r.createArrayLiteralExpression(Pe, ce), d);
              }
              function as() {
                var d = Ae(), P = ur();
                if (wr(25)) {
                  var $2 = wi(true);
                  return ue(Ue(r.createSpreadAssignment($2), d), P);
                }
                var ce = mo(), Pe = Da();
                if (Ir(137))
                  return fo(d, P, ce, Pe, 174, 0);
                if (Ir(151))
                  return fo(d, P, ce, Pe, 175, 0);
                var We = wr(41), Er = Ot(), Rr = W(), Fr = wr(57), et = wr(53);
                if (We || L() === 20 || L() === 29)
                  return lc(d, P, ce, Pe, We, Rr, Fr, et);
                var wt, Gt = Er && L() !== 58;
                if (Gt) {
                  var Wt = wr(63), pn = Wt ? Vt(function() {
                    return wi(true);
                  }) : void 0;
                  wt = r.createShorthandPropertyAssignment(Rr, pn), wt.equalsToken = Wt;
                } else {
                  rr(58);
                  var Pn = Vt(function() {
                    return wi(true);
                  });
                  wt = r.createPropertyAssignment(Rr, Pn);
                }
                return wt.illegalDecorators = ce, wt.modifiers = Pe, wt.questionToken = Fr, wt.exclamationToken = et, ue(Ue(wt, d), P);
              }
              function o_() {
                var d = Ae(), P = f.getTokenPos(), $2 = rr(18), ce = f.hasPrecedingLineBreak(), Pe = $t(12, as, true);
                return on(18, 19, $2, P), Ue(r.createObjectLiteralExpression(Pe, ce), d);
              }
              function s_() {
                var d = Zn();
                yn(false);
                var P = Ae(), $2 = ur(), ce = Da();
                rr(98);
                var Pe = wr(41), We = Pe ? 1 : 0, Er = e.some(ce, e.isAsyncModifier) ? 2 : 0, Rr = We && Er ? oi(lo) : We ? ri(lo) : Er ? Qn(lo) : lo(), Fr = Ii(), et = l(We | Er), wt = zi(58, false), Gt = Jo(We | Er);
                yn(d);
                var Wt = r.createFunctionExpression(ce, Pe, Rr, Fr, et, wt, Gt);
                return ue(Ue(Wt, P), $2);
              }
              function lo() {
                return en() ? Fi() : void 0;
              }
              function tu() {
                var d = Ae();
                if (rr(103), Xr(24)) {
                  var P = jn();
                  return Ue(r.createMetaProperty(103, P), d);
                }
                var $2 = Ae(), ce = jo($2, i_(), false), Pe;
                ce.kind === 230 && (Pe = ce.typeArguments, ce = ce.expression), L() === 28 && gt(e.Diagnostics.Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0, e.getTextOfNodeFromSourceText(Ie, ce));
                var We = L() === 20 ? n_() : void 0;
                return Ue(r.createNewExpression(ce, Pe, We), d);
              }
              function Ua(d, P) {
                var $2 = Ae(), ce = ur(), Pe = f.getTokenPos(), We = rr(18, P);
                if (We || d) {
                  var Er = f.hasPrecedingLineBreak(), Rr = Jn(1, Ai);
                  on(18, 19, We, Pe);
                  var Fr = ue(Ue(r.createBlock(Rr, Er), $2), ce);
                  return L() === 63 && (gt(e.Diagnostics.Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_the_whole_assignment_in_parentheses), fr()), Fr;
                } else {
                  var Rr = De();
                  return ue(Ue(r.createBlock(Rr, void 0), $2), ce);
                }
              }
              function Jo(d, P) {
                var $2 = Kn();
                In(!!(d & 1));
                var ce = Fn();
                hn(!!(d & 2));
                var Pe = Ct;
                Ct = false;
                var We = Zn();
                We && yn(false);
                var Er = Ua(!!(d & 16), P);
                return We && yn(true), Ct = Pe, In($2), hn(ce), Er;
              }
              function __() {
                var d = Ae(), P = ur();
                return rr(26), ue(Ue(r.createEmptyStatement(), d), P);
              }
              function nu() {
                var d = Ae(), P = ur();
                rr(99);
                var $2 = f.getTokenPos(), ce = rr(20), Pe = Vt(pi);
                on(20, 21, ce, $2);
                var We = Ai(), Er = Xr(91) ? Ai() : void 0;
                return ue(Ue(r.createIfStatement(Pe, We, Er), d), P);
              }
              function c_() {
                var d = Ae(), P = ur();
                rr(90);
                var $2 = Ai();
                rr(115);
                var ce = f.getTokenPos(), Pe = rr(20), We = Vt(pi);
                return on(20, 21, Pe, ce), Xr(26), ue(Ue(r.createDoStatement($2, We), d), P);
              }
              function iu() {
                var d = Ae(), P = ur();
                rr(115);
                var $2 = f.getTokenPos(), ce = rr(20), Pe = Vt(pi);
                on(20, 21, ce, $2);
                var We = Ai();
                return ue(Ue(r.createWhileStatement(Pe, We), d), P);
              }
              function ac() {
                var d = Ae(), P = ur();
                rr(97);
                var $2 = wr(133);
                rr(20);
                var ce;
                L() !== 26 && (L() === 113 || L() === 119 || L() === 85 ? ce = ds(true) : ce = ui(pi));
                var Pe;
                if ($2 ? rr(162) : Xr(162)) {
                  var We = Vt(function() {
                    return wi(true);
                  });
                  rr(21), Pe = r.createForOfStatement($2, ce, We, Ai());
                } else if (Xr(101)) {
                  var We = Vt(pi);
                  rr(21), Pe = r.createForInStatement(ce, We, Ai());
                } else {
                  rr(26);
                  var Er = L() !== 26 && L() !== 21 ? Vt(pi) : void 0;
                  rr(26);
                  var Rr = L() !== 21 ? Vt(pi) : void 0;
                  rr(21), Pe = r.createForStatement(ce, Er, Rr, Ai());
                }
                return ue(Ue(Pe, d), P);
              }
              function oc(d) {
                var P = Ae(), $2 = ur();
                rr(d === 249 ? 81 : 86);
                var ce = ti() ? void 0 : Tn();
                Bn();
                var Pe = d === 249 ? r.createBreakStatement(ce) : r.createContinueStatement(ce);
                return ue(Ue(Pe, P), $2);
              }
              function u_() {
                var d = Ae(), P = ur();
                rr(105);
                var $2 = ti() ? void 0 : Vt(pi);
                return Bn(), ue(Ue(r.createReturnStatement($2), d), P);
              }
              function au() {
                var d = Ae(), P = ur();
                rr(116);
                var $2 = f.getTokenPos(), ce = rr(20), Pe = Vt(pi);
                on(20, 21, ce, $2);
                var We = En(33554432, Ai);
                return ue(Ue(r.createWithStatement(Pe, We), d), P);
              }
              function ou() {
                var d = Ae(), P = ur();
                rr(82);
                var $2 = Vt(pi);
                rr(58);
                var ce = Jn(3, Ai);
                return ue(Ue(r.createCaseClause($2, ce), d), P);
              }
              function os() {
                var d = Ae();
                rr(88), rr(58);
                var P = Jn(3, Ai);
                return Ue(r.createDefaultClause(P), d);
              }
              function ia() {
                return L() === 82 ? ou() : os();
              }
              function ss() {
                var d = Ae();
                rr(18);
                var P = Jn(2, ia);
                return rr(19), Ue(r.createCaseBlock(P), d);
              }
              function l_() {
                var d = Ae(), P = ur();
                rr(107), rr(20);
                var $2 = Vt(pi);
                rr(21);
                var ce = ss();
                return ue(Ue(r.createSwitchStatement($2, ce), d), P);
              }
              function sc() {
                var d = Ae(), P = ur();
                rr(109);
                var $2 = f.hasPrecedingLineBreak() ? void 0 : Vt(pi);
                return $2 === void 0 && (de++, $2 = Ue(r.createIdentifier(""), Ae())), li() || rn($2), ue(Ue(r.createThrowStatement($2), d), P);
              }
              function su() {
                var d = Ae(), P = ur();
                rr(111);
                var $2 = Ua(false), ce = L() === 83 ? _c() : void 0, Pe;
                return (!ce || L() === 96) && (rr(96, e.Diagnostics.catch_or_finally_expected), Pe = Ua(false)), ue(Ue(r.createTryStatement($2, ce, Pe), d), P);
              }
              function _c() {
                var d = Ae();
                rr(83);
                var P;
                Xr(20) ? (P = fs2(), rr(21)) : P = void 0;
                var $2 = Ua(false);
                return Ue(r.createCatchClause(P, $2), d);
              }
              function _u() {
                var d = Ae(), P = ur();
                return rr(87), Bn(), ue(Ue(r.createDebuggerStatement(), d), P);
              }
              function _s() {
                var d = Ae(), P = ur(), $2, ce = L() === 20, Pe = Vt(pi);
                return e.isIdentifier(Pe) && Xr(58) ? $2 = r.createLabeledStatement(Pe, Ai()) : (li() || rn(Pe), $2 = r.createExpressionStatement(Pe), ce && (P = false)), ue(Ue($2, d), P);
              }
              function cs() {
                return fr(), e.tokenIsIdentifierOrKeyword(L()) && !f.hasPrecedingLineBreak();
              }
              function p_() {
                return fr(), L() === 84 && !f.hasPrecedingLineBreak();
              }
              function f_() {
                return fr(), L() === 98 && !f.hasPrecedingLineBreak();
              }
              function Fo() {
                return fr(), (e.tokenIsIdentifierOrKeyword(L()) || L() === 8 || L() === 9 || L() === 10) && !f.hasPrecedingLineBreak();
              }
              function d_() {
                for (; ; )
                  switch (L()) {
                    case 113:
                    case 119:
                    case 85:
                    case 98:
                    case 84:
                    case 92:
                      return true;
                    case 118:
                    case 154:
                      return Ws();
                    case 142:
                    case 143:
                      return lu();
                    case 126:
                    case 127:
                    case 132:
                    case 136:
                    case 121:
                    case 122:
                    case 123:
                    case 146:
                      if (fr(), f.hasPrecedingLineBreak())
                        return false;
                      continue;
                    case 159:
                      return fr(), L() === 18 || L() === 79 || L() === 93;
                    case 100:
                      return fr(), L() === 10 || L() === 41 || L() === 18 || e.tokenIsIdentifierOrKeyword(L());
                    case 93:
                      var d = fr();
                      if (d === 154 && (d = Gr(fr)), d === 63 || d === 41 || d === 18 || d === 88 || d === 128)
                        return true;
                      continue;
                    case 124:
                      fr();
                      continue;
                    default:
                      return false;
                  }
              }
              function Bo() {
                return Gr(d_);
              }
              function us() {
                switch (L()) {
                  case 59:
                  case 26:
                  case 18:
                  case 113:
                  case 119:
                  case 98:
                  case 84:
                  case 92:
                  case 99:
                  case 90:
                  case 115:
                  case 97:
                  case 86:
                  case 81:
                  case 105:
                  case 116:
                  case 107:
                  case 109:
                  case 111:
                  case 87:
                  case 83:
                  case 96:
                    return true;
                  case 100:
                    return Bo() || Gr(Nt);
                  case 85:
                  case 93:
                    return Bo();
                  case 132:
                  case 136:
                  case 118:
                  case 142:
                  case 143:
                  case 154:
                  case 159:
                    return true;
                  case 127:
                  case 123:
                  case 121:
                  case 122:
                  case 124:
                  case 146:
                    return Bo() || !Gr(cs);
                  default:
                    return Sa();
                }
              }
              function m_() {
                return fr(), en() || L() === 18 || L() === 22;
              }
              function cu() {
                return Gr(m_);
              }
              function Ai() {
                switch (L()) {
                  case 26:
                    return __();
                  case 18:
                    return Ua(false);
                  case 113:
                    return qo(Ae(), ur(), void 0, void 0);
                  case 119:
                    if (cu())
                      return qo(Ae(), ur(), void 0, void 0);
                    break;
                  case 98:
                    return za(Ae(), ur(), void 0, void 0);
                  case 84:
                    return hc(Ae(), ur(), void 0, void 0);
                  case 99:
                    return nu();
                  case 90:
                    return c_();
                  case 115:
                    return iu();
                  case 97:
                    return ac();
                  case 86:
                    return oc(248);
                  case 81:
                    return oc(249);
                  case 105:
                    return u_();
                  case 116:
                    return au();
                  case 107:
                    return l_();
                  case 109:
                    return sc();
                  case 111:
                  case 83:
                  case 96:
                    return su();
                  case 87:
                    return _u();
                  case 59:
                    return po();
                  case 132:
                  case 118:
                  case 154:
                  case 142:
                  case 143:
                  case 136:
                  case 85:
                  case 92:
                  case 93:
                  case 100:
                  case 121:
                  case 122:
                  case 123:
                  case 126:
                  case 127:
                  case 124:
                  case 146:
                  case 159:
                    if (Bo())
                      return po();
                    break;
                }
                return _s();
              }
              function g_(d) {
                return d.kind === 136;
              }
              function po() {
                var d = Ae(), P = ur(), $2 = mo(), ce = Da(), Pe = e.some(ce, g_);
                if (Pe) {
                  var We = uu(d);
                  if (We)
                    return We;
                  for (var Er = 0, Rr = ce; Er < Rr.length; Er++) {
                    var Fr = Rr[Er];
                    Fr.flags |= 16777216;
                  }
                  return En(16777216, function() {
                    return ls(d, P, $2, ce);
                  });
                } else
                  return ls(d, P, $2, ce);
              }
              function uu(d) {
                return En(16777216, function() {
                  var P = Xi(He, d);
                  if (P)
                    return sa(P);
                });
              }
              function ls(d, P, $2, ce) {
                switch (L()) {
                  case 113:
                  case 119:
                  case 85:
                    return qo(d, P, $2, ce);
                  case 98:
                    return za(d, P, $2, ce);
                  case 84:
                    return hc(d, P, $2, ce);
                  case 118:
                    return Ec(d, P, $2, ce);
                  case 154:
                    return Tc(d, P, $2, ce);
                  case 92:
                    return E_(d, P, $2, ce);
                  case 159:
                  case 142:
                  case 143:
                    return Wa(d, P, $2, ce);
                  case 100:
                    return bu(d, P, $2, ce);
                  case 93:
                    switch (fr(), L()) {
                      case 88:
                      case 63:
                        return Ic(d, P, $2, ce);
                      case 128:
                        return Es(d, P, $2, ce);
                      default:
                        return xu(d, P, $2, ce);
                    }
                  default:
                    if ($2 || ce) {
                      var Pe = Vn(279, true, e.Diagnostics.Declaration_expected);
                      return e.setTextRangePos(Pe, d), Pe.illegalDecorators = $2, Pe.modifiers = ce, Pe;
                    }
                    return;
                }
              }
              function lu() {
                return fr(), !f.hasPrecedingLineBreak() && (Ot() || L() === 10);
              }
              function Ia(d, P) {
                if (L() !== 18) {
                  if (d & 4) {
                    A();
                    return;
                  }
                  if (ti()) {
                    Bn();
                    return;
                  }
                }
                return Jo(d, P);
              }
              function cc() {
                var d = Ae();
                if (L() === 27)
                  return Ue(r.createOmittedExpression(), d);
                var P = wr(25), $2 = Oa(), ce = Na();
                return Ue(r.createBindingElement(P, void 0, $2, ce), d);
              }
              function y_() {
                var d = Ae(), P = wr(25), $2 = en(), ce = W(), Pe;
                $2 && L() !== 58 ? (Pe = ce, ce = void 0) : (rr(58), Pe = Oa());
                var We = Na();
                return Ue(r.createBindingElement(P, ce, Pe, We), d);
              }
              function ps() {
                var d = Ae();
                rr(18);
                var P = $t(9, y_);
                return rr(19), Ue(r.createObjectBindingPattern(P), d);
              }
              function uc() {
                var d = Ae();
                rr(22);
                var P = $t(10, cc);
                return rr(23), Ue(r.createArrayBindingPattern(P), d);
              }
              function h_() {
                return L() === 18 || L() === 22 || L() === 80 || en();
              }
              function Oa(d) {
                return L() === 22 ? uc() : L() === 18 ? ps() : Fi(d);
              }
              function Ma() {
                return fs2(true);
              }
              function fs2(d) {
                var P = Ae(), $2 = ur(), ce = Oa(e.Diagnostics.Private_identifiers_are_not_allowed_in_variable_declarations), Pe;
                d && ce.kind === 79 && L() === 53 && !f.hasPrecedingLineBreak() && (Pe = An());
                var We = ua(), Er = Gs(L()) ? void 0 : Na(), Rr = r.createVariableDeclaration(ce, Pe, We, Er);
                return ue(Ue(Rr, P), $2);
              }
              function ds(d) {
                var P = Ae(), $2 = 0;
                switch (L()) {
                  case 113:
                    break;
                  case 119:
                    $2 |= 1;
                    break;
                  case 85:
                    $2 |= 2;
                    break;
                  default:
                    e.Debug.fail();
                }
                fr();
                var ce;
                if (L() === 162 && Gr(v_))
                  ce = De();
                else {
                  var Pe = si();
                  cn(d), ce = $t(8, d ? fs2 : Ma), cn(Pe);
                }
                return Ue(r.createVariableDeclarationList(ce, $2), P);
              }
              function v_() {
                return Gn() && fr() === 21;
              }
              function qo(d, P, $2, ce) {
                var Pe = ds(false);
                Bn();
                var We = r.createVariableStatement(ce, Pe);
                return We.illegalDecorators = $2, ue(Ue(We, d), P);
              }
              function za(d, P, $2, ce) {
                var Pe = Fn(), We = e.modifiersToFlags(ce);
                rr(98);
                var Er = wr(41), Rr = We & 1024 ? lo() : Fi(), Fr = Er ? 1 : 0, et = We & 512 ? 2 : 0, wt = Ii();
                We & 1 && hn(true);
                var Gt = l(Fr | et), Wt = zi(58, false), pn = Ia(Fr | et, e.Diagnostics.or_expected);
                hn(Pe);
                var Pn = r.createFunctionDeclaration(ce, Er, Rr, wt, Gt, Wt, pn);
                return Pn.illegalDecorators = $2, ue(Ue(Pn, d), P);
              }
              function pu() {
                if (L() === 135)
                  return rr(135);
                if (L() === 10 && Gr(fr) === 20)
                  return Kt(function() {
                    var d = ji();
                    return d.text === "constructor" ? d : void 0;
                  });
              }
              function b_(d, P, $2, ce) {
                return Kt(function() {
                  if (pu()) {
                    var Pe = Ii(), We = l(0), Er = zi(58, false), Rr = Ia(0, e.Diagnostics.or_expected), Fr = r.createConstructorDeclaration(ce, We, Rr);
                    return Fr.illegalDecorators = $2, Fr.typeParameters = Pe, Fr.type = Er, ue(Ue(Fr, d), P);
                  }
                });
              }
              function lc(d, P, $2, ce, Pe, We, Er, Rr, Fr) {
                var et = Pe ? 1 : 0, wt = e.some(ce, e.isAsyncModifier) ? 2 : 0, Gt = Ii(), Wt = l(et | wt), pn = zi(58, false), Pn = Ia(et | wt, Fr), _i = r.createMethodDeclaration(Va($2, ce), Pe, We, Er, Gt, Wt, pn, Pn);
                return _i.exclamationToken = Rr, ue(Ue(_i, d), P);
              }
              function ms(d, P, $2, ce, Pe, We) {
                var Er = !We && !f.hasPrecedingLineBreak() ? wr(53) : void 0, Rr = ua(), Fr = ln(45056, Na);
                Rn(Pe, Rr, Fr);
                var et = r.createPropertyDeclaration(Va($2, ce), Pe, We || Er, Rr, Fr);
                return ue(Ue(et, d), P);
              }
              function pc(d, P, $2, ce) {
                var Pe = wr(41), We = W(), Er = wr(57);
                return Pe || L() === 20 || L() === 29 ? lc(d, P, $2, ce, Pe, We, Er, void 0, e.Diagnostics.or_expected) : ms(d, P, $2, ce, We, Er);
              }
              function fo(d, P, $2, ce, Pe, We) {
                var Er = W(), Rr = Ii(), Fr = l(0), et = zi(58, false), wt = Ia(We), Gt = Pe === 174 ? r.createGetAccessorDeclaration(Va($2, ce), Er, Fr, et, wt) : r.createSetAccessorDeclaration(Va($2, ce), Er, Fr, wt);
                return Gt.typeParameters = Rr, e.isSetAccessorDeclaration(Gt) && (Gt.type = et), ue(Ue(Gt, d), P);
              }
              function fc() {
                var d;
                if (L() === 59)
                  return true;
                for (; e.isModifierKind(L()); ) {
                  if (d = L(), e.isClassMemberModifier(d))
                    return true;
                  fr();
                }
                if (L() === 41 || (Ti() && (d = L(), fr()), L() === 22))
                  return true;
                if (d !== void 0) {
                  if (!e.isKeyword(d) || d === 151 || d === 137)
                    return true;
                  switch (L()) {
                    case 20:
                    case 29:
                    case 53:
                    case 58:
                    case 63:
                    case 57:
                      return true;
                    default:
                      return ti();
                  }
                }
                return false;
              }
              function fu(d, P, $2, ce) {
                mn(124);
                var Pe = du(), We = ue(Ue(r.createClassStaticBlockDeclaration(Pe), d), P);
                return We.illegalDecorators = $2, We.modifiers = ce, We;
              }
              function du() {
                var d = Kn(), P = Fn();
                In(false), hn(true);
                var $2 = Ua(false);
                return In(d), hn(P), $2;
              }
              function ga() {
                if (Fn() && L() === 133) {
                  var d = Ae(), P = Tn(e.Diagnostics.Expression_expected);
                  fr();
                  var $2 = jo(d, P, true);
                  return la(d, $2);
                }
                return ta();
              }
              function dc() {
                var d = Ae();
                if (Xr(59)) {
                  var P = vi(ga);
                  return Ue(r.createDecorator(P), d);
                }
              }
              function mo() {
                for (var d = Ae(), P, $2; $2 = dc(); )
                  P = e.append(P, $2);
                return P && vn(P, d);
              }
              function mu(d, P, $2) {
                var ce = Ae(), Pe = L();
                if (L() === 85 && d) {
                  if (!Kt(Ar))
                    return;
                } else {
                  if (P && L() === 124 && Gr(wc))
                    return;
                  if ($2 && L() === 124)
                    return;
                  if (!Ut())
                    return;
                }
                return Ue(r.createToken(Pe), ce);
              }
              function Va(d, P) {
                if (!d)
                  return P;
                if (!P)
                  return d;
                var $2 = r.createNodeArray(e.concatenate(d, P));
                return e.setTextRangePosEnd($2, d.pos, P.end), $2;
              }
              function Da(d, P) {
                for (var $2 = Ae(), ce, Pe, We = false; Pe = mu(d, P, We); )
                  Pe.kind === 124 && (We = true), ce = e.append(ce, Pe);
                return ce && vn(ce, $2);
              }
              function mc() {
                var d;
                if (L() === 132) {
                  var P = Ae();
                  fr();
                  var $2 = Ue(r.createToken(132), P);
                  d = vn([$2], P);
                }
                return d;
              }
              function gc() {
                var d = Ae();
                if (L() === 26)
                  return fr(), Ue(r.createSemicolonClassElement(), d);
                var P = ur(), $2 = mo(), ce = Da(true, true);
                if (L() === 124 && Gr(wc))
                  return fu(d, P, $2, ce);
                if (Ir(137))
                  return fo(d, P, $2, ce, 174, 0);
                if (Ir(151))
                  return fo(d, P, $2, ce, 175, 0);
                if (L() === 135 || L() === 10) {
                  var Pe = b_(d, P, $2, ce);
                  if (Pe)
                    return Pe;
                }
                if (ke())
                  return Zr(d, P, $2, ce);
                if (e.tokenIsIdentifierOrKeyword(L()) || L() === 10 || L() === 8 || L() === 41 || L() === 22) {
                  var We = e.some(ce, g_);
                  if (We) {
                    for (var Er = 0, Rr = ce; Er < Rr.length; Er++) {
                      var Fr = Rr[Er];
                      Fr.flags |= 16777216;
                    }
                    return En(16777216, function() {
                      return pc(d, P, $2, ce);
                    });
                  } else
                    return pc(d, P, $2, ce);
                }
                if ($2 || ce) {
                  var et = Vn(79, true, e.Diagnostics.Declaration_expected);
                  return ms(d, P, $2, ce, et, void 0);
                }
                return e.Debug.fail("Should not have attempted to parse class member declaration.");
              }
              function yc() {
                return gs(Ae(), ur(), void 0, void 0, 228);
              }
              function hc(d, P, $2, ce) {
                return gs(d, P, $2, ce, 260);
              }
              function gs(d, P, $2, ce, Pe) {
                var We = Fn();
                rr(84);
                var Er = ys(), Rr = Ii();
                e.some(ce, e.isExportModifier) && hn(true);
                var Fr = hs(), et;
                rr(18) ? (et = hu(), rr(19)) : et = De(), hn(We);
                var wt = Pe === 260 ? r.createClassDeclaration(Va($2, ce), Er, Rr, Fr, et) : r.createClassExpression(Va($2, ce), Er, Rr, Fr, et);
                return ue(Ue(wt, d), P);
              }
              function ys() {
                return en() && !gu() ? ni(en()) : void 0;
              }
              function gu() {
                return L() === 117 && Gr(Bi);
              }
              function hs() {
                if (bc())
                  return Jn(22, vc);
              }
              function vc() {
                var d = Ae(), P = L();
                e.Debug.assert(P === 94 || P === 117), fr();
                var $2 = $t(7, yu);
                return Ue(r.createHeritageClause(P, $2), d);
              }
              function yu() {
                var d = Ae(), P = ta();
                if (P.kind === 230)
                  return P;
                var $2 = vs();
                return Ue(r.createExpressionWithTypeArguments(P, $2), d);
              }
              function vs() {
                return L() === 29 ? Jt(20, Un, 29, 31) : void 0;
              }
              function bc() {
                return L() === 94 || L() === 117;
              }
              function hu() {
                return Jn(5, gc);
              }
              function Ec(d, P, $2, ce) {
                rr(118);
                var Pe = Tn(), We = Ii(), Er = hs(), Rr = Sn(), Fr = r.createInterfaceDeclaration(ce, Pe, We, Er, Rr);
                return Fr.illegalDecorators = $2, ue(Ue(Fr, d), P);
              }
              function Tc(d, P, $2, ce) {
                rr(154);
                var Pe = Tn(), We = Ii();
                rr(63);
                var Er = L() === 139 && Kt(Rs) || Un();
                Bn();
                var Rr = r.createTypeAliasDeclaration(ce, Pe, We, Er);
                return Rr.illegalDecorators = $2, ue(Ue(Rr, d), P);
              }
              function Sc() {
                var d = Ae(), P = ur(), $2 = W(), ce = Vt(Na);
                return ue(Ue(r.createEnumMember($2, ce), d), P);
              }
              function E_(d, P, $2, ce) {
                rr(92);
                var Pe = Tn(), We;
                rr(18) ? (We = bi(function() {
                  return $t(6, Sc);
                }), rr(19)) : We = De();
                var Er = r.createEnumDeclaration(ce, Pe, We);
                return Er.illegalDecorators = $2, ue(Ue(Er, d), P);
              }
              function Cc() {
                var d = Ae(), P;
                return rr(18) ? (P = Jn(1, Ai), rr(19)) : P = De(), Ue(r.createModuleBlock(P), d);
              }
              function Dc(d, P, $2, ce, Pe) {
                var We = Pe & 16, Er = Tn(), Rr = Xr(24) ? Dc(Ae(), false, void 0, void 0, 4 | We) : Cc(), Fr = r.createModuleDeclaration(ce, Er, Rr, Pe);
                return Fr.illegalDecorators = $2, ue(Ue(Fr, d), P);
              }
              function xc(d, P, $2, ce) {
                var Pe = 0, We;
                L() === 159 ? (We = Tn(), Pe |= 1024) : (We = ji(), We.text = Ei(We.text));
                var Er;
                L() === 18 ? Er = Cc() : Bn();
                var Rr = r.createModuleDeclaration(ce, We, Er, Pe);
                return Rr.illegalDecorators = $2, ue(Ue(Rr, d), P);
              }
              function Wa(d, P, $2, ce) {
                var Pe = 0;
                if (L() === 159)
                  return xc(d, P, $2, ce);
                if (Xr(143))
                  Pe |= 16;
                else if (rr(142), L() === 10)
                  return xc(d, P, $2, ce);
                return Dc(d, P, $2, ce, Pe);
              }
              function go() {
                return L() === 147 && Gr(bs);
              }
              function bs() {
                return fr() === 20;
              }
              function wc() {
                return fr() === 18;
              }
              function vu() {
                return fr() === 43;
              }
              function Es(d, P, $2, ce) {
                rr(128), rr(143);
                var Pe = Tn();
                Bn();
                var We = r.createNamespaceExportDeclaration(Pe);
                return We.illegalDecorators = $2, We.modifiers = ce, ue(Ue(We, d), P);
              }
              function bu(d, P, $2, ce) {
                rr(100);
                var Pe = f.getStartPos(), We;
                Ot() && (We = Tn());
                var Er = false;
                if (L() !== 158 && (We == null ? void 0 : We.escapedText) === "type" && (Ot() || Ka()) && (Er = true, We = Ot() ? Tn() : void 0), We && !Ac())
                  return Tu(d, P, $2, ce, We, Er);
                var Rr;
                (We || L() === 41 || L() === 18) && (Rr = Su(We, Pe, Er), rr(158));
                var Fr = Ss(), et;
                L() === 130 && !f.hasPrecedingLineBreak() && (et = T_()), Bn();
                var wt = r.createImportDeclaration(ce, Rr, Fr, et);
                return wt.illegalDecorators = $2, ue(Ue(wt, d), P);
              }
              function Eu() {
                var d = Ae(), P = e.tokenIsIdentifierOrKeyword(L()) ? jn() : wa(10);
                rr(58);
                var $2 = wi(true);
                return Ue(r.createAssertEntry(P, $2), d);
              }
              function T_(d) {
                var P = Ae();
                d || rr(130);
                var $2 = f.getTokenPos();
                if (rr(18)) {
                  var ce = f.hasPrecedingLineBreak(), Pe = $t(24, Eu, true);
                  if (!rr(19)) {
                    var We = e.lastOrUndefined(vr);
                    We && We.code === e.Diagnostics._0_expected.code && e.addRelatedInfo(We, e.createDetachedDiagnostic(ct, $2, 1, e.Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                  }
                  return Ue(r.createAssertClause(Pe, ce), P);
                } else {
                  var Pe = vn([], Ae(), void 0, false);
                  return Ue(r.createAssertClause(Pe, false), P);
                }
              }
              function Ka() {
                return L() === 41 || L() === 18;
              }
              function Ac() {
                return L() === 27 || L() === 158;
              }
              function Tu(d, P, $2, ce, Pe, We) {
                rr(63);
                var Er = Ts();
                Bn();
                var Rr = r.createImportEqualsDeclaration(ce, We, Pe, Er);
                Rr.illegalDecorators = $2;
                var Fr = ue(Ue(Rr, d), P);
                return Fr;
              }
              function Su(d, P, $2) {
                var ce;
                return (!d || Xr(27)) && (ce = L() === 41 ? kc() : La(272)), Ue(r.createImportClause($2, d, ce), P);
              }
              function Ts() {
                return go() ? Cu() : Qt(false);
              }
              function Cu() {
                var d = Ae();
                rr(147), rr(20);
                var P = Ss();
                return rr(21), Ue(r.createExternalModuleReference(P), d);
              }
              function Ss() {
                if (L() === 10) {
                  var d = ji();
                  return d.text = Ei(d.text), d;
                } else
                  return pi();
              }
              function kc() {
                var d = Ae();
                rr(41), rr(128);
                var P = Tn();
                return Ue(r.createNamespaceImport(P), d);
              }
              function La(d) {
                var P = Ae(), $2 = d === 272 ? r.createNamedImports(Jt(23, Ha, 18, 19)) : r.createNamedExports(Jt(23, Du, 18, 19));
                return Ue($2, P);
              }
              function Du() {
                var d = ur();
                return ue(Pc(278), d);
              }
              function Ha() {
                return Pc(273);
              }
              function Pc(d) {
                var P = Ae(), $2 = e.isKeyword(L()) && !Ot(), ce = f.getTokenPos(), Pe = f.getTextPos(), We = false, Er, Rr = true, Fr = jn();
                if (Fr.escapedText === "type")
                  if (L() === 128) {
                    var et = jn();
                    if (L() === 128) {
                      var wt = jn();
                      e.tokenIsIdentifierOrKeyword(L()) ? (We = true, Er = et, Fr = Wt(), Rr = false) : (Er = Fr, Fr = wt, Rr = false);
                    } else
                      e.tokenIsIdentifierOrKeyword(L()) ? (Er = Fr, Rr = false, Fr = Wt()) : (We = true, Fr = et);
                  } else
                    e.tokenIsIdentifierOrKeyword(L()) && (We = true, Fr = Wt());
                Rr && L() === 128 && (Er = Fr, rr(128), Fr = Wt()), d === 273 && $2 && dn(ce, Pe, e.Diagnostics.Identifier_expected);
                var Gt = d === 273 ? r.createImportSpecifier(We, Er, Fr) : r.createExportSpecifier(We, Er, Fr);
                return Ue(Gt, P);
                function Wt() {
                  return $2 = e.isKeyword(L()) && !Ot(), ce = f.getTokenPos(), Pe = f.getTextPos(), jn();
                }
              }
              function Nc(d) {
                return Ue(r.createNamespaceExport(jn()), d);
              }
              function xu(d, P, $2, ce) {
                var Pe = Fn();
                hn(true);
                var We, Er, Rr, Fr = Xr(154), et = Ae();
                Xr(41) ? (Xr(128) && (We = Nc(et)), rr(158), Er = Ss()) : (We = La(276), (L() === 158 || L() === 10 && !f.hasPrecedingLineBreak()) && (rr(158), Er = Ss())), Er && L() === 130 && !f.hasPrecedingLineBreak() && (Rr = T_()), Bn(), hn(Pe);
                var wt = r.createExportDeclaration(ce, Fr, We, Er, Rr);
                return wt.illegalDecorators = $2, ue(Ue(wt, d), P);
              }
              function Ic(d, P, $2, ce) {
                var Pe = Fn();
                hn(true);
                var We;
                Xr(63) ? We = true : rr(88);
                var Er = wi(true);
                Bn(), hn(Pe);
                var Rr = r.createExportAssignment(ce, We, Er);
                return Rr.illegalDecorators = $2, ue(Ue(Rr, d), P);
              }
              var Cs;
              (function(d) {
                d[d.SourceElements = 0] = "SourceElements", d[d.BlockStatements = 1] = "BlockStatements", d[d.SwitchClauses = 2] = "SwitchClauses", d[d.SwitchClauseStatements = 3] = "SwitchClauseStatements", d[d.TypeMembers = 4] = "TypeMembers", d[d.ClassMembers = 5] = "ClassMembers", d[d.EnumMembers = 6] = "EnumMembers", d[d.HeritageClauseElement = 7] = "HeritageClauseElement", d[d.VariableDeclarations = 8] = "VariableDeclarations", d[d.ObjectBindingElements = 9] = "ObjectBindingElements", d[d.ArrayBindingElements = 10] = "ArrayBindingElements", d[d.ArgumentExpressions = 11] = "ArgumentExpressions", d[d.ObjectLiteralMembers = 12] = "ObjectLiteralMembers", d[d.JsxAttributes = 13] = "JsxAttributes", d[d.JsxChildren = 14] = "JsxChildren", d[d.ArrayLiteralMembers = 15] = "ArrayLiteralMembers", d[d.Parameters = 16] = "Parameters", d[d.JSDocParameters = 17] = "JSDocParameters", d[d.RestProperties = 18] = "RestProperties", d[d.TypeParameters = 19] = "TypeParameters", d[d.TypeArguments = 20] = "TypeArguments", d[d.TupleElementTypes = 21] = "TupleElementTypes", d[d.HeritageClauses = 22] = "HeritageClauses", d[d.ImportOrExportSpecifiers = 23] = "ImportOrExportSpecifiers", d[d.AssertEntries = 24] = "AssertEntries", d[d.Count = 25] = "Count";
              })(Cs || (Cs = {}));
              var S_;
              (function(d) {
                d[d.False = 0] = "False", d[d.True = 1] = "True", d[d.Unknown = 2] = "Unknown";
              })(S_ || (S_ = {}));
              var Oc;
              (function(d) {
                function P(et, wt, Gt) {
                  mt("file.js", et, 99, void 0, 1), f.setText(et, wt, Gt), Mr = f.scan();
                  var Wt = $2(), pn = Dt("file.js", 99, 1, false, [], r.createToken(1), 0, e.noop), Pn = e.attachFileToDiagnostics(vr, pn);
                  return nt && (pn.jsDocDiagnostics = e.attachFileToDiagnostics(nt, pn)), at(), Wt ? { jsDocTypeExpression: Wt, diagnostics: Pn } : void 0;
                }
                d.parseJSDocTypeExpressionForTests = P;
                function $2(et) {
                  var wt = Ae(), Gt = (et ? Xr : rr)(18), Wt = En(8388608, ka);
                  (!et || Gt) && kn(19);
                  var pn = r.createJSDocTypeExpression(Wt);
                  return Hr(pn), Ue(pn, wt);
                }
                d.parseJSDocTypeExpression = $2;
                function ce() {
                  for (var et = Ae(), wt = Xr(18), Gt = Ae(), Wt = Qt(false); L() === 80; )
                    dt(), Le(), Wt = Ue(r.createJSDocMemberName(Wt, Tn()), Gt);
                  wt && kn(19);
                  var pn = r.createJSDocNameReference(Wt);
                  return Hr(pn), Ue(pn, et);
                }
                d.parseJSDocNameReference = ce;
                function Pe(et, wt, Gt) {
                  mt("", et, 99, void 0, 1);
                  var Wt = En(8388608, function() {
                    return Fr(wt, Gt);
                  }), pn = { languageVariant: 0, text: et }, Pn = e.attachFileToDiagnostics(vr, pn);
                  return at(), Wt ? { jsDoc: Wt, diagnostics: Pn } : void 0;
                }
                d.parseIsolatedJSDocComment = Pe;
                function We(et, wt, Gt) {
                  var Wt = Mr, pn = vr.length, Pn = xt, _i = En(8388608, function() {
                    return Fr(wt, Gt);
                  });
                  return e.setParent(_i, et), Yr & 262144 && (nt || (nt = []), nt.push.apply(nt, vr)), Mr = Wt, vr.length = pn, xt = Pn, _i;
                }
                d.parseJSDocComment = We;
                var Er;
                (function(et) {
                  et[et.BeginningOfLine = 0] = "BeginningOfLine", et[et.SawAsterisk = 1] = "SawAsterisk", et[et.SavingComments = 2] = "SavingComments", et[et.SavingBackticks = 3] = "SavingBackticks";
                })(Er || (Er = {}));
                var Rr;
                (function(et) {
                  et[et.Property = 1] = "Property", et[et.Parameter = 2] = "Parameter", et[et.CallbackParameter = 4] = "CallbackParameter";
                })(Rr || (Rr = {}));
                function Fr(et, wt) {
                  et === void 0 && (et = 0);
                  var Gt = Ie, Wt = wt === void 0 ? Gt.length : et + wt;
                  if (wt = Wt - et, e.Debug.assert(et >= 0), e.Debug.assert(et <= Wt), e.Debug.assert(Wt <= Gt.length), !Me(Gt, et))
                    return;
                  var pn, Pn, _i, Ln, ya, Ci = [], Xn = [];
                  return f.scanRange(et + 3, wt - 5, function() {
                    var sr = 1, $r, Wr = et - (Gt.lastIndexOf(`
`, et) + 1) + 4;
                    function st(Oi) {
                      $r || ($r = Wr), Ci.push(Oi), Wr += Oi.length;
                    }
                    for (Le(); zo(5); )
                      ;
                    zo(4) && (sr = 0, Wr = 0);
                    e:
                      for (; ; ) {
                        switch (L()) {
                          case 59:
                            sr === 0 || sr === 1 ? (aa(Ci), ya || (ya = Ae()), pa(o(Wr)), sr = 0, $r = void 0) : st(f.getTokenText());
                            break;
                          case 4:
                            Ci.push(f.getTokenText()), sr = 0, Wr = 0;
                            break;
                          case 41:
                            var ht = f.getTokenText();
                            sr === 1 || sr === 2 ? (sr = 2, st(ht)) : (sr = 1, Wr += ht.length);
                            break;
                          case 5:
                            var Bt = f.getTokenText();
                            sr === 2 ? Ci.push(Bt) : $r !== void 0 && Wr + Bt.length > $r && Ci.push(Bt.slice($r - Wr)), Wr += Bt.length;
                            break;
                          case 1:
                            break e;
                          case 18:
                            sr = 2;
                            var Cn = f.getStartPos(), yi = f.getTextPos() - 1, fi = Ke(yi);
                            if (fi) {
                              Ln || ki(Ci), Xn.push(Ue(r.createJSDocText(Ci.join("")), Ln != null ? Ln : et, Cn)), Xn.push(fi), Ci = [], Ln = f.getTextPos();
                              break;
                            }
                          default:
                            sr = 2, st(f.getTokenText());
                            break;
                        }
                        Le();
                      }
                    aa(Ci), Xn.length && Ci.length && Xn.push(Ue(r.createJSDocText(Ci.join("")), Ln != null ? Ln : et, ya)), Xn.length && pn && e.Debug.assertIsDefined(ya, "having parsed tags implies that the end of the comment span should be set");
                    var Wi = pn && vn(pn, Pn, _i);
                    return Ue(r.createJSDocComment(Xn.length ? vn(Xn, et, ya) : Ci.length ? Ci.join("") : void 0, Wi), et, Wt);
                  });
                  function ki(sr) {
                    for (; sr.length && (sr[0] === `
` || sr[0] === "\r"); )
                      sr.shift();
                  }
                  function aa(sr) {
                    for (; sr.length && sr[sr.length - 1].trim() === ""; )
                      sr.pop();
                  }
                  function Ga() {
                    for (; ; ) {
                      if (Le(), L() === 1)
                        return true;
                      if (!(L() === 5 || L() === 4))
                        return false;
                    }
                  }
                  function ii() {
                    if (!((L() === 5 || L() === 4) && Gr(Ga)))
                      for (; L() === 5 || L() === 4; )
                        Le();
                  }
                  function i() {
                    if ((L() === 5 || L() === 4) && Gr(Ga))
                      return "";
                    for (var sr = f.hasPrecedingLineBreak(), $r = false, Wr = ""; sr && L() === 41 || L() === 5 || L() === 4; )
                      Wr += f.getTokenText(), L() === 4 ? (sr = true, $r = true, Wr = "") : L() === 41 && (sr = false), Le();
                    return $r ? Wr : "";
                  }
                  function o(sr) {
                    e.Debug.assert(L() === 59);
                    var $r = f.getTokenPos();
                    Le();
                    var Wr = yo(void 0), st = i(), ht;
                    switch (Wr.escapedText) {
                      case "author":
                        ht = Il($r, Wr, sr, st);
                        break;
                      case "implements":
                        ht = Ol($r, Wr, sr, st);
                        break;
                      case "augments":
                      case "extends":
                        ht = Ml($r, Wr, sr, st);
                        break;
                      case "class":
                      case "constructor":
                        ht = Vi($r, r.createJSDocClassTag, Wr, sr, st);
                        break;
                      case "public":
                        ht = Vi($r, r.createJSDocPublicTag, Wr, sr, st);
                        break;
                      case "private":
                        ht = Vi($r, r.createJSDocPrivateTag, Wr, sr, st);
                        break;
                      case "protected":
                        ht = Vi($r, r.createJSDocProtectedTag, Wr, sr, st);
                        break;
                      case "readonly":
                        ht = Vi($r, r.createJSDocReadonlyTag, Wr, sr, st);
                        break;
                      case "override":
                        ht = Vi($r, r.createJSDocOverrideTag, Wr, sr, st);
                        break;
                      case "deprecated":
                        Qe = true, ht = Vi($r, r.createJSDocDeprecatedTag, Wr, sr, st);
                        break;
                      case "this":
                        ht = Ll($r, Wr, sr, st);
                        break;
                      case "enum":
                        ht = Ku($r, Wr, sr, st);
                        break;
                      case "arg":
                      case "argument":
                      case "param":
                        return xs($r, Wr, 2, sr);
                      case "return":
                      case "returns":
                        ht = Mc($r, Wr, sr, st);
                        break;
                      case "template":
                        ht = Gu($r, Wr, sr, st);
                        break;
                      case "type":
                        ht = Uu($r, Wr, sr, st);
                        break;
                      case "typedef":
                        ht = Rl($r, Wr, sr, st);
                        break;
                      case "callback":
                        ht = Jl($r, Wr, sr, st);
                        break;
                      case "see":
                        ht = zu($r, Wr, sr, st);
                        break;
                      default:
                        ht = $n($r, Wr, sr, st);
                        break;
                    }
                    return ht;
                  }
                  function u(sr, $r, Wr, st) {
                    return st || (Wr += $r - sr), b(Wr, st.slice(Wr));
                  }
                  function b(sr, $r) {
                    var Wr = Ae(), st = [], ht = [], Bt, Cn = 0, yi = true, fi;
                    function Wi(As) {
                      fi || (fi = sr), st.push(As), sr += As.length;
                    }
                    $r !== void 0 && ($r !== "" && Wi($r), Cn = 1);
                    var Oi = L();
                    e:
                      for (; ; ) {
                        switch (Oi) {
                          case 4:
                            Cn = 0, st.push(f.getTokenText()), sr = 0;
                            break;
                          case 59:
                            if (Cn === 3 || Cn === 2 && (!yi || Gr(Y))) {
                              st.push(f.getTokenText());
                              break;
                            }
                            f.setTextPos(f.getTextPos() - 1);
                          case 1:
                            break e;
                          case 5:
                            if (Cn === 2 || Cn === 3)
                              Wi(f.getTokenText());
                            else {
                              var ha = f.getTokenText();
                              fi !== void 0 && sr + ha.length > fi && st.push(ha.slice(fi - sr)), sr += ha.length;
                            }
                            break;
                          case 18:
                            Cn = 2;
                            var ws = f.getStartPos(), Rc = f.getTextPos() - 1, jc = Ke(Rc);
                            jc ? (ht.push(Ue(r.createJSDocText(st.join("")), Bt != null ? Bt : Wr, ws)), ht.push(jc), st = [], Bt = f.getTextPos()) : Wi(f.getTokenText());
                            break;
                          case 61:
                            Cn === 3 ? Cn = 2 : Cn = 3, Wi(f.getTokenText());
                            break;
                          case 41:
                            if (Cn === 0) {
                              Cn = 1, sr += 1;
                              break;
                            }
                          default:
                            Cn !== 3 && (Cn = 2), Wi(f.getTokenText());
                            break;
                        }
                        yi = L() === 5, Oi = Le();
                      }
                    if (ki(st), aa(st), ht.length)
                      return st.length && ht.push(Ue(r.createJSDocText(st.join("")), Bt != null ? Bt : Wr)), vn(ht, Wr, f.getTextPos());
                    if (st.length)
                      return st.join("");
                  }
                  function Y() {
                    var sr = Le();
                    return sr === 5 || sr === 4;
                  }
                  function Ke(sr) {
                    var $r = Kt(Or);
                    if ($r) {
                      Le(), ii();
                      var Wr = Ae(), st = e.tokenIsIdentifierOrKeyword(L()) ? Qt(true) : void 0;
                      if (st)
                        for (; L() === 80; )
                          dt(), Le(), st = Ue(r.createJSDocMemberName(st, Tn()), Wr);
                      for (var ht = []; L() !== 19 && L() !== 4 && L() !== 1; )
                        ht.push(f.getTokenText()), Le();
                      var Bt = $r === "link" ? r.createJSDocLink : $r === "linkcode" ? r.createJSDocLinkCode : r.createJSDocLinkPlain;
                      return Ue(Bt(st, ht.join("")), sr, f.getTextPos());
                    }
                  }
                  function Or() {
                    if (i(), L() === 18 && Le() === 59 && e.tokenIsIdentifierOrKeyword(Le())) {
                      var sr = f.getTokenValue();
                      if (kt(sr))
                        return sr;
                    }
                  }
                  function kt(sr) {
                    return sr === "link" || sr === "linkcode" || sr === "linkplain";
                  }
                  function $n(sr, $r, Wr, st) {
                    return Ue(r.createJSDocUnknownTag($r, u(sr, Ae(), Wr, st)), sr);
                  }
                  function pa(sr) {
                    sr && (pn ? pn.push(sr) : (pn = [sr], Pn = sr.pos), _i = sr.end);
                  }
                  function Uo() {
                    return i(), L() === 18 ? $2() : void 0;
                  }
                  function Xa() {
                    var sr = zo(22);
                    sr && ii();
                    var $r = zo(61), Wr = Ul();
                    return $r && Mi(61), sr && (ii(), wr(63) && pi(), rr(23)), { name: Wr, isBracketed: sr };
                  }
                  function Ds(sr) {
                    switch (sr.kind) {
                      case 149:
                        return true;
                      case 185:
                        return Ds(sr.elementType);
                      default:
                        return e.isTypeReferenceNode(sr) && e.isIdentifier(sr.typeName) && sr.typeName.escapedText === "Object" && !sr.typeArguments;
                    }
                  }
                  function xs(sr, $r, Wr, st) {
                    var ht = Uo(), Bt = !ht;
                    i();
                    var Cn = Xa(), yi = Cn.name, fi = Cn.isBracketed, Wi = i();
                    Bt && !Gr(Or) && (ht = Uo());
                    var Oi = u(sr, Ae(), st, Wi), ha = Wr !== 4 && qu(ht, yi, Wr, st);
                    ha && (ht = ha, Bt = true);
                    var ws = Wr === 1 ? r.createJSDocPropertyTag($r, yi, fi, ht, Bt, Oi) : r.createJSDocParameterTag($r, yi, fi, ht, Bt, Oi);
                    return Ue(ws, sr);
                  }
                  function qu(sr, $r, Wr, st) {
                    if (sr && Ds(sr.type)) {
                      for (var ht = Ae(), Bt = void 0, Cn = void 0; Bt = Kt(function() {
                        return Lc(Wr, st, $r);
                      }); )
                        (Bt.kind === 343 || Bt.kind === 350) && (Cn = e.append(Cn, Bt));
                      if (Cn) {
                        var yi = Ue(r.createJSDocTypeLiteral(Cn, sr.type.kind === 185), ht);
                        return Ue(r.createJSDocTypeExpression(yi), ht);
                      }
                    }
                  }
                  function Mc(sr, $r, Wr, st) {
                    e.some(pn, e.isJSDocReturnTag) && dn($r.pos, f.getTokenPos(), e.Diagnostics._0_tag_already_specified, $r.escapedText);
                    var ht = Uo();
                    return Ue(r.createJSDocReturnTag($r, ht, u(sr, Ae(), Wr, st)), sr);
                  }
                  function Uu(sr, $r, Wr, st) {
                    e.some(pn, e.isJSDocTypeTag) && dn($r.pos, f.getTokenPos(), e.Diagnostics._0_tag_already_specified, $r.escapedText);
                    var ht = $2(true), Bt = Wr !== void 0 && st !== void 0 ? u(sr, Ae(), Wr, st) : void 0;
                    return Ue(r.createJSDocTypeTag($r, ht, Bt), sr);
                  }
                  function zu(sr, $r, Wr, st) {
                    var ht = L() === 22 || Gr(function() {
                      return Le() === 59 && e.tokenIsIdentifierOrKeyword(Le()) && kt(f.getTokenValue());
                    }), Bt = ht ? void 0 : ce(), Cn = Wr !== void 0 && st !== void 0 ? u(sr, Ae(), Wr, st) : void 0;
                    return Ue(r.createJSDocSeeTag($r, Bt, Cn), sr);
                  }
                  function Il(sr, $r, Wr, st) {
                    var ht = Ae(), Bt = Vu(), Cn = f.getStartPos(), yi = u(sr, Cn, Wr, st);
                    yi || (Cn = f.getStartPos());
                    var fi = typeof yi != "string" ? vn(e.concatenate([Ue(Bt, ht, Cn)], yi), ht) : Bt.text + yi;
                    return Ue(r.createJSDocAuthorTag($r, fi), sr);
                  }
                  function Vu() {
                    for (var sr = [], $r = false, Wr = f.getToken(); Wr !== 1 && Wr !== 4; ) {
                      if (Wr === 29)
                        $r = true;
                      else {
                        if (Wr === 59 && !$r)
                          break;
                        if (Wr === 31 && $r) {
                          sr.push(f.getTokenText()), f.setTextPos(f.getTokenPos() + 1);
                          break;
                        }
                      }
                      sr.push(f.getTokenText()), Wr = Le();
                    }
                    return r.createJSDocText(sr.join(""));
                  }
                  function Ol(sr, $r, Wr, st) {
                    var ht = Wu();
                    return Ue(r.createJSDocImplementsTag($r, ht, u(sr, Ae(), Wr, st)), sr);
                  }
                  function Ml(sr, $r, Wr, st) {
                    var ht = Wu();
                    return Ue(r.createJSDocAugmentsTag($r, ht, u(sr, Ae(), Wr, st)), sr);
                  }
                  function Wu() {
                    var sr = Xr(18), $r = Ae(), Wr = wu(), st = vs(), ht = r.createExpressionWithTypeArguments(Wr, st), Bt = Ue(ht, $r);
                    return sr && rr(19), Bt;
                  }
                  function wu() {
                    for (var sr = Ae(), $r = yo(); Xr(24); ) {
                      var Wr = yo();
                      $r = Ue(r.createPropertyAccessExpression($r, Wr), sr);
                    }
                    return $r;
                  }
                  function Vi(sr, $r, Wr, st, ht) {
                    return Ue($r(Wr, u(sr, Ae(), st, ht)), sr);
                  }
                  function Ll(sr, $r, Wr, st) {
                    var ht = $2(true);
                    return ii(), Ue(r.createJSDocThisTag($r, ht, u(sr, Ae(), Wr, st)), sr);
                  }
                  function Ku(sr, $r, Wr, st) {
                    var ht = $2(true);
                    return ii(), Ue(r.createJSDocEnumTag($r, ht, u(sr, Ae(), Wr, st)), sr);
                  }
                  function Rl(sr, $r, Wr, st) {
                    var ht, Bt = Uo();
                    i();
                    var Cn = Au();
                    ii();
                    var yi = b(Wr), fi;
                    if (!Bt || Ds(Bt.type)) {
                      for (var Wi = void 0, Oi = void 0, ha = void 0, ws = false; Wi = Kt(function() {
                        return Fl(Wr);
                      }); )
                        if (ws = true, Wi.kind === 346)
                          if (Oi) {
                            var Rc = gt(e.Diagnostics.A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags);
                            Rc && e.addRelatedInfo(Rc, e.createDetachedDiagnostic(ct, 0, 0, e.Diagnostics.The_tag_was_first_specified_here));
                            break;
                          } else
                            Oi = Wi;
                        else
                          ha = e.append(ha, Wi);
                      if (ws) {
                        var jc = Bt && Bt.type.kind === 185, As = r.createJSDocTypeLiteral(ha, jc);
                        Bt = Oi && Oi.typeExpression && !Ds(Oi.typeExpression.type) ? Oi.typeExpression : Ue(As, sr), fi = Bt.end;
                      }
                    }
                    fi = fi || yi !== void 0 ? Ae() : ((ht = Cn != null ? Cn : Bt) !== null && ht !== void 0 ? ht : $r).end, yi || (yi = u(sr, fi, Wr, st));
                    var Xu = r.createJSDocTypedefTag($r, Bt, Cn, yi);
                    return Ue(Xu, sr, fi);
                  }
                  function Au(sr) {
                    var $r = f.getTokenPos();
                    if (e.tokenIsIdentifierOrKeyword(L())) {
                      var Wr = yo();
                      if (Xr(24)) {
                        var st = Au(true), ht = r.createModuleDeclaration(void 0, Wr, st, sr ? 4 : void 0);
                        return Ue(ht, $r);
                      }
                      return sr && (Wr.isInJSDocNamespace = true), Wr;
                    }
                  }
                  function jl(sr) {
                    for (var $r = Ae(), Wr, st; Wr = Kt(function() {
                      return Lc(4, sr);
                    }); )
                      st = e.append(st, Wr);
                    return vn(st || [], $r);
                  }
                  function Jl(sr, $r, Wr, st) {
                    var ht = Au();
                    ii();
                    var Bt = b(Wr), Cn = jl(Wr), yi = Kt(function() {
                      if (zo(59)) {
                        var Oi = o(Wr);
                        if (Oi && Oi.kind === 344)
                          return Oi;
                      }
                    }), fi = Ue(r.createJSDocSignature(void 0, Cn, yi), sr);
                    Bt || (Bt = u(sr, Ae(), Wr, st));
                    var Wi = Bt !== void 0 ? Ae() : fi.end;
                    return Ue(r.createJSDocCallbackTag($r, fi, ht, Bt), sr, Wi);
                  }
                  function Hu(sr, $r) {
                    for (; !e.isIdentifier(sr) || !e.isIdentifier($r); )
                      if (!e.isIdentifier(sr) && !e.isIdentifier($r) && sr.right.escapedText === $r.right.escapedText)
                        sr = sr.left, $r = $r.left;
                      else
                        return false;
                    return sr.escapedText === $r.escapedText;
                  }
                  function Fl(sr) {
                    return Lc(1, sr);
                  }
                  function Lc(sr, $r, Wr) {
                    for (var st = true, ht = false; ; )
                      switch (Le()) {
                        case 59:
                          if (st) {
                            var Bt = Bl(sr, $r);
                            return Bt && (Bt.kind === 343 || Bt.kind === 350) && sr !== 4 && Wr && (e.isIdentifier(Bt.name) || !Hu(Wr, Bt.name.left)) ? false : Bt;
                          }
                          ht = false;
                          break;
                        case 4:
                          st = true, ht = false;
                          break;
                        case 41:
                          ht && (st = false), ht = true;
                          break;
                        case 79:
                          st = false;
                          break;
                        case 1:
                          return false;
                      }
                  }
                  function Bl(sr, $r) {
                    e.Debug.assert(L() === 59);
                    var Wr = f.getStartPos();
                    Le();
                    var st = yo();
                    ii();
                    var ht;
                    switch (st.escapedText) {
                      case "type":
                        return sr === 1 && Uu(Wr, st);
                      case "prop":
                      case "property":
                        ht = 1;
                        break;
                      case "arg":
                      case "argument":
                      case "param":
                        ht = 6;
                        break;
                      default:
                        return false;
                    }
                    return sr & ht ? xs(Wr, st, sr, $r) : false;
                  }
                  function ql() {
                    var sr = Ae(), $r = zo(22);
                    $r && ii();
                    var Wr = yo(e.Diagnostics.Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces), st;
                    if ($r && (ii(), rr(63), st = En(8388608, ka), rr(23)), !e.nodeIsMissing(Wr))
                      return Ue(r.createTypeParameterDeclaration(void 0, Wr, void 0, st), sr);
                  }
                  function ku() {
                    var sr = Ae(), $r = [];
                    do {
                      ii();
                      var Wr = ql();
                      Wr !== void 0 && $r.push(Wr), i();
                    } while (zo(27));
                    return vn($r, sr);
                  }
                  function Gu(sr, $r, Wr, st) {
                    var ht = L() === 18 ? $2() : void 0, Bt = ku();
                    return Ue(r.createJSDocTemplateTag($r, ht, Bt, u(sr, Ae(), Wr, st)), sr);
                  }
                  function zo(sr) {
                    return L() === sr ? (Le(), true) : false;
                  }
                  function Ul() {
                    var sr = yo();
                    for (Xr(22) && rr(23); Xr(24); ) {
                      var $r = yo();
                      Xr(22) && rr(23), sr = qn(sr, $r);
                    }
                    return sr;
                  }
                  function yo(sr) {
                    if (!e.tokenIsIdentifierOrKeyword(L()))
                      return Vn(79, !sr, sr || e.Diagnostics.Identifier_expected);
                    de++;
                    var $r = f.getTokenPos(), Wr = f.getTextPos(), st = L(), ht = Ei(f.getTokenValue()), Bt = Ue(r.createIdentifier(ht, void 0, st), $r, Wr);
                    return Le(), Bt;
                  }
                }
              })(Oc = Z.JSDocParser || (Z.JSDocParser = {}));
            })(he || (he = {}));
            var yr;
            (function(Z) {
              function f(Ie, me, xe, Ye) {
                if (Ye = Ye || e.Debug.shouldAssert(2), r(Ie, me, xe, Ye), e.textChangeRangeIsUnchanged(xe))
                  return Ie;
                if (Ie.statements.length === 0)
                  return he.parseSourceFile(Ie.fileName, me, Ie.languageVersion, void 0, true, Ie.scriptKind, Ie.setExternalModuleIndicator);
                var vr = Ie;
                e.Debug.assert(!vr.hasBeenIncrementallyParsed), vr.hasBeenIncrementallyParsed = true, he.fixupParentReferences(vr);
                var nt = Ie.text, pr = ct(Ie), Mr = Ge(Ie, xe);
                r(Ie, me, Mr, Ye), e.Debug.assert(Mr.span.start <= xe.span.start), e.Debug.assert(e.textSpanEnd(Mr.span) === e.textSpanEnd(xe.span)), e.Debug.assert(e.textSpanEnd(e.textChangeRangeNewSpan(Mr)) === e.textSpanEnd(e.textChangeRangeNewSpan(xe)));
                var ot = e.textChangeRangeNewSpan(Mr).length - Mr.span.length;
                pt(vr, Mr.span.start, e.textSpanEnd(Mr.span), e.textSpanEnd(e.textChangeRangeNewSpan(Mr)), ot, nt, me, Ye);
                var At = he.parseSourceFile(Ie.fileName, me, Ie.languageVersion, pr, true, Ie.scriptKind, Ie.setExternalModuleIndicator);
                return At.commentDirectives = h(Ie.commentDirectives, At.commentDirectives, Mr.span.start, e.textSpanEnd(Mr.span), ot, nt, me, Ye), At.impliedNodeFormat = Ie.impliedNodeFormat, At;
              }
              Z.updateSourceFile = f;
              function h(Ie, me, xe, Ye, vr, nt, pr, Mr) {
                if (!Ie)
                  return me;
                for (var ot, At = false, re = 0, de = Ie; re < de.length; re++) {
                  var He = de[re], Nr = He.range, Yr = He.type;
                  if (Nr.end < xe)
                    ot = e.append(ot, He);
                  else if (Nr.pos > Ye) {
                    xt();
                    var Ct = { range: { pos: Nr.pos + vr, end: Nr.end + vr }, type: Yr };
                    ot = e.append(ot, Ct), Mr && e.Debug.assert(nt.substring(Nr.pos, Nr.end) === pr.substring(Ct.range.pos, Ct.range.end));
                  }
                }
                return xt(), ot;
                function xt() {
                  At || (At = true, ot ? me && ot.push.apply(ot, me) : ot = me);
                }
              }
              function oe(Ie, me, xe, Ye, vr, nt) {
                me ? Mr(Ie) : pr(Ie);
                return;
                function pr(ot) {
                  var At = "";
                  if (nt && xr(ot) && (At = Ye.substring(ot.pos, ot.end)), ot._children && (ot._children = void 0), e.setTextRangePosEnd(ot, ot.pos + xe, ot.end + xe), nt && xr(ot) && e.Debug.assert(At === vr.substring(ot.pos, ot.end)), ze(ot, pr, Mr), e.hasJSDocNodes(ot))
                    for (var re = 0, de = ot.jsDoc; re < de.length; re++) {
                      var He = de[re];
                      pr(He);
                    }
                  qr(ot, nt);
                }
                function Mr(ot) {
                  ot._children = void 0, e.setTextRangePosEnd(ot, ot.pos + xe, ot.end + xe);
                  for (var At = 0, re = ot; At < re.length; At++) {
                    var de = re[At];
                    pr(de);
                  }
                }
              }
              function xr(Ie) {
                switch (Ie.kind) {
                  case 10:
                  case 8:
                  case 79:
                    return true;
                }
                return false;
              }
              function jr(Ie, me, xe, Ye, vr) {
                e.Debug.assert(Ie.end >= me, "Adjusting an element that was entirely before the change range"), e.Debug.assert(Ie.pos <= xe, "Adjusting an element that was entirely after the change range"), e.Debug.assert(Ie.pos <= Ie.end);
                var nt = Math.min(Ie.pos, Ye), pr = Ie.end >= xe ? Ie.end + vr : Math.min(Ie.end, Ye);
                e.Debug.assert(nt <= pr), Ie.parent && (e.Debug.assertGreaterThanOrEqual(nt, Ie.parent.pos), e.Debug.assertLessThanOrEqual(pr, Ie.parent.end)), e.setTextRangePosEnd(Ie, nt, pr);
              }
              function qr(Ie, me) {
                if (me) {
                  var xe = Ie.pos, Ye = function(Mr) {
                    e.Debug.assert(Mr.pos >= xe), xe = Mr.end;
                  };
                  if (e.hasJSDocNodes(Ie))
                    for (var vr = 0, nt = Ie.jsDoc; vr < nt.length; vr++) {
                      var pr = nt[vr];
                      Ye(pr);
                    }
                  ze(Ie, Ye), e.Debug.assert(xe <= Ie.end);
                }
              }
              function pt(Ie, me, xe, Ye, vr, nt, pr, Mr) {
                ot(Ie);
                return;
                function ot(re) {
                  if (e.Debug.assert(re.pos <= re.end), re.pos > xe) {
                    oe(re, false, vr, nt, pr, Mr);
                    return;
                  }
                  var de = re.end;
                  if (de >= me) {
                    if (re.intersectsChange = true, re._children = void 0, jr(re, me, xe, Ye, vr), ze(re, ot, At), e.hasJSDocNodes(re))
                      for (var He = 0, Nr = re.jsDoc; He < Nr.length; He++) {
                        var Yr = Nr[He];
                        ot(Yr);
                      }
                    qr(re, Mr);
                    return;
                  }
                  e.Debug.assert(de < me);
                }
                function At(re) {
                  if (e.Debug.assert(re.pos <= re.end), re.pos > xe) {
                    oe(re, true, vr, nt, pr, Mr);
                    return;
                  }
                  var de = re.end;
                  if (de >= me) {
                    re.intersectsChange = true, re._children = void 0, jr(re, me, xe, Ye, vr);
                    for (var He = 0, Nr = re; He < Nr.length; He++) {
                      var Yr = Nr[He];
                      ot(Yr);
                    }
                    return;
                  }
                  e.Debug.assert(de < me);
                }
              }
              function Ge(Ie, me) {
                for (var xe = 1, Ye = me.span.start, vr = 0; Ye > 0 && vr <= xe; vr++) {
                  var nt = K(Ie, Ye);
                  e.Debug.assert(nt.pos <= Ye);
                  var pr = nt.pos;
                  Ye = Math.max(0, pr - 1);
                }
                var Mr = e.createTextSpanFromBounds(Ye, e.textSpanEnd(me.span)), ot = me.newLength + (me.span.start - Ye);
                return e.createTextChangeRange(Mr, ot);
              }
              function K(Ie, me) {
                var xe = Ie, Ye;
                if (ze(Ie, pr), Ye) {
                  var vr = nt(Ye);
                  vr.pos > xe.pos && (xe = vr);
                }
                return xe;
                function nt(Mr) {
                  for (; ; ) {
                    var ot = e.getLastChild(Mr);
                    if (ot)
                      Mr = ot;
                    else
                      return Mr;
                  }
                }
                function pr(Mr) {
                  if (!e.nodeIsMissing(Mr))
                    if (Mr.pos <= me) {
                      if (Mr.pos >= xe.pos && (xe = Mr), me < Mr.end)
                        return ze(Mr, pr), true;
                      e.Debug.assert(Mr.end <= me), Ye = Mr;
                    } else
                      return e.Debug.assert(Mr.pos > me), true;
                }
              }
              function r(Ie, me, xe, Ye) {
                var vr = Ie.text;
                if (xe && (e.Debug.assert(vr.length - xe.span.length + xe.newLength === me.length), Ye || e.Debug.shouldAssert(3))) {
                  var nt = vr.substr(0, xe.span.start), pr = me.substr(0, xe.span.start);
                  e.Debug.assert(nt === pr);
                  var Mr = vr.substring(e.textSpanEnd(xe.span), vr.length), ot = me.substring(e.textSpanEnd(e.textChangeRangeNewSpan(xe)), me.length);
                  e.Debug.assert(Mr === ot);
                }
              }
              function ct(Ie) {
                var me = Ie.statements, xe = 0;
                e.Debug.assert(xe < me.length);
                var Ye = me[xe], vr = -1;
                return { currentNode: function(pr) {
                  return pr !== vr && (Ye && Ye.end === pr && xe < me.length - 1 && (xe++, Ye = me[xe]), (!Ye || Ye.pos !== pr) && nt(pr)), vr = pr, e.Debug.assert(!Ye || Ye.pos === pr), Ye;
                } };
                function nt(pr) {
                  me = void 0, xe = -1, Ye = void 0, ze(Ie, Mr, ot);
                  return;
                  function Mr(At) {
                    return pr >= At.pos && pr < At.end ? (ze(At, Mr, ot), true) : false;
                  }
                  function ot(At) {
                    if (pr >= At.pos && pr < At.end)
                      for (var re = 0; re < At.length; re++) {
                        var de = At[re];
                        if (de) {
                          if (de.pos === pr)
                            return me = At, xe = re, Ye = de, true;
                          if (de.pos < pr && pr < de.end)
                            return ze(de, Mr, ot), true;
                        }
                      }
                    return false;
                  }
                }
              }
              Z.createSyntaxCursor = ct;
              var ft;
              (function(Ie) {
                Ie[Ie.Value = -1] = "Value";
              })(ft || (ft = {}));
            })(yr || (yr = {}));
            function kr(Z) {
              return e.fileExtensionIsOneOf(Z, e.supportedDeclarationExtensions);
            }
            e.isDeclarationFileName = kr;
            function nr(Z, f, h, oe) {
              if (Z) {
                if (Z === "import")
                  return e.ModuleKind.ESNext;
                if (Z === "require")
                  return e.ModuleKind.CommonJS;
                oe(f, h - f, e.Diagnostics.resolution_mode_should_be_either_require_or_import);
              }
            }
            function tr(Z, f) {
              for (var h = [], oe = 0, xr = e.getLeadingCommentRanges(f, 0) || e.emptyArray; oe < xr.length; oe++) {
                var jr = xr[oe], qr = f.substring(jr.pos, jr.end);
                Pr(h, jr, qr);
              }
              Z.pragmas = new e.Map();
              for (var pt = 0, Ge = h; pt < Ge.length; pt++) {
                var K = Ge[pt];
                if (Z.pragmas.has(K.name)) {
                  var r = Z.pragmas.get(K.name);
                  r instanceof Array ? r.push(K.args) : Z.pragmas.set(K.name, [r, K.args]);
                  continue;
                }
                Z.pragmas.set(K.name, K.args);
              }
            }
            e.processCommentPragmas = tr;
            function Lr(Z, f) {
              Z.checkJsDirective = void 0, Z.referencedFiles = [], Z.typeReferenceDirectives = [], Z.libReferenceDirectives = [], Z.amdDependencies = [], Z.hasNoDefaultLib = false, Z.pragmas.forEach(function(h, oe) {
                switch (oe) {
                  case "reference": {
                    var xr = Z.referencedFiles, jr = Z.typeReferenceDirectives, qr = Z.libReferenceDirectives;
                    e.forEach(e.toArray(h), function(r) {
                      var ct = r.arguments, ft = ct.types, Ie = ct.lib, me = ct.path, xe = ct["resolution-mode"];
                      if (r.arguments["no-default-lib"])
                        Z.hasNoDefaultLib = true;
                      else if (ft) {
                        var Ye = nr(xe, ft.pos, ft.end, f);
                        jr.push(T({ pos: ft.pos, end: ft.end, fileName: ft.value }, Ye ? { resolutionMode: Ye } : {}));
                      } else
                        Ie ? qr.push({ pos: Ie.pos, end: Ie.end, fileName: Ie.value }) : me ? xr.push({ pos: me.pos, end: me.end, fileName: me.value }) : f(r.range.pos, r.range.end - r.range.pos, e.Diagnostics.Invalid_reference_directive_syntax);
                    });
                    break;
                  }
                  case "amd-dependency": {
                    Z.amdDependencies = e.map(e.toArray(h), function(r) {
                      return { name: r.arguments.name, path: r.arguments.path };
                    });
                    break;
                  }
                  case "amd-module": {
                    if (h instanceof Array)
                      for (var pt = 0, Ge = h; pt < Ge.length; pt++) {
                        var K = Ge[pt];
                        Z.moduleName && f(K.range.pos, K.range.end - K.range.pos, e.Diagnostics.An_AMD_module_cannot_have_multiple_name_assignments), Z.moduleName = K.arguments.name;
                      }
                    else
                      Z.moduleName = h.arguments.name;
                    break;
                  }
                  case "ts-nocheck":
                  case "ts-check": {
                    e.forEach(e.toArray(h), function(r) {
                      (!Z.checkJsDirective || r.range.pos > Z.checkJsDirective.pos) && (Z.checkJsDirective = { enabled: oe === "ts-check", end: r.range.end, pos: r.range.pos });
                    });
                    break;
                  }
                  case "jsx":
                  case "jsxfrag":
                  case "jsximportsource":
                  case "jsxruntime":
                    return;
                  default:
                    e.Debug.fail("Unhandled pragma kind");
                }
              });
            }
            e.processPragmasIntoFields = Lr;
            var zr = new e.Map();
            function ye(Z) {
              if (zr.has(Z))
                return zr.get(Z);
              var f = new RegExp("(\\s".concat(Z, `\\s*=\\s*)(?:(?:'([^']*)')|(?:"([^"]*)"))`), "im");
              return zr.set(Z, f), f;
            }
            var ir = /^\/\/\/\s*<(\S+)\s.*?\/>/im, Dr = /^\/\/\/?\s*@(\S+)\s*(.*)\s*$/im;
            function Pr(Z, f, h) {
              var oe = f.kind === 2 && ir.exec(h);
              if (oe) {
                var xr = oe[1].toLowerCase(), jr = e.commentPragmas[xr];
                if (!jr || !(jr.kind & 1))
                  return;
                if (jr.args) {
                  for (var qr = {}, pt = 0, Ge = jr.args; pt < Ge.length; pt++) {
                    var K = Ge[pt], r = ye(K.name), ct = r.exec(h);
                    if (!ct && !K.optional)
                      return;
                    if (ct) {
                      var ft = ct[2] || ct[3];
                      if (K.captureSpan) {
                        var Ie = f.pos + ct.index + ct[1].length + 1;
                        qr[K.name] = { value: ft, pos: Ie, end: Ie + ft.length };
                      } else
                        qr[K.name] = ft;
                    }
                  }
                  Z.push({ name: xr, args: { arguments: qr, range: f } });
                } else
                  Z.push({ name: xr, args: { arguments: {}, range: f } });
                return;
              }
              var me = f.kind === 2 && Dr.exec(h);
              if (me)
                return Br(Z, f, 2, me);
              if (f.kind === 3)
                for (var xe = /@(\S+)(\s+.*)?$/gim, Ye = void 0; Ye = xe.exec(h); )
                  Br(Z, f, 4, Ye);
            }
            function Br(Z, f, h, oe) {
              if (oe) {
                var xr = oe[1].toLowerCase(), jr = e.commentPragmas[xr];
                if (!(!jr || !(jr.kind & h))) {
                  var qr = oe[2], pt = ut(jr, qr);
                  pt !== "fail" && Z.push({ name: xr, args: { arguments: pt, range: f } });
                }
              }
            }
            function ut(Z, f) {
              if (!f)
                return {};
              if (!Z.args)
                return {};
              for (var h = e.trimString(f).split(/\s+/), oe = {}, xr = 0; xr < Z.args.length; xr++) {
                var jr = Z.args[xr];
                if (!h[xr] && !jr.optional)
                  return "fail";
                if (jr.captureSpan)
                  return e.Debug.fail("Capture spans not yet implemented for non-xml pragmas");
                oe[jr.name] = h[xr];
              }
              return oe;
            }
            function rt(Z, f) {
              return Z.kind !== f.kind ? false : Z.kind === 79 ? Z.escapedText === f.escapedText : Z.kind === 108 ? true : Z.name.escapedText === f.name.escapedText && rt(Z.expression, f.expression);
            }
            e.tagNamesAreEquivalent = rt;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(B) {
              B[B.NonInstantiated = 0] = "NonInstantiated", B[B.Instantiated = 1] = "Instantiated", B[B.ConstEnumOnly = 2] = "ConstEnumOnly";
            })(t3 = e.ModuleInstanceState || (e.ModuleInstanceState = {}));
            function w(B, U) {
              return B.body && !B.body.parent && (e.setParent(B.body, B), e.setParentRecursive(B.body, false)), B.body ? s(B.body, U) : 1;
            }
            e.getModuleInstanceState = w;
            function s(B, U) {
              U === void 0 && (U = new e.Map());
              var m = e.getNodeId(B);
              if (U.has(m))
                return U.get(m) || 0;
              U.set(m, void 0);
              var v = q(B, U);
              return U.set(m, v), v;
            }
            function q(B, U) {
              switch (B.kind) {
                case 261:
                case 262:
                  return 0;
                case 263:
                  if (e.isEnumConst(B))
                    return 2;
                  break;
                case 269:
                case 268:
                  if (!e.hasSyntacticModifier(B, 1))
                    return 0;
                  break;
                case 275:
                  var m = B;
                  if (!m.moduleSpecifier && m.exportClause && m.exportClause.kind === 276) {
                    for (var v = 0, g = 0, O = m.exportClause.elements; g < O.length; g++) {
                      var S = O[g], te = F(S, U);
                      if (te > v && (v = te), v === 1)
                        return v;
                    }
                    return v;
                  }
                  break;
                case 265: {
                  var Je = 0;
                  return e.forEachChild(B, function(qe) {
                    var ge = s(qe, U);
                    switch (ge) {
                      case 0:
                        return;
                      case 2:
                        Je = 2;
                        return;
                      case 1:
                        return Je = 1, true;
                      default:
                        e.Debug.assertNever(ge);
                    }
                  }), Je;
                }
                case 264:
                  return w(B, U);
                case 79:
                  if (B.isInJSDocNamespace)
                    return 0;
              }
              return 1;
            }
            function F(B, U) {
              for (var m = B.propertyName || B.name, v = B.parent; v; ) {
                if (e.isBlock(v) || e.isModuleBlock(v) || e.isSourceFile(v)) {
                  for (var g = v.statements, O = void 0, S = 0, te = g; S < te.length; S++) {
                    var Je = te[S];
                    if (e.nodeHasName(Je, m)) {
                      Je.parent || (e.setParent(Je, v), e.setParentRecursive(Je, false));
                      var qe = s(Je, U);
                      if ((O === void 0 || qe > O) && (O = qe), O === 1)
                        return O;
                    }
                  }
                  if (O !== void 0)
                    return O;
                }
                v = v.parent;
              }
              return 1;
            }
            var fe;
            (function(B) {
              B[B.None = 0] = "None", B[B.IsContainer = 1] = "IsContainer", B[B.IsBlockScopedContainer = 2] = "IsBlockScopedContainer", B[B.IsControlFlowContainer = 4] = "IsControlFlowContainer", B[B.IsFunctionLike = 8] = "IsFunctionLike", B[B.IsFunctionExpression = 16] = "IsFunctionExpression", B[B.HasLocals = 32] = "HasLocals", B[B.IsInterface = 64] = "IsInterface", B[B.IsObjectLiteralOrClassExpressionMethodOrAccessor = 128] = "IsObjectLiteralOrClassExpressionMethodOrAccessor";
            })(fe || (fe = {}));
            function Ee(B) {
              return e.Debug.attachFlowNodeDebugInfo(B), B;
            }
            var Se = se();
            function J(B, U) {
              e.performance.mark("beforeBind"), e.perfLogger.logStartBindFile("" + B.fileName), Se(B, U), e.perfLogger.logStopBindFile(), e.performance.mark("afterBind"), e.performance.measure("Bind", "beforeBind", "afterBind");
            }
            e.bindSourceFile = J;
            function se() {
              var B, U, m, v, g, O, S, te, Je, qe, ge, ie, H, pe, j, be, Xe, Re, Fe, dr, ze, ve, er = false, ar = 0, Cr, Ce, $e = { flags: 1 }, gr = { flags: 1 }, X = hn();
              function Te(p, ne, Ne, or, it2) {
                return e.createDiagnosticForNodeInSourceFile(e.getSourceFileOfNode(p) || B, p, ne, Ne, or, it2);
              }
              function we(p, ne) {
                B = p, U = ne, m = e.getEmitScriptTarget(U), ve = he(B, ne), Ce = new e.Set(), ar = 0, Cr = e.objectAllocator.getSymbolConstructor(), e.Debug.attachFlowNodeDebugInfo($e), e.Debug.attachFlowNodeDebugInfo(gr), B.locals || (e.tracing === null || e.tracing === void 0 || e.tracing.push("bind", "bindSourceFile", { path: B.path }, true), wr(B), e.tracing === null || e.tracing === void 0 || e.tracing.pop(), B.symbolCount = ar, B.classifiableNames = Ce, _r()), B = void 0, U = void 0, m = void 0, v = void 0, g = void 0, O = void 0, S = void 0, te = void 0, Je = void 0, qe = false, ge = void 0, ie = void 0, H = void 0, pe = void 0, j = void 0, be = void 0, Xe = void 0, Fe = void 0, dr = false, er = false, ze = 0;
              }
              return we;
              function he(p, ne) {
                return e.getStrictOptionValue(ne, "alwaysStrict") && !p.isDeclarationFile ? true : !!p.externalModuleIndicator;
              }
              function yr(p, ne) {
                return ar++, new Cr(p, ne);
              }
              function kr(p, ne, Ne) {
                p.flags |= Ne, ne.symbol = p, p.declarations = e.appendIfUnique(p.declarations, ne), Ne & 1955 && !p.exports && (p.exports = e.createSymbolTable()), Ne & 6240 && !p.members && (p.members = e.createSymbolTable()), p.constEnumOnlyModule && p.flags & 304 && (p.constEnumOnlyModule = false), Ne & 111551 && e.setValueDeclaration(p, ne);
              }
              function nr(p) {
                if (p.kind === 274)
                  return p.isExportEquals ? "export=" : "default";
                var ne = e.getNameOfDeclaration(p);
                if (ne) {
                  if (e.isAmbientModule(p)) {
                    var Ne = e.getTextOfIdentifierOrLiteral(ne);
                    return e.isGlobalScopeAugmentation(p) ? "__global" : '"'.concat(Ne, '"');
                  }
                  if (ne.kind === 164) {
                    var or = ne.expression;
                    if (e.isStringOrNumericLiteralLike(or))
                      return e.escapeLeadingUnderscores(or.text);
                    if (e.isSignedNumericLiteral(or))
                      return e.tokenToString(or.operator) + or.operand.text;
                    e.Debug.fail("Only computed properties with literal names have declaration names");
                  }
                  if (e.isPrivateIdentifier(ne)) {
                    var it2 = e.getContainingClass(p);
                    if (!it2)
                      return;
                    var vt = it2.symbol;
                    return e.getSymbolNameForPrivateIdentifier(vt, ne.escapedText);
                  }
                  return e.isPropertyNameLiteral(ne) ? e.getEscapedTextOfIdentifierOrLiteral(ne) : void 0;
                }
                switch (p.kind) {
                  case 173:
                    return "__constructor";
                  case 181:
                  case 176:
                  case 326:
                    return "__call";
                  case 182:
                  case 177:
                    return "__new";
                  case 178:
                    return "__index";
                  case 275:
                    return "__export";
                  case 308:
                    return "export=";
                  case 223:
                    if (e.getAssignmentDeclarationKind(p) === 2)
                      return "export=";
                    e.Debug.fail("Unknown binary declaration kind");
                    break;
                  case 320:
                    return e.isJSDocConstructSignature(p) ? "__new" : "__call";
                  case 166:
                    e.Debug.assert(p.parent.kind === 320, "Impossible parameter parent kind", function() {
                      return "parent is: ".concat(e.Debug.formatSyntaxKind(p.parent.kind), ", expected JSDocFunctionType");
                    });
                    var Tt = p.parent, St = Tt.parameters.indexOf(p);
                    return "arg" + St;
                }
              }
              function tr(p) {
                return e.isNamedDeclaration(p) ? e.declarationNameToString(p.name) : e.unescapeLeadingUnderscores(e.Debug.checkDefined(nr(p)));
              }
              function Lr(p, ne, Ne, or, it2, vt, Tt) {
                e.Debug.assert(Tt || !e.hasDynamicName(Ne));
                var St = e.hasSyntacticModifier(Ne, 1024) || e.isExportSpecifier(Ne) && Ne.name.escapedText === "default", tn = Tt ? "__computed" : St && ne ? "default" : nr(Ne), Mt;
                if (tn === void 0)
                  Mt = yr(0, "__missing");
                else if (Mt = p.get(tn), or & 2885600 && Ce.add(tn), !Mt)
                  p.set(tn, Mt = yr(0, tn)), vt && (Mt.isReplaceableByMethod = true);
                else {
                  if (vt && !Mt.isReplaceableByMethod)
                    return Mt;
                  if (Mt.flags & it2) {
                    if (Mt.isReplaceableByMethod)
                      p.set(tn, Mt = yr(0, tn));
                    else if (!(or & 3 && Mt.flags & 67108864)) {
                      e.isNamedDeclaration(Ne) && e.setParent(Ne.name, Ne);
                      var $t = Mt.flags & 2 ? e.Diagnostics.Cannot_redeclare_block_scoped_variable_0 : e.Diagnostics.Duplicate_identifier_0, y = true;
                      (Mt.flags & 384 || or & 384) && ($t = e.Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations, y = false);
                      var De = false;
                      e.length(Mt.declarations) && (St || Mt.declarations && Mt.declarations.length && Ne.kind === 274 && !Ne.isExportEquals) && ($t = e.Diagnostics.A_module_cannot_have_multiple_default_exports, y = false, De = true);
                      var R = [];
                      e.isTypeAliasDeclaration(Ne) && e.nodeIsMissing(Ne.type) && e.hasSyntacticModifier(Ne, 1) && Mt.flags & 2887656 && R.push(Te(Ne, e.Diagnostics.Did_you_mean_0, "export type { ".concat(e.unescapeLeadingUnderscores(Ne.name.escapedText), " }")));
                      var Jt = e.getNameOfDeclaration(Ne) || Ne;
                      e.forEach(Mt.declarations, function(qn, Ni) {
                        var _a = e.getNameOfDeclaration(qn) || qn, Ri = Te(_a, $t, y ? tr(qn) : void 0);
                        B.bindDiagnostics.push(De ? e.addRelatedInfo(Ri, Te(Jt, Ni === 0 ? e.Diagnostics.Another_export_default_is_here : e.Diagnostics.and_here)) : Ri), De && R.push(Te(_a, e.Diagnostics.The_first_export_default_is_here));
                      });
                      var Qt = Te(Jt, $t, y ? tr(Ne) : void 0);
                      B.bindDiagnostics.push(e.addRelatedInfo.apply(void 0, D([Qt], R, false))), Mt = yr(0, tn);
                    }
                  }
                }
                return kr(Mt, Ne, or), Mt.parent ? e.Debug.assert(Mt.parent === ne, "Existing symbol parent should match new one") : Mt.parent = ne, Mt;
              }
              function zr(p, ne, Ne) {
                var or = !!(e.getCombinedModifierFlags(p) & 1) || ye(p);
                if (ne & 2097152)
                  return p.kind === 278 || p.kind === 268 && or ? Lr(g.symbol.exports, g.symbol, p, ne, Ne) : Lr(g.locals, void 0, p, ne, Ne);
                if (e.isJSDocTypeAlias(p) && e.Debug.assert(e.isInJSFile(p)), !e.isAmbientModule(p) && (or || g.flags & 64)) {
                  if (!g.locals || e.hasSyntacticModifier(p, 1024) && !nr(p))
                    return Lr(g.symbol.exports, g.symbol, p, ne, Ne);
                  var it2 = ne & 111551 ? 1048576 : 0, vt = Lr(g.locals, void 0, p, it2, Ne);
                  return vt.exportSymbol = Lr(g.symbol.exports, g.symbol, p, ne, Ne), p.localSymbol = vt, vt;
                } else
                  return Lr(g.locals, void 0, p, ne, Ne);
              }
              function ye(p) {
                if (p.parent && e.isModuleDeclaration(p) && (p = p.parent), !e.isJSDocTypeAlias(p))
                  return false;
                if (!e.isJSDocEnumTag(p) && p.fullName)
                  return true;
                var ne = e.getNameOfDeclaration(p);
                return ne ? !!(e.isPropertyAccessEntityNameExpression(ne.parent) && jt(ne.parent) || e.isDeclaration(ne.parent) && e.getCombinedModifierFlags(ne.parent) & 1) : false;
              }
              function ir(p, ne) {
                var Ne = g, or = O, it2 = S;
                if (ne & 1 ? (p.kind !== 216 && (O = g), g = S = p, ne & 32 && (g.locals = e.createSymbolTable()), Fn(g)) : ne & 2 && (S = p, S.locals = void 0), ne & 4) {
                  var vt = ge, Tt = ie, St = H, tn = pe, Mt = Xe, $t = Fe, y = dr, De = ne & 16 && !e.hasSyntacticModifier(p, 512) && !p.asteriskToken && !!e.getImmediatelyInvokedFunctionExpression(p) || p.kind === 172;
                  De || (ge = Ee({ flags: 2 }), ne & 144 && (ge.node = p)), pe = De || p.kind === 173 || e.isInJSFile(p) && (p.kind === 259 || p.kind === 215) ? qr() : void 0, Xe = void 0, ie = void 0, H = void 0, Fe = void 0, dr = false, ut(p), p.flags &= -2817, !(ge.flags & 1) && ne & 8 && e.nodeIsPresent(p.body) && (p.flags |= 256, dr && (p.flags |= 512), p.endFlowNode = ge), p.kind === 308 && (p.flags |= ze, p.endFlowNode = ge), pe && (r(pe, ge), ge = xe(pe), (p.kind === 173 || p.kind === 172 || e.isInJSFile(p) && (p.kind === 259 || p.kind === 215)) && (p.returnFlowNode = ge)), De || (ge = vt), ie = Tt, H = St, pe = tn, Xe = Mt, Fe = $t, dr = y;
                } else
                  ne & 64 ? (qe = false, ut(p), p.flags = qe ? p.flags | 128 : p.flags & -129) : ut(p);
                g = Ne, O = or, S = it2;
              }
              function Dr(p) {
                Pr(p, function(ne) {
                  return ne.kind === 259 ? wr(ne) : void 0;
                }), Pr(p, function(ne) {
                  return ne.kind !== 259 ? wr(ne) : void 0;
                });
              }
              function Pr(p, ne) {
                ne === void 0 && (ne = wr), p !== void 0 && e.forEach(p, ne);
              }
              function Br(p) {
                e.forEachChild(p, wr, Pr);
              }
              function ut(p) {
                var ne = er;
                if (er = false, Li(p)) {
                  Br(p), fn(p), er = ne;
                  return;
                }
                switch (p.kind >= 240 && p.kind <= 256 && !U.allowUnreachableCode && (p.flowNode = ge), p.kind) {
                  case 244:
                    de(p);
                    break;
                  case 243:
                    He(p);
                    break;
                  case 245:
                    Nr(p);
                    break;
                  case 246:
                  case 247:
                    Yr(p);
                    break;
                  case 242:
                    Ct(p);
                    break;
                  case 250:
                  case 254:
                    xt(p);
                    break;
                  case 249:
                  case 248:
                    Zt(p);
                    break;
                  case 255:
                    mt(p);
                    break;
                  case 252:
                    at(p);
                    break;
                  case 266:
                    k(p);
                    break;
                  case 292:
                    ue(p);
                    break;
                  case 241:
                    Qe(p);
                    break;
                  case 253:
                    Kr(p);
                    break;
                  case 221:
                    cn(p);
                    break;
                  case 222:
                    In(p);
                    break;
                  case 223:
                    if (e.isDestructuringAssignment(p)) {
                      er = ne, yn(p);
                      return;
                    }
                    X(p);
                    break;
                  case 217:
                    ln(p);
                    break;
                  case 224:
                    En(p);
                    break;
                  case 257:
                    ui(p);
                    break;
                  case 208:
                  case 209:
                    si(p);
                    break;
                  case 210:
                    di(p);
                    break;
                  case 232:
                    Kn(p);
                    break;
                  case 348:
                  case 341:
                  case 342:
                    vi(p);
                    break;
                  case 308: {
                    Dr(p.statements), wr(p.endOfFileToken);
                    break;
                  }
                  case 238:
                  case 265:
                    Dr(p.statements);
                    break;
                  case 205:
                    ei(p);
                    break;
                  case 166:
                    hi(p);
                    break;
                  case 207:
                  case 206:
                  case 299:
                  case 227:
                    er = ne;
                  default:
                    Br(p);
                    break;
                }
                fn(p), er = ne;
              }
              function rt(p) {
                switch (p.kind) {
                  case 79:
                  case 80:
                  case 108:
                  case 208:
                  case 209:
                    return f(p);
                  case 210:
                    return h(p);
                  case 214:
                  case 232:
                    return rt(p.expression);
                  case 223:
                    return xr(p);
                  case 221:
                    return p.operator === 53 && rt(p.operand);
                  case 218:
                    return rt(p.expression);
                }
                return false;
              }
              function Z(p) {
                return e.isDottedName(p) || (e.isPropertyAccessExpression(p) || e.isNonNullExpression(p) || e.isParenthesizedExpression(p)) && Z(p.expression) || e.isBinaryExpression(p) && p.operatorToken.kind === 27 && Z(p.right) || e.isElementAccessExpression(p) && (e.isStringOrNumericLiteralLike(p.argumentExpression) || e.isEntityNameExpression(p.argumentExpression)) && Z(p.expression) || e.isAssignmentExpression(p) && Z(p.left);
              }
              function f(p) {
                return Z(p) || e.isOptionalChain(p) && f(p.expression);
              }
              function h(p) {
                if (p.arguments)
                  for (var ne = 0, Ne = p.arguments; ne < Ne.length; ne++) {
                    var or = Ne[ne];
                    if (f(or))
                      return true;
                  }
                return !!(p.expression.kind === 208 && f(p.expression.expression));
              }
              function oe(p, ne) {
                return e.isTypeOfExpression(p) && jr(p.expression) && e.isStringLiteralLike(ne);
              }
              function xr(p) {
                switch (p.operatorToken.kind) {
                  case 63:
                  case 75:
                  case 76:
                  case 77:
                    return f(p.left);
                  case 34:
                  case 35:
                  case 36:
                  case 37:
                    return jr(p.left) || jr(p.right) || oe(p.right, p.left) || oe(p.left, p.right);
                  case 102:
                    return jr(p.left);
                  case 101:
                    return rt(p.right);
                  case 27:
                    return rt(p.right);
                }
                return false;
              }
              function jr(p) {
                switch (p.kind) {
                  case 214:
                    return jr(p.expression);
                  case 223:
                    switch (p.operatorToken.kind) {
                      case 63:
                        return jr(p.left);
                      case 27:
                        return jr(p.right);
                    }
                }
                return f(p);
              }
              function qr() {
                return Ee({ flags: 4, antecedents: void 0 });
              }
              function pt() {
                return Ee({ flags: 8, antecedents: void 0 });
              }
              function Ge(p, ne, Ne) {
                return Ee({ flags: 1024, target: p, antecedents: ne, antecedent: Ne });
              }
              function K(p) {
                p.flags |= p.flags & 2048 ? 4096 : 2048;
              }
              function r(p, ne) {
                !(ne.flags & 1) && !e.contains(p.antecedents, ne) && ((p.antecedents || (p.antecedents = [])).push(ne), K(ne));
              }
              function ct(p, ne, Ne) {
                return ne.flags & 1 ? ne : Ne ? (Ne.kind === 110 && p & 64 || Ne.kind === 95 && p & 32) && !e.isExpressionOfOptionalChainRoot(Ne) && !e.isNullishCoalesce(Ne.parent) ? $e : rt(Ne) ? (K(ne), Ee({ flags: p, antecedent: ne, node: Ne })) : ne : p & 32 ? ne : $e;
              }
              function ft(p, ne, Ne, or) {
                return K(p), Ee({ flags: 128, antecedent: p, switchStatement: ne, clauseStart: Ne, clauseEnd: or });
              }
              function Ie(p, ne, Ne) {
                K(ne);
                var or = Ee({ flags: p, antecedent: ne, node: Ne });
                return Xe && r(Xe, or), or;
              }
              function me(p, ne) {
                return K(p), Ee({ flags: 512, antecedent: p, node: ne });
              }
              function xe(p) {
                var ne = p.antecedents;
                return ne ? ne.length === 1 ? ne[0] : p : $e;
              }
              function Ye(p) {
                var ne = p.parent;
                switch (ne.kind) {
                  case 242:
                  case 244:
                  case 243:
                    return ne.expression === p;
                  case 245:
                  case 224:
                    return ne.condition === p;
                }
                return false;
              }
              function vr(p) {
                for (; ; )
                  if (p.kind === 214)
                    p = p.expression;
                  else if (p.kind === 221 && p.operator === 53)
                    p = p.operand;
                  else
                    return p.kind === 223 && (p.operatorToken.kind === 55 || p.operatorToken.kind === 56 || p.operatorToken.kind === 60);
              }
              function nt(p) {
                return p = e.skipParentheses(p), e.isBinaryExpression(p) && e.isLogicalOrCoalescingAssignmentOperator(p.operatorToken.kind);
              }
              function pr(p) {
                for (; e.isParenthesizedExpression(p.parent) || e.isPrefixUnaryExpression(p.parent) && p.parent.operator === 53; )
                  p = p.parent;
                return !Ye(p) && !vr(p.parent) && !(e.isOptionalChain(p.parent) && p.parent.expression === p);
              }
              function Mr(p, ne, Ne, or) {
                var it2 = j, vt = be;
                j = Ne, be = or, p(ne), j = it2, be = vt;
              }
              function ot(p, ne, Ne) {
                Mr(wr, p, ne, Ne), (!p || !nt(p) && !vr(p) && !(e.isOptionalChain(p) && e.isOutermostOptionalChain(p))) && (r(ne, ct(32, ge, p)), r(Ne, ct(64, ge, p)));
              }
              function At(p, ne, Ne) {
                var or = ie, it2 = H;
                ie = ne, H = Ne, wr(p), ie = or, H = it2;
              }
              function re(p, ne) {
                for (var Ne = Fe; Ne && p.parent.kind === 253; )
                  Ne.continueTarget = ne, Ne = Ne.next, p = p.parent;
                return ne;
              }
              function de(p) {
                var ne = re(p, pt()), Ne = qr(), or = qr();
                r(ne, ge), ge = ne, ot(p.expression, Ne, or), ge = xe(Ne), At(p.statement, or, ne), r(ne, ge), ge = xe(or);
              }
              function He(p) {
                var ne = pt(), Ne = re(p, qr()), or = qr();
                r(ne, ge), ge = ne, At(p.statement, or, Ne), r(Ne, ge), ge = xe(Ne), ot(p.expression, ne, or), ge = xe(or);
              }
              function Nr(p) {
                var ne = re(p, pt()), Ne = qr(), or = qr();
                wr(p.initializer), r(ne, ge), ge = ne, ot(p.condition, Ne, or), ge = xe(Ne), At(p.statement, or, ne), wr(p.incrementor), r(ne, ge), ge = xe(or);
              }
              function Yr(p) {
                var ne = re(p, pt()), Ne = qr();
                wr(p.expression), r(ne, ge), ge = ne, p.kind === 247 && wr(p.awaitModifier), r(Ne, ge), wr(p.initializer), p.initializer.kind !== 258 && Dt(p.initializer), At(p.statement, Ne, ne), r(ne, ge), ge = xe(Ne);
              }
              function Ct(p) {
                var ne = qr(), Ne = qr(), or = qr();
                ot(p.expression, ne, Ne), ge = xe(ne), wr(p.thenStatement), r(or, ge), ge = xe(Ne), wr(p.elseStatement), r(or, ge), ge = xe(or);
              }
              function xt(p) {
                wr(p.expression), p.kind === 250 && (dr = true, pe && r(pe, ge)), ge = $e;
              }
              function Lt(p) {
                for (var ne = Fe; ne; ne = ne.next)
                  if (ne.name === p)
                    return ne;
              }
              function zt(p, ne, Ne) {
                var or = p.kind === 249 ? ne : Ne;
                or && (r(or, ge), ge = $e);
              }
              function Zt(p) {
                if (wr(p.label), p.label) {
                  var ne = Lt(p.label.escapedText);
                  ne && (ne.referenced = true, zt(p, ne.breakTarget, ne.continueTarget));
                } else
                  zt(p, ie, H);
              }
              function mt(p) {
                var ne = pe, Ne = Xe, or = qr(), it2 = qr(), vt = qr();
                if (p.finallyBlock && (pe = it2), r(vt, ge), Xe = vt, wr(p.tryBlock), r(or, ge), p.catchClause && (ge = xe(vt), vt = qr(), r(vt, ge), Xe = vt, wr(p.catchClause), r(or, ge)), pe = ne, Xe = Ne, p.finallyBlock) {
                  var Tt = qr();
                  Tt.antecedents = e.concatenate(e.concatenate(or.antecedents, vt.antecedents), it2.antecedents), ge = Tt, wr(p.finallyBlock), ge.flags & 1 ? ge = $e : (pe && it2.antecedents && r(pe, Ge(Tt, it2.antecedents, ge)), Xe && vt.antecedents && r(Xe, Ge(Tt, vt.antecedents, ge)), ge = or.antecedents ? Ge(Tt, or.antecedents, ge) : $e);
                } else
                  ge = xe(or);
              }
              function at(p) {
                var ne = qr();
                wr(p.expression);
                var Ne = ie, or = Re;
                ie = ne, Re = ge, wr(p.caseBlock), r(ne, ge);
                var it2 = e.forEach(p.caseBlock.clauses, function(vt) {
                  return vt.kind === 293;
                });
                p.possiblyExhaustive = !it2 && !ne.antecedents, it2 || r(ne, ft(Re, p, 0, 0)), ie = Ne, Re = or, ge = xe(ne);
              }
              function k(p) {
                for (var ne = p.clauses, Ne = rt(p.parent.expression), or = $e, it2 = 0; it2 < ne.length; it2++) {
                  for (var vt = it2; !ne[it2].statements.length && it2 + 1 < ne.length; )
                    wr(ne[it2]), it2++;
                  var Tt = qr();
                  r(Tt, Ne ? ft(Re, p.parent, vt, it2 + 1) : Re), r(Tt, or), ge = xe(Tt);
                  var St = ne[it2];
                  wr(St), or = ge, !(ge.flags & 1) && it2 !== ne.length - 1 && U.noFallthroughCasesInSwitch && (St.fallthroughFlowNode = ge);
                }
              }
              function ue(p) {
                var ne = ge;
                ge = Re, wr(p.expression), ge = ne, Pr(p.statements);
              }
              function Qe(p) {
                wr(p.expression), Sr(p.expression);
              }
              function Sr(p) {
                if (p.kind === 210) {
                  var ne = p;
                  ne.expression.kind !== 106 && e.isDottedName(ne.expression) && (ge = me(ge, ne));
                }
              }
              function Kr(p) {
                var ne = qr();
                Fe = { next: Fe, name: p.label.escapedText, breakTarget: ne, continueTarget: void 0, referenced: false }, wr(p.label), wr(p.statement), !Fe.referenced && !U.allowUnusedLabels && kn(e.unusedLabelIsError(U), p.label, e.Diagnostics.Unused_label), Fe = Fe.next, r(ne, ge), ge = xe(ne);
              }
              function Hr(p) {
                p.kind === 223 && p.operatorToken.kind === 63 ? Dt(p.left) : Dt(p);
              }
              function Dt(p) {
                if (Z(p))
                  ge = Ie(16, ge, p);
                else if (p.kind === 206)
                  for (var ne = 0, Ne = p.elements; ne < Ne.length; ne++) {
                    var or = Ne[ne];
                    or.kind === 227 ? Dt(or.expression) : Hr(or);
                  }
                else if (p.kind === 207)
                  for (var it2 = 0, vt = p.properties; it2 < vt.length; it2++) {
                    var Tt = vt[it2];
                    Tt.kind === 299 ? Hr(Tt.initializer) : Tt.kind === 300 ? Dt(Tt.name) : Tt.kind === 301 && Dt(Tt.expression);
                  }
              }
              function Xt(p, ne, Ne) {
                var or = qr();
                p.operatorToken.kind === 55 || p.operatorToken.kind === 76 ? ot(p.left, or, Ne) : ot(p.left, ne, or), ge = xe(or), wr(p.operatorToken), e.isLogicalOrCoalescingAssignmentOperator(p.operatorToken.kind) ? (Mr(wr, p.right, ne, Ne), Dt(p.left), r(ne, ct(32, ge, p)), r(Ne, ct(64, ge, p))) : ot(p.right, ne, Ne);
              }
              function cn(p) {
                if (p.operator === 53) {
                  var ne = j;
                  j = be, be = ne, Br(p), be = j, j = ne;
                } else
                  Br(p), (p.operator === 45 || p.operator === 46) && Dt(p.operand);
              }
              function In(p) {
                Br(p), (p.operator === 45 || p.operator === 46) && Dt(p.operand);
              }
              function yn(p) {
                er ? (er = false, wr(p.operatorToken), wr(p.right), er = true, wr(p.left)) : (er = true, wr(p.left), er = false, wr(p.operatorToken), wr(p.right)), Dt(p.left);
              }
              function hn() {
                return e.createBinaryExpressionTrampoline(p, ne, Ne, or, it2, void 0);
                function p(Tt, St) {
                  if (St) {
                    St.stackIndex++, e.setParent(Tt, v);
                    var tn = ve;
                    An(Tt);
                    var Mt = v;
                    v = Tt, St.skip = false, St.inStrictModeStack[St.stackIndex] = tn, St.parentStack[St.stackIndex] = Mt;
                  } else
                    St = { stackIndex: 0, skip: false, inStrictModeStack: [void 0], parentStack: [void 0] };
                  var $t = Tt.operatorToken.kind;
                  if ($t === 55 || $t === 56 || $t === 60 || e.isLogicalOrCoalescingAssignmentOperator($t)) {
                    if (pr(Tt)) {
                      var y = qr();
                      Xt(Tt, y, y), ge = xe(y);
                    } else
                      Xt(Tt, j, be);
                    St.skip = true;
                  }
                  return St;
                }
                function ne(Tt, St, tn) {
                  if (!St.skip) {
                    var Mt = vt(Tt);
                    return tn.operatorToken.kind === 27 && Sr(Tt), Mt;
                  }
                }
                function Ne(Tt, St, tn) {
                  St.skip || wr(Tt);
                }
                function or(Tt, St, tn) {
                  if (!St.skip) {
                    var Mt = vt(Tt);
                    return tn.operatorToken.kind === 27 && Sr(Tt), Mt;
                  }
                }
                function it2(Tt, St) {
                  if (!St.skip) {
                    var tn = Tt.operatorToken.kind;
                    if (e.isAssignmentOperator(tn) && !e.isAssignmentTarget(Tt) && (Dt(Tt.left), tn === 63 && Tt.left.kind === 209)) {
                      var Mt = Tt.left;
                      jr(Mt.expression) && (ge = Ie(256, ge, Tt));
                    }
                  }
                  var $t = St.inStrictModeStack[St.stackIndex], y = St.parentStack[St.stackIndex];
                  $t !== void 0 && (ve = $t), y !== void 0 && (v = y), St.skip = false, St.stackIndex--;
                }
                function vt(Tt) {
                  if (Tt && e.isBinaryExpression(Tt) && !e.isDestructuringAssignment(Tt))
                    return Tt;
                  wr(Tt);
                }
              }
              function ln(p) {
                Br(p), p.expression.kind === 208 && Dt(p.expression);
              }
              function En(p) {
                var ne = qr(), Ne = qr(), or = qr();
                ot(p.condition, ne, Ne), ge = xe(ne), wr(p.questionToken), wr(p.whenTrue), r(or, ge), ge = xe(Ne), wr(p.colonToken), wr(p.whenFalse), r(or, ge), ge = xe(or);
              }
              function Vt(p) {
                var ne = e.isOmittedExpression(p) ? void 0 : p.name;
                if (e.isBindingPattern(ne))
                  for (var Ne = 0, or = ne.elements; Ne < or.length; Ne++) {
                    var it2 = or[Ne];
                    Vt(it2);
                  }
                else
                  ge = Ie(16, ge, p);
              }
              function ui(p) {
                Br(p), (p.initializer || e.isForInOrOfStatement(p.parent.parent)) && Vt(p);
              }
              function ei(p) {
                wr(p.dotDotDotToken), wr(p.propertyName), ri(p.initializer), wr(p.name);
              }
              function hi(p) {
                Pr(p.modifiers), wr(p.dotDotDotToken), wr(p.questionToken), wr(p.type), ri(p.initializer), wr(p.name);
              }
              function ri(p) {
                if (p) {
                  var ne = ge;
                  if (wr(p), !(ne === $e || ne === ge)) {
                    var Ne = qr();
                    r(Ne, ne), r(Ne, ge), ge = xe(Ne);
                  }
                }
              }
              function vi(p) {
                wr(p.tagName), p.kind !== 342 && p.fullName && (e.setParent(p.fullName, p), e.setParentRecursive(p.fullName, false)), typeof p.comment != "string" && Pr(p.comment);
              }
              function Qn(p) {
                Br(p);
                var ne = e.getHostSignatureFromJSDoc(p);
                ne && ne.kind !== 171 && kr(ne.symbol, ne, 32);
              }
              function Yn(p, ne, Ne) {
                Mr(wr, p, ne, Ne), (!e.isOptionalChain(p) || e.isOutermostOptionalChain(p)) && (r(ne, ct(32, ge, p)), r(Ne, ct(64, ge, p)));
              }
              function oi(p) {
                switch (p.kind) {
                  case 208:
                    wr(p.questionDotToken), wr(p.name);
                    break;
                  case 209:
                    wr(p.questionDotToken), wr(p.argumentExpression);
                    break;
                  case 210:
                    wr(p.questionDotToken), Pr(p.typeArguments), Pr(p.arguments);
                    break;
                }
              }
              function bi(p, ne, Ne) {
                var or = e.isOptionalChainRoot(p) ? qr() : void 0;
                Yn(p.expression, or || ne, Ne), or && (ge = xe(or)), Mr(oi, p, ne, Ne), e.isOutermostOptionalChain(p) && (r(ne, ct(32, ge, p)), r(Ne, ct(64, ge, p)));
              }
              function Dn(p) {
                if (pr(p)) {
                  var ne = qr();
                  bi(p, ne, ne), ge = xe(ne);
                } else
                  bi(p, j, be);
              }
              function Kn(p) {
                e.isOptionalChain(p) ? Dn(p) : Br(p);
              }
              function si(p) {
                e.isOptionalChain(p) ? Dn(p) : Br(p);
              }
              function di(p) {
                if (e.isOptionalChain(p))
                  Dn(p);
                else {
                  var ne = e.skipParentheses(p.expression);
                  ne.kind === 215 || ne.kind === 216 ? (Pr(p.typeArguments), Pr(p.arguments), wr(p.expression)) : (Br(p), p.expression.kind === 106 && (ge = me(ge, p)));
                }
                if (p.expression.kind === 208) {
                  var Ne = p.expression;
                  e.isIdentifier(Ne.name) && jr(Ne.expression) && e.isPushOrUnshiftIdentifier(Ne.name) && (ge = Ie(256, ge, p));
                }
              }
              function Zn(p) {
                switch (p.kind) {
                  case 228:
                  case 260:
                  case 263:
                  case 207:
                  case 184:
                  case 325:
                  case 289:
                    return 1;
                  case 261:
                    return 65;
                  case 264:
                  case 262:
                  case 197:
                  case 178:
                    return 33;
                  case 308:
                    return 37;
                  case 174:
                  case 175:
                  case 171:
                    if (e.isObjectLiteralOrClassExpressionMethodOrAccessor(p))
                      return 173;
                  case 173:
                  case 259:
                  case 170:
                  case 176:
                  case 326:
                  case 320:
                  case 181:
                  case 177:
                  case 182:
                  case 172:
                    return 45;
                  case 215:
                  case 216:
                    return 61;
                  case 265:
                    return 4;
                  case 169:
                    return p.initializer ? 4 : 0;
                  case 295:
                  case 245:
                  case 246:
                  case 247:
                  case 266:
                    return 2;
                  case 238:
                    return e.isFunctionLike(p.parent) || e.isClassStaticBlockDeclaration(p.parent) ? 0 : 2;
                }
                return 0;
              }
              function Fn(p) {
                te && (te.nextContainer = p), te = p;
              }
              function gt(p, ne, Ne) {
                switch (g.kind) {
                  case 264:
                    return zr(p, ne, Ne);
                  case 308:
                    return dn(p, ne, Ne);
                  case 228:
                  case 260:
                    return mi(p, ne, Ne);
                  case 263:
                    return Lr(g.symbol.exports, g.symbol, p, ne, Ne);
                  case 184:
                  case 325:
                  case 207:
                  case 261:
                  case 289:
                    return Lr(g.symbol.members, g.symbol, p, ne, Ne);
                  case 181:
                  case 182:
                  case 176:
                  case 177:
                  case 326:
                  case 178:
                  case 171:
                  case 170:
                  case 173:
                  case 174:
                  case 175:
                  case 259:
                  case 215:
                  case 216:
                  case 320:
                  case 348:
                  case 341:
                  case 172:
                  case 262:
                  case 197:
                    return Lr(g.locals, void 0, p, ne, Ne);
                }
              }
              function mi(p, ne, Ne) {
                return e.isStatic(p) ? Lr(g.symbol.exports, g.symbol, p, ne, Ne) : Lr(g.symbol.members, g.symbol, p, ne, Ne);
              }
              function dn(p, ne, Ne) {
                return e.isExternalModule(B) ? zr(p, ne, Ne) : Lr(B.locals, void 0, p, ne, Ne);
              }
              function On(p) {
                var ne = e.isSourceFile(p) ? p : e.tryCast(p.body, e.isModuleBlock);
                return !!ne && ne.statements.some(function(Ne) {
                  return e.isExportDeclaration(Ne) || e.isExportAssignment(Ne);
                });
              }
              function br(p) {
                p.flags & 16777216 && !On(p) ? p.flags |= 64 : p.flags &= -65;
              }
              function Ae(p) {
                if (br(p), e.isAmbientModule(p))
                  if (e.hasSyntacticModifier(p, 1) && Rn(p, e.Diagnostics.export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible), e.isModuleAugmentationExternal(p))
                    ur(p);
                  else {
                    var ne = void 0;
                    if (p.name.kind === 10) {
                      var Ne = p.name.text;
                      ne = e.tryParsePattern(Ne), ne === void 0 && Rn(p.name, e.Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character, Ne);
                    }
                    var or = gt(p, 512, 110735);
                    B.patternAmbientModules = e.append(B.patternAmbientModules, ne && !e.isString(ne) ? { pattern: ne, symbol: or } : void 0);
                  }
                else {
                  var it2 = ur(p);
                  if (it2 !== 0) {
                    var or = p.symbol;
                    or.constEnumOnlyModule = !(or.flags & 304) && it2 === 2 && or.constEnumOnlyModule !== false;
                  }
                }
              }
              function ur(p) {
                var ne = w(p), Ne = ne !== 0;
                return gt(p, Ne ? 512 : 1024, Ne ? 110735 : 0), ne;
              }
              function L(p) {
                var ne = yr(131072, nr(p));
                kr(ne, p, 131072);
                var Ne = yr(2048, "__type");
                kr(Ne, p, 2048), Ne.members = e.createSymbolTable(), Ne.members.set(ne.escapedName, ne);
              }
              function qt(p) {
                return Le(p, 4096, "__object");
              }
              function nn(p) {
                return Le(p, 4096, "__jsxAttributes");
              }
              function fr(p, ne, Ne) {
                return gt(p, ne, Ne);
              }
              function Le(p, ne, Ne) {
                var or = yr(ne, Ne);
                return ne & 106508 && (or.parent = g.symbol), kr(or, p, ne), or;
              }
              function Ve(p, ne, Ne) {
                switch (S.kind) {
                  case 264:
                    zr(p, ne, Ne);
                    break;
                  case 308:
                    if (e.isExternalOrCommonJsModule(g)) {
                      zr(p, ne, Ne);
                      break;
                    }
                  default:
                    S.locals || (S.locals = e.createSymbolTable(), Fn(S)), Lr(S.locals, void 0, p, ne, Ne);
                }
              }
              function _r() {
                if (Je) {
                  for (var p = g, ne = te, Ne = S, or = v, it2 = ge, vt = 0, Tt = Je; vt < Tt.length; vt++) {
                    var St = Tt[vt], tn = St.parent.parent;
                    g = e.findAncestor(tn.parent, function(De) {
                      return !!(Zn(De) & 1);
                    }) || B, S = e.getEnclosingBlockScopeContainer(tn) || B, ge = Ee({ flags: 2 }), v = St, wr(St.typeExpression);
                    var Mt = e.getNameOfDeclaration(St);
                    if ((e.isJSDocEnumTag(St) || !St.fullName) && Mt && e.isPropertyAccessEntityNameExpression(Mt.parent)) {
                      var $t = jt(Mt.parent);
                      if ($t) {
                        Pt(B.symbol, Mt.parent, $t, !!e.findAncestor(Mt, function(De) {
                          return e.isPropertyAccessExpression(De) && De.name.escapedText === "prototype";
                        }), false);
                        var y = g;
                        switch (e.getAssignmentDeclarationPropertyAccessKind(Mt.parent)) {
                          case 1:
                          case 2:
                            e.isExternalOrCommonJsModule(B) ? g = B : g = void 0;
                            break;
                          case 4:
                            g = Mt.parent.expression;
                            break;
                          case 3:
                            g = Mt.parent.expression.name;
                            break;
                          case 5:
                            g = je(B, Mt.parent.expression) ? B : e.isPropertyAccessExpression(Mt.parent.expression) ? Mt.parent.expression.name : Mt.parent.expression;
                            break;
                          case 0:
                            return e.Debug.fail("Shouldn't have detected typedef or enum on non-assignment declaration");
                        }
                        g && zr(St, 524288, 788968), g = y;
                      }
                    } else
                      e.isJSDocEnumTag(St) || !St.fullName || St.fullName.kind === 79 ? (v = St.parent, Ve(St, 524288, 788968)) : wr(St.fullName);
                  }
                  g = p, te = ne, S = Ne, v = or, ge = it2;
                }
              }
              function lr(p) {
                !B.parseDiagnostics.length && !(p.flags & 16777216) && !(p.flags & 8388608) && !e.isIdentifierName(p) && (ve && p.originalKeywordKind >= 117 && p.originalKeywordKind <= 125 ? B.bindDiagnostics.push(Te(p, Vr(p), e.declarationNameToString(p))) : p.originalKeywordKind === 133 ? e.isExternalModule(B) && e.isInTopLevelContext(p) ? B.bindDiagnostics.push(Te(p, e.Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module, e.declarationNameToString(p))) : p.flags & 32768 && B.bindDiagnostics.push(Te(p, e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, e.declarationNameToString(p))) : p.originalKeywordKind === 125 && p.flags & 8192 && B.bindDiagnostics.push(Te(p, e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, e.declarationNameToString(p))));
              }
              function Vr(p) {
                return e.getContainingClass(p) ? e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode : B.externalModuleIndicator ? e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode : e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode;
              }
              function tt(p) {
                p.escapedText === "#constructor" && (B.parseDiagnostics.length || B.bindDiagnostics.push(Te(p, e.Diagnostics.constructor_is_a_reserved_word, e.declarationNameToString(p))));
              }
              function dt(p) {
                ve && e.isLeftHandSideExpression(p.left) && e.isAssignmentOperator(p.operatorToken.kind) && _e(p, p.left);
              }
              function It(p) {
                ve && p.variableDeclaration && _e(p, p.variableDeclaration.name);
              }
              function an(p) {
                if (ve && p.expression.kind === 79) {
                  var ne = e.getErrorSpanForNode(B, p.expression);
                  B.bindDiagnostics.push(e.createFileDiagnostic(B, ne.start, ne.length, e.Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode));
                }
              }
              function sn(p) {
                return e.isIdentifier(p) && (p.escapedText === "eval" || p.escapedText === "arguments");
              }
              function _e(p, ne) {
                if (ne && ne.kind === 79) {
                  var Ne = ne;
                  if (sn(Ne)) {
                    var or = e.getErrorSpanForNode(B, ne);
                    B.bindDiagnostics.push(e.createFileDiagnostic(B, or.start, or.length, Gr(p), e.idText(Ne)));
                  }
                }
              }
              function Gr(p) {
                return e.getContainingClass(p) ? e.Diagnostics.Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode : B.externalModuleIndicator ? e.Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode : e.Diagnostics.Invalid_use_of_0_in_strict_mode;
              }
              function Kt(p) {
                ve && _e(p, p.name);
              }
              function en(p) {
                return e.getContainingClass(p) ? e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode : B.externalModuleIndicator ? e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode : e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5;
              }
              function Ot(p) {
                if (m < 2 && S.kind !== 308 && S.kind !== 264 && !e.isFunctionLikeOrClassStaticBlockDeclaration(S)) {
                  var ne = e.getErrorSpanForNode(B, p);
                  B.bindDiagnostics.push(e.createFileDiagnostic(B, ne.start, ne.length, en(p)));
                }
              }
              function rr(p) {
                m < 1 && ve && p.numericLiteralFlags & 32 && B.bindDiagnostics.push(Te(p, e.Diagnostics.Octal_literals_are_not_allowed_in_strict_mode));
              }
              function Hn(p) {
                ve && _e(p, p.operand);
              }
              function rn(p) {
                ve && (p.operator === 45 || p.operator === 46) && _e(p, p.operand);
              }
              function xn(p) {
                ve && Rn(p, e.Diagnostics.with_statements_are_not_allowed_in_strict_mode);
              }
              function Mn(p) {
                ve && e.getEmitScriptTarget(U) >= 2 && (e.isDeclarationStatement(p.statement) || e.isVariableStatement(p.statement)) && Rn(p.label, e.Diagnostics.A_label_is_not_allowed_here);
              }
              function Rn(p, ne, Ne, or, it2) {
                var vt = e.getSpanOfTokenAtPosition(B, p.pos);
                B.bindDiagnostics.push(e.createFileDiagnostic(B, vt.start, vt.length, ne, Ne, or, it2));
              }
              function kn(p, ne, Ne) {
                on(p, ne, ne, Ne);
              }
              function on(p, ne, Ne, or) {
                Xr(p, { pos: e.getTokenPosOfNode(ne, B), end: Ne.end }, or);
              }
              function Xr(p, ne, Ne) {
                var or = e.createFileDiagnostic(B, ne.pos, ne.end - ne.pos, Ne);
                p ? B.bindDiagnostics.push(or) : B.bindSuggestionDiagnostics = e.append(B.bindSuggestionDiagnostics, T(T({}, or), { category: e.DiagnosticCategory.Suggestion }));
              }
              function wr(p) {
                if (p) {
                  e.setParent(p, v), e.tracing && (p.tracingPath = B.path);
                  var ne = ve;
                  if (An(p), p.kind > 162) {
                    var Ne = v;
                    v = p;
                    var or = Zn(p);
                    or === 0 ? ut(p) : ir(p, or), v = Ne;
                  } else {
                    var Ne = v;
                    p.kind === 1 && (v = p), fn(p), v = Ne;
                  }
                  ve = ne;
                }
              }
              function fn(p) {
                if (e.hasJSDocNodes(p))
                  if (e.isInJSFile(p))
                    for (var ne = 0, Ne = p.jsDoc; ne < Ne.length; ne++) {
                      var or = Ne[ne];
                      wr(or);
                    }
                  else
                    for (var it2 = 0, vt = p.jsDoc; it2 < vt.length; it2++) {
                      var or = vt[it2];
                      e.setParent(or, p), e.setParentRecursive(or, false);
                    }
              }
              function mn(p) {
                if (!ve)
                  for (var ne = 0, Ne = p; ne < Ne.length; ne++) {
                    var or = Ne[ne];
                    if (!e.isPrologueDirective(or))
                      return;
                    if (Mi(or)) {
                      ve = true;
                      return;
                    }
                  }
              }
              function Mi(p) {
                var ne = e.getSourceTextOfNodeFromSourceFile(B, p.expression);
                return ne === '"use strict"' || ne === "'use strict'";
              }
              function An(p) {
                switch (p.kind) {
                  case 79:
                    if (p.isInJSDocNamespace) {
                      for (var ne = p.parent; ne && !e.isJSDocTypeAlias(ne); )
                        ne = ne.parent;
                      Ve(ne, 524288, 788968);
                      break;
                    }
                  case 108:
                    return ge && (e.isExpression(p) || v.kind === 300) && (p.flowNode = ge), lr(p);
                  case 163:
                    ge && e.isPartOfTypeQuery(p) && (p.flowNode = ge);
                    break;
                  case 233:
                  case 106:
                    p.flowNode = ge;
                    break;
                  case 80:
                    return tt(p);
                  case 208:
                  case 209:
                    var Ne = p;
                    ge && Z(Ne) && (Ne.flowNode = ge), e.isSpecialPropertyDeclaration(Ne) && ee(Ne), e.isInJSFile(Ne) && B.commonJsModuleIndicator && e.isModuleExportsAccessExpression(Ne) && !V(S, "module") && Lr(B.locals, void 0, Ne.expression, 134217729, 111550);
                    break;
                  case 223:
                    var or = e.getAssignmentDeclarationKind(p);
                    switch (or) {
                      case 1:
                        Tn(p);
                        break;
                      case 2:
                        jn(p);
                        break;
                      case 3:
                        Ir(p.left, p);
                        break;
                      case 6:
                        le(p);
                        break;
                      case 4:
                        Si(p);
                        break;
                      case 5:
                        var it2 = p.left.expression;
                        if (e.isInJSFile(p) && e.isIdentifier(it2)) {
                          var vt = V(S, it2.escapedText);
                          if (e.isThisInitializedDeclaration(vt == null ? void 0 : vt.valueDeclaration)) {
                            Si(p);
                            break;
                          }
                        }
                        hr(p);
                        break;
                      case 0:
                        break;
                      default:
                        e.Debug.fail("Unknown binary expression special property assignment kind");
                    }
                    return dt(p);
                  case 295:
                    return It(p);
                  case 217:
                    return an(p);
                  case 8:
                    return rr(p);
                  case 222:
                    return Hn(p);
                  case 221:
                    return rn(p);
                  case 251:
                    return xn(p);
                  case 253:
                    return Mn(p);
                  case 194:
                    qe = true;
                    return;
                  case 179:
                    break;
                  case 165:
                    return Xi(p);
                  case 166:
                    return Hi(p);
                  case 257:
                    return qi(p);
                  case 205:
                    return p.flowNode = ge, qi(p);
                  case 169:
                  case 168:
                    return xi(p);
                  case 299:
                  case 300:
                    return Jn(p, 4, 0);
                  case 302:
                    return Jn(p, 8, 900095);
                  case 176:
                  case 177:
                  case 178:
                    return gt(p, 131072, 0);
                  case 171:
                  case 170:
                    return Jn(p, 8192 | (p.questionToken ? 16777216 : 0), e.isObjectLiteralMethod(p) ? 0 : 103359);
                  case 259:
                    return Gi(p);
                  case 173:
                    return gt(p, 16384, 0);
                  case 174:
                    return Jn(p, 32768, 46015);
                  case 175:
                    return Jn(p, 65536, 78783);
                  case 181:
                  case 320:
                  case 326:
                  case 182:
                    return L(p);
                  case 184:
                  case 325:
                  case 197:
                    return ti(p);
                  case 335:
                    return Qn(p);
                  case 207:
                    return qt(p);
                  case 215:
                  case 216:
                    return da(p);
                  case 210:
                    var Tt = e.getAssignmentDeclarationKind(p);
                    switch (Tt) {
                      case 7:
                        return Ar(p);
                      case 8:
                        return Fi(p);
                      case 9:
                        return Ze(p);
                      case 0:
                        break;
                      default:
                        return e.Debug.fail("Unknown call expression assignment declaration kind");
                    }
                    e.isInJSFile(p) && oa(p);
                    break;
                  case 228:
                  case 260:
                    return ve = true, Zi(p);
                  case 261:
                    return Ve(p, 64, 788872);
                  case 262:
                    return Ve(p, 524288, 788968);
                  case 263:
                    return Ki(p);
                  case 264:
                    return Ae(p);
                  case 289:
                    return nn(p);
                  case 288:
                    return fr(p, 4, 0);
                  case 268:
                  case 271:
                  case 273:
                  case 278:
                    return gt(p, 2097152, 2097152);
                  case 267:
                    return Ue(p);
                  case 270:
                    return Ei(p);
                  case 275:
                    return Vn(p);
                  case 274:
                    return vn(p);
                  case 308:
                    return mn(p.statements), li();
                  case 238:
                    if (!e.isFunctionLikeOrClassStaticBlockDeclaration(p.parent))
                      return;
                  case 265:
                    return mn(p.statements);
                  case 343:
                    if (p.parent.kind === 326)
                      return Hi(p);
                    if (p.parent.kind !== 325)
                      break;
                  case 350:
                    var St = p, tn = St.isBracketed || St.typeExpression && St.typeExpression.type.kind === 319 ? 16777220 : 4;
                    return gt(St, tn, 0);
                  case 348:
                  case 341:
                  case 342:
                    return (Je || (Je = [])).push(p);
                }
              }
              function xi(p) {
                var ne = e.isAutoAccessorPropertyDeclaration(p), Ne = ne ? 98304 : 4, or = ne ? 13247 : 0;
                return Jn(p, Ne | (p.questionToken ? 16777216 : 0), or);
              }
              function ti(p) {
                return Le(p, 2048, "__type");
              }
              function li() {
                if (br(B), e.isExternalModule(B))
                  Bn();
                else if (e.isJsonSourceFile(B)) {
                  Bn();
                  var p = B.symbol;
                  Lr(B.symbol.exports, B.symbol, B, 4, 67108863), B.symbol = p;
                }
              }
              function Bn() {
                Le(B, 512, '"'.concat(e.removeFileExtension(B.fileName), '"'));
              }
              function vn(p) {
                if (!g.symbol || !g.symbol.exports)
                  Le(p, 111551, nr(p));
                else {
                  var ne = e.exportAssignmentIsAlias(p) ? 2097152 : 4, Ne = Lr(g.symbol.exports, g.symbol, p, ne, 67108863);
                  p.isExportEquals && e.setValueDeclaration(Ne, p);
                }
              }
              function Ue(p) {
                e.some(p.modifiers) && B.bindDiagnostics.push(Te(p, e.Diagnostics.Modifiers_cannot_appear_here));
                var ne = e.isSourceFile(p.parent) ? e.isExternalModule(p.parent) ? p.parent.isDeclarationFile ? void 0 : e.Diagnostics.Global_module_exports_may_only_appear_in_declaration_files : e.Diagnostics.Global_module_exports_may_only_appear_in_module_files : e.Diagnostics.Global_module_exports_may_only_appear_at_top_level;
                ne ? B.bindDiagnostics.push(Te(p, ne)) : (B.symbol.globalExports = B.symbol.globalExports || e.createSymbolTable(), Lr(B.symbol.globalExports, B.symbol, p, 2097152, 2097152));
              }
              function Vn(p) {
                !g.symbol || !g.symbol.exports ? Le(p, 8388608, nr(p)) : p.exportClause ? e.isNamespaceExport(p.exportClause) && (e.setParent(p.exportClause, p), Lr(g.symbol.exports, g.symbol, p.exportClause, 2097152, 2097152)) : Lr(g.symbol.exports, g.symbol, p, 8388608, 0);
              }
              function Ei(p) {
                p.name && gt(p, 2097152, 2097152);
              }
              function ni(p) {
                return B.externalModuleIndicator && B.externalModuleIndicator !== true ? false : (B.commonJsModuleIndicator || (B.commonJsModuleIndicator = p, B.externalModuleIndicator || Bn()), true);
              }
              function Fi(p) {
                if (ni(p)) {
                  var ne = Bi(p.arguments[0], void 0, function(or, it2) {
                    return it2 && kr(it2, or, 67110400), it2;
                  });
                  if (ne) {
                    var Ne = 1048580;
                    Lr(ne.exports, ne, p, Ne, 0);
                  }
                }
              }
              function Tn(p) {
                if (ni(p)) {
                  var ne = Bi(p.left.expression, void 0, function(it2, vt) {
                    return vt && kr(vt, it2, 67110400), vt;
                  });
                  if (ne) {
                    var Ne = e.isAliasableExpression(p.right) && (e.isExportsIdentifier(p.left.expression) || e.isModuleExportsAccessExpression(p.left.expression)), or = Ne ? 2097152 : 1048580;
                    e.setParent(p.left, p), Lr(ne.exports, ne, p.left, or, 0);
                  }
                }
              }
              function jn(p) {
                if (ni(p)) {
                  var ne = e.getRightMostAssignedExpression(p.right);
                  if (!(e.isEmptyObjectLiteral(ne) || g === B && je(B, ne))) {
                    if (e.isObjectLiteralExpression(ne) && e.every(ne.properties, e.isShorthandPropertyAssignment)) {
                      e.forEach(ne.properties, Ti);
                      return;
                    }
                    var Ne = e.exportAssignmentIsAlias(p) ? 2097152 : 1049092, or = Lr(B.symbol.exports, B.symbol, p, Ne | 67108864, 0);
                    e.setValueDeclaration(or, p);
                  }
                }
              }
              function Ti(p) {
                Lr(B.symbol.exports, B.symbol, p, 69206016, 0);
              }
              function Si(p) {
                e.Debug.assert(e.isInJSFile(p));
                var ne = e.isBinaryExpression(p) && e.isPropertyAccessExpression(p.left) && e.isPrivateIdentifier(p.left.name) || e.isPropertyAccessExpression(p) && e.isPrivateIdentifier(p.name);
                if (!ne) {
                  var Ne = e.getThisContainer(p, false);
                  switch (Ne.kind) {
                    case 259:
                    case 215:
                      var or = Ne.symbol;
                      if (e.isBinaryExpression(Ne.parent) && Ne.parent.operatorToken.kind === 63) {
                        var it2 = Ne.parent.left;
                        e.isBindableStaticAccessExpression(it2) && e.isPrototypeAccess(it2.expression) && (or = Gn(it2.expression.expression, O));
                      }
                      or && or.valueDeclaration && (or.members = or.members || e.createSymbolTable(), e.hasDynamicName(p) ? C(p, or, or.members) : Lr(or.members, or, p, 67108868, 0), kr(or, or.valueDeclaration, 32));
                      break;
                    case 173:
                    case 169:
                    case 171:
                    case 174:
                    case 175:
                    case 172:
                      var vt = Ne.parent, Tt = e.isStatic(Ne) ? vt.symbol.exports : vt.symbol.members;
                      e.hasDynamicName(p) ? C(p, vt.symbol, Tt) : Lr(Tt, vt.symbol, p, 67108868, 0, true);
                      break;
                    case 308:
                      if (e.hasDynamicName(p))
                        break;
                      Ne.commonJsModuleIndicator ? Lr(Ne.symbol.exports, Ne.symbol, p, 1048580, 0) : gt(p, 1, 111550);
                      break;
                    default:
                      e.Debug.failBadSyntaxKind(Ne);
                  }
                }
              }
              function C(p, ne, Ne) {
                Lr(Ne, ne, p, 4, 0, true, true), W(p, ne);
              }
              function W(p, ne) {
                ne && (ne.assignmentDeclarationMembers || (ne.assignmentDeclarationMembers = new e.Map())).set(e.getNodeId(p), p);
              }
              function ee(p) {
                p.expression.kind === 108 ? Si(p) : e.isBindableStaticAccessExpression(p) && p.parent.parent.kind === 308 && (e.isPrototypeAccess(p.expression) ? Ir(p, p.parent) : yt(p));
              }
              function le(p) {
                e.setParent(p.left, p), e.setParent(p.right, p), Ht(p.left.expression, p.left, false, true);
              }
              function Ze(p) {
                var ne = Gn(p.arguments[0].expression);
                ne && ne.valueDeclaration && kr(ne, ne.valueDeclaration, 32), Ut(p, ne, true);
              }
              function Ir(p, ne) {
                var Ne = p.expression, or = Ne.expression;
                e.setParent(or, Ne), e.setParent(Ne, p), e.setParent(p, ne), Ht(or, p, true, true);
              }
              function Ar(p) {
                var ne = Gn(p.arguments[0]), Ne = p.parent.parent.kind === 308;
                ne = Pt(ne, p.arguments[0], Ne, false, false), Ut(p, ne, false);
              }
              function hr(p) {
                var ne, Ne = Gn(p.left.expression, g) || Gn(p.left.expression, S);
                if (!(!e.isInJSFile(p) && !e.isFunctionSymbol(Ne))) {
                  var or = e.getLeftmostAccessExpression(p.left);
                  if (!(e.isIdentifier(or) && ((ne = V(g, or.escapedText)) === null || ne === void 0 ? void 0 : ne.flags) & 2097152))
                    if (e.setParent(p.left, p), e.setParent(p.right, p), e.isIdentifier(p.left.expression) && g === B && je(B, p.left.expression))
                      Tn(p);
                    else if (e.hasDynamicName(p)) {
                      Le(p, 67108868, "__computed");
                      var it2 = Pt(Ne, p.left.expression, jt(p.left), false, false);
                      W(p, it2);
                    } else
                      yt(e.cast(p.left, e.isBindableStaticNameExpression));
                }
              }
              function yt(p) {
                e.Debug.assert(!e.isIdentifier(p)), e.setParent(p.expression, p), Ht(p.expression, p, false, false);
              }
              function Pt(p, ne, Ne, or, it2) {
                if ((p == null ? void 0 : p.flags) & 2097152)
                  return p;
                if (Ne && !or) {
                  var vt = 67110400, Tt = 110735;
                  p = Bi(ne, p, function(St, tn, Mt) {
                    if (tn)
                      return kr(tn, St, vt), tn;
                    var $t = Mt ? Mt.exports : B.jsGlobalAugmentations || (B.jsGlobalAugmentations = e.createSymbolTable());
                    return Lr($t, Mt, St, vt, Tt);
                  });
                }
                return it2 && p && p.valueDeclaration && kr(p, p.valueDeclaration, 32), p;
              }
              function Ut(p, ne, Ne) {
                if (!(!ne || !gi(ne))) {
                  var or = Ne ? ne.members || (ne.members = e.createSymbolTable()) : ne.exports || (ne.exports = e.createSymbolTable()), it2 = 0, vt = 0;
                  e.isFunctionLikeDeclaration(e.getAssignedExpandoInitializer(p)) ? (it2 = 8192, vt = 103359) : e.isCallExpression(p) && e.isBindableObjectDefinePropertyCall(p) && (e.some(p.arguments[2].properties, function(Tt) {
                    var St = e.getNameOfDeclaration(Tt);
                    return !!St && e.isIdentifier(St) && e.idText(St) === "set";
                  }) && (it2 |= 65540, vt |= 78783), e.some(p.arguments[2].properties, function(Tt) {
                    var St = e.getNameOfDeclaration(Tt);
                    return !!St && e.isIdentifier(St) && e.idText(St) === "get";
                  }) && (it2 |= 32772, vt |= 46015)), it2 === 0 && (it2 = 4, vt = 0), Lr(or, ne, p, it2 | 67108864, vt & -67108865);
                }
              }
              function jt(p) {
                return e.isBinaryExpression(p.parent) ? Pi(p.parent).parent.kind === 308 : p.parent.parent.kind === 308;
              }
              function Ht(p, ne, Ne, or) {
                var it2 = Gn(p, g) || Gn(p, S), vt = jt(ne);
                it2 = Pt(it2, ne.expression, vt, Ne, or), Ut(ne, it2, Ne);
              }
              function gi(p) {
                if (p.flags & 1072)
                  return true;
                var ne = p.valueDeclaration;
                if (ne && e.isCallExpression(ne))
                  return !!e.getAssignedExpandoInitializer(ne);
                var Ne = ne ? e.isVariableDeclaration(ne) ? ne.initializer : e.isBinaryExpression(ne) ? ne.right : e.isPropertyAccessExpression(ne) && e.isBinaryExpression(ne.parent) ? ne.parent.right : void 0 : void 0;
                if (Ne = Ne && e.getRightMostAssignedExpression(Ne), Ne) {
                  var or = e.isPrototypeAccess(e.isVariableDeclaration(ne) ? ne.name : e.isBinaryExpression(ne) ? ne.left : ne);
                  return !!e.getExpandoInitializer(e.isBinaryExpression(Ne) && (Ne.operatorToken.kind === 56 || Ne.operatorToken.kind === 60) ? Ne.right : Ne, or);
                }
                return false;
              }
              function Pi(p) {
                for (; e.isBinaryExpression(p.parent); )
                  p = p.parent;
                return p.parent;
              }
              function Gn(p, ne) {
                if (ne === void 0 && (ne = g), e.isIdentifier(p))
                  return V(ne, p.escapedText);
                var Ne = Gn(p.expression);
                return Ne && Ne.exports && Ne.exports.get(e.getElementOrPropertyAccessName(p));
              }
              function Bi(p, ne, Ne) {
                if (je(B, p))
                  return B.symbol;
                if (e.isIdentifier(p))
                  return Ne(p, Gn(p), ne);
                var or = Bi(p.expression, ne, Ne), it2 = e.getNameOrArgument(p);
                return e.isPrivateIdentifier(it2) && e.Debug.fail("unexpected PrivateIdentifier"), Ne(it2, or && or.exports && or.exports.get(e.getElementOrPropertyAccessName(p)), or);
              }
              function oa(p) {
                !B.commonJsModuleIndicator && e.isRequireCall(p, false) && ni(p);
              }
              function Zi(p) {
                if (p.kind === 260)
                  Ve(p, 32, 899503);
                else {
                  var ne = p.name ? p.name.escapedText : "__class";
                  Le(p, 32, ne), p.name && Ce.add(p.name.escapedText);
                }
                var Ne = p.symbol, or = yr(4194308, "prototype"), it2 = Ne.exports.get(or.escapedName);
                it2 && (p.name && e.setParent(p.name, p), B.bindDiagnostics.push(Te(it2.declarations[0], e.Diagnostics.Duplicate_identifier_0, e.symbolName(or)))), Ne.exports.set(or.escapedName, or), or.parent = Ne;
              }
              function Ki(p) {
                return e.isEnumConst(p) ? Ve(p, 128, 899967) : Ve(p, 256, 899327);
              }
              function qi(p) {
                if (ve && _e(p, p.name), !e.isBindingPattern(p.name)) {
                  var ne = p.kind === 257 ? p : p.parent.parent;
                  e.isInJSFile(p) && e.isVariableDeclarationInitializedToBareOrAccessedRequire(ne) && !e.getJSDocTypeTag(p) && !(e.getCombinedModifierFlags(p) & 1) ? gt(p, 2097152, 2097152) : e.isBlockOrCatchScoped(p) ? Ve(p, 2, 111551) : e.isParameterDeclaration(p) ? gt(p, 1, 111551) : gt(p, 1, 111550);
                }
              }
              function Hi(p) {
                if (!(p.kind === 343 && g.kind !== 326) && (ve && !(p.flags & 16777216) && _e(p, p.name), e.isBindingPattern(p.name) ? Le(p, 1, "__" + p.parent.parameters.indexOf(p)) : gt(p, 1, 111551), e.isParameterPropertyDeclaration(p, p.parent))) {
                  var ne = p.parent.parent;
                  Lr(ne.symbol.members, ne.symbol, p, 4 | (p.questionToken ? 16777216 : 0), 0);
                }
              }
              function Gi(p) {
                !B.isDeclarationFile && !(p.flags & 16777216) && e.isAsyncFunction(p) && (ze |= 2048), Kt(p), ve ? (Ot(p), Ve(p, 16, 110991)) : gt(p, 16, 110991);
              }
              function da(p) {
                !B.isDeclarationFile && !(p.flags & 16777216) && e.isAsyncFunction(p) && (ze |= 2048), ge && (p.flowNode = ge), Kt(p);
                var ne = p.name ? p.name.escapedText : "__function";
                return Le(p, 16, ne);
              }
              function Jn(p, ne, Ne) {
                return !B.isDeclarationFile && !(p.flags & 16777216) && e.isAsyncFunction(p) && (ze |= 2048), ge && e.isObjectLiteralOrClassExpressionMethodOrAccessor(p) && (p.flowNode = ge), e.hasDynamicName(p) ? Le(p, ne, "__computed") : gt(p, ne, Ne);
              }
              function ea(p) {
                var ne = e.findAncestor(p, function(Ne) {
                  return Ne.parent && e.isConditionalTypeNode(Ne.parent) && Ne.parent.extendsType === Ne;
                });
                return ne && ne.parent;
              }
              function Xi(p) {
                if (e.isJSDocTemplateTag(p.parent)) {
                  var ne = e.getEffectiveContainerForJSDocTemplateTag(p.parent);
                  ne ? (ne.locals || (ne.locals = e.createSymbolTable()), Lr(ne.locals, void 0, p, 262144, 526824)) : gt(p, 262144, 526824);
                } else if (p.parent.kind === 192) {
                  var Ne = ea(p.parent);
                  Ne ? (Ne.locals || (Ne.locals = e.createSymbolTable()), Lr(Ne.locals, void 0, p, 262144, 526824)) : Le(p, 262144, nr(p));
                } else
                  gt(p, 262144, 526824);
              }
              function sa(p) {
                var ne = w(p);
                return ne === 1 || ne === 2 && e.shouldPreserveConstEnums(U);
              }
              function Li(p) {
                if (!(ge.flags & 1))
                  return false;
                if (ge === $e) {
                  var ne = e.isStatementButNotDeclaration(p) && p.kind !== 239 || p.kind === 260 || p.kind === 264 && sa(p);
                  if (ne && (ge = gr, !U.allowUnreachableCode)) {
                    var Ne = e.unreachableCodeIsError(U) && !(p.flags & 16777216) && (!e.isVariableStatement(p) || !!(e.getCombinedNodeFlags(p.declarationList) & 3) || p.declarationList.declarations.some(function(or) {
                      return !!or.initializer;
                    }));
                    Me(p, function(or, it2) {
                      return on(Ne, or, it2, e.Diagnostics.Unreachable_code_detected);
                    });
                  }
                }
                return true;
              }
            }
            function Me(B, U) {
              if (e.isStatement(B) && Q(B) && e.isBlock(B.parent)) {
                var m = B.parent.statements, v = e.sliceAfter(m, B);
                e.getRangesWhere(v, Q, function(g, O) {
                  return U(v[g], v[O - 1]);
                });
              } else
                U(B, B);
            }
            function Q(B) {
              return !e.isFunctionDeclaration(B) && !Be(B) && !e.isEnumDeclaration(B) && !(e.isVariableStatement(B) && !(e.getCombinedNodeFlags(B) & 3) && B.declarationList.declarations.some(function(U) {
                return !U.initializer;
              }));
            }
            function Be(B) {
              switch (B.kind) {
                case 261:
                case 262:
                  return true;
                case 264:
                  return w(B) !== 1;
                case 263:
                  return e.hasSyntacticModifier(B, 2048);
                default:
                  return false;
              }
            }
            function je(B, U) {
              var m = 0, v = e.createQueue();
              for (v.enqueue(U); !v.isEmpty() && m < 100; ) {
                if (m++, U = v.dequeue(), e.isExportsIdentifier(U) || e.isModuleExportsAccessExpression(U))
                  return true;
                if (e.isIdentifier(U)) {
                  var g = V(B, U.escapedText);
                  if (g && g.valueDeclaration && e.isVariableDeclaration(g.valueDeclaration) && g.valueDeclaration.initializer) {
                    var O = g.valueDeclaration.initializer;
                    v.enqueue(O), e.isAssignmentExpression(O, true) && (v.enqueue(O.left), v.enqueue(O.right));
                  }
                }
              }
              return false;
            }
            e.isExportsOrModuleExportsOrAlias = je;
            function V(B, U) {
              var m = B.locals && B.locals.get(U);
              return m ? m.exportSymbol || m : e.isSourceFile(B) && B.jsGlobalAugmentations && B.jsGlobalAugmentations.has(U) ? B.jsGlobalAugmentations.get(U) : B.symbol && B.symbol.exports && B.symbol.exports.get(U);
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(w, s, q, F, fe, Ee, Se, J, se, Me) {
              return Q;
              function Q(Be) {
                Be === void 0 && (Be = function() {
                  return true;
                });
                var je = [], V = [];
                return { walkType: function(ie) {
                  try {
                    return B(ie), { visitedTypes: e.getOwnValues(je), visitedSymbols: e.getOwnValues(V) };
                  } finally {
                    e.clear(je), e.clear(V);
                  }
                }, walkSymbol: function(ie) {
                  try {
                    return ge(ie), { visitedTypes: e.getOwnValues(je), visitedSymbols: e.getOwnValues(V) };
                  } finally {
                    e.clear(je), e.clear(V);
                  }
                } };
                function B(ie) {
                  if (ie && !je[ie.id]) {
                    je[ie.id] = ie;
                    var H = ge(ie.symbol);
                    if (!H) {
                      if (ie.flags & 524288) {
                        var pe = ie, j = pe.objectFlags;
                        j & 4 && U(ie), j & 32 && S(ie), j & 3 && Je(ie), j & 24 && qe(pe);
                      }
                      ie.flags & 262144 && m(ie), ie.flags & 3145728 && v(ie), ie.flags & 4194304 && g(ie), ie.flags & 8388608 && O(ie);
                    }
                  }
                }
                function U(ie) {
                  B(ie.target), e.forEach(Me(ie), B);
                }
                function m(ie) {
                  B(J(ie));
                }
                function v(ie) {
                  e.forEach(ie.types, B);
                }
                function g(ie) {
                  B(ie.type);
                }
                function O(ie) {
                  B(ie.objectType), B(ie.indexType), B(ie.constraint);
                }
                function S(ie) {
                  B(ie.typeParameter), B(ie.constraintType), B(ie.templateType), B(ie.modifiersType);
                }
                function te(ie) {
                  var H = s(ie);
                  H && B(H.type), e.forEach(ie.typeParameters, B);
                  for (var pe = 0, j = ie.parameters; pe < j.length; pe++) {
                    var be = j[pe];
                    ge(be);
                  }
                  B(w(ie)), B(q(ie));
                }
                function Je(ie) {
                  qe(ie), e.forEach(ie.typeParameters, B), e.forEach(F(ie), B), B(ie.thisType);
                }
                function qe(ie) {
                  for (var H = fe(ie), pe = 0, j = H.indexInfos; pe < j.length; pe++) {
                    var be = j[pe];
                    B(be.keyType), B(be.type);
                  }
                  for (var Xe = 0, Re = H.callSignatures; Xe < Re.length; Xe++) {
                    var Fe = Re[Xe];
                    te(Fe);
                  }
                  for (var dr = 0, ze = H.constructSignatures; dr < ze.length; dr++) {
                    var Fe = ze[dr];
                    te(Fe);
                  }
                  for (var ve = 0, er = H.properties; ve < er.length; ve++) {
                    var ar = er[ve];
                    ge(ar);
                  }
                }
                function ge(ie) {
                  if (!ie)
                    return false;
                  var H = e.getSymbolId(ie);
                  if (V[H])
                    return false;
                  if (V[H] = ie, !Be(ie))
                    return true;
                  var pe = Ee(ie);
                  return B(pe), ie.exports && ie.exports.forEach(ge), e.forEach(ie.declarations, function(j) {
                    if (j.type && j.type.kind === 183) {
                      var be = j.type, Xe = Se(se(be.exprName));
                      ge(Xe);
                    }
                  }), false;
                }
              }
            }
            e.createGetSymbolWalker = t3;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            function w(U, m, v, g) {
              if (U === void 0 || m === void 0)
                return U;
              var O = m(U);
              if (O === U)
                return U;
              var S;
              if (O !== void 0)
                return e.isArray(O) ? S = (g || B)(O) : S = O, e.Debug.assertNode(S, v), S;
            }
            e.visitNode = w;
            function s(U, m, v, g, O) {
              if (U === void 0 || m === void 0)
                return U;
              var S = U.length;
              (g === void 0 || g < 0) && (g = 0), (O === void 0 || O > S - g) && (O = S - g);
              var te, Je = -1, qe = -1;
              g > 0 || O < S ? te = U.hasTrailingComma && g + O === S : (Je = U.pos, qe = U.end, te = U.hasTrailingComma);
              var ge = F(U, m, v, g, O);
              if (ge !== U) {
                var ie = e.factory.createNodeArray(ge, te);
                return e.setTextRangePosEnd(ie, Je, qe), ie;
              }
              return U;
            }
            e.visitNodes = s;
            function q(U, m, v, g, O) {
              if (U === void 0)
                return U;
              var S = U.length;
              return (g === void 0 || g < 0) && (g = 0), (O === void 0 || O > S - g) && (O = S - g), F(U, m, v, g, O);
            }
            e.visitArray = q;
            function F(U, m, v, g, O) {
              var S, te = U.length;
              (g > 0 || O < te) && (S = []);
              for (var Je = 0; Je < O; Je++) {
                var qe = U[Je + g], ge = qe !== void 0 ? m(qe) : void 0;
                if ((S !== void 0 || ge === void 0 || ge !== qe) && (S === void 0 && (S = U.slice(0, Je)), ge))
                  if (e.isArray(ge))
                    for (var ie = 0, H = ge; ie < H.length; ie++) {
                      var pe = H[ie];
                      e.Debug.assertNode(pe, v), S.push(pe);
                    }
                  else
                    e.Debug.assertNode(ge, v), S.push(ge);
              }
              return S != null ? S : U;
            }
            function fe(U, m, v, g, O, S) {
              return S === void 0 && (S = s), v.startLexicalEnvironment(), U = S(U, m, e.isStatement, g), O && (U = v.factory.ensureUseStrict(U)), e.factory.mergeLexicalEnvironment(U, v.endLexicalEnvironment());
            }
            e.visitLexicalEnvironment = fe;
            function Ee(U, m, v, g) {
              g === void 0 && (g = s);
              var O;
              return v.startLexicalEnvironment(), U && (v.setLexicalEnvironmentFlags(1, true), O = g(U, m, e.isParameterDeclaration), v.getLexicalEnvironmentFlags() & 2 && e.getEmitScriptTarget(v.getCompilerOptions()) >= 2 && (O = Se(O, v)), v.setLexicalEnvironmentFlags(1, false)), v.suspendLexicalEnvironment(), O;
            }
            e.visitParameterList = Ee;
            function Se(U, m) {
              for (var v, g = 0; g < U.length; g++) {
                var O = U[g], S = J(O, m);
                (v || S !== O) && (v || (v = U.slice(0, g)), v[g] = S);
              }
              return v ? e.setTextRange(m.factory.createNodeArray(v, U.hasTrailingComma), U) : U;
            }
            function J(U, m) {
              return U.dotDotDotToken ? U : e.isBindingPattern(U.name) ? se(U, m) : U.initializer ? Me(U, U.name, U.initializer, m) : U;
            }
            function se(U, m) {
              var v = m.factory;
              return m.addInitializationStatement(v.createVariableStatement(void 0, v.createVariableDeclarationList([v.createVariableDeclaration(U.name, void 0, U.type, U.initializer ? v.createConditionalExpression(v.createStrictEquality(v.getGeneratedNameForNode(U), v.createVoidZero()), void 0, U.initializer, void 0, v.getGeneratedNameForNode(U)) : v.getGeneratedNameForNode(U))]))), v.updateParameterDeclaration(U, U.modifiers, U.dotDotDotToken, v.getGeneratedNameForNode(U), U.questionToken, U.type, void 0);
            }
            function Me(U, m, v, g) {
              var O = g.factory;
              return g.addInitializationStatement(O.createIfStatement(O.createTypeCheck(O.cloneNode(m), "undefined"), e.setEmitFlags(e.setTextRange(O.createBlock([O.createExpressionStatement(e.setEmitFlags(e.setTextRange(O.createAssignment(e.setEmitFlags(O.cloneNode(m), 48), e.setEmitFlags(v, 48 | e.getEmitFlags(v) | 1536)), U), 1536))]), U), 1953))), O.updateParameterDeclaration(U, U.modifiers, U.dotDotDotToken, U.name, U.questionToken, U.type, void 0);
            }
            function Q(U, m, v, g) {
              g === void 0 && (g = w), v.resumeLexicalEnvironment();
              var O = g(U, m, e.isConciseBody), S = v.endLexicalEnvironment();
              if (e.some(S)) {
                if (!O)
                  return v.factory.createBlock(S);
                var te = v.factory.converters.convertToFunctionBlock(O), Je = e.factory.mergeLexicalEnvironment(te.statements, S);
                return v.factory.updateBlock(te, Je);
              }
              return O;
            }
            e.visitFunctionBody = Q;
            function Be(U, m, v, g) {
              g === void 0 && (g = w), v.startBlockScope();
              var O = g(U, m, e.isStatement, v.factory.liftToBlock), S = v.endBlockScope();
              return e.some(S) ? e.isBlock(O) ? (S.push.apply(S, O.statements), v.factory.updateBlock(O, S)) : (S.push(O), v.factory.createBlock(S)) : O;
            }
            e.visitIterationBody = Be;
            function je(U, m, v, g, O, S) {
              if (g === void 0 && (g = s), S === void 0 && (S = w), U !== void 0) {
                var te = V[U.kind];
                return te === void 0 ? U : te(U, m, v, g, S, O);
              }
            }
            e.visitEachChild = je;
            var V = (t3 = {}, t3[79] = function(m, v, g, O, S, te) {
              return g.factory.updateIdentifier(m, O(m.typeArguments, v, e.isTypeNodeOrTypeParameterDeclaration));
            }, t3[163] = function(m, v, g, O, S, te) {
              return g.factory.updateQualifiedName(m, S(m.left, v, e.isEntityName), S(m.right, v, e.isIdentifier));
            }, t3[164] = function(m, v, g, O, S, te) {
              return g.factory.updateComputedPropertyName(m, S(m.expression, v, e.isExpression));
            }, t3[165] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeParameterDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isIdentifier), S(m.constraint, v, e.isTypeNode), S(m.default, v, e.isTypeNode));
            }, t3[166] = function(m, v, g, O, S, te) {
              return g.factory.updateParameterDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.dotDotDotToken, te, e.isDotDotDotToken), S(m.name, v, e.isBindingName), S(m.questionToken, te, e.isQuestionToken), S(m.type, v, e.isTypeNode), S(m.initializer, v, e.isExpression));
            }, t3[167] = function(m, v, g, O, S, te) {
              return g.factory.updateDecorator(m, S(m.expression, v, e.isExpression));
            }, t3[168] = function(m, v, g, O, S, te) {
              return g.factory.updatePropertySignature(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isPropertyName), S(m.questionToken, te, e.isToken), S(m.type, v, e.isTypeNode));
            }, t3[169] = function(m, v, g, O, S, te) {
              var Je;
              return g.factory.updatePropertyDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.name, v, e.isPropertyName), S((Je = m.questionToken) !== null && Je !== void 0 ? Je : m.exclamationToken, te, e.isQuestionOrExclamationToken), S(m.type, v, e.isTypeNode), S(m.initializer, v, e.isExpression));
            }, t3[170] = function(m, v, g, O, S, te) {
              return g.factory.updateMethodSignature(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isPropertyName), S(m.questionToken, te, e.isQuestionToken), O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[171] = function(m, v, g, O, S, te) {
              return g.factory.updateMethodDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.asteriskToken, te, e.isAsteriskToken), S(m.name, v, e.isPropertyName), S(m.questionToken, te, e.isQuestionToken), O(m.typeParameters, v, e.isTypeParameterDeclaration), Ee(m.parameters, v, g, O), S(m.type, v, e.isTypeNode), Q(m.body, v, g, S));
            }, t3[173] = function(m, v, g, O, S, te) {
              return g.factory.updateConstructorDeclaration(m, O(m.modifiers, v, e.isModifier), Ee(m.parameters, v, g, O), Q(m.body, v, g, S));
            }, t3[174] = function(m, v, g, O, S, te) {
              return g.factory.updateGetAccessorDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.name, v, e.isPropertyName), Ee(m.parameters, v, g, O), S(m.type, v, e.isTypeNode), Q(m.body, v, g, S));
            }, t3[175] = function(m, v, g, O, S, te) {
              return g.factory.updateSetAccessorDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.name, v, e.isPropertyName), Ee(m.parameters, v, g, O), Q(m.body, v, g, S));
            }, t3[172] = function(m, v, g, O, S, te) {
              return g.startLexicalEnvironment(), g.suspendLexicalEnvironment(), g.factory.updateClassStaticBlockDeclaration(m, Q(m.body, v, g, S));
            }, t3[176] = function(m, v, g, O, S, te) {
              return g.factory.updateCallSignature(m, O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[177] = function(m, v, g, O, S, te) {
              return g.factory.updateConstructSignature(m, O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[178] = function(m, v, g, O, S, te) {
              return g.factory.updateIndexSignature(m, O(m.modifiers, v, e.isModifier), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[179] = function(m, v, g, O, S, te) {
              return g.factory.updateTypePredicateNode(m, S(m.assertsModifier, v, e.isAssertsKeyword), S(m.parameterName, v, e.isIdentifierOrThisTypeNode), S(m.type, v, e.isTypeNode));
            }, t3[180] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeReferenceNode(m, S(m.typeName, v, e.isEntityName), O(m.typeArguments, v, e.isTypeNode));
            }, t3[181] = function(m, v, g, O, S, te) {
              return g.factory.updateFunctionTypeNode(m, O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[182] = function(m, v, g, O, S, te) {
              return g.factory.updateConstructorTypeNode(m, O(m.modifiers, v, e.isModifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.parameters, v, e.isParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[183] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeQueryNode(m, S(m.exprName, v, e.isEntityName), O(m.typeArguments, v, e.isTypeNode));
            }, t3[184] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeLiteralNode(m, O(m.members, v, e.isTypeElement));
            }, t3[185] = function(m, v, g, O, S, te) {
              return g.factory.updateArrayTypeNode(m, S(m.elementType, v, e.isTypeNode));
            }, t3[186] = function(m, v, g, O, S, te) {
              return g.factory.updateTupleTypeNode(m, O(m.elements, v, e.isTypeNode));
            }, t3[187] = function(m, v, g, O, S, te) {
              return g.factory.updateOptionalTypeNode(m, S(m.type, v, e.isTypeNode));
            }, t3[188] = function(m, v, g, O, S, te) {
              return g.factory.updateRestTypeNode(m, S(m.type, v, e.isTypeNode));
            }, t3[189] = function(m, v, g, O, S, te) {
              return g.factory.updateUnionTypeNode(m, O(m.types, v, e.isTypeNode));
            }, t3[190] = function(m, v, g, O, S, te) {
              return g.factory.updateIntersectionTypeNode(m, O(m.types, v, e.isTypeNode));
            }, t3[191] = function(m, v, g, O, S, te) {
              return g.factory.updateConditionalTypeNode(m, S(m.checkType, v, e.isTypeNode), S(m.extendsType, v, e.isTypeNode), S(m.trueType, v, e.isTypeNode), S(m.falseType, v, e.isTypeNode));
            }, t3[192] = function(m, v, g, O, S, te) {
              return g.factory.updateInferTypeNode(m, S(m.typeParameter, v, e.isTypeParameterDeclaration));
            }, t3[202] = function(m, v, g, O, S, te) {
              return g.factory.updateImportTypeNode(m, S(m.argument, v, e.isTypeNode), S(m.assertions, v, e.isImportTypeAssertionContainer), S(m.qualifier, v, e.isEntityName), O(m.typeArguments, v, e.isTypeNode), m.isTypeOf);
            }, t3[298] = function(m, v, g, O, S, te) {
              return g.factory.updateImportTypeAssertionContainer(m, S(m.assertClause, v, e.isAssertClause), m.multiLine);
            }, t3[199] = function(m, v, g, O, S, te) {
              return g.factory.updateNamedTupleMember(m, S(m.dotDotDotToken, te, e.isDotDotDotToken), S(m.name, v, e.isIdentifier), S(m.questionToken, te, e.isQuestionToken), S(m.type, v, e.isTypeNode));
            }, t3[193] = function(m, v, g, O, S, te) {
              return g.factory.updateParenthesizedType(m, S(m.type, v, e.isTypeNode));
            }, t3[195] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeOperatorNode(m, S(m.type, v, e.isTypeNode));
            }, t3[196] = function(m, v, g, O, S, te) {
              return g.factory.updateIndexedAccessTypeNode(m, S(m.objectType, v, e.isTypeNode), S(m.indexType, v, e.isTypeNode));
            }, t3[197] = function(m, v, g, O, S, te) {
              return g.factory.updateMappedTypeNode(m, S(m.readonlyToken, te, e.isReadonlyKeywordOrPlusOrMinusToken), S(m.typeParameter, v, e.isTypeParameterDeclaration), S(m.nameType, v, e.isTypeNode), S(m.questionToken, te, e.isQuestionOrPlusOrMinusToken), S(m.type, v, e.isTypeNode), O(m.members, v, e.isTypeElement));
            }, t3[198] = function(m, v, g, O, S, te) {
              return g.factory.updateLiteralTypeNode(m, S(m.literal, v, e.isExpression));
            }, t3[200] = function(m, v, g, O, S, te) {
              return g.factory.updateTemplateLiteralType(m, S(m.head, v, e.isTemplateHead), O(m.templateSpans, v, e.isTemplateLiteralTypeSpan));
            }, t3[201] = function(m, v, g, O, S, te) {
              return g.factory.updateTemplateLiteralTypeSpan(m, S(m.type, v, e.isTypeNode), S(m.literal, v, e.isTemplateMiddleOrTemplateTail));
            }, t3[203] = function(m, v, g, O, S, te) {
              return g.factory.updateObjectBindingPattern(m, O(m.elements, v, e.isBindingElement));
            }, t3[204] = function(m, v, g, O, S, te) {
              return g.factory.updateArrayBindingPattern(m, O(m.elements, v, e.isArrayBindingElement));
            }, t3[205] = function(m, v, g, O, S, te) {
              return g.factory.updateBindingElement(m, S(m.dotDotDotToken, te, e.isDotDotDotToken), S(m.propertyName, v, e.isPropertyName), S(m.name, v, e.isBindingName), S(m.initializer, v, e.isExpression));
            }, t3[206] = function(m, v, g, O, S, te) {
              return g.factory.updateArrayLiteralExpression(m, O(m.elements, v, e.isExpression));
            }, t3[207] = function(m, v, g, O, S, te) {
              return g.factory.updateObjectLiteralExpression(m, O(m.properties, v, e.isObjectLiteralElementLike));
            }, t3[208] = function(m, v, g, O, S, te) {
              return e.isPropertyAccessChain(m) ? g.factory.updatePropertyAccessChain(m, S(m.expression, v, e.isExpression), S(m.questionDotToken, te, e.isQuestionDotToken), S(m.name, v, e.isMemberName)) : g.factory.updatePropertyAccessExpression(m, S(m.expression, v, e.isExpression), S(m.name, v, e.isMemberName));
            }, t3[209] = function(m, v, g, O, S, te) {
              return e.isElementAccessChain(m) ? g.factory.updateElementAccessChain(m, S(m.expression, v, e.isExpression), S(m.questionDotToken, te, e.isQuestionDotToken), S(m.argumentExpression, v, e.isExpression)) : g.factory.updateElementAccessExpression(m, S(m.expression, v, e.isExpression), S(m.argumentExpression, v, e.isExpression));
            }, t3[210] = function(m, v, g, O, S, te) {
              return e.isCallChain(m) ? g.factory.updateCallChain(m, S(m.expression, v, e.isExpression), S(m.questionDotToken, te, e.isQuestionDotToken), O(m.typeArguments, v, e.isTypeNode), O(m.arguments, v, e.isExpression)) : g.factory.updateCallExpression(m, S(m.expression, v, e.isExpression), O(m.typeArguments, v, e.isTypeNode), O(m.arguments, v, e.isExpression));
            }, t3[211] = function(m, v, g, O, S, te) {
              return g.factory.updateNewExpression(m, S(m.expression, v, e.isExpression), O(m.typeArguments, v, e.isTypeNode), O(m.arguments, v, e.isExpression));
            }, t3[212] = function(m, v, g, O, S, te) {
              return g.factory.updateTaggedTemplateExpression(m, S(m.tag, v, e.isExpression), O(m.typeArguments, v, e.isTypeNode), S(m.template, v, e.isTemplateLiteral));
            }, t3[213] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeAssertion(m, S(m.type, v, e.isTypeNode), S(m.expression, v, e.isExpression));
            }, t3[214] = function(m, v, g, O, S, te) {
              return g.factory.updateParenthesizedExpression(m, S(m.expression, v, e.isExpression));
            }, t3[215] = function(m, v, g, O, S, te) {
              return g.factory.updateFunctionExpression(m, O(m.modifiers, v, e.isModifier), S(m.asteriskToken, te, e.isAsteriskToken), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), Ee(m.parameters, v, g, O), S(m.type, v, e.isTypeNode), Q(m.body, v, g, S));
            }, t3[216] = function(m, v, g, O, S, te) {
              return g.factory.updateArrowFunction(m, O(m.modifiers, v, e.isModifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), Ee(m.parameters, v, g, O), S(m.type, v, e.isTypeNode), S(m.equalsGreaterThanToken, te, e.isEqualsGreaterThanToken), Q(m.body, v, g, S));
            }, t3[217] = function(m, v, g, O, S, te) {
              return g.factory.updateDeleteExpression(m, S(m.expression, v, e.isExpression));
            }, t3[218] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeOfExpression(m, S(m.expression, v, e.isExpression));
            }, t3[219] = function(m, v, g, O, S, te) {
              return g.factory.updateVoidExpression(m, S(m.expression, v, e.isExpression));
            }, t3[220] = function(m, v, g, O, S, te) {
              return g.factory.updateAwaitExpression(m, S(m.expression, v, e.isExpression));
            }, t3[221] = function(m, v, g, O, S, te) {
              return g.factory.updatePrefixUnaryExpression(m, S(m.operand, v, e.isExpression));
            }, t3[222] = function(m, v, g, O, S, te) {
              return g.factory.updatePostfixUnaryExpression(m, S(m.operand, v, e.isExpression));
            }, t3[223] = function(m, v, g, O, S, te) {
              return g.factory.updateBinaryExpression(m, S(m.left, v, e.isExpression), S(m.operatorToken, te, e.isBinaryOperatorToken), S(m.right, v, e.isExpression));
            }, t3[224] = function(m, v, g, O, S, te) {
              return g.factory.updateConditionalExpression(m, S(m.condition, v, e.isExpression), S(m.questionToken, te, e.isQuestionToken), S(m.whenTrue, v, e.isExpression), S(m.colonToken, te, e.isColonToken), S(m.whenFalse, v, e.isExpression));
            }, t3[225] = function(m, v, g, O, S, te) {
              return g.factory.updateTemplateExpression(m, S(m.head, v, e.isTemplateHead), O(m.templateSpans, v, e.isTemplateSpan));
            }, t3[226] = function(m, v, g, O, S, te) {
              return g.factory.updateYieldExpression(m, S(m.asteriskToken, te, e.isAsteriskToken), S(m.expression, v, e.isExpression));
            }, t3[227] = function(m, v, g, O, S, te) {
              return g.factory.updateSpreadElement(m, S(m.expression, v, e.isExpression));
            }, t3[228] = function(m, v, g, O, S, te) {
              return g.factory.updateClassExpression(m, O(m.modifiers, v, e.isModifierLike), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.heritageClauses, v, e.isHeritageClause), O(m.members, v, e.isClassElement));
            }, t3[230] = function(m, v, g, O, S, te) {
              return g.factory.updateExpressionWithTypeArguments(m, S(m.expression, v, e.isExpression), O(m.typeArguments, v, e.isTypeNode));
            }, t3[231] = function(m, v, g, O, S, te) {
              return g.factory.updateAsExpression(m, S(m.expression, v, e.isExpression), S(m.type, v, e.isTypeNode));
            }, t3[235] = function(m, v, g, O, S, te) {
              return g.factory.updateSatisfiesExpression(m, S(m.expression, v, e.isExpression), S(m.type, v, e.isTypeNode));
            }, t3[232] = function(m, v, g, O, S, te) {
              return e.isOptionalChain(m) ? g.factory.updateNonNullChain(m, S(m.expression, v, e.isExpression)) : g.factory.updateNonNullExpression(m, S(m.expression, v, e.isExpression));
            }, t3[233] = function(m, v, g, O, S, te) {
              return g.factory.updateMetaProperty(m, S(m.name, v, e.isIdentifier));
            }, t3[236] = function(m, v, g, O, S, te) {
              return g.factory.updateTemplateSpan(m, S(m.expression, v, e.isExpression), S(m.literal, v, e.isTemplateMiddleOrTemplateTail));
            }, t3[238] = function(m, v, g, O, S, te) {
              return g.factory.updateBlock(m, O(m.statements, v, e.isStatement));
            }, t3[240] = function(m, v, g, O, S, te) {
              return g.factory.updateVariableStatement(m, O(m.modifiers, v, e.isModifier), S(m.declarationList, v, e.isVariableDeclarationList));
            }, t3[241] = function(m, v, g, O, S, te) {
              return g.factory.updateExpressionStatement(m, S(m.expression, v, e.isExpression));
            }, t3[242] = function(m, v, g, O, S, te) {
              return g.factory.updateIfStatement(m, S(m.expression, v, e.isExpression), S(m.thenStatement, v, e.isStatement, g.factory.liftToBlock), S(m.elseStatement, v, e.isStatement, g.factory.liftToBlock));
            }, t3[243] = function(m, v, g, O, S, te) {
              return g.factory.updateDoStatement(m, Be(m.statement, v, g, S), S(m.expression, v, e.isExpression));
            }, t3[244] = function(m, v, g, O, S, te) {
              return g.factory.updateWhileStatement(m, S(m.expression, v, e.isExpression), Be(m.statement, v, g, S));
            }, t3[245] = function(m, v, g, O, S, te) {
              return g.factory.updateForStatement(m, S(m.initializer, v, e.isForInitializer), S(m.condition, v, e.isExpression), S(m.incrementor, v, e.isExpression), Be(m.statement, v, g, S));
            }, t3[246] = function(m, v, g, O, S, te) {
              return g.factory.updateForInStatement(m, S(m.initializer, v, e.isForInitializer), S(m.expression, v, e.isExpression), Be(m.statement, v, g, S));
            }, t3[247] = function(m, v, g, O, S, te) {
              return g.factory.updateForOfStatement(m, S(m.awaitModifier, te, e.isAwaitKeyword), S(m.initializer, v, e.isForInitializer), S(m.expression, v, e.isExpression), Be(m.statement, v, g, S));
            }, t3[248] = function(m, v, g, O, S, te) {
              return g.factory.updateContinueStatement(m, S(m.label, v, e.isIdentifier));
            }, t3[249] = function(m, v, g, O, S, te) {
              return g.factory.updateBreakStatement(m, S(m.label, v, e.isIdentifier));
            }, t3[250] = function(m, v, g, O, S, te) {
              return g.factory.updateReturnStatement(m, S(m.expression, v, e.isExpression));
            }, t3[251] = function(m, v, g, O, S, te) {
              return g.factory.updateWithStatement(m, S(m.expression, v, e.isExpression), S(m.statement, v, e.isStatement, g.factory.liftToBlock));
            }, t3[252] = function(m, v, g, O, S, te) {
              return g.factory.updateSwitchStatement(m, S(m.expression, v, e.isExpression), S(m.caseBlock, v, e.isCaseBlock));
            }, t3[253] = function(m, v, g, O, S, te) {
              return g.factory.updateLabeledStatement(m, S(m.label, v, e.isIdentifier), S(m.statement, v, e.isStatement, g.factory.liftToBlock));
            }, t3[254] = function(m, v, g, O, S, te) {
              return g.factory.updateThrowStatement(m, S(m.expression, v, e.isExpression));
            }, t3[255] = function(m, v, g, O, S, te) {
              return g.factory.updateTryStatement(m, S(m.tryBlock, v, e.isBlock), S(m.catchClause, v, e.isCatchClause), S(m.finallyBlock, v, e.isBlock));
            }, t3[257] = function(m, v, g, O, S, te) {
              return g.factory.updateVariableDeclaration(m, S(m.name, v, e.isBindingName), S(m.exclamationToken, te, e.isExclamationToken), S(m.type, v, e.isTypeNode), S(m.initializer, v, e.isExpression));
            }, t3[258] = function(m, v, g, O, S, te) {
              return g.factory.updateVariableDeclarationList(m, O(m.declarations, v, e.isVariableDeclaration));
            }, t3[259] = function(m, v, g, O, S, te) {
              return g.factory.updateFunctionDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.asteriskToken, te, e.isAsteriskToken), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), Ee(m.parameters, v, g, O), S(m.type, v, e.isTypeNode), Q(m.body, v, g, S));
            }, t3[260] = function(m, v, g, O, S, te) {
              return g.factory.updateClassDeclaration(m, O(m.modifiers, v, e.isModifierLike), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.heritageClauses, v, e.isHeritageClause), O(m.members, v, e.isClassElement));
            }, t3[261] = function(m, v, g, O, S, te) {
              return g.factory.updateInterfaceDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), O(m.heritageClauses, v, e.isHeritageClause), O(m.members, v, e.isTypeElement));
            }, t3[262] = function(m, v, g, O, S, te) {
              return g.factory.updateTypeAliasDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isIdentifier), O(m.typeParameters, v, e.isTypeParameterDeclaration), S(m.type, v, e.isTypeNode));
            }, t3[263] = function(m, v, g, O, S, te) {
              return g.factory.updateEnumDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isIdentifier), O(m.members, v, e.isEnumMember));
            }, t3[264] = function(m, v, g, O, S, te) {
              return g.factory.updateModuleDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.name, v, e.isModuleName), S(m.body, v, e.isModuleBody));
            }, t3[265] = function(m, v, g, O, S, te) {
              return g.factory.updateModuleBlock(m, O(m.statements, v, e.isStatement));
            }, t3[266] = function(m, v, g, O, S, te) {
              return g.factory.updateCaseBlock(m, O(m.clauses, v, e.isCaseOrDefaultClause));
            }, t3[267] = function(m, v, g, O, S, te) {
              return g.factory.updateNamespaceExportDeclaration(m, S(m.name, v, e.isIdentifier));
            }, t3[268] = function(m, v, g, O, S, te) {
              return g.factory.updateImportEqualsDeclaration(m, O(m.modifiers, v, e.isModifier), m.isTypeOnly, S(m.name, v, e.isIdentifier), S(m.moduleReference, v, e.isModuleReference));
            }, t3[269] = function(m, v, g, O, S, te) {
              return g.factory.updateImportDeclaration(m, O(m.modifiers, v, e.isModifier), S(m.importClause, v, e.isImportClause), S(m.moduleSpecifier, v, e.isExpression), S(m.assertClause, v, e.isAssertClause));
            }, t3[296] = function(m, v, g, O, S, te) {
              return g.factory.updateAssertClause(m, O(m.elements, v, e.isAssertEntry), m.multiLine);
            }, t3[297] = function(m, v, g, O, S, te) {
              return g.factory.updateAssertEntry(m, S(m.name, v, e.isAssertionKey), S(m.value, v, e.isExpression));
            }, t3[270] = function(m, v, g, O, S, te) {
              return g.factory.updateImportClause(m, m.isTypeOnly, S(m.name, v, e.isIdentifier), S(m.namedBindings, v, e.isNamedImportBindings));
            }, t3[271] = function(m, v, g, O, S, te) {
              return g.factory.updateNamespaceImport(m, S(m.name, v, e.isIdentifier));
            }, t3[277] = function(m, v, g, O, S, te) {
              return g.factory.updateNamespaceExport(m, S(m.name, v, e.isIdentifier));
            }, t3[272] = function(m, v, g, O, S, te) {
              return g.factory.updateNamedImports(m, O(m.elements, v, e.isImportSpecifier));
            }, t3[273] = function(m, v, g, O, S, te) {
              return g.factory.updateImportSpecifier(m, m.isTypeOnly, S(m.propertyName, v, e.isIdentifier), S(m.name, v, e.isIdentifier));
            }, t3[274] = function(m, v, g, O, S, te) {
              return g.factory.updateExportAssignment(m, O(m.modifiers, v, e.isModifier), S(m.expression, v, e.isExpression));
            }, t3[275] = function(m, v, g, O, S, te) {
              return g.factory.updateExportDeclaration(m, O(m.modifiers, v, e.isModifier), m.isTypeOnly, S(m.exportClause, v, e.isNamedExportBindings), S(m.moduleSpecifier, v, e.isExpression), S(m.assertClause, v, e.isAssertClause));
            }, t3[276] = function(m, v, g, O, S, te) {
              return g.factory.updateNamedExports(m, O(m.elements, v, e.isExportSpecifier));
            }, t3[278] = function(m, v, g, O, S, te) {
              return g.factory.updateExportSpecifier(m, m.isTypeOnly, S(m.propertyName, v, e.isIdentifier), S(m.name, v, e.isIdentifier));
            }, t3[280] = function(m, v, g, O, S, te) {
              return g.factory.updateExternalModuleReference(m, S(m.expression, v, e.isExpression));
            }, t3[281] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxElement(m, S(m.openingElement, v, e.isJsxOpeningElement), O(m.children, v, e.isJsxChild), S(m.closingElement, v, e.isJsxClosingElement));
            }, t3[282] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxSelfClosingElement(m, S(m.tagName, v, e.isJsxTagNameExpression), O(m.typeArguments, v, e.isTypeNode), S(m.attributes, v, e.isJsxAttributes));
            }, t3[283] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxOpeningElement(m, S(m.tagName, v, e.isJsxTagNameExpression), O(m.typeArguments, v, e.isTypeNode), S(m.attributes, v, e.isJsxAttributes));
            }, t3[284] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxClosingElement(m, S(m.tagName, v, e.isJsxTagNameExpression));
            }, t3[285] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxFragment(m, S(m.openingFragment, v, e.isJsxOpeningFragment), O(m.children, v, e.isJsxChild), S(m.closingFragment, v, e.isJsxClosingFragment));
            }, t3[288] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxAttribute(m, S(m.name, v, e.isIdentifier), S(m.initializer, v, e.isStringLiteralOrJsxExpression));
            }, t3[289] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxAttributes(m, O(m.properties, v, e.isJsxAttributeLike));
            }, t3[290] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxSpreadAttribute(m, S(m.expression, v, e.isExpression));
            }, t3[291] = function(m, v, g, O, S, te) {
              return g.factory.updateJsxExpression(m, S(m.expression, v, e.isExpression));
            }, t3[292] = function(m, v, g, O, S, te) {
              return g.factory.updateCaseClause(m, S(m.expression, v, e.isExpression), O(m.statements, v, e.isStatement));
            }, t3[293] = function(m, v, g, O, S, te) {
              return g.factory.updateDefaultClause(m, O(m.statements, v, e.isStatement));
            }, t3[294] = function(m, v, g, O, S, te) {
              return g.factory.updateHeritageClause(m, O(m.types, v, e.isExpressionWithTypeArguments));
            }, t3[295] = function(m, v, g, O, S, te) {
              return g.factory.updateCatchClause(m, S(m.variableDeclaration, v, e.isVariableDeclaration), S(m.block, v, e.isBlock));
            }, t3[299] = function(m, v, g, O, S, te) {
              return g.factory.updatePropertyAssignment(m, S(m.name, v, e.isPropertyName), S(m.initializer, v, e.isExpression));
            }, t3[300] = function(m, v, g, O, S, te) {
              return g.factory.updateShorthandPropertyAssignment(m, S(m.name, v, e.isIdentifier), S(m.objectAssignmentInitializer, v, e.isExpression));
            }, t3[301] = function(m, v, g, O, S, te) {
              return g.factory.updateSpreadAssignment(m, S(m.expression, v, e.isExpression));
            }, t3[302] = function(m, v, g, O, S, te) {
              return g.factory.updateEnumMember(m, S(m.name, v, e.isPropertyName), S(m.initializer, v, e.isExpression));
            }, t3[308] = function(m, v, g, O, S, te) {
              return g.factory.updateSourceFile(m, fe(m.statements, v, g, void 0, void 0, O));
            }, t3[353] = function(m, v, g, O, S, te) {
              return g.factory.updatePartiallyEmittedExpression(m, S(m.expression, v, e.isExpression));
            }, t3[354] = function(m, v, g, O, S, te) {
              return g.factory.updateCommaListExpression(m, O(m.elements, v, e.isExpression));
            }, t3);
            function B(U) {
              return e.Debug.assert(U.length <= 1, "Too many nodes written to output."), e.singleOrUndefined(U);
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3(j) {
              return j = e.getOriginalNode(j), j ? e.getNodeId(j) : 0;
            }
            e.getOriginalNodeId = t3;
            function w(j) {
              return !j || !e.isNamedImports(j) ? false : e.some(j.elements, s);
            }
            function s(j) {
              return j.propertyName !== void 0 && j.propertyName.escapedText === "default";
            }
            function q(j, be) {
              return Xe;
              function Xe(Fe) {
                return Fe.kind === 308 ? be(Fe) : Re(Fe);
              }
              function Re(Fe) {
                return j.factory.createBundle(e.map(Fe.sourceFiles, be), Fe.prepends);
              }
            }
            e.chainBundle = q;
            function F(j) {
              return !!e.getNamespaceDeclarationNode(j);
            }
            e.getExportNeedsImportStarHelper = F;
            function fe(j) {
              if (e.getNamespaceDeclarationNode(j))
                return true;
              var be = j.importClause && j.importClause.namedBindings;
              if (!be || !e.isNamedImports(be))
                return false;
              for (var Xe = 0, Re = 0, Fe = be.elements; Re < Fe.length; Re++) {
                var dr = Fe[Re];
                s(dr) && Xe++;
              }
              return Xe > 0 && Xe !== be.elements.length || !!(be.elements.length - Xe) && e.isDefaultImport(j);
            }
            e.getImportNeedsImportStarHelper = fe;
            function Ee(j) {
              return !fe(j) && (e.isDefaultImport(j) || !!j.importClause && e.isNamedImports(j.importClause.namedBindings) && w(j.importClause.namedBindings));
            }
            e.getImportNeedsImportDefaultHelper = Ee;
            function Se(j, be, Xe, Re) {
              for (var Fe = [], dr = e.createMultiMap(), ze = [], ve = new e.Map(), er, ar = false, Cr, Ce = false, $e = false, gr = false, X = 0, Te = be.statements; X < Te.length; X++) {
                var we = Te[X];
                switch (we.kind) {
                  case 269:
                    Fe.push(we), !$e && fe(we) && ($e = true), !gr && Ee(we) && (gr = true);
                    break;
                  case 268:
                    we.moduleReference.kind === 280 && Fe.push(we);
                    break;
                  case 275:
                    if (we.moduleSpecifier)
                      if (!we.exportClause)
                        Fe.push(we), Ce = true;
                      else if (Fe.push(we), e.isNamedExports(we.exportClause))
                        Lr(we);
                      else {
                        var he = we.exportClause.name;
                        ve.get(e.idText(he)) || (se(ze, t3(we), he), ve.set(e.idText(he), true), er = e.append(er, he)), $e = true;
                      }
                    else
                      Lr(we);
                    break;
                  case 274:
                    we.isExportEquals && !Cr && (Cr = we);
                    break;
                  case 240:
                    if (e.hasSyntacticModifier(we, 1))
                      for (var yr = 0, kr = we.declarationList.declarations; yr < kr.length; yr++) {
                        var nr = kr[yr];
                        er = J(nr, ve, er);
                      }
                    break;
                  case 259:
                    if (e.hasSyntacticModifier(we, 1))
                      if (e.hasSyntacticModifier(we, 1024))
                        ar || (se(ze, t3(we), j.factory.getDeclarationName(we)), ar = true);
                      else {
                        var he = we.name;
                        ve.get(e.idText(he)) || (se(ze, t3(we), he), ve.set(e.idText(he), true), er = e.append(er, he));
                      }
                    break;
                  case 260:
                    if (e.hasSyntacticModifier(we, 1))
                      if (e.hasSyntacticModifier(we, 1024))
                        ar || (se(ze, t3(we), j.factory.getDeclarationName(we)), ar = true);
                      else {
                        var he = we.name;
                        he && !ve.get(e.idText(he)) && (se(ze, t3(we), he), ve.set(e.idText(he), true), er = e.append(er, he));
                      }
                    break;
                }
              }
              var tr = e.createExternalHelpersImportDeclarationIfNeeded(j.factory, j.getEmitHelperFactory(), be, Re, Ce, $e, gr);
              return tr && Fe.unshift(tr), { externalImports: Fe, exportSpecifiers: dr, exportEquals: Cr, hasExportStarsToExportValues: Ce, exportedBindings: ze, exportedNames: er, externalHelpersImportDeclaration: tr };
              function Lr(zr) {
                for (var ye = 0, ir = e.cast(zr.exportClause, e.isNamedExports).elements; ye < ir.length; ye++) {
                  var Dr = ir[ye];
                  if (!ve.get(e.idText(Dr.name))) {
                    var Pr = Dr.propertyName || Dr.name;
                    zr.moduleSpecifier || dr.add(e.idText(Pr), Dr);
                    var Br = Xe.getReferencedImportDeclaration(Pr) || Xe.getReferencedValueDeclaration(Pr);
                    Br && se(ze, t3(Br), Dr.name), ve.set(e.idText(Dr.name), true), er = e.append(er, Dr.name);
                  }
                }
              }
            }
            e.collectExternalModuleInfo = Se;
            function J(j, be, Xe) {
              if (e.isBindingPattern(j.name))
                for (var Re = 0, Fe = j.name.elements; Re < Fe.length; Re++) {
                  var dr = Fe[Re];
                  e.isOmittedExpression(dr) || (Xe = J(dr, be, Xe));
                }
              else if (!e.isGeneratedIdentifier(j.name)) {
                var ze = e.idText(j.name);
                be.get(ze) || (be.set(ze, true), Xe = e.append(Xe, j.name));
              }
              return Xe;
            }
            function se(j, be, Xe) {
              var Re = j[be];
              return Re ? Re.push(Xe) : j[be] = Re = [Xe], Re;
            }
            function Me(j) {
              return e.isStringLiteralLike(j) || j.kind === 8 || e.isKeyword(j.kind) || e.isIdentifier(j);
            }
            e.isSimpleCopiableExpression = Me;
            function Q(j) {
              return !e.isIdentifier(j) && Me(j);
            }
            e.isSimpleInlineableExpression = Q;
            function Be(j) {
              return j >= 64 && j <= 78;
            }
            e.isCompoundAssignment = Be;
            function je(j) {
              switch (j) {
                case 64:
                  return 39;
                case 65:
                  return 40;
                case 66:
                  return 41;
                case 67:
                  return 42;
                case 68:
                  return 43;
                case 69:
                  return 44;
                case 70:
                  return 47;
                case 71:
                  return 48;
                case 72:
                  return 49;
                case 73:
                  return 50;
                case 74:
                  return 51;
                case 78:
                  return 52;
                case 75:
                  return 56;
                case 76:
                  return 55;
                case 77:
                  return 60;
              }
            }
            e.getNonAssignmentOperatorForCompoundAssignment = je;
            function V(j) {
              if (e.isExpressionStatement(j)) {
                var be = e.skipParentheses(j.expression);
                return e.isSuperCall(be) ? be : void 0;
              }
            }
            e.getSuperCallFromStatement = V;
            function B(j, be) {
              for (var Xe = be; Xe < j.length; Xe += 1) {
                var Re = j[Xe];
                if (V(Re))
                  return Xe;
              }
              return -1;
            }
            e.findSuperStatementIndex = B;
            function U(j, be, Xe) {
              return e.filter(j.members, function(Re) {
                return g(Re, be, Xe);
              });
            }
            e.getProperties = U;
            function m(j) {
              return O(j) || e.isClassStaticBlockDeclaration(j);
            }
            function v(j) {
              return e.filter(j.members, m);
            }
            e.getStaticPropertiesAndClassStaticBlock = v;
            function g(j, be, Xe) {
              return e.isPropertyDeclaration(j) && (!!j.initializer || !be) && e.hasStaticModifier(j) === Xe;
            }
            function O(j) {
              return e.isPropertyDeclaration(j) && e.hasStaticModifier(j);
            }
            function S(j) {
              return j.kind === 169 && j.initializer !== void 0;
            }
            e.isInitializedProperty = S;
            function te(j) {
              return !e.isStatic(j) && (e.isMethodOrAccessor(j) || e.isAutoAccessorPropertyDeclaration(j)) && e.isPrivateIdentifier(j.name);
            }
            e.isNonStaticMethodOrAccessorWithPrivateName = te;
            function Je(j) {
              var be;
              if (j)
                for (var Xe = j.parameters, Re = Xe.length > 0 && e.parameterIsThisKeyword(Xe[0]), Fe = Re ? 1 : 0, dr = Re ? Xe.length - 1 : Xe.length, ze = 0; ze < dr; ze++) {
                  var ve = Xe[ze + Fe];
                  (be || e.hasDecorators(ve)) && (be || (be = new Array(dr)), be[ze] = e.getDecorators(ve));
                }
              return be;
            }
            function qe(j) {
              var be = e.getDecorators(j), Xe = Je(e.getFirstConstructorWithBody(j));
              if (!(!e.some(be) && !e.some(Xe)))
                return { decorators: be, parameters: Xe };
            }
            e.getAllDecoratorsOfClass = qe;
            function ge(j, be) {
              switch (j.kind) {
                case 174:
                case 175:
                  return ie(j, be);
                case 171:
                  return H(j);
                case 169:
                  return pe(j);
                default:
                  return;
              }
            }
            e.getAllDecoratorsOfClassElement = ge;
            function ie(j, be) {
              if (j.body) {
                var Xe = e.getAllAccessorDeclarations(be.members, j), Re = Xe.firstAccessor, Fe = Xe.secondAccessor, dr = Xe.getAccessor, ze = Xe.setAccessor, ve = e.hasDecorators(Re) ? Re : Fe && e.hasDecorators(Fe) ? Fe : void 0;
                if (!(!ve || j !== ve)) {
                  var er = e.getDecorators(ve), ar = Je(ze);
                  if (!(!e.some(er) && !e.some(ar)))
                    return { decorators: er, parameters: ar, getDecorators: dr && e.getDecorators(dr), setDecorators: ze && e.getDecorators(ze) };
                }
              }
            }
            function H(j) {
              if (j.body) {
                var be = e.getDecorators(j), Xe = Je(j);
                if (!(!e.some(be) && !e.some(Xe)))
                  return { decorators: be, parameters: Xe };
              }
            }
            function pe(j) {
              var be = e.getDecorators(j);
              if (e.some(be))
                return { decorators: be };
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            e.scanner = e.createScanner(99, true);
            var t3;
            (function(l) {
              l[l.None = 0] = "None", l[l.Value = 1] = "Value", l[l.Type = 2] = "Type", l[l.Namespace = 4] = "Namespace", l[l.All = 7] = "All";
            })(t3 = e.SemanticMeaning || (e.SemanticMeaning = {}));
            function w(l) {
              switch (l.kind) {
                case 257:
                  return e.isInJSFile(l) && e.getJSDocEnumTag(l) ? 7 : 1;
                case 166:
                case 205:
                case 169:
                case 168:
                case 299:
                case 300:
                case 171:
                case 170:
                case 173:
                case 174:
                case 175:
                case 259:
                case 215:
                case 216:
                case 295:
                case 288:
                  return 1;
                case 165:
                case 261:
                case 262:
                case 184:
                  return 2;
                case 348:
                  return l.name === void 0 ? 3 : 2;
                case 302:
                case 260:
                  return 3;
                case 264:
                  return e.isAmbientModule(l) || e.getModuleInstanceState(l) === 1 ? 5 : 4;
                case 263:
                case 272:
                case 273:
                case 268:
                case 269:
                case 274:
                case 275:
                  return 7;
                case 308:
                  return 5;
              }
              return 7;
            }
            e.getMeaningFromDeclaration = w;
            function s(l) {
              l = pt(l);
              var A = l.parent;
              return l.kind === 308 ? 1 : e.isExportAssignment(A) || e.isExportSpecifier(A) || e.isExternalModuleReference(A) || e.isImportSpecifier(A) || e.isImportClause(A) || e.isImportEqualsDeclaration(A) && l === A.name ? 7 : F(l) ? q(l) : e.isDeclarationName(l) ? w(A) : e.isEntityName(l) && e.findAncestor(l, e.or(e.isJSDocNameReference, e.isJSDocLinkLike, e.isJSDocMemberName)) ? 7 : J(l) ? 2 : fe(l) ? 4 : e.isTypeParameterDeclaration(A) ? (e.Debug.assert(e.isJSDocTemplateTag(A.parent)), 2) : e.isLiteralTypeNode(A) ? 3 : 1;
            }
            e.getMeaningFromLocation = s;
            function q(l) {
              var A = l.kind === 163 ? l : e.isQualifiedName(l.parent) && l.parent.right === l ? l.parent : void 0;
              return A && A.parent.kind === 268 ? 7 : 4;
            }
            function F(l) {
              for (; l.parent.kind === 163; )
                l = l.parent;
              return e.isInternalModuleImportEqualsDeclaration(l.parent) && l.parent.moduleReference === l;
            }
            e.isInRightSideOfInternalImportEqualsDeclaration = F;
            function fe(l) {
              return Ee(l) || Se(l);
            }
            function Ee(l) {
              var A = l, M = true;
              if (A.parent.kind === 163) {
                for (; A.parent && A.parent.kind === 163; )
                  A = A.parent;
                M = A.right === l;
              }
              return A.parent.kind === 180 && !M;
            }
            function Se(l) {
              var A = l, M = true;
              if (A.parent.kind === 208) {
                for (; A.parent && A.parent.kind === 208; )
                  A = A.parent;
                M = A.name === l;
              }
              if (!M && A.parent.kind === 230 && A.parent.parent.kind === 294) {
                var ke = A.parent.parent.parent;
                return ke.kind === 260 && A.parent.parent.token === 117 || ke.kind === 261 && A.parent.parent.token === 94;
              }
              return false;
            }
            function J(l) {
              switch (e.isRightSideOfQualifiedNameOrPropertyAccess(l) && (l = l.parent), l.kind) {
                case 108:
                  return !e.isExpressionNode(l);
                case 194:
                  return true;
              }
              switch (l.parent.kind) {
                case 180:
                  return true;
                case 202:
                  return !l.parent.isTypeOf;
                case 230:
                  return e.isPartOfTypeNode(l.parent);
              }
              return false;
            }
            function se(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isCallExpression, B, A, M);
            }
            e.isCallExpressionTarget = se;
            function Me(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isNewExpression, B, A, M);
            }
            e.isNewExpressionTarget = Me;
            function Q(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isCallOrNewExpression, B, A, M);
            }
            e.isCallOrNewExpressionTarget = Q;
            function Be(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isTaggedTemplateExpression, U, A, M);
            }
            e.isTaggedTemplateTag = Be;
            function je(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isDecorator, B, A, M);
            }
            e.isDecoratorTarget = je;
            function V(l, A, M) {
              return A === void 0 && (A = false), M === void 0 && (M = false), v(l, e.isJsxOpeningLikeElement, m, A, M);
            }
            e.isJsxOpeningLikeElementTagName = V;
            function B(l) {
              return l.expression;
            }
            function U(l) {
              return l.tag;
            }
            function m(l) {
              return l.tagName;
            }
            function v(l, A, M, ke, cr) {
              var Zr = ke ? O(l) : g(l);
              return cr && (Zr = e.skipOuterExpressions(Zr)), !!Zr && !!Zr.parent && A(Zr.parent) && M(Zr.parent) === Zr;
            }
            function g(l) {
              return pe(l) ? l.parent : l;
            }
            e.climbPastPropertyAccess = g;
            function O(l) {
              return pe(l) || j(l) ? l.parent : l;
            }
            e.climbPastPropertyOrElementAccess = O;
            function S(l, A) {
              for (; l; ) {
                if (l.kind === 253 && l.label.escapedText === A)
                  return l.label;
                l = l.parent;
              }
            }
            e.getTargetLabel = S;
            function te(l, A) {
              return e.isPropertyAccessExpression(l.expression) ? l.expression.name.text === A : false;
            }
            e.hasPropertyAccessExpressionWithName = te;
            function Je(l) {
              var A;
              return e.isIdentifier(l) && ((A = e.tryCast(l.parent, e.isBreakOrContinueStatement)) === null || A === void 0 ? void 0 : A.label) === l;
            }
            e.isJumpStatementTarget = Je;
            function qe(l) {
              var A;
              return e.isIdentifier(l) && ((A = e.tryCast(l.parent, e.isLabeledStatement)) === null || A === void 0 ? void 0 : A.label) === l;
            }
            e.isLabelOfLabeledStatement = qe;
            function ge(l) {
              return qe(l) || Je(l);
            }
            e.isLabelName = ge;
            function ie(l) {
              var A;
              return ((A = e.tryCast(l.parent, e.isJSDocTag)) === null || A === void 0 ? void 0 : A.tagName) === l;
            }
            e.isTagName = ie;
            function H(l) {
              var A;
              return ((A = e.tryCast(l.parent, e.isQualifiedName)) === null || A === void 0 ? void 0 : A.right) === l;
            }
            e.isRightSideOfQualifiedName = H;
            function pe(l) {
              var A;
              return ((A = e.tryCast(l.parent, e.isPropertyAccessExpression)) === null || A === void 0 ? void 0 : A.name) === l;
            }
            e.isRightSideOfPropertyAccess = pe;
            function j(l) {
              var A;
              return ((A = e.tryCast(l.parent, e.isElementAccessExpression)) === null || A === void 0 ? void 0 : A.argumentExpression) === l;
            }
            e.isArgumentExpressionOfElementAccess = j;
            function be(l) {
              var A;
              return ((A = e.tryCast(l.parent, e.isModuleDeclaration)) === null || A === void 0 ? void 0 : A.name) === l;
            }
            e.isNameOfModuleDeclaration = be;
            function Xe(l) {
              var A;
              return e.isIdentifier(l) && ((A = e.tryCast(l.parent, e.isFunctionLike)) === null || A === void 0 ? void 0 : A.name) === l;
            }
            e.isNameOfFunctionDeclaration = Xe;
            function Re(l) {
              switch (l.parent.kind) {
                case 169:
                case 168:
                case 299:
                case 302:
                case 171:
                case 170:
                case 174:
                case 175:
                case 264:
                  return e.getNameOfDeclaration(l.parent) === l;
                case 209:
                  return l.parent.argumentExpression === l;
                case 164:
                  return true;
                case 198:
                  return l.parent.parent.kind === 196;
                default:
                  return false;
              }
            }
            e.isLiteralNameOfPropertyDeclarationOrIndexAccess = Re;
            function Fe(l) {
              return e.isExternalModuleImportEqualsDeclaration(l.parent.parent) && e.getExternalModuleImportEqualsDeclarationExpression(l.parent.parent) === l;
            }
            e.isExpressionOfExternalModuleImportEqualsDeclaration = Fe;
            function dr(l) {
              for (e.isJSDocTypeAlias(l) && (l = l.parent.parent); ; ) {
                if (l = l.parent, !l)
                  return;
                switch (l.kind) {
                  case 308:
                  case 171:
                  case 170:
                  case 259:
                  case 215:
                  case 174:
                  case 175:
                  case 260:
                  case 261:
                  case 263:
                  case 264:
                    return l;
                }
              }
            }
            e.getContainerNode = dr;
            function ze(l) {
              switch (l.kind) {
                case 308:
                  return e.isExternalModule(l) ? "module" : "script";
                case 264:
                  return "module";
                case 260:
                case 228:
                  return "class";
                case 261:
                  return "interface";
                case 262:
                case 341:
                case 348:
                  return "type";
                case 263:
                  return "enum";
                case 257:
                  return _t(l);
                case 205:
                  return _t(e.getRootDeclaration(l));
                case 216:
                case 259:
                case 215:
                  return "function";
                case 174:
                  return "getter";
                case 175:
                  return "setter";
                case 171:
                case 170:
                  return "method";
                case 299:
                  var A = l.initializer;
                  return e.isFunctionLike(A) ? "method" : "property";
                case 169:
                case 168:
                case 300:
                case 301:
                  return "property";
                case 178:
                  return "index";
                case 177:
                  return "construct";
                case 176:
                  return "call";
                case 173:
                case 172:
                  return "constructor";
                case 165:
                  return "type parameter";
                case 302:
                  return "enum member";
                case 166:
                  return e.hasSyntacticModifier(l, 16476) ? "property" : "parameter";
                case 268:
                case 273:
                case 278:
                case 271:
                case 277:
                  return "alias";
                case 223:
                  var M = e.getAssignmentDeclarationKind(l), ke = l.right;
                  switch (M) {
                    case 7:
                    case 8:
                    case 9:
                    case 0:
                      return "";
                    case 1:
                    case 2:
                      var cr = ze(ke);
                      return cr === "" ? "const" : cr;
                    case 3:
                      return e.isFunctionExpression(ke) ? "method" : "property";
                    case 4:
                      return "property";
                    case 5:
                      return e.isFunctionExpression(ke) ? "method" : "property";
                    case 6:
                      return "local class";
                    default:
                      return e.assertType(M), "";
                  }
                case 79:
                  return e.isImportClause(l.parent) ? "alias" : "";
                case 274:
                  var Zr = ze(l.expression);
                  return Zr === "" ? "const" : Zr;
                default:
                  return "";
              }
              function _t(Rt) {
                return e.isVarConst(Rt) ? "const" : e.isLet(Rt) ? "let" : "var";
              }
            }
            e.getNodeKind = ze;
            function ve(l) {
              switch (l.kind) {
                case 108:
                  return true;
                case 79:
                  return e.identifierIsThisKeyword(l) && l.parent.kind === 166;
                default:
                  return false;
              }
            }
            e.isThis = ve;
            var er = /^\/\/\/\s*</;
            function ar(l, A) {
              var M = e.getLineStarts(A), ke = A.getLineAndCharacterOfPosition(l).line;
              return M[ke];
            }
            e.getLineStartPositionForPosition = ar;
            function Cr(l, A) {
              return X(l.pos, l.end, A);
            }
            e.rangeContainsRange = Cr;
            function Ce(l, A) {
              return gr(l, A.pos) && gr(l, A.end);
            }
            e.rangeContainsRangeExclusive = Ce;
            function $e(l, A) {
              return l.pos <= A && A <= l.end;
            }
            e.rangeContainsPosition = $e;
            function gr(l, A) {
              return l.pos < A && A < l.end;
            }
            e.rangeContainsPositionExclusive = gr;
            function X(l, A, M) {
              return l <= M.pos && A >= M.end;
            }
            e.startEndContainsRange = X;
            function Te(l, A, M) {
              return l.pos <= A && l.end >= M;
            }
            e.rangeContainsStartEnd = Te;
            function we(l, A, M) {
              return yr(l.pos, l.end, A, M);
            }
            e.rangeOverlapsWithStartEnd = we;
            function he(l, A, M, ke) {
              return yr(l.getStart(A), l.end, M, ke);
            }
            e.nodeOverlapsWithStartEnd = he;
            function yr(l, A, M, ke) {
              var cr = Math.max(l, M), Zr = Math.min(A, ke);
              return cr < Zr;
            }
            e.startEndOverlapsWithStartEnd = yr;
            function kr(l, A, M) {
              return e.Debug.assert(l.pos <= A), A < l.end || !nr(l, M);
            }
            e.positionBelongsToNode = kr;
            function nr(l, A) {
              if (l === void 0 || e.nodeIsMissing(l))
                return false;
              switch (l.kind) {
                case 260:
                case 261:
                case 263:
                case 207:
                case 203:
                case 184:
                case 238:
                case 265:
                case 266:
                case 272:
                case 276:
                  return tr(l, 19, A);
                case 295:
                  return nr(l.block, A);
                case 211:
                  if (!l.arguments)
                    return true;
                case 210:
                case 214:
                case 193:
                  return tr(l, 21, A);
                case 181:
                case 182:
                  return nr(l.type, A);
                case 173:
                case 174:
                case 175:
                case 259:
                case 215:
                case 171:
                case 170:
                case 177:
                case 176:
                case 216:
                  return l.body ? nr(l.body, A) : l.type ? nr(l.type, A) : zr(l, 21, A);
                case 264:
                  return !!l.body && nr(l.body, A);
                case 242:
                  return l.elseStatement ? nr(l.elseStatement, A) : nr(l.thenStatement, A);
                case 241:
                  return nr(l.expression, A) || zr(l, 26, A);
                case 206:
                case 204:
                case 209:
                case 164:
                case 186:
                  return tr(l, 23, A);
                case 178:
                  return l.type ? nr(l.type, A) : zr(l, 23, A);
                case 292:
                case 293:
                  return false;
                case 245:
                case 246:
                case 247:
                case 244:
                  return nr(l.statement, A);
                case 243:
                  return zr(l, 115, A) ? tr(l, 21, A) : nr(l.statement, A);
                case 183:
                  return nr(l.exprName, A);
                case 218:
                case 217:
                case 219:
                case 226:
                case 227:
                  var M = l;
                  return nr(M.expression, A);
                case 212:
                  return nr(l.template, A);
                case 225:
                  var ke = e.lastOrUndefined(l.templateSpans);
                  return nr(ke, A);
                case 236:
                  return e.nodeIsPresent(l.literal);
                case 275:
                case 269:
                  return e.nodeIsPresent(l.moduleSpecifier);
                case 221:
                  return nr(l.operand, A);
                case 223:
                  return nr(l.right, A);
                case 224:
                  return nr(l.whenFalse, A);
                default:
                  return true;
              }
            }
            function tr(l, A, M) {
              var ke = l.getChildren(M);
              if (ke.length) {
                var cr = e.last(ke);
                if (cr.kind === A)
                  return true;
                if (cr.kind === 26 && ke.length !== 1)
                  return ke[ke.length - 2].kind === A;
              }
              return false;
            }
            function Lr(l) {
              var A = ir(l);
              if (A) {
                var M = A.getChildren(), ke = e.indexOfNode(M, l);
                return { listItemIndex: ke, list: A };
              }
            }
            e.findListItemInfo = Lr;
            function zr(l, A, M) {
              return !!ye(l, A, M);
            }
            e.hasChildOfKind = zr;
            function ye(l, A, M) {
              return e.find(l.getChildren(M), function(ke) {
                return ke.kind === A;
              });
            }
            e.findChildOfKind = ye;
            function ir(l) {
              var A = e.find(l.parent.getChildren(), function(M) {
                return e.isSyntaxList(M) && Cr(M, l);
              });
              return e.Debug.assert(!A || e.contains(A.getChildren(), l)), A;
            }
            e.findContainingList = ir;
            function Dr(l) {
              return l.kind === 88;
            }
            function Pr(l) {
              return l.kind === 84;
            }
            function Br(l) {
              return l.kind === 98;
            }
            function ut(l) {
              if (e.isNamedDeclaration(l))
                return l.name;
              if (e.isClassDeclaration(l)) {
                var A = l.modifiers && e.find(l.modifiers, Dr);
                if (A)
                  return A;
              }
              if (e.isClassExpression(l)) {
                var M = e.find(l.getChildren(), Pr);
                if (M)
                  return M;
              }
            }
            function rt(l) {
              if (e.isNamedDeclaration(l))
                return l.name;
              if (e.isFunctionDeclaration(l)) {
                var A = e.find(l.modifiers, Dr);
                if (A)
                  return A;
              }
              if (e.isFunctionExpression(l)) {
                var M = e.find(l.getChildren(), Br);
                if (M)
                  return M;
              }
            }
            function Z(l) {
              var A;
              return e.findAncestor(l, function(M) {
                return e.isTypeNode(M) && (A = M), !e.isQualifiedName(M.parent) && !e.isTypeNode(M.parent) && !e.isTypeElement(M.parent);
              }), A;
            }
            function f(l, A) {
              if (!(l.flags & 8388608)) {
                var M = or(l, A);
                if (M)
                  return M;
                var ke = Z(l);
                return ke && A.getTypeAtLocation(ke);
              }
            }
            e.getContextualTypeFromParentOrAncestorTypeNode = f;
            function h(l, A) {
              if (!A)
                switch (l.kind) {
                  case 260:
                  case 228:
                    return ut(l);
                  case 259:
                  case 215:
                    return rt(l);
                  case 173:
                    return l;
                }
              if (e.isNamedDeclaration(l))
                return l.name;
            }
            function oe(l, A) {
              if (l.importClause) {
                if (l.importClause.name && l.importClause.namedBindings)
                  return;
                if (l.importClause.name)
                  return l.importClause.name;
                if (l.importClause.namedBindings) {
                  if (e.isNamedImports(l.importClause.namedBindings)) {
                    var M = e.singleOrUndefined(l.importClause.namedBindings.elements);
                    return M ? M.name : void 0;
                  } else if (e.isNamespaceImport(l.importClause.namedBindings))
                    return l.importClause.namedBindings.name;
                }
              }
              if (!A)
                return l.moduleSpecifier;
            }
            function xr(l, A) {
              if (l.exportClause) {
                if (e.isNamedExports(l.exportClause)) {
                  var M = e.singleOrUndefined(l.exportClause.elements);
                  return M ? l.exportClause.elements[0].name : void 0;
                } else if (e.isNamespaceExport(l.exportClause))
                  return l.exportClause.name;
              }
              if (!A)
                return l.moduleSpecifier;
            }
            function jr(l) {
              if (l.types.length === 1)
                return l.types[0].expression;
            }
            function qr(l, A) {
              var M = l.parent;
              if (e.isModifier(l) && (A || l.kind !== 88) ? e.canHaveModifiers(M) && e.contains(M.modifiers, l) : l.kind === 84 ? e.isClassDeclaration(M) || e.isClassExpression(l) : l.kind === 98 ? e.isFunctionDeclaration(M) || e.isFunctionExpression(l) : l.kind === 118 ? e.isInterfaceDeclaration(M) : l.kind === 92 ? e.isEnumDeclaration(M) : l.kind === 154 ? e.isTypeAliasDeclaration(M) : l.kind === 143 || l.kind === 142 ? e.isModuleDeclaration(M) : l.kind === 100 ? e.isImportEqualsDeclaration(M) : l.kind === 137 ? e.isGetAccessorDeclaration(M) : l.kind === 151 && e.isSetAccessorDeclaration(M)) {
                var ke = h(M, A);
                if (ke)
                  return ke;
              }
              if ((l.kind === 113 || l.kind === 85 || l.kind === 119) && e.isVariableDeclarationList(M) && M.declarations.length === 1) {
                var cr = M.declarations[0];
                if (e.isIdentifier(cr.name))
                  return cr.name;
              }
              if (l.kind === 154) {
                if (e.isImportClause(M) && M.isTypeOnly) {
                  var ke = oe(M.parent, A);
                  if (ke)
                    return ke;
                }
                if (e.isExportDeclaration(M) && M.isTypeOnly) {
                  var ke = xr(M, A);
                  if (ke)
                    return ke;
                }
              }
              if (l.kind === 128) {
                if (e.isImportSpecifier(M) && M.propertyName || e.isExportSpecifier(M) && M.propertyName || e.isNamespaceImport(M) || e.isNamespaceExport(M))
                  return M.name;
                if (e.isExportDeclaration(M) && M.exportClause && e.isNamespaceExport(M.exportClause))
                  return M.exportClause.name;
              }
              if (l.kind === 100 && e.isImportDeclaration(M)) {
                var ke = oe(M, A);
                if (ke)
                  return ke;
              }
              if (l.kind === 93) {
                if (e.isExportDeclaration(M)) {
                  var ke = xr(M, A);
                  if (ke)
                    return ke;
                }
                if (e.isExportAssignment(M))
                  return e.skipOuterExpressions(M.expression);
              }
              if (l.kind === 147 && e.isExternalModuleReference(M))
                return M.expression;
              if (l.kind === 158 && (e.isImportDeclaration(M) || e.isExportDeclaration(M)) && M.moduleSpecifier)
                return M.moduleSpecifier;
              if ((l.kind === 94 || l.kind === 117) && e.isHeritageClause(M) && M.token === l.kind) {
                var ke = jr(M);
                if (ke)
                  return ke;
              }
              if (l.kind === 94) {
                if (e.isTypeParameterDeclaration(M) && M.constraint && e.isTypeReferenceNode(M.constraint))
                  return M.constraint.typeName;
                if (e.isConditionalTypeNode(M) && e.isTypeReferenceNode(M.extendsType))
                  return M.extendsType.typeName;
              }
              if (l.kind === 138 && e.isInferTypeNode(M))
                return M.typeParameter.name;
              if (l.kind === 101 && e.isTypeParameterDeclaration(M) && e.isMappedTypeNode(M.parent))
                return M.name;
              if (l.kind === 141 && e.isTypeOperatorNode(M) && M.operator === 141 && e.isTypeReferenceNode(M.type))
                return M.type.typeName;
              if (l.kind === 146 && e.isTypeOperatorNode(M) && M.operator === 146 && e.isArrayTypeNode(M.type) && e.isTypeReferenceNode(M.type.elementType))
                return M.type.elementType.typeName;
              if (!A) {
                if ((l.kind === 103 && e.isNewExpression(M) || l.kind === 114 && e.isVoidExpression(M) || l.kind === 112 && e.isTypeOfExpression(M) || l.kind === 133 && e.isAwaitExpression(M) || l.kind === 125 && e.isYieldExpression(M) || l.kind === 89 && e.isDeleteExpression(M)) && M.expression)
                  return e.skipOuterExpressions(M.expression);
                if ((l.kind === 101 || l.kind === 102) && e.isBinaryExpression(M) && M.operatorToken === l)
                  return e.skipOuterExpressions(M.right);
                if (l.kind === 128 && e.isAsExpression(M) && e.isTypeReferenceNode(M.type))
                  return M.type.typeName;
                if (l.kind === 101 && e.isForInStatement(M) || l.kind === 162 && e.isForOfStatement(M))
                  return e.skipOuterExpressions(M.expression);
              }
              return l;
            }
            function pt(l) {
              return qr(l, false);
            }
            e.getAdjustedReferenceLocation = pt;
            function Ge(l) {
              return qr(l, true);
            }
            e.getAdjustedRenameLocation = Ge;
            function K(l, A) {
              return r(l, A, function(M) {
                return e.isPropertyNameLiteral(M) || e.isKeyword(M.kind) || e.isPrivateIdentifier(M);
              });
            }
            e.getTouchingPropertyName = K;
            function r(l, A, M) {
              return ft(l, A, false, M, false);
            }
            e.getTouchingToken = r;
            function ct(l, A) {
              return ft(l, A, true, void 0, false);
            }
            e.getTokenAtPosition = ct;
            function ft(l, A, M, ke, cr) {
              var Zr = l, _t, Rt = function() {
                var _n = Zr.getChildren(l), Nt = e.binarySearchKey(_n, A, function(Ft, Sn) {
                  return Sn;
                }, function(Ft, Sn) {
                  var wn = _n[Ft].getEnd();
                  if (wn < A)
                    return -1;
                  var Wn = M ? _n[Ft].getFullStart() : _n[Ft].getStart(l, true);
                  return Wn > A ? 1 : bn(_n[Ft], Wn, wn) ? _n[Ft - 1] && bn(_n[Ft - 1]) ? 1 : 0 : ke && Wn === A && _n[Ft - 1] && _n[Ft - 1].getEnd() === A && bn(_n[Ft - 1]) ? 1 : -1;
                });
                return _t ? { value: _t } : Nt >= 0 && _n[Nt] ? (Zr = _n[Nt], "continue-outer") : { value: Zr };
              };
              e:
                for (; ; ) {
                  var un = Rt();
                  if (typeof un == "object")
                    return un.value;
                  switch (un) {
                    case "continue-outer":
                      continue e;
                  }
                }
              function bn(_n, Nt, Ft) {
                if (Ft != null || (Ft = _n.getEnd()), Ft < A || (Nt != null || (Nt = M ? _n.getFullStart() : _n.getStart(l, true)), Nt > A))
                  return false;
                if (A < Ft || A === Ft && (_n.kind === 1 || cr))
                  return true;
                if (ke && Ft === A) {
                  var Sn = Ye(A, l, _n);
                  if (Sn && ke(Sn))
                    return _t = Sn, true;
                }
                return false;
              }
            }
            function Ie(l, A) {
              for (var M = ct(l, A); At(M); ) {
                var ke = xe(M, M.parent, l);
                if (!ke)
                  return;
                M = ke;
              }
              return M;
            }
            e.findFirstNonJsxWhitespaceToken = Ie;
            function me(l, A) {
              var M = ct(l, A);
              return e.isToken(M) && A > M.getStart(l) && A < M.getEnd() ? M : Ye(A, l);
            }
            e.findTokenOnLeftOfPosition = me;
            function xe(l, A, M) {
              return ke(A);
              function ke(cr) {
                return e.isToken(cr) && cr.pos === l.end ? cr : e.firstDefined(cr.getChildren(M), function(Zr) {
                  var _t = Zr.pos <= l.pos && Zr.end > l.end || Zr.pos === l.end;
                  return _t && mt(Zr, M) ? ke(Zr) : void 0;
                });
              }
            }
            e.findNextToken = xe;
            function Ye(l, A, M, ke) {
              var cr = Zr(M || A);
              return e.Debug.assert(!(cr && At(cr))), cr;
              function Zr(_t) {
                if (vr(_t) && _t.kind !== 1)
                  return _t;
                var Rt = _t.getChildren(A), un = e.binarySearchKey(Rt, l, function(wn, Wn) {
                  return Wn;
                }, function(wn, Wn) {
                  return l < Rt[wn].end ? !Rt[wn - 1] || l >= Rt[wn - 1].end ? 0 : 1 : -1;
                });
                if (un >= 0 && Rt[un]) {
                  var bn = Rt[un];
                  if (l < bn.end) {
                    var _n = bn.getStart(A, !ke), Nt = _n >= l || !mt(bn, A) || At(bn);
                    if (Nt) {
                      var Ft = pr(Rt, un, A, _t.kind);
                      return Ft && nt(Ft, A);
                    } else
                      return Zr(bn);
                  }
                }
                e.Debug.assert(M !== void 0 || _t.kind === 308 || _t.kind === 1 || e.isJSDocCommentContainingNode(_t));
                var Sn = pr(Rt, Rt.length, A, _t.kind);
                return Sn && nt(Sn, A);
              }
            }
            e.findPrecedingToken = Ye;
            function vr(l) {
              return e.isToken(l) && !At(l);
            }
            function nt(l, A) {
              if (vr(l))
                return l;
              var M = l.getChildren(A);
              if (M.length === 0)
                return l;
              var ke = pr(M, M.length, A, l.kind);
              return ke && nt(ke, A);
            }
            function pr(l, A, M, ke) {
              for (var cr = A - 1; cr >= 0; cr--) {
                var Zr = l[cr];
                if (At(Zr))
                  cr === 0 && (ke === 11 || ke === 282) && e.Debug.fail("`JsxText` tokens should not be the first child of `JsxElement | JsxSelfClosingElement`");
                else if (mt(l[cr], M))
                  return l[cr];
              }
            }
            function Mr(l, A, M) {
              if (M === void 0 && (M = Ye(A, l)), M && e.isStringTextContainingNode(M)) {
                var ke = M.getStart(l), cr = M.getEnd();
                if (ke < A && A < cr)
                  return true;
                if (A === cr)
                  return !!M.isUnterminated;
              }
              return false;
            }
            e.isInString = Mr;
            function ot(l, A) {
              var M = ct(l, A);
              return M ? !!(M.kind === 11 || M.kind === 29 && M.parent.kind === 11 || M.kind === 29 && M.parent.kind === 291 || M && M.kind === 19 && M.parent.kind === 291 || M.kind === 29 && M.parent.kind === 284) : false;
            }
            e.isInsideJsxElementOrAttribute = ot;
            function At(l) {
              return e.isJsxText(l) && l.containsOnlyTriviaWhiteSpaces;
            }
            function re(l, A) {
              var M = ct(l, A);
              return e.isTemplateLiteralKind(M.kind) && A > M.getStart(l);
            }
            e.isInTemplateString = re;
            function de(l, A) {
              var M = ct(l, A);
              return !!(e.isJsxText(M) || M.kind === 18 && e.isJsxExpression(M.parent) && e.isJsxElement(M.parent.parent) || M.kind === 29 && e.isJsxOpeningLikeElement(M.parent) && e.isJsxElement(M.parent.parent));
            }
            e.isInJSXText = de;
            function He(l, A) {
              function M(ke) {
                for (; ke; )
                  if (ke.kind >= 282 && ke.kind <= 291 || ke.kind === 11 || ke.kind === 29 || ke.kind === 31 || ke.kind === 79 || ke.kind === 19 || ke.kind === 18 || ke.kind === 43)
                    ke = ke.parent;
                  else if (ke.kind === 281) {
                    if (A > ke.getStart(l))
                      return true;
                    ke = ke.parent;
                  } else
                    return false;
                return false;
              }
              return M(ct(l, A));
            }
            e.isInsideJsxElement = He;
            function Nr(l, A, M) {
              var ke = e.tokenToString(l.kind), cr = e.tokenToString(A), Zr = l.getFullStart(), _t = M.text.lastIndexOf(cr, Zr);
              if (_t !== -1) {
                if (M.text.lastIndexOf(ke, Zr - 1) < _t) {
                  var Rt = Ye(_t + 1, M);
                  if (Rt && Rt.kind === A)
                    return Rt;
                }
                for (var un = l.kind, bn = 0; ; ) {
                  var _n = Ye(l.getFullStart(), M);
                  if (!_n)
                    return;
                  if (l = _n, l.kind === A) {
                    if (bn === 0)
                      return l;
                    bn--;
                  } else
                    l.kind === un && bn++;
                }
              }
            }
            e.findPrecedingMatchingToken = Nr;
            function Yr(l, A, M) {
              return A ? l.getNonNullableType() : M ? l.getNonOptionalType() : l;
            }
            e.removeOptionality = Yr;
            function Ct(l, A, M) {
              var ke = Lt(l, A);
              return ke !== void 0 && (e.isPartOfTypeNode(ke.called) || xt(ke.called, ke.nTypeArguments, M).length !== 0 || Ct(ke.called, A, M));
            }
            e.isPossiblyTypeArgumentPosition = Ct;
            function xt(l, A, M) {
              var ke = M.getTypeAtLocation(l);
              e.isOptionalChain(l.parent) && (ke = Yr(ke, e.isOptionalChainRoot(l.parent), true));
              var cr = e.isNewExpression(l.parent) ? ke.getConstructSignatures() : ke.getCallSignatures();
              return cr.filter(function(Zr) {
                return !!Zr.typeParameters && Zr.typeParameters.length >= A;
              });
            }
            e.getPossibleGenericSignatures = xt;
            function Lt(l, A) {
              if (A.text.lastIndexOf("<", l ? l.pos : A.text.length) !== -1)
                for (var M = l, ke = 0, cr = 0; M; ) {
                  switch (M.kind) {
                    case 29:
                      if (M = Ye(M.getFullStart(), A), M && M.kind === 28 && (M = Ye(M.getFullStart(), A)), !M || !e.isIdentifier(M))
                        return;
                      if (!ke)
                        return e.isDeclarationName(M) ? void 0 : { called: M, nTypeArguments: cr };
                      ke--;
                      break;
                    case 49:
                      ke = 3;
                      break;
                    case 48:
                      ke = 2;
                      break;
                    case 31:
                      ke++;
                      break;
                    case 19:
                      if (M = Nr(M, 18, A), !M)
                        return;
                      break;
                    case 21:
                      if (M = Nr(M, 20, A), !M)
                        return;
                      break;
                    case 23:
                      if (M = Nr(M, 22, A), !M)
                        return;
                      break;
                    case 27:
                      cr++;
                      break;
                    case 38:
                    case 79:
                    case 10:
                    case 8:
                    case 9:
                    case 110:
                    case 95:
                    case 112:
                    case 94:
                    case 141:
                    case 24:
                    case 51:
                    case 57:
                    case 58:
                      break;
                    default:
                      if (e.isTypeNode(M))
                        break;
                      return;
                  }
                  M = Ye(M.getFullStart(), A);
                }
            }
            e.getPossibleTypeArgumentsInfo = Lt;
            function zt(l, A, M) {
              return e.formatting.getRangeOfEnclosingComment(l, A, void 0, M);
            }
            e.isInComment = zt;
            function Zt(l, A) {
              var M = ct(l, A);
              return !!e.findAncestor(M, e.isJSDoc);
            }
            e.hasDocComment = Zt;
            function mt(l, A) {
              return l.kind === 1 ? !!l.jsDoc : l.getWidth(A) !== 0;
            }
            function at(l, A) {
              A === void 0 && (A = 0);
              var M = [], ke = e.isDeclaration(l) ? e.getCombinedNodeFlagsAlwaysIncludeJSDoc(l) & ~A : 0;
              return ke & 8 && M.push("private"), ke & 16 && M.push("protected"), ke & 4 && M.push("public"), (ke & 32 || e.isClassStaticBlockDeclaration(l)) && M.push("static"), ke & 256 && M.push("abstract"), ke & 1 && M.push("export"), ke & 8192 && M.push("deprecated"), l.flags & 16777216 && M.push("declare"), l.kind === 274 && M.push("export"), M.length > 0 ? M.join(",") : "";
            }
            e.getNodeModifiers = at;
            function k(l) {
              if (l.kind === 180 || l.kind === 210)
                return l.typeArguments;
              if (e.isFunctionLike(l) || l.kind === 260 || l.kind === 261)
                return l.typeParameters;
            }
            e.getTypeArgumentOrTypeParameterList = k;
            function ue(l) {
              return l === 2 || l === 3;
            }
            e.isComment = ue;
            function Qe(l) {
              return !!(l === 10 || l === 13 || e.isTemplateLiteralKind(l));
            }
            e.isStringOrRegularExpressionOrTemplateLiteral = Qe;
            function Sr(l) {
              return 18 <= l && l <= 78;
            }
            e.isPunctuation = Sr;
            function Kr(l, A, M) {
              return e.isTemplateLiteralKind(l.kind) && l.getStart(M) < A && A < l.end || !!l.isUnterminated && A === l.end;
            }
            e.isInsideTemplateLiteral = Kr;
            function Hr(l) {
              switch (l) {
                case 123:
                case 121:
                case 122:
                  return true;
              }
              return false;
            }
            e.isAccessibilityModifier = Hr;
            function Dt(l) {
              var A = e.clone(l);
              return e.setConfigFileInOptions(A, l && l.configFile), A;
            }
            e.cloneCompilerOptions = Dt;
            function Xt(l) {
              return !!((l.kind === 206 || l.kind === 207) && (l.parent.kind === 223 && l.parent.left === l && l.parent.operatorToken.kind === 63 || l.parent.kind === 247 && l.parent.initializer === l || Xt(l.parent.kind === 299 ? l.parent.parent : l.parent)));
            }
            e.isArrayLiteralOrObjectLiteralDestructuringPattern = Xt;
            function cn(l, A) {
              return yn(l, A, true);
            }
            e.isInReferenceComment = cn;
            function In(l, A) {
              return yn(l, A, false);
            }
            e.isInNonReferenceComment = In;
            function yn(l, A, M) {
              var ke = zt(l, A, void 0);
              return !!ke && M === er.test(l.text.substring(ke.pos, ke.end));
            }
            function hn(l) {
              if (l)
                switch (l.kind) {
                  case 10:
                  case 14:
                    return En(l);
                  default:
                    return ln(l);
                }
            }
            e.getReplacementSpanForContextToken = hn;
            function ln(l, A, M) {
              return e.createTextSpanFromBounds(l.getStart(A), (M || l).getEnd());
            }
            e.createTextSpanFromNode = ln;
            function En(l) {
              if (!l.isUnterminated)
                return e.createTextSpanFromBounds(l.getStart() + 1, l.getEnd() - 1);
            }
            e.createTextSpanFromStringLiteralLikeContent = En;
            function Vt(l, A) {
              return e.createRange(l.getStart(A), l.end);
            }
            e.createTextRangeFromNode = Vt;
            function ui(l) {
              return e.createTextSpanFromBounds(l.pos, l.end);
            }
            e.createTextSpanFromRange = ui;
            function ei(l) {
              return e.createRange(l.start, l.start + l.length);
            }
            e.createTextRangeFromSpan = ei;
            function hi(l, A, M) {
              return ri(e.createTextSpan(l, A), M);
            }
            e.createTextChangeFromStartLength = hi;
            function ri(l, A) {
              return { span: l, newText: A };
            }
            e.createTextChange = ri, e.typeKeywords = [131, 129, 160, 134, 95, 138, 141, 144, 104, 148, 149, 146, 152, 153, 110, 114, 155, 156, 157];
            function vi(l) {
              return e.contains(e.typeKeywords, l);
            }
            e.isTypeKeyword = vi;
            function Qn(l) {
              return l.kind === 154;
            }
            e.isTypeKeywordToken = Qn;
            function Yn(l) {
              return Qn(l) || e.isIdentifier(l) && l.text === "type";
            }
            e.isTypeKeywordTokenOrIdentifier = Yn;
            function oi(l) {
              return !!(l.flags & 1536) && l.name.charCodeAt(0) === 34;
            }
            e.isExternalModuleSymbol = oi;
            function bi() {
              var l = [];
              return function(A) {
                var M = e.getNodeId(A);
                return !l[M] && (l[M] = true);
              };
            }
            e.nodeSeenTracker = bi;
            function Dn(l) {
              return l.getText(0, l.getLength());
            }
            e.getSnapshotText = Dn;
            function Kn(l, A) {
              for (var M = "", ke = 0; ke < A; ke++)
                M += l;
              return M;
            }
            e.repeatString = Kn;
            function si(l) {
              return l.isTypeParameter() && l.getConstraint() || l;
            }
            e.skipConstraint = si;
            function di(l) {
              return l.kind === 164 ? e.isStringOrNumericLiteralLike(l.expression) ? l.expression.text : void 0 : e.isPrivateIdentifier(l) ? e.idText(l) : e.getTextOfIdentifierOrLiteral(l);
            }
            e.getNameFromPropertyName = di;
            function Zn(l) {
              return l.getSourceFiles().some(function(A) {
                return !A.isDeclarationFile && !l.isSourceFileFromExternalLibrary(A) && !!(A.externalModuleIndicator || A.commonJsModuleIndicator);
              });
            }
            e.programContainsModules = Zn;
            function Fn(l) {
              return l.getSourceFiles().some(function(A) {
                return !A.isDeclarationFile && !l.isSourceFileFromExternalLibrary(A) && !!A.externalModuleIndicator;
              });
            }
            e.programContainsEsModules = Fn;
            function gt(l) {
              return !!l.module || e.getEmitScriptTarget(l) >= 2 || !!l.noEmit;
            }
            e.compilerOptionsIndicateEsModules = gt;
            function mi(l, A) {
              return { fileExists: function(M) {
                return l.fileExists(M);
              }, getCurrentDirectory: function() {
                return A.getCurrentDirectory();
              }, readFile: e.maybeBind(A, A.readFile), useCaseSensitiveFileNames: e.maybeBind(A, A.useCaseSensitiveFileNames), getSymlinkCache: e.maybeBind(A, A.getSymlinkCache) || l.getSymlinkCache, getModuleSpecifierCache: e.maybeBind(A, A.getModuleSpecifierCache), getPackageJsonInfoCache: function() {
                var M;
                return (M = l.getModuleResolutionCache()) === null || M === void 0 ? void 0 : M.getPackageJsonInfoCache();
              }, getGlobalTypingsCacheLocation: e.maybeBind(A, A.getGlobalTypingsCacheLocation), redirectTargetsMap: l.redirectTargetsMap, getProjectReferenceRedirect: function(M) {
                return l.getProjectReferenceRedirect(M);
              }, isSourceOfProjectReferenceRedirect: function(M) {
                return l.isSourceOfProjectReferenceRedirect(M);
              }, getNearestAncestorDirectoryWithPackageJson: e.maybeBind(A, A.getNearestAncestorDirectoryWithPackageJson), getFileIncludeReasons: function() {
                return l.getFileIncludeReasons();
              } };
            }
            e.createModuleSpecifierResolutionHost = mi;
            function dn(l, A) {
              return T(T({}, mi(l, A)), { getCommonSourceDirectory: function() {
                return l.getCommonSourceDirectory();
              } });
            }
            e.getModuleSpecifierResolverHost = dn;
            function On(l) {
              return l >= e.ModuleResolutionKind.Node16 && l <= e.ModuleResolutionKind.NodeNext;
            }
            e.moduleResolutionRespectsExports = On;
            function br(l) {
              return l === e.ModuleResolutionKind.NodeJs || l >= e.ModuleResolutionKind.Node16 && l <= e.ModuleResolutionKind.NodeNext;
            }
            e.moduleResolutionUsesNodeModules = br;
            function Ae(l, A, M, ke) {
              return l || A && A.length ? ur(l, A, M, ke) : void 0;
            }
            e.makeImportIfNecessary = Ae;
            function ur(l, A, M, ke, cr) {
              return e.factory.createImportDeclaration(void 0, l || A ? e.factory.createImportClause(!!cr, l, A && A.length ? e.factory.createNamedImports(A) : void 0) : void 0, typeof M == "string" ? L(M, ke) : M, void 0);
            }
            e.makeImport = ur;
            function L(l, A) {
              return e.factory.createStringLiteral(l, A === 0);
            }
            e.makeStringLiteral = L;
            var qt;
            (function(l) {
              l[l.Single = 0] = "Single", l[l.Double = 1] = "Double";
            })(qt = e.QuotePreference || (e.QuotePreference = {}));
            function nn(l, A) {
              return e.isStringDoubleQuoted(l, A) ? 1 : 0;
            }
            e.quotePreferenceFromString = nn;
            function fr(l, A) {
              if (A.quotePreference && A.quotePreference !== "auto")
                return A.quotePreference === "single" ? 0 : 1;
              var M = l.imports && e.find(l.imports, function(ke) {
                return e.isStringLiteral(ke) && !e.nodeIsSynthesized(ke.parent);
              });
              return M ? nn(M, l) : 1;
            }
            e.getQuotePreference = fr;
            function Le(l) {
              switch (l) {
                case 0:
                  return "'";
                case 1:
                  return '"';
                default:
                  return e.Debug.assertNever(l);
              }
            }
            e.getQuoteFromPreference = Le;
            function Ve(l) {
              var A = _r(l);
              return A === void 0 ? void 0 : e.unescapeLeadingUnderscores(A);
            }
            e.symbolNameNoDefault = Ve;
            function _r(l) {
              return l.escapedName !== "default" ? l.escapedName : e.firstDefined(l.declarations, function(A) {
                var M = e.getNameOfDeclaration(A);
                return M && M.kind === 79 ? M.escapedText : void 0;
              });
            }
            e.symbolEscapedNameNoDefault = _r;
            function lr(l) {
              return e.isStringLiteralLike(l) && (e.isExternalModuleReference(l.parent) || e.isImportDeclaration(l.parent) || e.isRequireCall(l.parent, false) && l.parent.arguments[0] === l || e.isImportCall(l.parent) && l.parent.arguments[0] === l);
            }
            e.isModuleSpecifierLike = lr;
            function Vr(l) {
              return e.isBindingElement(l) && e.isObjectBindingPattern(l.parent) && e.isIdentifier(l.name) && !l.propertyName;
            }
            e.isObjectBindingElementWithoutPropertyName = Vr;
            function tt(l, A) {
              var M = l.getTypeAtLocation(A.parent);
              return M && l.getPropertyOfType(M, A.name.text);
            }
            e.getPropertySymbolFromBindingElement = tt;
            function dt(l, A, M) {
              if (l)
                for (; l.parent; ) {
                  if (e.isSourceFile(l.parent) || !It(M, l.parent, A))
                    return l;
                  l = l.parent;
                }
            }
            e.getParentNodeInSpan = dt;
            function It(l, A, M) {
              return e.textSpanContainsPosition(l, A.getStart(M)) && A.getEnd() <= e.textSpanEnd(l);
            }
            function an(l, A) {
              return e.canHaveModifiers(l) ? e.find(l.modifiers, function(M) {
                return M.kind === A;
              }) : void 0;
            }
            e.findModifier = an;
            function sn(l, A, M, ke) {
              var cr = e.isArray(M) ? M[0] : M, Zr = cr.kind === 240 ? e.isRequireVariableStatement : e.isAnyImportSyntax, _t = e.filter(A.statements, Zr), Rt = e.isArray(M) ? e.stableSort(M, e.OrganizeImports.compareImportsOrRequireStatements) : [M];
              if (!_t.length)
                l.insertNodesAtTopOfFile(A, Rt, ke);
              else if (_t && e.OrganizeImports.importsAreSorted(_t))
                for (var un = 0, bn = Rt; un < bn.length; un++) {
                  var _n = bn[un], Nt = e.OrganizeImports.getImportDeclarationInsertionIndex(_t, _n);
                  if (Nt === 0) {
                    var Ft = _t[0] === A.statements[0] ? { leadingTriviaOption: e.textChanges.LeadingTriviaOption.Exclude } : {};
                    l.insertNodeBefore(A, _t[0], _n, false, Ft);
                  } else {
                    var Sn = _t[Nt - 1];
                    l.insertNodeAfter(A, Sn, _n);
                  }
                }
              else {
                var wn = e.lastOrUndefined(_t);
                wn ? l.insertNodesAfter(A, wn, Rt) : l.insertNodesAtTopOfFile(A, Rt, ke);
              }
            }
            e.insertImports = sn;
            function _e(l, A) {
              return e.Debug.assert(l.isTypeOnly), e.cast(l.getChildAt(0, A), Qn);
            }
            e.getTypeKeywordOfTypeOnlyImport = _e;
            function Gr(l, A) {
              return !!l && !!A && l.start === A.start && l.length === A.length;
            }
            e.textSpansEqual = Gr;
            function Kt(l, A) {
              return l.fileName === A.fileName && Gr(l.textSpan, A.textSpan);
            }
            e.documentSpansEqual = Kt;
            function en(l, A) {
              if (l) {
                for (var M = 0; M < l.length; M++)
                  if (l.indexOf(l[M]) === M) {
                    var ke = A(l[M], M);
                    if (ke)
                      return ke;
                  }
              }
            }
            e.forEachUnique = en;
            function Ot(l, A, M) {
              for (var ke = A; ke < M; ke++)
                if (!e.isWhiteSpaceLike(l.charCodeAt(ke)))
                  return false;
              return true;
            }
            e.isTextWhiteSpaceLike = Ot;
            function rr(l, A, M) {
              var ke = A.tryGetSourcePosition(l);
              return ke && (!M || M(e.normalizePath(ke.fileName)) ? ke : void 0);
            }
            e.getMappedLocation = rr;
            function Hn(l, A, M) {
              var ke = l.fileName, cr = l.textSpan, Zr = rr({ fileName: ke, pos: cr.start }, A, M);
              if (Zr) {
                var _t = rr({ fileName: ke, pos: cr.start + cr.length }, A, M), Rt = _t ? _t.pos - Zr.pos : cr.length;
                return { fileName: Zr.fileName, textSpan: { start: Zr.pos, length: Rt }, originalFileName: l.fileName, originalTextSpan: l.textSpan, contextSpan: rn(l, A, M), originalContextSpan: l.contextSpan };
              }
            }
            e.getMappedDocumentSpan = Hn;
            function rn(l, A, M) {
              var ke = l.contextSpan && rr({ fileName: l.fileName, pos: l.contextSpan.start }, A, M), cr = l.contextSpan && rr({ fileName: l.fileName, pos: l.contextSpan.start + l.contextSpan.length }, A, M);
              return ke && cr ? { start: ke.pos, length: cr.pos - ke.pos } : void 0;
            }
            e.getMappedContextSpan = rn;
            function xn(l) {
              var A = l.declarations ? e.firstOrUndefined(l.declarations) : void 0;
              return !!e.findAncestor(A, function(M) {
                return e.isParameter(M) ? true : e.isBindingElement(M) || e.isObjectBindingPattern(M) || e.isArrayBindingPattern(M) ? false : "quit";
              });
            }
            e.isFirstDeclarationOfSymbolParameter = xn;
            var Mn = Rn();
            function Rn() {
              var l = e.defaultMaximumTruncationLength * 10, A, M, ke, cr;
              _n();
              var Zr = function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.text);
              };
              return { displayParts: function() {
                var Nt = A.length && A[A.length - 1].text;
                return cr > l && Nt && Nt !== "..." && (e.isWhiteSpaceLike(Nt.charCodeAt(Nt.length - 1)) || A.push(on(" ", e.SymbolDisplayPartKind.space)), A.push(on("...", e.SymbolDisplayPartKind.punctuation))), A;
              }, writeKeyword: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.keyword);
              }, writeOperator: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.operator);
              }, writePunctuation: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.punctuation);
              }, writeTrailingSemicolon: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.punctuation);
              }, writeSpace: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.space);
              }, writeStringLiteral: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.stringLiteral);
              }, writeParameter: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.parameterName);
              }, writeProperty: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.propertyName);
              }, writeLiteral: function(Nt) {
                return Rt(Nt, e.SymbolDisplayPartKind.stringLiteral);
              }, writeSymbol: un, writeLine: bn, write: Zr, writeComment: Zr, getText: function() {
                return "";
              }, getTextPos: function() {
                return 0;
              }, getColumn: function() {
                return 0;
              }, getLine: function() {
                return 0;
              }, isAtStartOfLine: function() {
                return false;
              }, hasTrailingWhitespace: function() {
                return false;
              }, hasTrailingComment: function() {
                return false;
              }, rawWrite: e.notImplemented, getIndent: function() {
                return ke;
              }, increaseIndent: function() {
                ke++;
              }, decreaseIndent: function() {
                ke--;
              }, clear: _n, trackSymbol: function() {
                return false;
              }, reportInaccessibleThisError: e.noop, reportInaccessibleUniqueSymbolError: e.noop, reportPrivateInBaseOfClassExpression: e.noop };
              function _t() {
                if (!(cr > l) && M) {
                  var Nt = e.getIndentString(ke);
                  Nt && (cr += Nt.length, A.push(on(Nt, e.SymbolDisplayPartKind.space))), M = false;
                }
              }
              function Rt(Nt, Ft) {
                cr > l || (_t(), cr += Nt.length, A.push(on(Nt, Ft)));
              }
              function un(Nt, Ft) {
                cr > l || (_t(), cr += Nt.length, A.push(kn(Nt, Ft)));
              }
              function bn() {
                cr > l || (cr += 1, A.push(Ti()), M = true);
              }
              function _n() {
                A = [], M = true, ke = 0, cr = 0;
              }
            }
            function kn(l, A) {
              return on(l, M(A));
              function M(ke) {
                var cr = ke.flags;
                return cr & 3 ? xn(ke) ? e.SymbolDisplayPartKind.parameterName : e.SymbolDisplayPartKind.localName : cr & 4 || cr & 32768 || cr & 65536 ? e.SymbolDisplayPartKind.propertyName : cr & 8 ? e.SymbolDisplayPartKind.enumMemberName : cr & 16 ? e.SymbolDisplayPartKind.functionName : cr & 32 ? e.SymbolDisplayPartKind.className : cr & 64 ? e.SymbolDisplayPartKind.interfaceName : cr & 384 ? e.SymbolDisplayPartKind.enumName : cr & 1536 ? e.SymbolDisplayPartKind.moduleName : cr & 8192 ? e.SymbolDisplayPartKind.methodName : cr & 262144 ? e.SymbolDisplayPartKind.typeParameterName : cr & 524288 || cr & 2097152 ? e.SymbolDisplayPartKind.aliasName : e.SymbolDisplayPartKind.text;
              }
            }
            e.symbolPart = kn;
            function on(l, A) {
              return { text: l, kind: e.SymbolDisplayPartKind[A] };
            }
            e.displayPart = on;
            function Xr() {
              return on(" ", e.SymbolDisplayPartKind.space);
            }
            e.spacePart = Xr;
            function wr(l) {
              return on(e.tokenToString(l), e.SymbolDisplayPartKind.keyword);
            }
            e.keywordPart = wr;
            function fn(l) {
              return on(e.tokenToString(l), e.SymbolDisplayPartKind.punctuation);
            }
            e.punctuationPart = fn;
            function mn(l) {
              return on(e.tokenToString(l), e.SymbolDisplayPartKind.operator);
            }
            e.operatorPart = mn;
            function Mi(l) {
              return on(l, e.SymbolDisplayPartKind.parameterName);
            }
            e.parameterNamePart = Mi;
            function An(l) {
              return on(l, e.SymbolDisplayPartKind.propertyName);
            }
            e.propertyNamePart = An;
            function xi(l) {
              var A = e.stringToToken(l);
              return A === void 0 ? ti(l) : wr(A);
            }
            e.textOrKeywordPart = xi;
            function ti(l) {
              return on(l, e.SymbolDisplayPartKind.text);
            }
            e.textPart = ti;
            function li(l) {
              return on(l, e.SymbolDisplayPartKind.aliasName);
            }
            e.typeAliasNamePart = li;
            function Bn(l) {
              return on(l, e.SymbolDisplayPartKind.typeParameterName);
            }
            e.typeParameterNamePart = Bn;
            function vn(l) {
              return on(l, e.SymbolDisplayPartKind.linkText);
            }
            e.linkTextPart = vn;
            function Ue(l, A) {
              return { text: l, kind: e.SymbolDisplayPartKind[e.SymbolDisplayPartKind.linkName], target: { fileName: e.getSourceFileOfNode(A).fileName, textSpan: ln(A) } };
            }
            e.linkNamePart = Ue;
            function Vn(l) {
              return on(l, e.SymbolDisplayPartKind.link);
            }
            e.linkPart = Vn;
            function Ei(l, A) {
              var M, ke = e.isJSDocLink(l) ? "link" : e.isJSDocLinkCode(l) ? "linkcode" : "linkplain", cr = [Vn("{@".concat(ke, " "))];
              if (!l.name)
                l.text && cr.push(vn(l.text));
              else {
                var Zr = A == null ? void 0 : A.getSymbolAtLocation(l.name), _t = Fi(l.text), Rt = e.getTextOfNode(l.name) + l.text.slice(0, _t), un = ni(l.text.slice(_t)), bn = (Zr == null ? void 0 : Zr.valueDeclaration) || ((M = Zr == null ? void 0 : Zr.declarations) === null || M === void 0 ? void 0 : M[0]);
                bn ? (cr.push(Ue(Rt, bn)), un && cr.push(vn(un))) : cr.push(vn(Rt + (_t || un.indexOf("://") === 0 ? "" : " ") + un));
              }
              return cr.push(Vn("}")), cr;
            }
            e.buildLinkParts = Ei;
            function ni(l) {
              var A = 0;
              if (l.charCodeAt(A++) === 124) {
                for (; A < l.length && l.charCodeAt(A) === 32; )
                  A++;
                return l.slice(A);
              }
              return l;
            }
            function Fi(l) {
              if (l.indexOf("()") === 0)
                return 2;
              if (l[0] !== "<")
                return 0;
              for (var A = 0, M = 0; M < l.length; )
                if (l[M] === "<" && A++, l[M] === ">" && A--, M++, !A)
                  return M;
              return 0;
            }
            var Tn = `\r
`;
            function jn(l, A) {
              var M;
              return (A == null ? void 0 : A.newLineCharacter) || ((M = l.getNewLine) === null || M === void 0 ? void 0 : M.call(l)) || Tn;
            }
            e.getNewLineOrDefaultFromHost = jn;
            function Ti() {
              return on(`
`, e.SymbolDisplayPartKind.lineBreak);
            }
            e.lineBreakPart = Ti;
            function Si(l) {
              try {
                return l(Mn), Mn.displayParts();
              } finally {
                Mn.clear();
              }
            }
            e.mapToDisplayParts = Si;
            function C(l, A, M, ke) {
              return ke === void 0 && (ke = 0), Si(function(cr) {
                l.writeType(A, M, ke | 1024 | 16384, cr);
              });
            }
            e.typeToDisplayParts = C;
            function W(l, A, M, ke, cr) {
              return cr === void 0 && (cr = 0), Si(function(Zr) {
                l.writeSymbol(A, M, ke, cr | 8, Zr);
              });
            }
            e.symbolToDisplayParts = W;
            function ee(l, A, M, ke) {
              return ke === void 0 && (ke = 0), ke |= 25632, Si(function(cr) {
                l.writeSignature(A, M, ke, void 0, cr);
              });
            }
            e.signatureToDisplayParts = ee;
            function le(l, A) {
              var M = A.getSourceFile();
              return Si(function(ke) {
                var cr = e.createPrinter({ removeComments: true, omitTrailingSemicolon: true });
                cr.writeNode(4, l, M, ke);
              });
            }
            e.nodeToDisplayParts = le;
            function Ze(l) {
              return !!l.parent && e.isImportOrExportSpecifier(l.parent) && l.parent.propertyName === l;
            }
            e.isImportOrExportSpecifierName = Ze;
            function Ir(l, A) {
              return e.ensureScriptKind(l, A.getScriptKind && A.getScriptKind(l));
            }
            e.getScriptKind = Ir;
            function Ar(l, A) {
              for (var M = l; yt(M) || hr(M) && M.target; )
                hr(M) && M.target ? M = M.target : M = e.skipAlias(M, A);
              return M;
            }
            e.getSymbolTarget = Ar;
            function hr(l) {
              return (l.flags & 33554432) !== 0;
            }
            function yt(l) {
              return (l.flags & 2097152) !== 0;
            }
            function Pt(l, A) {
              return e.getSymbolId(e.skipAlias(l, A));
            }
            e.getUniqueSymbolId = Pt;
            function Ut(l, A) {
              for (; e.isWhiteSpaceLike(l.charCodeAt(A)); )
                A += 1;
              return A;
            }
            e.getFirstNonSpaceCharacterPosition = Ut;
            function jt(l, A) {
              for (; A > -1 && e.isWhiteSpaceSingleLine(l.charCodeAt(A)); )
                A -= 1;
              return A + 1;
            }
            e.getPrecedingNonSpaceCharacterPosition = jt;
            function Ht(l, A) {
              A === void 0 && (A = true);
              var M = l && Pi(l);
              return M && !A && oa(M), M;
            }
            e.getSynthesizedDeepClone = Ht;
            function gi(l, A, M) {
              var ke = M(l);
              return ke ? e.setOriginalNode(ke, l) : ke = Pi(l, M), ke && !A && oa(ke), ke;
            }
            e.getSynthesizedDeepCloneWithReplacements = gi;
            function Pi(l, A) {
              var M = A ? function(_t) {
                return gi(_t, true, A);
              } : Ht, ke = A ? function(_t) {
                return _t && Bi(_t, true, A);
              } : function(_t) {
                return _t && Gn(_t);
              }, cr = e.visitEachChild(l, M, e.nullTransformationContext, ke, M);
              if (cr === l) {
                var Zr = e.isStringLiteral(l) ? e.setOriginalNode(e.factory.createStringLiteralFromNode(l), l) : e.isNumericLiteral(l) ? e.setOriginalNode(e.factory.createNumericLiteral(l.text, l.numericLiteralFlags), l) : e.factory.cloneNode(l);
                return e.setTextRange(Zr, l);
              }
              return cr.parent = void 0, cr;
            }
            function Gn(l, A) {
              return A === void 0 && (A = true), l && e.factory.createNodeArray(l.map(function(M) {
                return Ht(M, A);
              }), l.hasTrailingComma);
            }
            e.getSynthesizedDeepClones = Gn;
            function Bi(l, A, M) {
              return e.factory.createNodeArray(l.map(function(ke) {
                return gi(ke, A, M);
              }), l.hasTrailingComma);
            }
            e.getSynthesizedDeepClonesWithReplacements = Bi;
            function oa(l) {
              Zi(l), Ki(l);
            }
            e.suppressLeadingAndTrailingTrivia = oa;
            function Zi(l) {
              Gi(l, 512, da);
            }
            e.suppressLeadingTrivia = Zi;
            function Ki(l) {
              Gi(l, 1024, e.getLastChild);
            }
            e.suppressTrailingTrivia = Ki;
            function qi(l, A) {
              var M = l.getSourceFile(), ke = M.text;
              Hi(l, ke) ? Xi(l, A, M) : Li(l, A, M), sa(l, A, M);
            }
            e.copyComments = qi;
            function Hi(l, A) {
              for (var M = l.getFullStart(), ke = l.getStart(), cr = M; cr < ke; cr++)
                if (A.charCodeAt(cr) === 10)
                  return true;
              return false;
            }
            function Gi(l, A, M) {
              e.addEmitFlags(l, A);
              var ke = M(l);
              ke && Gi(ke, A, M);
            }
            function da(l) {
              return l.forEachChild(function(A) {
                return A;
              });
            }
            function Jn(l, A) {
              for (var M = l, ke = 1; !e.isFileLevelUniqueName(A, M); ke++)
                M = "".concat(l, "_").concat(ke);
              return M;
            }
            e.getUniqueName = Jn;
            function ea(l, A, M, ke) {
              for (var cr = 0, Zr = -1, _t = 0, Rt = l; _t < Rt.length; _t++) {
                var un = Rt[_t], bn = un.fileName, _n = un.textChanges;
                e.Debug.assert(bn === A);
                for (var Nt = 0, Ft = _n; Nt < Ft.length; Nt++) {
                  var Sn = Ft[Nt], wn = Sn.span, Wn = Sn.newText, Ji = ne(Wn, e.escapeString(M));
                  if (Ji !== -1 && (Zr = wn.start + cr + Ji, !ke))
                    return Zr;
                  cr += Wn.length - wn.length;
                }
              }
              return e.Debug.assert(ke), e.Debug.assert(Zr >= 0), Zr;
            }
            e.getRenameLocation = ea;
            function Xi(l, A, M, ke, cr) {
              e.forEachLeadingCommentRange(M.text, l.pos, p(A, M, ke, cr, e.addSyntheticLeadingComment));
            }
            e.copyLeadingComments = Xi;
            function sa(l, A, M, ke, cr) {
              e.forEachTrailingCommentRange(M.text, l.end, p(A, M, ke, cr, e.addSyntheticTrailingComment));
            }
            e.copyTrailingComments = sa;
            function Li(l, A, M, ke, cr) {
              e.forEachTrailingCommentRange(M.text, l.pos, p(A, M, ke, cr, e.addSyntheticLeadingComment));
            }
            e.copyTrailingAsLeadingComments = Li;
            function p(l, A, M, ke, cr) {
              return function(Zr, _t, Rt, un) {
                Rt === 3 ? (Zr += 2, _t -= 2) : Zr += 2, cr(l, M || Rt, A.text.slice(Zr, _t), ke !== void 0 ? ke : un);
              };
            }
            function ne(l, A) {
              if (e.startsWith(l, A))
                return 0;
              var M = l.indexOf(" " + A);
              return M === -1 && (M = l.indexOf("." + A)), M === -1 && (M = l.indexOf('"' + A)), M === -1 ? -1 : M + 1;
            }
            function Ne(l) {
              return e.isBinaryExpression(l) && l.operatorToken.kind === 27 || e.isObjectLiteralExpression(l) || e.isAsExpression(l) && e.isObjectLiteralExpression(l.expression);
            }
            e.needsParentheses = Ne;
            function or(l, A) {
              var M = l.parent;
              switch (M.kind) {
                case 211:
                  return A.getContextualType(M);
                case 223: {
                  var ke = M, cr = ke.left, Zr = ke.operatorToken, _t = ke.right;
                  return vt(Zr.kind) ? A.getTypeAtLocation(l === _t ? cr : _t) : A.getContextualType(l);
                }
                case 292:
                  return M.expression === l ? tn(M, A) : void 0;
                default:
                  return A.getContextualType(l);
              }
            }
            e.getContextualTypeFromParent = or;
            function it2(l, A, M) {
              var ke = fr(l, A), cr = JSON.stringify(M);
              return ke === 0 ? "'".concat(e.stripQuotes(cr).replace(/'/g, "\\'").replace(/\\"/g, '"'), "'") : cr;
            }
            e.quote = it2;
            function vt(l) {
              switch (l) {
                case 36:
                case 34:
                case 37:
                case 35:
                  return true;
                default:
                  return false;
              }
            }
            e.isEqualityOperatorKind = vt;
            function Tt(l) {
              switch (l.kind) {
                case 10:
                case 14:
                case 225:
                case 212:
                  return true;
                default:
                  return false;
              }
            }
            e.isStringLiteralOrTemplate = Tt;
            function St(l) {
              return !!l.getStringIndexType() || !!l.getNumberIndexType();
            }
            e.hasIndexSignature = St;
            function tn(l, A) {
              return A.getTypeAtLocation(l.parent.parent.expression);
            }
            e.getSwitchedType = tn, e.ANONYMOUS = "anonymous function";
            function Mt(l, A, M, ke) {
              var cr = M.getTypeChecker(), Zr = true, _t = function() {
                return Zr = false;
              }, Rt = cr.typeToTypeNode(l, A, 1, { trackSymbol: function(un, bn, _n) {
                return Zr = Zr && cr.isSymbolAccessible(un, bn, _n, false).accessibility === 0, !Zr;
              }, reportInaccessibleThisError: _t, reportPrivateInBaseOfClassExpression: _t, reportInaccessibleUniqueSymbolError: _t, moduleResolverHost: dn(M, ke) });
              return Zr ? Rt : void 0;
            }
            e.getTypeNodeIfAccessible = Mt;
            function $t(l) {
              return l === 176 || l === 177 || l === 178 || l === 168 || l === 170;
            }
            function y(l) {
              return l === 259 || l === 173 || l === 171 || l === 174 || l === 175;
            }
            function De(l) {
              return l === 264;
            }
            function R(l) {
              return l === 240 || l === 241 || l === 243 || l === 248 || l === 249 || l === 250 || l === 254 || l === 256 || l === 169 || l === 262 || l === 269 || l === 268 || l === 275 || l === 267 || l === 274;
            }
            e.syntaxRequiresTrailingSemicolonOrASI = R, e.syntaxMayBeASICandidate = e.or($t, y, De, R);
            function Jt(l, A) {
              var M = l.getLastToken(A);
              if (M && M.kind === 26)
                return false;
              if ($t(l.kind)) {
                if (M && M.kind === 27)
                  return false;
              } else if (De(l.kind)) {
                var ke = e.last(l.getChildren(A));
                if (ke && e.isModuleBlock(ke))
                  return false;
              } else if (y(l.kind)) {
                var ke = e.last(l.getChildren(A));
                if (ke && e.isFunctionBlock(ke))
                  return false;
              } else if (!R(l.kind))
                return false;
              if (l.kind === 243)
                return true;
              var cr = e.findAncestor(l, function(un) {
                return !un.parent;
              }), Zr = xe(l, cr, A);
              if (!Zr || Zr.kind === 19)
                return true;
              var _t = A.getLineAndCharacterOfPosition(l.getEnd()).line, Rt = A.getLineAndCharacterOfPosition(Zr.getStart(A)).line;
              return _t !== Rt;
            }
            function Qt(l, A, M) {
              var ke = e.findAncestor(A, function(cr) {
                return cr.end !== l ? "quit" : e.syntaxMayBeASICandidate(cr.kind);
              });
              return !!ke && Jt(ke, M);
            }
            e.positionIsASICandidate = Qt;
            function qn(l) {
              var A = 0, M = 0, ke = 5;
              return e.forEachChild(l, function cr(Zr) {
                if (R(Zr.kind)) {
                  var _t = Zr.getLastToken(l);
                  (_t == null ? void 0 : _t.kind) === 26 ? A++ : M++;
                } else if ($t(Zr.kind)) {
                  var _t = Zr.getLastToken(l);
                  if ((_t == null ? void 0 : _t.kind) === 26)
                    A++;
                  else if (_t && _t.kind !== 27) {
                    var Rt = e.getLineAndCharacterOfPosition(l, _t.getStart(l)).line, un = e.getLineAndCharacterOfPosition(l, e.getSpanOfTokenAtPosition(l, _t.end).start).line;
                    Rt !== un && M++;
                  }
                }
                return A + M >= ke ? true : e.forEachChild(Zr, cr);
              }), A === 0 && M <= 1 ? true : A / M > 1 / ke;
            }
            e.probablyUsesSemicolons = qn;
            function Ni(l, A) {
              return ra(l, l.getDirectories, A) || [];
            }
            e.tryGetDirectories = Ni;
            function _a(l, A, M, ke, cr) {
              return ra(l, l.readDirectory, A, M, ke, cr) || e.emptyArray;
            }
            e.tryReadDirectory = _a;
            function Ri(l, A) {
              return ra(l, l.fileExists, A);
            }
            e.tryFileExists = Ri;
            function ca(l, A) {
              return $i(function() {
                return e.directoryProbablyExists(A, l);
              }) || false;
            }
            e.tryDirectoryExists = ca;
            function $i(l) {
              try {
                return l();
              } catch {
                return;
              }
            }
            e.tryAndIgnoreErrors = $i;
            function ra(l, A) {
              for (var M = [], ke = 2; ke < arguments.length; ke++)
                M[ke - 2] = arguments[ke];
              return $i(function() {
                return A && A.apply(l, M);
              });
            }
            e.tryIOAndConsumeErrors = ra;
            function Ea(l, A, M) {
              var ke = [];
              return e.forEachAncestorDirectory(l, function(cr) {
                if (cr === M)
                  return true;
                var Zr = e.combinePaths(cr, "package.json");
                Ri(A, Zr) && ke.push(Zr);
              }), ke;
            }
            e.findPackageJsons = Ea;
            function Ui(l, A) {
              var M;
              return e.forEachAncestorDirectory(l, function(ke) {
                if (ke === "node_modules" || (M = e.findConfigFile(ke, function(cr) {
                  return Ri(A, cr);
                }, "package.json"), M))
                  return true;
              }), M;
            }
            e.findPackageJson = Ui;
            function ji(l, A) {
              if (!A.fileExists)
                return [];
              var M = [];
              return e.forEachAncestorDirectory(e.getDirectoryPath(l), function(ke) {
                var cr = e.combinePaths(ke, "package.json");
                if (A.fileExists(cr)) {
                  var Zr = ma(cr, A);
                  Zr && M.push(Zr);
                }
              }), M;
            }
            e.getPackageJsonsVisibleToFile = ji;
            function ma(l, A) {
              if (!A.readFile)
                return;
              var M = ["dependencies", "devDependencies", "optionalDependencies", "peerDependencies"], ke = A.readFile(l) || "", cr = Is(ke), Zr = {};
              if (cr)
                for (var _t = 0, Rt = M; _t < Rt.length; _t++) {
                  var un = Rt[_t], bn = cr[un];
                  if (bn) {
                    var _n = new e.Map();
                    for (var Nt in bn)
                      _n.set(Nt, bn[Nt]);
                    Zr[un] = _n;
                  }
                }
              var Ft = [[1, Zr.dependencies], [2, Zr.devDependencies], [8, Zr.optionalDependencies], [4, Zr.peerDependencies]];
              return T(T({}, Zr), { parseable: !!cr, fileName: l, get: Sn, has: function(wn, Wn) {
                return !!Sn(wn, Wn);
              } });
              function Sn(wn, Wn) {
                Wn === void 0 && (Wn = 15);
                for (var Ji = 0, Ba = Ft; Ji < Ba.length; Ji++) {
                  var Ao = Ba[Ji], ko = Ao[0], Po = Ao[1];
                  if (Po && Wn & ko) {
                    var ao = Po.get(wn);
                    if (ao !== void 0)
                      return ao;
                  }
                }
              }
            }
            e.createPackageJsonInfo = ma;
            function vo(l, A, M) {
              var ke = (M.getPackageJsonsVisibleToFile && M.getPackageJsonsVisibleToFile(l.fileName) || ji(l.fileName, M)).filter(function(Ft) {
                return Ft.parseable;
              }), cr;
              return { allowsImportingAmbientModule: _t, allowsImportingSourceFile: Rt, allowsImportingSpecifier: un };
              function Zr(Ft) {
                for (var Sn = Nt(Ft), wn = 0, Wn = ke; wn < Wn.length; wn++) {
                  var Ji = Wn[wn];
                  if (Ji.has(Sn) || Ji.has(e.getTypesPackageName(Sn)))
                    return true;
                }
                return false;
              }
              function _t(Ft, Sn) {
                if (!ke.length || !Ft.valueDeclaration)
                  return true;
                var wn = Ft.valueDeclaration.getSourceFile(), Wn = _n(wn.fileName, Sn);
                if (typeof Wn > "u")
                  return true;
                var Ji = e.stripQuotes(Ft.getName());
                return bn(Ji) ? true : Zr(Wn) || Zr(Ji);
              }
              function Rt(Ft, Sn) {
                if (!ke.length)
                  return true;
                var wn = _n(Ft.fileName, Sn);
                return wn ? Zr(wn) : true;
              }
              function un(Ft) {
                return !ke.length || bn(Ft) || e.pathIsRelative(Ft) || e.isRootedDiskPath(Ft) ? true : Zr(Ft);
              }
              function bn(Ft) {
                return !!(e.isSourceFileJS(l) && e.JsTyping.nodeCoreModules.has(Ft) && (cr === void 0 && (cr = wa(l)), cr));
              }
              function _n(Ft, Sn) {
                if (e.stringContains(Ft, "node_modules")) {
                  var wn = e.moduleSpecifiers.getNodeModulesPackageName(M.getCompilationSettings(), l, Ft, Sn, A);
                  if (wn && !e.pathIsRelative(wn) && !e.isRootedDiskPath(wn))
                    return Nt(wn);
                }
              }
              function Nt(Ft) {
                var Sn = e.getPathComponents(e.getPackageNameFromTypesPackageName(Ft)).slice(1);
                return e.startsWith(Sn[0], "@") ? "".concat(Sn[0], "/").concat(Sn[1]) : Sn[0];
              }
            }
            e.createPackageJsonImportFilter = vo;
            function Is(l) {
              try {
                return JSON.parse(l);
              } catch {
                return;
              }
            }
            function wa(l) {
              return e.some(l.imports, function(A) {
                var M = A.text;
                return e.JsTyping.nodeCoreModules.has(M);
              });
            }
            e.consumesNodeCoreModules = wa;
            function Ho(l) {
              return e.contains(e.getPathComponents(l), "node_modules");
            }
            e.isInsideNodeModules = Ho;
            function Ta(l) {
              return l.file !== void 0 && l.start !== void 0 && l.length !== void 0;
            }
            e.isDiagnosticWithLocation = Ta;
            function Ja(l, A) {
              var M = ln(l), ke = e.binarySearchKey(A, M, e.identity, e.compareTextSpans);
              if (ke >= 0) {
                var cr = A[ke];
                return e.Debug.assertEqual(cr.file, l.getSourceFile(), "Diagnostics proided to 'findDiagnosticForNode' must be from a single SourceFile"), e.cast(cr, Ta);
              }
            }
            e.findDiagnosticForNode = Ja;
            function bo(l, A) {
              var M, ke = e.binarySearchKey(A, l.start, function(Rt) {
                return Rt.start;
              }, e.compareValues);
              for (ke < 0 && (ke = ~ke); ((M = A[ke - 1]) === null || M === void 0 ? void 0 : M.start) === l.start; )
                ke--;
              for (var cr = [], Zr = e.textSpanEnd(l); ; ) {
                var _t = e.tryCast(A[ke], Ta);
                if (!_t || _t.start > Zr)
                  break;
                e.textSpanContainsTextSpan(l, _t) && cr.push(_t), ke++;
              }
              return cr;
            }
            e.getDiagnosticsWithinSpan = bo;
            function Eo(l) {
              var A = l.startPosition, M = l.endPosition;
              return e.createTextSpanFromBounds(A, M === void 0 ? A : M);
            }
            e.getRefactorContextSpan = Eo;
            function to(l, A) {
              var M = ct(l, A.start), ke = e.findAncestor(M, function(cr) {
                return cr.getStart(l) < A.start || cr.getEnd() > e.textSpanEnd(A) ? "quit" : e.isExpression(cr) && Gr(A, ln(cr, l));
              });
              return ke;
            }
            e.getFixableErrorSpanExpression = to;
            function Aa(l, A, M) {
              return M === void 0 && (M = e.identity), l ? e.isArray(l) ? M(e.map(l, A)) : A(l, 0) : void 0;
            }
            e.mapOneOrMany = Aa;
            function To(l) {
              return e.isArray(l) ? e.first(l) : l;
            }
            e.firstOrOnly = To;
            function Os(l, A) {
              if (Co(l)) {
                var M = ka(l);
                if (M)
                  return M;
                var ke = e.codefix.moduleSymbolToValidIdentifier(no(l), A, false), cr = e.codefix.moduleSymbolToValidIdentifier(no(l), A, true);
                return ke === cr ? ke : [ke, cr];
              }
              return l.name;
            }
            e.getNamesForExportedSymbol = Os;
            function So(l, A, M) {
              return Co(l) ? ka(l) || e.codefix.moduleSymbolToValidIdentifier(no(l), A, !!M) : l.name;
            }
            e.getNameForExportedSymbol = So;
            function Co(l) {
              return !(l.flags & 33554432) && (l.escapedName === "export=" || l.escapedName === "default");
            }
            function ka(l) {
              return e.firstDefined(l.declarations, function(A) {
                var M;
                return e.isExportAssignment(A) ? (M = e.tryCast(e.skipOuterExpressions(A.expression), e.isIdentifier)) === null || M === void 0 ? void 0 : M.text : void 0;
              });
            }
            function no(l) {
              var A;
              return e.Debug.checkDefined(l.parent, "Symbol parent was undefined. Flags: ".concat(e.Debug.formatSymbolFlags(l.flags), ". ") + "Declarations: ".concat((A = l.declarations) === null || A === void 0 ? void 0 : A.map(function(M) {
                var ke = e.Debug.formatSyntaxKind(M.kind), cr = e.isInJSFile(M), Zr = M.expression;
                return (cr ? "[JS]" : "") + ke + (Zr ? " (expression: ".concat(e.Debug.formatSyntaxKind(Zr.kind), ")") : "");
              }).join(", "), "."));
            }
            function Go(l, A, M) {
              var ke = A.length;
              if (ke + M > l.length)
                return false;
              for (var cr = 0; cr < ke; cr++)
                if (A.charCodeAt(cr) !== l.charCodeAt(cr + M))
                  return false;
              return true;
            }
            e.stringContainsAt = Go;
            function Ii(l) {
              return l.charCodeAt(0) === 95;
            }
            e.startsWithUnderscore = Ii;
            function Fa(l) {
              return !io(l);
            }
            e.isGlobalDeclaration = Fa;
            function io(l) {
              var A = l.getSourceFile();
              return !A.externalModuleIndicator && !A.commonJsModuleIndicator ? false : e.isInJSFile(l) || !e.findAncestor(l, e.isGlobalScopeAugmentation);
            }
            e.isNonGlobalDeclaration = io;
            function Do(l) {
              return !!(e.getCombinedNodeFlagsAlwaysIncludeJSDoc(l) & 8192);
            }
            e.isDeprecatedDeclaration = Do;
            function xo(l, A) {
              var M = e.firstDefined(l.imports, function(ke) {
                if (e.JsTyping.nodeCoreModules.has(ke.text))
                  return e.startsWith(ke.text, "node:");
              });
              return M != null ? M : A.usesUriStyleNodeCoreModules;
            }
            e.shouldUseUriStyleNodeCoreModules = xo;
            function Xo(l) {
              return l === `
` ? 1 : 0;
            }
            e.getNewLineKind = Xo;
            function $o(l) {
              return e.isArray(l) ? e.formatStringFromArgs(e.getLocaleSpecificMessage(l[0]), l.slice(1)) : e.getLocaleSpecificMessage(l);
            }
            e.diagnosticToString = $o;
            function zi(l, A) {
              var M = l.options, ke = !M.semicolons || M.semicolons === e.SemicolonPreference.Ignore, cr = M.semicolons === e.SemicolonPreference.Remove || ke && !qn(A);
              return T(T({}, M), { semicolons: cr ? e.SemicolonPreference.Remove : e.SemicolonPreference.Ignore });
            }
            e.getFormatCodeSettingsForWriting = zi;
            function Ms(l) {
              return l === 2 || l === 3;
            }
            e.jsxModeNeedsExplicitImport = Ms;
            function wo(l, A) {
              return l.isSourceFileFromExternalLibrary(A) || l.isSourceFileDefaultLibrary(A);
            }
            e.isSourceFileFromLibrary = wo;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(je) {
              je[je.Named = 0] = "Named", je[je.Default = 1] = "Default", je[je.Namespace = 2] = "Namespace", je[je.CommonJS = 3] = "CommonJS";
            })(t3 = e.ImportKind || (e.ImportKind = {}));
            var w;
            (function(je) {
              je[je.Named = 0] = "Named", je[je.Default = 1] = "Default", je[je.ExportEquals = 2] = "ExportEquals", je[je.UMD = 3] = "UMD";
            })(w = e.ExportKind || (e.ExportKind = {}));
            function s(je) {
              var V = 1, B = e.createMultiMap(), U = new e.Map(), m = new e.Map(), v, g = { isUsableByFile: function(ie) {
                return ie === v;
              }, isEmpty: function() {
                return !B.size;
              }, clear: function() {
                B.clear(), U.clear(), v = void 0;
              }, add: function(ie, H, pe, j, be, Xe, Re, Fe) {
                ie !== v && (g.clear(), v = ie);
                var dr;
                if (be) {
                  var ze = e.getNodeModulePathParts(be.fileName);
                  if (ze) {
                    var ve = ze.topLevelNodeModulesIndex, er = ze.topLevelPackageNameIndex, ar = ze.packageRootIndex;
                    if (dr = e.unmangleScopedPackageName(e.getPackageNameFromTypesPackageName(be.fileName.substring(er + 1, ar))), e.startsWith(ie, be.path.substring(0, ve))) {
                      var Cr = m.get(dr), Ce = be.fileName.substring(0, er + 1);
                      if (Cr) {
                        var $e = Cr.indexOf(e.nodeModulesPathPart);
                        ve > $e && m.set(dr, Ce);
                      } else
                        m.set(dr, Ce);
                    }
                  }
                }
                var gr = Xe === 1, X = gr && e.getLocalSymbolForExportDefault(H) || H, Te = Xe === 0 || e.isExternalModuleSymbol(X) ? e.unescapeLeadingUnderscores(pe) : e.getNamesForExportedSymbol(X, void 0), we = typeof Te == "string" ? Te : Te[0], he = typeof Te == "string" ? void 0 : Te[1], yr = e.stripQuotes(j.name), kr = V++, nr = e.skipAlias(H, Fe), tr = H.flags & 33554432 ? void 0 : H, Lr = j.flags & 33554432 ? void 0 : j;
                (!tr || !Lr) && U.set(kr, [H, j]), B.add(S(we, H, e.isExternalModuleNameRelative(yr) ? void 0 : yr, Fe), { id: kr, symbolTableKey: pe, symbolName: we, capitalizedSymbolName: he, moduleName: yr, moduleFile: be, moduleFileName: be == null ? void 0 : be.fileName, packageName: dr, exportKind: Xe, targetFlags: nr.flags, isFromPackageJson: Re, symbol: tr, moduleSymbol: Lr });
              }, get: function(ie, H) {
                if (ie === v) {
                  var pe = B.get(H);
                  return pe == null ? void 0 : pe.map(O);
                }
              }, search: function(ie, H, pe, j) {
                if (ie === v)
                  return e.forEachEntry(B, function(be, Xe) {
                    var Re = te(Xe), Fe = Re.symbolName, dr = Re.ambientModuleName, ze = H && be[0].capitalizedSymbolName || Fe;
                    if (pe(ze, be[0].targetFlags)) {
                      var ve = be.map(O), er = ve.filter(function(Cr, Ce) {
                        return ge(Cr, be[Ce].packageName);
                      });
                      if (er.length) {
                        var ar = j(er, ze, !!dr, Xe);
                        if (ar !== void 0)
                          return ar;
                      }
                    }
                  });
              }, releaseSymbols: function() {
                U.clear();
              }, onFileChanged: function(ie, H, pe) {
                return Je(ie) && Je(H) ? false : v && v !== H.path || pe && e.consumesNodeCoreModules(ie) !== e.consumesNodeCoreModules(H) || !e.arrayIsEqualTo(ie.moduleAugmentations, H.moduleAugmentations) || !qe(ie, H) ? (g.clear(), true) : (v = H.path, false);
              } };
              return e.Debug.isDebugging && Object.defineProperty(g, "__cache", { get: function() {
                return B;
              } }), g;
              function O(ie) {
                if (ie.symbol && ie.moduleSymbol)
                  return ie;
                var H = ie.id, pe = ie.exportKind, j = ie.targetFlags, be = ie.isFromPackageJson, Xe = ie.moduleFileName, Re = U.get(H) || e.emptyArray, Fe = Re[0], dr = Re[1];
                if (Fe && dr)
                  return { symbol: Fe, moduleSymbol: dr, moduleFileName: Xe, exportKind: pe, targetFlags: j, isFromPackageJson: be };
                var ze = (be ? je.getPackageJsonAutoImportProvider() : je.getCurrentProgram()).getTypeChecker(), ve = ie.moduleSymbol || dr || e.Debug.checkDefined(ie.moduleFile ? ze.getMergedSymbol(ie.moduleFile.symbol) : ze.tryFindAmbientModule(ie.moduleName)), er = ie.symbol || Fe || e.Debug.checkDefined(pe === 2 ? ze.resolveExternalModuleSymbol(ve) : ze.tryGetMemberInModuleExportsAndProperties(e.unescapeLeadingUnderscores(ie.symbolTableKey), ve), "Could not find symbol '".concat(ie.symbolName, "' by key '").concat(ie.symbolTableKey, "' in module ").concat(ve.name));
                return U.set(H, [er, ve]), { symbol: er, moduleSymbol: ve, moduleFileName: Xe, exportKind: pe, targetFlags: j, isFromPackageJson: be };
              }
              function S(ie, H, pe, j) {
                var be = pe || "";
                return "".concat(ie, "|").concat(e.getSymbolId(e.skipAlias(H, j)), "|").concat(be);
              }
              function te(ie) {
                var H = ie.substring(0, ie.indexOf("|")), pe = ie.substring(ie.lastIndexOf("|") + 1), j = pe === "" ? void 0 : pe;
                return { symbolName: H, ambientModuleName: j };
              }
              function Je(ie) {
                return !ie.commonJsModuleIndicator && !ie.externalModuleIndicator && !ie.moduleAugmentations && !ie.ambientModuleNames;
              }
              function qe(ie, H) {
                if (!e.arrayIsEqualTo(ie.ambientModuleNames, H.ambientModuleNames))
                  return false;
                for (var pe = -1, j = -1, be = function(ze) {
                  var ve = function(er) {
                    return e.isNonGlobalAmbientModule(er) && er.name.text === ze;
                  };
                  if (pe = e.findIndex(ie.statements, ve, pe + 1), j = e.findIndex(H.statements, ve, j + 1), ie.statements[pe] !== H.statements[j])
                    return { value: false };
                }, Xe = 0, Re = H.ambientModuleNames; Xe < Re.length; Xe++) {
                  var Fe = Re[Xe], dr = be(Fe);
                  if (typeof dr == "object")
                    return dr.value;
                }
                return true;
              }
              function ge(ie, H) {
                if (!H || !ie.moduleFileName)
                  return true;
                var pe = je.getGlobalTypingsCacheLocation();
                if (pe && e.startsWith(ie.moduleFileName, pe))
                  return true;
                var j = m.get(H);
                return !j || e.startsWith(ie.moduleFileName, j);
              }
            }
            e.createCacheableExportInfoMap = s;
            function q(je, V, B, U, m, v, g) {
              var O;
              if (V === B)
                return false;
              var S = g == null ? void 0 : g.get(V.path, B.path, U, {});
              if ((S == null ? void 0 : S.isBlockedByPackageJsonDependencies) !== void 0)
                return !S.isBlockedByPackageJsonDependencies;
              var te = e.hostGetCanonicalFileName(v), Je = (O = v.getGlobalTypingsCacheLocation) === null || O === void 0 ? void 0 : O.call(v), qe = !!e.moduleSpecifiers.forEachFileNameOfModule(V.fileName, B.fileName, v, false, function(ie) {
                var H = je.getSourceFile(ie);
                return (H === B || !H) && F(V.fileName, ie, te, Je);
              });
              if (m) {
                var ge = qe && m.allowsImportingSourceFile(B, v);
                return g == null || g.setBlockedByPackageJsonDependencies(V.path, B.path, U, {}, !ge), ge;
              }
              return qe;
            }
            e.isImportableFile = q;
            function F(je, V, B, U) {
              var m = e.forEachAncestorDirectory(V, function(g) {
                return e.getBaseFileName(g) === "node_modules" ? g : void 0;
              }), v = m && e.getDirectoryPath(B(m));
              return v === void 0 || e.startsWith(B(je), v) || !!U && e.startsWith(B(U), v);
            }
            function fe(je, V, B, U, m) {
              var v, g, O = e.hostUsesCaseSensitiveFileNames(V), S = B.autoImportFileExcludePatterns && e.mapDefined(B.autoImportFileExcludePatterns, function(qe) {
                var ge = e.getPatternFromSpec(qe, "", "exclude");
                return ge ? e.getRegexFromPattern(ge, O) : void 0;
              });
              Ee(je.getTypeChecker(), je.getSourceFiles(), S, function(qe, ge) {
                return m(qe, ge, je, false);
              });
              var te = U && ((v = V.getPackageJsonAutoImportProvider) === null || v === void 0 ? void 0 : v.call(V));
              if (te) {
                var Je = e.timestamp();
                Ee(te.getTypeChecker(), te.getSourceFiles(), S, function(qe, ge) {
                  return m(qe, ge, te, true);
                }), (g = V.log) === null || g === void 0 || g.call(V, "forEachExternalModuleToImportFrom autoImportProvider: ".concat(e.timestamp() - Je));
              }
            }
            e.forEachExternalModuleToImportFrom = fe;
            function Ee(je, V, B, U) {
              for (var m, v = function(ge) {
                return B == null ? void 0 : B.some(function(ie) {
                  return ie.test(ge);
                });
              }, g = 0, O = je.getAmbientModules(); g < O.length; g++) {
                var S = O[g];
                !e.stringContains(S.name, "*") && !(B && (!((m = S.declarations) === null || m === void 0) && m.every(function(ge) {
                  return v(ge.getSourceFile().fileName);
                }))) && U(S, void 0);
              }
              for (var te = 0, Je = V; te < Je.length; te++) {
                var qe = Je[te];
                e.isExternalOrCommonJsModule(qe) && !v(qe.fileName) && U(je.getMergedSymbol(qe.symbol), qe);
              }
            }
            function Se(je, V, B, U, m) {
              var v, g, O, S, te, Je = e.timestamp();
              (v = V.getPackageJsonAutoImportProvider) === null || v === void 0 || v.call(V);
              var qe = ((g = V.getCachedExportInfoMap) === null || g === void 0 ? void 0 : g.call(V)) || s({ getCurrentProgram: function() {
                return B;
              }, getPackageJsonAutoImportProvider: function() {
                var H;
                return (H = V.getPackageJsonAutoImportProvider) === null || H === void 0 ? void 0 : H.call(V);
              }, getGlobalTypingsCacheLocation: function() {
                var H;
                return (H = V.getGlobalTypingsCacheLocation) === null || H === void 0 ? void 0 : H.call(V);
              } });
              if (qe.isUsableByFile(je.path))
                return (O = V.log) === null || O === void 0 || O.call(V, "getExportInfoMap: cache hit"), qe;
              (S = V.log) === null || S === void 0 || S.call(V, "getExportInfoMap: cache miss or empty; calculating new results");
              var ge = B.getCompilerOptions(), ie = 0;
              try {
                fe(B, V, U, true, function(H, pe, j, be) {
                  ++ie % 100 === 0 && (m == null || m.throwIfCancellationRequested());
                  var Xe = new e.Map(), Re = j.getTypeChecker(), Fe = J(H, Re, ge);
                  Fe && se(Fe.symbol, Re) && qe.add(je.path, Fe.symbol, Fe.exportKind === 1 ? "default" : "export=", H, pe, Fe.exportKind, be, Re), Re.forEachExportAndPropertyOfModule(H, function(dr, ze) {
                    dr !== (Fe == null ? void 0 : Fe.symbol) && se(dr, Re) && e.addToSeen(Xe, ze) && qe.add(je.path, dr, ze, H, pe, 0, be, Re);
                  });
                });
              } catch (H) {
                throw qe.clear(), H;
              }
              return (te = V.log) === null || te === void 0 || te.call(V, "getExportInfoMap: done in ".concat(e.timestamp() - Je, " ms")), qe;
            }
            e.getExportInfoMap = Se;
            function J(je, V, B) {
              var U = Me(je, V);
              if (U) {
                var m = U.symbol, v = U.exportKind, g = Q(m, V, B);
                return g && T({ symbol: m, exportKind: v }, g);
              }
            }
            e.getDefaultLikeExportInfo = J;
            function se(je, V) {
              return !V.isUndefinedSymbol(je) && !V.isUnknownSymbol(je) && !e.isKnownSymbol(je) && !e.isPrivateIdentifierSymbol(je);
            }
            function Me(je, V) {
              var B = V.resolveExternalModuleSymbol(je);
              if (B !== je)
                return { symbol: B, exportKind: 2 };
              var U = V.tryGetMemberInModuleExports("default", je);
              if (U)
                return { symbol: U, exportKind: 1 };
            }
            function Q(je, V, B) {
              var U = e.getLocalSymbolForExportDefault(je);
              if (U)
                return { symbolForMeaning: U, name: U.name };
              var m = Be(je);
              if (m !== void 0)
                return { symbolForMeaning: je, name: m };
              if (je.flags & 2097152) {
                var v = V.getImmediateAliasedSymbol(je);
                if (v && v.parent)
                  return Q(v, V, B);
              }
              return je.escapedName !== "default" && je.escapedName !== "export=" ? { symbolForMeaning: je, name: je.getName() } : { symbolForMeaning: je, name: e.getNameForExportedSymbol(je, B.target) };
            }
            function Be(je) {
              return je.declarations && e.firstDefined(je.declarations, function(V) {
                var B;
                if (e.isExportAssignment(V))
                  return (B = e.tryCast(e.skipOuterExpressions(V.expression), e.isIdentifier)) === null || B === void 0 ? void 0 : B.text;
                if (e.isExportSpecifier(V))
                  return e.Debug.assert(V.name.text === "default", "Expected the specifier to be a default export"), V.propertyName && V.propertyName.text;
              });
            }
          })(N || (N = {}));
          var N;
          (function(e) {
            function t3() {
              var O = e.createScanner(99, false);
              function S(Je, qe, ge) {
                return F(te(Je, qe, ge), Je);
              }
              function te(Je, qe, ge) {
                var ie = 0, H = 0, pe = [], j = Se(qe), be = j.prefix, Xe = j.pushTemplate;
                Je = be + Je;
                var Re = be.length;
                Xe && pe.push(15), O.setText(Je);
                var Fe = 0, dr = [], ze = 0;
                do {
                  ie = O.scan(), e.isTrivia(ie) || (ar(), H = ie);
                  var ve = O.getTextPos();
                  if (q(O.getTokenPos(), ve, Re, Me(ie), dr), ve >= Je.length) {
                    var er = s(O, ie, e.lastOrUndefined(pe));
                    er !== void 0 && (Fe = er);
                  }
                } while (ie !== 1);
                function ar() {
                  switch (ie) {
                    case 43:
                    case 68:
                      !w[H] && O.reScanSlashToken() === 13 && (ie = 13);
                      break;
                    case 29:
                      H === 79 && ze++;
                      break;
                    case 31:
                      ze > 0 && ze--;
                      break;
                    case 131:
                    case 152:
                    case 148:
                    case 134:
                    case 153:
                      ze > 0 && !ge && (ie = 79);
                      break;
                    case 15:
                      pe.push(ie);
                      break;
                    case 18:
                      pe.length > 0 && pe.push(ie);
                      break;
                    case 19:
                      if (pe.length > 0) {
                        var Cr = e.lastOrUndefined(pe);
                        Cr === 15 ? (ie = O.reScanTemplateToken(false), ie === 17 ? pe.pop() : e.Debug.assertEqual(ie, 16, "Should have been a template middle.")) : (e.Debug.assertEqual(Cr, 18, "Should have been an open brace"), pe.pop());
                      }
                      break;
                    default:
                      if (!e.isKeyword(ie))
                        break;
                      (H === 24 || e.isKeyword(H) && e.isKeyword(ie) && !Ee(H, ie)) && (ie = 79);
                  }
                }
                return { endOfLineState: Fe, spans: dr };
              }
              return { getClassificationsForLine: S, getEncodedLexicalClassifications: te };
            }
            e.createClassifier = t3;
            var w = e.arrayToNumericMap([79, 10, 8, 9, 13, 108, 45, 46, 21, 23, 19, 110, 95], function(O) {
              return O;
            }, function() {
              return true;
            });
            function s(O, S, te) {
              switch (S) {
                case 10: {
                  if (!O.isUnterminated())
                    return;
                  for (var Je = O.getTokenText(), qe = Je.length - 1, ge = 0; Je.charCodeAt(qe - ge) === 92; )
                    ge++;
                  return ge & 1 ? Je.charCodeAt(0) === 34 ? 3 : 2 : void 0;
                }
                case 3:
                  return O.isUnterminated() ? 1 : void 0;
                default:
                  if (e.isTemplateLiteralKind(S)) {
                    if (!O.isUnterminated())
                      return;
                    switch (S) {
                      case 17:
                        return 5;
                      case 14:
                        return 4;
                      default:
                        return e.Debug.fail("Only 'NoSubstitutionTemplateLiteral's and 'TemplateTail's can be unterminated; got SyntaxKind #" + S);
                    }
                  }
                  return te === 15 ? 6 : void 0;
              }
            }
            function q(O, S, te, Je, qe) {
              if (Je !== 8) {
                O === 0 && te > 0 && (O += te);
                var ge = S - O;
                ge > 0 && qe.push(O - te, ge, Je);
              }
            }
            function F(O, S) {
              for (var te = [], Je = O.spans, qe = 0, ge = 0; ge < Je.length; ge += 3) {
                var ie = Je[ge], H = Je[ge + 1], pe = Je[ge + 2];
                if (qe >= 0) {
                  var j = ie - qe;
                  j > 0 && te.push({ length: j, classification: e.TokenClass.Whitespace });
                }
                te.push({ length: H, classification: fe(pe) }), qe = ie + H;
              }
              var be = S.length - qe;
              return be > 0 && te.push({ length: be, classification: e.TokenClass.Whitespace }), { entries: te, finalLexState: O.endOfLineState };
            }
            function fe(O) {
              switch (O) {
                case 1:
                  return e.TokenClass.Comment;
                case 3:
                  return e.TokenClass.Keyword;
                case 4:
                  return e.TokenClass.NumberLiteral;
                case 25:
                  return e.TokenClass.BigIntLiteral;
                case 5:
                  return e.TokenClass.Operator;
                case 6:
                  return e.TokenClass.StringLiteral;
                case 8:
                  return e.TokenClass.Whitespace;
                case 10:
                  return e.TokenClass.Punctuation;
                case 2:
                case 11:
                case 12:
                case 13:
                case 14:
                case 15:
                case 16:
                case 9:
                case 17:
                  return e.TokenClass.Identifier;
                default:
                  return;
              }
            }
            function Ee(O, S) {
              if (!e.isAccessibilityModifier(O))
                return true;
              switch (S) {
                case 137:
                case 151:
                case 135:
                case 124:
                case 127:
                  return true;
                default:
                  return false;
              }
            }
            function Se(O) {
              switch (O) {
                case 3:
                  return { prefix: `"\\
` };
                case 2:
                  return { prefix: `'\\
` };
                case 1:
                  return { prefix: `/*
` };
                case 4:
                  return { prefix: "`\n" };
                case 5:
                  return { prefix: `}
`, pushTemplate: true };
                case 6:
                  return { prefix: "", pushTemplate: true };
                case 0:
                  return { prefix: "" };
                default:
                  return e.Debug.assertNever(O);
              }
            }
            function J(O) {
              switch (O) {
                case 41:
                case 43:
                case 44:
                case 39:
                case 40:
                case 47:
                case 48:
                case 49:
                case 29:
                case 31:
                case 32:
                case 33:
                case 102:
                case 101:
                case 128:
                case 150:
                case 34:
                case 35:
                case 36:
                case 37:
                case 50:
                case 52:
                case 51:
                case 55:
                case 56:
                case 74:
                case 73:
                case 78:
                case 70:
                case 71:
                case 72:
                case 64:
                case 65:
                case 66:
                case 68:
                case 69:
                case 63:
                case 27:
                case 60:
                case 75:
                case 76:
                case 77:
                  return true;
                default:
                  return false;
              }
            }
            function se(O) {
              switch (O) {
                case 39:
                case 40:
                case 54:
                case 53:
                case 45:
                case 46:
                  return true;
                default:
                  return false;
              }
            }
            function Me(O) {
              if (e.isKeyword(O))
                return 3;
              if (J(O) || se(O))
                return 5;
              if (O >= 18 && O <= 78)
                return 10;
              switch (O) {
                case 8:
                  return 4;
                case 9:
                  return 25;
                case 10:
                  return 6;
                case 13:
                  return 7;
                case 7:
                case 3:
                case 2:
                  return 1;
                case 5:
                case 4:
                  return 8;
                case 79:
                default:
                  return e.isTemplateLiteralKind(O) ? 6 : 2;
              }
            }
            function Q(O, S, te, Je, qe) {
              return m(je(O, S, te, Je, qe));
            }
            e.getSemanticClassifications = Q;
            function Be(O, S) {
              switch (S) {
                case 264:
                case 260:
                case 261:
                case 259:
                case 228:
                case 215:
                case 216:
                  O.throwIfCancellationRequested();
              }
            }
            function je(O, S, te, Je, qe) {
              var ge = [];
              return te.forEachChild(function H(pe) {
                if (!(!pe || !e.textSpanIntersectsWith(qe, pe.pos, pe.getFullWidth()))) {
                  if (Be(S, pe.kind), e.isIdentifier(pe) && !e.nodeIsMissing(pe) && Je.has(pe.escapedText)) {
                    var j = O.getSymbolAtLocation(pe), be = j && V(j, e.getMeaningFromLocation(pe), O);
                    be && ie(pe.getStart(te), pe.getEnd(), be);
                  }
                  pe.forEachChild(H);
                }
              }), { spans: ge, endOfLineState: 0 };
              function ie(H, pe, j) {
                var be = pe - H;
                e.Debug.assert(be > 0, "Classification had non-positive length of ".concat(be)), ge.push(H), ge.push(be), ge.push(j);
              }
            }
            e.getEncodedSemanticClassifications = je;
            function V(O, S, te) {
              var Je = O.getFlags();
              if (Je & 2885600)
                return Je & 32 ? 11 : Je & 384 ? 12 : Je & 524288 ? 16 : Je & 1536 ? S & 4 || S & 1 && B(O) ? 14 : void 0 : Je & 2097152 ? V(te.getAliasedSymbol(O), S, te) : S & 2 ? Je & 64 ? 13 : Je & 262144 ? 15 : void 0 : void 0;
            }
            function B(O) {
              return e.some(O.declarations, function(S) {
                return e.isModuleDeclaration(S) && e.getModuleInstanceState(S) === 1;
              });
            }
            function U(O) {
              switch (O) {
                case 1:
                  return "comment";
                case 2:
                  return "identifier";
                case 3:
                  return "keyword";
                case 4:
                  return "number";
                case 25:
                  return "bigint";
                case 5:
                  return "operator";
                case 6:
                  return "string";
                case 8:
                  return "whitespace";
                case 9:
                  return "text";
                case 10:
                  return "punctuation";
                case 11:
                  return "class name";
                case 12:
                  return "enum name";
                case 13:
                  return "interface name";
                case 14:
                  return "module name";
                case 15:
                  return "type parameter name";
                case 16:
                  return "type alias name";
                case 17:
                  return "parameter name";
                case 18:
                  return "doc comment tag name";
                case 19:
                  return "jsx open tag name";
                case 20:
                  return "jsx close tag name";
                case 21:
                  return "jsx self closing tag name";
                case 22:
                  return "jsx attribute";
                case 23:
                  return "jsx text";
                case 24:
                  return "jsx attribute string literal value";
                default:
                  return;
              }
            }
            function m(O) {
              e.Debug.assert(O.spans.length % 3 === 0);
              for (var S = O.spans, te = [], Je = 0; Je < S.length; Je += 3)
                te.push({ textSpan: e.createTextSpan(S[Je], S[Je + 1]), classificationType: U(S[Je + 2]) });
              return te;
            }
            function v(O, S, te) {
              return m(g(O, S, te));
            }
            e.getSyntacticClassifications = v;
            function g(O, S, te) {
              var Je = te.start, qe = te.length, ge = e.createScanner(99, false, S.languageVariant, S.text), ie = e.createScanner(99, false, S.languageVariant, S.text), H = [];
              return Ce(S), { spans: H, endOfLineState: 0 };
              function pe($e, gr, X) {
                H.push($e), H.push(gr), H.push(X);
              }
              function j($e) {
                for (ge.setTextPos($e.pos); ; ) {
                  var gr = ge.getTextPos();
                  if (!e.couldStartTrivia(S.text, gr))
                    return gr;
                  var X = ge.scan(), Te = ge.getTextPos(), we = Te - gr;
                  if (!e.isTrivia(X))
                    return gr;
                  switch (X) {
                    case 4:
                    case 5:
                      continue;
                    case 2:
                    case 3:
                      be($e, X, gr, we), ge.setTextPos(Te);
                      continue;
                    case 7:
                      var he = S.text, yr = he.charCodeAt(gr);
                      if (yr === 60 || yr === 62) {
                        pe(gr, we, 1);
                        continue;
                      }
                      e.Debug.assert(yr === 124 || yr === 61), ze(he, gr, Te);
                      break;
                    case 6:
                      break;
                    default:
                      e.Debug.assertNever(X);
                  }
                }
              }
              function be($e, gr, X, Te) {
                if (gr === 3) {
                  var we = e.parseIsolatedJSDocComment(S.text, X, Te);
                  if (we && we.jsDoc) {
                    e.setParent(we.jsDoc, $e), Re(we.jsDoc);
                    return;
                  }
                } else if (gr === 2 && Fe(X, Te))
                  return;
                Xe(X, Te);
              }
              function Xe($e, gr) {
                pe($e, gr, 1);
              }
              function Re($e) {
                var gr, X, Te, we, he, yr, kr, nr = $e.pos;
                if ($e.tags)
                  for (var tr = 0, Lr = $e.tags; tr < Lr.length; tr++) {
                    var zr = Lr[tr];
                    zr.pos !== nr && Xe(nr, zr.pos - nr), pe(zr.pos, 1, 10), pe(zr.tagName.pos, zr.tagName.end - zr.tagName.pos, 18), nr = zr.tagName.end;
                    var ye = zr.tagName.end;
                    switch (zr.kind) {
                      case 343:
                        var ir = zr;
                        Br(ir), ye = ir.isNameFirst && ((gr = ir.typeExpression) === null || gr === void 0 ? void 0 : gr.end) || ir.name.end;
                        break;
                      case 350:
                        var Dr = zr;
                        ye = Dr.isNameFirst && ((X = Dr.typeExpression) === null || X === void 0 ? void 0 : X.end) || Dr.name.end;
                        break;
                      case 347:
                        dr(zr), nr = zr.end, ye = zr.typeParameters.end;
                        break;
                      case 348:
                        var Pr = zr;
                        ye = ((Te = Pr.typeExpression) === null || Te === void 0 ? void 0 : Te.kind) === 312 && ((we = Pr.fullName) === null || we === void 0 ? void 0 : we.end) || ((he = Pr.typeExpression) === null || he === void 0 ? void 0 : he.end) || ye;
                        break;
                      case 341:
                        ye = zr.typeExpression.end;
                        break;
                      case 346:
                        Ce(zr.typeExpression), nr = zr.end, ye = zr.typeExpression.end;
                        break;
                      case 345:
                      case 342:
                        ye = zr.typeExpression.end;
                        break;
                      case 344:
                        Ce(zr.typeExpression), nr = zr.end, ye = ((yr = zr.typeExpression) === null || yr === void 0 ? void 0 : yr.end) || ye;
                        break;
                      case 349:
                        ye = ((kr = zr.name) === null || kr === void 0 ? void 0 : kr.end) || ye;
                        break;
                      case 331:
                      case 332:
                        ye = zr.class.end;
                        break;
                    }
                    typeof zr.comment == "object" ? Xe(zr.comment.pos, zr.comment.end - zr.comment.pos) : typeof zr.comment == "string" && Xe(ye, zr.end - ye);
                  }
                nr !== $e.end && Xe(nr, $e.end - nr);
                return;
                function Br(ut) {
                  ut.isNameFirst && (Xe(nr, ut.name.pos - nr), pe(ut.name.pos, ut.name.end - ut.name.pos, 17), nr = ut.name.end), ut.typeExpression && (Xe(nr, ut.typeExpression.pos - nr), Ce(ut.typeExpression), nr = ut.typeExpression.end), ut.isNameFirst || (Xe(nr, ut.name.pos - nr), pe(ut.name.pos, ut.name.end - ut.name.pos, 17), nr = ut.name.end);
                }
              }
              function Fe($e, gr) {
                var X = /^(\/\/\/\s*)(<)(?:(\S+)((?:[^/]|\/[^>])*)(\/>)?)?/im, Te = /(\s)(\S+)(\s*)(=)(\s*)('[^']+'|"[^"]+")/img, we = S.text.substr($e, gr), he = X.exec(we);
                if (!he || !he[3] || !(he[3] in e.commentPragmas))
                  return false;
                var yr = $e;
                Xe(yr, he[1].length), yr += he[1].length, pe(yr, he[2].length, 10), yr += he[2].length, pe(yr, he[3].length, 21), yr += he[3].length;
                for (var kr = he[4], nr = yr; ; ) {
                  var tr = Te.exec(kr);
                  if (!tr)
                    break;
                  var Lr = yr + tr.index + tr[1].length;
                  Lr > nr && (Xe(nr, Lr - nr), nr = Lr), pe(nr, tr[2].length, 22), nr += tr[2].length, tr[3].length && (Xe(nr, tr[3].length), nr += tr[3].length), pe(nr, tr[4].length, 5), nr += tr[4].length, tr[5].length && (Xe(nr, tr[5].length), nr += tr[5].length), pe(nr, tr[6].length, 24), nr += tr[6].length;
                }
                yr += he[4].length, yr > nr && Xe(nr, yr - nr), he[5] && (pe(yr, he[5].length, 10), yr += he[5].length);
                var zr = $e + gr;
                return yr < zr && Xe(yr, zr - yr), true;
              }
              function dr($e) {
                for (var gr = 0, X = $e.getChildren(); gr < X.length; gr++) {
                  var Te = X[gr];
                  Ce(Te);
                }
              }
              function ze($e, gr, X) {
                var Te;
                for (Te = gr; Te < X && !e.isLineBreak($e.charCodeAt(Te)); Te++)
                  ;
                for (pe(gr, Te - gr, 1), ie.setTextPos(Te); ie.getTextPos() < X; )
                  ve();
              }
              function ve() {
                var $e = ie.getTextPos(), gr = ie.scan(), X = ie.getTextPos(), Te = Cr(gr);
                Te && pe($e, X - $e, Te);
              }
              function er($e) {
                if (e.isJSDoc($e) || e.nodeIsMissing($e))
                  return true;
                var gr = ar($e);
                if (!e.isToken($e) && $e.kind !== 11 && gr === void 0)
                  return false;
                var X = $e.kind === 11 ? $e.pos : j($e), Te = $e.end - X;
                if (e.Debug.assert(Te >= 0), Te > 0) {
                  var we = gr || Cr($e.kind, $e);
                  we && pe(X, Te, we);
                }
                return true;
              }
              function ar($e) {
                switch ($e.parent && $e.parent.kind) {
                  case 283:
                    if ($e.parent.tagName === $e)
                      return 19;
                    break;
                  case 284:
                    if ($e.parent.tagName === $e)
                      return 20;
                    break;
                  case 282:
                    if ($e.parent.tagName === $e)
                      return 21;
                    break;
                  case 288:
                    if ($e.parent.name === $e)
                      return 22;
                    break;
                }
              }
              function Cr($e, gr) {
                if (e.isKeyword($e))
                  return 3;
                if (($e === 29 || $e === 31) && gr && e.getTypeArgumentOrTypeParameterList(gr.parent))
                  return 10;
                if (e.isPunctuation($e)) {
                  if (gr) {
                    var X = gr.parent;
                    if ($e === 63 && (X.kind === 257 || X.kind === 169 || X.kind === 166 || X.kind === 288) || X.kind === 223 || X.kind === 221 || X.kind === 222 || X.kind === 224)
                      return 5;
                  }
                  return 10;
                } else {
                  if ($e === 8)
                    return 4;
                  if ($e === 9)
                    return 25;
                  if ($e === 10)
                    return gr && gr.parent.kind === 288 ? 24 : 6;
                  if ($e === 13)
                    return 6;
                  if (e.isTemplateLiteralKind($e))
                    return 6;
                  if ($e === 11)
                    return 23;
                  if ($e === 79) {
                    if (gr) {
                      switch (gr.parent.kind) {
                        case 260:
                          return gr.parent.name === gr ? 11 : void 0;
                        case 165:
                          return gr.parent.name === gr ? 15 : void 0;
                        case 261:
                          return gr.parent.name === gr ? 13 : void 0;
                        case 263:
                          return gr.parent.name === gr ? 12 : void 0;
                        case 264:
                          return gr.parent.name === gr ? 14 : void 0;
                        case 166:
                          return gr.parent.name === gr ? e.isThisIdentifier(gr) ? 3 : 17 : void 0;
                      }
                      if (e.isConstTypeReference(gr.parent))
                        return 3;
                    }
                    return 2;
                  }
                }
              }
              function Ce($e) {
                if ($e && e.decodedTextSpanIntersectsWith(Je, qe, $e.pos, $e.getFullWidth())) {
                  Be(O, $e.kind);
                  for (var gr = 0, X = $e.getChildren(S); gr < X.length; gr++) {
                    var Te = X[gr];
                    er(Te) || Ce(Te);
                  }
                }
              }
            }
            e.getEncodedSyntacticClassifications = g;
          })(N || (N = {}));
          var N;
          (function(e) {
            var t3;
            (function(w) {
              var s;
              (function(q) {
                var F;
                (function(g) {
                  g[g.typeOffset = 8] = "typeOffset", g[g.modifierMask = 255] = "modifierMask";
                })(F = q.TokenEncodingConsts || (q.TokenEncodingConsts = {}));
                var fe;
                (function(g) {
                  g[g.class = 0] = "class", g[g.enum = 1] = "enum", g[g.interface = 2] = "interface", g[g.namespace = 3] = "namespace", g[g.typeParameter = 4] = "typeParameter", g[g.type = 5] = "type", g[g.parameter = 6] = "parameter", g[g.variable = 7] = "variable", g[g.enumMember = 8] = "enumMember", g[g.property = 9] = "property", g[g.function = 10] = "function", g[g.member = 11] = "member";
                })(fe = q.TokenType || (q.TokenType = {}));
                var Ee;
                (function(g) {
                  g[g.declaration = 0] = "declaration", g[g.static = 1] = "static", g[g.async = 2] = "async", g[g.readonly = 3] = "readonly", g[g.defaultLibrary = 4] = "defaultLibrary", g[g.local = 5] = "local";
                })(Ee = q.TokenModifier || (q.TokenModifier = {}));
                function Se(g, O, S, te) {
                  var Je = J(g, O, S, te);
                  e.Debug.assert(Je.spans.length % 3 === 0);
                  for (var qe = Je.spans, ge = [], ie = 0; ie < qe.length; ie += 3)
                    ge.push({ textSpan: e.createTextSpan(qe[ie], qe[ie + 1]), classificationType: qe[ie + 2] });
                  return ge;
                }
                q.getSemanticClassifications = Se;
                function J(g, O, S, te) {
                  return { spans: se(g, S, te, O), endOfLineState: 0 };
                }
                q.getEncodedSemanticClassifications = J;
                function se(g, O, S, te) {
                  var Je = [], qe = function(ge, ie, H) {
                    Je.push(ge.getStart(O), ge.getWidth(O), (ie + 1 << 8) + H);
                  };
                  return g && O && Me(g, O, S, qe, te), Je;
                }
                function Me(g, O, S, te, Je) {
                  var qe = g.getTypeChecker(), ge = false;
                  function ie(H) {
                    switch (H.kind) {
                      case 264:
                      case 260:
                      case 261:
                      case 259:
                      case 228:
                      case 215:
                      case 216:
                        Je.throwIfCancellationRequested();
                    }
                    if (!(!H || !e.textSpanIntersectsWith(S, H.pos, H.getFullWidth()) || H.getFullWidth() === 0)) {
                      var pe = ge;
                      if ((e.isJsxElement(H) || e.isJsxSelfClosingElement(H)) && (ge = true), e.isJsxExpression(H) && (ge = false), e.isIdentifier(H) && !ge && !B(H) && !e.isInfinityOrNaNString(H.escapedText)) {
                        var j = qe.getSymbolAtLocation(H);
                        if (j) {
                          j.flags & 2097152 && (j = qe.getAliasedSymbol(j));
                          var be = Q(j, e.getMeaningFromLocation(H));
                          if (be !== void 0) {
                            var Xe = 0;
                            if (H.parent) {
                              var Re = e.isBindingElement(H.parent) || v.get(H.parent.kind) === be;
                              Re && H.parent.name === H && (Xe = 1 << 0);
                            }
                            be === 6 && m(H) && (be = 9), be = Be(qe, H, be);
                            var Fe = j.valueDeclaration;
                            if (Fe) {
                              var dr = e.getCombinedModifierFlags(Fe), ze = e.getCombinedNodeFlags(Fe);
                              dr & 32 && (Xe |= 1 << 1), dr & 512 && (Xe |= 1 << 2), be !== 0 && be !== 2 && (dr & 64 || ze & 2 || j.getFlags() & 8) && (Xe |= 1 << 3), (be === 7 || be === 10) && je(Fe, O) && (Xe |= 1 << 5), g.isSourceFileDefaultLibrary(Fe.getSourceFile()) && (Xe |= 1 << 4);
                            } else
                              j.declarations && j.declarations.some(function(ve) {
                                return g.isSourceFileDefaultLibrary(ve.getSourceFile());
                              }) && (Xe |= 1 << 4);
                            te(H, be, Xe);
                          }
                        }
                      }
                      e.forEachChild(H, ie), ge = pe;
                    }
                  }
                  ie(O);
                }
                function Q(g, O) {
                  var S = g.getFlags();
                  if (S & 32)
                    return 0;
                  if (S & 384)
                    return 1;
                  if (S & 524288)
                    return 5;
                  if (S & 64) {
                    if (O & 2)
                      return 2;
                  } else if (S & 262144)
                    return 4;
                  var te = g.valueDeclaration || g.declarations && g.declarations[0];
                  return te && e.isBindingElement(te) && (te = V(te)), te && v.get(te.kind);
                }
                function Be(g, O, S) {
                  if (S === 7 || S === 9 || S === 6) {
                    var te = g.getTypeAtLocation(O);
                    if (te) {
                      var Je = function(qe) {
                        return qe(te) || te.isUnion() && te.types.some(qe);
                      };
                      if (S !== 6 && Je(function(qe) {
                        return qe.getConstructSignatures().length > 0;
                      }))
                        return 0;
                      if (Je(function(qe) {
                        return qe.getCallSignatures().length > 0;
                      }) && !Je(function(qe) {
                        return qe.getProperties().length > 0;
                      }) || U(O))
                        return S === 9 ? 11 : 10;
                    }
                  }
                  return S;
                }
                function je(g, O) {
                  return e.isBindingElement(g) && (g = V(g)), e.isVariableDeclaration(g) ? (!e.isSourceFile(g.parent.parent.parent) || e.isCatchClause(g.parent)) && g.getSourceFile() === O : e.isFunctionDeclaration(g) ? !e.isSourceFile(g.parent) && g.getSourceFile() === O : false;
                }
                function V(g) {
                  for (; ; )
                    if (e.isBindingElement(g.parent.parent))
                      g = g.parent.parent;
                    else
                      return g.parent.parent;
                }
                function B(g) {
                  var O = g.parent;
                  return O && (e.isImportClause(O) || e.isImportSpecifier(O) || e.isNamespaceImport(O));
                }
                function U(g) {
                  for (; m(g); )
                    g = g.parent;
                  return e.isCallExpression(g.parent) && g.parent.expression === g;
                }
                function m(g) {
                  return e.isQualifiedName(g.parent) && g.parent.right === g || e.isPropertyAccessExpression(g.parent) && g.parent.name === g;
                }
                var v = new e.Map([[257, 7], [166, 6], [169, 9], [264, 3], [263, 1], [302, 8], [260, 0], [171, 11], [259, 10], [215, 10], [170, 11], [174, 9], [175, 9], [168, 9], [261, 2], [262, 5], [165, 4], [299, 9], [300, 9]]);
              })(s = w.v2020 || (w.v2020 = {}));
            })(t3 = e.classifier || (e.classifier = {}));
          })(N || (N = {}));
          var N;
          (function(e) {
            e.servicesVersion = "0.8";
            function t3(X, Te, we, he) {
              var yr = e.isNodeKind(X) ? new w(X, Te, we) : X === 79 ? new J(79, Te, we) : X === 80 ? new se(80, Te, we) : new Se(X, Te, we);
              return yr.parent = he, yr.flags = he.flags & 50720768, yr;
            }
            var w = function() {
              function X(Te, we, he) {
                this.pos = we, this.end = he, this.flags = 0, this.modifierFlagsCache = 0, this.transformFlags = 0, this.parent = void 0, this.kind = Te;
              }
              return X.prototype.assertHasRealPosition = function(Te) {
                e.Debug.assert(!e.positionIsSynthesized(this.pos) && !e.positionIsSynthesized(this.end), Te || "Node must have a real position for this operation");
              }, X.prototype.getSourceFile = function() {
                return e.getSourceFileOfNode(this);
              }, X.prototype.getStart = function(Te, we) {
                return this.assertHasRealPosition(), e.getTokenPosOfNode(this, Te, we);
              }, X.prototype.getFullStart = function() {
                return this.assertHasRealPosition(), this.pos;
              }, X.prototype.getEnd = function() {
                return this.assertHasRealPosition(), this.end;
              }, X.prototype.getWidth = function(Te) {
                return this.assertHasRealPosition(), this.getEnd() - this.getStart(Te);
              }, X.prototype.getFullWidth = function() {
                return this.assertHasRealPosition(), this.end - this.pos;
              }, X.prototype.getLeadingTriviaWidth = function(Te) {
                return this.assertHasRealPosition(), this.getStart(Te) - this.pos;
              }, X.prototype.getFullText = function(Te) {
                return this.assertHasRealPosition(), (Te || this.getSourceFile()).text.substring(this.pos, this.end);
              }, X.prototype.getText = function(Te) {
                return this.assertHasRealPosition(), Te || (Te = this.getSourceFile()), Te.text.substring(this.getStart(Te), this.getEnd());
              }, X.prototype.getChildCount = function(Te) {
                return this.getChildren(Te).length;
              }, X.prototype.getChildAt = function(Te, we) {
                return this.getChildren(we)[Te];
              }, X.prototype.getChildren = function(Te) {
                return this.assertHasRealPosition("Node without a real position cannot be scanned and thus has no token nodes - use forEachChild and collect the result if that's fine"), this._children || (this._children = s(this, Te));
              }, X.prototype.getFirstToken = function(Te) {
                this.assertHasRealPosition();
                var we = this.getChildren(Te);
                if (we.length) {
                  var he = e.find(we, function(yr) {
                    return yr.kind < 312 || yr.kind > 350;
                  });
                  return he.kind < 163 ? he : he.getFirstToken(Te);
                }
              }, X.prototype.getLastToken = function(Te) {
                this.assertHasRealPosition();
                var we = this.getChildren(Te), he = e.lastOrUndefined(we);
                if (he)
                  return he.kind < 163 ? he : he.getLastToken(Te);
              }, X.prototype.forEachChild = function(Te, we) {
                return e.forEachChild(this, Te, we);
              }, X;
            }();
            function s(X, Te) {
              if (!e.isNodeKind(X.kind))
                return e.emptyArray;
              var we = [];
              if (e.isJSDocCommentContainingNode(X))
                return X.forEachChild(function(nr) {
                  we.push(nr);
                }), we;
              e.scanner.setText((Te || X.getSourceFile()).text);
              var he = X.pos, yr = function(nr) {
                q(we, he, nr.pos, X), we.push(nr), he = nr.end;
              }, kr = function(nr) {
                q(we, he, nr.pos, X), we.push(F(nr, X)), he = nr.end;
              };
              return e.forEach(X.jsDoc, yr), he = X.pos, X.forEachChild(yr, kr), q(we, he, X.end, X), e.scanner.setText(void 0), we;
            }
            function q(X, Te, we, he) {
              for (e.scanner.setTextPos(Te); Te < we; ) {
                var yr = e.scanner.scan(), kr = e.scanner.getTextPos();
                if (kr <= we && (yr === 79 && e.Debug.fail("Did not expect ".concat(e.Debug.formatSyntaxKind(he.kind), " to have an Identifier in its trivia")), X.push(t3(yr, Te, kr, he))), Te = kr, yr === 1)
                  break;
              }
            }
            function F(X, Te) {
              var we = t3(351, X.pos, X.end, Te);
              we._children = [];
              for (var he = X.pos, yr = 0, kr = X; yr < kr.length; yr++) {
                var nr = kr[yr];
                q(we._children, he, nr.pos, Te), we._children.push(nr), he = nr.end;
              }
              return q(we._children, he, X.end, Te), we;
            }
            var fe = function() {
              function X(Te, we) {
                this.pos = Te, this.end = we, this.flags = 0, this.modifierFlagsCache = 0, this.transformFlags = 0, this.parent = void 0;
              }
              return X.prototype.getSourceFile = function() {
                return e.getSourceFileOfNode(this);
              }, X.prototype.getStart = function(Te, we) {
                return e.getTokenPosOfNode(this, Te, we);
              }, X.prototype.getFullStart = function() {
                return this.pos;
              }, X.prototype.getEnd = function() {
                return this.end;
              }, X.prototype.getWidth = function(Te) {
                return this.getEnd() - this.getStart(Te);
              }, X.prototype.getFullWidth = function() {
                return this.end - this.pos;
              }, X.prototype.getLeadingTriviaWidth = function(Te) {
                return this.getStart(Te) - this.pos;
              }, X.prototype.getFullText = function(Te) {
                return (Te || this.getSourceFile()).text.substring(this.pos, this.end);
              }, X.prototype.getText = function(Te) {
                return Te || (Te = this.getSourceFile()), Te.text.substring(this.getStart(Te), this.getEnd());
              }, X.prototype.getChildCount = function() {
                return this.getChildren().length;
              }, X.prototype.getChildAt = function(Te) {
                return this.getChildren()[Te];
              }, X.prototype.getChildren = function() {
                return this.kind === 1 && this.jsDoc || e.emptyArray;
              }, X.prototype.getFirstToken = function() {
              }, X.prototype.getLastToken = function() {
              }, X.prototype.forEachChild = function() {
              }, X;
            }(), Ee = function() {
              function X(Te, we) {
                this.flags = Te, this.escapedName = we;
              }
              return X.prototype.getFlags = function() {
                return this.flags;
              }, Object.defineProperty(X.prototype, "name", { get: function() {
                return e.symbolName(this);
              }, enumerable: false, configurable: true }), X.prototype.getEscapedName = function() {
                return this.escapedName;
              }, X.prototype.getName = function() {
                return this.name;
              }, X.prototype.getDeclarations = function() {
                return this.declarations;
              }, X.prototype.getDocumentationComment = function(Te) {
                if (!this.documentationComment)
                  if (this.documentationComment = e.emptyArray, !this.declarations && this.target && this.target.tupleLabelDeclaration) {
                    var we = this.target.tupleLabelDeclaration;
                    this.documentationComment = V([we], Te);
                  } else
                    this.documentationComment = V(this.declarations, Te);
                return this.documentationComment;
              }, X.prototype.getContextualDocumentationComment = function(Te, we) {
                if (Te) {
                  if (e.isGetAccessor(Te) && (this.contextualGetAccessorDocumentationComment || (this.contextualGetAccessorDocumentationComment = V(e.filter(this.declarations, e.isGetAccessor), we)), e.length(this.contextualGetAccessorDocumentationComment)))
                    return this.contextualGetAccessorDocumentationComment;
                  if (e.isSetAccessor(Te) && (this.contextualSetAccessorDocumentationComment || (this.contextualSetAccessorDocumentationComment = V(e.filter(this.declarations, e.isSetAccessor), we)), e.length(this.contextualSetAccessorDocumentationComment)))
                    return this.contextualSetAccessorDocumentationComment;
                }
                return this.getDocumentationComment(we);
              }, X.prototype.getJsDocTags = function(Te) {
                return this.tags === void 0 && (this.tags = je(this.declarations, Te)), this.tags;
              }, X.prototype.getContextualJsDocTags = function(Te, we) {
                if (Te) {
                  if (e.isGetAccessor(Te) && (this.contextualGetAccessorTags || (this.contextualGetAccessorTags = je(e.filter(this.declarations, e.isGetAccessor), we)), e.length(this.contextualGetAccessorTags)))
                    return this.contextualGetAccessorTags;
                  if (e.isSetAccessor(Te) && (this.contextualSetAccessorTags || (this.contextualSetAccessorTags = je(e.filter(this.declarations, e.isSetAccessor), we)), e.length(this.contextualSetAccessorTags)))
                    return this.contextualSetAccessorTags;
                }
                return this.getJsDocTags(we);
              }, X;
            }(), Se = function(X) {
              E(Te, X);
              function Te(we, he, yr) {
                var kr = X.call(this, he, yr) || this;
                return kr.kind = we, kr;
              }
              return Te;
            }(fe), J = function(X) {
              E(Te, X);
              function Te(we, he, yr) {
                var kr = X.call(this, he, yr) || this;
                return kr.kind = 79, kr;
              }
              return Object.defineProperty(Te.prototype, "text", { get: function() {
                return e.idText(this);
              }, enumerable: false, configurable: true }), Te;
            }(fe);
            J.prototype.kind = 79;
            var se = function(X) {
              E(Te, X);
              function Te(we, he, yr) {
                return X.call(this, he, yr) || this;
              }
              return Object.defineProperty(Te.prototype, "text", { get: function() {
                return e.idText(this);
              }, enumerable: false, configurable: true }), Te;
            }(fe);
            se.prototype.kind = 80;
            var Me = function() {
              function X(Te, we) {
                this.checker = Te, this.flags = we;
              }
              return X.prototype.getFlags = function() {
                return this.flags;
              }, X.prototype.getSymbol = function() {
                return this.symbol;
              }, X.prototype.getProperties = function() {
                return this.checker.getPropertiesOfType(this);
              }, X.prototype.getProperty = function(Te) {
                return this.checker.getPropertyOfType(this, Te);
              }, X.prototype.getApparentProperties = function() {
                return this.checker.getAugmentedPropertiesOfType(this);
              }, X.prototype.getCallSignatures = function() {
                return this.checker.getSignaturesOfType(this, 0);
              }, X.prototype.getConstructSignatures = function() {
                return this.checker.getSignaturesOfType(this, 1);
              }, X.prototype.getStringIndexType = function() {
                return this.checker.getIndexTypeOfType(this, 0);
              }, X.prototype.getNumberIndexType = function() {
                return this.checker.getIndexTypeOfType(this, 1);
              }, X.prototype.getBaseTypes = function() {
                return this.isClassOrInterface() ? this.checker.getBaseTypes(this) : void 0;
              }, X.prototype.isNullableType = function() {
                return this.checker.isNullableType(this);
              }, X.prototype.getNonNullableType = function() {
                return this.checker.getNonNullableType(this);
              }, X.prototype.getNonOptionalType = function() {
                return this.checker.getNonOptionalType(this);
              }, X.prototype.getConstraint = function() {
                return this.checker.getBaseConstraintOfType(this);
              }, X.prototype.getDefault = function() {
                return this.checker.getDefaultFromTypeParameter(this);
              }, X.prototype.isUnion = function() {
                return !!(this.flags & 1048576);
              }, X.prototype.isIntersection = function() {
                return !!(this.flags & 2097152);
              }, X.prototype.isUnionOrIntersection = function() {
                return !!(this.flags & 3145728);
              }, X.prototype.isLiteral = function() {
                return !!(this.flags & 384);
              }, X.prototype.isStringLiteral = function() {
                return !!(this.flags & 128);
              }, X.prototype.isNumberLiteral = function() {
                return !!(this.flags & 256);
              }, X.prototype.isTypeParameter = function() {
                return !!(this.flags & 262144);
              }, X.prototype.isClassOrInterface = function() {
                return !!(e.getObjectFlags(this) & 3);
              }, X.prototype.isClass = function() {
                return !!(e.getObjectFlags(this) & 1);
              }, X.prototype.isIndexType = function() {
                return !!(this.flags & 4194304);
              }, Object.defineProperty(X.prototype, "typeArguments", { get: function() {
                if (e.getObjectFlags(this) & 4)
                  return this.checker.getTypeArguments(this);
              }, enumerable: false, configurable: true }), X;
            }(), Q = function() {
              function X(Te, we) {
                this.checker = Te, this.flags = we;
              }
              return X.prototype.getDeclaration = function() {
                return this.declaration;
              }, X.prototype.getTypeParameters = function() {
                return this.typeParameters;
              }, X.prototype.getParameters = function() {
                return this.parameters;
              }, X.prototype.getReturnType = function() {
                return this.checker.getReturnTypeOfSignature(this);
              }, X.prototype.getTypeParameterAtPosition = function(Te) {
                var we = this.checker.getParameterType(this, Te);
                if (we.isIndexType() && e.isThisTypeParameter(we.type)) {
                  var he = we.type.getConstraint();
                  if (he)
                    return this.checker.getIndexType(he);
                }
                return we;
              }, X.prototype.getDocumentationComment = function() {
                return this.documentationComment || (this.documentationComment = V(e.singleElementArray(this.declaration), this.checker));
              }, X.prototype.getJsDocTags = function() {
                return this.jsDocTags || (this.jsDocTags = je(e.singleElementArray(this.declaration), this.checker));
              }, X;
            }();
            function Be(X) {
              return e.getJSDocTags(X).some(function(Te) {
                return Te.tagName.text === "inheritDoc" || Te.tagName.text === "inheritdoc";
              });
            }
            function je(X, Te) {
              if (!X)
                return e.emptyArray;
              var we = e.JsDoc.getJsDocTagsFromDeclarations(X, Te);
              if (Te && (we.length === 0 || X.some(Be)))
                for (var he = new e.Set(), yr = function(Lr) {
                  var zr = B(Te, Lr, function(ye) {
                    var ir;
                    if (!he.has(ye))
                      return he.add(ye), Lr.kind === 174 || Lr.kind === 175 ? ye.getContextualJsDocTags(Lr, Te) : ((ir = ye.declarations) === null || ir === void 0 ? void 0 : ir.length) === 1 ? ye.getJsDocTags() : void 0;
                  });
                  zr && (we = D(D([], zr, true), we, true));
                }, kr = 0, nr = X; kr < nr.length; kr++) {
                  var tr = nr[kr];
                  yr(tr);
                }
              return we;
            }
            function V(X, Te) {
              if (!X)
                return e.emptyArray;
              var we = e.JsDoc.getJsDocCommentsFromDeclarations(X, Te);
              if (Te && (we.length === 0 || X.some(Be)))
                for (var he = new e.Set(), yr = function(Lr) {
                  var zr = B(Te, Lr, function(ye) {
                    if (!he.has(ye))
                      return he.add(ye), Lr.kind === 174 || Lr.kind === 175 ? ye.getContextualDocumentationComment(Lr, Te) : ye.getDocumentationComment(Te);
                  });
                  zr && (we = we.length === 0 ? zr.slice() : zr.concat(e.lineBreakPart(), we));
                }, kr = 0, nr = X; kr < nr.length; kr++) {
                  var tr = nr[kr];
                  yr(tr);
                }
              return we;
            }
            function B(X, Te, we) {
              var he, yr = ((he = Te.parent) === null || he === void 0 ? void 0 : he.kind) === 173 ? Te.parent.parent : Te.parent;
              if (yr) {
                var kr = e.hasStaticModifier(Te);
                return e.firstDefined(e.getAllSuperTypeNodes(yr), function(nr) {
                  var tr = X.getTypeAtLocation(nr), Lr = kr && tr.symbol ? X.getTypeOfSymbol(tr.symbol) : tr, zr = X.getPropertyOfType(Lr, Te.symbol.name);
                  return zr ? we(zr) : void 0;
                });
              }
            }
            var U = function(X) {
              E(Te, X);
              function Te(we, he, yr) {
                var kr = X.call(this, we, he, yr) || this;
                return kr.kind = 308, kr;
              }
              return Te.prototype.update = function(we, he) {
                return e.updateSourceFile(this, we, he);
              }, Te.prototype.getLineAndCharacterOfPosition = function(we) {
                return e.getLineAndCharacterOfPosition(this, we);
              }, Te.prototype.getLineStarts = function() {
                return e.getLineStarts(this);
              }, Te.prototype.getPositionOfLineAndCharacter = function(we, he, yr) {
                return e.computePositionOfLineAndCharacter(e.getLineStarts(this), we, he, this.text, yr);
              }, Te.prototype.getLineEndOfPosition = function(we) {
                var he = this.getLineAndCharacterOfPosition(we).line, yr = this.getLineStarts(), kr;
                he + 1 >= yr.length && (kr = this.getEnd()), kr || (kr = yr[he + 1] - 1);
                var nr = this.getFullText();
                return nr[kr] === `
` && nr[kr - 1] === "\r" ? kr - 1 : kr;
              }, Te.prototype.getNamedDeclarations = function() {
                return this.namedDeclarations || (this.namedDeclarations = this.computeNamedDeclarations()), this.namedDeclarations;
              }, Te.prototype.computeNamedDeclarations = function() {
                var we = e.createMultiMap();
                return this.forEachChild(nr), we;
                function he(tr) {
                  var Lr = kr(tr);
                  Lr && we.add(Lr, tr);
                }
                function yr(tr) {
                  var Lr = we.get(tr);
                  return Lr || we.set(tr, Lr = []), Lr;
                }
                function kr(tr) {
                  var Lr = e.getNonAssignedNameOfDeclaration(tr);
                  return Lr && (e.isComputedPropertyName(Lr) && e.isPropertyAccessExpression(Lr.expression) ? Lr.expression.name.text : e.isPropertyName(Lr) ? e.getNameFromPropertyName(Lr) : void 0);
                }
                function nr(tr) {
                  switch (tr.kind) {
                    case 259:
                    case 215:
                    case 171:
                    case 170:
                      var Lr = tr, zr = kr(Lr);
                      if (zr) {
                        var ye = yr(zr), ir = e.lastOrUndefined(ye);
                        ir && Lr.parent === ir.parent && Lr.symbol === ir.symbol ? Lr.body && !ir.body && (ye[ye.length - 1] = Lr) : ye.push(Lr);
                      }
                      e.forEachChild(tr, nr);
                      break;
                    case 260:
                    case 228:
                    case 261:
                    case 262:
                    case 263:
                    case 264:
                    case 268:
                    case 278:
                    case 273:
                    case 270:
                    case 271:
                    case 174:
                    case 175:
                    case 184:
                      he(tr), e.forEachChild(tr, nr);
                      break;
                    case 166:
                      if (!e.hasSyntacticModifier(tr, 16476))
                        break;
                    case 257:
                    case 205: {
                      var Dr = tr;
                      if (e.isBindingPattern(Dr.name)) {
                        e.forEachChild(Dr.name, nr);
                        break;
                      }
                      Dr.initializer && nr(Dr.initializer);
                    }
                    case 302:
                    case 169:
                    case 168:
                      he(tr);
                      break;
                    case 275:
                      var Pr = tr;
                      Pr.exportClause && (e.isNamedExports(Pr.exportClause) ? e.forEach(Pr.exportClause.elements, nr) : nr(Pr.exportClause.name));
                      break;
                    case 269:
                      var Br = tr.importClause;
                      Br && (Br.name && he(Br.name), Br.namedBindings && (Br.namedBindings.kind === 271 ? he(Br.namedBindings) : e.forEach(Br.namedBindings.elements, nr)));
                      break;
                    case 223:
                      e.getAssignmentDeclarationKind(tr) !== 0 && he(tr);
                    default:
                      e.forEachChild(tr, nr);
                  }
                }
              }, Te;
            }(w), m = function() {
              function X(Te, we, he) {
                this.fileName = Te, this.text = we, this.skipTrivia = he;
              }
              return X.prototype.getLineAndCharacterOfPosition = function(Te) {
                return e.getLineAndCharacterOfPosition(this, Te);
              }, X;
            }();
            function v() {
              return { getNodeConstructor: function() {
                return w;
              }, getTokenConstructor: function() {
                return Se;
              }, getIdentifierConstructor: function() {
                return J;
              }, getPrivateIdentifierConstructor: function() {
                return se;
              }, getSourceFileConstructor: function() {
                return U;
              }, getSymbolConstructor: function() {
                return Ee;
              }, getTypeConstructor: function() {
                return Me;
              }, getSignatureConstructor: function() {
                return Q;
              }, getSourceMapSourceConstructor: function() {
                return m;
              } };
            }
            function g(X) {
              var Te = true;
              for (var we in X)
                if (e.hasProperty(X, we) && !O(we)) {
                  Te = false;
                  break;
                }
              if (Te)
                return X;
              var he = {};
              for (var we in X)
                if (e.hasProperty(X, we)) {
                  var yr = O(we) ? we : we.charAt(0).toLowerCase() + we.substr(1);
                  he[yr] = X[we];
                }
              return he;
            }
            e.toEditorSettings = g;
            function O(X) {
              return !X.length || X.charAt(0) === X.charAt(0).toLowerCase();
            }
            function S(X) {
              return X ? e.map(X, function(Te) {
                return Te.text;
              }).join("") : "";
            }
            e.displayPartsToString = S;
            function te() {
              return { target: 1, jsx: 1 };
            }
            e.getDefaultCompilerOptions = te;
            function Je() {
              return e.codefix.getSupportedErrorCodes();
            }
            e.getSupportedCodeFixes = Je;
            var qe = function() {
              function X(Te) {
                this.host = Te;
              }
              return X.prototype.getCurrentSourceFile = function(Te) {
                var we, he, yr, kr, nr, tr, Lr, zr, ye = this.host.getScriptSnapshot(Te);
                if (!ye)
                  throw new Error("Could not find file: '" + Te + "'.");
                var ir = e.getScriptKind(Te, this.host), Dr = this.host.getScriptVersion(Te), Pr;
                if (this.currentFileName !== Te) {
                  var Br = { languageVersion: 99, impliedNodeFormat: e.getImpliedNodeFormatForFile(e.toPath(Te, this.host.getCurrentDirectory(), ((yr = (he = (we = this.host).getCompilerHost) === null || he === void 0 ? void 0 : he.call(we)) === null || yr === void 0 ? void 0 : yr.getCanonicalFileName) || e.hostGetCanonicalFileName(this.host)), (zr = (Lr = (tr = (nr = (kr = this.host).getCompilerHost) === null || nr === void 0 ? void 0 : nr.call(kr)) === null || tr === void 0 ? void 0 : tr.getModuleResolutionCache) === null || Lr === void 0 ? void 0 : Lr.call(tr)) === null || zr === void 0 ? void 0 : zr.getPackageJsonInfoCache(), this.host, this.host.getCompilationSettings()), setExternalModuleIndicator: e.getSetExternalModuleIndicator(this.host.getCompilationSettings()) };
                  Pr = ie(Te, ye, Br, Dr, true, ir);
                } else if (this.currentFileVersion !== Dr) {
                  var ut = ye.getChangeRange(this.currentFileScriptSnapshot);
                  Pr = H(this.currentSourceFile, ye, Dr, ut);
                }
                return Pr && (this.currentFileVersion = Dr, this.currentFileName = Te, this.currentFileScriptSnapshot = ye, this.currentSourceFile = Pr), this.currentSourceFile;
              }, X;
            }();
            function ge(X, Te, we) {
              X.version = we, X.scriptSnapshot = Te;
            }
            function ie(X, Te, we, he, yr, kr) {
              var nr = e.createSourceFile(X, e.getSnapshotText(Te), we, yr, kr);
              return ge(nr, Te, he), nr;
            }
            e.createLanguageServiceSourceFile = ie;
            function H(X, Te, we, he, yr) {
              if (he && we !== X.version) {
                var kr = void 0, nr = he.span.start !== 0 ? X.text.substr(0, he.span.start) : "", tr = e.textSpanEnd(he.span) !== X.text.length ? X.text.substr(e.textSpanEnd(he.span)) : "";
                if (he.newLength === 0)
                  kr = nr && tr ? nr + tr : nr || tr;
                else {
                  var Lr = Te.getText(he.span.start, he.span.start + he.newLength);
                  kr = nr && tr ? nr + Lr + tr : nr ? nr + Lr : Lr + tr;
                }
                var zr = e.updateSourceFile(X, kr, he, yr);
                return ge(zr, Te, we), zr.nameTable = void 0, X !== zr && X.scriptSnapshot && (X.scriptSnapshot.dispose && X.scriptSnapshot.dispose(), X.scriptSnapshot = void 0), zr;
              }
              var ye = { languageVersion: X.languageVersion, impliedNodeFormat: X.impliedNodeFormat, setExternalModuleIndicator: X.setExternalModuleIndicator };
              return ie(X.fileName, Te, ye, we, true, X.scriptKind);
            }
            e.updateLanguageServiceSourceFile = H;
            var pe = { isCancellationRequested: e.returnFalse, throwIfCancellationRequested: e.noop }, j = function() {
              function X(Te) {
                this.cancellationToken = Te;
              }
              return X.prototype.isCancellationRequested = function() {
                return this.cancellationToken.isCancellationRequested();
              }, X.prototype.throwIfCancellationRequested = function() {
                if (this.isCancellationRequested())
                  throw e.tracing === null || e.tracing === void 0 || e.tracing.instant("session", "cancellationThrown", { kind: "CancellationTokenObject" }), new e.OperationCanceledException();
              }, X;
            }(), be = function() {
              function X(Te, we) {
                we === void 0 && (we = 20), this.hostCancellationToken = Te, this.throttleWaitMilliseconds = we, this.lastCancellationCheckTime = 0;
              }
              return X.prototype.isCancellationRequested = function() {
                var Te = e.timestamp(), we = Math.abs(Te - this.lastCancellationCheckTime);
                return we >= this.throttleWaitMilliseconds ? (this.lastCancellationCheckTime = Te, this.hostCancellationToken.isCancellationRequested()) : false;
              }, X.prototype.throwIfCancellationRequested = function() {
                if (this.isCancellationRequested())
                  throw e.tracing === null || e.tracing === void 0 || e.tracing.instant("session", "cancellationThrown", { kind: "ThrottledCancellationToken" }), new e.OperationCanceledException();
              }, X;
            }();
            e.ThrottledCancellationToken = be;
            var Xe = ["getSemanticDiagnostics", "getSuggestionDiagnostics", "getCompilerOptionsDiagnostics", "getSemanticClassifications", "getEncodedSemanticClassifications", "getCodeFixesAtPosition", "getCombinedCodeFix", "applyCodeActionCommand", "organizeImports", "getEditsForFileRename", "getEmitOutput", "getApplicableRefactors", "getEditsForRefactor", "prepareCallHierarchy", "provideCallHierarchyIncomingCalls", "provideCallHierarchyOutgoingCalls", "provideInlayHints"], Re = D(D([], Xe, true), ["getCompletionsAtPosition", "getCompletionEntryDetails", "getCompletionEntrySymbol", "getSignatureHelpItems", "getQuickInfoAtPosition", "getDefinitionAtPosition", "getDefinitionAndBoundSpan", "getImplementationAtPosition", "getTypeDefinitionAtPosition", "getReferencesAtPosition", "findReferences", "getOccurrencesAtPosition", "getDocumentHighlights", "getNavigateToItems", "getRenameInfo", "findRenameLocations", "getApplicableRefactors"], false);
            function Fe(X, Te, we) {
              var he, yr;
              Te === void 0 && (Te = e.createDocumentRegistry(X.useCaseSensitiveFileNames && X.useCaseSensitiveFileNames(), X.getCurrentDirectory()));
              var kr;
              we === void 0 ? kr = e.LanguageServiceMode.Semantic : typeof we == "boolean" ? kr = we ? e.LanguageServiceMode.Syntactic : e.LanguageServiceMode.Semantic : kr = we;
              var nr = new qe(X), tr, Lr, zr = 0, ye = X.getCancellationToken ? new j(X.getCancellationToken()) : pe, ir = X.getCurrentDirectory();
              e.maybeSetLocalizedDiagnosticMessages((yr = X.getLocalizedDiagnosticMessages) === null || yr === void 0 ? void 0 : yr.bind(X));
              function Dr(Le) {
                X.log && X.log(Le);
              }
              var Pr = e.hostUsesCaseSensitiveFileNames(X), Br = e.createGetCanonicalFileName(Pr), ut = e.getSourceMapper({ useCaseSensitiveFileNames: function() {
                return Pr;
              }, getCurrentDirectory: function() {
                return ir;
              }, getProgram: f, fileExists: e.maybeBind(X, X.fileExists), readFile: e.maybeBind(X, X.readFile), getDocumentPositionMapper: e.maybeBind(X, X.getDocumentPositionMapper), getSourceFileLike: e.maybeBind(X, X.getSourceFileLike), log: Dr });
              function rt(Le) {
                var Ve = tr.getSourceFile(Le);
                if (!Ve) {
                  var _r = new Error("Could not find source file: '".concat(Le, "'."));
                  throw _r.ProgramFiles = tr.getSourceFiles().map(function(lr) {
                    return lr.fileName;
                  }), _r;
                }
                return Ve;
              }
              function Z() {
                var Le, Ve, _r;
                if (e.Debug.assert(kr !== e.LanguageServiceMode.Syntactic), X.getProjectVersion) {
                  var lr = X.getProjectVersion();
                  if (lr) {
                    if (Lr === lr && !(!((Le = X.hasChangedAutomaticTypeDirectiveNames) === null || Le === void 0) && Le.call(X)))
                      return;
                    Lr = lr;
                  }
                }
                var Vr = X.getTypeRootsVersion ? X.getTypeRootsVersion() : 0;
                zr !== Vr && (Dr("TypeRoots version has changed; provide new program"), tr = void 0, zr = Vr);
                var tt = X.getScriptFileNames().slice(), dt = X.getCompilationSettings() || te(), It = X.hasInvalidatedResolutions || e.returnFalse, an = e.maybeBind(X, X.hasChangedAutomaticTypeDirectiveNames), sn = (Ve = X.getProjectReferences) === null || Ve === void 0 ? void 0 : Ve.call(X), _e, Gr = { getSourceFile: kn, getSourceFileByPath: on, getCancellationToken: function() {
                  return ye;
                }, getCanonicalFileName: Br, useCaseSensitiveFileNames: function() {
                  return Pr;
                }, getNewLine: function() {
                  return e.getNewLineCharacter(dt, function() {
                    return e.getNewLineOrDefaultFromHost(X);
                  });
                }, getDefaultLibFileName: function(Xr) {
                  return X.getDefaultLibFileName(Xr);
                }, writeFile: e.noop, getCurrentDirectory: function() {
                  return ir;
                }, fileExists: function(Xr) {
                  return X.fileExists(Xr);
                }, readFile: function(Xr) {
                  return X.readFile && X.readFile(Xr);
                }, getSymlinkCache: e.maybeBind(X, X.getSymlinkCache), realpath: e.maybeBind(X, X.realpath), directoryExists: function(Xr) {
                  return e.directoryProbablyExists(Xr, X);
                }, getDirectories: function(Xr) {
                  return X.getDirectories ? X.getDirectories(Xr) : [];
                }, readDirectory: function(Xr, wr, fn, mn, Mi) {
                  return e.Debug.checkDefined(X.readDirectory, "'LanguageServiceHost.readDirectory' must be implemented to correctly process 'projectReferences'"), X.readDirectory(Xr, wr, fn, mn, Mi);
                }, onReleaseOldSourceFile: Rn, onReleaseParsedCommandLine: Mn, hasInvalidatedResolutions: It, hasChangedAutomaticTypeDirectiveNames: an, trace: e.maybeBind(X, X.trace), resolveModuleNames: e.maybeBind(X, X.resolveModuleNames), getModuleResolutionCache: e.maybeBind(X, X.getModuleResolutionCache), resolveTypeReferenceDirectives: e.maybeBind(X, X.resolveTypeReferenceDirectives), useSourceOfProjectReferenceRedirect: e.maybeBind(X, X.useSourceOfProjectReferenceRedirect), getParsedCommandLine: rn }, Kt = Gr.getSourceFile, en = e.changeCompilerHostLikeToUseCache(Gr, function(Xr) {
                  return e.toPath(Xr, ir, Br);
                }, function() {
                  for (var Xr = [], wr = 0; wr < arguments.length; wr++)
                    Xr[wr] = arguments[wr];
                  return Kt.call.apply(Kt, D([Gr], Xr, false));
                }).getSourceFileWithCache;
                Gr.getSourceFile = en, (_r = X.setCompilerHost) === null || _r === void 0 || _r.call(X, Gr);
                var Ot = { useCaseSensitiveFileNames: Pr, fileExists: function(Xr) {
                  return Gr.fileExists(Xr);
                }, readFile: function(Xr) {
                  return Gr.readFile(Xr);
                }, readDirectory: function() {
                  for (var Xr, wr = [], fn = 0; fn < arguments.length; fn++)
                    wr[fn] = arguments[fn];
                  return (Xr = Gr).readDirectory.apply(Xr, wr);
                }, trace: Gr.trace, getCurrentDirectory: Gr.getCurrentDirectory, onUnRecoverableConfigFileDiagnostic: e.noop }, rr = Te.getKeyForCompilationSettings(dt);
                if (e.isProgramUptoDate(tr, tt, dt, function(Xr, wr) {
                  return X.getScriptVersion(wr);
                }, function(Xr) {
                  return Gr.fileExists(Xr);
                }, It, an, rn, sn))
                  return;
                var Hn = { rootNames: tt, options: dt, host: Gr, oldProgram: tr, projectReferences: sn };
                tr = e.createProgram(Hn), Gr = void 0, _e = void 0, ut.clearCache(), tr.getTypeChecker();
                return;
                function rn(Xr) {
                  var wr = e.toPath(Xr, ir, Br), fn = _e == null ? void 0 : _e.get(wr);
                  if (fn !== void 0)
                    return fn || void 0;
                  var mn = X.getParsedCommandLine ? X.getParsedCommandLine(Xr) : xn(Xr);
                  return (_e || (_e = new e.Map())).set(wr, mn || false), mn;
                }
                function xn(Xr) {
                  var wr = kn(Xr, 100);
                  if (wr)
                    return wr.path = e.toPath(Xr, ir, Br), wr.resolvedPath = wr.path, wr.originalFileName = wr.fileName, e.parseJsonSourceFileConfigFileContent(wr, Ot, e.getNormalizedAbsolutePath(e.getDirectoryPath(Xr), ir), void 0, e.getNormalizedAbsolutePath(Xr, ir));
                }
                function Mn(Xr, wr, fn) {
                  var mn;
                  X.getParsedCommandLine ? (mn = X.onReleaseParsedCommandLine) === null || mn === void 0 || mn.call(X, Xr, wr, fn) : wr && Rn(wr.sourceFile, fn);
                }
                function Rn(Xr, wr) {
                  var fn = Te.getKeyForCompilationSettings(wr);
                  Te.releaseDocumentWithKey(Xr.resolvedPath, fn, Xr.scriptKind, Xr.impliedNodeFormat);
                }
                function kn(Xr, wr, fn, mn) {
                  return on(Xr, e.toPath(Xr, ir, Br), wr, fn, mn);
                }
                function on(Xr, wr, fn, mn, Mi) {
                  e.Debug.assert(Gr, "getOrCreateSourceFileByPath called after typical CompilerHost lifetime, check the callstack something with a reference to an old host.");
                  var An = X.getScriptSnapshot(Xr);
                  if (An) {
                    var xi = e.getScriptKind(Xr, X), ti = X.getScriptVersion(Xr);
                    if (!Mi) {
                      var li = tr && tr.getSourceFileByPath(wr);
                      if (li) {
                        if (xi === li.scriptKind)
                          return Te.updateDocumentWithKey(Xr, wr, X, rr, An, ti, xi, fn);
                        Te.releaseDocumentWithKey(li.resolvedPath, Te.getKeyForCompilationSettings(tr.getCompilerOptions()), li.scriptKind, li.impliedNodeFormat);
                      }
                    }
                    return Te.acquireDocumentWithKey(Xr, wr, X, rr, An, ti, xi, fn);
                  }
                }
              }
              function f() {
                if (kr === e.LanguageServiceMode.Syntactic) {
                  e.Debug.assert(tr === void 0);
                  return;
                }
                return Z(), tr;
              }
              function h() {
                var Le;
                return (Le = X.getPackageJsonAutoImportProvider) === null || Le === void 0 ? void 0 : Le.call(X);
              }
              function oe(Le, Ve) {
                var _r = tr.getTypeChecker(), lr = Kt();
                if (!lr)
                  return false;
                for (var Vr = 0, tt = Le; Vr < tt.length; Vr++)
                  for (var dt = tt[Vr], It = 0, an = dt.references; It < an.length; It++) {
                    var sn = an[It], _e = en(sn);
                    if (e.Debug.assertIsDefined(_e), Ve.has(sn) || e.FindAllReferences.isDeclarationOfSymbol(_e, lr)) {
                      Ve.add(sn), sn.isDefinition = true;
                      var Gr = e.getMappedDocumentSpan(sn, ut, e.maybeBind(X, X.fileExists));
                      Gr && Ve.add(Gr);
                    } else
                      sn.isDefinition = false;
                  }
                return true;
                function Kt() {
                  for (var Ot = 0, rr = Le; Ot < rr.length; Ot++)
                    for (var Hn = rr[Ot], rn = 0, xn = Hn.references; rn < xn.length; rn++) {
                      var Mn = xn[rn];
                      if (Ve.has(Mn)) {
                        var Rn = en(Mn);
                        return e.Debug.assertIsDefined(Rn), _r.getSymbolAtLocation(Rn);
                      }
                      var kn = e.getMappedDocumentSpan(Mn, ut, e.maybeBind(X, X.fileExists));
                      if (kn && Ve.has(kn)) {
                        var Rn = en(kn);
                        if (Rn)
                          return _r.getSymbolAtLocation(Rn);
                      }
                    }
                }
                function en(Ot) {
                  var rr = tr.getSourceFile(Ot.fileName);
                  if (rr) {
                    var Hn = e.getTouchingPropertyName(rr, Ot.textSpan.start), rn = e.FindAllReferences.Core.getAdjustedNode(Hn, { use: 1 });
                    return rn;
                  }
                }
              }
              function xr() {
                tr = void 0;
              }
              function jr() {
                if (tr) {
                  var Le = Te.getKeyForCompilationSettings(tr.getCompilerOptions());
                  e.forEach(tr.getSourceFiles(), function(Ve) {
                    return Te.releaseDocumentWithKey(Ve.resolvedPath, Le, Ve.scriptKind, Ve.impliedNodeFormat);
                  }), tr = void 0;
                }
                X = void 0;
              }
              function qr(Le) {
                return Z(), tr.getSyntacticDiagnostics(rt(Le), ye).slice();
              }
              function pt(Le) {
                Z();
                var Ve = rt(Le), _r = tr.getSemanticDiagnostics(Ve, ye);
                if (!e.getEmitDeclarations(tr.getCompilerOptions()))
                  return _r.slice();
                var lr = tr.getDeclarationDiagnostics(Ve, ye);
                return D(D([], _r, true), lr, true);
              }
              function Ge(Le) {
                return Z(), e.computeSuggestionDiagnostics(rt(Le), tr, ye);
              }
              function K() {
                return Z(), D(D([], tr.getOptionsDiagnostics(ye), true), tr.getGlobalDiagnostics(ye), true);
              }
              function r(Le, Ve, _r, lr) {
                _r === void 0 && (_r = e.emptyOptions);
                var Vr = T(T({}, e.identity(_r)), { includeCompletionsForModuleExports: _r.includeCompletionsForModuleExports || _r.includeExternalModuleExports, includeCompletionsWithInsertText: _r.includeCompletionsWithInsertText || _r.includeInsertTextCompletions });
                return Z(), e.Completions.getCompletionsAtPosition(X, tr, Dr, rt(Le), Ve, Vr, _r.triggerCharacter, _r.triggerKind, ye, lr && e.formatting.getFormatContext(lr, X));
              }
              function ct(Le, Ve, _r, lr, Vr, tt, dt) {
                return tt === void 0 && (tt = e.emptyOptions), Z(), e.Completions.getCompletionEntryDetails(tr, Dr, rt(Le), Ve, { name: _r, source: Vr, data: dt }, X, lr && e.formatting.getFormatContext(lr, X), tt, ye);
              }
              function ft(Le, Ve, _r, lr, Vr) {
                return Vr === void 0 && (Vr = e.emptyOptions), Z(), e.Completions.getCompletionEntrySymbol(tr, Dr, rt(Le), Ve, { name: _r, source: lr }, X, Vr);
              }
              function Ie(Le, Ve) {
                Z();
                var _r = rt(Le), lr = e.getTouchingPropertyName(_r, Ve);
                if (lr !== _r) {
                  var Vr = tr.getTypeChecker(), tt = me(lr), dt = Cr(tt, Vr);
                  if (!dt || Vr.isUnknownSymbol(dt)) {
                    var It = xe(_r, tt, Ve) ? Vr.getTypeAtLocation(tt) : void 0;
                    return It && { kind: "", kindModifiers: "", textSpan: e.createTextSpanFromNode(tt, _r), displayParts: Vr.runWithCancellationToken(ye, function(en) {
                      return e.typeToDisplayParts(en, It, e.getContainerNode(tt));
                    }), documentation: It.symbol ? It.symbol.getDocumentationComment(Vr) : void 0, tags: It.symbol ? It.symbol.getJsDocTags(Vr) : void 0 };
                  }
                  var an = Vr.runWithCancellationToken(ye, function(en) {
                    return e.SymbolDisplay.getSymbolDisplayPartsDocumentationAndSymbolKind(en, dt, _r, e.getContainerNode(tt), tt);
                  }), sn = an.symbolKind, _e = an.displayParts, Gr = an.documentation, Kt = an.tags;
                  return { kind: sn, kindModifiers: e.SymbolDisplay.getSymbolModifiers(Vr, dt), textSpan: e.createTextSpanFromNode(tt, _r), displayParts: _e, documentation: Gr, tags: Kt };
                }
              }
              function me(Le) {
                return e.isNewExpression(Le.parent) && Le.pos === Le.parent.pos ? Le.parent.expression : e.isNamedTupleMember(Le.parent) && Le.pos === Le.parent.pos || e.isImportMeta(Le.parent) && Le.parent.name === Le ? Le.parent : Le;
              }
              function xe(Le, Ve, _r) {
                switch (Ve.kind) {
                  case 79:
                    return !e.isLabelName(Ve) && !e.isTagName(Ve) && !e.isConstTypeReference(Ve.parent);
                  case 208:
                  case 163:
                    return !e.isInComment(Le, _r);
                  case 108:
                  case 194:
                  case 106:
                  case 199:
                    return true;
                  case 233:
                    return e.isImportMeta(Ve);
                  default:
                    return false;
                }
              }
              function Ye(Le, Ve, _r, lr) {
                return Z(), e.GoToDefinition.getDefinitionAtPosition(tr, rt(Le), Ve, _r, lr);
              }
              function vr(Le, Ve) {
                return Z(), e.GoToDefinition.getDefinitionAndBoundSpan(tr, rt(Le), Ve);
              }
              function nt(Le, Ve) {
                return Z(), e.GoToDefinition.getTypeDefinitionAtPosition(tr.getTypeChecker(), rt(Le), Ve);
              }
              function pr(Le, Ve) {
                return Z(), e.FindAllReferences.getImplementationsAtPosition(tr, ye, tr.getSourceFiles(), rt(Le), Ve);
              }
              function Mr(Le, Ve) {
                return e.flatMap(ot(Le, Ve, [Le]), function(_r) {
                  return _r.highlightSpans.map(function(lr) {
                    return T(T({ fileName: _r.fileName, textSpan: lr.textSpan, isWriteAccess: lr.kind === "writtenReference" }, lr.isInString && { isInString: true }), lr.contextSpan && { contextSpan: lr.contextSpan });
                  });
                });
              }
              function ot(Le, Ve, _r) {
                var lr = e.normalizePath(Le);
                e.Debug.assert(_r.some(function(dt) {
                  return e.normalizePath(dt) === lr;
                })), Z();
                var Vr = e.mapDefined(_r, function(dt) {
                  return tr.getSourceFile(dt);
                }), tt = rt(Le);
                return e.DocumentHighlights.getDocumentHighlights(tr, ye, tt, Ve, Vr);
              }
              function At(Le, Ve, _r, lr, Vr) {
                Z();
                var tt = rt(Le), dt = e.getAdjustedRenameLocation(e.getTouchingPropertyName(tt, Ve));
                if (e.Rename.nodeIsEligibleForRename(dt))
                  if (e.isIdentifier(dt) && (e.isJsxOpeningElement(dt.parent) || e.isJsxClosingElement(dt.parent)) && e.isIntrinsicJsxName(dt.escapedText)) {
                    var It = dt.parent.parent, an = It.openingElement, sn = It.closingElement;
                    return [an, sn].map(function(_e) {
                      var Gr = e.createTextSpanFromNode(_e.tagName, tt);
                      return T({ fileName: tt.fileName, textSpan: Gr }, e.FindAllReferences.toContextSpan(Gr, tt, _e.parent));
                    });
                  } else
                    return de(dt, Ve, { findInStrings: _r, findInComments: lr, providePrefixAndSuffixTextForRename: Vr, use: 2 }, function(_e, Gr, Kt) {
                      return e.FindAllReferences.toRenameLocation(_e, Gr, Kt, Vr || false);
                    });
              }
              function re(Le, Ve) {
                return Z(), de(e.getTouchingPropertyName(rt(Le), Ve), Ve, { use: 1 }, e.FindAllReferences.toReferenceEntry);
              }
              function de(Le, Ve, _r, lr) {
                Z();
                var Vr = _r && _r.use === 2 ? tr.getSourceFiles().filter(function(tt) {
                  return !tr.isSourceFileDefaultLibrary(tt);
                }) : tr.getSourceFiles();
                return e.FindAllReferences.findReferenceOrRenameEntries(tr, ye, Vr, Le, Ve, _r, lr);
              }
              function He(Le, Ve) {
                return Z(), e.FindAllReferences.findReferencedSymbols(tr, ye, tr.getSourceFiles(), rt(Le), Ve);
              }
              function Nr(Le) {
                return Z(), e.FindAllReferences.Core.getReferencesForFileName(Le, tr, tr.getSourceFiles()).map(e.FindAllReferences.toReferenceEntry);
              }
              function Yr(Le, Ve, _r, lr) {
                lr === void 0 && (lr = false), Z();
                var Vr = _r ? [rt(_r)] : tr.getSourceFiles();
                return e.NavigateTo.getNavigateToItems(Vr, tr.getTypeChecker(), ye, Le, Ve, lr);
              }
              function Ct(Le, Ve, _r) {
                Z();
                var lr = rt(Le), Vr = X.getCustomTransformers && X.getCustomTransformers();
                return e.getFileEmitOutput(tr, lr, !!Ve, ye, Vr, _r);
              }
              function xt(Le, Ve, _r) {
                var lr = _r === void 0 ? e.emptyOptions : _r, Vr = lr.triggerReason;
                Z();
                var tt = rt(Le);
                return e.SignatureHelp.getSignatureHelpItems(tr, tt, Ve, Vr, ye);
              }
              function Lt(Le) {
                return nr.getCurrentSourceFile(Le);
              }
              function zt(Le, Ve, _r) {
                var lr = nr.getCurrentSourceFile(Le), Vr = e.getTouchingPropertyName(lr, Ve);
                if (Vr !== lr) {
                  switch (Vr.kind) {
                    case 208:
                    case 163:
                    case 10:
                    case 95:
                    case 110:
                    case 104:
                    case 106:
                    case 108:
                    case 194:
                    case 79:
                      break;
                    default:
                      return;
                  }
                  for (var tt = Vr; ; )
                    if (e.isRightSideOfPropertyAccess(tt) || e.isRightSideOfQualifiedName(tt))
                      tt = tt.parent;
                    else if (e.isNameOfModuleDeclaration(tt))
                      if (tt.parent.parent.kind === 264 && tt.parent.parent.body === tt.parent)
                        tt = tt.parent.parent.name;
                      else
                        break;
                    else
                      break;
                  return e.createTextSpanFromBounds(tt.getStart(), Vr.getEnd());
                }
              }
              function Zt(Le, Ve) {
                var _r = nr.getCurrentSourceFile(Le);
                return e.BreakpointResolver.spanInSourceFileAtLocation(_r, Ve);
              }
              function mt(Le) {
                return e.NavigationBar.getNavigationBarItems(nr.getCurrentSourceFile(Le), ye);
              }
              function at(Le) {
                return e.NavigationBar.getNavigationTree(nr.getCurrentSourceFile(Le), ye);
              }
              function k(Le, Ve, _r) {
                Z();
                var lr = _r || "original";
                return lr === "2020" ? e.classifier.v2020.getSemanticClassifications(tr, ye, rt(Le), Ve) : e.getSemanticClassifications(tr.getTypeChecker(), ye, rt(Le), tr.getClassifiableNames(), Ve);
              }
              function ue(Le, Ve, _r) {
                Z();
                var lr = _r || "original";
                return lr === "original" ? e.getEncodedSemanticClassifications(tr.getTypeChecker(), ye, rt(Le), tr.getClassifiableNames(), Ve) : e.classifier.v2020.getEncodedSemanticClassifications(tr, ye, rt(Le), Ve);
              }
              function Qe(Le, Ve) {
                return e.getSyntacticClassifications(ye, nr.getCurrentSourceFile(Le), Ve);
              }
              function Sr(Le, Ve) {
                return e.getEncodedSyntacticClassifications(ye, nr.getCurrentSourceFile(Le), Ve);
              }
              function Kr(Le) {
                var Ve = nr.getCurrentSourceFile(Le);
                return e.OutliningElementsCollector.collectElements(Ve, ye);
              }
              var Hr = new e.Map(e.getEntries((he = {}, he[18] = 19, he[20] = 21, he[22] = 23, he[31] = 29, he)));
              Hr.forEach(function(Le, Ve) {
                return Hr.set(Le.toString(), Number(Ve));
              });
              function Dt(Le, Ve) {
                var _r = nr.getCurrentSourceFile(Le), lr = e.getTouchingToken(_r, Ve), Vr = lr.getStart(_r) === Ve ? Hr.get(lr.kind.toString()) : void 0, tt = Vr && e.findChildOfKind(lr.parent, Vr, _r);
                return tt ? [e.createTextSpanFromNode(lr, _r), e.createTextSpanFromNode(tt, _r)].sort(function(dt, It) {
                  return dt.start - It.start;
                }) : e.emptyArray;
              }
              function Xt(Le, Ve, _r) {
                var lr = e.timestamp(), Vr = g(_r), tt = nr.getCurrentSourceFile(Le);
                Dr("getIndentationAtPosition: getCurrentSourceFile: " + (e.timestamp() - lr)), lr = e.timestamp();
                var dt = e.formatting.SmartIndenter.getIndentation(Ve, tt, Vr);
                return Dr("getIndentationAtPosition: computeIndentation  : " + (e.timestamp() - lr)), dt;
              }
              function cn(Le, Ve, _r, lr) {
                var Vr = nr.getCurrentSourceFile(Le);
                return e.formatting.formatSelection(Ve, _r, Vr, e.formatting.getFormatContext(g(lr), X));
              }
              function In(Le, Ve) {
                return e.formatting.formatDocument(nr.getCurrentSourceFile(Le), e.formatting.getFormatContext(g(Ve), X));
              }
              function yn(Le, Ve, _r, lr) {
                var Vr = nr.getCurrentSourceFile(Le), tt = e.formatting.getFormatContext(g(lr), X);
                if (!e.isInComment(Vr, Ve))
                  switch (_r) {
                    case "{":
                      return e.formatting.formatOnOpeningCurly(Ve, Vr, tt);
                    case "}":
                      return e.formatting.formatOnClosingCurly(Ve, Vr, tt);
                    case ";":
                      return e.formatting.formatOnSemicolon(Ve, Vr, tt);
                    case `
`:
                      return e.formatting.formatOnEnter(Ve, Vr, tt);
                  }
                return [];
              }
              function hn(Le, Ve, _r, lr, Vr, tt) {
                tt === void 0 && (tt = e.emptyOptions), Z();
                var dt = rt(Le), It = e.createTextSpanFromBounds(Ve, _r), an = e.formatting.getFormatContext(Vr, X);
                return e.flatMap(e.deduplicate(lr, e.equateValues, e.compareValues), function(sn) {
                  return ye.throwIfCancellationRequested(), e.codefix.getFixes({ errorCode: sn, sourceFile: dt, span: It, program: tr, host: X, cancellationToken: ye, formatContext: an, preferences: tt });
                });
              }
              function ln(Le, Ve, _r, lr) {
                lr === void 0 && (lr = e.emptyOptions), Z(), e.Debug.assert(Le.type === "file");
                var Vr = rt(Le.fileName), tt = e.formatting.getFormatContext(_r, X);
                return e.codefix.getAllFixes({ fixId: Ve, sourceFile: Vr, program: tr, host: X, cancellationToken: ye, formatContext: tt, preferences: lr });
              }
              function En(Le, Ve, _r) {
                var lr;
                _r === void 0 && (_r = e.emptyOptions), Z(), e.Debug.assert(Le.type === "file");
                var Vr = rt(Le.fileName), tt = e.formatting.getFormatContext(Ve, X), dt = (lr = Le.mode) !== null && lr !== void 0 ? lr : Le.skipDestructiveCodeActions ? "SortAndCombine" : "All";
                return e.OrganizeImports.organizeImports(Vr, tt, X, tr, _r, dt);
              }
              function Vt(Le, Ve, _r, lr) {
                return lr === void 0 && (lr = e.emptyOptions), e.getEditsForFileRename(f(), Le, Ve, X, e.formatting.getFormatContext(_r, X), lr, ut);
              }
              function ui(Le, Ve) {
                var _r = typeof Le == "string" ? Ve : Le;
                return e.isArray(_r) ? Promise.all(_r.map(function(lr) {
                  return ei(lr);
                })) : ei(_r);
              }
              function ei(Le) {
                var Ve = function(_r) {
                  return e.toPath(_r, ir, Br);
                };
                return e.Debug.assertEqual(Le.type, "install package"), X.installPackage ? X.installPackage({ fileName: Ve(Le.file), packageName: Le.packageName }) : Promise.reject("Host does not implement `installPackage`");
              }
              function hi(Le, Ve, _r) {
                return e.JsDoc.getDocCommentTemplateAtPosition(e.getNewLineOrDefaultFromHost(X), nr.getCurrentSourceFile(Le), Ve, _r);
              }
              function ri(Le, Ve, _r) {
                if (_r === 60)
                  return false;
                var lr = nr.getCurrentSourceFile(Le);
                if (e.isInString(lr, Ve))
                  return false;
                if (e.isInsideJsxElementOrAttribute(lr, Ve))
                  return _r === 123;
                if (e.isInTemplateString(lr, Ve))
                  return false;
                switch (_r) {
                  case 39:
                  case 34:
                  case 96:
                    return !e.isInComment(lr, Ve);
                }
                return true;
              }
              function vi(Le, Ve) {
                var _r = nr.getCurrentSourceFile(Le), lr = e.findPrecedingToken(Ve, _r);
                if (lr) {
                  var Vr = lr.kind === 31 && e.isJsxOpeningElement(lr.parent) ? lr.parent.parent : e.isJsxText(lr) && e.isJsxElement(lr.parent) ? lr.parent : void 0;
                  if (Vr && Kn(Vr))
                    return { newText: "</".concat(Vr.openingElement.tagName.getText(_r), ">") };
                  var tt = lr.kind === 31 && e.isJsxOpeningFragment(lr.parent) ? lr.parent.parent : e.isJsxText(lr) && e.isJsxFragment(lr.parent) ? lr.parent : void 0;
                  if (tt && si(tt))
                    return { newText: "</>" };
                }
              }
              function Qn(Le, Ve) {
                return { lineStarts: Le.getLineStarts(), firstLine: Le.getLineAndCharacterOfPosition(Ve.pos).line, lastLine: Le.getLineAndCharacterOfPosition(Ve.end).line };
              }
              function Yn(Le, Ve, _r) {
                for (var lr = nr.getCurrentSourceFile(Le), Vr = [], tt = Qn(lr, Ve), dt = tt.lineStarts, It = tt.firstLine, an = tt.lastLine, sn = _r || false, _e = Number.MAX_VALUE, Gr = new e.Map(), Kt = new RegExp(/\S/), en = e.isInsideJsxElement(lr, dt[It]), Ot = en ? "{/*" : "//", rr = It; rr <= an; rr++) {
                  var Hn = lr.text.substring(dt[rr], lr.getLineEndOfPosition(dt[rr])), rn = Kt.exec(Hn);
                  rn && (_e = Math.min(_e, rn.index), Gr.set(rr.toString(), rn.index), Hn.substr(rn.index, Ot.length) !== Ot && (sn = _r === void 0 || _r));
                }
                for (var rr = It; rr <= an; rr++)
                  if (!(It !== an && dt[rr] === Ve.end)) {
                    var xn = Gr.get(rr.toString());
                    xn !== void 0 && (en ? Vr.push.apply(Vr, oi(Le, { pos: dt[rr] + _e, end: lr.getLineEndOfPosition(dt[rr]) }, sn, en)) : sn ? Vr.push({ newText: Ot, span: { length: 0, start: dt[rr] + _e } }) : lr.text.substr(dt[rr] + xn, Ot.length) === Ot && Vr.push({ newText: "", span: { length: Ot.length, start: dt[rr] + xn } }));
                  }
                return Vr;
              }
              function oi(Le, Ve, _r, lr) {
                for (var Vr, tt = nr.getCurrentSourceFile(Le), dt = [], It = tt.text, an = false, sn = _r || false, _e = [], Gr = Ve.pos, Kt = lr !== void 0 ? lr : e.isInsideJsxElement(tt, Gr), en = Kt ? "{/*" : "/*", Ot = Kt ? "*/}" : "*/", rr = Kt ? "\\{\\/\\*" : "\\/\\*", Hn = Kt ? "\\*\\/\\}" : "\\*\\/"; Gr <= Ve.end; ) {
                  var rn = It.substr(Gr, en.length) === en ? en.length : 0, xn = e.isInComment(tt, Gr + rn);
                  if (xn)
                    Kt && (xn.pos--, xn.end++), _e.push(xn.pos), xn.kind === 3 && _e.push(xn.end), an = true, Gr = xn.end + 1;
                  else {
                    var Mn = It.substring(Gr, Ve.end).search("(".concat(rr, ")|(").concat(Hn, ")"));
                    sn = _r !== void 0 ? _r : sn || !e.isTextWhiteSpaceLike(It, Gr, Mn === -1 ? Ve.end : Gr + Mn), Gr = Mn === -1 ? Ve.end + 1 : Gr + Mn + Ot.length;
                  }
                }
                if (sn || !an) {
                  ((Vr = e.isInComment(tt, Ve.pos)) === null || Vr === void 0 ? void 0 : Vr.kind) !== 2 && e.insertSorted(_e, Ve.pos, e.compareValues), e.insertSorted(_e, Ve.end, e.compareValues);
                  var Rn = _e[0];
                  It.substr(Rn, en.length) !== en && dt.push({ newText: en, span: { length: 0, start: Rn } });
                  for (var kn = 1; kn < _e.length - 1; kn++)
                    It.substr(_e[kn] - Ot.length, Ot.length) !== Ot && dt.push({ newText: Ot, span: { length: 0, start: _e[kn] } }), It.substr(_e[kn], en.length) !== en && dt.push({ newText: en, span: { length: 0, start: _e[kn] } });
                  dt.length % 2 !== 0 && dt.push({ newText: Ot, span: { length: 0, start: _e[_e.length - 1] } });
                } else
                  for (var on = 0, Xr = _e; on < Xr.length; on++) {
                    var wr = Xr[on], fn = wr - Ot.length > 0 ? wr - Ot.length : 0, rn = It.substr(fn, Ot.length) === Ot ? Ot.length : 0;
                    dt.push({ newText: "", span: { length: en.length, start: wr - rn } });
                  }
                return dt;
              }
              function bi(Le, Ve) {
                var _r = nr.getCurrentSourceFile(Le), lr = Qn(_r, Ve), Vr = lr.firstLine, tt = lr.lastLine;
                return Vr === tt && Ve.pos !== Ve.end ? oi(Le, Ve, true) : Yn(Le, Ve, true);
              }
              function Dn(Le, Ve) {
                var _r = nr.getCurrentSourceFile(Le), lr = [], Vr = Ve.pos, tt = Ve.end;
                Vr === tt && (tt += e.isInsideJsxElement(_r, Vr) ? 2 : 1);
                for (var dt = Vr; dt <= tt; dt++) {
                  var It = e.isInComment(_r, dt);
                  if (It) {
                    switch (It.kind) {
                      case 2:
                        lr.push.apply(lr, Yn(Le, { end: It.end, pos: It.pos + 1 }, false));
                        break;
                      case 3:
                        lr.push.apply(lr, oi(Le, { end: It.end, pos: It.pos + 1 }, false));
                    }
                    dt = It.end + 1;
                  }
                }
                return lr;
              }
              function Kn(Le) {
                var Ve = Le.openingElement, _r = Le.closingElement, lr = Le.parent;
                return !e.tagNamesAreEquivalent(Ve.tagName, _r.tagName) || e.isJsxElement(lr) && e.tagNamesAreEquivalent(Ve.tagName, lr.openingElement.tagName) && Kn(lr);
              }
              function si(Le) {
                var Ve = Le.closingFragment, _r = Le.parent;
                return !!(Ve.flags & 131072) || e.isJsxFragment(_r) && si(_r);
              }
              function di(Le, Ve, _r) {
                var lr = nr.getCurrentSourceFile(Le), Vr = e.formatting.getRangeOfEnclosingComment(lr, Ve);
                return Vr && (!_r || Vr.kind === 3) ? e.createTextSpanFromRange(Vr) : void 0;
              }
              function Zn(Le, Ve) {
                Z();
                var _r = rt(Le);
                ye.throwIfCancellationRequested();
                var lr = _r.text, Vr = [];
                if (Ve.length > 0 && !Hn(_r.fileName))
                  for (var tt = Ot(), dt = void 0; dt = tt.exec(lr); ) {
                    ye.throwIfCancellationRequested();
                    var It = 3;
                    e.Debug.assert(dt.length === Ve.length + It);
                    var an = dt[1], sn = dt.index + an.length;
                    if (e.isInComment(_r, sn)) {
                      for (var _e = void 0, Gr = 0; Gr < Ve.length; Gr++)
                        dt[Gr + It] && (_e = Ve[Gr]);
                      if (_e === void 0)
                        return e.Debug.fail();
                      if (!rr(lr.charCodeAt(sn + _e.text.length))) {
                        var Kt = dt[2];
                        Vr.push({ descriptor: _e, message: Kt, position: sn });
                      }
                    }
                  }
                return Vr;
                function en(rn) {
                  return rn.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
                }
                function Ot() {
                  var rn = /(?:\/\/+\s*)/.source, xn = /(?:\/\*+\s*)/.source, Mn = /(?:^(?:\s|\*)*)/.source, Rn = "(" + Mn + "|" + rn + "|" + xn + ")", kn = "(?:" + e.map(Ve, function(mn) {
                    return "(" + en(mn.text) + ")";
                  }).join("|") + ")", on = /(?:$|\*\/)/.source, Xr = /(?:.*?)/.source, wr = "(" + kn + Xr + ")", fn = Rn + wr + on;
                  return new RegExp(fn, "gim");
                }
                function rr(rn) {
                  return rn >= 97 && rn <= 122 || rn >= 65 && rn <= 90 || rn >= 48 && rn <= 57;
                }
                function Hn(rn) {
                  return e.stringContains(rn, "/node_modules/");
                }
              }
              function Fn(Le, Ve, _r) {
                return Z(), e.Rename.getRenameInfo(tr, rt(Le), Ve, _r || {});
              }
              function gt(Le, Ve, _r, lr, Vr, tt) {
                var dt = typeof Ve == "number" ? [Ve, void 0] : [Ve.pos, Ve.end], It = dt[0], an = dt[1];
                return { file: Le, startPosition: It, endPosition: an, program: f(), host: X, formatContext: e.formatting.getFormatContext(lr, X), cancellationToken: ye, preferences: _r, triggerReason: Vr, kind: tt };
              }
              function mi(Le, Ve, _r) {
                return { file: Le, program: f(), host: X, span: Ve, preferences: _r, cancellationToken: ye };
              }
              function dn(Le, Ve) {
                return e.SmartSelectionRange.getSmartSelectionRange(Ve, nr.getCurrentSourceFile(Le));
              }
              function On(Le, Ve, _r, lr, Vr) {
                _r === void 0 && (_r = e.emptyOptions), Z();
                var tt = rt(Le);
                return e.refactor.getApplicableRefactors(gt(tt, Ve, _r, e.emptyOptions, lr, Vr));
              }
              function br(Le, Ve, _r, lr, Vr, tt) {
                tt === void 0 && (tt = e.emptyOptions), Z();
                var dt = rt(Le);
                return e.refactor.getEditsForRefactor(gt(dt, _r, tt, Ve), lr, Vr);
              }
              function Ae(Le, Ve) {
                return Ve === 0 ? { line: 0, character: 0 } : ut.toLineColumnOffset(Le, Ve);
              }
              function ur(Le, Ve) {
                Z();
                var _r = e.CallHierarchy.resolveCallHierarchyDeclaration(tr, e.getTouchingPropertyName(rt(Le), Ve));
                return _r && e.mapOneOrMany(_r, function(lr) {
                  return e.CallHierarchy.createCallHierarchyItem(tr, lr);
                });
              }
              function L(Le, Ve) {
                Z();
                var _r = rt(Le), lr = e.firstOrOnly(e.CallHierarchy.resolveCallHierarchyDeclaration(tr, Ve === 0 ? _r : e.getTouchingPropertyName(_r, Ve)));
                return lr ? e.CallHierarchy.getIncomingCalls(tr, lr, ye) : [];
              }
              function qt(Le, Ve) {
                Z();
                var _r = rt(Le), lr = e.firstOrOnly(e.CallHierarchy.resolveCallHierarchyDeclaration(tr, Ve === 0 ? _r : e.getTouchingPropertyName(_r, Ve)));
                return lr ? e.CallHierarchy.getOutgoingCalls(tr, lr) : [];
              }
              function nn(Le, Ve, _r) {
                _r === void 0 && (_r = e.emptyOptions), Z();
                var lr = rt(Le);
                return e.InlayHints.provideInlayHints(mi(lr, Ve, _r));
              }
              var fr = { dispose: jr, cleanupSemanticCache: xr, getSyntacticDiagnostics: qr, getSemanticDiagnostics: pt, getSuggestionDiagnostics: Ge, getCompilerOptionsDiagnostics: K, getSyntacticClassifications: Qe, getSemanticClassifications: k, getEncodedSyntacticClassifications: Sr, getEncodedSemanticClassifications: ue, getCompletionsAtPosition: r, getCompletionEntryDetails: ct, getCompletionEntrySymbol: ft, getSignatureHelpItems: xt, getQuickInfoAtPosition: Ie, getDefinitionAtPosition: Ye, getDefinitionAndBoundSpan: vr, getImplementationAtPosition: pr, getTypeDefinitionAtPosition: nt, getReferencesAtPosition: re, findReferences: He, getFileReferences: Nr, getOccurrencesAtPosition: Mr, getDocumentHighlights: ot, getNameOrDottedNameSpan: zt, getBreakpointStatementAtPosition: Zt, getNavigateToItems: Yr, getRenameInfo: Fn, getSmartSelectionRange: dn, findRenameLocations: At, getNavigationBarItems: mt, getNavigationTree: at, getOutliningSpans: Kr, getTodoComments: Zn, getBraceMatchingAtPosition: Dt, getIndentationAtPosition: Xt, getFormattingEditsForRange: cn, getFormattingEditsForDocument: In, getFormattingEditsAfterKeystroke: yn, getDocCommentTemplateAtPosition: hi, isValidBraceCompletionAtPosition: ri, getJsxClosingTagAtPosition: vi, getSpanOfEnclosingComment: di, getCodeFixesAtPosition: hn, getCombinedCodeFix: ln, applyCodeActionCommand: ui, organizeImports: En, getEditsForFileRename: Vt, getEmitOutput: Ct, getNonBoundSourceFile: Lt, getProgram: f, getCurrentProgram: function() {
                return tr;
              }, getAutoImportProvider: h, updateIsDefinitionOfReferencedSymbols: oe, getApplicableRefactors: On, getEditsForRefactor: br, toLineColumnOffset: Ae, getSourceMapper: function() {
                return ut;
              }, clearSourceMapperCache: function() {
                return ut.clearCache();
              }, prepareCallHierarchy: ur, provideCallHierarchyIncomingCalls: L, provideCallHierarchyOutgoingCalls: qt, toggleLineComment: Yn, toggleMultilineComment: oi, commentSelection: bi, uncommentSelection: Dn, provideInlayHints: nn };
              switch (kr) {
                case e.LanguageServiceMode.Semantic:
                  break;
                case e.LanguageServiceMode.PartialSemantic:
                  Xe.forEach(function(Le) {
                    return fr[Le] = function() {
                      throw new Error("LanguageService Operation: ".concat(Le, " not allowed in LanguageServiceMode.PartialSemantic"));
                    };
                  });
                  break;
                case e.LanguageServiceMode.Syntactic:
                  Re.forEach(function(Le) {
                    return fr[Le] = function() {
                      throw new Error("LanguageService Operation: ".concat(Le, " not allowed in LanguageServiceMode.Syntactic"));
                    };
                  });
                  break;
                default:
                  e.Debug.assertNever(kr);
              }
              return fr;
            }
            e.createLanguageService = Fe;
            function dr(X) {
              return X.nameTable || ze(X), X.nameTable;
            }
            e.getNameTable = dr;
            function ze(X) {
              var Te = X.nameTable = new e.Map();
              X.forEachChild(function we(he) {
                if (e.isIdentifier(he) && !e.isTagName(he) && he.escapedText || e.isStringOrNumericLiteralLike(he) && ve(he)) {
                  var yr = e.getEscapedTextOfIdentifierOrLiteral(he);
                  Te.set(yr, Te.get(yr) === void 0 ? he.pos : -1);
                } else if (e.isPrivateIdentifier(he)) {
                  var yr = he.escapedText;
                  Te.set(yr, Te.get(yr) === void 0 ? he.pos : -1);
                }
                if (e.forEachChild(he, we), e.hasJSDocNodes(he))
                  for (var kr = 0, nr = he.jsDoc; kr < nr.length; kr++) {
                    var tr = nr[kr];
                    e.forEachChild(tr, we);
                  }
              });
            }
            function ve(X) {
              return e.isDeclarationName(X) || X.parent.kind === 280 || $e(X) || e.isLiteralComputedPropertyDeclarationName(X);
            }
            function er(X) {
              var Te = ar(X);
              return Te && (e.isObjectLiteralExpression(Te.parent) || e.isJsxAttributes(Te.parent)) ? Te : void 0;
            }
            e.getContainingObjectLiteralElement = er;
            function ar(X) {
              switch (X.kind) {
                case 10:
                case 14:
                case 8:
                  if (X.parent.kind === 164)
                    return e.isObjectLiteralElement(X.parent.parent) ? X.parent.parent : void 0;
                case 79:
                  return e.isObjectLiteralElement(X.parent) && (X.parent.parent.kind === 207 || X.parent.parent.kind === 289) && X.parent.name === X ? X.parent : void 0;
              }
            }
            function Cr(X, Te) {
              var we = er(X);
              if (we) {
                var he = Te.getContextualType(we.parent), yr = he && Ce(we, Te, he, false);
                if (yr && yr.length === 1)
                  return e.first(yr);
              }
              return Te.getSymbolAtLocation(X);
            }
            function Ce(X, Te, we, he) {
              var yr = e.getNameFromPropertyName(X.name);
              if (!yr)
                return e.emptyArray;
              if (!we.isUnion()) {
                var kr = we.getProperty(yr);
                return kr ? [kr] : e.emptyArray;
              }
              var nr = e.mapDefined(we.types, function(tr) {
                return (e.isObjectLiteralExpression(X.parent) || e.isJsxAttributes(X.parent)) && Te.isTypeInvalidDueToUnionDiscriminant(tr, X.parent) ? void 0 : tr.getProperty(yr);
              });
              if (he && (nr.length === 0 || nr.length === we.types.length)) {
                var kr = we.getProperty(yr);
                if (kr)
                  return [kr];
              }
              return nr.length === 0 ? e.mapDefined(we.types, function(tr) {
                return tr.getProperty(yr);
              }) : nr;
            }
            e.getPropertySymbolsFromContextualType = Ce;
            function $e(X) {
              return X && X.parent && X.parent.kind === 209 && X.parent.argumentExpression === X;
            }
            function gr(X) {
              return e.combinePaths("/prettier-security-dirname-placeholder", e.getDefaultLibFileName(X));
            }
            e.getDefaultLibFilePath = gr, e.setObjectAllocator(v());
          })(N || (N = {})), _.exports = N;
        } }), Sl = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/internal/constants.js"(a, _) {
          Jr();
          var D = "2.0.0", T = 256, ae = Number.MAX_SAFE_INTEGER || 9007199254740991, z = 16;
          _.exports = { SEMVER_SPEC_VERSION: D, MAX_LENGTH: T, MAX_SAFE_INTEGER: ae, MAX_SAFE_COMPONENT_LENGTH: z };
        } }), Cl = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/internal/debug.js"(a, _) {
          Jr();
          var D = typeof ba == "object" && ba.env && ba.env.NODE_DEBUG && /\bsemver\b/i.test(ba.env.NODE_DEBUG) ? function() {
            for (var T = arguments.length, ae = new Array(T), z = 0; z < T; z++)
              ae[z] = arguments[z];
            return console.error("SEMVER", ...ae);
          } : () => {
          };
          _.exports = D;
        } }), Bc = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/internal/re.js"(a, _) {
          Jr();
          var { MAX_SAFE_COMPONENT_LENGTH: D } = Sl(), T = Cl();
          a = _.exports = {};
          var ae = a.re = [], z = a.src = [], I = a.t = {}, E = 0, N = (e, t3, w) => {
            let s = E++;
            T(e, s, t3), I[e] = s, z[s] = t3, ae[s] = new RegExp(t3, w ? "g" : void 0);
          };
          N("NUMERICIDENTIFIER", "0|[1-9]\\d*"), N("NUMERICIDENTIFIERLOOSE", "[0-9]+"), N("NONNUMERICIDENTIFIER", "\\d*[a-zA-Z-][a-zA-Z0-9-]*"), N("MAINVERSION", `(${z[I.NUMERICIDENTIFIER]})\\.(${z[I.NUMERICIDENTIFIER]})\\.(${z[I.NUMERICIDENTIFIER]})`), N("MAINVERSIONLOOSE", `(${z[I.NUMERICIDENTIFIERLOOSE]})\\.(${z[I.NUMERICIDENTIFIERLOOSE]})\\.(${z[I.NUMERICIDENTIFIERLOOSE]})`), N("PRERELEASEIDENTIFIER", `(?:${z[I.NUMERICIDENTIFIER]}|${z[I.NONNUMERICIDENTIFIER]})`), N("PRERELEASEIDENTIFIERLOOSE", `(?:${z[I.NUMERICIDENTIFIERLOOSE]}|${z[I.NONNUMERICIDENTIFIER]})`), N("PRERELEASE", `(?:-(${z[I.PRERELEASEIDENTIFIER]}(?:\\.${z[I.PRERELEASEIDENTIFIER]})*))`), N("PRERELEASELOOSE", `(?:-?(${z[I.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${z[I.PRERELEASEIDENTIFIERLOOSE]})*))`), N("BUILDIDENTIFIER", "[0-9A-Za-z-]+"), N("BUILD", `(?:\\+(${z[I.BUILDIDENTIFIER]}(?:\\.${z[I.BUILDIDENTIFIER]})*))`), N("FULLPLAIN", `v?${z[I.MAINVERSION]}${z[I.PRERELEASE]}?${z[I.BUILD]}?`), N("FULL", `^${z[I.FULLPLAIN]}$`), N("LOOSEPLAIN", `[v=\\s]*${z[I.MAINVERSIONLOOSE]}${z[I.PRERELEASELOOSE]}?${z[I.BUILD]}?`), N("LOOSE", `^${z[I.LOOSEPLAIN]}$`), N("GTLT", "((?:<|>)?=?)"), N("XRANGEIDENTIFIERLOOSE", `${z[I.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`), N("XRANGEIDENTIFIER", `${z[I.NUMERICIDENTIFIER]}|x|X|\\*`), N("XRANGEPLAIN", `[v=\\s]*(${z[I.XRANGEIDENTIFIER]})(?:\\.(${z[I.XRANGEIDENTIFIER]})(?:\\.(${z[I.XRANGEIDENTIFIER]})(?:${z[I.PRERELEASE]})?${z[I.BUILD]}?)?)?`), N("XRANGEPLAINLOOSE", `[v=\\s]*(${z[I.XRANGEIDENTIFIERLOOSE]})(?:\\.(${z[I.XRANGEIDENTIFIERLOOSE]})(?:\\.(${z[I.XRANGEIDENTIFIERLOOSE]})(?:${z[I.PRERELEASELOOSE]})?${z[I.BUILD]}?)?)?`), N("XRANGE", `^${z[I.GTLT]}\\s*${z[I.XRANGEPLAIN]}$`), N("XRANGELOOSE", `^${z[I.GTLT]}\\s*${z[I.XRANGEPLAINLOOSE]}$`), N("COERCE", `(^|[^\\d])(\\d{1,${D}})(?:\\.(\\d{1,${D}}))?(?:\\.(\\d{1,${D}}))?(?:$|[^\\d])`), N("COERCERTL", z[I.COERCE], true), N("LONETILDE", "(?:~>?)"), N("TILDETRIM", `(\\s*)${z[I.LONETILDE]}\\s+`, true), a.tildeTrimReplace = "$1~", N("TILDE", `^${z[I.LONETILDE]}${z[I.XRANGEPLAIN]}$`), N("TILDELOOSE", `^${z[I.LONETILDE]}${z[I.XRANGEPLAINLOOSE]}$`), N("LONECARET", "(?:\\^)"), N("CARETTRIM", `(\\s*)${z[I.LONECARET]}\\s+`, true), a.caretTrimReplace = "$1^", N("CARET", `^${z[I.LONECARET]}${z[I.XRANGEPLAIN]}$`), N("CARETLOOSE", `^${z[I.LONECARET]}${z[I.XRANGEPLAINLOOSE]}$`), N("COMPARATORLOOSE", `^${z[I.GTLT]}\\s*(${z[I.LOOSEPLAIN]})$|^$`), N("COMPARATOR", `^${z[I.GTLT]}\\s*(${z[I.FULLPLAIN]})$|^$`), N("COMPARATORTRIM", `(\\s*)${z[I.GTLT]}\\s*(${z[I.LOOSEPLAIN]}|${z[I.XRANGEPLAIN]})`, true), a.comparatorTrimReplace = "$1$2$3", N("HYPHENRANGE", `^\\s*(${z[I.XRANGEPLAIN]})\\s+-\\s+(${z[I.XRANGEPLAIN]})\\s*$`), N("HYPHENRANGELOOSE", `^\\s*(${z[I.XRANGEPLAINLOOSE]})\\s+-\\s+(${z[I.XRANGEPLAINLOOSE]})\\s*$`), N("STAR", "(<|>)?=?\\s*\\*"), N("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$"), N("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
        } }), Dl = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/internal/parse-options.js"(a, _) {
          Jr();
          var D = ["includePrerelease", "loose", "rtl"], T = (ae) => ae ? typeof ae != "object" ? { loose: true } : D.filter((z) => ae[z]).reduce((z, I) => (z[I] = true, z), {}) : {};
          _.exports = T;
        } }), fy = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/internal/identifiers.js"(a, _) {
          Jr();
          var D = /^[0-9]+$/, T = (z, I) => {
            let E = D.test(z), N = D.test(I);
            return E && N && (z = +z, I = +I), z === I ? 0 : E && !N ? -1 : N && !E ? 1 : z < I ? -1 : 1;
          }, ae = (z, I) => T(I, z);
          _.exports = { compareIdentifiers: T, rcompareIdentifiers: ae };
        } }), fa = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/classes/semver.js"(a, _) {
          Jr();
          var D = Cl(), { MAX_LENGTH: T, MAX_SAFE_INTEGER: ae } = Sl(), { re: z, t: I } = Bc(), E = Dl(), { compareIdentifiers: N } = fy(), e = class {
            constructor(t3, w) {
              if (w = E(w), t3 instanceof e) {
                if (t3.loose === !!w.loose && t3.includePrerelease === !!w.includePrerelease)
                  return t3;
                t3 = t3.version;
              } else if (typeof t3 != "string")
                throw new TypeError(`Invalid Version: ${t3}`);
              if (t3.length > T)
                throw new TypeError(`version is longer than ${T} characters`);
              D("SemVer", t3, w), this.options = w, this.loose = !!w.loose, this.includePrerelease = !!w.includePrerelease;
              let s = t3.trim().match(w.loose ? z[I.LOOSE] : z[I.FULL]);
              if (!s)
                throw new TypeError(`Invalid Version: ${t3}`);
              if (this.raw = t3, this.major = +s[1], this.minor = +s[2], this.patch = +s[3], this.major > ae || this.major < 0)
                throw new TypeError("Invalid major version");
              if (this.minor > ae || this.minor < 0)
                throw new TypeError("Invalid minor version");
              if (this.patch > ae || this.patch < 0)
                throw new TypeError("Invalid patch version");
              s[4] ? this.prerelease = s[4].split(".").map((q) => {
                if (/^[0-9]+$/.test(q)) {
                  let F = +q;
                  if (F >= 0 && F < ae)
                    return F;
                }
                return q;
              }) : this.prerelease = [], this.build = s[5] ? s[5].split(".") : [], this.format();
            }
            format() {
              return this.version = `${this.major}.${this.minor}.${this.patch}`, this.prerelease.length && (this.version += `-${this.prerelease.join(".")}`), this.version;
            }
            toString() {
              return this.version;
            }
            compare(t3) {
              if (D("SemVer.compare", this.version, this.options, t3), !(t3 instanceof e)) {
                if (typeof t3 == "string" && t3 === this.version)
                  return 0;
                t3 = new e(t3, this.options);
              }
              return t3.version === this.version ? 0 : this.compareMain(t3) || this.comparePre(t3);
            }
            compareMain(t3) {
              return t3 instanceof e || (t3 = new e(t3, this.options)), N(this.major, t3.major) || N(this.minor, t3.minor) || N(this.patch, t3.patch);
            }
            comparePre(t3) {
              if (t3 instanceof e || (t3 = new e(t3, this.options)), this.prerelease.length && !t3.prerelease.length)
                return -1;
              if (!this.prerelease.length && t3.prerelease.length)
                return 1;
              if (!this.prerelease.length && !t3.prerelease.length)
                return 0;
              let w = 0;
              do {
                let s = this.prerelease[w], q = t3.prerelease[w];
                if (D("prerelease compare", w, s, q), s === void 0 && q === void 0)
                  return 0;
                if (q === void 0)
                  return 1;
                if (s === void 0)
                  return -1;
                if (s === q)
                  continue;
                return N(s, q);
              } while (++w);
            }
            compareBuild(t3) {
              t3 instanceof e || (t3 = new e(t3, this.options));
              let w = 0;
              do {
                let s = this.build[w], q = t3.build[w];
                if (D("prerelease compare", w, s, q), s === void 0 && q === void 0)
                  return 0;
                if (q === void 0)
                  return 1;
                if (s === void 0)
                  return -1;
                if (s === q)
                  continue;
                return N(s, q);
              } while (++w);
            }
            inc(t3, w) {
              switch (t3) {
                case "premajor":
                  this.prerelease.length = 0, this.patch = 0, this.minor = 0, this.major++, this.inc("pre", w);
                  break;
                case "preminor":
                  this.prerelease.length = 0, this.patch = 0, this.minor++, this.inc("pre", w);
                  break;
                case "prepatch":
                  this.prerelease.length = 0, this.inc("patch", w), this.inc("pre", w);
                  break;
                case "prerelease":
                  this.prerelease.length === 0 && this.inc("patch", w), this.inc("pre", w);
                  break;
                case "major":
                  (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) && this.major++, this.minor = 0, this.patch = 0, this.prerelease = [];
                  break;
                case "minor":
                  (this.patch !== 0 || this.prerelease.length === 0) && this.minor++, this.patch = 0, this.prerelease = [];
                  break;
                case "patch":
                  this.prerelease.length === 0 && this.patch++, this.prerelease = [];
                  break;
                case "pre":
                  if (this.prerelease.length === 0)
                    this.prerelease = [0];
                  else {
                    let s = this.prerelease.length;
                    for (; --s >= 0; )
                      typeof this.prerelease[s] == "number" && (this.prerelease[s]++, s = -2);
                    s === -1 && this.prerelease.push(0);
                  }
                  w && (N(this.prerelease[0], w) === 0 ? isNaN(this.prerelease[1]) && (this.prerelease = [w, 0]) : this.prerelease = [w, 0]);
                  break;
                default:
                  throw new Error(`invalid increment argument: ${t3}`);
              }
              return this.format(), this.raw = this.version, this;
            }
          };
          _.exports = e;
        } }), qc = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/parse.js"(a, _) {
          Jr();
          var { MAX_LENGTH: D } = Sl(), { re: T, t: ae } = Bc(), z = fa(), I = Dl(), E = (N, e) => {
            if (e = I(e), N instanceof z)
              return N;
            if (typeof N != "string" || N.length > D || !(e.loose ? T[ae.LOOSE] : T[ae.FULL]).test(N))
              return null;
            try {
              return new z(N, e);
            } catch {
              return null;
            }
          };
          _.exports = E;
        } }), aE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/valid.js"(a, _) {
          Jr();
          var D = qc(), T = (ae, z) => {
            let I = D(ae, z);
            return I ? I.version : null;
          };
          _.exports = T;
        } }), oE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/clean.js"(a, _) {
          Jr();
          var D = qc(), T = (ae, z) => {
            let I = D(ae.trim().replace(/^[=v]+/, ""), z);
            return I ? I.version : null;
          };
          _.exports = T;
        } }), sE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/inc.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z, I, E) => {
            typeof I == "string" && (E = I, I = void 0);
            try {
              return new D(ae instanceof D ? ae.version : ae, I).inc(z, E).version;
            } catch {
              return null;
            }
          };
          _.exports = T;
        } }), eo = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/compare.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z, I) => new D(ae, I).compare(new D(z, I));
          _.exports = T;
        } }), Yp = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/eq.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) === 0;
          _.exports = T;
        } }), _E = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/diff.js"(a, _) {
          Jr();
          var D = qc(), T = Yp(), ae = (z, I) => {
            if (T(z, I))
              return null;
            {
              let E = D(z), N = D(I), e = E.prerelease.length || N.prerelease.length, t3 = e ? "pre" : "", w = e ? "prerelease" : "";
              for (let s in E)
                if ((s === "major" || s === "minor" || s === "patch") && E[s] !== N[s])
                  return t3 + s;
              return w;
            }
          };
          _.exports = ae;
        } }), cE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/major.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z) => new D(ae, z).major;
          _.exports = T;
        } }), uE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/minor.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z) => new D(ae, z).minor;
          _.exports = T;
        } }), lE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/patch.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z) => new D(ae, z).patch;
          _.exports = T;
        } }), pE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/prerelease.js"(a, _) {
          Jr();
          var D = qc(), T = (ae, z) => {
            let I = D(ae, z);
            return I && I.prerelease.length ? I.prerelease : null;
          };
          _.exports = T;
        } }), fE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/rcompare.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(z, ae, I);
          _.exports = T;
        } }), dE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/compare-loose.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z) => D(ae, z, true);
          _.exports = T;
        } }), Zp = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/compare-build.js"(a, _) {
          Jr();
          var D = fa(), T = (ae, z, I) => {
            let E = new D(ae, I), N = new D(z, I);
            return E.compare(N) || E.compareBuild(N);
          };
          _.exports = T;
        } }), mE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/sort.js"(a, _) {
          Jr();
          var D = Zp(), T = (ae, z) => ae.sort((I, E) => D(I, E, z));
          _.exports = T;
        } }), gE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/rsort.js"(a, _) {
          Jr();
          var D = Zp(), T = (ae, z) => ae.sort((I, E) => D(E, I, z));
          _.exports = T;
        } }), xl = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/gt.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) > 0;
          _.exports = T;
        } }), ef = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/lt.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) < 0;
          _.exports = T;
        } }), dy = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/neq.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) !== 0;
          _.exports = T;
        } }), rf = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/gte.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) >= 0;
          _.exports = T;
        } }), tf = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/lte.js"(a, _) {
          Jr();
          var D = eo(), T = (ae, z, I) => D(ae, z, I) <= 0;
          _.exports = T;
        } }), my = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/cmp.js"(a, _) {
          Jr();
          var D = Yp(), T = dy(), ae = xl(), z = rf(), I = ef(), E = tf(), N = (e, t3, w, s) => {
            switch (t3) {
              case "===":
                return typeof e == "object" && (e = e.version), typeof w == "object" && (w = w.version), e === w;
              case "!==":
                return typeof e == "object" && (e = e.version), typeof w == "object" && (w = w.version), e !== w;
              case "":
              case "=":
              case "==":
                return D(e, w, s);
              case "!=":
                return T(e, w, s);
              case ">":
                return ae(e, w, s);
              case ">=":
                return z(e, w, s);
              case "<":
                return I(e, w, s);
              case "<=":
                return E(e, w, s);
              default:
                throw new TypeError(`Invalid operator: ${t3}`);
            }
          };
          _.exports = N;
        } }), yE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/coerce.js"(a, _) {
          Jr();
          var D = fa(), T = qc(), { re: ae, t: z } = Bc(), I = (E, N) => {
            if (E instanceof D)
              return E;
            if (typeof E == "number" && (E = String(E)), typeof E != "string")
              return null;
            N = N || {};
            let e = null;
            if (!N.rtl)
              e = E.match(ae[z.COERCE]);
            else {
              let t3;
              for (; (t3 = ae[z.COERCERTL].exec(E)) && (!e || e.index + e[0].length !== E.length); )
                (!e || t3.index + t3[0].length !== e.index + e[0].length) && (e = t3), ae[z.COERCERTL].lastIndex = t3.index + t3[1].length + t3[2].length;
              ae[z.COERCERTL].lastIndex = -1;
            }
            return e === null ? null : T(`${e[2]}.${e[3] || "0"}.${e[4] || "0"}`, N);
          };
          _.exports = I;
        } }), hE = Ur({ "node_modules/yallist/iterator.js"(a, _) {
          "use strict";
          Jr(), _.exports = function(D) {
            D.prototype[Symbol.iterator] = function* () {
              for (let T = this.head; T; T = T.next)
                yield T.value;
            };
          };
        } }), vE = Ur({ "node_modules/yallist/yallist.js"(a, _) {
          "use strict";
          Jr(), _.exports = D, D.Node = I, D.create = D;
          function D(E) {
            var N = this;
            if (N instanceof D || (N = new D()), N.tail = null, N.head = null, N.length = 0, E && typeof E.forEach == "function")
              E.forEach(function(w) {
                N.push(w);
              });
            else if (arguments.length > 0)
              for (var e = 0, t3 = arguments.length; e < t3; e++)
                N.push(arguments[e]);
            return N;
          }
          D.prototype.removeNode = function(E) {
            if (E.list !== this)
              throw new Error("removing node which does not belong to this list");
            var N = E.next, e = E.prev;
            return N && (N.prev = e), e && (e.next = N), E === this.head && (this.head = N), E === this.tail && (this.tail = e), E.list.length--, E.next = null, E.prev = null, E.list = null, N;
          }, D.prototype.unshiftNode = function(E) {
            if (E !== this.head) {
              E.list && E.list.removeNode(E);
              var N = this.head;
              E.list = this, E.next = N, N && (N.prev = E), this.head = E, this.tail || (this.tail = E), this.length++;
            }
          }, D.prototype.pushNode = function(E) {
            if (E !== this.tail) {
              E.list && E.list.removeNode(E);
              var N = this.tail;
              E.list = this, E.prev = N, N && (N.next = E), this.tail = E, this.head || (this.head = E), this.length++;
            }
          }, D.prototype.push = function() {
            for (var E = 0, N = arguments.length; E < N; E++)
              ae(this, arguments[E]);
            return this.length;
          }, D.prototype.unshift = function() {
            for (var E = 0, N = arguments.length; E < N; E++)
              z(this, arguments[E]);
            return this.length;
          }, D.prototype.pop = function() {
            if (this.tail) {
              var E = this.tail.value;
              return this.tail = this.tail.prev, this.tail ? this.tail.next = null : this.head = null, this.length--, E;
            }
          }, D.prototype.shift = function() {
            if (this.head) {
              var E = this.head.value;
              return this.head = this.head.next, this.head ? this.head.prev = null : this.tail = null, this.length--, E;
            }
          }, D.prototype.forEach = function(E, N) {
            N = N || this;
            for (var e = this.head, t3 = 0; e !== null; t3++)
              E.call(N, e.value, t3, this), e = e.next;
          }, D.prototype.forEachReverse = function(E, N) {
            N = N || this;
            for (var e = this.tail, t3 = this.length - 1; e !== null; t3--)
              E.call(N, e.value, t3, this), e = e.prev;
          }, D.prototype.get = function(E) {
            for (var N = 0, e = this.head; e !== null && N < E; N++)
              e = e.next;
            if (N === E && e !== null)
              return e.value;
          }, D.prototype.getReverse = function(E) {
            for (var N = 0, e = this.tail; e !== null && N < E; N++)
              e = e.prev;
            if (N === E && e !== null)
              return e.value;
          }, D.prototype.map = function(E, N) {
            N = N || this;
            for (var e = new D(), t3 = this.head; t3 !== null; )
              e.push(E.call(N, t3.value, this)), t3 = t3.next;
            return e;
          }, D.prototype.mapReverse = function(E, N) {
            N = N || this;
            for (var e = new D(), t3 = this.tail; t3 !== null; )
              e.push(E.call(N, t3.value, this)), t3 = t3.prev;
            return e;
          }, D.prototype.reduce = function(E, N) {
            var e, t3 = this.head;
            if (arguments.length > 1)
              e = N;
            else if (this.head)
              t3 = this.head.next, e = this.head.value;
            else
              throw new TypeError("Reduce of empty list with no initial value");
            for (var w = 0; t3 !== null; w++)
              e = E(e, t3.value, w), t3 = t3.next;
            return e;
          }, D.prototype.reduceReverse = function(E, N) {
            var e, t3 = this.tail;
            if (arguments.length > 1)
              e = N;
            else if (this.tail)
              t3 = this.tail.prev, e = this.tail.value;
            else
              throw new TypeError("Reduce of empty list with no initial value");
            for (var w = this.length - 1; t3 !== null; w--)
              e = E(e, t3.value, w), t3 = t3.prev;
            return e;
          }, D.prototype.toArray = function() {
            for (var E = new Array(this.length), N = 0, e = this.head; e !== null; N++)
              E[N] = e.value, e = e.next;
            return E;
          }, D.prototype.toArrayReverse = function() {
            for (var E = new Array(this.length), N = 0, e = this.tail; e !== null; N++)
              E[N] = e.value, e = e.prev;
            return E;
          }, D.prototype.slice = function(E, N) {
            N = N || this.length, N < 0 && (N += this.length), E = E || 0, E < 0 && (E += this.length);
            var e = new D();
            if (N < E || N < 0)
              return e;
            E < 0 && (E = 0), N > this.length && (N = this.length);
            for (var t3 = 0, w = this.head; w !== null && t3 < E; t3++)
              w = w.next;
            for (; w !== null && t3 < N; t3++, w = w.next)
              e.push(w.value);
            return e;
          }, D.prototype.sliceReverse = function(E, N) {
            N = N || this.length, N < 0 && (N += this.length), E = E || 0, E < 0 && (E += this.length);
            var e = new D();
            if (N < E || N < 0)
              return e;
            E < 0 && (E = 0), N > this.length && (N = this.length);
            for (var t3 = this.length, w = this.tail; w !== null && t3 > N; t3--)
              w = w.prev;
            for (; w !== null && t3 > E; t3--, w = w.prev)
              e.push(w.value);
            return e;
          }, D.prototype.splice = function(E, N) {
            E > this.length && (E = this.length - 1), E < 0 && (E = this.length + E);
            for (var e = 0, t3 = this.head; t3 !== null && e < E; e++)
              t3 = t3.next;
            for (var w = [], e = 0; t3 && e < N; e++)
              w.push(t3.value), t3 = this.removeNode(t3);
            t3 === null && (t3 = this.tail), t3 !== this.head && t3 !== this.tail && (t3 = t3.prev);
            for (var e = 0; e < (arguments.length <= 2 ? 0 : arguments.length - 2); e++)
              t3 = T(this, t3, e + 2 < 2 || arguments.length <= e + 2 ? void 0 : arguments[e + 2]);
            return w;
          }, D.prototype.reverse = function() {
            for (var E = this.head, N = this.tail, e = E; e !== null; e = e.prev) {
              var t3 = e.prev;
              e.prev = e.next, e.next = t3;
            }
            return this.head = N, this.tail = E, this;
          };
          function T(E, N, e) {
            var t3 = N === E.head ? new I(e, null, N, E) : new I(e, N, N.next, E);
            return t3.next === null && (E.tail = t3), t3.prev === null && (E.head = t3), E.length++, t3;
          }
          function ae(E, N) {
            E.tail = new I(N, E.tail, null, E), E.head || (E.head = E.tail), E.length++;
          }
          function z(E, N) {
            E.head = new I(N, null, E.head, E), E.tail || (E.tail = E.head), E.length++;
          }
          function I(E, N, e, t3) {
            if (!(this instanceof I))
              return new I(E, N, e, t3);
            this.list = t3, this.value = E, N ? (N.next = this, this.prev = N) : this.prev = null, e ? (e.prev = this, this.next = e) : this.next = null;
          }
          try {
            hE()(D);
          } catch {
          }
        } }), bE = Ur({ "node_modules/lru-cache/index.js"(a, _) {
          "use strict";
          Jr();
          var D = vE(), T = Symbol("max"), ae = Symbol("length"), z = Symbol("lengthCalculator"), I = Symbol("allowStale"), E = Symbol("maxAge"), N = Symbol("dispose"), e = Symbol("noDisposeOnSet"), t3 = Symbol("lruList"), w = Symbol("cache"), s = Symbol("updateAgeOnGet"), q = () => 1, F = class {
            constructor(Q) {
              if (typeof Q == "number" && (Q = { max: Q }), Q || (Q = {}), Q.max && (typeof Q.max != "number" || Q.max < 0))
                throw new TypeError("max must be a non-negative number");
              let Be = this[T] = Q.max || 1 / 0, je = Q.length || q;
              if (this[z] = typeof je != "function" ? q : je, this[I] = Q.stale || false, Q.maxAge && typeof Q.maxAge != "number")
                throw new TypeError("maxAge must be a number");
              this[E] = Q.maxAge || 0, this[N] = Q.dispose, this[e] = Q.noDisposeOnSet || false, this[s] = Q.updateAgeOnGet || false, this.reset();
            }
            set max(Q) {
              if (typeof Q != "number" || Q < 0)
                throw new TypeError("max must be a non-negative number");
              this[T] = Q || 1 / 0, Se(this);
            }
            get max() {
              return this[T];
            }
            set allowStale(Q) {
              this[I] = !!Q;
            }
            get allowStale() {
              return this[I];
            }
            set maxAge(Q) {
              if (typeof Q != "number")
                throw new TypeError("maxAge must be a non-negative number");
              this[E] = Q, Se(this);
            }
            get maxAge() {
              return this[E];
            }
            set lengthCalculator(Q) {
              typeof Q != "function" && (Q = q), Q !== this[z] && (this[z] = Q, this[ae] = 0, this[t3].forEach((Be) => {
                Be.length = this[z](Be.value, Be.key), this[ae] += Be.length;
              })), Se(this);
            }
            get lengthCalculator() {
              return this[z];
            }
            get length() {
              return this[ae];
            }
            get itemCount() {
              return this[t3].length;
            }
            rforEach(Q, Be) {
              Be = Be || this;
              for (let je = this[t3].tail; je !== null; ) {
                let V = je.prev;
                Me(this, Q, je, Be), je = V;
              }
            }
            forEach(Q, Be) {
              Be = Be || this;
              for (let je = this[t3].head; je !== null; ) {
                let V = je.next;
                Me(this, Q, je, Be), je = V;
              }
            }
            keys() {
              return this[t3].toArray().map((Q) => Q.key);
            }
            values() {
              return this[t3].toArray().map((Q) => Q.value);
            }
            reset() {
              this[N] && this[t3] && this[t3].length && this[t3].forEach((Q) => this[N](Q.key, Q.value)), this[w] = /* @__PURE__ */ new Map(), this[t3] = new D(), this[ae] = 0;
            }
            dump() {
              return this[t3].map((Q) => Ee(this, Q) ? false : { k: Q.key, v: Q.value, e: Q.now + (Q.maxAge || 0) }).toArray().filter((Q) => Q);
            }
            dumpLru() {
              return this[t3];
            }
            set(Q, Be, je) {
              if (je = je || this[E], je && typeof je != "number")
                throw new TypeError("maxAge must be a number");
              let V = je ? Date.now() : 0, B = this[z](Be, Q);
              if (this[w].has(Q)) {
                if (B > this[T])
                  return J(this, this[w].get(Q)), false;
                let v = this[w].get(Q).value;
                return this[N] && (this[e] || this[N](Q, v.value)), v.now = V, v.maxAge = je, v.value = Be, this[ae] += B - v.length, v.length = B, this.get(Q), Se(this), true;
              }
              let U = new se(Q, Be, B, V, je);
              return U.length > this[T] ? (this[N] && this[N](Q, Be), false) : (this[ae] += U.length, this[t3].unshift(U), this[w].set(Q, this[t3].head), Se(this), true);
            }
            has(Q) {
              if (!this[w].has(Q))
                return false;
              let Be = this[w].get(Q).value;
              return !Ee(this, Be);
            }
            get(Q) {
              return fe(this, Q, true);
            }
            peek(Q) {
              return fe(this, Q, false);
            }
            pop() {
              let Q = this[t3].tail;
              return Q ? (J(this, Q), Q.value) : null;
            }
            del(Q) {
              J(this, this[w].get(Q));
            }
            load(Q) {
              this.reset();
              let Be = Date.now();
              for (let je = Q.length - 1; je >= 0; je--) {
                let V = Q[je], B = V.e || 0;
                if (B === 0)
                  this.set(V.k, V.v);
                else {
                  let U = B - Be;
                  U > 0 && this.set(V.k, V.v, U);
                }
              }
            }
            prune() {
              this[w].forEach((Q, Be) => fe(this, Be, false));
            }
          }, fe = (Q, Be, je) => {
            let V = Q[w].get(Be);
            if (V) {
              let B = V.value;
              if (Ee(Q, B)) {
                if (J(Q, V), !Q[I])
                  return;
              } else
                je && (Q[s] && (V.value.now = Date.now()), Q[t3].unshiftNode(V));
              return B.value;
            }
          }, Ee = (Q, Be) => {
            if (!Be || !Be.maxAge && !Q[E])
              return false;
            let je = Date.now() - Be.now;
            return Be.maxAge ? je > Be.maxAge : Q[E] && je > Q[E];
          }, Se = (Q) => {
            if (Q[ae] > Q[T])
              for (let Be = Q[t3].tail; Q[ae] > Q[T] && Be !== null; ) {
                let je = Be.prev;
                J(Q, Be), Be = je;
              }
          }, J = (Q, Be) => {
            if (Be) {
              let je = Be.value;
              Q[N] && Q[N](je.key, je.value), Q[ae] -= je.length, Q[w].delete(je.key), Q[t3].removeNode(Be);
            }
          }, se = class {
            constructor(Q, Be, je, V, B) {
              this.key = Q, this.value = Be, this.length = je, this.now = V, this.maxAge = B || 0;
            }
          }, Me = (Q, Be, je, V) => {
            let B = je.value;
            Ee(Q, B) && (J(Q, je), Q[I] || (B = void 0)), B && Be.call(V, B.value, B.key, Q);
          };
          _.exports = F;
        } }), ro = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/classes/range.js"(a, _) {
          Jr();
          var D = class {
            constructor(g, O) {
              if (O = z(O), g instanceof D)
                return g.loose === !!O.loose && g.includePrerelease === !!O.includePrerelease ? g : new D(g.raw, O);
              if (g instanceof I)
                return this.raw = g.value, this.set = [[g]], this.format(), this;
              if (this.options = O, this.loose = !!O.loose, this.includePrerelease = !!O.includePrerelease, this.raw = g, this.set = g.split("||").map((S) => this.parseRange(S.trim())).filter((S) => S.length), !this.set.length)
                throw new TypeError(`Invalid SemVer Range: ${g}`);
              if (this.set.length > 1) {
                let S = this.set[0];
                if (this.set = this.set.filter((te) => !F(te[0])), this.set.length === 0)
                  this.set = [S];
                else if (this.set.length > 1) {
                  for (let te of this.set)
                    if (te.length === 1 && fe(te[0])) {
                      this.set = [te];
                      break;
                    }
                }
              }
              this.format();
            }
            format() {
              return this.range = this.set.map((g) => g.join(" ").trim()).join("||").trim(), this.range;
            }
            toString() {
              return this.range;
            }
            parseRange(g) {
              g = g.trim();
              let S = `parseRange:${Object.keys(this.options).join(",")}:${g}`, te = ae.get(S);
              if (te)
                return te;
              let Je = this.options.loose, qe = Je ? e[t3.HYPHENRANGELOOSE] : e[t3.HYPHENRANGE];
              g = g.replace(qe, m(this.options.includePrerelease)), E("hyphen replace", g), g = g.replace(e[t3.COMPARATORTRIM], w), E("comparator trim", g), g = g.replace(e[t3.TILDETRIM], s), g = g.replace(e[t3.CARETTRIM], q), g = g.split(/\s+/).join(" ");
              let ge = g.split(" ").map((j) => Se(j, this.options)).join(" ").split(/\s+/).map((j) => U(j, this.options));
              Je && (ge = ge.filter((j) => (E("loose invalid filter", j, this.options), !!j.match(e[t3.COMPARATORLOOSE])))), E("range list", ge);
              let ie = /* @__PURE__ */ new Map(), H = ge.map((j) => new I(j, this.options));
              for (let j of H) {
                if (F(j))
                  return [j];
                ie.set(j.value, j);
              }
              ie.size > 1 && ie.has("") && ie.delete("");
              let pe = [...ie.values()];
              return ae.set(S, pe), pe;
            }
            intersects(g, O) {
              if (!(g instanceof D))
                throw new TypeError("a Range is required");
              return this.set.some((S) => Ee(S, O) && g.set.some((te) => Ee(te, O) && S.every((Je) => te.every((qe) => Je.intersects(qe, O)))));
            }
            test(g) {
              if (!g)
                return false;
              if (typeof g == "string")
                try {
                  g = new N(g, this.options);
                } catch {
                  return false;
                }
              for (let O = 0; O < this.set.length; O++)
                if (v(this.set[O], g, this.options))
                  return true;
              return false;
            }
          };
          _.exports = D;
          var T = bE(), ae = new T({ max: 1e3 }), z = Dl(), I = wl(), E = Cl(), N = fa(), { re: e, t: t3, comparatorTrimReplace: w, tildeTrimReplace: s, caretTrimReplace: q } = Bc(), F = (g) => g.value === "<0.0.0-0", fe = (g) => g.value === "", Ee = (g, O) => {
            let S = true, te = g.slice(), Je = te.pop();
            for (; S && te.length; )
              S = te.every((qe) => Je.intersects(qe, O)), Je = te.pop();
            return S;
          }, Se = (g, O) => (E("comp", g, O), g = Q(g, O), E("caret", g), g = se(g, O), E("tildes", g), g = je(g, O), E("xrange", g), g = B(g, O), E("stars", g), g), J = (g) => !g || g.toLowerCase() === "x" || g === "*", se = (g, O) => g.trim().split(/\s+/).map((S) => Me(S, O)).join(" "), Me = (g, O) => {
            let S = O.loose ? e[t3.TILDELOOSE] : e[t3.TILDE];
            return g.replace(S, (te, Je, qe, ge, ie) => {
              E("tilde", g, te, Je, qe, ge, ie);
              let H;
              return J(Je) ? H = "" : J(qe) ? H = `>=${Je}.0.0 <${+Je + 1}.0.0-0` : J(ge) ? H = `>=${Je}.${qe}.0 <${Je}.${+qe + 1}.0-0` : ie ? (E("replaceTilde pr", ie), H = `>=${Je}.${qe}.${ge}-${ie} <${Je}.${+qe + 1}.0-0`) : H = `>=${Je}.${qe}.${ge} <${Je}.${+qe + 1}.0-0`, E("tilde return", H), H;
            });
          }, Q = (g, O) => g.trim().split(/\s+/).map((S) => Be(S, O)).join(" "), Be = (g, O) => {
            E("caret", g, O);
            let S = O.loose ? e[t3.CARETLOOSE] : e[t3.CARET], te = O.includePrerelease ? "-0" : "";
            return g.replace(S, (Je, qe, ge, ie, H) => {
              E("caret", g, Je, qe, ge, ie, H);
              let pe;
              return J(qe) ? pe = "" : J(ge) ? pe = `>=${qe}.0.0${te} <${+qe + 1}.0.0-0` : J(ie) ? qe === "0" ? pe = `>=${qe}.${ge}.0${te} <${qe}.${+ge + 1}.0-0` : pe = `>=${qe}.${ge}.0${te} <${+qe + 1}.0.0-0` : H ? (E("replaceCaret pr", H), qe === "0" ? ge === "0" ? pe = `>=${qe}.${ge}.${ie}-${H} <${qe}.${ge}.${+ie + 1}-0` : pe = `>=${qe}.${ge}.${ie}-${H} <${qe}.${+ge + 1}.0-0` : pe = `>=${qe}.${ge}.${ie}-${H} <${+qe + 1}.0.0-0`) : (E("no pr"), qe === "0" ? ge === "0" ? pe = `>=${qe}.${ge}.${ie}${te} <${qe}.${ge}.${+ie + 1}-0` : pe = `>=${qe}.${ge}.${ie}${te} <${qe}.${+ge + 1}.0-0` : pe = `>=${qe}.${ge}.${ie} <${+qe + 1}.0.0-0`), E("caret return", pe), pe;
            });
          }, je = (g, O) => (E("replaceXRanges", g, O), g.split(/\s+/).map((S) => V(S, O)).join(" ")), V = (g, O) => {
            g = g.trim();
            let S = O.loose ? e[t3.XRANGELOOSE] : e[t3.XRANGE];
            return g.replace(S, (te, Je, qe, ge, ie, H) => {
              E("xRange", g, te, Je, qe, ge, ie, H);
              let pe = J(qe), j = pe || J(ge), be = j || J(ie), Xe = be;
              return Je === "=" && Xe && (Je = ""), H = O.includePrerelease ? "-0" : "", pe ? Je === ">" || Je === "<" ? te = "<0.0.0-0" : te = "*" : Je && Xe ? (j && (ge = 0), ie = 0, Je === ">" ? (Je = ">=", j ? (qe = +qe + 1, ge = 0, ie = 0) : (ge = +ge + 1, ie = 0)) : Je === "<=" && (Je = "<", j ? qe = +qe + 1 : ge = +ge + 1), Je === "<" && (H = "-0"), te = `${Je + qe}.${ge}.${ie}${H}`) : j ? te = `>=${qe}.0.0${H} <${+qe + 1}.0.0-0` : be && (te = `>=${qe}.${ge}.0${H} <${qe}.${+ge + 1}.0-0`), E("xRange return", te), te;
            });
          }, B = (g, O) => (E("replaceStars", g, O), g.trim().replace(e[t3.STAR], "")), U = (g, O) => (E("replaceGTE0", g, O), g.trim().replace(e[O.includePrerelease ? t3.GTE0PRE : t3.GTE0], "")), m = (g) => (O, S, te, Je, qe, ge, ie, H, pe, j, be, Xe, Re) => (J(te) ? S = "" : J(Je) ? S = `>=${te}.0.0${g ? "-0" : ""}` : J(qe) ? S = `>=${te}.${Je}.0${g ? "-0" : ""}` : ge ? S = `>=${S}` : S = `>=${S}${g ? "-0" : ""}`, J(pe) ? H = "" : J(j) ? H = `<${+pe + 1}.0.0-0` : J(be) ? H = `<${pe}.${+j + 1}.0-0` : Xe ? H = `<=${pe}.${j}.${be}-${Xe}` : g ? H = `<${pe}.${j}.${+be + 1}-0` : H = `<=${H}`, `${S} ${H}`.trim()), v = (g, O, S) => {
            for (let te = 0; te < g.length; te++)
              if (!g[te].test(O))
                return false;
            if (O.prerelease.length && !S.includePrerelease) {
              for (let te = 0; te < g.length; te++)
                if (E(g[te].semver), g[te].semver !== I.ANY && g[te].semver.prerelease.length > 0) {
                  let Je = g[te].semver;
                  if (Je.major === O.major && Je.minor === O.minor && Je.patch === O.patch)
                    return true;
                }
              return false;
            }
            return true;
          };
        } }), wl = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/classes/comparator.js"(a, _) {
          Jr();
          var D = Symbol("SemVer ANY"), T = class {
            static get ANY() {
              return D;
            }
            constructor(w, s) {
              if (s = ae(s), w instanceof T) {
                if (w.loose === !!s.loose)
                  return w;
                w = w.value;
              }
              N("comparator", w, s), this.options = s, this.loose = !!s.loose, this.parse(w), this.semver === D ? this.value = "" : this.value = this.operator + this.semver.version, N("comp", this);
            }
            parse(w) {
              let s = this.options.loose ? z[I.COMPARATORLOOSE] : z[I.COMPARATOR], q = w.match(s);
              if (!q)
                throw new TypeError(`Invalid comparator: ${w}`);
              this.operator = q[1] !== void 0 ? q[1] : "", this.operator === "=" && (this.operator = ""), q[2] ? this.semver = new e(q[2], this.options.loose) : this.semver = D;
            }
            toString() {
              return this.value;
            }
            test(w) {
              if (N("Comparator.test", w, this.options.loose), this.semver === D || w === D)
                return true;
              if (typeof w == "string")
                try {
                  w = new e(w, this.options);
                } catch {
                  return false;
                }
              return E(w, this.operator, this.semver, this.options);
            }
            intersects(w, s) {
              if (!(w instanceof T))
                throw new TypeError("a Comparator is required");
              if ((!s || typeof s != "object") && (s = { loose: !!s, includePrerelease: false }), this.operator === "")
                return this.value === "" ? true : new t3(w.value, s).test(this.value);
              if (w.operator === "")
                return w.value === "" ? true : new t3(this.value, s).test(w.semver);
              let q = (this.operator === ">=" || this.operator === ">") && (w.operator === ">=" || w.operator === ">"), F = (this.operator === "<=" || this.operator === "<") && (w.operator === "<=" || w.operator === "<"), fe = this.semver.version === w.semver.version, Ee = (this.operator === ">=" || this.operator === "<=") && (w.operator === ">=" || w.operator === "<="), Se = E(this.semver, "<", w.semver, s) && (this.operator === ">=" || this.operator === ">") && (w.operator === "<=" || w.operator === "<"), J = E(this.semver, ">", w.semver, s) && (this.operator === "<=" || this.operator === "<") && (w.operator === ">=" || w.operator === ">");
              return q || F || fe && Ee || Se || J;
            }
          };
          _.exports = T;
          var ae = Dl(), { re: z, t: I } = Bc(), E = my(), N = Cl(), e = fa(), t3 = ro();
        } }), Al = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/functions/satisfies.js"(a, _) {
          Jr();
          var D = ro(), T = (ae, z, I) => {
            try {
              z = new D(z, I);
            } catch {
              return false;
            }
            return z.test(ae);
          };
          _.exports = T;
        } }), EE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/to-comparators.js"(a, _) {
          Jr();
          var D = ro(), T = (ae, z) => new D(ae, z).set.map((I) => I.map((E) => E.value).join(" ").trim().split(" "));
          _.exports = T;
        } }), TE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/max-satisfying.js"(a, _) {
          Jr();
          var D = fa(), T = ro(), ae = (z, I, E) => {
            let N = null, e = null, t3 = null;
            try {
              t3 = new T(I, E);
            } catch {
              return null;
            }
            return z.forEach((w) => {
              t3.test(w) && (!N || e.compare(w) === -1) && (N = w, e = new D(N, E));
            }), N;
          };
          _.exports = ae;
        } }), SE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/min-satisfying.js"(a, _) {
          Jr();
          var D = fa(), T = ro(), ae = (z, I, E) => {
            let N = null, e = null, t3 = null;
            try {
              t3 = new T(I, E);
            } catch {
              return null;
            }
            return z.forEach((w) => {
              t3.test(w) && (!N || e.compare(w) === 1) && (N = w, e = new D(N, E));
            }), N;
          };
          _.exports = ae;
        } }), CE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/min-version.js"(a, _) {
          Jr();
          var D = fa(), T = ro(), ae = xl(), z = (I, E) => {
            I = new T(I, E);
            let N = new D("0.0.0");
            if (I.test(N) || (N = new D("0.0.0-0"), I.test(N)))
              return N;
            N = null;
            for (let e = 0; e < I.set.length; ++e) {
              let t3 = I.set[e], w = null;
              t3.forEach((s) => {
                let q = new D(s.semver.version);
                switch (s.operator) {
                  case ">":
                    q.prerelease.length === 0 ? q.patch++ : q.prerelease.push(0), q.raw = q.format();
                  case "":
                  case ">=":
                    (!w || ae(q, w)) && (w = q);
                    break;
                  case "<":
                  case "<=":
                    break;
                  default:
                    throw new Error(`Unexpected operation: ${s.operator}`);
                }
              }), w && (!N || ae(N, w)) && (N = w);
            }
            return N && I.test(N) ? N : null;
          };
          _.exports = z;
        } }), DE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/valid.js"(a, _) {
          Jr();
          var D = ro(), T = (ae, z) => {
            try {
              return new D(ae, z).range || "*";
            } catch {
              return null;
            }
          };
          _.exports = T;
        } }), nf = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/outside.js"(a, _) {
          Jr();
          var D = fa(), T = wl(), { ANY: ae } = T, z = ro(), I = Al(), E = xl(), N = ef(), e = tf(), t3 = rf(), w = (s, q, F, fe) => {
            s = new D(s, fe), q = new z(q, fe);
            let Ee, Se, J, se, Me;
            switch (F) {
              case ">":
                Ee = E, Se = e, J = N, se = ">", Me = ">=";
                break;
              case "<":
                Ee = N, Se = t3, J = E, se = "<", Me = "<=";
                break;
              default:
                throw new TypeError('Must provide a hilo val of "<" or ">"');
            }
            if (I(s, q, fe))
              return false;
            for (let Q = 0; Q < q.set.length; ++Q) {
              let Be = q.set[Q], je = null, V = null;
              if (Be.forEach((B) => {
                B.semver === ae && (B = new T(">=0.0.0")), je = je || B, V = V || B, Ee(B.semver, je.semver, fe) ? je = B : J(B.semver, V.semver, fe) && (V = B);
              }), je.operator === se || je.operator === Me || (!V.operator || V.operator === se) && Se(s, V.semver))
                return false;
              if (V.operator === Me && J(s, V.semver))
                return false;
            }
            return true;
          };
          _.exports = w;
        } }), xE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/gtr.js"(a, _) {
          Jr();
          var D = nf(), T = (ae, z, I) => D(ae, z, ">", I);
          _.exports = T;
        } }), wE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/ltr.js"(a, _) {
          Jr();
          var D = nf(), T = (ae, z, I) => D(ae, z, "<", I);
          _.exports = T;
        } }), AE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/intersects.js"(a, _) {
          Jr();
          var D = ro(), T = (ae, z, I) => (ae = new D(ae, I), z = new D(z, I), ae.intersects(z));
          _.exports = T;
        } }), kE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/simplify.js"(a, _) {
          Jr();
          var D = Al(), T = eo();
          _.exports = (ae, z, I) => {
            let E = [], N = null, e = null, t3 = ae.sort((F, fe) => T(F, fe, I));
            for (let F of t3)
              D(F, z, I) ? (e = F, N || (N = F)) : (e && E.push([N, e]), e = null, N = null);
            N && E.push([N, null]);
            let w = [];
            for (let [F, fe] of E)
              F === fe ? w.push(F) : !fe && F === t3[0] ? w.push("*") : fe ? F === t3[0] ? w.push(`<=${fe}`) : w.push(`${F} - ${fe}`) : w.push(`>=${F}`);
            let s = w.join(" || "), q = typeof z.raw == "string" ? z.raw : String(z);
            return s.length < q.length ? s : z;
          };
        } }), PE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/ranges/subset.js"(a, _) {
          Jr();
          var D = ro(), T = wl(), { ANY: ae } = T, z = Al(), I = eo(), E = function(w, s) {
            let q = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
            if (w === s)
              return true;
            w = new D(w, q), s = new D(s, q);
            let F = false;
            e:
              for (let fe of w.set) {
                for (let Ee of s.set) {
                  let Se = N(fe, Ee, q);
                  if (F = F || Se !== null, Se)
                    continue e;
                }
                if (F)
                  return false;
              }
            return true;
          }, N = (w, s, q) => {
            if (w === s)
              return true;
            if (w.length === 1 && w[0].semver === ae) {
              if (s.length === 1 && s[0].semver === ae)
                return true;
              q.includePrerelease ? w = [new T(">=0.0.0-0")] : w = [new T(">=0.0.0")];
            }
            if (s.length === 1 && s[0].semver === ae) {
              if (q.includePrerelease)
                return true;
              s = [new T(">=0.0.0")];
            }
            let F = /* @__PURE__ */ new Set(), fe, Ee;
            for (let V of w)
              V.operator === ">" || V.operator === ">=" ? fe = e(fe, V, q) : V.operator === "<" || V.operator === "<=" ? Ee = t3(Ee, V, q) : F.add(V.semver);
            if (F.size > 1)
              return null;
            let Se;
            if (fe && Ee) {
              if (Se = I(fe.semver, Ee.semver, q), Se > 0)
                return null;
              if (Se === 0 && (fe.operator !== ">=" || Ee.operator !== "<="))
                return null;
            }
            for (let V of F) {
              if (fe && !z(V, String(fe), q) || Ee && !z(V, String(Ee), q))
                return null;
              for (let B of s)
                if (!z(V, String(B), q))
                  return false;
              return true;
            }
            let J, se, Me, Q, Be = Ee && !q.includePrerelease && Ee.semver.prerelease.length ? Ee.semver : false, je = fe && !q.includePrerelease && fe.semver.prerelease.length ? fe.semver : false;
            Be && Be.prerelease.length === 1 && Ee.operator === "<" && Be.prerelease[0] === 0 && (Be = false);
            for (let V of s) {
              if (Q = Q || V.operator === ">" || V.operator === ">=", Me = Me || V.operator === "<" || V.operator === "<=", fe) {
                if (je && V.semver.prerelease && V.semver.prerelease.length && V.semver.major === je.major && V.semver.minor === je.minor && V.semver.patch === je.patch && (je = false), V.operator === ">" || V.operator === ">=") {
                  if (J = e(fe, V, q), J === V && J !== fe)
                    return false;
                } else if (fe.operator === ">=" && !z(fe.semver, String(V), q))
                  return false;
              }
              if (Ee) {
                if (Be && V.semver.prerelease && V.semver.prerelease.length && V.semver.major === Be.major && V.semver.minor === Be.minor && V.semver.patch === Be.patch && (Be = false), V.operator === "<" || V.operator === "<=") {
                  if (se = t3(Ee, V, q), se === V && se !== Ee)
                    return false;
                } else if (Ee.operator === "<=" && !z(Ee.semver, String(V), q))
                  return false;
              }
              if (!V.operator && (Ee || fe) && Se !== 0)
                return false;
            }
            return !(fe && Me && !Ee && Se !== 0 || Ee && Q && !fe && Se !== 0 || je || Be);
          }, e = (w, s, q) => {
            if (!w)
              return s;
            let F = I(w.semver, s.semver, q);
            return F > 0 ? w : F < 0 || s.operator === ">" && w.operator === ">=" ? s : w;
          }, t3 = (w, s, q) => {
            if (!w)
              return s;
            let F = I(w.semver, s.semver, q);
            return F < 0 ? w : F > 0 || s.operator === "<" && w.operator === "<=" ? s : w;
          };
          _.exports = E;
        } }), af = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/semver/index.js"(a, _) {
          Jr();
          var D = Bc(), T = Sl(), ae = fa(), z = fy(), I = qc(), E = aE(), N = oE(), e = sE(), t3 = _E(), w = cE(), s = uE(), q = lE(), F = pE(), fe = eo(), Ee = fE(), Se = dE(), J = Zp(), se = mE(), Me = gE(), Q = xl(), Be = ef(), je = Yp(), V = dy(), B = rf(), U = tf(), m = my(), v = yE(), g = wl(), O = ro(), S = Al(), te = EE(), Je = TE(), qe = SE(), ge = CE(), ie = DE(), H = nf(), pe = xE(), j = wE(), be = AE(), Xe = kE(), Re = PE();
          _.exports = { parse: I, valid: E, clean: N, inc: e, diff: t3, major: w, minor: s, patch: q, prerelease: F, compare: fe, rcompare: Ee, compareLoose: Se, compareBuild: J, sort: se, rsort: Me, gt: Q, lt: Be, eq: je, neq: V, gte: B, lte: U, cmp: m, coerce: v, Comparator: g, Range: O, satisfies: S, toComparators: te, maxSatisfying: Je, minSatisfying: qe, minVersion: ge, validRange: ie, outside: H, gtr: pe, ltr: j, intersects: be, simplifyRange: Xe, subset: Re, SemVer: ae, re: D.re, src: D.src, tokens: D.t, SEMVER_SPEC_VERSION: T.SEMVER_SPEC_VERSION, compareIdentifiers: z.compareIdentifiers, rcompareIdentifiers: z.rcompareIdentifiers };
        } }), of = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/version-check.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(N, e, t3, w) {
            w === void 0 && (w = t3);
            var s = Object.getOwnPropertyDescriptor(e, t3);
            (!s || ("get" in s ? !e.__esModule : s.writable || s.configurable)) && (s = { enumerable: true, get: function() {
              return e[t3];
            } }), Object.defineProperty(N, w, s);
          } : function(N, e, t3, w) {
            w === void 0 && (w = t3), N[w] = e[t3];
          }), D = a && a.__setModuleDefault || (Object.create ? function(N, e) {
            Object.defineProperty(N, "default", { enumerable: true, value: e });
          } : function(N, e) {
            N.default = e;
          }), T = a && a.__importStar || function(N) {
            if (N && N.__esModule)
              return N;
            var e = {};
            if (N != null)
              for (var t3 in N)
                t3 !== "default" && Object.prototype.hasOwnProperty.call(N, t3) && _(e, N, t3);
            return D(e, N), e;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.typescriptVersionIsAtLeast = void 0;
          var ae = T(af()), z = T(Di()), I = ["3.7", "3.8", "3.9", "4.0", "4.1", "4.2", "4.3", "4.4", "4.5", "4.6", "4.7", "4.8"], E = {};
          a.typescriptVersionIsAtLeast = E;
          for (let N of I)
            E[N] = true;
        } }), sf = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/getModifiers.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(e, t3, w, s) {
            s === void 0 && (s = w);
            var q = Object.getOwnPropertyDescriptor(t3, w);
            (!q || ("get" in q ? !t3.__esModule : q.writable || q.configurable)) && (q = { enumerable: true, get: function() {
              return t3[w];
            } }), Object.defineProperty(e, s, q);
          } : function(e, t3, w, s) {
            s === void 0 && (s = w), e[s] = t3[w];
          }), D = a && a.__setModuleDefault || (Object.create ? function(e, t3) {
            Object.defineProperty(e, "default", { enumerable: true, value: t3 });
          } : function(e, t3) {
            e.default = t3;
          }), T = a && a.__importStar || function(e) {
            if (e && e.__esModule)
              return e;
            var t3 = {};
            if (e != null)
              for (var w in e)
                w !== "default" && Object.prototype.hasOwnProperty.call(e, w) && _(t3, e, w);
            return D(t3, e), t3;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.getDecorators = a.getModifiers = void 0;
          var ae = T(Di()), z = of(), I = z.typescriptVersionIsAtLeast["4.8"];
          function E(e) {
            var t3;
            if (e != null) {
              if (I) {
                if (ae.canHaveModifiers(e)) {
                  let w = ae.getModifiers(e);
                  return w ? Array.from(w) : void 0;
                }
                return;
              }
              return (t3 = e.modifiers) === null || t3 === void 0 ? void 0 : t3.filter((w) => !ae.isDecorator(w));
            }
          }
          a.getModifiers = E;
          function N(e) {
            var t3;
            if (e != null) {
              if (I) {
                if (ae.canHaveDecorators(e)) {
                  let w = ae.getDecorators(e);
                  return w ? Array.from(w) : void 0;
                }
                return;
              }
              return (t3 = e.decorators) === null || t3 === void 0 ? void 0 : t3.filter(ae.isDecorator);
            }
          }
          a.getDecorators = N;
        } }), NE = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/jsx/xhtml-entities.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.xhtmlEntities = void 0, a.xhtmlEntities = { quot: '"', amp: "&", apos: "'", lt: "<", gt: ">", nbsp: "\xA0", iexcl: "\xA1", cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", brvbar: "\xA6", sect: "\xA7", uml: "\xA8", copy: "\xA9", ordf: "\xAA", laquo: "\xAB", not: "\xAC", shy: "\xAD", reg: "\xAE", macr: "\xAF", deg: "\xB0", plusmn: "\xB1", sup2: "\xB2", sup3: "\xB3", acute: "\xB4", micro: "\xB5", para: "\xB6", middot: "\xB7", cedil: "\xB8", sup1: "\xB9", ordm: "\xBA", raquo: "\xBB", frac14: "\xBC", frac12: "\xBD", frac34: "\xBE", iquest: "\xBF", Agrave: "\xC0", Aacute: "\xC1", Acirc: "\xC2", Atilde: "\xC3", Auml: "\xC4", Aring: "\xC5", AElig: "\xC6", Ccedil: "\xC7", Egrave: "\xC8", Eacute: "\xC9", Ecirc: "\xCA", Euml: "\xCB", Igrave: "\xCC", Iacute: "\xCD", Icirc: "\xCE", Iuml: "\xCF", ETH: "\xD0", Ntilde: "\xD1", Ograve: "\xD2", Oacute: "\xD3", Ocirc: "\xD4", Otilde: "\xD5", Ouml: "\xD6", times: "\xD7", Oslash: "\xD8", Ugrave: "\xD9", Uacute: "\xDA", Ucirc: "\xDB", Uuml: "\xDC", Yacute: "\xDD", THORN: "\xDE", szlig: "\xDF", agrave: "\xE0", aacute: "\xE1", acirc: "\xE2", atilde: "\xE3", auml: "\xE4", aring: "\xE5", aelig: "\xE6", ccedil: "\xE7", egrave: "\xE8", eacute: "\xE9", ecirc: "\xEA", euml: "\xEB", igrave: "\xEC", iacute: "\xED", icirc: "\xEE", iuml: "\xEF", eth: "\xF0", ntilde: "\xF1", ograve: "\xF2", oacute: "\xF3", ocirc: "\xF4", otilde: "\xF5", ouml: "\xF6", divide: "\xF7", oslash: "\xF8", ugrave: "\xF9", uacute: "\xFA", ucirc: "\xFB", uuml: "\xFC", yacute: "\xFD", thorn: "\xFE", yuml: "\xFF", OElig: "\u0152", oelig: "\u0153", Scaron: "\u0160", scaron: "\u0161", Yuml: "\u0178", fnof: "\u0192", circ: "\u02C6", tilde: "\u02DC", Alpha: "\u0391", Beta: "\u0392", Gamma: "\u0393", Delta: "\u0394", Epsilon: "\u0395", Zeta: "\u0396", Eta: "\u0397", Theta: "\u0398", Iota: "\u0399", Kappa: "\u039A", Lambda: "\u039B", Mu: "\u039C", Nu: "\u039D", Xi: "\u039E", Omicron: "\u039F", Pi: "\u03A0", Rho: "\u03A1", Sigma: "\u03A3", Tau: "\u03A4", Upsilon: "\u03A5", Phi: "\u03A6", Chi: "\u03A7", Psi: "\u03A8", Omega: "\u03A9", alpha: "\u03B1", beta: "\u03B2", gamma: "\u03B3", delta: "\u03B4", epsilon: "\u03B5", zeta: "\u03B6", eta: "\u03B7", theta: "\u03B8", iota: "\u03B9", kappa: "\u03BA", lambda: "\u03BB", mu: "\u03BC", nu: "\u03BD", xi: "\u03BE", omicron: "\u03BF", pi: "\u03C0", rho: "\u03C1", sigmaf: "\u03C2", sigma: "\u03C3", tau: "\u03C4", upsilon: "\u03C5", phi: "\u03C6", chi: "\u03C7", psi: "\u03C8", omega: "\u03C9", thetasym: "\u03D1", upsih: "\u03D2", piv: "\u03D6", ensp: "\u2002", emsp: "\u2003", thinsp: "\u2009", zwnj: "\u200C", zwj: "\u200D", lrm: "\u200E", rlm: "\u200F", ndash: "\u2013", mdash: "\u2014", lsquo: "\u2018", rsquo: "\u2019", sbquo: "\u201A", ldquo: "\u201C", rdquo: "\u201D", bdquo: "\u201E", dagger: "\u2020", Dagger: "\u2021", bull: "\u2022", hellip: "\u2026", permil: "\u2030", prime: "\u2032", Prime: "\u2033", lsaquo: "\u2039", rsaquo: "\u203A", oline: "\u203E", frasl: "\u2044", euro: "\u20AC", image: "\u2111", weierp: "\u2118", real: "\u211C", trade: "\u2122", alefsym: "\u2135", larr: "\u2190", uarr: "\u2191", rarr: "\u2192", darr: "\u2193", harr: "\u2194", crarr: "\u21B5", lArr: "\u21D0", uArr: "\u21D1", rArr: "\u21D2", dArr: "\u21D3", hArr: "\u21D4", forall: "\u2200", part: "\u2202", exist: "\u2203", empty: "\u2205", nabla: "\u2207", isin: "\u2208", notin: "\u2209", ni: "\u220B", prod: "\u220F", sum: "\u2211", minus: "\u2212", lowast: "\u2217", radic: "\u221A", prop: "\u221D", infin: "\u221E", ang: "\u2220", and: "\u2227", or: "\u2228", cap: "\u2229", cup: "\u222A", int: "\u222B", there4: "\u2234", sim: "\u223C", cong: "\u2245", asymp: "\u2248", ne: "\u2260", equiv: "\u2261", le: "\u2264", ge: "\u2265", sub: "\u2282", sup: "\u2283", nsub: "\u2284", sube: "\u2286", supe: "\u2287", oplus: "\u2295", otimes: "\u2297", perp: "\u22A5", sdot: "\u22C5", lceil: "\u2308", rceil: "\u2309", lfloor: "\u230A", rfloor: "\u230B", lang: "\u2329", rang: "\u232A", loz: "\u25CA", spades: "\u2660", clubs: "\u2663", hearts: "\u2665", diams: "\u2666" };
        } }), gy = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/types/dist/generated/ast-spec.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.AST_TOKEN_TYPES = a.AST_NODE_TYPES = void 0;
          var _;
          (function(T) {
            T.AccessorProperty = "AccessorProperty", T.ArrayExpression = "ArrayExpression", T.ArrayPattern = "ArrayPattern", T.ArrowFunctionExpression = "ArrowFunctionExpression", T.AssignmentExpression = "AssignmentExpression", T.AssignmentPattern = "AssignmentPattern", T.AwaitExpression = "AwaitExpression", T.BinaryExpression = "BinaryExpression", T.BlockStatement = "BlockStatement", T.BreakStatement = "BreakStatement", T.CallExpression = "CallExpression", T.CatchClause = "CatchClause", T.ChainExpression = "ChainExpression", T.ClassBody = "ClassBody", T.ClassDeclaration = "ClassDeclaration", T.ClassExpression = "ClassExpression", T.ConditionalExpression = "ConditionalExpression", T.ContinueStatement = "ContinueStatement", T.DebuggerStatement = "DebuggerStatement", T.Decorator = "Decorator", T.DoWhileStatement = "DoWhileStatement", T.EmptyStatement = "EmptyStatement", T.ExportAllDeclaration = "ExportAllDeclaration", T.ExportDefaultDeclaration = "ExportDefaultDeclaration", T.ExportNamedDeclaration = "ExportNamedDeclaration", T.ExportSpecifier = "ExportSpecifier", T.ExpressionStatement = "ExpressionStatement", T.ForInStatement = "ForInStatement", T.ForOfStatement = "ForOfStatement", T.ForStatement = "ForStatement", T.FunctionDeclaration = "FunctionDeclaration", T.FunctionExpression = "FunctionExpression", T.Identifier = "Identifier", T.IfStatement = "IfStatement", T.ImportAttribute = "ImportAttribute", T.ImportDeclaration = "ImportDeclaration", T.ImportDefaultSpecifier = "ImportDefaultSpecifier", T.ImportExpression = "ImportExpression", T.ImportNamespaceSpecifier = "ImportNamespaceSpecifier", T.ImportSpecifier = "ImportSpecifier", T.JSXAttribute = "JSXAttribute", T.JSXClosingElement = "JSXClosingElement", T.JSXClosingFragment = "JSXClosingFragment", T.JSXElement = "JSXElement", T.JSXEmptyExpression = "JSXEmptyExpression", T.JSXExpressionContainer = "JSXExpressionContainer", T.JSXFragment = "JSXFragment", T.JSXIdentifier = "JSXIdentifier", T.JSXMemberExpression = "JSXMemberExpression", T.JSXNamespacedName = "JSXNamespacedName", T.JSXOpeningElement = "JSXOpeningElement", T.JSXOpeningFragment = "JSXOpeningFragment", T.JSXSpreadAttribute = "JSXSpreadAttribute", T.JSXSpreadChild = "JSXSpreadChild", T.JSXText = "JSXText", T.LabeledStatement = "LabeledStatement", T.Literal = "Literal", T.LogicalExpression = "LogicalExpression", T.MemberExpression = "MemberExpression", T.MetaProperty = "MetaProperty", T.MethodDefinition = "MethodDefinition", T.NewExpression = "NewExpression", T.ObjectExpression = "ObjectExpression", T.ObjectPattern = "ObjectPattern", T.PrivateIdentifier = "PrivateIdentifier", T.Program = "Program", T.Property = "Property", T.PropertyDefinition = "PropertyDefinition", T.RestElement = "RestElement", T.ReturnStatement = "ReturnStatement", T.SequenceExpression = "SequenceExpression", T.SpreadElement = "SpreadElement", T.StaticBlock = "StaticBlock", T.Super = "Super", T.SwitchCase = "SwitchCase", T.SwitchStatement = "SwitchStatement", T.TaggedTemplateExpression = "TaggedTemplateExpression", T.TemplateElement = "TemplateElement", T.TemplateLiteral = "TemplateLiteral", T.ThisExpression = "ThisExpression", T.ThrowStatement = "ThrowStatement", T.TryStatement = "TryStatement", T.UnaryExpression = "UnaryExpression", T.UpdateExpression = "UpdateExpression", T.VariableDeclaration = "VariableDeclaration", T.VariableDeclarator = "VariableDeclarator", T.WhileStatement = "WhileStatement", T.WithStatement = "WithStatement", T.YieldExpression = "YieldExpression", T.TSAbstractAccessorProperty = "TSAbstractAccessorProperty", T.TSAbstractKeyword = "TSAbstractKeyword", T.TSAbstractMethodDefinition = "TSAbstractMethodDefinition", T.TSAbstractPropertyDefinition = "TSAbstractPropertyDefinition", T.TSAnyKeyword = "TSAnyKeyword", T.TSArrayType = "TSArrayType", T.TSAsExpression = "TSAsExpression", T.TSAsyncKeyword = "TSAsyncKeyword", T.TSBigIntKeyword = "TSBigIntKeyword", T.TSBooleanKeyword = "TSBooleanKeyword", T.TSCallSignatureDeclaration = "TSCallSignatureDeclaration", T.TSClassImplements = "TSClassImplements", T.TSConditionalType = "TSConditionalType", T.TSConstructorType = "TSConstructorType", T.TSConstructSignatureDeclaration = "TSConstructSignatureDeclaration", T.TSDeclareFunction = "TSDeclareFunction", T.TSDeclareKeyword = "TSDeclareKeyword", T.TSEmptyBodyFunctionExpression = "TSEmptyBodyFunctionExpression", T.TSEnumDeclaration = "TSEnumDeclaration", T.TSEnumMember = "TSEnumMember", T.TSExportAssignment = "TSExportAssignment", T.TSExportKeyword = "TSExportKeyword", T.TSExternalModuleReference = "TSExternalModuleReference", T.TSFunctionType = "TSFunctionType", T.TSInstantiationExpression = "TSInstantiationExpression", T.TSImportEqualsDeclaration = "TSImportEqualsDeclaration", T.TSImportType = "TSImportType", T.TSIndexedAccessType = "TSIndexedAccessType", T.TSIndexSignature = "TSIndexSignature", T.TSInferType = "TSInferType", T.TSInterfaceBody = "TSInterfaceBody", T.TSInterfaceDeclaration = "TSInterfaceDeclaration", T.TSInterfaceHeritage = "TSInterfaceHeritage", T.TSIntersectionType = "TSIntersectionType", T.TSIntrinsicKeyword = "TSIntrinsicKeyword", T.TSLiteralType = "TSLiteralType", T.TSMappedType = "TSMappedType", T.TSMethodSignature = "TSMethodSignature", T.TSModuleBlock = "TSModuleBlock", T.TSModuleDeclaration = "TSModuleDeclaration", T.TSNamedTupleMember = "TSNamedTupleMember", T.TSNamespaceExportDeclaration = "TSNamespaceExportDeclaration", T.TSNeverKeyword = "TSNeverKeyword", T.TSNonNullExpression = "TSNonNullExpression", T.TSNullKeyword = "TSNullKeyword", T.TSNumberKeyword = "TSNumberKeyword", T.TSObjectKeyword = "TSObjectKeyword", T.TSOptionalType = "TSOptionalType", T.TSParameterProperty = "TSParameterProperty", T.TSPrivateKeyword = "TSPrivateKeyword", T.TSPropertySignature = "TSPropertySignature", T.TSProtectedKeyword = "TSProtectedKeyword", T.TSPublicKeyword = "TSPublicKeyword", T.TSQualifiedName = "TSQualifiedName", T.TSReadonlyKeyword = "TSReadonlyKeyword", T.TSRestType = "TSRestType", T.TSSatisfiesExpression = "TSSatisfiesExpression", T.TSStaticKeyword = "TSStaticKeyword", T.TSStringKeyword = "TSStringKeyword", T.TSSymbolKeyword = "TSSymbolKeyword", T.TSTemplateLiteralType = "TSTemplateLiteralType", T.TSThisType = "TSThisType", T.TSTupleType = "TSTupleType", T.TSTypeAliasDeclaration = "TSTypeAliasDeclaration", T.TSTypeAnnotation = "TSTypeAnnotation", T.TSTypeAssertion = "TSTypeAssertion", T.TSTypeLiteral = "TSTypeLiteral", T.TSTypeOperator = "TSTypeOperator", T.TSTypeParameter = "TSTypeParameter", T.TSTypeParameterDeclaration = "TSTypeParameterDeclaration", T.TSTypeParameterInstantiation = "TSTypeParameterInstantiation", T.TSTypePredicate = "TSTypePredicate", T.TSTypeQuery = "TSTypeQuery", T.TSTypeReference = "TSTypeReference", T.TSUndefinedKeyword = "TSUndefinedKeyword", T.TSUnionType = "TSUnionType", T.TSUnknownKeyword = "TSUnknownKeyword", T.TSVoidKeyword = "TSVoidKeyword";
          })(_ = a.AST_NODE_TYPES || (a.AST_NODE_TYPES = {}));
          var D;
          (function(T) {
            T.Boolean = "Boolean", T.Identifier = "Identifier", T.JSXIdentifier = "JSXIdentifier", T.JSXText = "JSXText", T.Keyword = "Keyword", T.Null = "Null", T.Numeric = "Numeric", T.Punctuator = "Punctuator", T.RegularExpression = "RegularExpression", T.String = "String", T.Template = "Template", T.Block = "Block", T.Line = "Line";
          })(D = a.AST_TOKEN_TYPES || (a.AST_TOKEN_TYPES = {}));
        } }), IE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/types/dist/lib.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
        } }), OE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/types/dist/parser-options.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
        } }), ME = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/types/dist/ts-estree.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(ae, z, I, E) {
            E === void 0 && (E = I);
            var N = Object.getOwnPropertyDescriptor(z, I);
            (!N || ("get" in N ? !z.__esModule : N.writable || N.configurable)) && (N = { enumerable: true, get: function() {
              return z[I];
            } }), Object.defineProperty(ae, E, N);
          } : function(ae, z, I, E) {
            E === void 0 && (E = I), ae[E] = z[I];
          }), D = a && a.__setModuleDefault || (Object.create ? function(ae, z) {
            Object.defineProperty(ae, "default", { enumerable: true, value: z });
          } : function(ae, z) {
            ae.default = z;
          }), T = a && a.__importStar || function(ae) {
            if (ae && ae.__esModule)
              return ae;
            var z = {};
            if (ae != null)
              for (var I in ae)
                I !== "default" && Object.prototype.hasOwnProperty.call(ae, I) && _(z, ae, I);
            return D(z, ae), z;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.TSESTree = void 0, a.TSESTree = T(gy());
        } }), LE = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/types/dist/index.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(ae, z, I, E) {
            E === void 0 && (E = I);
            var N = Object.getOwnPropertyDescriptor(z, I);
            (!N || ("get" in N ? !z.__esModule : N.writable || N.configurable)) && (N = { enumerable: true, get: function() {
              return z[I];
            } }), Object.defineProperty(ae, E, N);
          } : function(ae, z, I, E) {
            E === void 0 && (E = I), ae[E] = z[I];
          }), D = a && a.__exportStar || function(ae, z) {
            for (var I in ae)
              I !== "default" && !Object.prototype.hasOwnProperty.call(z, I) && _(z, ae, I);
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.AST_TOKEN_TYPES = a.AST_NODE_TYPES = void 0;
          var T = gy();
          Object.defineProperty(a, "AST_NODE_TYPES", { enumerable: true, get: function() {
            return T.AST_NODE_TYPES;
          } }), Object.defineProperty(a, "AST_TOKEN_TYPES", { enumerable: true, get: function() {
            return T.AST_TOKEN_TYPES;
          } }), D(IE(), a), D(OE(), a), D(ME(), a);
        } }), RE = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/ts-estree/ts-nodes.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
        } }), jE = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/ts-estree/estree-to-ts-node-types.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
        } }), kl = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/ts-estree/index.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(ae, z, I, E) {
            E === void 0 && (E = I);
            var N = Object.getOwnPropertyDescriptor(z, I);
            (!N || ("get" in N ? !z.__esModule : N.writable || N.configurable)) && (N = { enumerable: true, get: function() {
              return z[I];
            } }), Object.defineProperty(ae, E, N);
          } : function(ae, z, I, E) {
            E === void 0 && (E = I), ae[E] = z[I];
          }), D = a && a.__exportStar || function(ae, z) {
            for (var I in ae)
              I !== "default" && !Object.prototype.hasOwnProperty.call(z, I) && _(z, ae, I);
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.TSESTree = a.AST_TOKEN_TYPES = a.AST_NODE_TYPES = void 0;
          var T = LE();
          Object.defineProperty(a, "AST_NODE_TYPES", { enumerable: true, get: function() {
            return T.AST_NODE_TYPES;
          } }), Object.defineProperty(a, "AST_TOKEN_TYPES", { enumerable: true, get: function() {
            return T.AST_TOKEN_TYPES;
          } }), Object.defineProperty(a, "TSESTree", { enumerable: true, get: function() {
            return T.TSESTree;
          } }), D(RE(), a), D(jE(), a);
        } }), Pl = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/node-utils.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(ve, er, ar, Cr) {
            Cr === void 0 && (Cr = ar);
            var Ce = Object.getOwnPropertyDescriptor(er, ar);
            (!Ce || ("get" in Ce ? !er.__esModule : Ce.writable || Ce.configurable)) && (Ce = { enumerable: true, get: function() {
              return er[ar];
            } }), Object.defineProperty(ve, Cr, Ce);
          } : function(ve, er, ar, Cr) {
            Cr === void 0 && (Cr = ar), ve[Cr] = er[ar];
          }), D = a && a.__setModuleDefault || (Object.create ? function(ve, er) {
            Object.defineProperty(ve, "default", { enumerable: true, value: er });
          } : function(ve, er) {
            ve.default = er;
          }), T = a && a.__importStar || function(ve) {
            if (ve && ve.__esModule)
              return ve;
            var er = {};
            if (ve != null)
              for (var ar in ve)
                ar !== "default" && Object.prototype.hasOwnProperty.call(ve, ar) && _(er, ve, ar);
            return D(er, ve), er;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.isThisInTypeQuery = a.isThisIdentifier = a.identifierIsThisKeyword = a.firstDefined = a.nodeHasTokens = a.createError = a.TSError = a.convertTokens = a.convertToken = a.getTokenType = a.isChildUnwrappableOptionalChain = a.isChainExpression = a.isOptional = a.isComputedProperty = a.unescapeStringLiteralText = a.hasJSXAncestor = a.findFirstMatchingAncestor = a.findNextToken = a.getTSNodeAccessibility = a.getDeclarationKind = a.isJSXToken = a.isToken = a.getRange = a.canContainDirective = a.getLocFor = a.getLineAndCharacterFor = a.getBinaryExpressionType = a.isJSDocComment = a.isComment = a.isComma = a.getLastModifier = a.hasModifier = a.isESTreeClassMember = a.getTextForTokenKind = a.isLogicalOperator = a.isAssignmentOperator = void 0;
          var ae = T(Di()), z = sf(), I = NE(), E = kl(), N = ae.SyntaxKind, e = [N.BarBarToken, N.AmpersandAmpersandToken, N.QuestionQuestionToken];
          function t3(ve) {
            return ve.kind >= N.FirstAssignment && ve.kind <= N.LastAssignment;
          }
          a.isAssignmentOperator = t3;
          function w(ve) {
            return e.includes(ve.kind);
          }
          a.isLogicalOperator = w;
          function s(ve) {
            return ae.tokenToString(ve);
          }
          a.getTextForTokenKind = s;
          function q(ve) {
            return ve.kind !== N.SemicolonClassElement;
          }
          a.isESTreeClassMember = q;
          function F(ve, er) {
            let ar = (0, z.getModifiers)(er);
            return (ar == null ? void 0 : ar.some((Cr) => Cr.kind === ve)) === true;
          }
          a.hasModifier = F;
          function fe(ve) {
            var er;
            let ar = (0, z.getModifiers)(ve);
            return ar == null ? null : (er = ar[ar.length - 1]) !== null && er !== void 0 ? er : null;
          }
          a.getLastModifier = fe;
          function Ee(ve) {
            return ve.kind === N.CommaToken;
          }
          a.isComma = Ee;
          function Se(ve) {
            return ve.kind === N.SingleLineCommentTrivia || ve.kind === N.MultiLineCommentTrivia;
          }
          a.isComment = Se;
          function J(ve) {
            return ve.kind === N.JSDocComment;
          }
          a.isJSDocComment = J;
          function se(ve) {
            return t3(ve) ? E.AST_NODE_TYPES.AssignmentExpression : w(ve) ? E.AST_NODE_TYPES.LogicalExpression : E.AST_NODE_TYPES.BinaryExpression;
          }
          a.getBinaryExpressionType = se;
          function Me(ve, er) {
            let ar = er.getLineAndCharacterOfPosition(ve);
            return { line: ar.line + 1, column: ar.character };
          }
          a.getLineAndCharacterFor = Me;
          function Q(ve, er, ar) {
            return { start: Me(ve, ar), end: Me(er, ar) };
          }
          a.getLocFor = Q;
          function Be(ve) {
            if (ve.kind === ae.SyntaxKind.Block)
              switch (ve.parent.kind) {
                case ae.SyntaxKind.Constructor:
                case ae.SyntaxKind.GetAccessor:
                case ae.SyntaxKind.SetAccessor:
                case ae.SyntaxKind.ArrowFunction:
                case ae.SyntaxKind.FunctionExpression:
                case ae.SyntaxKind.FunctionDeclaration:
                case ae.SyntaxKind.MethodDeclaration:
                  return true;
                default:
                  return false;
              }
            return true;
          }
          a.canContainDirective = Be;
          function je(ve, er) {
            return [ve.getStart(er), ve.getEnd()];
          }
          a.getRange = je;
          function V(ve) {
            return ve.kind >= N.FirstToken && ve.kind <= N.LastToken;
          }
          a.isToken = V;
          function B(ve) {
            return ve.kind >= N.JsxElement && ve.kind <= N.JsxAttribute;
          }
          a.isJSXToken = B;
          function U(ve) {
            return ve.flags & ae.NodeFlags.Let ? "let" : ve.flags & ae.NodeFlags.Const ? "const" : "var";
          }
          a.getDeclarationKind = U;
          function m(ve) {
            let er = (0, z.getModifiers)(ve);
            if (er == null)
              return null;
            for (let ar of er)
              switch (ar.kind) {
                case N.PublicKeyword:
                  return "public";
                case N.ProtectedKeyword:
                  return "protected";
                case N.PrivateKeyword:
                  return "private";
                default:
                  break;
              }
            return null;
          }
          a.getTSNodeAccessibility = m;
          function v(ve, er, ar) {
            return Cr(er);
            function Cr(Ce) {
              return ae.isToken(Ce) && Ce.pos === ve.end ? Ce : Re(Ce.getChildren(ar), ($e) => ($e.pos <= ve.pos && $e.end > ve.end || $e.pos === ve.end) && Xe($e, ar) ? Cr($e) : void 0);
            }
          }
          a.findNextToken = v;
          function g(ve, er) {
            for (; ve; ) {
              if (er(ve))
                return ve;
              ve = ve.parent;
            }
          }
          a.findFirstMatchingAncestor = g;
          function O(ve) {
            return !!g(ve, B);
          }
          a.hasJSXAncestor = O;
          function S(ve) {
            return ve.replace(/&(?:#\d+|#x[\da-fA-F]+|[0-9a-zA-Z]+);/g, (er) => {
              let ar = er.slice(1, -1);
              if (ar[0] === "#") {
                let Cr = ar[1] === "x" ? parseInt(ar.slice(2), 16) : parseInt(ar.slice(1), 10);
                return Cr > 1114111 ? er : String.fromCodePoint(Cr);
              }
              return I.xhtmlEntities[ar] || er;
            });
          }
          a.unescapeStringLiteralText = S;
          function te(ve) {
            return ve.kind === N.ComputedPropertyName;
          }
          a.isComputedProperty = te;
          function Je(ve) {
            return ve.questionToken ? ve.questionToken.kind === N.QuestionToken : false;
          }
          a.isOptional = Je;
          function qe(ve) {
            return ve.type === E.AST_NODE_TYPES.ChainExpression;
          }
          a.isChainExpression = qe;
          function ge(ve, er) {
            return qe(er) && ve.expression.kind !== ae.SyntaxKind.ParenthesizedExpression;
          }
          a.isChildUnwrappableOptionalChain = ge;
          function ie(ve) {
            if ("originalKeywordKind" in ve && ve.originalKeywordKind)
              return ve.originalKeywordKind === N.NullKeyword ? E.AST_TOKEN_TYPES.Null : ve.originalKeywordKind >= N.FirstFutureReservedWord && ve.originalKeywordKind <= N.LastKeyword ? E.AST_TOKEN_TYPES.Identifier : E.AST_TOKEN_TYPES.Keyword;
            if (ve.kind >= N.FirstKeyword && ve.kind <= N.LastFutureReservedWord)
              return ve.kind === N.FalseKeyword || ve.kind === N.TrueKeyword ? E.AST_TOKEN_TYPES.Boolean : E.AST_TOKEN_TYPES.Keyword;
            if (ve.kind >= N.FirstPunctuation && ve.kind <= N.LastPunctuation)
              return E.AST_TOKEN_TYPES.Punctuator;
            if (ve.kind >= N.NoSubstitutionTemplateLiteral && ve.kind <= N.TemplateTail)
              return E.AST_TOKEN_TYPES.Template;
            switch (ve.kind) {
              case N.NumericLiteral:
                return E.AST_TOKEN_TYPES.Numeric;
              case N.JsxText:
                return E.AST_TOKEN_TYPES.JSXText;
              case N.StringLiteral:
                return ve.parent && (ve.parent.kind === N.JsxAttribute || ve.parent.kind === N.JsxElement) ? E.AST_TOKEN_TYPES.JSXText : E.AST_TOKEN_TYPES.String;
              case N.RegularExpressionLiteral:
                return E.AST_TOKEN_TYPES.RegularExpression;
              case N.Identifier:
              case N.ConstructorKeyword:
              case N.GetKeyword:
              case N.SetKeyword:
              default:
            }
            return ve.parent && ve.kind === N.Identifier && (B(ve.parent) || ve.parent.kind === N.PropertyAccessExpression && O(ve)) ? E.AST_TOKEN_TYPES.JSXIdentifier : E.AST_TOKEN_TYPES.Identifier;
          }
          a.getTokenType = ie;
          function H(ve, er) {
            let ar = ve.kind === N.JsxText ? ve.getFullStart() : ve.getStart(er), Cr = ve.getEnd(), Ce = er.text.slice(ar, Cr), $e = ie(ve);
            return $e === E.AST_TOKEN_TYPES.RegularExpression ? { type: $e, value: Ce, range: [ar, Cr], loc: Q(ar, Cr, er), regex: { pattern: Ce.slice(1, Ce.lastIndexOf("/")), flags: Ce.slice(Ce.lastIndexOf("/") + 1) } } : { type: $e, value: Ce, range: [ar, Cr], loc: Q(ar, Cr, er) };
          }
          a.convertToken = H;
          function pe(ve) {
            let er = [];
            function ar(Cr) {
              if (!(Se(Cr) || J(Cr)))
                if (V(Cr) && Cr.kind !== N.EndOfFileToken) {
                  let Ce = H(Cr, ve);
                  Ce && er.push(Ce);
                } else
                  Cr.getChildren(ve).forEach(ar);
            }
            return ar(ve), er;
          }
          a.convertTokens = pe;
          var j = class extends Error {
            constructor(ve, er, ar, Cr, Ce) {
              super(ve), this.fileName = er, this.index = ar, this.lineNumber = Cr, this.column = Ce, Object.defineProperty(this, "name", { value: new.target.name, enumerable: false, configurable: true });
            }
          };
          a.TSError = j;
          function be(ve, er, ar) {
            let Cr = ve.getLineAndCharacterOfPosition(er);
            return new j(ar, ve.fileName, er, Cr.line + 1, Cr.character);
          }
          a.createError = be;
          function Xe(ve, er) {
            return ve.kind === N.EndOfFileToken ? !!ve.jsDoc : ve.getWidth(er) !== 0;
          }
          a.nodeHasTokens = Xe;
          function Re(ve, er) {
            if (ve !== void 0)
              for (let ar = 0; ar < ve.length; ar++) {
                let Cr = er(ve[ar], ar);
                if (Cr !== void 0)
                  return Cr;
              }
          }
          a.firstDefined = Re;
          function Fe(ve) {
            return ve.originalKeywordKind === N.ThisKeyword;
          }
          a.identifierIsThisKeyword = Fe;
          function dr(ve) {
            return !!ve && ve.kind === N.Identifier && Fe(ve);
          }
          a.isThisIdentifier = dr;
          function ze(ve) {
            if (!dr(ve))
              return false;
            for (; ae.isQualifiedName(ve.parent) && ve.parent.left === ve; )
              ve = ve.parent;
            return ve.parent.kind === N.TypeQuery;
          }
          a.isThisInTypeQuery = ze;
        } }), yy = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/convert.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(s, q, F, fe) {
            fe === void 0 && (fe = F);
            var Ee = Object.getOwnPropertyDescriptor(q, F);
            (!Ee || ("get" in Ee ? !q.__esModule : Ee.writable || Ee.configurable)) && (Ee = { enumerable: true, get: function() {
              return q[F];
            } }), Object.defineProperty(s, fe, Ee);
          } : function(s, q, F, fe) {
            fe === void 0 && (fe = F), s[fe] = q[F];
          }), D = a && a.__setModuleDefault || (Object.create ? function(s, q) {
            Object.defineProperty(s, "default", { enumerable: true, value: q });
          } : function(s, q) {
            s.default = q;
          }), T = a && a.__importStar || function(s) {
            if (s && s.__esModule)
              return s;
            var q = {};
            if (s != null)
              for (var F in s)
                F !== "default" && Object.prototype.hasOwnProperty.call(s, F) && _(q, s, F);
            return D(q, s), q;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.Converter = a.convertError = void 0;
          var ae = T(Di()), z = sf(), I = Pl(), E = kl(), N = of(), e = ae.SyntaxKind;
          function t3(s) {
            return (0, I.createError)(s.file, s.start, "message" in s && s.message || s.messageText);
          }
          a.convertError = t3;
          var w = class {
            constructor(s, q) {
              this.esTreeNodeToTSNodeMap = /* @__PURE__ */ new WeakMap(), this.tsNodeToESTreeNodeMap = /* @__PURE__ */ new WeakMap(), this.allowPattern = false, this.inTypeMode = false, this.ast = s, this.options = Object.assign({}, q);
            }
            getASTMaps() {
              return { esTreeNodeToTSNodeMap: this.esTreeNodeToTSNodeMap, tsNodeToESTreeNodeMap: this.tsNodeToESTreeNodeMap };
            }
            convertProgram() {
              return this.converter(this.ast);
            }
            converter(s, q, F, fe) {
              if (!s)
                return null;
              let Ee = this.inTypeMode, Se = this.allowPattern;
              F !== void 0 && (this.inTypeMode = F), fe !== void 0 && (this.allowPattern = fe);
              let J = this.convertNode(s, q != null ? q : s.parent);
              return this.registerTSNodeInNodeMap(s, J), this.inTypeMode = Ee, this.allowPattern = Se, J;
            }
            fixExports(s, q) {
              let F = (0, z.getModifiers)(s);
              if ((F == null ? void 0 : F[0].kind) === e.ExportKeyword) {
                this.registerTSNodeInNodeMap(s, q);
                let fe = F[0], Ee = F[1], Se = Ee && Ee.kind === e.DefaultKeyword, J = Se ? (0, I.findNextToken)(Ee, this.ast, this.ast) : (0, I.findNextToken)(fe, this.ast, this.ast);
                if (q.range[0] = J.getStart(this.ast), q.loc = (0, I.getLocFor)(q.range[0], q.range[1], this.ast), Se)
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ExportDefaultDeclaration, declaration: q, range: [fe.getStart(this.ast), q.range[1]], exportKind: "value" });
                {
                  let se = q.type === E.AST_NODE_TYPES.TSInterfaceDeclaration || q.type === E.AST_NODE_TYPES.TSTypeAliasDeclaration, Me = "declare" in q && q.declare === true;
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ExportNamedDeclaration, declaration: q, specifiers: [], source: null, exportKind: se || Me ? "type" : "value", range: [fe.getStart(this.ast), q.range[1]], assertions: [] });
                }
              }
              return q;
            }
            registerTSNodeInNodeMap(s, q) {
              q && this.options.shouldPreserveNodeMaps && (this.tsNodeToESTreeNodeMap.has(s) || this.tsNodeToESTreeNodeMap.set(s, q));
            }
            convertPattern(s, q) {
              return this.converter(s, q, this.inTypeMode, true);
            }
            convertChild(s, q) {
              return this.converter(s, q, this.inTypeMode, false);
            }
            convertType(s, q) {
              return this.converter(s, q, true, false);
            }
            createNode(s, q) {
              let F = q;
              return F.range || (F.range = (0, I.getRange)(s, this.ast)), F.loc || (F.loc = (0, I.getLocFor)(F.range[0], F.range[1], this.ast)), F && this.options.shouldPreserveNodeMaps && this.esTreeNodeToTSNodeMap.set(F, s), F;
            }
            convertBindingNameWithTypeAnnotation(s, q, F) {
              let fe = this.convertPattern(s);
              return q && (fe.typeAnnotation = this.convertTypeAnnotation(q, F), this.fixParentLocation(fe, fe.typeAnnotation.range)), fe;
            }
            convertTypeAnnotation(s, q) {
              let F = (q == null ? void 0 : q.kind) === e.FunctionType || (q == null ? void 0 : q.kind) === e.ConstructorType ? 2 : 1, fe = s.getFullStart() - F, Ee = (0, I.getLocFor)(fe, s.end, this.ast);
              return { type: E.AST_NODE_TYPES.TSTypeAnnotation, loc: Ee, range: [fe, s.end], typeAnnotation: this.convertType(s) };
            }
            convertBodyExpressions(s, q) {
              let F = (0, I.canContainDirective)(q);
              return s.map((fe) => {
                let Ee = this.convertChild(fe);
                if (F)
                  if (Ee != null && Ee.expression && ae.isExpressionStatement(fe) && ae.isStringLiteral(fe.expression)) {
                    let Se = Ee.expression.raw;
                    return Ee.directive = Se.slice(1, -1), Ee;
                  } else
                    F = false;
                return Ee;
              }).filter((fe) => fe);
            }
            convertTypeArgumentsToTypeParameters(s, q) {
              let F = (0, I.findNextToken)(s, this.ast, this.ast);
              return this.createNode(q, { type: E.AST_NODE_TYPES.TSTypeParameterInstantiation, range: [s.pos - 1, F.end], params: s.map((fe) => this.convertType(fe)) });
            }
            convertTSTypeParametersToTypeParametersDeclaration(s) {
              let q = (0, I.findNextToken)(s, this.ast, this.ast);
              return { type: E.AST_NODE_TYPES.TSTypeParameterDeclaration, range: [s.pos - 1, q.end], loc: (0, I.getLocFor)(s.pos - 1, q.end, this.ast), params: s.map((F) => this.convertType(F)) };
            }
            convertParameters(s) {
              return s != null && s.length ? s.map((q) => {
                let F = this.convertChild(q), fe = (0, z.getDecorators)(q);
                return fe != null && fe.length && (F.decorators = fe.map((Ee) => this.convertChild(Ee))), F;
              }) : [];
            }
            convertChainExpression(s, q) {
              let { child: F, isOptional: fe } = (() => s.type === E.AST_NODE_TYPES.MemberExpression ? { child: s.object, isOptional: s.optional } : s.type === E.AST_NODE_TYPES.CallExpression ? { child: s.callee, isOptional: s.optional } : { child: s.expression, isOptional: false })(), Ee = (0, I.isChildUnwrappableOptionalChain)(q, F);
              if (!Ee && !fe)
                return s;
              if (Ee && (0, I.isChainExpression)(F)) {
                let Se = F.expression;
                s.type === E.AST_NODE_TYPES.MemberExpression ? s.object = Se : s.type === E.AST_NODE_TYPES.CallExpression ? s.callee = Se : s.expression = Se;
              }
              return this.createNode(q, { type: E.AST_NODE_TYPES.ChainExpression, expression: s });
            }
            deeplyCopy(s) {
              if (s.kind === ae.SyntaxKind.JSDocFunctionType)
                throw (0, I.createError)(this.ast, s.pos, "JSDoc types can only be used inside documentation comments.");
              let q = `TS${e[s.kind]}`;
              if (this.options.errorOnUnknownASTType && !E.AST_NODE_TYPES[q])
                throw new Error(`Unknown AST_NODE_TYPE: "${q}"`);
              let F = this.createNode(s, { type: q });
              "type" in s && (F.typeAnnotation = s.type && "kind" in s.type && ae.isTypeNode(s.type) ? this.convertTypeAnnotation(s.type, s) : null), "typeArguments" in s && (F.typeParameters = s.typeArguments && "pos" in s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : null), "typeParameters" in s && (F.typeParameters = s.typeParameters && "pos" in s.typeParameters ? this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters) : null);
              let fe = (0, z.getDecorators)(s);
              fe != null && fe.length && (F.decorators = fe.map((Se) => this.convertChild(Se)));
              let Ee = /* @__PURE__ */ new Set(["_children", "decorators", "end", "flags", "illegalDecorators", "heritageClauses", "locals", "localSymbol", "jsDoc", "kind", "modifierFlagsCache", "modifiers", "nextContainer", "parent", "pos", "symbol", "transformFlags", "type", "typeArguments", "typeParameters"]);
              return Object.entries(s).filter((Se) => {
                let [J] = Se;
                return !Ee.has(J);
              }).forEach((Se) => {
                let [J, se] = Se;
                Array.isArray(se) ? F[J] = se.map((Me) => this.convertChild(Me)) : se && typeof se == "object" && se.kind ? F[J] = this.convertChild(se) : F[J] = se;
              }), F;
            }
            convertJSXIdentifier(s) {
              let q = this.createNode(s, { type: E.AST_NODE_TYPES.JSXIdentifier, name: s.getText() });
              return this.registerTSNodeInNodeMap(s, q), q;
            }
            convertJSXNamespaceOrIdentifier(s) {
              let q = s.getText(), F = q.indexOf(":");
              if (F > 0) {
                let fe = (0, I.getRange)(s, this.ast), Ee = this.createNode(s, { type: E.AST_NODE_TYPES.JSXNamespacedName, namespace: this.createNode(s, { type: E.AST_NODE_TYPES.JSXIdentifier, name: q.slice(0, F), range: [fe[0], fe[0] + F] }), name: this.createNode(s, { type: E.AST_NODE_TYPES.JSXIdentifier, name: q.slice(F + 1), range: [fe[0] + F + 1, fe[1]] }), range: fe });
                return this.registerTSNodeInNodeMap(s, Ee), Ee;
              }
              return this.convertJSXIdentifier(s);
            }
            convertJSXTagName(s, q) {
              let F;
              switch (s.kind) {
                case e.PropertyAccessExpression:
                  if (s.name.kind === e.PrivateIdentifier)
                    throw new Error("Non-private identifier expected.");
                  F = this.createNode(s, { type: E.AST_NODE_TYPES.JSXMemberExpression, object: this.convertJSXTagName(s.expression, q), property: this.convertJSXIdentifier(s.name) });
                  break;
                case e.ThisKeyword:
                case e.Identifier:
                default:
                  return this.convertJSXNamespaceOrIdentifier(s);
              }
              return this.registerTSNodeInNodeMap(s, F), F;
            }
            convertMethodSignature(s) {
              let q = this.createNode(s, { type: E.AST_NODE_TYPES.TSMethodSignature, computed: (0, I.isComputedProperty)(s.name), key: this.convertChild(s.name), params: this.convertParameters(s.parameters), kind: (() => {
                switch (s.kind) {
                  case e.GetAccessor:
                    return "get";
                  case e.SetAccessor:
                    return "set";
                  case e.MethodSignature:
                    return "method";
                }
              })() });
              (0, I.isOptional)(s) && (q.optional = true), s.type && (q.returnType = this.convertTypeAnnotation(s.type, s)), (0, I.hasModifier)(e.ReadonlyKeyword, s) && (q.readonly = true), s.typeParameters && (q.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters));
              let F = (0, I.getTSNodeAccessibility)(s);
              return F && (q.accessibility = F), (0, I.hasModifier)(e.ExportKeyword, s) && (q.export = true), (0, I.hasModifier)(e.StaticKeyword, s) && (q.static = true), q;
            }
            convertAssertClasue(s) {
              return s === void 0 ? [] : s.elements.map((q) => this.convertChild(q));
            }
            applyModifiersToResult(s, q) {
              if (!q)
                return;
              let F = [];
              for (let fe of q)
                switch (fe.kind) {
                  case e.ExportKeyword:
                  case e.DefaultKeyword:
                    break;
                  case e.ConstKeyword:
                    s.const = true;
                    break;
                  case e.DeclareKeyword:
                    s.declare = true;
                    break;
                  default:
                    F.push(this.convertChild(fe));
                    break;
                }
              F.length > 0 && (s.modifiers = F);
            }
            fixParentLocation(s, q) {
              q[0] < s.range[0] && (s.range[0] = q[0], s.loc.start = (0, I.getLineAndCharacterFor)(s.range[0], this.ast)), q[1] > s.range[1] && (s.range[1] = q[1], s.loc.end = (0, I.getLineAndCharacterFor)(s.range[1], this.ast));
            }
            assertModuleSpecifier(s, q) {
              var F;
              if (!q && s.moduleSpecifier == null)
                throw (0, I.createError)(this.ast, s.pos, "Module specifier must be a string literal.");
              if (s.moduleSpecifier && ((F = s.moduleSpecifier) === null || F === void 0 ? void 0 : F.kind) !== e.StringLiteral)
                throw (0, I.createError)(this.ast, s.moduleSpecifier.pos, "Module specifier must be a string literal.");
            }
            convertNode(s, q) {
              var F, fe, Ee, Se, J, se, Me, Q, Be, je;
              switch (s.kind) {
                case e.SourceFile:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Program, body: this.convertBodyExpressions(s.statements, s), sourceType: s.externalModuleIndicator ? "module" : "script", range: [s.getStart(this.ast), s.endOfFileToken.end] });
                case e.Block:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.BlockStatement, body: this.convertBodyExpressions(s.statements, s) });
                case e.Identifier:
                  return (0, I.isThisInTypeQuery)(s) ? this.createNode(s, { type: E.AST_NODE_TYPES.ThisExpression }) : this.createNode(s, { type: E.AST_NODE_TYPES.Identifier, name: s.text });
                case e.PrivateIdentifier:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.PrivateIdentifier, name: s.text.slice(1) });
                case e.WithStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.WithStatement, object: this.convertChild(s.expression), body: this.convertChild(s.statement) });
                case e.ReturnStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ReturnStatement, argument: this.convertChild(s.expression) });
                case e.LabeledStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.LabeledStatement, label: this.convertChild(s.label), body: this.convertChild(s.statement) });
                case e.ContinueStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ContinueStatement, label: this.convertChild(s.label) });
                case e.BreakStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.BreakStatement, label: this.convertChild(s.label) });
                case e.IfStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.IfStatement, test: this.convertChild(s.expression), consequent: this.convertChild(s.thenStatement), alternate: this.convertChild(s.elseStatement) });
                case e.SwitchStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.SwitchStatement, discriminant: this.convertChild(s.expression), cases: s.caseBlock.clauses.map((V) => this.convertChild(V)) });
                case e.CaseClause:
                case e.DefaultClause:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.SwitchCase, test: s.kind === e.CaseClause ? this.convertChild(s.expression) : null, consequent: s.statements.map((V) => this.convertChild(V)) });
                case e.ThrowStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ThrowStatement, argument: this.convertChild(s.expression) });
                case e.TryStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TryStatement, block: this.convertChild(s.tryBlock), handler: this.convertChild(s.catchClause), finalizer: this.convertChild(s.finallyBlock) });
                case e.CatchClause:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.CatchClause, param: s.variableDeclaration ? this.convertBindingNameWithTypeAnnotation(s.variableDeclaration.name, s.variableDeclaration.type) : null, body: this.convertChild(s.block) });
                case e.WhileStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.WhileStatement, test: this.convertChild(s.expression), body: this.convertChild(s.statement) });
                case e.DoStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.DoWhileStatement, test: this.convertChild(s.expression), body: this.convertChild(s.statement) });
                case e.ForStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ForStatement, init: this.convertChild(s.initializer), test: this.convertChild(s.condition), update: this.convertChild(s.incrementor), body: this.convertChild(s.statement) });
                case e.ForInStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ForInStatement, left: this.convertPattern(s.initializer), right: this.convertChild(s.expression), body: this.convertChild(s.statement) });
                case e.ForOfStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ForOfStatement, left: this.convertPattern(s.initializer), right: this.convertChild(s.expression), body: this.convertChild(s.statement), await: Boolean(s.awaitModifier && s.awaitModifier.kind === e.AwaitKeyword) });
                case e.FunctionDeclaration: {
                  let V = (0, I.hasModifier)(e.DeclareKeyword, s), B = this.createNode(s, { type: V || !s.body ? E.AST_NODE_TYPES.TSDeclareFunction : E.AST_NODE_TYPES.FunctionDeclaration, id: this.convertChild(s.name), generator: !!s.asteriskToken, expression: false, async: (0, I.hasModifier)(e.AsyncKeyword, s), params: this.convertParameters(s.parameters), body: this.convertChild(s.body) || void 0 });
                  return s.type && (B.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (B.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), V && (B.declare = true), this.fixExports(s, B);
                }
                case e.VariableDeclaration: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.VariableDeclarator, id: this.convertBindingNameWithTypeAnnotation(s.name, s.type, s), init: this.convertChild(s.initializer) });
                  return s.exclamationToken && (V.definite = true), V;
                }
                case e.VariableStatement: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.VariableDeclaration, declarations: s.declarationList.declarations.map((B) => this.convertChild(B)), kind: (0, I.getDeclarationKind)(s.declarationList) });
                  return (0, I.hasModifier)(e.DeclareKeyword, s) && (V.declare = true), this.fixExports(s, V);
                }
                case e.VariableDeclarationList:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.VariableDeclaration, declarations: s.declarations.map((V) => this.convertChild(V)), kind: (0, I.getDeclarationKind)(s) });
                case e.ExpressionStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ExpressionStatement, expression: this.convertChild(s.expression) });
                case e.ThisKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ThisExpression });
                case e.ArrayLiteralExpression:
                  return this.allowPattern ? this.createNode(s, { type: E.AST_NODE_TYPES.ArrayPattern, elements: s.elements.map((V) => this.convertPattern(V)) }) : this.createNode(s, { type: E.AST_NODE_TYPES.ArrayExpression, elements: s.elements.map((V) => this.convertChild(V)) });
                case e.ObjectLiteralExpression:
                  return this.allowPattern ? this.createNode(s, { type: E.AST_NODE_TYPES.ObjectPattern, properties: s.properties.map((V) => this.convertPattern(V)) }) : this.createNode(s, { type: E.AST_NODE_TYPES.ObjectExpression, properties: s.properties.map((V) => this.convertChild(V)) });
                case e.PropertyAssignment:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Property, key: this.convertChild(s.name), value: this.converter(s.initializer, s, this.inTypeMode, this.allowPattern), computed: (0, I.isComputedProperty)(s.name), method: false, shorthand: false, kind: "init" });
                case e.ShorthandPropertyAssignment:
                  return s.objectAssignmentInitializer ? this.createNode(s, { type: E.AST_NODE_TYPES.Property, key: this.convertChild(s.name), value: this.createNode(s, { type: E.AST_NODE_TYPES.AssignmentPattern, left: this.convertPattern(s.name), right: this.convertChild(s.objectAssignmentInitializer) }), computed: false, method: false, shorthand: true, kind: "init" }) : this.createNode(s, { type: E.AST_NODE_TYPES.Property, key: this.convertChild(s.name), value: this.convertChild(s.name), computed: false, method: false, shorthand: true, kind: "init" });
                case e.ComputedPropertyName:
                  return this.convertChild(s.expression);
                case e.PropertyDeclaration: {
                  let V = (0, I.hasModifier)(e.AbstractKeyword, s), B = (0, I.hasModifier)(e.AccessorKeyword, s), U = (() => B ? V ? E.AST_NODE_TYPES.TSAbstractAccessorProperty : E.AST_NODE_TYPES.AccessorProperty : V ? E.AST_NODE_TYPES.TSAbstractPropertyDefinition : E.AST_NODE_TYPES.PropertyDefinition)(), m = this.createNode(s, { type: U, key: this.convertChild(s.name), value: V ? null : this.convertChild(s.initializer), computed: (0, I.isComputedProperty)(s.name), static: (0, I.hasModifier)(e.StaticKeyword, s), readonly: (0, I.hasModifier)(e.ReadonlyKeyword, s) || void 0, declare: (0, I.hasModifier)(e.DeclareKeyword, s), override: (0, I.hasModifier)(e.OverrideKeyword, s) });
                  s.type && (m.typeAnnotation = this.convertTypeAnnotation(s.type, s));
                  let v = (0, z.getDecorators)(s);
                  v && (m.decorators = v.map((O) => this.convertChild(O)));
                  let g = (0, I.getTSNodeAccessibility)(s);
                  return g && (m.accessibility = g), (s.name.kind === e.Identifier || s.name.kind === e.ComputedPropertyName || s.name.kind === e.PrivateIdentifier) && s.questionToken && (m.optional = true), s.exclamationToken && (m.definite = true), m.key.type === E.AST_NODE_TYPES.Literal && s.questionToken && (m.optional = true), m;
                }
                case e.GetAccessor:
                case e.SetAccessor:
                  if (s.parent.kind === e.InterfaceDeclaration || s.parent.kind === e.TypeLiteral)
                    return this.convertMethodSignature(s);
                case e.MethodDeclaration: {
                  let V = this.createNode(s, { type: s.body ? E.AST_NODE_TYPES.FunctionExpression : E.AST_NODE_TYPES.TSEmptyBodyFunctionExpression, id: null, generator: !!s.asteriskToken, expression: false, async: (0, I.hasModifier)(e.AsyncKeyword, s), body: this.convertChild(s.body), range: [s.parameters.pos - 1, s.end], params: [] });
                  s.type && (V.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (V.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters), this.fixParentLocation(V, V.typeParameters.range));
                  let B;
                  if (q.kind === e.ObjectLiteralExpression)
                    V.params = s.parameters.map((U) => this.convertChild(U)), B = this.createNode(s, { type: E.AST_NODE_TYPES.Property, key: this.convertChild(s.name), value: V, computed: (0, I.isComputedProperty)(s.name), method: s.kind === e.MethodDeclaration, shorthand: false, kind: "init" });
                  else {
                    V.params = this.convertParameters(s.parameters);
                    let U = (0, I.hasModifier)(e.AbstractKeyword, s) ? E.AST_NODE_TYPES.TSAbstractMethodDefinition : E.AST_NODE_TYPES.MethodDefinition;
                    B = this.createNode(s, { type: U, key: this.convertChild(s.name), value: V, computed: (0, I.isComputedProperty)(s.name), static: (0, I.hasModifier)(e.StaticKeyword, s), kind: "method", override: (0, I.hasModifier)(e.OverrideKeyword, s) });
                    let m = (0, z.getDecorators)(s);
                    m && (B.decorators = m.map((g) => this.convertChild(g)));
                    let v = (0, I.getTSNodeAccessibility)(s);
                    v && (B.accessibility = v);
                  }
                  return s.questionToken && (B.optional = true), s.kind === e.GetAccessor ? B.kind = "get" : s.kind === e.SetAccessor ? B.kind = "set" : !B.static && s.name.kind === e.StringLiteral && s.name.text === "constructor" && B.type !== E.AST_NODE_TYPES.Property && (B.kind = "constructor"), B;
                }
                case e.Constructor: {
                  let V = (0, I.getLastModifier)(s), B = V && (0, I.findNextToken)(V, s, this.ast) || s.getFirstToken(), U = this.createNode(s, { type: s.body ? E.AST_NODE_TYPES.FunctionExpression : E.AST_NODE_TYPES.TSEmptyBodyFunctionExpression, id: null, params: this.convertParameters(s.parameters), generator: false, expression: false, async: false, body: this.convertChild(s.body), range: [s.parameters.pos - 1, s.end] });
                  s.typeParameters && (U.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters), this.fixParentLocation(U, U.typeParameters.range)), s.type && (U.returnType = this.convertTypeAnnotation(s.type, s));
                  let m = this.createNode(s, { type: E.AST_NODE_TYPES.Identifier, name: "constructor", range: [B.getStart(this.ast), B.end] }), v = (0, I.hasModifier)(e.StaticKeyword, s), g = this.createNode(s, { type: (0, I.hasModifier)(e.AbstractKeyword, s) ? E.AST_NODE_TYPES.TSAbstractMethodDefinition : E.AST_NODE_TYPES.MethodDefinition, key: m, value: U, computed: false, static: v, kind: v ? "method" : "constructor", override: false }), O = (0, I.getTSNodeAccessibility)(s);
                  return O && (g.accessibility = O), g;
                }
                case e.FunctionExpression: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.FunctionExpression, id: this.convertChild(s.name), generator: !!s.asteriskToken, params: this.convertParameters(s.parameters), body: this.convertChild(s.body), async: (0, I.hasModifier)(e.AsyncKeyword, s), expression: false });
                  return s.type && (V.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (V.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), V;
                }
                case e.SuperKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Super });
                case e.ArrayBindingPattern:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ArrayPattern, elements: s.elements.map((V) => this.convertPattern(V)) });
                case e.OmittedExpression:
                  return null;
                case e.ObjectBindingPattern:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ObjectPattern, properties: s.elements.map((V) => this.convertPattern(V)) });
                case e.BindingElement:
                  if (q.kind === e.ArrayBindingPattern) {
                    let V = this.convertChild(s.name, q);
                    return s.initializer ? this.createNode(s, { type: E.AST_NODE_TYPES.AssignmentPattern, left: V, right: this.convertChild(s.initializer) }) : s.dotDotDotToken ? this.createNode(s, { type: E.AST_NODE_TYPES.RestElement, argument: V }) : V;
                  } else {
                    let V;
                    return s.dotDotDotToken ? V = this.createNode(s, { type: E.AST_NODE_TYPES.RestElement, argument: this.convertChild((F = s.propertyName) !== null && F !== void 0 ? F : s.name) }) : V = this.createNode(s, { type: E.AST_NODE_TYPES.Property, key: this.convertChild((fe = s.propertyName) !== null && fe !== void 0 ? fe : s.name), value: this.convertChild(s.name), computed: Boolean(s.propertyName && s.propertyName.kind === e.ComputedPropertyName), method: false, shorthand: !s.propertyName, kind: "init" }), s.initializer && (V.value = this.createNode(s, { type: E.AST_NODE_TYPES.AssignmentPattern, left: this.convertChild(s.name), right: this.convertChild(s.initializer), range: [s.name.getStart(this.ast), s.initializer.end] })), V;
                  }
                case e.ArrowFunction: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.ArrowFunctionExpression, generator: false, id: null, params: this.convertParameters(s.parameters), body: this.convertChild(s.body), async: (0, I.hasModifier)(e.AsyncKeyword, s), expression: s.body.kind !== e.Block });
                  return s.type && (V.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (V.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), V;
                }
                case e.YieldExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.YieldExpression, delegate: !!s.asteriskToken, argument: this.convertChild(s.expression) });
                case e.AwaitExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.AwaitExpression, argument: this.convertChild(s.expression) });
                case e.NoSubstitutionTemplateLiteral:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TemplateLiteral, quasis: [this.createNode(s, { type: E.AST_NODE_TYPES.TemplateElement, value: { raw: this.ast.text.slice(s.getStart(this.ast) + 1, s.end - 1), cooked: s.text }, tail: true })], expressions: [] });
                case e.TemplateExpression: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TemplateLiteral, quasis: [this.convertChild(s.head)], expressions: [] });
                  return s.templateSpans.forEach((B) => {
                    V.expressions.push(this.convertChild(B.expression)), V.quasis.push(this.convertChild(B.literal));
                  }), V;
                }
                case e.TaggedTemplateExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TaggedTemplateExpression, typeParameters: s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : void 0, tag: this.convertChild(s.tag), quasi: this.convertChild(s.template) });
                case e.TemplateHead:
                case e.TemplateMiddle:
                case e.TemplateTail: {
                  let V = s.kind === e.TemplateTail;
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TemplateElement, value: { raw: this.ast.text.slice(s.getStart(this.ast) + 1, s.end - (V ? 1 : 2)), cooked: s.text }, tail: V });
                }
                case e.SpreadAssignment:
                case e.SpreadElement:
                  return this.allowPattern ? this.createNode(s, { type: E.AST_NODE_TYPES.RestElement, argument: this.convertPattern(s.expression) }) : this.createNode(s, { type: E.AST_NODE_TYPES.SpreadElement, argument: this.convertChild(s.expression) });
                case e.Parameter: {
                  let V, B;
                  return s.dotDotDotToken ? V = B = this.createNode(s, { type: E.AST_NODE_TYPES.RestElement, argument: this.convertChild(s.name) }) : s.initializer ? (V = this.convertChild(s.name), B = this.createNode(s, { type: E.AST_NODE_TYPES.AssignmentPattern, left: V, right: this.convertChild(s.initializer) }), (0, z.getModifiers)(s) && (B.range[0] = V.range[0], B.loc = (0, I.getLocFor)(B.range[0], B.range[1], this.ast))) : V = B = this.convertChild(s.name, q), s.type && (V.typeAnnotation = this.convertTypeAnnotation(s.type, s), this.fixParentLocation(V, V.typeAnnotation.range)), s.questionToken && (s.questionToken.end > V.range[1] && (V.range[1] = s.questionToken.end, V.loc.end = (0, I.getLineAndCharacterFor)(V.range[1], this.ast)), V.optional = true), (0, z.getModifiers)(s) ? this.createNode(s, { type: E.AST_NODE_TYPES.TSParameterProperty, accessibility: (Ee = (0, I.getTSNodeAccessibility)(s)) !== null && Ee !== void 0 ? Ee : void 0, readonly: (0, I.hasModifier)(e.ReadonlyKeyword, s) || void 0, static: (0, I.hasModifier)(e.StaticKeyword, s) || void 0, export: (0, I.hasModifier)(e.ExportKeyword, s) || void 0, override: (0, I.hasModifier)(e.OverrideKeyword, s) || void 0, parameter: B }) : B;
                }
                case e.ClassDeclaration:
                case e.ClassExpression: {
                  let V = (Se = s.heritageClauses) !== null && Se !== void 0 ? Se : [], B = s.kind === e.ClassDeclaration ? E.AST_NODE_TYPES.ClassDeclaration : E.AST_NODE_TYPES.ClassExpression, U = V.find((S) => S.token === e.ExtendsKeyword), m = V.find((S) => S.token === e.ImplementsKeyword), v = this.createNode(s, { type: B, id: this.convertChild(s.name), body: this.createNode(s, { type: E.AST_NODE_TYPES.ClassBody, body: [], range: [s.members.pos - 1, s.end] }), superClass: U != null && U.types[0] ? this.convertChild(U.types[0].expression) : null });
                  if (U) {
                    if (U.types.length > 1)
                      throw (0, I.createError)(this.ast, U.types[1].pos, "Classes can only extend a single class.");
                    !((J = U.types[0]) === null || J === void 0) && J.typeArguments && (v.superTypeParameters = this.convertTypeArgumentsToTypeParameters(U.types[0].typeArguments, U.types[0]));
                  }
                  s.typeParameters && (v.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), m && (v.implements = m.types.map((S) => this.convertChild(S))), (0, I.hasModifier)(e.AbstractKeyword, s) && (v.abstract = true), (0, I.hasModifier)(e.DeclareKeyword, s) && (v.declare = true);
                  let g = (0, z.getDecorators)(s);
                  g && (v.decorators = g.map((S) => this.convertChild(S)));
                  let O = s.members.filter(I.isESTreeClassMember);
                  return O.length && (v.body.body = O.map((S) => this.convertChild(S))), this.fixExports(s, v);
                }
                case e.ModuleBlock:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSModuleBlock, body: this.convertBodyExpressions(s.statements, s) });
                case e.ImportDeclaration: {
                  this.assertModuleSpecifier(s, false);
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.ImportDeclaration, source: this.convertChild(s.moduleSpecifier), specifiers: [], importKind: "value", assertions: this.convertAssertClasue(s.assertClause) });
                  if (s.importClause && (s.importClause.isTypeOnly && (V.importKind = "type"), s.importClause.name && V.specifiers.push(this.convertChild(s.importClause)), s.importClause.namedBindings))
                    switch (s.importClause.namedBindings.kind) {
                      case e.NamespaceImport:
                        V.specifiers.push(this.convertChild(s.importClause.namedBindings));
                        break;
                      case e.NamedImports:
                        V.specifiers = V.specifiers.concat(s.importClause.namedBindings.elements.map((B) => this.convertChild(B)));
                        break;
                    }
                  return V;
                }
                case e.NamespaceImport:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ImportNamespaceSpecifier, local: this.convertChild(s.name) });
                case e.ImportSpecifier:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ImportSpecifier, local: this.convertChild(s.name), imported: this.convertChild((se = s.propertyName) !== null && se !== void 0 ? se : s.name), importKind: s.isTypeOnly ? "type" : "value" });
                case e.ImportClause: {
                  let V = this.convertChild(s.name);
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ImportDefaultSpecifier, local: V, range: V.range });
                }
                case e.ExportDeclaration:
                  return ((Me = s.exportClause) === null || Me === void 0 ? void 0 : Me.kind) === e.NamedExports ? (this.assertModuleSpecifier(s, true), this.createNode(s, { type: E.AST_NODE_TYPES.ExportNamedDeclaration, source: this.convertChild(s.moduleSpecifier), specifiers: s.exportClause.elements.map((V) => this.convertChild(V)), exportKind: s.isTypeOnly ? "type" : "value", declaration: null, assertions: this.convertAssertClasue(s.assertClause) })) : (this.assertModuleSpecifier(s, false), this.createNode(s, { type: E.AST_NODE_TYPES.ExportAllDeclaration, source: this.convertChild(s.moduleSpecifier), exportKind: s.isTypeOnly ? "type" : "value", exported: s.exportClause && s.exportClause.kind === e.NamespaceExport ? this.convertChild(s.exportClause.name) : null, assertions: this.convertAssertClasue(s.assertClause) }));
                case e.ExportSpecifier:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ExportSpecifier, local: this.convertChild((Q = s.propertyName) !== null && Q !== void 0 ? Q : s.name), exported: this.convertChild(s.name), exportKind: s.isTypeOnly ? "type" : "value" });
                case e.ExportAssignment:
                  return s.isExportEquals ? this.createNode(s, { type: E.AST_NODE_TYPES.TSExportAssignment, expression: this.convertChild(s.expression) }) : this.createNode(s, { type: E.AST_NODE_TYPES.ExportDefaultDeclaration, declaration: this.convertChild(s.expression), exportKind: "value" });
                case e.PrefixUnaryExpression:
                case e.PostfixUnaryExpression: {
                  let V = (0, I.getTextForTokenKind)(s.operator);
                  return V === "++" || V === "--" ? this.createNode(s, { type: E.AST_NODE_TYPES.UpdateExpression, operator: V, prefix: s.kind === e.PrefixUnaryExpression, argument: this.convertChild(s.operand) }) : this.createNode(s, { type: E.AST_NODE_TYPES.UnaryExpression, operator: V, prefix: s.kind === e.PrefixUnaryExpression, argument: this.convertChild(s.operand) });
                }
                case e.DeleteExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.UnaryExpression, operator: "delete", prefix: true, argument: this.convertChild(s.expression) });
                case e.VoidExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.UnaryExpression, operator: "void", prefix: true, argument: this.convertChild(s.expression) });
                case e.TypeOfExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.UnaryExpression, operator: "typeof", prefix: true, argument: this.convertChild(s.expression) });
                case e.TypeOperator:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeOperator, operator: (0, I.getTextForTokenKind)(s.operator), typeAnnotation: this.convertChild(s.type) });
                case e.BinaryExpression:
                  if ((0, I.isComma)(s.operatorToken)) {
                    let V = this.createNode(s, { type: E.AST_NODE_TYPES.SequenceExpression, expressions: [] }), B = this.convertChild(s.left);
                    return B.type === E.AST_NODE_TYPES.SequenceExpression && s.left.kind !== e.ParenthesizedExpression ? V.expressions = V.expressions.concat(B.expressions) : V.expressions.push(B), V.expressions.push(this.convertChild(s.right)), V;
                  } else {
                    let V = (0, I.getBinaryExpressionType)(s.operatorToken);
                    return this.allowPattern && V === E.AST_NODE_TYPES.AssignmentExpression ? this.createNode(s, { type: E.AST_NODE_TYPES.AssignmentPattern, left: this.convertPattern(s.left, s), right: this.convertChild(s.right) }) : this.createNode(s, { type: V, operator: (0, I.getTextForTokenKind)(s.operatorToken.kind), left: this.converter(s.left, s, this.inTypeMode, V === E.AST_NODE_TYPES.AssignmentExpression), right: this.convertChild(s.right) });
                  }
                case e.PropertyAccessExpression: {
                  let V = this.convertChild(s.expression), B = this.convertChild(s.name), U = false, m = this.createNode(s, { type: E.AST_NODE_TYPES.MemberExpression, object: V, property: B, computed: U, optional: s.questionDotToken !== void 0 });
                  return this.convertChainExpression(m, s);
                }
                case e.ElementAccessExpression: {
                  let V = this.convertChild(s.expression), B = this.convertChild(s.argumentExpression), U = true, m = this.createNode(s, { type: E.AST_NODE_TYPES.MemberExpression, object: V, property: B, computed: U, optional: s.questionDotToken !== void 0 });
                  return this.convertChainExpression(m, s);
                }
                case e.CallExpression: {
                  if (s.expression.kind === e.ImportKeyword) {
                    if (s.arguments.length !== 1 && s.arguments.length !== 2)
                      throw (0, I.createError)(this.ast, s.arguments.pos, "Dynamic import requires exactly one or two arguments.");
                    return this.createNode(s, { type: E.AST_NODE_TYPES.ImportExpression, source: this.convertChild(s.arguments[0]), attributes: s.arguments[1] ? this.convertChild(s.arguments[1]) : null });
                  }
                  let V = this.convertChild(s.expression), B = s.arguments.map((m) => this.convertChild(m)), U = this.createNode(s, { type: E.AST_NODE_TYPES.CallExpression, callee: V, arguments: B, optional: s.questionDotToken !== void 0 });
                  return s.typeArguments && (U.typeParameters = this.convertTypeArgumentsToTypeParameters(s.typeArguments, s)), this.convertChainExpression(U, s);
                }
                case e.NewExpression: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.NewExpression, callee: this.convertChild(s.expression), arguments: s.arguments ? s.arguments.map((B) => this.convertChild(B)) : [] });
                  return s.typeArguments && (V.typeParameters = this.convertTypeArgumentsToTypeParameters(s.typeArguments, s)), V;
                }
                case e.ConditionalExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ConditionalExpression, test: this.convertChild(s.condition), consequent: this.convertChild(s.whenTrue), alternate: this.convertChild(s.whenFalse) });
                case e.MetaProperty:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.MetaProperty, meta: this.createNode(s.getFirstToken(), { type: E.AST_NODE_TYPES.Identifier, name: (0, I.getTextForTokenKind)(s.keywordToken) }), property: this.convertChild(s.name) });
                case e.Decorator:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Decorator, expression: this.convertChild(s.expression) });
                case e.StringLiteral:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: q.kind === e.JsxAttribute ? (0, I.unescapeStringLiteralText)(s.text) : s.text, raw: s.getText() });
                case e.NumericLiteral:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: Number(s.text), raw: s.getText() });
                case e.BigIntLiteral: {
                  let V = (0, I.getRange)(s, this.ast), B = this.ast.text.slice(V[0], V[1]), U = B.slice(0, -1).replace(/_/g, ""), m = typeof BigInt < "u" ? BigInt(U) : null;
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, raw: B, value: m, bigint: m === null ? U : String(m), range: V });
                }
                case e.RegularExpressionLiteral: {
                  let V = s.text.slice(1, s.text.lastIndexOf("/")), B = s.text.slice(s.text.lastIndexOf("/") + 1), U = null;
                  try {
                    U = new RegExp(V, B);
                  } catch {
                    U = null;
                  }
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: U, raw: s.text, regex: { pattern: V, flags: B } });
                }
                case e.TrueKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: true, raw: "true" });
                case e.FalseKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: false, raw: "false" });
                case e.NullKeyword:
                  return !N.typescriptVersionIsAtLeast["4.0"] && this.inTypeMode ? this.createNode(s, { type: E.AST_NODE_TYPES.TSNullKeyword }) : this.createNode(s, { type: E.AST_NODE_TYPES.Literal, value: null, raw: "null" });
                case e.EmptyStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.EmptyStatement });
                case e.DebuggerStatement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.DebuggerStatement });
                case e.JsxElement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXElement, openingElement: this.convertChild(s.openingElement), closingElement: this.convertChild(s.closingElement), children: s.children.map((V) => this.convertChild(V)) });
                case e.JsxFragment:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXFragment, openingFragment: this.convertChild(s.openingFragment), closingFragment: this.convertChild(s.closingFragment), children: s.children.map((V) => this.convertChild(V)) });
                case e.JsxSelfClosingElement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXElement, openingElement: this.createNode(s, { type: E.AST_NODE_TYPES.JSXOpeningElement, typeParameters: s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : void 0, selfClosing: true, name: this.convertJSXTagName(s.tagName, s), attributes: s.attributes.properties.map((V) => this.convertChild(V)), range: (0, I.getRange)(s, this.ast) }), closingElement: null, children: [] });
                case e.JsxOpeningElement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXOpeningElement, typeParameters: s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : void 0, selfClosing: false, name: this.convertJSXTagName(s.tagName, s), attributes: s.attributes.properties.map((V) => this.convertChild(V)) });
                case e.JsxClosingElement:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXClosingElement, name: this.convertJSXTagName(s.tagName, s) });
                case e.JsxOpeningFragment:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXOpeningFragment });
                case e.JsxClosingFragment:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXClosingFragment });
                case e.JsxExpression: {
                  let V = s.expression ? this.convertChild(s.expression) : this.createNode(s, { type: E.AST_NODE_TYPES.JSXEmptyExpression, range: [s.getStart(this.ast) + 1, s.getEnd() - 1] });
                  return s.dotDotDotToken ? this.createNode(s, { type: E.AST_NODE_TYPES.JSXSpreadChild, expression: V }) : this.createNode(s, { type: E.AST_NODE_TYPES.JSXExpressionContainer, expression: V });
                }
                case e.JsxAttribute:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXAttribute, name: this.convertJSXNamespaceOrIdentifier(s.name), value: this.convertChild(s.initializer) });
                case e.JsxText: {
                  let V = s.getFullStart(), B = s.getEnd(), U = this.ast.text.slice(V, B);
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXText, value: (0, I.unescapeStringLiteralText)(U), raw: U, range: [V, B] });
                }
                case e.JsxSpreadAttribute:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.JSXSpreadAttribute, argument: this.convertChild(s.expression) });
                case e.QualifiedName:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSQualifiedName, left: this.convertChild(s.left), right: this.convertChild(s.right) });
                case e.TypeReference:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeReference, typeName: this.convertType(s.typeName), typeParameters: s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : void 0 });
                case e.TypeParameter:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeParameter, name: this.convertType(s.name), constraint: s.constraint ? this.convertType(s.constraint) : void 0, default: s.default ? this.convertType(s.default) : void 0, in: (0, I.hasModifier)(e.InKeyword, s), out: (0, I.hasModifier)(e.OutKeyword, s) });
                case e.ThisType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSThisType });
                case e.AnyKeyword:
                case e.BigIntKeyword:
                case e.BooleanKeyword:
                case e.NeverKeyword:
                case e.NumberKeyword:
                case e.ObjectKeyword:
                case e.StringKeyword:
                case e.SymbolKeyword:
                case e.UnknownKeyword:
                case e.VoidKeyword:
                case e.UndefinedKeyword:
                case e.IntrinsicKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES[`TS${e[s.kind]}`] });
                case e.NonNullExpression: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSNonNullExpression, expression: this.convertChild(s.expression) });
                  return this.convertChainExpression(V, s);
                }
                case e.TypeLiteral:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeLiteral, members: s.members.map((V) => this.convertChild(V)) });
                case e.ArrayType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSArrayType, elementType: this.convertType(s.elementType) });
                case e.IndexedAccessType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSIndexedAccessType, objectType: this.convertType(s.objectType), indexType: this.convertType(s.indexType) });
                case e.ConditionalType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSConditionalType, checkType: this.convertType(s.checkType), extendsType: this.convertType(s.extendsType), trueType: this.convertType(s.trueType), falseType: this.convertType(s.falseType) });
                case e.TypeQuery:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeQuery, exprName: this.convertType(s.exprName), typeParameters: s.typeArguments && this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) });
                case e.MappedType: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSMappedType, typeParameter: this.convertType(s.typeParameter), nameType: (Be = this.convertType(s.nameType)) !== null && Be !== void 0 ? Be : null });
                  return s.readonlyToken && (s.readonlyToken.kind === e.ReadonlyKeyword ? V.readonly = true : V.readonly = (0, I.getTextForTokenKind)(s.readonlyToken.kind)), s.questionToken && (s.questionToken.kind === e.QuestionToken ? V.optional = true : V.optional = (0, I.getTextForTokenKind)(s.questionToken.kind)), s.type && (V.typeAnnotation = this.convertType(s.type)), V;
                }
                case e.ParenthesizedExpression:
                  return this.convertChild(s.expression, q);
                case e.TypeAliasDeclaration: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeAliasDeclaration, id: this.convertChild(s.name), typeAnnotation: this.convertType(s.type) });
                  return (0, I.hasModifier)(e.DeclareKeyword, s) && (V.declare = true), s.typeParameters && (V.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), this.fixExports(s, V);
                }
                case e.MethodSignature:
                  return this.convertMethodSignature(s);
                case e.PropertySignature: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSPropertySignature, optional: (0, I.isOptional)(s) || void 0, computed: (0, I.isComputedProperty)(s.name), key: this.convertChild(s.name), typeAnnotation: s.type ? this.convertTypeAnnotation(s.type, s) : void 0, initializer: this.convertChild(s.initializer) || void 0, readonly: (0, I.hasModifier)(e.ReadonlyKeyword, s) || void 0, static: (0, I.hasModifier)(e.StaticKeyword, s) || void 0, export: (0, I.hasModifier)(e.ExportKeyword, s) || void 0 }), B = (0, I.getTSNodeAccessibility)(s);
                  return B && (V.accessibility = B), V;
                }
                case e.IndexSignature: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSIndexSignature, parameters: s.parameters.map((U) => this.convertChild(U)) });
                  s.type && (V.typeAnnotation = this.convertTypeAnnotation(s.type, s)), (0, I.hasModifier)(e.ReadonlyKeyword, s) && (V.readonly = true);
                  let B = (0, I.getTSNodeAccessibility)(s);
                  return B && (V.accessibility = B), (0, I.hasModifier)(e.ExportKeyword, s) && (V.export = true), (0, I.hasModifier)(e.StaticKeyword, s) && (V.static = true), V;
                }
                case e.ConstructorType: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSConstructorType, params: this.convertParameters(s.parameters), abstract: (0, I.hasModifier)(e.AbstractKeyword, s) });
                  return s.type && (V.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (V.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), V;
                }
                case e.FunctionType:
                case e.ConstructSignature:
                case e.CallSignature: {
                  let V = s.kind === e.ConstructSignature ? E.AST_NODE_TYPES.TSConstructSignatureDeclaration : s.kind === e.CallSignature ? E.AST_NODE_TYPES.TSCallSignatureDeclaration : E.AST_NODE_TYPES.TSFunctionType, B = this.createNode(s, { type: V, params: this.convertParameters(s.parameters) });
                  return s.type && (B.returnType = this.convertTypeAnnotation(s.type, s)), s.typeParameters && (B.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), B;
                }
                case e.ExpressionWithTypeArguments: {
                  let V = q.kind, B = V === e.InterfaceDeclaration ? E.AST_NODE_TYPES.TSInterfaceHeritage : V === e.HeritageClause ? E.AST_NODE_TYPES.TSClassImplements : E.AST_NODE_TYPES.TSInstantiationExpression, U = this.createNode(s, { type: B, expression: this.convertChild(s.expression) });
                  return s.typeArguments && (U.typeParameters = this.convertTypeArgumentsToTypeParameters(s.typeArguments, s)), U;
                }
                case e.InterfaceDeclaration: {
                  let V = (je = s.heritageClauses) !== null && je !== void 0 ? je : [], B = this.createNode(s, { type: E.AST_NODE_TYPES.TSInterfaceDeclaration, body: this.createNode(s, { type: E.AST_NODE_TYPES.TSInterfaceBody, body: s.members.map((U) => this.convertChild(U)), range: [s.members.pos - 1, s.end] }), id: this.convertChild(s.name) });
                  if (s.typeParameters && (B.typeParameters = this.convertTSTypeParametersToTypeParametersDeclaration(s.typeParameters)), V.length > 0) {
                    let U = [], m = [];
                    for (let v of V)
                      if (v.token === e.ExtendsKeyword)
                        for (let g of v.types)
                          U.push(this.convertChild(g, s));
                      else
                        for (let g of v.types)
                          m.push(this.convertChild(g, s));
                    U.length && (B.extends = U), m.length && (B.implements = m);
                  }
                  return (0, I.hasModifier)(e.AbstractKeyword, s) && (B.abstract = true), (0, I.hasModifier)(e.DeclareKeyword, s) && (B.declare = true), this.fixExports(s, B);
                }
                case e.TypePredicate: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSTypePredicate, asserts: s.assertsModifier !== void 0, parameterName: this.convertChild(s.parameterName), typeAnnotation: null });
                  return s.type && (V.typeAnnotation = this.convertTypeAnnotation(s.type, s), V.typeAnnotation.loc = V.typeAnnotation.typeAnnotation.loc, V.typeAnnotation.range = V.typeAnnotation.typeAnnotation.range), V;
                }
                case e.ImportType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSImportType, isTypeOf: !!s.isTypeOf, parameter: this.convertChild(s.argument), qualifier: this.convertChild(s.qualifier), typeParameters: s.typeArguments ? this.convertTypeArgumentsToTypeParameters(s.typeArguments, s) : null });
                case e.EnumDeclaration: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSEnumDeclaration, id: this.convertChild(s.name), members: s.members.map((B) => this.convertChild(B)) });
                  return this.applyModifiersToResult(V, (0, z.getModifiers)(s)), this.fixExports(s, V);
                }
                case e.EnumMember: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSEnumMember, id: this.convertChild(s.name) });
                  return s.initializer && (V.initializer = this.convertChild(s.initializer)), s.name.kind === ae.SyntaxKind.ComputedPropertyName && (V.computed = true), V;
                }
                case e.ModuleDeclaration: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSModuleDeclaration, id: this.convertChild(s.name) });
                  return s.body && (V.body = this.convertChild(s.body)), this.applyModifiersToResult(V, (0, z.getModifiers)(s)), s.flags & ae.NodeFlags.GlobalAugmentation && (V.global = true), this.fixExports(s, V);
                }
                case e.ParenthesizedType:
                  return this.convertType(s.type);
                case e.UnionType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSUnionType, types: s.types.map((V) => this.convertType(V)) });
                case e.IntersectionType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSIntersectionType, types: s.types.map((V) => this.convertType(V)) });
                case e.AsExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSAsExpression, expression: this.convertChild(s.expression), typeAnnotation: this.convertType(s.type) });
                case e.InferType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSInferType, typeParameter: this.convertType(s.typeParameter) });
                case e.LiteralType:
                  return N.typescriptVersionIsAtLeast["4.0"] && s.literal.kind === e.NullKeyword ? this.createNode(s.literal, { type: E.AST_NODE_TYPES.TSNullKeyword }) : this.createNode(s, { type: E.AST_NODE_TYPES.TSLiteralType, literal: this.convertType(s.literal) });
                case e.TypeAssertionExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTypeAssertion, typeAnnotation: this.convertType(s.type), expression: this.convertChild(s.expression) });
                case e.ImportEqualsDeclaration:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSImportEqualsDeclaration, id: this.convertChild(s.name), moduleReference: this.convertChild(s.moduleReference), importKind: s.isTypeOnly ? "type" : "value", isExport: (0, I.hasModifier)(e.ExportKeyword, s) });
                case e.ExternalModuleReference:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSExternalModuleReference, expression: this.convertChild(s.expression) });
                case e.NamespaceExportDeclaration:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSNamespaceExportDeclaration, id: this.convertChild(s.name) });
                case e.AbstractKeyword:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSAbstractKeyword });
                case e.TupleType: {
                  let V = "elementTypes" in s ? s.elementTypes.map((B) => this.convertType(B)) : s.elements.map((B) => this.convertType(B));
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSTupleType, elementTypes: V });
                }
                case e.NamedTupleMember: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSNamedTupleMember, elementType: this.convertType(s.type, s), label: this.convertChild(s.name, s), optional: s.questionToken != null });
                  return s.dotDotDotToken ? (V.range[0] = V.label.range[0], V.loc.start = V.label.loc.start, this.createNode(s, { type: E.AST_NODE_TYPES.TSRestType, typeAnnotation: V })) : V;
                }
                case e.OptionalType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSOptionalType, typeAnnotation: this.convertType(s.type) });
                case e.RestType:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSRestType, typeAnnotation: this.convertType(s.type) });
                case e.TemplateLiteralType: {
                  let V = this.createNode(s, { type: E.AST_NODE_TYPES.TSTemplateLiteralType, quasis: [this.convertChild(s.head)], types: [] });
                  return s.templateSpans.forEach((B) => {
                    V.types.push(this.convertChild(B.type)), V.quasis.push(this.convertChild(B.literal));
                  }), V;
                }
                case e.ClassStaticBlockDeclaration:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.StaticBlock, body: this.convertBodyExpressions(s.body.statements, s) });
                case e.AssertEntry:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.ImportAttribute, key: this.convertChild(s.name), value: this.convertChild(s.value) });
                case e.SatisfiesExpression:
                  return this.createNode(s, { type: E.AST_NODE_TYPES.TSSatisfiesExpression, expression: this.convertChild(s.expression), typeAnnotation: this.convertChild(s.type) });
                default:
                  return this.deeplyCopy(s);
              }
            }
          };
          a.Converter = w;
        } }), ho = {};
        Tl(ho, { __assign: () => bl, __asyncDelegator: () => $E, __asyncGenerator: () => XE, __asyncValues: () => QE, __await: () => Fu, __awaiter: () => zE, __classPrivateFieldGet: () => rT, __classPrivateFieldSet: () => tT, __createBinding: () => WE, __decorate: () => BE, __exportStar: () => KE, __extends: () => JE, __generator: () => VE, __importDefault: () => eT, __importStar: () => ZE, __makeTemplateObject: () => YE, __metadata: () => UE, __param: () => qE, __read: () => hy, __rest: () => FE, __spread: () => HE, __spreadArrays: () => GE, __values: () => Hp });
        function JE(a, _) {
          vl(a, _);
          function D() {
            this.constructor = a;
          }
          a.prototype = _ === null ? Object.create(_) : (D.prototype = _.prototype, new D());
        }
        function FE(a, _) {
          var D = {};
          for (var T in a)
            Object.prototype.hasOwnProperty.call(a, T) && _.indexOf(T) < 0 && (D[T] = a[T]);
          if (a != null && typeof Object.getOwnPropertySymbols == "function")
            for (var ae = 0, T = Object.getOwnPropertySymbols(a); ae < T.length; ae++)
              _.indexOf(T[ae]) < 0 && Object.prototype.propertyIsEnumerable.call(a, T[ae]) && (D[T[ae]] = a[T[ae]]);
          return D;
        }
        function BE(a, _, D, T) {
          var ae = arguments.length, z = ae < 3 ? _ : T === null ? T = Object.getOwnPropertyDescriptor(_, D) : T, I;
          if (typeof Reflect == "object" && typeof Reflect.decorate == "function")
            z = Reflect.decorate(a, _, D, T);
          else
            for (var E = a.length - 1; E >= 0; E--)
              (I = a[E]) && (z = (ae < 3 ? I(z) : ae > 3 ? I(_, D, z) : I(_, D)) || z);
          return ae > 3 && z && Object.defineProperty(_, D, z), z;
        }
        function qE(a, _) {
          return function(D, T) {
            _(D, T, a);
          };
        }
        function UE(a, _) {
          if (typeof Reflect == "object" && typeof Reflect.metadata == "function")
            return Reflect.metadata(a, _);
        }
        function zE(a, _, D, T) {
          function ae(z) {
            return z instanceof D ? z : new D(function(I) {
              I(z);
            });
          }
          return new (D || (D = Promise))(function(z, I) {
            function E(t3) {
              try {
                e(T.next(t3));
              } catch (w) {
                I(w);
              }
            }
            function N(t3) {
              try {
                e(T.throw(t3));
              } catch (w) {
                I(w);
              }
            }
            function e(t3) {
              t3.done ? z(t3.value) : ae(t3.value).then(E, N);
            }
            e((T = T.apply(a, _ || [])).next());
          });
        }
        function VE(a, _) {
          var D = { label: 0, sent: function() {
            if (z[0] & 1)
              throw z[1];
            return z[1];
          }, trys: [], ops: [] }, T, ae, z, I;
          return I = { next: E(0), throw: E(1), return: E(2) }, typeof Symbol == "function" && (I[Symbol.iterator] = function() {
            return this;
          }), I;
          function E(e) {
            return function(t3) {
              return N([e, t3]);
            };
          }
          function N(e) {
            if (T)
              throw new TypeError("Generator is already executing.");
            for (; D; )
              try {
                if (T = 1, ae && (z = e[0] & 2 ? ae.return : e[0] ? ae.throw || ((z = ae.return) && z.call(ae), 0) : ae.next) && !(z = z.call(ae, e[1])).done)
                  return z;
                switch (ae = 0, z && (e = [e[0] & 2, z.value]), e[0]) {
                  case 0:
                  case 1:
                    z = e;
                    break;
                  case 4:
                    return D.label++, { value: e[1], done: false };
                  case 5:
                    D.label++, ae = e[1], e = [0];
                    continue;
                  case 7:
                    e = D.ops.pop(), D.trys.pop();
                    continue;
                  default:
                    if (z = D.trys, !(z = z.length > 0 && z[z.length - 1]) && (e[0] === 6 || e[0] === 2)) {
                      D = 0;
                      continue;
                    }
                    if (e[0] === 3 && (!z || e[1] > z[0] && e[1] < z[3])) {
                      D.label = e[1];
                      break;
                    }
                    if (e[0] === 6 && D.label < z[1]) {
                      D.label = z[1], z = e;
                      break;
                    }
                    if (z && D.label < z[2]) {
                      D.label = z[2], D.ops.push(e);
                      break;
                    }
                    z[2] && D.ops.pop(), D.trys.pop();
                    continue;
                }
                e = _.call(a, D);
              } catch (t3) {
                e = [6, t3], ae = 0;
              } finally {
                T = z = 0;
              }
            if (e[0] & 5)
              throw e[1];
            return { value: e[0] ? e[1] : void 0, done: true };
          }
        }
        function WE(a, _, D, T) {
          T === void 0 && (T = D), a[T] = _[D];
        }
        function KE(a, _) {
          for (var D in a)
            D !== "default" && !_.hasOwnProperty(D) && (_[D] = a[D]);
        }
        function Hp(a) {
          var _ = typeof Symbol == "function" && Symbol.iterator, D = _ && a[_], T = 0;
          if (D)
            return D.call(a);
          if (a && typeof a.length == "number")
            return { next: function() {
              return a && T >= a.length && (a = void 0), { value: a && a[T++], done: !a };
            } };
          throw new TypeError(_ ? "Object is not iterable." : "Symbol.iterator is not defined.");
        }
        function hy(a, _) {
          var D = typeof Symbol == "function" && a[Symbol.iterator];
          if (!D)
            return a;
          var T = D.call(a), ae, z = [], I;
          try {
            for (; (_ === void 0 || _-- > 0) && !(ae = T.next()).done; )
              z.push(ae.value);
          } catch (E) {
            I = { error: E };
          } finally {
            try {
              ae && !ae.done && (D = T.return) && D.call(T);
            } finally {
              if (I)
                throw I.error;
            }
          }
          return z;
        }
        function HE() {
          for (var a = [], _ = 0; _ < arguments.length; _++)
            a = a.concat(hy(arguments[_]));
          return a;
        }
        function GE() {
          for (var a = 0, _ = 0, D = arguments.length; _ < D; _++)
            a += arguments[_].length;
          for (var T = Array(a), ae = 0, _ = 0; _ < D; _++)
            for (var z = arguments[_], I = 0, E = z.length; I < E; I++, ae++)
              T[ae] = z[I];
          return T;
        }
        function Fu(a) {
          return this instanceof Fu ? (this.v = a, this) : new Fu(a);
        }
        function XE(a, _, D) {
          if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
          var T = D.apply(a, _ || []), ae, z = [];
          return ae = {}, I("next"), I("throw"), I("return"), ae[Symbol.asyncIterator] = function() {
            return this;
          }, ae;
          function I(s) {
            T[s] && (ae[s] = function(q) {
              return new Promise(function(F, fe) {
                z.push([s, q, F, fe]) > 1 || E(s, q);
              });
            });
          }
          function E(s, q) {
            try {
              N(T[s](q));
            } catch (F) {
              w(z[0][3], F);
            }
          }
          function N(s) {
            s.value instanceof Fu ? Promise.resolve(s.value.v).then(e, t3) : w(z[0][2], s);
          }
          function e(s) {
            E("next", s);
          }
          function t3(s) {
            E("throw", s);
          }
          function w(s, q) {
            s(q), z.shift(), z.length && E(z[0][0], z[0][1]);
          }
        }
        function $E(a) {
          var _, D;
          return _ = {}, T("next"), T("throw", function(ae) {
            throw ae;
          }), T("return"), _[Symbol.iterator] = function() {
            return this;
          }, _;
          function T(ae, z) {
            _[ae] = a[ae] ? function(I) {
              return (D = !D) ? { value: Fu(a[ae](I)), done: ae === "return" } : z ? z(I) : I;
            } : z;
          }
        }
        function QE(a) {
          if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
          var _ = a[Symbol.asyncIterator], D;
          return _ ? _.call(a) : (a = typeof Hp == "function" ? Hp(a) : a[Symbol.iterator](), D = {}, T("next"), T("throw"), T("return"), D[Symbol.asyncIterator] = function() {
            return this;
          }, D);
          function T(z) {
            D[z] = a[z] && function(I) {
              return new Promise(function(E, N) {
                I = a[z](I), ae(E, N, I.done, I.value);
              });
            };
          }
          function ae(z, I, E, N) {
            Promise.resolve(N).then(function(e) {
              z({ value: e, done: E });
            }, I);
          }
        }
        function YE(a, _) {
          return Object.defineProperty ? Object.defineProperty(a, "raw", { value: _ }) : a.raw = _, a;
        }
        function ZE(a) {
          if (a && a.__esModule)
            return a;
          var _ = {};
          if (a != null)
            for (var D in a)
              Object.hasOwnProperty.call(a, D) && (_[D] = a[D]);
          return _.default = a, _;
        }
        function eT(a) {
          return a && a.__esModule ? a : { default: a };
        }
        function rT(a, _) {
          if (!_.has(a))
            throw new TypeError("attempted to get private field on non-instance");
          return _.get(a);
        }
        function tT(a, _, D) {
          if (!_.has(a))
            throw new TypeError("attempted to set private field on non-instance");
          return _.set(a, D), D;
        }
        var vl, bl, Ko = Bu({ "node_modules/tslib/tslib.es6.js"() {
          Jr(), vl = function(a, _) {
            return vl = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(D, T) {
              D.__proto__ = T;
            } || function(D, T) {
              for (var ae in T)
                T.hasOwnProperty(ae) && (D[ae] = T[ae]);
            }, vl(a, _);
          }, bl = function() {
            return bl = Object.assign || function(_) {
              for (var D, T = 1, ae = arguments.length; T < ae; T++) {
                D = arguments[T];
                for (var z in D)
                  Object.prototype.hasOwnProperty.call(D, z) && (_[z] = D[z]);
              }
              return _;
            }, bl.apply(this, arguments);
          };
        } }), nT = Ur({ "node_modules/tsutils/typeguard/2.8/node.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isExpressionStatement = a.isExpression = a.isExportSpecifier = a.isExportDeclaration = a.isExportAssignment = a.isEnumMember = a.isEnumDeclaration = a.isEntityNameExpression = a.isEntityName = a.isEmptyStatement = a.isElementAccessExpression = a.isDoStatement = a.isDeleteExpression = a.isDefaultClause = a.isDecorator = a.isDebuggerStatement = a.isComputedPropertyName = a.isContinueStatement = a.isConstructSignatureDeclaration = a.isConstructorTypeNode = a.isConstructorDeclaration = a.isConditionalTypeNode = a.isConditionalExpression = a.isCommaListExpression = a.isClassLikeDeclaration = a.isClassExpression = a.isClassDeclaration = a.isCatchClause = a.isCaseOrDefaultClause = a.isCaseClause = a.isCaseBlock = a.isCallSignatureDeclaration = a.isCallLikeExpression = a.isCallExpression = a.isBreakStatement = a.isBreakOrContinueStatement = a.isBooleanLiteral = a.isBlockLike = a.isBlock = a.isBindingPattern = a.isBindingElement = a.isBinaryExpression = a.isAwaitExpression = a.isAssertionExpression = a.isAsExpression = a.isArrowFunction = a.isArrayTypeNode = a.isArrayLiteralExpression = a.isArrayBindingPattern = a.isAccessorDeclaration = void 0, a.isNamespaceImport = a.isNamespaceDeclaration = a.isNamedImports = a.isNamedExports = a.isModuleDeclaration = a.isModuleBlock = a.isMethodSignature = a.isMethodDeclaration = a.isMetaProperty = a.isMappedTypeNode = a.isLiteralTypeNode = a.isLiteralExpression = a.isLabeledStatement = a.isJsxText = a.isJsxSpreadAttribute = a.isJsxSelfClosingElement = a.isJsxOpeningLikeElement = a.isJsxOpeningFragment = a.isJsxOpeningElement = a.isJsxFragment = a.isJsxExpression = a.isJsxElement = a.isJsxClosingFragment = a.isJsxClosingElement = a.isJsxAttributes = a.isJsxAttributeLike = a.isJsxAttribute = a.isJsDoc = a.isIterationStatement = a.isIntersectionTypeNode = a.isInterfaceDeclaration = a.isInferTypeNode = a.isIndexSignatureDeclaration = a.isIndexedAccessTypeNode = a.isImportSpecifier = a.isImportEqualsDeclaration = a.isImportDeclaration = a.isImportClause = a.isIfStatement = a.isIdentifier = a.isGetAccessorDeclaration = a.isFunctionTypeNode = a.isFunctionExpression = a.isFunctionDeclaration = a.isForStatement = a.isForOfStatement = a.isForInOrOfStatement = a.isForInStatement = a.isExternalModuleReference = a.isExpressionWithTypeArguments = void 0, a.isVariableStatement = a.isVariableDeclaration = a.isUnionTypeNode = a.isTypeQueryNode = a.isTypeReferenceNode = a.isTypePredicateNode = a.isTypeParameterDeclaration = a.isTypeOperatorNode = a.isTypeOfExpression = a.isTypeLiteralNode = a.isTypeAssertion = a.isTypeAliasDeclaration = a.isTupleTypeNode = a.isTryStatement = a.isThrowStatement = a.isTextualLiteral = a.isTemplateLiteral = a.isTemplateExpression = a.isTaggedTemplateExpression = a.isSyntaxList = a.isSwitchStatement = a.isStringLiteral = a.isSpreadElement = a.isSpreadAssignment = a.isSourceFile = a.isSignatureDeclaration = a.isShorthandPropertyAssignment = a.isSetAccessorDeclaration = a.isReturnStatement = a.isRegularExpressionLiteral = a.isQualifiedName = a.isPropertySignature = a.isPropertyDeclaration = a.isPropertyAssignment = a.isPropertyAccessExpression = a.isPrefixUnaryExpression = a.isPostfixUnaryExpression = a.isParenthesizedTypeNode = a.isParenthesizedExpression = a.isParameterDeclaration = a.isOmittedExpression = a.isObjectLiteralExpression = a.isObjectBindingPattern = a.isNumericOrStringLikeLiteral = a.isNumericLiteral = a.isNullLiteral = a.isNoSubstitutionTemplateLiteral = a.isNonNullExpression = a.isNewExpression = a.isNamespaceExportDeclaration = void 0, a.isWithStatement = a.isWhileStatement = a.isVoidExpression = a.isVariableDeclarationList = void 0;
          var _ = Di();
          function D(_e) {
            return _e.kind === _.SyntaxKind.GetAccessor || _e.kind === _.SyntaxKind.SetAccessor;
          }
          a.isAccessorDeclaration = D;
          function T(_e) {
            return _e.kind === _.SyntaxKind.ArrayBindingPattern;
          }
          a.isArrayBindingPattern = T;
          function ae(_e) {
            return _e.kind === _.SyntaxKind.ArrayLiteralExpression;
          }
          a.isArrayLiteralExpression = ae;
          function z(_e) {
            return _e.kind === _.SyntaxKind.ArrayType;
          }
          a.isArrayTypeNode = z;
          function I(_e) {
            return _e.kind === _.SyntaxKind.ArrowFunction;
          }
          a.isArrowFunction = I;
          function E(_e) {
            return _e.kind === _.SyntaxKind.AsExpression;
          }
          a.isAsExpression = E;
          function N(_e) {
            return _e.kind === _.SyntaxKind.AsExpression || _e.kind === _.SyntaxKind.TypeAssertionExpression;
          }
          a.isAssertionExpression = N;
          function e(_e) {
            return _e.kind === _.SyntaxKind.AwaitExpression;
          }
          a.isAwaitExpression = e;
          function t3(_e) {
            return _e.kind === _.SyntaxKind.BinaryExpression;
          }
          a.isBinaryExpression = t3;
          function w(_e) {
            return _e.kind === _.SyntaxKind.BindingElement;
          }
          a.isBindingElement = w;
          function s(_e) {
            return _e.kind === _.SyntaxKind.ArrayBindingPattern || _e.kind === _.SyntaxKind.ObjectBindingPattern;
          }
          a.isBindingPattern = s;
          function q(_e) {
            return _e.kind === _.SyntaxKind.Block;
          }
          a.isBlock = q;
          function F(_e) {
            return _e.statements !== void 0;
          }
          a.isBlockLike = F;
          function fe(_e) {
            return _e.kind === _.SyntaxKind.TrueKeyword || _e.kind === _.SyntaxKind.FalseKeyword;
          }
          a.isBooleanLiteral = fe;
          function Ee(_e) {
            return _e.kind === _.SyntaxKind.BreakStatement || _e.kind === _.SyntaxKind.ContinueStatement;
          }
          a.isBreakOrContinueStatement = Ee;
          function Se(_e) {
            return _e.kind === _.SyntaxKind.BreakStatement;
          }
          a.isBreakStatement = Se;
          function J(_e) {
            return _e.kind === _.SyntaxKind.CallExpression;
          }
          a.isCallExpression = J;
          function se(_e) {
            switch (_e.kind) {
              case _.SyntaxKind.CallExpression:
              case _.SyntaxKind.Decorator:
              case _.SyntaxKind.JsxOpeningElement:
              case _.SyntaxKind.JsxSelfClosingElement:
              case _.SyntaxKind.NewExpression:
              case _.SyntaxKind.TaggedTemplateExpression:
                return true;
              default:
                return false;
            }
          }
          a.isCallLikeExpression = se;
          function Me(_e) {
            return _e.kind === _.SyntaxKind.CallSignature;
          }
          a.isCallSignatureDeclaration = Me;
          function Q(_e) {
            return _e.kind === _.SyntaxKind.CaseBlock;
          }
          a.isCaseBlock = Q;
          function Be(_e) {
            return _e.kind === _.SyntaxKind.CaseClause;
          }
          a.isCaseClause = Be;
          function je(_e) {
            return _e.kind === _.SyntaxKind.CaseClause || _e.kind === _.SyntaxKind.DefaultClause;
          }
          a.isCaseOrDefaultClause = je;
          function V(_e) {
            return _e.kind === _.SyntaxKind.CatchClause;
          }
          a.isCatchClause = V;
          function B(_e) {
            return _e.kind === _.SyntaxKind.ClassDeclaration;
          }
          a.isClassDeclaration = B;
          function U(_e) {
            return _e.kind === _.SyntaxKind.ClassExpression;
          }
          a.isClassExpression = U;
          function m(_e) {
            return _e.kind === _.SyntaxKind.ClassDeclaration || _e.kind === _.SyntaxKind.ClassExpression;
          }
          a.isClassLikeDeclaration = m;
          function v(_e) {
            return _e.kind === _.SyntaxKind.CommaListExpression;
          }
          a.isCommaListExpression = v;
          function g(_e) {
            return _e.kind === _.SyntaxKind.ConditionalExpression;
          }
          a.isConditionalExpression = g;
          function O(_e) {
            return _e.kind === _.SyntaxKind.ConditionalType;
          }
          a.isConditionalTypeNode = O;
          function S(_e) {
            return _e.kind === _.SyntaxKind.Constructor;
          }
          a.isConstructorDeclaration = S;
          function te(_e) {
            return _e.kind === _.SyntaxKind.ConstructorType;
          }
          a.isConstructorTypeNode = te;
          function Je(_e) {
            return _e.kind === _.SyntaxKind.ConstructSignature;
          }
          a.isConstructSignatureDeclaration = Je;
          function qe(_e) {
            return _e.kind === _.SyntaxKind.ContinueStatement;
          }
          a.isContinueStatement = qe;
          function ge(_e) {
            return _e.kind === _.SyntaxKind.ComputedPropertyName;
          }
          a.isComputedPropertyName = ge;
          function ie(_e) {
            return _e.kind === _.SyntaxKind.DebuggerStatement;
          }
          a.isDebuggerStatement = ie;
          function H(_e) {
            return _e.kind === _.SyntaxKind.Decorator;
          }
          a.isDecorator = H;
          function pe(_e) {
            return _e.kind === _.SyntaxKind.DefaultClause;
          }
          a.isDefaultClause = pe;
          function j(_e) {
            return _e.kind === _.SyntaxKind.DeleteExpression;
          }
          a.isDeleteExpression = j;
          function be(_e) {
            return _e.kind === _.SyntaxKind.DoStatement;
          }
          a.isDoStatement = be;
          function Xe(_e) {
            return _e.kind === _.SyntaxKind.ElementAccessExpression;
          }
          a.isElementAccessExpression = Xe;
          function Re(_e) {
            return _e.kind === _.SyntaxKind.EmptyStatement;
          }
          a.isEmptyStatement = Re;
          function Fe(_e) {
            return _e.kind === _.SyntaxKind.Identifier || ei(_e);
          }
          a.isEntityName = Fe;
          function dr(_e) {
            return _e.kind === _.SyntaxKind.Identifier || ln(_e) && dr(_e.expression);
          }
          a.isEntityNameExpression = dr;
          function ze(_e) {
            return _e.kind === _.SyntaxKind.EnumDeclaration;
          }
          a.isEnumDeclaration = ze;
          function ve(_e) {
            return _e.kind === _.SyntaxKind.EnumMember;
          }
          a.isEnumMember = ve;
          function er(_e) {
            return _e.kind === _.SyntaxKind.ExportAssignment;
          }
          a.isExportAssignment = er;
          function ar(_e) {
            return _e.kind === _.SyntaxKind.ExportDeclaration;
          }
          a.isExportDeclaration = ar;
          function Cr(_e) {
            return _e.kind === _.SyntaxKind.ExportSpecifier;
          }
          a.isExportSpecifier = Cr;
          function Ce(_e) {
            switch (_e.kind) {
              case _.SyntaxKind.ArrayLiteralExpression:
              case _.SyntaxKind.ArrowFunction:
              case _.SyntaxKind.AsExpression:
              case _.SyntaxKind.AwaitExpression:
              case _.SyntaxKind.BinaryExpression:
              case _.SyntaxKind.CallExpression:
              case _.SyntaxKind.ClassExpression:
              case _.SyntaxKind.CommaListExpression:
              case _.SyntaxKind.ConditionalExpression:
              case _.SyntaxKind.DeleteExpression:
              case _.SyntaxKind.ElementAccessExpression:
              case _.SyntaxKind.FalseKeyword:
              case _.SyntaxKind.FunctionExpression:
              case _.SyntaxKind.Identifier:
              case _.SyntaxKind.JsxElement:
              case _.SyntaxKind.JsxFragment:
              case _.SyntaxKind.JsxExpression:
              case _.SyntaxKind.JsxOpeningElement:
              case _.SyntaxKind.JsxOpeningFragment:
              case _.SyntaxKind.JsxSelfClosingElement:
              case _.SyntaxKind.MetaProperty:
              case _.SyntaxKind.NewExpression:
              case _.SyntaxKind.NonNullExpression:
              case _.SyntaxKind.NoSubstitutionTemplateLiteral:
              case _.SyntaxKind.NullKeyword:
              case _.SyntaxKind.NumericLiteral:
              case _.SyntaxKind.ObjectLiteralExpression:
              case _.SyntaxKind.OmittedExpression:
              case _.SyntaxKind.ParenthesizedExpression:
              case _.SyntaxKind.PostfixUnaryExpression:
              case _.SyntaxKind.PrefixUnaryExpression:
              case _.SyntaxKind.PropertyAccessExpression:
              case _.SyntaxKind.RegularExpressionLiteral:
              case _.SyntaxKind.SpreadElement:
              case _.SyntaxKind.StringLiteral:
              case _.SyntaxKind.SuperKeyword:
              case _.SyntaxKind.TaggedTemplateExpression:
              case _.SyntaxKind.TemplateExpression:
              case _.SyntaxKind.ThisKeyword:
              case _.SyntaxKind.TrueKeyword:
              case _.SyntaxKind.TypeAssertionExpression:
              case _.SyntaxKind.TypeOfExpression:
              case _.SyntaxKind.VoidExpression:
              case _.SyntaxKind.YieldExpression:
                return true;
              default:
                return false;
            }
          }
          a.isExpression = Ce;
          function $e(_e) {
            return _e.kind === _.SyntaxKind.ExpressionStatement;
          }
          a.isExpressionStatement = $e;
          function gr(_e) {
            return _e.kind === _.SyntaxKind.ExpressionWithTypeArguments;
          }
          a.isExpressionWithTypeArguments = gr;
          function X(_e) {
            return _e.kind === _.SyntaxKind.ExternalModuleReference;
          }
          a.isExternalModuleReference = X;
          function Te(_e) {
            return _e.kind === _.SyntaxKind.ForInStatement;
          }
          a.isForInStatement = Te;
          function we(_e) {
            return _e.kind === _.SyntaxKind.ForOfStatement || _e.kind === _.SyntaxKind.ForInStatement;
          }
          a.isForInOrOfStatement = we;
          function he(_e) {
            return _e.kind === _.SyntaxKind.ForOfStatement;
          }
          a.isForOfStatement = he;
          function yr(_e) {
            return _e.kind === _.SyntaxKind.ForStatement;
          }
          a.isForStatement = yr;
          function kr(_e) {
            return _e.kind === _.SyntaxKind.FunctionDeclaration;
          }
          a.isFunctionDeclaration = kr;
          function nr(_e) {
            return _e.kind === _.SyntaxKind.FunctionExpression;
          }
          a.isFunctionExpression = nr;
          function tr(_e) {
            return _e.kind === _.SyntaxKind.FunctionType;
          }
          a.isFunctionTypeNode = tr;
          function Lr(_e) {
            return _e.kind === _.SyntaxKind.GetAccessor;
          }
          a.isGetAccessorDeclaration = Lr;
          function zr(_e) {
            return _e.kind === _.SyntaxKind.Identifier;
          }
          a.isIdentifier = zr;
          function ye(_e) {
            return _e.kind === _.SyntaxKind.IfStatement;
          }
          a.isIfStatement = ye;
          function ir(_e) {
            return _e.kind === _.SyntaxKind.ImportClause;
          }
          a.isImportClause = ir;
          function Dr(_e) {
            return _e.kind === _.SyntaxKind.ImportDeclaration;
          }
          a.isImportDeclaration = Dr;
          function Pr(_e) {
            return _e.kind === _.SyntaxKind.ImportEqualsDeclaration;
          }
          a.isImportEqualsDeclaration = Pr;
          function Br(_e) {
            return _e.kind === _.SyntaxKind.ImportSpecifier;
          }
          a.isImportSpecifier = Br;
          function ut(_e) {
            return _e.kind === _.SyntaxKind.IndexedAccessType;
          }
          a.isIndexedAccessTypeNode = ut;
          function rt(_e) {
            return _e.kind === _.SyntaxKind.IndexSignature;
          }
          a.isIndexSignatureDeclaration = rt;
          function Z(_e) {
            return _e.kind === _.SyntaxKind.InferType;
          }
          a.isInferTypeNode = Z;
          function f(_e) {
            return _e.kind === _.SyntaxKind.InterfaceDeclaration;
          }
          a.isInterfaceDeclaration = f;
          function h(_e) {
            return _e.kind === _.SyntaxKind.IntersectionType;
          }
          a.isIntersectionTypeNode = h;
          function oe(_e) {
            switch (_e.kind) {
              case _.SyntaxKind.ForStatement:
              case _.SyntaxKind.ForOfStatement:
              case _.SyntaxKind.ForInStatement:
              case _.SyntaxKind.WhileStatement:
              case _.SyntaxKind.DoStatement:
                return true;
              default:
                return false;
            }
          }
          a.isIterationStatement = oe;
          function xr(_e) {
            return _e.kind === _.SyntaxKind.JSDocComment;
          }
          a.isJsDoc = xr;
          function jr(_e) {
            return _e.kind === _.SyntaxKind.JsxAttribute;
          }
          a.isJsxAttribute = jr;
          function qr(_e) {
            return _e.kind === _.SyntaxKind.JsxAttribute || _e.kind === _.SyntaxKind.JsxSpreadAttribute;
          }
          a.isJsxAttributeLike = qr;
          function pt(_e) {
            return _e.kind === _.SyntaxKind.JsxAttributes;
          }
          a.isJsxAttributes = pt;
          function Ge(_e) {
            return _e.kind === _.SyntaxKind.JsxClosingElement;
          }
          a.isJsxClosingElement = Ge;
          function K(_e) {
            return _e.kind === _.SyntaxKind.JsxClosingFragment;
          }
          a.isJsxClosingFragment = K;
          function r(_e) {
            return _e.kind === _.SyntaxKind.JsxElement;
          }
          a.isJsxElement = r;
          function ct(_e) {
            return _e.kind === _.SyntaxKind.JsxExpression;
          }
          a.isJsxExpression = ct;
          function ft(_e) {
            return _e.kind === _.SyntaxKind.JsxFragment;
          }
          a.isJsxFragment = ft;
          function Ie(_e) {
            return _e.kind === _.SyntaxKind.JsxOpeningElement;
          }
          a.isJsxOpeningElement = Ie;
          function me(_e) {
            return _e.kind === _.SyntaxKind.JsxOpeningFragment;
          }
          a.isJsxOpeningFragment = me;
          function xe(_e) {
            return _e.kind === _.SyntaxKind.JsxOpeningElement || _e.kind === _.SyntaxKind.JsxSelfClosingElement;
          }
          a.isJsxOpeningLikeElement = xe;
          function Ye(_e) {
            return _e.kind === _.SyntaxKind.JsxSelfClosingElement;
          }
          a.isJsxSelfClosingElement = Ye;
          function vr(_e) {
            return _e.kind === _.SyntaxKind.JsxSpreadAttribute;
          }
          a.isJsxSpreadAttribute = vr;
          function nt(_e) {
            return _e.kind === _.SyntaxKind.JsxText;
          }
          a.isJsxText = nt;
          function pr(_e) {
            return _e.kind === _.SyntaxKind.LabeledStatement;
          }
          a.isLabeledStatement = pr;
          function Mr(_e) {
            return _e.kind >= _.SyntaxKind.FirstLiteralToken && _e.kind <= _.SyntaxKind.LastLiteralToken;
          }
          a.isLiteralExpression = Mr;
          function ot(_e) {
            return _e.kind === _.SyntaxKind.LiteralType;
          }
          a.isLiteralTypeNode = ot;
          function At(_e) {
            return _e.kind === _.SyntaxKind.MappedType;
          }
          a.isMappedTypeNode = At;
          function re(_e) {
            return _e.kind === _.SyntaxKind.MetaProperty;
          }
          a.isMetaProperty = re;
          function de(_e) {
            return _e.kind === _.SyntaxKind.MethodDeclaration;
          }
          a.isMethodDeclaration = de;
          function He(_e) {
            return _e.kind === _.SyntaxKind.MethodSignature;
          }
          a.isMethodSignature = He;
          function Nr(_e) {
            return _e.kind === _.SyntaxKind.ModuleBlock;
          }
          a.isModuleBlock = Nr;
          function Yr(_e) {
            return _e.kind === _.SyntaxKind.ModuleDeclaration;
          }
          a.isModuleDeclaration = Yr;
          function Ct(_e) {
            return _e.kind === _.SyntaxKind.NamedExports;
          }
          a.isNamedExports = Ct;
          function xt(_e) {
            return _e.kind === _.SyntaxKind.NamedImports;
          }
          a.isNamedImports = xt;
          function Lt(_e) {
            return Yr(_e) && _e.name.kind === _.SyntaxKind.Identifier && _e.body !== void 0 && (_e.body.kind === _.SyntaxKind.ModuleBlock || Lt(_e.body));
          }
          a.isNamespaceDeclaration = Lt;
          function zt(_e) {
            return _e.kind === _.SyntaxKind.NamespaceImport;
          }
          a.isNamespaceImport = zt;
          function Zt(_e) {
            return _e.kind === _.SyntaxKind.NamespaceExportDeclaration;
          }
          a.isNamespaceExportDeclaration = Zt;
          function mt(_e) {
            return _e.kind === _.SyntaxKind.NewExpression;
          }
          a.isNewExpression = mt;
          function at(_e) {
            return _e.kind === _.SyntaxKind.NonNullExpression;
          }
          a.isNonNullExpression = at;
          function k(_e) {
            return _e.kind === _.SyntaxKind.NoSubstitutionTemplateLiteral;
          }
          a.isNoSubstitutionTemplateLiteral = k;
          function ue(_e) {
            return _e.kind === _.SyntaxKind.NullKeyword;
          }
          a.isNullLiteral = ue;
          function Qe(_e) {
            return _e.kind === _.SyntaxKind.NumericLiteral;
          }
          a.isNumericLiteral = Qe;
          function Sr(_e) {
            switch (_e.kind) {
              case _.SyntaxKind.StringLiteral:
              case _.SyntaxKind.NumericLiteral:
              case _.SyntaxKind.NoSubstitutionTemplateLiteral:
                return true;
              default:
                return false;
            }
          }
          a.isNumericOrStringLikeLiteral = Sr;
          function Kr(_e) {
            return _e.kind === _.SyntaxKind.ObjectBindingPattern;
          }
          a.isObjectBindingPattern = Kr;
          function Hr(_e) {
            return _e.kind === _.SyntaxKind.ObjectLiteralExpression;
          }
          a.isObjectLiteralExpression = Hr;
          function Dt(_e) {
            return _e.kind === _.SyntaxKind.OmittedExpression;
          }
          a.isOmittedExpression = Dt;
          function Xt(_e) {
            return _e.kind === _.SyntaxKind.Parameter;
          }
          a.isParameterDeclaration = Xt;
          function cn(_e) {
            return _e.kind === _.SyntaxKind.ParenthesizedExpression;
          }
          a.isParenthesizedExpression = cn;
          function In(_e) {
            return _e.kind === _.SyntaxKind.ParenthesizedType;
          }
          a.isParenthesizedTypeNode = In;
          function yn(_e) {
            return _e.kind === _.SyntaxKind.PostfixUnaryExpression;
          }
          a.isPostfixUnaryExpression = yn;
          function hn(_e) {
            return _e.kind === _.SyntaxKind.PrefixUnaryExpression;
          }
          a.isPrefixUnaryExpression = hn;
          function ln(_e) {
            return _e.kind === _.SyntaxKind.PropertyAccessExpression;
          }
          a.isPropertyAccessExpression = ln;
          function En(_e) {
            return _e.kind === _.SyntaxKind.PropertyAssignment;
          }
          a.isPropertyAssignment = En;
          function Vt(_e) {
            return _e.kind === _.SyntaxKind.PropertyDeclaration;
          }
          a.isPropertyDeclaration = Vt;
          function ui(_e) {
            return _e.kind === _.SyntaxKind.PropertySignature;
          }
          a.isPropertySignature = ui;
          function ei(_e) {
            return _e.kind === _.SyntaxKind.QualifiedName;
          }
          a.isQualifiedName = ei;
          function hi(_e) {
            return _e.kind === _.SyntaxKind.RegularExpressionLiteral;
          }
          a.isRegularExpressionLiteral = hi;
          function ri(_e) {
            return _e.kind === _.SyntaxKind.ReturnStatement;
          }
          a.isReturnStatement = ri;
          function vi(_e) {
            return _e.kind === _.SyntaxKind.SetAccessor;
          }
          a.isSetAccessorDeclaration = vi;
          function Qn(_e) {
            return _e.kind === _.SyntaxKind.ShorthandPropertyAssignment;
          }
          a.isShorthandPropertyAssignment = Qn;
          function Yn(_e) {
            return _e.parameters !== void 0;
          }
          a.isSignatureDeclaration = Yn;
          function oi(_e) {
            return _e.kind === _.SyntaxKind.SourceFile;
          }
          a.isSourceFile = oi;
          function bi(_e) {
            return _e.kind === _.SyntaxKind.SpreadAssignment;
          }
          a.isSpreadAssignment = bi;
          function Dn(_e) {
            return _e.kind === _.SyntaxKind.SpreadElement;
          }
          a.isSpreadElement = Dn;
          function Kn(_e) {
            return _e.kind === _.SyntaxKind.StringLiteral;
          }
          a.isStringLiteral = Kn;
          function si(_e) {
            return _e.kind === _.SyntaxKind.SwitchStatement;
          }
          a.isSwitchStatement = si;
          function di(_e) {
            return _e.kind === _.SyntaxKind.SyntaxList;
          }
          a.isSyntaxList = di;
          function Zn(_e) {
            return _e.kind === _.SyntaxKind.TaggedTemplateExpression;
          }
          a.isTaggedTemplateExpression = Zn;
          function Fn(_e) {
            return _e.kind === _.SyntaxKind.TemplateExpression;
          }
          a.isTemplateExpression = Fn;
          function gt(_e) {
            return _e.kind === _.SyntaxKind.TemplateExpression || _e.kind === _.SyntaxKind.NoSubstitutionTemplateLiteral;
          }
          a.isTemplateLiteral = gt;
          function mi(_e) {
            return _e.kind === _.SyntaxKind.StringLiteral || _e.kind === _.SyntaxKind.NoSubstitutionTemplateLiteral;
          }
          a.isTextualLiteral = mi;
          function dn(_e) {
            return _e.kind === _.SyntaxKind.ThrowStatement;
          }
          a.isThrowStatement = dn;
          function On(_e) {
            return _e.kind === _.SyntaxKind.TryStatement;
          }
          a.isTryStatement = On;
          function br(_e) {
            return _e.kind === _.SyntaxKind.TupleType;
          }
          a.isTupleTypeNode = br;
          function Ae(_e) {
            return _e.kind === _.SyntaxKind.TypeAliasDeclaration;
          }
          a.isTypeAliasDeclaration = Ae;
          function ur(_e) {
            return _e.kind === _.SyntaxKind.TypeAssertionExpression;
          }
          a.isTypeAssertion = ur;
          function L(_e) {
            return _e.kind === _.SyntaxKind.TypeLiteral;
          }
          a.isTypeLiteralNode = L;
          function qt(_e) {
            return _e.kind === _.SyntaxKind.TypeOfExpression;
          }
          a.isTypeOfExpression = qt;
          function nn(_e) {
            return _e.kind === _.SyntaxKind.TypeOperator;
          }
          a.isTypeOperatorNode = nn;
          function fr(_e) {
            return _e.kind === _.SyntaxKind.TypeParameter;
          }
          a.isTypeParameterDeclaration = fr;
          function Le(_e) {
            return _e.kind === _.SyntaxKind.TypePredicate;
          }
          a.isTypePredicateNode = Le;
          function Ve(_e) {
            return _e.kind === _.SyntaxKind.TypeReference;
          }
          a.isTypeReferenceNode = Ve;
          function _r(_e) {
            return _e.kind === _.SyntaxKind.TypeQuery;
          }
          a.isTypeQueryNode = _r;
          function lr(_e) {
            return _e.kind === _.SyntaxKind.UnionType;
          }
          a.isUnionTypeNode = lr;
          function Vr(_e) {
            return _e.kind === _.SyntaxKind.VariableDeclaration;
          }
          a.isVariableDeclaration = Vr;
          function tt(_e) {
            return _e.kind === _.SyntaxKind.VariableStatement;
          }
          a.isVariableStatement = tt;
          function dt(_e) {
            return _e.kind === _.SyntaxKind.VariableDeclarationList;
          }
          a.isVariableDeclarationList = dt;
          function It(_e) {
            return _e.kind === _.SyntaxKind.VoidExpression;
          }
          a.isVoidExpression = It;
          function an(_e) {
            return _e.kind === _.SyntaxKind.WhileStatement;
          }
          a.isWhileStatement = an;
          function sn(_e) {
            return _e.kind === _.SyntaxKind.WithStatement;
          }
          a.isWithStatement = sn;
        } }), iT = Ur({ "node_modules/tsutils/typeguard/2.9/node.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isImportTypeNode = void 0;
          var _ = (Ko(), ja(ho));
          _.__exportStar(nT(), a);
          var D = Di();
          function T(ae) {
            return ae.kind === D.SyntaxKind.ImportType;
          }
          a.isImportTypeNode = T;
        } }), aT = Ur({ "node_modules/tsutils/typeguard/3.0/node.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isSyntheticExpression = a.isRestTypeNode = a.isOptionalTypeNode = void 0;
          var _ = (Ko(), ja(ho));
          _.__exportStar(iT(), a);
          var D = Di();
          function T(I) {
            return I.kind === D.SyntaxKind.OptionalType;
          }
          a.isOptionalTypeNode = T;
          function ae(I) {
            return I.kind === D.SyntaxKind.RestType;
          }
          a.isRestTypeNode = ae;
          function z(I) {
            return I.kind === D.SyntaxKind.SyntheticExpression;
          }
          a.isSyntheticExpression = z;
        } }), vy = Ur({ "node_modules/tsutils/typeguard/3.2/node.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isBigIntLiteral = void 0;
          var _ = (Ko(), ja(ho));
          _.__exportStar(aT(), a);
          var D = Di();
          function T(ae) {
            return ae.kind === D.SyntaxKind.BigIntLiteral;
          }
          a.isBigIntLiteral = T;
        } }), by = Ur({ "node_modules/tsutils/typeguard/node.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = (Ko(), ja(ho));
          _.__exportStar(vy(), a);
        } }), oT = Ur({ "node_modules/tsutils/typeguard/2.8/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isUniqueESSymbolType = a.isUnionType = a.isUnionOrIntersectionType = a.isTypeVariable = a.isTypeReference = a.isTypeParameter = a.isSubstitutionType = a.isObjectType = a.isLiteralType = a.isIntersectionType = a.isInterfaceType = a.isInstantiableType = a.isIndexedAccessype = a.isIndexedAccessType = a.isGenericType = a.isEnumType = a.isConditionalType = void 0;
          var _ = Di();
          function D(se) {
            return (se.flags & _.TypeFlags.Conditional) !== 0;
          }
          a.isConditionalType = D;
          function T(se) {
            return (se.flags & _.TypeFlags.Enum) !== 0;
          }
          a.isEnumType = T;
          function ae(se) {
            return (se.flags & _.TypeFlags.Object) !== 0 && (se.objectFlags & _.ObjectFlags.ClassOrInterface) !== 0 && (se.objectFlags & _.ObjectFlags.Reference) !== 0;
          }
          a.isGenericType = ae;
          function z(se) {
            return (se.flags & _.TypeFlags.IndexedAccess) !== 0;
          }
          a.isIndexedAccessType = z;
          function I(se) {
            return (se.flags & _.TypeFlags.Index) !== 0;
          }
          a.isIndexedAccessype = I;
          function E(se) {
            return (se.flags & _.TypeFlags.Instantiable) !== 0;
          }
          a.isInstantiableType = E;
          function N(se) {
            return (se.flags & _.TypeFlags.Object) !== 0 && (se.objectFlags & _.ObjectFlags.ClassOrInterface) !== 0;
          }
          a.isInterfaceType = N;
          function e(se) {
            return (se.flags & _.TypeFlags.Intersection) !== 0;
          }
          a.isIntersectionType = e;
          function t3(se) {
            return (se.flags & (_.TypeFlags.StringOrNumberLiteral | _.TypeFlags.BigIntLiteral)) !== 0;
          }
          a.isLiteralType = t3;
          function w(se) {
            return (se.flags & _.TypeFlags.Object) !== 0;
          }
          a.isObjectType = w;
          function s(se) {
            return (se.flags & _.TypeFlags.Substitution) !== 0;
          }
          a.isSubstitutionType = s;
          function q(se) {
            return (se.flags & _.TypeFlags.TypeParameter) !== 0;
          }
          a.isTypeParameter = q;
          function F(se) {
            return (se.flags & _.TypeFlags.Object) !== 0 && (se.objectFlags & _.ObjectFlags.Reference) !== 0;
          }
          a.isTypeReference = F;
          function fe(se) {
            return (se.flags & _.TypeFlags.TypeVariable) !== 0;
          }
          a.isTypeVariable = fe;
          function Ee(se) {
            return (se.flags & _.TypeFlags.UnionOrIntersection) !== 0;
          }
          a.isUnionOrIntersectionType = Ee;
          function Se(se) {
            return (se.flags & _.TypeFlags.Union) !== 0;
          }
          a.isUnionType = Se;
          function J(se) {
            return (se.flags & _.TypeFlags.UniqueESSymbol) !== 0;
          }
          a.isUniqueESSymbolType = J;
        } }), Kg = Ur({ "node_modules/tsutils/typeguard/2.9/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = (Ko(), ja(ho));
          _.__exportStar(oT(), a);
        } }), sT = Ur({ "node_modules/tsutils/typeguard/3.0/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isTupleTypeReference = a.isTupleType = void 0;
          var _ = (Ko(), ja(ho));
          _.__exportStar(Kg(), a);
          var D = Di(), T = Kg();
          function ae(I) {
            return (I.flags & D.TypeFlags.Object && I.objectFlags & D.ObjectFlags.Tuple) !== 0;
          }
          a.isTupleType = ae;
          function z(I) {
            return T.isTypeReference(I) && ae(I.target);
          }
          a.isTupleTypeReference = z;
        } }), Ey = Ur({ "node_modules/tsutils/typeguard/3.2/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = (Ko(), ja(ho));
          _.__exportStar(sT(), a);
        } }), _T = Ur({ "node_modules/tsutils/typeguard/3.2/index.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = (Ko(), ja(ho));
          _.__exportStar(vy(), a), _.__exportStar(Ey(), a);
        } }), cT = Ur({ "node_modules/tsutils/typeguard/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = (Ko(), ja(ho));
          _.__exportStar(Ey(), a);
        } }), uT = Ur({ "node_modules/tsutils/util/type.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.getBaseClassMemberOfClassElement = a.getIteratorYieldResultFromIteratorResult = a.getInstanceTypeOfClassLikeDeclaration = a.getConstructorTypeOfClassLikeDeclaration = a.getSymbolOfClassLikeDeclaration = a.getPropertyNameFromType = a.symbolHasReadonlyDeclaration = a.isPropertyReadonlyInType = a.getWellKnownSymbolPropertyOfType = a.getPropertyOfType = a.isBooleanLiteralType = a.isFalsyType = a.isThenableType = a.someTypePart = a.intersectionTypeParts = a.unionTypeParts = a.getCallSignaturesOfType = a.isTypeAssignableToString = a.isTypeAssignableToNumber = a.isOptionalChainingUndefinedMarkerType = a.removeOptionalChainingUndefinedMarkerType = a.removeOptionalityFromType = a.isEmptyObjectType = void 0;
          var _ = Di(), D = cT(), T = Ty(), ae = by();
          function z(ie) {
            if (D.isObjectType(ie) && ie.objectFlags & _.ObjectFlags.Anonymous && ie.getProperties().length === 0 && ie.getCallSignatures().length === 0 && ie.getConstructSignatures().length === 0 && ie.getStringIndexType() === void 0 && ie.getNumberIndexType() === void 0) {
              let H = ie.getBaseTypes();
              return H === void 0 || H.every(z);
            }
            return false;
          }
          a.isEmptyObjectType = z;
          function I(ie, H) {
            if (!E(H, _.TypeFlags.Undefined))
              return H;
            let pe = E(H, _.TypeFlags.Null);
            return H = ie.getNonNullableType(H), pe ? ie.getNullableType(H, _.TypeFlags.Null) : H;
          }
          a.removeOptionalityFromType = I;
          function E(ie, H) {
            for (let pe of F(ie))
              if (T.isTypeFlagSet(pe, H))
                return true;
            return false;
          }
          function N(ie, H) {
            if (!D.isUnionType(H))
              return e(ie, H) ? H.getNonNullableType() : H;
            let pe = 0, j = false;
            for (let be of H.types)
              e(ie, be) ? j = true : pe |= be.flags;
            return j ? ie.getNullableType(H.getNonNullableType(), pe) : H;
          }
          a.removeOptionalChainingUndefinedMarkerType = N;
          function e(ie, H) {
            return T.isTypeFlagSet(H, _.TypeFlags.Undefined) && ie.getNullableType(H.getNonNullableType(), _.TypeFlags.Undefined) !== H;
          }
          a.isOptionalChainingUndefinedMarkerType = e;
          function t3(ie, H) {
            return s(ie, H, _.TypeFlags.NumberLike);
          }
          a.isTypeAssignableToNumber = t3;
          function w(ie, H) {
            return s(ie, H, _.TypeFlags.StringLike);
          }
          a.isTypeAssignableToString = w;
          function s(ie, H, pe) {
            pe |= _.TypeFlags.Any;
            let j;
            return function be(Xe) {
              if (D.isTypeParameter(Xe) && Xe.symbol !== void 0 && Xe.symbol.declarations !== void 0) {
                if (j === void 0)
                  j = /* @__PURE__ */ new Set([Xe]);
                else if (!j.has(Xe))
                  j.add(Xe);
                else
                  return false;
                let Re = Xe.symbol.declarations[0];
                return Re.constraint === void 0 ? true : be(ie.getTypeFromTypeNode(Re.constraint));
              }
              return D.isUnionType(Xe) ? Xe.types.every(be) : D.isIntersectionType(Xe) ? Xe.types.some(be) : T.isTypeFlagSet(Xe, pe);
            }(H);
          }
          function q(ie) {
            if (D.isUnionType(ie)) {
              let H = [];
              for (let pe of ie.types)
                H.push(...q(pe));
              return H;
            }
            if (D.isIntersectionType(ie)) {
              let H;
              for (let pe of ie.types) {
                let j = q(pe);
                if (j.length !== 0) {
                  if (H !== void 0)
                    return [];
                  H = j;
                }
              }
              return H === void 0 ? [] : H;
            }
            return ie.getCallSignatures();
          }
          a.getCallSignaturesOfType = q;
          function F(ie) {
            return D.isUnionType(ie) ? ie.types : [ie];
          }
          a.unionTypeParts = F;
          function fe(ie) {
            return D.isIntersectionType(ie) ? ie.types : [ie];
          }
          a.intersectionTypeParts = fe;
          function Ee(ie, H, pe) {
            return H(ie) ? ie.types.some(pe) : pe(ie);
          }
          a.someTypePart = Ee;
          function Se(ie, H) {
            let pe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : ie.getTypeAtLocation(H);
            for (let j of F(ie.getApparentType(pe))) {
              let be = j.getProperty("then");
              if (be === void 0)
                continue;
              let Xe = ie.getTypeOfSymbolAtLocation(be, H);
              for (let Re of F(Xe))
                for (let Fe of Re.getCallSignatures())
                  if (Fe.parameters.length !== 0 && J(ie, Fe.parameters[0], H))
                    return true;
            }
            return false;
          }
          a.isThenableType = Se;
          function J(ie, H, pe) {
            let j = ie.getApparentType(ie.getTypeOfSymbolAtLocation(H, pe));
            if (H.valueDeclaration.dotDotDotToken && (j = j.getNumberIndexType(), j === void 0))
              return false;
            for (let be of F(j))
              if (be.getCallSignatures().length !== 0)
                return true;
            return false;
          }
          function se(ie) {
            return ie.flags & (_.TypeFlags.Undefined | _.TypeFlags.Null | _.TypeFlags.Void) ? true : D.isLiteralType(ie) ? !ie.value : Me(ie, false);
          }
          a.isFalsyType = se;
          function Me(ie, H) {
            return T.isTypeFlagSet(ie, _.TypeFlags.BooleanLiteral) && ie.intrinsicName === (H ? "true" : "false");
          }
          a.isBooleanLiteralType = Me;
          function Q(ie, H) {
            return H.startsWith("__") ? ie.getProperties().find((pe) => pe.escapedName === H) : ie.getProperty(H);
          }
          a.getPropertyOfType = Q;
          function Be(ie, H, pe) {
            let j = "__@" + H;
            for (let be of ie.getProperties()) {
              if (!be.name.startsWith(j))
                continue;
              let Xe = pe.getApparentType(pe.getTypeAtLocation(be.valueDeclaration.name.expression)).symbol;
              if (be.escapedName === je(pe, Xe, H))
                return be;
            }
          }
          a.getWellKnownSymbolPropertyOfType = Be;
          function je(ie, H, pe) {
            let j = H && ie.getTypeOfSymbolAtLocation(H, H.valueDeclaration).getProperty(pe), be = j && ie.getTypeOfSymbolAtLocation(j, j.valueDeclaration);
            return be && D.isUniqueESSymbolType(be) ? be.escapedName : "__@" + pe;
          }
          function V(ie, H, pe) {
            let j = false, be = false;
            for (let Xe of F(ie))
              if (Q(Xe, H) === void 0) {
                let Re = (T.isNumericPropertyName(H) ? pe.getIndexInfoOfType(Xe, _.IndexKind.Number) : void 0) || pe.getIndexInfoOfType(Xe, _.IndexKind.String);
                if (Re !== void 0 && Re.isReadonly) {
                  if (j)
                    return true;
                  be = true;
                }
              } else {
                if (be || B(Xe, H, pe))
                  return true;
                j = true;
              }
            return false;
          }
          a.isPropertyReadonlyInType = V;
          function B(ie, H, pe) {
            return Ee(ie, D.isIntersectionType, (j) => {
              let be = Q(j, H);
              if (be === void 0)
                return false;
              if (be.flags & _.SymbolFlags.Transient) {
                if (/^(?:[1-9]\d*|0)$/.test(H) && D.isTupleTypeReference(j))
                  return j.target.readonly;
                switch (U(j, H, pe)) {
                  case true:
                    return true;
                  case false:
                    return false;
                  default:
                }
              }
              return T.isSymbolFlagSet(be, _.SymbolFlags.ValueModule) || m(be, pe);
            });
          }
          function U(ie, H, pe) {
            if (!D.isObjectType(ie) || !T.isObjectFlagSet(ie, _.ObjectFlags.Mapped))
              return;
            let j = ie.symbol.declarations[0];
            return j.readonlyToken !== void 0 && !/^__@[^@]+$/.test(H) ? j.readonlyToken.kind !== _.SyntaxKind.MinusToken : V(ie.modifiersType, H, pe);
          }
          function m(ie, H) {
            return (ie.flags & _.SymbolFlags.Accessor) === _.SymbolFlags.GetAccessor || ie.declarations !== void 0 && ie.declarations.some((pe) => T.isModifierFlagSet(pe, _.ModifierFlags.Readonly) || ae.isVariableDeclaration(pe) && T.isNodeFlagSet(pe.parent, _.NodeFlags.Const) || ae.isCallExpression(pe) && T.isReadonlyAssignmentDeclaration(pe, H) || ae.isEnumMember(pe) || (ae.isPropertyAssignment(pe) || ae.isShorthandPropertyAssignment(pe)) && T.isInConstContext(pe.parent));
          }
          a.symbolHasReadonlyDeclaration = m;
          function v(ie) {
            if (ie.flags & (_.TypeFlags.StringLiteral | _.TypeFlags.NumberLiteral)) {
              let H = String(ie.value);
              return { displayName: H, symbolName: _.escapeLeadingUnderscores(H) };
            }
            if (D.isUniqueESSymbolType(ie))
              return { displayName: `[${ie.symbol ? `${g(ie.symbol) ? "Symbol." : ""}${ie.symbol.name}` : ie.escapedName.replace(/^__@|@\d+$/g, "")}]`, symbolName: ie.escapedName };
          }
          a.getPropertyNameFromType = v;
          function g(ie) {
            return T.isSymbolFlagSet(ie, _.SymbolFlags.Property) && ie.valueDeclaration !== void 0 && ae.isInterfaceDeclaration(ie.valueDeclaration.parent) && ie.valueDeclaration.parent.name.text === "SymbolConstructor" && O(ie.valueDeclaration.parent);
          }
          function O(ie) {
            return T.isNodeFlagSet(ie.parent, _.NodeFlags.GlobalAugmentation) || ae.isSourceFile(ie.parent) && !_.isExternalModule(ie.parent);
          }
          function S(ie, H) {
            var pe;
            return H.getSymbolAtLocation((pe = ie.name) !== null && pe !== void 0 ? pe : T.getChildOfKind(ie, _.SyntaxKind.ClassKeyword));
          }
          a.getSymbolOfClassLikeDeclaration = S;
          function te(ie, H) {
            return ie.kind === _.SyntaxKind.ClassExpression ? H.getTypeAtLocation(ie) : H.getTypeOfSymbolAtLocation(S(ie, H), ie);
          }
          a.getConstructorTypeOfClassLikeDeclaration = te;
          function Je(ie, H) {
            return ie.kind === _.SyntaxKind.ClassDeclaration ? H.getTypeAtLocation(ie) : H.getDeclaredTypeOfSymbol(S(ie, H));
          }
          a.getInstanceTypeOfClassLikeDeclaration = Je;
          function qe(ie, H, pe) {
            return D.isUnionType(ie) && ie.types.find((j) => {
              let be = j.getProperty("done");
              return be !== void 0 && Me(I(pe, pe.getTypeOfSymbolAtLocation(be, H)), false);
            }) || ie;
          }
          a.getIteratorYieldResultFromIteratorResult = qe;
          function ge(ie, H) {
            if (!ae.isClassLikeDeclaration(ie.parent))
              return;
            let pe = T.getBaseOfClassLikeExpression(ie.parent);
            if (pe === void 0)
              return;
            let j = T.getSingleLateBoundPropertyNameOfPropertyName(ie.name, H);
            if (j === void 0)
              return;
            let be = H.getTypeAtLocation(T.hasModifier(ie.modifiers, _.SyntaxKind.StaticKeyword) ? pe.expression : pe);
            return Q(be, j.symbolName);
          }
          a.getBaseClassMemberOfClassElement = ge;
        } }), Ty = Ur({ "node_modules/tsutils/util/util.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.isValidIdentifier = a.getLineBreakStyle = a.getLineRanges = a.forEachComment = a.forEachTokenWithTrivia = a.forEachToken = a.isFunctionWithBody = a.hasOwnThisReference = a.isBlockScopeBoundary = a.isFunctionScopeBoundary = a.isTypeScopeBoundary = a.isScopeBoundary = a.ScopeBoundarySelector = a.ScopeBoundary = a.isInSingleStatementContext = a.isBlockScopedDeclarationStatement = a.isBlockScopedVariableDeclaration = a.isBlockScopedVariableDeclarationList = a.getVariableDeclarationKind = a.VariableDeclarationKind = a.forEachDeclaredVariable = a.forEachDestructuringIdentifier = a.getPropertyName = a.getWrappedNodeAtPosition = a.getAstNodeAtPosition = a.commentText = a.isPositionInComment = a.getCommentAtPosition = a.getTokenAtPosition = a.getNextToken = a.getPreviousToken = a.getNextStatement = a.getPreviousStatement = a.isModifierFlagSet = a.isObjectFlagSet = a.isSymbolFlagSet = a.isTypeFlagSet = a.isNodeFlagSet = a.hasAccessModifier = a.isParameterProperty = a.hasModifier = a.getModifier = a.isThisParameter = a.isKeywordKind = a.isJsDocKind = a.isTypeNodeKind = a.isAssignmentKind = a.isNodeKind = a.isTokenKind = a.getChildOfKind = void 0, a.getBaseOfClassLikeExpression = a.hasExhaustiveCaseClauses = a.formatPseudoBigInt = a.unwrapParentheses = a.getSingleLateBoundPropertyNameOfPropertyName = a.getLateBoundPropertyNamesOfPropertyName = a.getLateBoundPropertyNames = a.getPropertyNameOfWellKnownSymbol = a.isWellKnownSymbolLiterally = a.isBindableObjectDefinePropertyCall = a.isReadonlyAssignmentDeclaration = a.isInConstContext = a.isConstAssertion = a.getTsCheckDirective = a.getCheckJsDirective = a.isAmbientModule = a.isCompilerOptionEnabled = a.isStrictCompilerOptionEnabled = a.getIIFE = a.isAmbientModuleBlock = a.isStatementInAmbientContext = a.findImportLikeNodes = a.findImports = a.ImportKind = a.parseJsDocOfNode = a.getJsDoc = a.canHaveJsDoc = a.isReassignmentTarget = a.getAccessKind = a.AccessKind = a.isExpressionValueUsed = a.getDeclarationOfBindingElement = a.hasSideEffects = a.SideEffectOptions = a.isSameLine = a.isNumericPropertyName = a.isValidJsxIdentifier = a.isValidNumericLiteral = a.isValidPropertyName = a.isValidPropertyAccess = void 0;
          var _ = Di(), D = by(), T = _T(), ae = uT();
          function z(k, ue, Qe) {
            for (let Sr of k.getChildren(Qe))
              if (Sr.kind === ue)
                return Sr;
          }
          a.getChildOfKind = z;
          function I(k) {
            return k >= _.SyntaxKind.FirstToken && k <= _.SyntaxKind.LastToken;
          }
          a.isTokenKind = I;
          function E(k) {
            return k >= _.SyntaxKind.FirstNode;
          }
          a.isNodeKind = E;
          function N(k) {
            return k >= _.SyntaxKind.FirstAssignment && k <= _.SyntaxKind.LastAssignment;
          }
          a.isAssignmentKind = N;
          function e(k) {
            return k >= _.SyntaxKind.FirstTypeNode && k <= _.SyntaxKind.LastTypeNode;
          }
          a.isTypeNodeKind = e;
          function t3(k) {
            return k >= _.SyntaxKind.FirstJSDocNode && k <= _.SyntaxKind.LastJSDocNode;
          }
          a.isJsDocKind = t3;
          function w(k) {
            return k >= _.SyntaxKind.FirstKeyword && k <= _.SyntaxKind.LastKeyword;
          }
          a.isKeywordKind = w;
          function s(k) {
            return k.name.kind === _.SyntaxKind.Identifier && k.name.originalKeywordKind === _.SyntaxKind.ThisKeyword;
          }
          a.isThisParameter = s;
          function q(k, ue) {
            if (k.modifiers !== void 0) {
              for (let Qe of k.modifiers)
                if (Qe.kind === ue)
                  return Qe;
            }
          }
          a.getModifier = q;
          function F(k) {
            if (k === void 0)
              return false;
            for (var ue = arguments.length, Qe = new Array(ue > 1 ? ue - 1 : 0), Sr = 1; Sr < ue; Sr++)
              Qe[Sr - 1] = arguments[Sr];
            for (let Kr of k)
              if (Qe.includes(Kr.kind))
                return true;
            return false;
          }
          a.hasModifier = F;
          function fe(k) {
            return F(k.modifiers, _.SyntaxKind.PublicKeyword, _.SyntaxKind.ProtectedKeyword, _.SyntaxKind.PrivateKeyword, _.SyntaxKind.ReadonlyKeyword);
          }
          a.isParameterProperty = fe;
          function Ee(k) {
            return se(k, _.ModifierFlags.AccessibilityModifier);
          }
          a.hasAccessModifier = Ee;
          function Se(k, ue) {
            return (k.flags & ue) !== 0;
          }
          a.isNodeFlagSet = Se, a.isTypeFlagSet = Se, a.isSymbolFlagSet = Se;
          function J(k, ue) {
            return (k.objectFlags & ue) !== 0;
          }
          a.isObjectFlagSet = J;
          function se(k, ue) {
            return (_.getCombinedModifierFlags(k) & ue) !== 0;
          }
          a.isModifierFlagSet = se;
          function Me(k) {
            let ue = k.parent;
            if (D.isBlockLike(ue)) {
              let Qe = ue.statements.indexOf(k);
              if (Qe > 0)
                return ue.statements[Qe - 1];
            }
          }
          a.getPreviousStatement = Me;
          function Q(k) {
            let ue = k.parent;
            if (D.isBlockLike(ue)) {
              let Qe = ue.statements.indexOf(k);
              if (Qe < ue.statements.length)
                return ue.statements[Qe + 1];
            }
          }
          a.getNextStatement = Q;
          function Be(k, ue) {
            let { pos: Qe } = k;
            if (Qe !== 0) {
              do
                k = k.parent;
              while (k.pos === Qe);
              return B(k, Qe - 1, ue != null ? ue : k.getSourceFile(), false);
            }
          }
          a.getPreviousToken = Be;
          function je(k, ue) {
            if (k.kind === _.SyntaxKind.SourceFile || k.kind === _.SyntaxKind.EndOfFileToken)
              return;
            let Qe = k.end;
            for (k = k.parent; k.end === Qe; ) {
              if (k.parent === void 0)
                return k.endOfFileToken;
              k = k.parent;
            }
            return B(k, Qe, ue != null ? ue : k.getSourceFile(), false);
          }
          a.getNextToken = je;
          function V(k, ue, Qe, Sr) {
            if (!(ue < k.pos || ue >= k.end))
              return I(k.kind) ? k : B(k, ue, Qe != null ? Qe : k.getSourceFile(), Sr === true);
          }
          a.getTokenAtPosition = V;
          function B(k, ue, Qe, Sr) {
            if (!Sr && (k = O(k, ue), I(k.kind)))
              return k;
            e:
              for (; ; ) {
                for (let Kr of k.getChildren(Qe))
                  if (Kr.end > ue && (Sr || Kr.kind !== _.SyntaxKind.JSDocComment)) {
                    if (I(Kr.kind))
                      return Kr;
                    k = Kr;
                    continue e;
                  }
                return;
              }
          }
          function U(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : k, Sr = V(Qe, ue, k);
            if (Sr === void 0 || Sr.kind === _.SyntaxKind.JsxText || ue >= Sr.end - (_.tokenToString(Sr.kind) || "").length)
              return;
            let Kr = Sr.pos === 0 ? (_.getShebang(k.text) || "").length : Sr.pos;
            return Kr !== 0 && _.forEachTrailingCommentRange(k.text, Kr, m, ue) || _.forEachLeadingCommentRange(k.text, Kr, m, ue);
          }
          a.getCommentAtPosition = U;
          function m(k, ue, Qe, Sr, Kr) {
            return Kr >= k && Kr < ue ? { pos: k, end: ue, kind: Qe } : void 0;
          }
          function v(k, ue, Qe) {
            return U(k, ue, Qe) !== void 0;
          }
          a.isPositionInComment = v;
          function g(k, ue) {
            return k.substring(ue.pos + 2, ue.kind === _.SyntaxKind.SingleLineCommentTrivia ? ue.end : ue.end - 2);
          }
          a.commentText = g;
          function O(k, ue) {
            if (!(k.pos > ue || k.end <= ue)) {
              for (; E(k.kind); ) {
                let Qe = _.forEachChild(k, (Sr) => Sr.pos <= ue && Sr.end > ue ? Sr : void 0);
                if (Qe === void 0)
                  break;
                k = Qe;
              }
              return k;
            }
          }
          a.getAstNodeAtPosition = O;
          function S(k, ue) {
            if (k.node.pos > ue || k.node.end <= ue)
              return;
            e:
              for (; ; ) {
                for (let Qe of k.children) {
                  if (Qe.node.pos > ue)
                    return k;
                  if (Qe.node.end > ue) {
                    k = Qe;
                    continue e;
                  }
                }
                return k;
              }
          }
          a.getWrappedNodeAtPosition = S;
          function te(k) {
            if (k.kind === _.SyntaxKind.ComputedPropertyName) {
              let ue = Lt(k.expression);
              if (D.isPrefixUnaryExpression(ue)) {
                let Qe = false;
                switch (ue.operator) {
                  case _.SyntaxKind.MinusToken:
                    Qe = true;
                  case _.SyntaxKind.PlusToken:
                    return D.isNumericLiteral(ue.operand) ? `${Qe ? "-" : ""}${ue.operand.text}` : T.isBigIntLiteral(ue.operand) ? `${Qe ? "-" : ""}${ue.operand.text.slice(0, -1)}` : void 0;
                  default:
                    return;
                }
              }
              return T.isBigIntLiteral(ue) ? ue.text.slice(0, -1) : D.isNumericOrStringLikeLiteral(ue) ? ue.text : void 0;
            }
            return k.kind === _.SyntaxKind.PrivateIdentifier ? void 0 : k.text;
          }
          a.getPropertyName = te;
          function Je(k, ue) {
            for (let Qe of k.elements) {
              if (Qe.kind !== _.SyntaxKind.BindingElement)
                continue;
              let Sr;
              if (Qe.name.kind === _.SyntaxKind.Identifier ? Sr = ue(Qe) : Sr = Je(Qe.name, ue), Sr)
                return Sr;
            }
          }
          a.forEachDestructuringIdentifier = Je;
          function qe(k, ue) {
            for (let Qe of k.declarations) {
              let Sr;
              if (Qe.name.kind === _.SyntaxKind.Identifier ? Sr = ue(Qe) : Sr = Je(Qe.name, ue), Sr)
                return Sr;
            }
          }
          a.forEachDeclaredVariable = qe;
          var ge;
          (function(k) {
            k[k.Var = 0] = "Var", k[k.Let = 1] = "Let", k[k.Const = 2] = "Const";
          })(ge = a.VariableDeclarationKind || (a.VariableDeclarationKind = {}));
          function ie(k) {
            return k.flags & _.NodeFlags.Let ? 1 : k.flags & _.NodeFlags.Const ? 2 : 0;
          }
          a.getVariableDeclarationKind = ie;
          function H(k) {
            return (k.flags & _.NodeFlags.BlockScoped) !== 0;
          }
          a.isBlockScopedVariableDeclarationList = H;
          function pe(k) {
            let ue = k.parent;
            return ue.kind === _.SyntaxKind.CatchClause || H(ue);
          }
          a.isBlockScopedVariableDeclaration = pe;
          function j(k) {
            switch (k.kind) {
              case _.SyntaxKind.VariableStatement:
                return H(k.declarationList);
              case _.SyntaxKind.ClassDeclaration:
              case _.SyntaxKind.EnumDeclaration:
              case _.SyntaxKind.InterfaceDeclaration:
              case _.SyntaxKind.TypeAliasDeclaration:
                return true;
              default:
                return false;
            }
          }
          a.isBlockScopedDeclarationStatement = j;
          function be(k) {
            switch (k.parent.kind) {
              case _.SyntaxKind.ForStatement:
              case _.SyntaxKind.ForInStatement:
              case _.SyntaxKind.ForOfStatement:
              case _.SyntaxKind.WhileStatement:
              case _.SyntaxKind.DoStatement:
              case _.SyntaxKind.IfStatement:
              case _.SyntaxKind.WithStatement:
              case _.SyntaxKind.LabeledStatement:
                return true;
              default:
                return false;
            }
          }
          a.isInSingleStatementContext = be;
          var Xe;
          (function(k) {
            k[k.None = 0] = "None", k[k.Function = 1] = "Function", k[k.Block = 2] = "Block", k[k.Type = 4] = "Type", k[k.ConditionalType = 8] = "ConditionalType";
          })(Xe = a.ScopeBoundary || (a.ScopeBoundary = {}));
          var Re;
          (function(k) {
            k[k.Function = 1] = "Function", k[k.Block = 3] = "Block", k[k.Type = 7] = "Type", k[k.InferType = 8] = "InferType";
          })(Re = a.ScopeBoundarySelector || (a.ScopeBoundarySelector = {}));
          function Fe(k) {
            return ze(k) || ve(k) || dr(k);
          }
          a.isScopeBoundary = Fe;
          function dr(k) {
            switch (k.kind) {
              case _.SyntaxKind.InterfaceDeclaration:
              case _.SyntaxKind.TypeAliasDeclaration:
              case _.SyntaxKind.MappedType:
                return 4;
              case _.SyntaxKind.ConditionalType:
                return 8;
              default:
                return 0;
            }
          }
          a.isTypeScopeBoundary = dr;
          function ze(k) {
            switch (k.kind) {
              case _.SyntaxKind.FunctionExpression:
              case _.SyntaxKind.ArrowFunction:
              case _.SyntaxKind.Constructor:
              case _.SyntaxKind.ModuleDeclaration:
              case _.SyntaxKind.ClassDeclaration:
              case _.SyntaxKind.ClassExpression:
              case _.SyntaxKind.EnumDeclaration:
              case _.SyntaxKind.MethodDeclaration:
              case _.SyntaxKind.FunctionDeclaration:
              case _.SyntaxKind.GetAccessor:
              case _.SyntaxKind.SetAccessor:
              case _.SyntaxKind.MethodSignature:
              case _.SyntaxKind.CallSignature:
              case _.SyntaxKind.ConstructSignature:
              case _.SyntaxKind.ConstructorType:
              case _.SyntaxKind.FunctionType:
                return 1;
              case _.SyntaxKind.SourceFile:
                return _.isExternalModule(k) ? 1 : 0;
              default:
                return 0;
            }
          }
          a.isFunctionScopeBoundary = ze;
          function ve(k) {
            switch (k.kind) {
              case _.SyntaxKind.Block:
                let ue = k.parent;
                return ue.kind !== _.SyntaxKind.CatchClause && (ue.kind === _.SyntaxKind.SourceFile || !ze(ue)) ? 2 : 0;
              case _.SyntaxKind.ForStatement:
              case _.SyntaxKind.ForInStatement:
              case _.SyntaxKind.ForOfStatement:
              case _.SyntaxKind.CaseBlock:
              case _.SyntaxKind.CatchClause:
              case _.SyntaxKind.WithStatement:
                return 2;
              default:
                return 0;
            }
          }
          a.isBlockScopeBoundary = ve;
          function er(k) {
            switch (k.kind) {
              case _.SyntaxKind.ClassDeclaration:
              case _.SyntaxKind.ClassExpression:
              case _.SyntaxKind.FunctionExpression:
                return true;
              case _.SyntaxKind.FunctionDeclaration:
                return k.body !== void 0;
              case _.SyntaxKind.MethodDeclaration:
              case _.SyntaxKind.GetAccessor:
              case _.SyntaxKind.SetAccessor:
                return k.parent.kind === _.SyntaxKind.ObjectLiteralExpression;
              default:
                return false;
            }
          }
          a.hasOwnThisReference = er;
          function ar(k) {
            switch (k.kind) {
              case _.SyntaxKind.GetAccessor:
              case _.SyntaxKind.SetAccessor:
              case _.SyntaxKind.FunctionDeclaration:
              case _.SyntaxKind.MethodDeclaration:
              case _.SyntaxKind.Constructor:
                return k.body !== void 0;
              case _.SyntaxKind.FunctionExpression:
              case _.SyntaxKind.ArrowFunction:
                return true;
              default:
                return false;
            }
          }
          a.isFunctionWithBody = ar;
          function Cr(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : k.getSourceFile(), Sr = [];
            for (; ; ) {
              if (I(k.kind))
                ue(k);
              else if (k.kind !== _.SyntaxKind.JSDocComment) {
                let Kr = k.getChildren(Qe);
                if (Kr.length === 1) {
                  k = Kr[0];
                  continue;
                }
                for (let Hr = Kr.length - 1; Hr >= 0; --Hr)
                  Sr.push(Kr[Hr]);
              }
              if (Sr.length === 0)
                break;
              k = Sr.pop();
            }
          }
          a.forEachToken = Cr;
          function Ce(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : k.getSourceFile(), Sr = Qe.text, Kr = _.createScanner(Qe.languageVersion, false, Qe.languageVariant, Sr);
            return Cr(k, (Hr) => {
              let Dt = Hr.kind === _.SyntaxKind.JsxText || Hr.pos === Hr.end ? Hr.pos : Hr.getStart(Qe);
              if (Dt !== Hr.pos) {
                Kr.setTextPos(Hr.pos);
                let Xt = Kr.scan(), cn = Kr.getTokenPos();
                for (; cn < Dt; ) {
                  let In = Kr.getTextPos();
                  if (ue(Sr, Xt, { pos: cn, end: In }, Hr.parent), In === Dt)
                    break;
                  Xt = Kr.scan(), cn = Kr.getTokenPos();
                }
              }
              return ue(Sr, Hr.kind, { end: Hr.end, pos: Dt }, Hr.parent);
            }, Qe);
          }
          a.forEachTokenWithTrivia = Ce;
          function $e(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : k.getSourceFile(), Sr = Qe.text, Kr = Qe.languageVariant !== _.LanguageVariant.JSX;
            return Cr(k, (Dt) => {
              if (Dt.pos !== Dt.end && (Dt.kind !== _.SyntaxKind.JsxText && _.forEachLeadingCommentRange(Sr, Dt.pos === 0 ? (_.getShebang(Sr) || "").length : Dt.pos, Hr), Kr || gr(Dt)))
                return _.forEachTrailingCommentRange(Sr, Dt.end, Hr);
            }, Qe);
            function Hr(Dt, Xt, cn) {
              ue(Sr, { pos: Dt, end: Xt, kind: cn });
            }
          }
          a.forEachComment = $e;
          function gr(k) {
            switch (k.kind) {
              case _.SyntaxKind.CloseBraceToken:
                return k.parent.kind !== _.SyntaxKind.JsxExpression || !X(k.parent.parent);
              case _.SyntaxKind.GreaterThanToken:
                switch (k.parent.kind) {
                  case _.SyntaxKind.JsxOpeningElement:
                    return k.end !== k.parent.end;
                  case _.SyntaxKind.JsxOpeningFragment:
                    return false;
                  case _.SyntaxKind.JsxSelfClosingElement:
                    return k.end !== k.parent.end || !X(k.parent.parent);
                  case _.SyntaxKind.JsxClosingElement:
                  case _.SyntaxKind.JsxClosingFragment:
                    return !X(k.parent.parent.parent);
                }
            }
            return true;
          }
          function X(k) {
            return k.kind === _.SyntaxKind.JsxElement || k.kind === _.SyntaxKind.JsxFragment;
          }
          function Te(k) {
            let ue = k.getLineStarts(), Qe = [], Sr = ue.length, Kr = k.text, Hr = 0;
            for (let Dt = 1; Dt < Sr; ++Dt) {
              let Xt = ue[Dt], cn = Xt;
              for (; cn > Hr && _.isLineBreak(Kr.charCodeAt(cn - 1)); --cn)
                ;
              Qe.push({ pos: Hr, end: Xt, contentLength: cn - Hr }), Hr = Xt;
            }
            return Qe.push({ pos: Hr, end: k.end, contentLength: k.end - Hr }), Qe;
          }
          a.getLineRanges = Te;
          function we(k) {
            let ue = k.getLineStarts();
            return ue.length === 1 || ue[1] < 2 || k.text[ue[1] - 2] !== "\r" ? `
` : `\r
`;
          }
          a.getLineBreakStyle = we;
          var he;
          function yr(k, ue) {
            return he === void 0 ? he = _.createScanner(ue, false, void 0, k) : (he.setScriptTarget(ue), he.setText(k)), he.scan(), he;
          }
          function kr(k) {
            let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : _.ScriptTarget.Latest, Qe = yr(k, ue);
            return Qe.isIdentifier() && Qe.getTextPos() === k.length && Qe.getTokenPos() === 0;
          }
          a.isValidIdentifier = kr;
          function nr(k) {
            return k >= 65536 ? 2 : 1;
          }
          function tr(k) {
            let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : _.ScriptTarget.Latest;
            if (k.length === 0)
              return false;
            let Qe = k.codePointAt(0);
            if (!_.isIdentifierStart(Qe, ue))
              return false;
            for (let Sr = nr(Qe); Sr < k.length; Sr += nr(Qe))
              if (Qe = k.codePointAt(Sr), !_.isIdentifierPart(Qe, ue))
                return false;
            return true;
          }
          a.isValidPropertyAccess = tr;
          function Lr(k) {
            let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : _.ScriptTarget.Latest;
            if (tr(k, ue))
              return true;
            let Qe = yr(k, ue);
            return Qe.getTextPos() === k.length && Qe.getToken() === _.SyntaxKind.NumericLiteral && Qe.getTokenValue() === k;
          }
          a.isValidPropertyName = Lr;
          function zr(k) {
            let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : _.ScriptTarget.Latest, Qe = yr(k, ue);
            return Qe.getToken() === _.SyntaxKind.NumericLiteral && Qe.getTextPos() === k.length && Qe.getTokenPos() === 0;
          }
          a.isValidNumericLiteral = zr;
          function ye(k) {
            let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : _.ScriptTarget.Latest;
            if (k.length === 0)
              return false;
            let Qe = false, Sr = k.codePointAt(0);
            if (!_.isIdentifierStart(Sr, ue))
              return false;
            for (let Kr = nr(Sr); Kr < k.length; Kr += nr(Sr))
              if (Sr = k.codePointAt(Kr), !_.isIdentifierPart(Sr, ue) && Sr !== 45)
                if (!Qe && Sr === 58 && Kr + nr(Sr) !== k.length)
                  Qe = true;
                else
                  return false;
            return true;
          }
          a.isValidJsxIdentifier = ye;
          function ir(k) {
            return String(+k) === k;
          }
          a.isNumericPropertyName = ir;
          function Dr(k, ue, Qe) {
            return _.getLineAndCharacterOfPosition(k, ue).line === _.getLineAndCharacterOfPosition(k, Qe).line;
          }
          a.isSameLine = Dr;
          var Pr;
          (function(k) {
            k[k.None = 0] = "None", k[k.TaggedTemplate = 1] = "TaggedTemplate", k[k.Constructor = 2] = "Constructor", k[k.JsxElement = 4] = "JsxElement";
          })(Pr = a.SideEffectOptions || (a.SideEffectOptions = {}));
          function Br(k, ue) {
            var Qe, Sr;
            let Kr = [];
            for (; ; ) {
              switch (k.kind) {
                case _.SyntaxKind.CallExpression:
                case _.SyntaxKind.PostfixUnaryExpression:
                case _.SyntaxKind.AwaitExpression:
                case _.SyntaxKind.YieldExpression:
                case _.SyntaxKind.DeleteExpression:
                  return true;
                case _.SyntaxKind.TypeAssertionExpression:
                case _.SyntaxKind.AsExpression:
                case _.SyntaxKind.ParenthesizedExpression:
                case _.SyntaxKind.NonNullExpression:
                case _.SyntaxKind.VoidExpression:
                case _.SyntaxKind.TypeOfExpression:
                case _.SyntaxKind.PropertyAccessExpression:
                case _.SyntaxKind.SpreadElement:
                case _.SyntaxKind.PartiallyEmittedExpression:
                  k = k.expression;
                  continue;
                case _.SyntaxKind.BinaryExpression:
                  if (N(k.operatorToken.kind))
                    return true;
                  Kr.push(k.right), k = k.left;
                  continue;
                case _.SyntaxKind.PrefixUnaryExpression:
                  switch (k.operator) {
                    case _.SyntaxKind.PlusPlusToken:
                    case _.SyntaxKind.MinusMinusToken:
                      return true;
                    default:
                      k = k.operand;
                      continue;
                  }
                case _.SyntaxKind.ElementAccessExpression:
                  k.argumentExpression !== void 0 && Kr.push(k.argumentExpression), k = k.expression;
                  continue;
                case _.SyntaxKind.ConditionalExpression:
                  Kr.push(k.whenTrue, k.whenFalse), k = k.condition;
                  continue;
                case _.SyntaxKind.NewExpression:
                  if (ue & 2)
                    return true;
                  k.arguments !== void 0 && Kr.push(...k.arguments), k = k.expression;
                  continue;
                case _.SyntaxKind.TaggedTemplateExpression:
                  if (ue & 1)
                    return true;
                  if (Kr.push(k.tag), k = k.template, k.kind === _.SyntaxKind.NoSubstitutionTemplateLiteral)
                    break;
                case _.SyntaxKind.TemplateExpression:
                  for (let Hr of k.templateSpans)
                    Kr.push(Hr.expression);
                  break;
                case _.SyntaxKind.ClassExpression: {
                  if (k.decorators !== void 0)
                    return true;
                  for (let Dt of k.members) {
                    if (Dt.decorators !== void 0)
                      return true;
                    if (!F(Dt.modifiers, _.SyntaxKind.DeclareKeyword))
                      if (((Qe = Dt.name) === null || Qe === void 0 ? void 0 : Qe.kind) === _.SyntaxKind.ComputedPropertyName && Kr.push(Dt.name.expression), D.isMethodDeclaration(Dt)) {
                        for (let Xt of Dt.parameters)
                          if (Xt.decorators !== void 0)
                            return true;
                      } else
                        D.isPropertyDeclaration(Dt) && Dt.initializer !== void 0 && F(Dt.modifiers, _.SyntaxKind.StaticKeyword) && Kr.push(Dt.initializer);
                  }
                  let Hr = at(k);
                  if (Hr === void 0)
                    break;
                  k = Hr.expression;
                  continue;
                }
                case _.SyntaxKind.ArrayLiteralExpression:
                  Kr.push(...k.elements);
                  break;
                case _.SyntaxKind.ObjectLiteralExpression:
                  for (let Hr of k.properties)
                    switch (((Sr = Hr.name) === null || Sr === void 0 ? void 0 : Sr.kind) === _.SyntaxKind.ComputedPropertyName && Kr.push(Hr.name.expression), Hr.kind) {
                      case _.SyntaxKind.PropertyAssignment:
                        Kr.push(Hr.initializer);
                        break;
                      case _.SyntaxKind.SpreadAssignment:
                        Kr.push(Hr.expression);
                    }
                  break;
                case _.SyntaxKind.JsxExpression:
                  if (k.expression === void 0)
                    break;
                  k = k.expression;
                  continue;
                case _.SyntaxKind.JsxElement:
                case _.SyntaxKind.JsxFragment:
                  for (let Hr of k.children)
                    Hr.kind !== _.SyntaxKind.JsxText && Kr.push(Hr);
                  if (k.kind === _.SyntaxKind.JsxFragment)
                    break;
                  k = k.openingElement;
                case _.SyntaxKind.JsxSelfClosingElement:
                case _.SyntaxKind.JsxOpeningElement:
                  if (ue & 4)
                    return true;
                  for (let Hr of k.attributes.properties)
                    Hr.kind === _.SyntaxKind.JsxSpreadAttribute ? Kr.push(Hr.expression) : Hr.initializer !== void 0 && Kr.push(Hr.initializer);
                  break;
                case _.SyntaxKind.CommaListExpression:
                  Kr.push(...k.elements);
              }
              if (Kr.length === 0)
                return false;
              k = Kr.pop();
            }
          }
          a.hasSideEffects = Br;
          function ut(k) {
            let ue = k.parent.parent;
            for (; ue.kind === _.SyntaxKind.BindingElement; )
              ue = ue.parent.parent;
            return ue;
          }
          a.getDeclarationOfBindingElement = ut;
          function rt(k) {
            for (; ; ) {
              let ue = k.parent;
              switch (ue.kind) {
                case _.SyntaxKind.CallExpression:
                case _.SyntaxKind.NewExpression:
                case _.SyntaxKind.ElementAccessExpression:
                case _.SyntaxKind.WhileStatement:
                case _.SyntaxKind.DoStatement:
                case _.SyntaxKind.WithStatement:
                case _.SyntaxKind.ThrowStatement:
                case _.SyntaxKind.ReturnStatement:
                case _.SyntaxKind.JsxExpression:
                case _.SyntaxKind.JsxSpreadAttribute:
                case _.SyntaxKind.JsxElement:
                case _.SyntaxKind.JsxFragment:
                case _.SyntaxKind.JsxSelfClosingElement:
                case _.SyntaxKind.ComputedPropertyName:
                case _.SyntaxKind.ArrowFunction:
                case _.SyntaxKind.ExportSpecifier:
                case _.SyntaxKind.ExportAssignment:
                case _.SyntaxKind.ImportDeclaration:
                case _.SyntaxKind.ExternalModuleReference:
                case _.SyntaxKind.Decorator:
                case _.SyntaxKind.TaggedTemplateExpression:
                case _.SyntaxKind.TemplateSpan:
                case _.SyntaxKind.ExpressionWithTypeArguments:
                case _.SyntaxKind.TypeOfExpression:
                case _.SyntaxKind.AwaitExpression:
                case _.SyntaxKind.YieldExpression:
                case _.SyntaxKind.LiteralType:
                case _.SyntaxKind.JsxAttributes:
                case _.SyntaxKind.JsxOpeningElement:
                case _.SyntaxKind.JsxClosingElement:
                case _.SyntaxKind.IfStatement:
                case _.SyntaxKind.CaseClause:
                case _.SyntaxKind.SwitchStatement:
                  return true;
                case _.SyntaxKind.PropertyAccessExpression:
                  return ue.expression === k;
                case _.SyntaxKind.QualifiedName:
                  return ue.left === k;
                case _.SyntaxKind.ShorthandPropertyAssignment:
                  return ue.objectAssignmentInitializer === k || !Z(ue);
                case _.SyntaxKind.PropertyAssignment:
                  return ue.initializer === k && !Z(ue);
                case _.SyntaxKind.SpreadAssignment:
                case _.SyntaxKind.SpreadElement:
                case _.SyntaxKind.ArrayLiteralExpression:
                  return !Z(ue);
                case _.SyntaxKind.ParenthesizedExpression:
                case _.SyntaxKind.AsExpression:
                case _.SyntaxKind.TypeAssertionExpression:
                case _.SyntaxKind.PostfixUnaryExpression:
                case _.SyntaxKind.PrefixUnaryExpression:
                case _.SyntaxKind.NonNullExpression:
                  k = ue;
                  continue;
                case _.SyntaxKind.ForStatement:
                  return ue.condition === k;
                case _.SyntaxKind.ForInStatement:
                case _.SyntaxKind.ForOfStatement:
                  return ue.expression === k;
                case _.SyntaxKind.ConditionalExpression:
                  if (ue.condition === k)
                    return true;
                  k = ue;
                  break;
                case _.SyntaxKind.PropertyDeclaration:
                case _.SyntaxKind.BindingElement:
                case _.SyntaxKind.VariableDeclaration:
                case _.SyntaxKind.Parameter:
                case _.SyntaxKind.EnumMember:
                  return ue.initializer === k;
                case _.SyntaxKind.ImportEqualsDeclaration:
                  return ue.moduleReference === k;
                case _.SyntaxKind.CommaListExpression:
                  if (ue.elements[ue.elements.length - 1] !== k)
                    return false;
                  k = ue;
                  break;
                case _.SyntaxKind.BinaryExpression:
                  if (ue.right === k) {
                    if (ue.operatorToken.kind === _.SyntaxKind.CommaToken) {
                      k = ue;
                      break;
                    }
                    return true;
                  }
                  switch (ue.operatorToken.kind) {
                    case _.SyntaxKind.CommaToken:
                    case _.SyntaxKind.EqualsToken:
                      return false;
                    case _.SyntaxKind.EqualsEqualsEqualsToken:
                    case _.SyntaxKind.EqualsEqualsToken:
                    case _.SyntaxKind.ExclamationEqualsEqualsToken:
                    case _.SyntaxKind.ExclamationEqualsToken:
                    case _.SyntaxKind.InstanceOfKeyword:
                    case _.SyntaxKind.PlusToken:
                    case _.SyntaxKind.MinusToken:
                    case _.SyntaxKind.AsteriskToken:
                    case _.SyntaxKind.SlashToken:
                    case _.SyntaxKind.PercentToken:
                    case _.SyntaxKind.AsteriskAsteriskToken:
                    case _.SyntaxKind.GreaterThanToken:
                    case _.SyntaxKind.GreaterThanGreaterThanToken:
                    case _.SyntaxKind.GreaterThanGreaterThanGreaterThanToken:
                    case _.SyntaxKind.GreaterThanEqualsToken:
                    case _.SyntaxKind.LessThanToken:
                    case _.SyntaxKind.LessThanLessThanToken:
                    case _.SyntaxKind.LessThanEqualsToken:
                    case _.SyntaxKind.AmpersandToken:
                    case _.SyntaxKind.BarToken:
                    case _.SyntaxKind.CaretToken:
                    case _.SyntaxKind.BarBarToken:
                    case _.SyntaxKind.AmpersandAmpersandToken:
                    case _.SyntaxKind.QuestionQuestionToken:
                    case _.SyntaxKind.InKeyword:
                    case _.SyntaxKind.QuestionQuestionEqualsToken:
                    case _.SyntaxKind.AmpersandAmpersandEqualsToken:
                    case _.SyntaxKind.BarBarEqualsToken:
                      return true;
                    default:
                      k = ue;
                  }
                  break;
                default:
                  return false;
              }
            }
          }
          a.isExpressionValueUsed = rt;
          function Z(k) {
            switch (k.kind) {
              case _.SyntaxKind.ShorthandPropertyAssignment:
                if (k.objectAssignmentInitializer !== void 0)
                  return true;
              case _.SyntaxKind.PropertyAssignment:
              case _.SyntaxKind.SpreadAssignment:
                k = k.parent;
                break;
              case _.SyntaxKind.SpreadElement:
                if (k.parent.kind !== _.SyntaxKind.ArrayLiteralExpression)
                  return false;
                k = k.parent;
            }
            for (; ; )
              switch (k.parent.kind) {
                case _.SyntaxKind.BinaryExpression:
                  return k.parent.left === k && k.parent.operatorToken.kind === _.SyntaxKind.EqualsToken;
                case _.SyntaxKind.ForOfStatement:
                  return k.parent.initializer === k;
                case _.SyntaxKind.ArrayLiteralExpression:
                case _.SyntaxKind.ObjectLiteralExpression:
                  k = k.parent;
                  break;
                case _.SyntaxKind.SpreadAssignment:
                case _.SyntaxKind.PropertyAssignment:
                  k = k.parent.parent;
                  break;
                case _.SyntaxKind.SpreadElement:
                  if (k.parent.parent.kind !== _.SyntaxKind.ArrayLiteralExpression)
                    return false;
                  k = k.parent.parent;
                  break;
                default:
                  return false;
              }
          }
          var f;
          (function(k) {
            k[k.None = 0] = "None", k[k.Read = 1] = "Read", k[k.Write = 2] = "Write", k[k.Delete = 4] = "Delete", k[k.ReadWrite = 3] = "ReadWrite", k[k.Modification = 6] = "Modification";
          })(f = a.AccessKind || (a.AccessKind = {}));
          function h(k) {
            let ue = k.parent;
            switch (ue.kind) {
              case _.SyntaxKind.DeleteExpression:
                return 4;
              case _.SyntaxKind.PostfixUnaryExpression:
                return 3;
              case _.SyntaxKind.PrefixUnaryExpression:
                return ue.operator === _.SyntaxKind.PlusPlusToken || ue.operator === _.SyntaxKind.MinusMinusToken ? 3 : 1;
              case _.SyntaxKind.BinaryExpression:
                return ue.right === k ? 1 : N(ue.operatorToken.kind) ? ue.operatorToken.kind === _.SyntaxKind.EqualsToken ? 2 : 3 : 1;
              case _.SyntaxKind.ShorthandPropertyAssignment:
                return ue.objectAssignmentInitializer === k ? 1 : Z(ue) ? 2 : 1;
              case _.SyntaxKind.PropertyAssignment:
                return ue.name === k ? 0 : Z(ue) ? 2 : 1;
              case _.SyntaxKind.ArrayLiteralExpression:
              case _.SyntaxKind.SpreadElement:
              case _.SyntaxKind.SpreadAssignment:
                return Z(ue) ? 2 : 1;
              case _.SyntaxKind.ParenthesizedExpression:
              case _.SyntaxKind.NonNullExpression:
              case _.SyntaxKind.TypeAssertionExpression:
              case _.SyntaxKind.AsExpression:
                return h(ue);
              case _.SyntaxKind.ForOfStatement:
              case _.SyntaxKind.ForInStatement:
                return ue.initializer === k ? 2 : 1;
              case _.SyntaxKind.ExpressionWithTypeArguments:
                return ue.parent.token === _.SyntaxKind.ExtendsKeyword && ue.parent.parent.kind !== _.SyntaxKind.InterfaceDeclaration ? 1 : 0;
              case _.SyntaxKind.ComputedPropertyName:
              case _.SyntaxKind.ExpressionStatement:
              case _.SyntaxKind.TypeOfExpression:
              case _.SyntaxKind.ElementAccessExpression:
              case _.SyntaxKind.ForStatement:
              case _.SyntaxKind.IfStatement:
              case _.SyntaxKind.DoStatement:
              case _.SyntaxKind.WhileStatement:
              case _.SyntaxKind.SwitchStatement:
              case _.SyntaxKind.WithStatement:
              case _.SyntaxKind.ThrowStatement:
              case _.SyntaxKind.CallExpression:
              case _.SyntaxKind.NewExpression:
              case _.SyntaxKind.TaggedTemplateExpression:
              case _.SyntaxKind.JsxExpression:
              case _.SyntaxKind.Decorator:
              case _.SyntaxKind.TemplateSpan:
              case _.SyntaxKind.JsxOpeningElement:
              case _.SyntaxKind.JsxSelfClosingElement:
              case _.SyntaxKind.JsxSpreadAttribute:
              case _.SyntaxKind.VoidExpression:
              case _.SyntaxKind.ReturnStatement:
              case _.SyntaxKind.AwaitExpression:
              case _.SyntaxKind.YieldExpression:
              case _.SyntaxKind.ConditionalExpression:
              case _.SyntaxKind.CaseClause:
              case _.SyntaxKind.JsxElement:
                return 1;
              case _.SyntaxKind.ArrowFunction:
                return ue.body === k ? 1 : 2;
              case _.SyntaxKind.PropertyDeclaration:
              case _.SyntaxKind.VariableDeclaration:
              case _.SyntaxKind.Parameter:
              case _.SyntaxKind.EnumMember:
              case _.SyntaxKind.BindingElement:
              case _.SyntaxKind.JsxAttribute:
                return ue.initializer === k ? 1 : 0;
              case _.SyntaxKind.PropertyAccessExpression:
                return ue.expression === k ? 1 : 0;
              case _.SyntaxKind.ExportAssignment:
                return ue.isExportEquals ? 1 : 0;
            }
            return 0;
          }
          a.getAccessKind = h;
          function oe(k) {
            return (h(k) & 2) !== 0;
          }
          a.isReassignmentTarget = oe;
          function xr(k) {
            switch (k.kind) {
              case _.SyntaxKind.Parameter:
              case _.SyntaxKind.CallSignature:
              case _.SyntaxKind.ConstructSignature:
              case _.SyntaxKind.MethodSignature:
              case _.SyntaxKind.PropertySignature:
              case _.SyntaxKind.ArrowFunction:
              case _.SyntaxKind.ParenthesizedExpression:
              case _.SyntaxKind.SpreadAssignment:
              case _.SyntaxKind.ShorthandPropertyAssignment:
              case _.SyntaxKind.PropertyAssignment:
              case _.SyntaxKind.FunctionExpression:
              case _.SyntaxKind.LabeledStatement:
              case _.SyntaxKind.ExpressionStatement:
              case _.SyntaxKind.VariableStatement:
              case _.SyntaxKind.FunctionDeclaration:
              case _.SyntaxKind.Constructor:
              case _.SyntaxKind.MethodDeclaration:
              case _.SyntaxKind.PropertyDeclaration:
              case _.SyntaxKind.GetAccessor:
              case _.SyntaxKind.SetAccessor:
              case _.SyntaxKind.ClassDeclaration:
              case _.SyntaxKind.ClassExpression:
              case _.SyntaxKind.InterfaceDeclaration:
              case _.SyntaxKind.TypeAliasDeclaration:
              case _.SyntaxKind.EnumMember:
              case _.SyntaxKind.EnumDeclaration:
              case _.SyntaxKind.ModuleDeclaration:
              case _.SyntaxKind.ImportEqualsDeclaration:
              case _.SyntaxKind.ImportDeclaration:
              case _.SyntaxKind.NamespaceExportDeclaration:
              case _.SyntaxKind.ExportAssignment:
              case _.SyntaxKind.IndexSignature:
              case _.SyntaxKind.FunctionType:
              case _.SyntaxKind.ConstructorType:
              case _.SyntaxKind.JSDocFunctionType:
              case _.SyntaxKind.ExportDeclaration:
              case _.SyntaxKind.NamedTupleMember:
              case _.SyntaxKind.EndOfFileToken:
                return true;
              default:
                return false;
            }
          }
          a.canHaveJsDoc = xr;
          function jr(k, ue) {
            let Qe = [];
            for (let Sr of k.getChildren(ue)) {
              if (!D.isJsDoc(Sr))
                break;
              Qe.push(Sr);
            }
            return Qe;
          }
          a.getJsDoc = jr;
          function qr(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : k.getSourceFile();
            if (xr(k) && k.kind !== _.SyntaxKind.EndOfFileToken) {
              let Sr = jr(k, Qe);
              if (Sr.length !== 0 || !ue)
                return Sr;
            }
            return pt(k, k.getStart(Qe), Qe, ue);
          }
          a.parseJsDocOfNode = qr;
          function pt(k, ue, Qe, Sr) {
            let Kr = _[Sr && Dr(Qe, k.pos, ue) ? "forEachTrailingCommentRange" : "forEachLeadingCommentRange"](Qe.text, k.pos, (yn, hn, ln) => ln === _.SyntaxKind.MultiLineCommentTrivia && Qe.text[yn + 2] === "*" ? { pos: yn } : void 0);
            if (Kr === void 0)
              return [];
            let Hr = Kr.pos, Dt = Qe.text.slice(Hr, ue), Xt = _.createSourceFile("jsdoc.ts", `${Dt}var a;`, Qe.languageVersion), cn = jr(Xt.statements[0], Xt);
            for (let yn of cn)
              In(yn, k);
            return cn;
            function In(yn, hn) {
              return yn.pos += Hr, yn.end += Hr, yn.parent = hn, _.forEachChild(yn, (ln) => In(ln, yn), (ln) => {
                ln.pos += Hr, ln.end += Hr;
                for (let En of ln)
                  In(En, yn);
              });
            }
          }
          var Ge;
          (function(k) {
            k[k.ImportDeclaration = 1] = "ImportDeclaration", k[k.ImportEquals = 2] = "ImportEquals", k[k.ExportFrom = 4] = "ExportFrom", k[k.DynamicImport = 8] = "DynamicImport", k[k.Require = 16] = "Require", k[k.ImportType = 32] = "ImportType", k[k.All = 63] = "All", k[k.AllImports = 59] = "AllImports", k[k.AllStaticImports = 3] = "AllStaticImports", k[k.AllImportExpressions = 24] = "AllImportExpressions", k[k.AllRequireLike = 18] = "AllRequireLike", k[k.AllNestedImports = 56] = "AllNestedImports", k[k.AllTopLevelImports = 7] = "AllTopLevelImports";
          })(Ge = a.ImportKind || (a.ImportKind = {}));
          function K(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true, Sr = [];
            for (let Hr of r(k, ue, Qe))
              switch (Hr.kind) {
                case _.SyntaxKind.ImportDeclaration:
                  Kr(Hr.moduleSpecifier);
                  break;
                case _.SyntaxKind.ImportEqualsDeclaration:
                  Kr(Hr.moduleReference.expression);
                  break;
                case _.SyntaxKind.ExportDeclaration:
                  Kr(Hr.moduleSpecifier);
                  break;
                case _.SyntaxKind.CallExpression:
                  Kr(Hr.arguments[0]);
                  break;
                case _.SyntaxKind.ImportType:
                  D.isLiteralTypeNode(Hr.argument) && Kr(Hr.argument.literal);
                  break;
                default:
                  throw new Error("unexpected node");
              }
            return Sr;
            function Kr(Hr) {
              D.isTextualLiteral(Hr) && Sr.push(Hr);
            }
          }
          a.findImports = K;
          function r(k, ue) {
            let Qe = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true;
            return new ct(k, ue, Qe).find();
          }
          a.findImportLikeNodes = r;
          var ct = class {
            constructor(k, ue, Qe) {
              this._sourceFile = k, this._options = ue, this._ignoreFileName = Qe, this._result = [];
            }
            find() {
              return this._sourceFile.isDeclarationFile && (this._options &= -25), this._options & 7 && this._findImports(this._sourceFile.statements), this._options & 56 && this._findNestedImports(), this._result;
            }
            _findImports(k) {
              for (let ue of k)
                D.isImportDeclaration(ue) ? this._options & 1 && this._result.push(ue) : D.isImportEqualsDeclaration(ue) ? this._options & 2 && ue.moduleReference.kind === _.SyntaxKind.ExternalModuleReference && this._result.push(ue) : D.isExportDeclaration(ue) ? ue.moduleSpecifier !== void 0 && this._options & 4 && this._result.push(ue) : D.isModuleDeclaration(ue) && this._findImportsInModule(ue);
            }
            _findImportsInModule(k) {
              if (k.body !== void 0) {
                if (k.body.kind === _.SyntaxKind.ModuleDeclaration)
                  return this._findImportsInModule(k.body);
                this._findImports(k.body.statements);
              }
            }
            _findNestedImports() {
              let k = this._ignoreFileName || (this._sourceFile.flags & _.NodeFlags.JavaScriptFile) !== 0, ue, Qe;
              if ((this._options & 56) === 16) {
                if (!k)
                  return;
                ue = /\brequire\s*[</(]/g, Qe = false;
              } else
                this._options & 16 && k ? (ue = /\b(?:import|require)\s*[</(]/g, Qe = (this._options & 32) !== 0) : (ue = /\bimport\s*[</(]/g, Qe = k && (this._options & 32) !== 0);
              for (let Sr = ue.exec(this._sourceFile.text); Sr !== null; Sr = ue.exec(this._sourceFile.text)) {
                let Kr = B(this._sourceFile, Sr.index, this._sourceFile, Sr[0][0] === "i" && Qe);
                if (Kr.kind === _.SyntaxKind.ImportKeyword) {
                  if (Kr.end - 6 !== Sr.index)
                    continue;
                  switch (Kr.parent.kind) {
                    case _.SyntaxKind.ImportType:
                      this._result.push(Kr.parent);
                      break;
                    case _.SyntaxKind.CallExpression:
                      Kr.parent.arguments.length > 1 && this._result.push(Kr.parent);
                  }
                } else
                  Kr.kind === _.SyntaxKind.Identifier && Kr.end - 7 === Sr.index && Kr.parent.kind === _.SyntaxKind.CallExpression && Kr.parent.expression === Kr && Kr.parent.arguments.length === 1 && this._result.push(Kr.parent);
              }
            }
          };
          function ft(k) {
            for (; k.flags & _.NodeFlags.NestedNamespace; )
              k = k.parent;
            return F(k.modifiers, _.SyntaxKind.DeclareKeyword) || Ie(k.parent);
          }
          a.isStatementInAmbientContext = ft;
          function Ie(k) {
            for (; k.kind === _.SyntaxKind.ModuleBlock; ) {
              do
                k = k.parent;
              while (k.flags & _.NodeFlags.NestedNamespace);
              if (F(k.modifiers, _.SyntaxKind.DeclareKeyword))
                return true;
              k = k.parent;
            }
            return false;
          }
          a.isAmbientModuleBlock = Ie;
          function me(k) {
            let ue = k.parent;
            for (; ue.kind === _.SyntaxKind.ParenthesizedExpression; )
              ue = ue.parent;
            return D.isCallExpression(ue) && k.end <= ue.expression.end ? ue : void 0;
          }
          a.getIIFE = me;
          function xe(k, ue) {
            return (k.strict ? k[ue] !== false : k[ue] === true) && (ue !== "strictPropertyInitialization" || xe(k, "strictNullChecks"));
          }
          a.isStrictCompilerOptionEnabled = xe;
          function Ye(k, ue) {
            switch (ue) {
              case "stripInternal":
              case "declarationMap":
              case "emitDeclarationOnly":
                return k[ue] === true && Ye(k, "declaration");
              case "declaration":
                return k.declaration || Ye(k, "composite");
              case "incremental":
                return k.incremental === void 0 ? Ye(k, "composite") : k.incremental;
              case "skipDefaultLibCheck":
                return k.skipDefaultLibCheck || Ye(k, "skipLibCheck");
              case "suppressImplicitAnyIndexErrors":
                return k.suppressImplicitAnyIndexErrors === true && Ye(k, "noImplicitAny");
              case "allowSyntheticDefaultImports":
                return k.allowSyntheticDefaultImports !== void 0 ? k.allowSyntheticDefaultImports : Ye(k, "esModuleInterop") || k.module === _.ModuleKind.System;
              case "noUncheckedIndexedAccess":
                return k.noUncheckedIndexedAccess === true && Ye(k, "strictNullChecks");
              case "allowJs":
                return k.allowJs === void 0 ? Ye(k, "checkJs") : k.allowJs;
              case "noImplicitAny":
              case "noImplicitThis":
              case "strictNullChecks":
              case "strictFunctionTypes":
              case "strictPropertyInitialization":
              case "alwaysStrict":
              case "strictBindCallApply":
                return xe(k, ue);
            }
            return k[ue] === true;
          }
          a.isCompilerOptionEnabled = Ye;
          function vr(k) {
            return k.name.kind === _.SyntaxKind.StringLiteral || (k.flags & _.NodeFlags.GlobalAugmentation) !== 0;
          }
          a.isAmbientModule = vr;
          function nt(k) {
            return pr(k);
          }
          a.getCheckJsDirective = nt;
          function pr(k) {
            let ue;
            return _.forEachLeadingCommentRange(k, (_.getShebang(k) || "").length, (Qe, Sr, Kr) => {
              if (Kr === _.SyntaxKind.SingleLineCommentTrivia) {
                let Hr = k.slice(Qe, Sr), Dt = /^\/{2,3}\s*@ts-(no)?check(?:\s|$)/i.exec(Hr);
                Dt !== null && (ue = { pos: Qe, end: Sr, enabled: Dt[1] === void 0 });
              }
            }), ue;
          }
          a.getTsCheckDirective = pr;
          function Mr(k) {
            return D.isTypeReferenceNode(k.type) && k.type.typeName.kind === _.SyntaxKind.Identifier && k.type.typeName.escapedText === "const";
          }
          a.isConstAssertion = Mr;
          function ot(k) {
            let ue = k;
            for (; ; ) {
              let Qe = ue.parent;
              e:
                switch (Qe.kind) {
                  case _.SyntaxKind.TypeAssertionExpression:
                  case _.SyntaxKind.AsExpression:
                    return Mr(Qe);
                  case _.SyntaxKind.PrefixUnaryExpression:
                    if (ue.kind !== _.SyntaxKind.NumericLiteral)
                      return false;
                    switch (Qe.operator) {
                      case _.SyntaxKind.PlusToken:
                      case _.SyntaxKind.MinusToken:
                        ue = Qe;
                        break e;
                      default:
                        return false;
                    }
                  case _.SyntaxKind.PropertyAssignment:
                    if (Qe.initializer !== ue)
                      return false;
                    ue = Qe.parent;
                    break;
                  case _.SyntaxKind.ShorthandPropertyAssignment:
                    ue = Qe.parent;
                    break;
                  case _.SyntaxKind.ParenthesizedExpression:
                  case _.SyntaxKind.ArrayLiteralExpression:
                  case _.SyntaxKind.ObjectLiteralExpression:
                  case _.SyntaxKind.TemplateExpression:
                    ue = Qe;
                    break;
                  default:
                    return false;
                }
            }
          }
          a.isInConstContext = ot;
          function At(k, ue) {
            if (!re(k))
              return false;
            let Qe = ue.getTypeAtLocation(k.arguments[2]);
            if (Qe.getProperty("value") === void 0)
              return Qe.getProperty("set") === void 0;
            let Sr = Qe.getProperty("writable");
            if (Sr === void 0)
              return false;
            let Kr = Sr.valueDeclaration !== void 0 && D.isPropertyAssignment(Sr.valueDeclaration) ? ue.getTypeAtLocation(Sr.valueDeclaration.initializer) : ue.getTypeOfSymbolAtLocation(Sr, k.arguments[2]);
            return ae.isBooleanLiteralType(Kr, false);
          }
          a.isReadonlyAssignmentDeclaration = At;
          function re(k) {
            return k.arguments.length === 3 && D.isEntityNameExpression(k.arguments[0]) && D.isNumericOrStringLikeLiteral(k.arguments[1]) && D.isPropertyAccessExpression(k.expression) && k.expression.name.escapedText === "defineProperty" && D.isIdentifier(k.expression.expression) && k.expression.expression.escapedText === "Object";
          }
          a.isBindableObjectDefinePropertyCall = re;
          function de(k) {
            return _.isPropertyAccessExpression(k) && _.isIdentifier(k.expression) && k.expression.escapedText === "Symbol";
          }
          a.isWellKnownSymbolLiterally = de;
          function He(k) {
            return { displayName: `[Symbol.${k.name.text}]`, symbolName: "__@" + k.name.text };
          }
          a.getPropertyNameOfWellKnownSymbol = He;
          var Nr = ((k) => {
            let [ue, Qe] = k;
            return ue < "4" || ue === "4" && Qe < "3";
          })(_.versionMajorMinor.split("."));
          function Yr(k, ue) {
            let Qe = { known: true, names: [] };
            if (k = Lt(k), Nr && de(k))
              Qe.names.push(He(k));
            else {
              let Sr = ue.getTypeAtLocation(k);
              for (let Kr of ae.unionTypeParts(ue.getBaseConstraintOfType(Sr) || Sr)) {
                let Hr = ae.getPropertyNameFromType(Kr);
                Hr ? Qe.names.push(Hr) : Qe.known = false;
              }
            }
            return Qe;
          }
          a.getLateBoundPropertyNames = Yr;
          function Ct(k, ue) {
            let Qe = te(k);
            return Qe !== void 0 ? { known: true, names: [{ displayName: Qe, symbolName: _.escapeLeadingUnderscores(Qe) }] } : k.kind === _.SyntaxKind.PrivateIdentifier ? { known: true, names: [{ displayName: k.text, symbolName: ue.getSymbolAtLocation(k).escapedName }] } : Yr(k.expression, ue);
          }
          a.getLateBoundPropertyNamesOfPropertyName = Ct;
          function xt(k, ue) {
            let Qe = te(k);
            if (Qe !== void 0)
              return { displayName: Qe, symbolName: _.escapeLeadingUnderscores(Qe) };
            if (k.kind === _.SyntaxKind.PrivateIdentifier)
              return { displayName: k.text, symbolName: ue.getSymbolAtLocation(k).escapedName };
            let { expression: Sr } = k;
            return Nr && de(Sr) ? He(Sr) : ae.getPropertyNameFromType(ue.getTypeAtLocation(Sr));
          }
          a.getSingleLateBoundPropertyNameOfPropertyName = xt;
          function Lt(k) {
            for (; k.kind === _.SyntaxKind.ParenthesizedExpression; )
              k = k.expression;
            return k;
          }
          a.unwrapParentheses = Lt;
          function zt(k) {
            return `${k.negative ? "-" : ""}${k.base10Value}n`;
          }
          a.formatPseudoBigInt = zt;
          function Zt(k, ue) {
            let Qe = k.caseBlock.clauses.filter(D.isCaseClause);
            if (Qe.length === 0)
              return false;
            let Sr = ae.unionTypeParts(ue.getTypeAtLocation(k.expression));
            if (Sr.length > Qe.length)
              return false;
            let Kr = new Set(Sr.map(mt));
            if (Kr.has(void 0))
              return false;
            let Hr = /* @__PURE__ */ new Set();
            for (let Dt of Qe) {
              let Xt = ue.getTypeAtLocation(Dt.expression);
              if (a.isTypeFlagSet(Xt, _.TypeFlags.Never))
                continue;
              let cn = mt(Xt);
              if (Kr.has(cn))
                Hr.add(cn);
              else if (cn !== "null" && cn !== "undefined")
                return false;
            }
            return Kr.size === Hr.size;
          }
          a.hasExhaustiveCaseClauses = Zt;
          function mt(k) {
            if (a.isTypeFlagSet(k, _.TypeFlags.Null))
              return "null";
            if (a.isTypeFlagSet(k, _.TypeFlags.Undefined))
              return "undefined";
            if (a.isTypeFlagSet(k, _.TypeFlags.NumberLiteral))
              return `${a.isTypeFlagSet(k, _.TypeFlags.EnumLiteral) ? "enum:" : ""}${k.value}`;
            if (a.isTypeFlagSet(k, _.TypeFlags.StringLiteral))
              return `${a.isTypeFlagSet(k, _.TypeFlags.EnumLiteral) ? "enum:" : ""}string:${k.value}`;
            if (a.isTypeFlagSet(k, _.TypeFlags.BigIntLiteral))
              return zt(k.value);
            if (T.isUniqueESSymbolType(k))
              return k.escapedName;
            if (ae.isBooleanLiteralType(k, true))
              return "true";
            if (ae.isBooleanLiteralType(k, false))
              return "false";
          }
          function at(k) {
            var ue;
            if (((ue = k.heritageClauses) === null || ue === void 0 ? void 0 : ue[0].token) === _.SyntaxKind.ExtendsKeyword)
              return k.heritageClauses[0].types[0];
          }
          a.getBaseOfClassLikeExpression = at;
        } }), lT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/convert-comments.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(e, t3, w, s) {
            s === void 0 && (s = w);
            var q = Object.getOwnPropertyDescriptor(t3, w);
            (!q || ("get" in q ? !t3.__esModule : q.writable || q.configurable)) && (q = { enumerable: true, get: function() {
              return t3[w];
            } }), Object.defineProperty(e, s, q);
          } : function(e, t3, w, s) {
            s === void 0 && (s = w), e[s] = t3[w];
          }), D = a && a.__setModuleDefault || (Object.create ? function(e, t3) {
            Object.defineProperty(e, "default", { enumerable: true, value: t3 });
          } : function(e, t3) {
            e.default = t3;
          }), T = a && a.__importStar || function(e) {
            if (e && e.__esModule)
              return e;
            var t3 = {};
            if (e != null)
              for (var w in e)
                w !== "default" && Object.prototype.hasOwnProperty.call(e, w) && _(t3, e, w);
            return D(t3, e), t3;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.convertComments = void 0;
          var ae = Ty(), z = T(Di()), I = Pl(), E = kl();
          function N(e, t3) {
            let w = [];
            return (0, ae.forEachComment)(e, (s, q) => {
              let F = q.kind == z.SyntaxKind.SingleLineCommentTrivia ? E.AST_TOKEN_TYPES.Line : E.AST_TOKEN_TYPES.Block, fe = [q.pos, q.end], Ee = (0, I.getLocFor)(fe[0], fe[1], e), Se = fe[0] + 2, J = q.kind === z.SyntaxKind.SingleLineCommentTrivia ? fe[1] - Se : fe[1] - Se - 2;
              w.push({ type: F, value: t3.slice(Se, Se + J), range: fe, loc: Ee });
            }, e), w;
          }
          a.convertComments = N;
        } }), Sy = Ur({ "node_modules/eslint-visitor-keys/dist/eslint-visitor-keys.cjs"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true });
          var _ = { AssignmentExpression: ["left", "right"], AssignmentPattern: ["left", "right"], ArrayExpression: ["elements"], ArrayPattern: ["elements"], ArrowFunctionExpression: ["params", "body"], AwaitExpression: ["argument"], BlockStatement: ["body"], BinaryExpression: ["left", "right"], BreakStatement: ["label"], CallExpression: ["callee", "arguments"], CatchClause: ["param", "body"], ChainExpression: ["expression"], ClassBody: ["body"], ClassDeclaration: ["id", "superClass", "body"], ClassExpression: ["id", "superClass", "body"], ConditionalExpression: ["test", "consequent", "alternate"], ContinueStatement: ["label"], DebuggerStatement: [], DoWhileStatement: ["body", "test"], EmptyStatement: [], ExportAllDeclaration: ["exported", "source"], ExportDefaultDeclaration: ["declaration"], ExportNamedDeclaration: ["declaration", "specifiers", "source"], ExportSpecifier: ["exported", "local"], ExpressionStatement: ["expression"], ExperimentalRestProperty: ["argument"], ExperimentalSpreadProperty: ["argument"], ForStatement: ["init", "test", "update", "body"], ForInStatement: ["left", "right", "body"], ForOfStatement: ["left", "right", "body"], FunctionDeclaration: ["id", "params", "body"], FunctionExpression: ["id", "params", "body"], Identifier: [], IfStatement: ["test", "consequent", "alternate"], ImportDeclaration: ["specifiers", "source"], ImportDefaultSpecifier: ["local"], ImportExpression: ["source"], ImportNamespaceSpecifier: ["local"], ImportSpecifier: ["imported", "local"], JSXAttribute: ["name", "value"], JSXClosingElement: ["name"], JSXElement: ["openingElement", "children", "closingElement"], JSXEmptyExpression: [], JSXExpressionContainer: ["expression"], JSXIdentifier: [], JSXMemberExpression: ["object", "property"], JSXNamespacedName: ["namespace", "name"], JSXOpeningElement: ["name", "attributes"], JSXSpreadAttribute: ["argument"], JSXText: [], JSXFragment: ["openingFragment", "children", "closingFragment"], JSXClosingFragment: [], JSXOpeningFragment: [], Literal: [], LabeledStatement: ["label", "body"], LogicalExpression: ["left", "right"], MemberExpression: ["object", "property"], MetaProperty: ["meta", "property"], MethodDefinition: ["key", "value"], NewExpression: ["callee", "arguments"], ObjectExpression: ["properties"], ObjectPattern: ["properties"], PrivateIdentifier: [], Program: ["body"], Property: ["key", "value"], PropertyDefinition: ["key", "value"], RestElement: ["argument"], ReturnStatement: ["argument"], SequenceExpression: ["expressions"], SpreadElement: ["argument"], StaticBlock: ["body"], Super: [], SwitchStatement: ["discriminant", "cases"], SwitchCase: ["test", "consequent"], TaggedTemplateExpression: ["tag", "quasi"], TemplateElement: [], TemplateLiteral: ["quasis", "expressions"], ThisExpression: [], ThrowStatement: ["argument"], TryStatement: ["block", "handler", "finalizer"], UnaryExpression: ["argument"], UpdateExpression: ["argument"], VariableDeclaration: ["declarations"], VariableDeclarator: ["id", "init"], WhileStatement: ["test", "body"], WithStatement: ["object", "body"], YieldExpression: ["argument"] }, D = Object.keys(_);
          for (let E of D)
            Object.freeze(_[E]);
          Object.freeze(_);
          var T = /* @__PURE__ */ new Set(["parent", "leadingComments", "trailingComments"]);
          function ae(E) {
            return !T.has(E) && E[0] !== "_";
          }
          function z(E) {
            return Object.keys(E).filter(ae);
          }
          function I(E) {
            let N = Object.assign({}, _);
            for (let e of Object.keys(E))
              if (Object.prototype.hasOwnProperty.call(N, e)) {
                let t3 = new Set(E[e]);
                for (let w of N[e])
                  t3.add(w);
                N[e] = Object.freeze(Array.from(t3));
              } else
                N[e] = Object.freeze(Array.from(E[e]));
            return Object.freeze(N);
          }
          a.KEYS = _, a.getKeys = z, a.unionWith = I;
        } }), pT = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/visitor-keys/dist/get-keys.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.getKeys = void 0;
          var _ = Sy(), D = _.getKeys;
          a.getKeys = D;
        } }), fT = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/visitor-keys/dist/visitor-keys.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(N, e, t3, w) {
            w === void 0 && (w = t3);
            var s = Object.getOwnPropertyDescriptor(e, t3);
            (!s || ("get" in s ? !e.__esModule : s.writable || s.configurable)) && (s = { enumerable: true, get: function() {
              return e[t3];
            } }), Object.defineProperty(N, w, s);
          } : function(N, e, t3, w) {
            w === void 0 && (w = t3), N[w] = e[t3];
          }), D = a && a.__setModuleDefault || (Object.create ? function(N, e) {
            Object.defineProperty(N, "default", { enumerable: true, value: e });
          } : function(N, e) {
            N.default = e;
          }), T = a && a.__importStar || function(N) {
            if (N && N.__esModule)
              return N;
            var e = {};
            if (N != null)
              for (var t3 in N)
                t3 !== "default" && Object.prototype.hasOwnProperty.call(N, t3) && _(e, N, t3);
            return D(e, N), e;
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.visitorKeys = void 0;
          var ae = T(Sy()), z = (() => {
            let N = ["typeParameters", "params", "returnType"], e = [...N, "body"], t3 = ["decorators", "key", "typeAnnotation"];
            return { AnonymousFunction: e, Function: ["id", ...e], FunctionType: N, ClassDeclaration: ["decorators", "id", "typeParameters", "superClass", "superTypeParameters", "implements", "body"], AbstractPropertyDefinition: ["decorators", "key", "typeAnnotation"], PropertyDefinition: [...t3, "value"], TypeAssertion: ["expression", "typeAnnotation"] };
          })(), I = { AccessorProperty: z.PropertyDefinition, ArrayPattern: ["decorators", "elements", "typeAnnotation"], ArrowFunctionExpression: z.AnonymousFunction, AssignmentPattern: ["decorators", "left", "right", "typeAnnotation"], CallExpression: ["callee", "typeParameters", "arguments"], ClassDeclaration: z.ClassDeclaration, ClassExpression: z.ClassDeclaration, Decorator: ["expression"], ExportAllDeclaration: ["exported", "source", "assertions"], ExportNamedDeclaration: ["declaration", "specifiers", "source", "assertions"], FunctionDeclaration: z.Function, FunctionExpression: z.Function, Identifier: ["decorators", "typeAnnotation"], ImportAttribute: ["key", "value"], ImportDeclaration: ["specifiers", "source", "assertions"], ImportExpression: ["source", "attributes"], JSXClosingFragment: [], JSXOpeningElement: ["name", "typeParameters", "attributes"], JSXOpeningFragment: [], JSXSpreadChild: ["expression"], MethodDefinition: ["decorators", "key", "value", "typeParameters"], NewExpression: ["callee", "typeParameters", "arguments"], ObjectPattern: ["decorators", "properties", "typeAnnotation"], PropertyDefinition: z.PropertyDefinition, RestElement: ["decorators", "argument", "typeAnnotation"], StaticBlock: ["body"], TaggedTemplateExpression: ["tag", "typeParameters", "quasi"], TSAbstractAccessorProperty: z.AbstractPropertyDefinition, TSAbstractKeyword: [], TSAbstractMethodDefinition: ["key", "value"], TSAbstractPropertyDefinition: z.AbstractPropertyDefinition, TSAnyKeyword: [], TSArrayType: ["elementType"], TSAsExpression: z.TypeAssertion, TSAsyncKeyword: [], TSBigIntKeyword: [], TSBooleanKeyword: [], TSCallSignatureDeclaration: z.FunctionType, TSClassImplements: ["expression", "typeParameters"], TSConditionalType: ["checkType", "extendsType", "trueType", "falseType"], TSConstructorType: z.FunctionType, TSConstructSignatureDeclaration: z.FunctionType, TSDeclareFunction: z.Function, TSDeclareKeyword: [], TSEmptyBodyFunctionExpression: ["id", ...z.FunctionType], TSEnumDeclaration: ["id", "members"], TSEnumMember: ["id", "initializer"], TSExportAssignment: ["expression"], TSExportKeyword: [], TSExternalModuleReference: ["expression"], TSFunctionType: z.FunctionType, TSImportEqualsDeclaration: ["id", "moduleReference"], TSImportType: ["parameter", "qualifier", "typeParameters"], TSIndexedAccessType: ["indexType", "objectType"], TSIndexSignature: ["parameters", "typeAnnotation"], TSInferType: ["typeParameter"], TSInstantiationExpression: ["expression", "typeParameters"], TSInterfaceBody: ["body"], TSInterfaceDeclaration: ["id", "typeParameters", "extends", "body"], TSInterfaceHeritage: ["expression", "typeParameters"], TSIntersectionType: ["types"], TSIntrinsicKeyword: [], TSLiteralType: ["literal"], TSMappedType: ["nameType", "typeParameter", "typeAnnotation"], TSMethodSignature: ["typeParameters", "key", "params", "returnType"], TSModuleBlock: ["body"], TSModuleDeclaration: ["id", "body"], TSNamedTupleMember: ["label", "elementType"], TSNamespaceExportDeclaration: ["id"], TSNeverKeyword: [], TSNonNullExpression: ["expression"], TSNullKeyword: [], TSNumberKeyword: [], TSObjectKeyword: [], TSOptionalType: ["typeAnnotation"], TSParameterProperty: ["decorators", "parameter"], TSPrivateKeyword: [], TSPropertySignature: ["typeAnnotation", "key", "initializer"], TSProtectedKeyword: [], TSPublicKeyword: [], TSQualifiedName: ["left", "right"], TSReadonlyKeyword: [], TSRestType: ["typeAnnotation"], TSSatisfiesExpression: ["typeAnnotation", "expression"], TSStaticKeyword: [], TSStringKeyword: [], TSSymbolKeyword: [], TSTemplateLiteralType: ["quasis", "types"], TSThisType: [], TSTupleType: ["elementTypes"], TSTypeAliasDeclaration: ["id", "typeParameters", "typeAnnotation"], TSTypeAnnotation: ["typeAnnotation"], TSTypeAssertion: z.TypeAssertion, TSTypeLiteral: ["members"], TSTypeOperator: ["typeAnnotation"], TSTypeParameter: ["name", "constraint", "default"], TSTypeParameterDeclaration: ["params"], TSTypeParameterInstantiation: ["params"], TSTypePredicate: ["typeAnnotation", "parameterName"], TSTypeQuery: ["exprName", "typeParameters"], TSTypeReference: ["typeName", "typeParameters"], TSUndefinedKeyword: [], TSUnionType: ["types"], TSUnknownKeyword: [], TSVoidKeyword: [] }, E = ae.unionWith(I);
          a.visitorKeys = E;
        } }), Cy = Ur({ "node_modules/@typescript-eslint/typescript-estree/node_modules/@typescript-eslint/visitor-keys/dist/index.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.visitorKeys = a.getKeys = void 0;
          var _ = pT();
          Object.defineProperty(a, "getKeys", { enumerable: true, get: function() {
            return _.getKeys;
          } });
          var D = fT();
          Object.defineProperty(a, "visitorKeys", { enumerable: true, get: function() {
            return D.visitorKeys;
          } });
        } }), Dy = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/simple-traverse.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.simpleTraverse = void 0;
          var _ = Cy();
          function D(I) {
            return I !== null && typeof I == "object" && typeof I.type == "string";
          }
          function T(I, E) {
            let N = I[E.type];
            return N != null ? N : [];
          }
          var ae = class {
            constructor(I) {
              let E = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              this.allVisitorKeys = _.visitorKeys, this.selectors = I, this.setParentPointers = E;
            }
            traverse(I, E) {
              if (!D(I))
                return;
              this.setParentPointers && (I.parent = E), "enter" in this.selectors ? this.selectors.enter(I, E) : I.type in this.selectors && this.selectors[I.type](I, E);
              let N = T(this.allVisitorKeys, I);
              if (!(N.length < 1))
                for (let e of N) {
                  let t3 = I[e];
                  if (Array.isArray(t3))
                    for (let w of t3)
                      this.traverse(w, I);
                  else
                    this.traverse(t3, I);
                }
            }
          };
          function z(I, E) {
            let N = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
            new ae(E, N).traverse(I, void 0);
          }
          a.simpleTraverse = z;
        } }), dT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/ast-converter.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.astConverter = void 0;
          var _ = yy(), D = lT(), T = Pl(), ae = Dy();
          function z(I, E, N) {
            let { parseDiagnostics: e } = I;
            if (e.length)
              throw (0, _.convertError)(e[0]);
            let t3 = new _.Converter(I, { errorOnUnknownASTType: E.errorOnUnknownASTType || false, shouldPreserveNodeMaps: N }), w = t3.convertProgram();
            (!E.range || !E.loc) && (0, ae.simpleTraverse)(w, { enter: (q) => {
              E.range || delete q.range, E.loc || delete q.loc;
            } }), E.tokens && (w.tokens = (0, T.convertTokens)(I)), E.comment && (w.comments = (0, D.convertComments)(I, E.code));
            let s = t3.getASTMaps();
            return { estree: w, astMaps: s };
          }
          a.astConverter = z;
        } }), xy = {};
        Tl(xy, { basename: () => Ny, default: () => Oy, delimiter: () => Xp, dirname: () => Py, extname: () => Iy, isAbsolute: () => cf, join: () => Ay, normalize: () => _f, relative: () => ky, resolve: () => El, sep: () => Gp });
        function wy(a, _) {
          for (var D = 0, T = a.length - 1; T >= 0; T--) {
            var ae = a[T];
            ae === "." ? a.splice(T, 1) : ae === ".." ? (a.splice(T, 1), D++) : D && (a.splice(T, 1), D--);
          }
          if (_)
            for (; D--; D)
              a.unshift("..");
          return a;
        }
        function El() {
          for (var a = "", _ = false, D = arguments.length - 1; D >= -1 && !_; D--) {
            var T = D >= 0 ? arguments[D] : "/";
            if (typeof T != "string")
              throw new TypeError("Arguments to path.resolve must be strings");
            if (!T)
              continue;
            a = T + "/" + a, _ = T.charAt(0) === "/";
          }
          return a = wy(uf(a.split("/"), function(ae) {
            return !!ae;
          }), !_).join("/"), (_ ? "/" : "") + a || ".";
        }
        function _f(a) {
          var _ = cf(a), D = My(a, -1) === "/";
          return a = wy(uf(a.split("/"), function(T) {
            return !!T;
          }), !_).join("/"), !a && !_ && (a = "."), a && D && (a += "/"), (_ ? "/" : "") + a;
        }
        function cf(a) {
          return a.charAt(0) === "/";
        }
        function Ay() {
          var a = Array.prototype.slice.call(arguments, 0);
          return _f(uf(a, function(_, D) {
            if (typeof _ != "string")
              throw new TypeError("Arguments to path.join must be strings");
            return _;
          }).join("/"));
        }
        function ky(a, _) {
          a = El(a).substr(1), _ = El(_).substr(1);
          function D(e) {
            for (var t3 = 0; t3 < e.length && e[t3] === ""; t3++)
              ;
            for (var w = e.length - 1; w >= 0 && e[w] === ""; w--)
              ;
            return t3 > w ? [] : e.slice(t3, w - t3 + 1);
          }
          for (var T = D(a.split("/")), ae = D(_.split("/")), z = Math.min(T.length, ae.length), I = z, E = 0; E < z; E++)
            if (T[E] !== ae[E]) {
              I = E;
              break;
            }
          for (var N = [], E = I; E < T.length; E++)
            N.push("..");
          return N = N.concat(ae.slice(I)), N.join("/");
        }
        function Py(a) {
          var _ = Nl(a), D = _[0], T = _[1];
          return !D && !T ? "." : (T && (T = T.substr(0, T.length - 1)), D + T);
        }
        function Ny(a, _) {
          var D = Nl(a)[2];
          return _ && D.substr(-1 * _.length) === _ && (D = D.substr(0, D.length - _.length)), D;
        }
        function Iy(a) {
          return Nl(a)[3];
        }
        function uf(a, _) {
          if (a.filter)
            return a.filter(_);
          for (var D = [], T = 0; T < a.length; T++)
            _(a[T], T, a) && D.push(a[T]);
          return D;
        }
        var Hg, Nl, Gp, Xp, Oy, My, mT = Bu({ "node-modules-polyfills:path"() {
          Jr(), Hg = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/, Nl = function(a) {
            return Hg.exec(a).slice(1);
          }, Gp = "/", Xp = ":", Oy = { extname: Iy, basename: Ny, dirname: Py, sep: Gp, delimiter: Xp, relative: ky, join: Ay, isAbsolute: cf, normalize: _f, resolve: El }, My = "ab".substr(-1) === "b" ? function(a, _, D) {
            return a.substr(_, D);
          } : function(a, _, D) {
            return _ < 0 && (_ = a.length + _), a.substr(_, D);
          };
        } }), Uc = Ur({ "node-modules-polyfills-commonjs:path"(a, _) {
          Jr();
          var D = (mT(), ja(xy));
          if (D && D.default) {
            _.exports = D.default;
            for (let T in D)
              _.exports[T] = D[T];
          } else
            D && (_.exports = D);
        } }), zc = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/shared.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(se, Me, Q, Be) {
            Be === void 0 && (Be = Q);
            var je = Object.getOwnPropertyDescriptor(Me, Q);
            (!je || ("get" in je ? !Me.__esModule : je.writable || je.configurable)) && (je = { enumerable: true, get: function() {
              return Me[Q];
            } }), Object.defineProperty(se, Be, je);
          } : function(se, Me, Q, Be) {
            Be === void 0 && (Be = Q), se[Be] = Me[Q];
          }), D = a && a.__setModuleDefault || (Object.create ? function(se, Me) {
            Object.defineProperty(se, "default", { enumerable: true, value: Me });
          } : function(se, Me) {
            se.default = Me;
          }), T = a && a.__importStar || function(se) {
            if (se && se.__esModule)
              return se;
            var Me = {};
            if (se != null)
              for (var Q in se)
                Q !== "default" && Object.prototype.hasOwnProperty.call(se, Q) && _(Me, se, Q);
            return D(Me, se), Me;
          }, ae = a && a.__importDefault || function(se) {
            return se && se.__esModule ? se : { default: se };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.getModuleResolver = a.getAstFromProgram = a.getCanonicalFileName = a.ensureAbsolutePath = a.createDefaultCompilerOptionsFromExtra = a.canonicalDirname = a.CORE_COMPILER_OPTIONS = void 0;
          var z = ae(Uc()), I = T(Di()), E = { noEmit: true, noUnusedLocals: true, noUnusedParameters: true };
          a.CORE_COMPILER_OPTIONS = E;
          var N = Object.assign(Object.assign({}, E), { allowNonTsExtensions: true, allowJs: true, checkJs: true });
          function e(se) {
            return se.debugLevel.has("typescript") ? Object.assign(Object.assign({}, N), { extendedDiagnostics: true }) : N;
          }
          a.createDefaultCompilerOptionsFromExtra = e;
          var t3 = I.sys !== void 0 ? I.sys.useCaseSensitiveFileNames : true, w = t3 ? (se) => se : (se) => se.toLowerCase();
          function s(se) {
            let Me = z.default.normalize(se);
            return Me.endsWith(z.default.sep) && (Me = Me.slice(0, -1)), w(Me);
          }
          a.getCanonicalFileName = s;
          function q(se, Me) {
            return z.default.isAbsolute(se) ? se : z.default.join(Me || "/prettier-security-dirname-placeholder", se);
          }
          a.ensureAbsolutePath = q;
          function F(se) {
            return z.default.dirname(se);
          }
          a.canonicalDirname = F;
          var fe = [I.Extension.Dts, I.Extension.Dcts, I.Extension.Dmts];
          function Ee(se) {
            var Me;
            return se ? (Me = fe.find((Q) => se.endsWith(Q))) !== null && Me !== void 0 ? Me : z.default.extname(se) : null;
          }
          function Se(se, Me) {
            let Q = se.getSourceFile(Me.filePath), Be = Ee(Me.filePath), je = Ee(Q == null ? void 0 : Q.fileName);
            if (Be === je)
              return Q && { ast: Q, program: se };
          }
          a.getAstFromProgram = Se;
          function J(se) {
            let Me;
            try {
              throw new Error("Dynamic require is not supported");
            } catch {
              let Be = ["Could not find the provided parserOptions.moduleResolver.", "Hint: use an absolute path if you are not in control over where the ESLint instance runs."];
              throw new Error(Be.join(`
`));
            }
            return Me;
          }
          a.getModuleResolver = J;
        } }), gT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/createDefaultProgram.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(w, s, q, F) {
            F === void 0 && (F = q);
            var fe = Object.getOwnPropertyDescriptor(s, q);
            (!fe || ("get" in fe ? !s.__esModule : fe.writable || fe.configurable)) && (fe = { enumerable: true, get: function() {
              return s[q];
            } }), Object.defineProperty(w, F, fe);
          } : function(w, s, q, F) {
            F === void 0 && (F = q), w[F] = s[q];
          }), D = a && a.__setModuleDefault || (Object.create ? function(w, s) {
            Object.defineProperty(w, "default", { enumerable: true, value: s });
          } : function(w, s) {
            w.default = s;
          }), T = a && a.__importStar || function(w) {
            if (w && w.__esModule)
              return w;
            var s = {};
            if (w != null)
              for (var q in w)
                q !== "default" && Object.prototype.hasOwnProperty.call(w, q) && _(s, w, q);
            return D(s, w), s;
          }, ae = a && a.__importDefault || function(w) {
            return w && w.__esModule ? w : { default: w };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createDefaultProgram = void 0;
          var z = ae(Ns()), I = ae(Uc()), E = T(Di()), N = zc(), e = (0, z.default)("typescript-eslint:typescript-estree:createDefaultProgram");
          function t3(w) {
            var s;
            if (e("Getting default program for: %s", w.filePath || "unnamed file"), ((s = w.projects) === null || s === void 0 ? void 0 : s.length) !== 1)
              return;
            let q = w.projects[0], F = E.getParsedCommandLineOfConfigFile(q, (0, N.createDefaultCompilerOptionsFromExtra)(w), Object.assign(Object.assign({}, E.sys), { onUnRecoverableConfigFileDiagnostic: () => {
            } }));
            if (!F)
              return;
            let fe = E.createCompilerHost(F.options, true);
            w.moduleResolver && (fe.resolveModuleNames = (0, N.getModuleResolver)(w.moduleResolver).resolveModuleNames);
            let Ee = fe.readFile;
            fe.readFile = (se) => I.default.normalize(se) === I.default.normalize(w.filePath) ? w.code : Ee(se);
            let Se = E.createProgram([w.filePath], F.options, fe), J = Se.getSourceFile(w.filePath);
            return J && { ast: J, program: Se };
          }
          a.createDefaultProgram = t3;
        } }), lf = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/getScriptKind.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(e, t3, w, s) {
            s === void 0 && (s = w);
            var q = Object.getOwnPropertyDescriptor(t3, w);
            (!q || ("get" in q ? !t3.__esModule : q.writable || q.configurable)) && (q = { enumerable: true, get: function() {
              return t3[w];
            } }), Object.defineProperty(e, s, q);
          } : function(e, t3, w, s) {
            s === void 0 && (s = w), e[s] = t3[w];
          }), D = a && a.__setModuleDefault || (Object.create ? function(e, t3) {
            Object.defineProperty(e, "default", { enumerable: true, value: t3 });
          } : function(e, t3) {
            e.default = t3;
          }), T = a && a.__importStar || function(e) {
            if (e && e.__esModule)
              return e;
            var t3 = {};
            if (e != null)
              for (var w in e)
                w !== "default" && Object.prototype.hasOwnProperty.call(e, w) && _(t3, e, w);
            return D(t3, e), t3;
          }, ae = a && a.__importDefault || function(e) {
            return e && e.__esModule ? e : { default: e };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.getLanguageVariant = a.getScriptKind = void 0;
          var z = ae(Uc()), I = T(Di());
          function E(e, t3) {
            switch (z.default.extname(e).toLowerCase()) {
              case I.Extension.Js:
              case I.Extension.Cjs:
              case I.Extension.Mjs:
                return I.ScriptKind.JS;
              case I.Extension.Jsx:
                return I.ScriptKind.JSX;
              case I.Extension.Ts:
              case I.Extension.Cts:
              case I.Extension.Mts:
                return I.ScriptKind.TS;
              case I.Extension.Tsx:
                return I.ScriptKind.TSX;
              case I.Extension.Json:
                return I.ScriptKind.JSON;
              default:
                return t3 ? I.ScriptKind.TSX : I.ScriptKind.TS;
            }
          }
          a.getScriptKind = E;
          function N(e) {
            switch (e) {
              case I.ScriptKind.TSX:
              case I.ScriptKind.JSX:
              case I.ScriptKind.JS:
              case I.ScriptKind.JSON:
                return I.LanguageVariant.JSX;
              default:
                return I.LanguageVariant.Standard;
            }
          }
          a.getLanguageVariant = N;
        } }), yT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/createIsolatedProgram.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(w, s, q, F) {
            F === void 0 && (F = q);
            var fe = Object.getOwnPropertyDescriptor(s, q);
            (!fe || ("get" in fe ? !s.__esModule : fe.writable || fe.configurable)) && (fe = { enumerable: true, get: function() {
              return s[q];
            } }), Object.defineProperty(w, F, fe);
          } : function(w, s, q, F) {
            F === void 0 && (F = q), w[F] = s[q];
          }), D = a && a.__setModuleDefault || (Object.create ? function(w, s) {
            Object.defineProperty(w, "default", { enumerable: true, value: s });
          } : function(w, s) {
            w.default = s;
          }), T = a && a.__importStar || function(w) {
            if (w && w.__esModule)
              return w;
            var s = {};
            if (w != null)
              for (var q in w)
                q !== "default" && Object.prototype.hasOwnProperty.call(w, q) && _(s, w, q);
            return D(s, w), s;
          }, ae = a && a.__importDefault || function(w) {
            return w && w.__esModule ? w : { default: w };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createIsolatedProgram = void 0;
          var z = ae(Ns()), I = T(Di()), E = lf(), N = zc(), e = (0, z.default)("typescript-eslint:typescript-estree:createIsolatedProgram");
          function t3(w) {
            e("Getting isolated program in %s mode for: %s", w.jsx ? "TSX" : "TS", w.filePath);
            let s = { fileExists() {
              return true;
            }, getCanonicalFileName() {
              return w.filePath;
            }, getCurrentDirectory() {
              return "";
            }, getDirectories() {
              return [];
            }, getDefaultLibFileName() {
              return "lib.d.ts";
            }, getNewLine() {
              return `
`;
            }, getSourceFile(fe) {
              return I.createSourceFile(fe, w.code, I.ScriptTarget.Latest, true, (0, E.getScriptKind)(w.filePath, w.jsx));
            }, readFile() {
            }, useCaseSensitiveFileNames() {
              return true;
            }, writeFile() {
              return null;
            } }, q = I.createProgram([w.filePath], Object.assign({ noResolve: true, target: I.ScriptTarget.Latest, jsx: w.jsx ? I.JsxEmit.Preserve : void 0 }, (0, N.createDefaultCompilerOptionsFromExtra)(w)), s), F = q.getSourceFile(w.filePath);
            if (!F)
              throw new Error("Expected an ast to be returned for the single-file isolated program.");
            return { ast: F, program: q };
          }
          a.createIsolatedProgram = t3;
        } }), Ly = {};
        Tl(Ly, { default: () => Ry });
        var Ry, hT = Bu({ "node-modules-polyfills:fs"() {
          Jr(), Ry = {};
        } }), jy = Ur({ "node-modules-polyfills-commonjs:fs"(a, _) {
          Jr();
          var D = (hT(), ja(Ly));
          if (D && D.default) {
            _.exports = D.default;
            for (let T in D)
              _.exports[T] = D[T];
          } else
            D && (_.exports = D);
        } }), Jy = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/createWatchProgram.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(v, g, O, S) {
            S === void 0 && (S = O);
            var te = Object.getOwnPropertyDescriptor(g, O);
            (!te || ("get" in te ? !g.__esModule : te.writable || te.configurable)) && (te = { enumerable: true, get: function() {
              return g[O];
            } }), Object.defineProperty(v, S, te);
          } : function(v, g, O, S) {
            S === void 0 && (S = O), v[S] = g[O];
          }), D = a && a.__setModuleDefault || (Object.create ? function(v, g) {
            Object.defineProperty(v, "default", { enumerable: true, value: g });
          } : function(v, g) {
            v.default = g;
          }), T = a && a.__importStar || function(v) {
            if (v && v.__esModule)
              return v;
            var g = {};
            if (v != null)
              for (var O in v)
                O !== "default" && Object.prototype.hasOwnProperty.call(v, O) && _(g, v, O);
            return D(g, v), g;
          }, ae = a && a.__importDefault || function(v) {
            return v && v.__esModule ? v : { default: v };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.getProgramsForProjects = a.createWatchProgram = a.clearWatchCaches = void 0;
          var z = ae(Ns()), I = ae(jy()), E = ae(af()), N = T(Di()), e = zc(), t3 = (0, z.default)("typescript-eslint:typescript-estree:createWatchProgram"), w = /* @__PURE__ */ new Map(), s = /* @__PURE__ */ new Map(), q = /* @__PURE__ */ new Map(), F = /* @__PURE__ */ new Map(), fe = /* @__PURE__ */ new Map(), Ee = /* @__PURE__ */ new Map();
          function Se() {
            w.clear(), s.clear(), q.clear(), Ee.clear(), F.clear(), fe.clear();
          }
          a.clearWatchCaches = Se;
          function J(v) {
            return (g, O) => {
              let S = (0, e.getCanonicalFileName)(g), te = (() => {
                let Je = v.get(S);
                return Je || (Je = /* @__PURE__ */ new Set(), v.set(S, Je)), Je;
              })();
              return te.add(O), { close: () => {
                te.delete(O);
              } };
            };
          }
          var se = { code: "", filePath: "" };
          function Me(v) {
            throw new Error(N.flattenDiagnosticMessageText(v.messageText, N.sys.newLine));
          }
          function Q(v) {
            var g;
            return !((g = N.sys) === null || g === void 0) && g.createHash ? N.sys.createHash(v) : v;
          }
          function Be(v, g, O) {
            let S = O.EXPERIMENTAL_useSourceOfProjectReferenceRedirect ? new Set(g.getSourceFiles().map((te) => (0, e.getCanonicalFileName)(te.fileName))) : new Set(g.getRootFileNames().map((te) => (0, e.getCanonicalFileName)(te)));
            return F.set(v, S), S;
          }
          function je(v) {
            let g = (0, e.getCanonicalFileName)(v.filePath), O = [];
            se.code = v.code, se.filePath = g;
            let S = s.get(g), te = Q(v.code);
            Ee.get(g) !== te && S && S.size > 0 && S.forEach((qe) => qe(g, N.FileWatcherEventKind.Changed));
            let Je = new Set(v.projects);
            for (let [qe, ge] of w.entries()) {
              if (!Je.has(qe))
                continue;
              let ie = F.get(qe), H = null;
              if (ie || (H = ge.getProgram().getProgram(), ie = Be(qe, H, v)), ie.has(g))
                return t3("Found existing program for file. %s", g), H = H != null ? H : ge.getProgram().getProgram(), H.getTypeChecker(), [H];
            }
            t3("File did not belong to any existing programs, moving to create/update. %s", g);
            for (let qe of v.projects) {
              let ge = w.get(qe);
              if (ge) {
                let j = m(ge, g, qe);
                if (!j)
                  continue;
                if (j.getTypeChecker(), Be(qe, j, v).has(g))
                  return t3("Found updated program for file. %s", g), [j];
                O.push(j);
                continue;
              }
              let ie = B(qe, v);
              w.set(qe, ie);
              let H = ie.getProgram().getProgram();
              if (H.getTypeChecker(), Be(qe, H, v).has(g))
                return t3("Found program for file. %s", g), [H];
              O.push(H);
            }
            return O;
          }
          a.getProgramsForProjects = je;
          var V = E.default.satisfies(N.version, ">=3.9.0-beta", { includePrerelease: true });
          function B(v, g) {
            t3("Creating watch program for %s.", v);
            let O = N.createWatchCompilerHost(v, (0, e.createDefaultCompilerOptionsFromExtra)(g), N.sys, N.createAbstractBuilder, Me, () => {
            });
            g.moduleResolver && (O.resolveModuleNames = (0, e.getModuleResolver)(g.moduleResolver).resolveModuleNames);
            let S = O.readFile;
            O.readFile = (ge, ie) => {
              let H = (0, e.getCanonicalFileName)(ge), pe = H === se.filePath ? se.code : S(H, ie);
              return pe !== void 0 && Ee.set(H, Q(pe)), pe;
            }, O.onUnRecoverableConfigFileDiagnostic = Me, O.afterProgramCreate = (ge) => {
              let ie = ge.getConfigFileParsingDiagnostics().filter((H) => H.category === N.DiagnosticCategory.Error && H.code !== 18003);
              ie.length > 0 && Me(ie[0]);
            }, O.watchFile = J(s), O.watchDirectory = J(q);
            let te = O.onCachedDirectoryStructureHostCreate;
            O.onCachedDirectoryStructureHostCreate = (ge) => {
              let ie = ge.readDirectory;
              ge.readDirectory = (H, pe, j, be, Xe) => ie(H, pe ? pe.concat(g.extraFileExtensions) : void 0, j, be, Xe), te(ge);
            }, O.extraFileExtensions = g.extraFileExtensions.map((ge) => ({ extension: ge, isMixedContent: true, scriptKind: N.ScriptKind.Deferred })), O.trace = t3, O.useSourceOfProjectReferenceRedirect = () => g.EXPERIMENTAL_useSourceOfProjectReferenceRedirect;
            let Je;
            V ? (O.setTimeout = void 0, O.clearTimeout = void 0) : (t3("Running without timeout fix"), O.setTimeout = function(ge, ie) {
              for (var H = arguments.length, pe = new Array(H > 2 ? H - 2 : 0), j = 2; j < H; j++)
                pe[j - 2] = arguments[j];
              return Je = ge.bind(void 0, ...pe), Je;
            }, O.clearTimeout = () => {
              Je = void 0;
            });
            let qe = N.createWatchProgram(O);
            if (!V) {
              let ge = qe.getProgram;
              qe.getProgram = () => (Je && Je(), Je = void 0, ge.call(qe));
            }
            return qe;
          }
          a.createWatchProgram = B;
          function U(v) {
            let O = I.default.statSync(v).mtimeMs, S = fe.get(v);
            return fe.set(v, O), S === void 0 ? false : Math.abs(S - O) > Number.EPSILON;
          }
          function m(v, g, O) {
            let S = v.getProgram().getProgram();
            if (ba.env.TSESTREE_NO_INVALIDATION === "true")
              return S;
            U(O) && (t3("tsconfig has changed - triggering program update. %s", O), s.get(O).forEach((be) => be(O, N.FileWatcherEventKind.Changed)), F.delete(O));
            let te = S.getSourceFile(g);
            if (te)
              return S;
            t3("File was not found in program - triggering folder update. %s", g);
            let Je = (0, e.canonicalDirname)(g), qe = null, ge = Je, ie = false;
            for (; qe !== ge; ) {
              qe = ge;
              let be = q.get(qe);
              be && (be.forEach((Xe) => {
                Je !== qe && Xe(Je, N.FileWatcherEventKind.Changed), Xe(qe, N.FileWatcherEventKind.Changed);
              }), ie = true), ge = (0, e.canonicalDirname)(qe);
            }
            if (!ie)
              return t3("No callback found for file, not part of this program. %s", g), null;
            if (F.delete(O), S = v.getProgram().getProgram(), te = S.getSourceFile(g), te)
              return S;
            t3("File was still not found in program after directory update - checking file deletions. %s", g);
            let pe = S.getRootFileNames().find((be) => !I.default.existsSync(be));
            if (!pe)
              return null;
            let j = s.get((0, e.getCanonicalFileName)(pe));
            return j ? (t3("Marking file as deleted. %s", pe), j.forEach((be) => be(pe, N.FileWatcherEventKind.Deleted)), F.delete(O), S = v.getProgram().getProgram(), te = S.getSourceFile(g), te ? S : (t3("File was still not found in program after deletion check, assuming it is not part of this program. %s", g), null)) : (t3("Could not find watch callbacks for root file. %s", pe), S);
          }
        } }), vT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/createProjectProgram.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(F, fe, Ee, Se) {
            Se === void 0 && (Se = Ee);
            var J = Object.getOwnPropertyDescriptor(fe, Ee);
            (!J || ("get" in J ? !fe.__esModule : J.writable || J.configurable)) && (J = { enumerable: true, get: function() {
              return fe[Ee];
            } }), Object.defineProperty(F, Se, J);
          } : function(F, fe, Ee, Se) {
            Se === void 0 && (Se = Ee), F[Se] = fe[Ee];
          }), D = a && a.__setModuleDefault || (Object.create ? function(F, fe) {
            Object.defineProperty(F, "default", { enumerable: true, value: fe });
          } : function(F, fe) {
            F.default = fe;
          }), T = a && a.__importStar || function(F) {
            if (F && F.__esModule)
              return F;
            var fe = {};
            if (F != null)
              for (var Ee in F)
                Ee !== "default" && Object.prototype.hasOwnProperty.call(F, Ee) && _(fe, F, Ee);
            return D(fe, F), fe;
          }, ae = a && a.__importDefault || function(F) {
            return F && F.__esModule ? F : { default: F };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createProjectProgram = void 0;
          var z = ae(Ns()), I = ae(Uc()), E = T(Di()), N = Pl(), e = Jy(), t3 = zc(), w = (0, z.default)("typescript-eslint:typescript-estree:createProjectProgram"), s = [E.Extension.Ts, E.Extension.Tsx, E.Extension.Js, E.Extension.Jsx, E.Extension.Mjs, E.Extension.Mts, E.Extension.Cjs, E.Extension.Cts];
          function q(F) {
            w("Creating project program for: %s", F.filePath);
            let fe = (0, e.getProgramsForProjects)(F), Ee = (0, N.firstDefined)(fe, (B) => (0, t3.getAstFromProgram)(B, F));
            if (Ee || F.createDefaultProgram)
              return Ee;
            let Se = (B) => {
              let U = I.default.relative(F.tsconfigRootDir || "/prettier-security-dirname-placeholder", B);
              return F.tsconfigRootDir ? `<tsconfigRootDir>/${U}` : `<cwd>/${U}`;
            }, J = Se(F.filePath), se = F.projects.map(Se), Me = se.length === 1 ? se[0] : `
${se.map((B) => `- ${B}`).join(`
`)}`, Q = [`ESLint was configured to run on \`${J}\` using \`parserOptions.project\`: ${Me}`], Be = false, je = F.extraFileExtensions || [];
            je.forEach((B) => {
              B.startsWith(".") || Q.push(`Found unexpected extension \`${B}\` specified with the \`parserOptions.extraFileExtensions\` option. Did you mean \`.${B}\`?`), s.includes(B) && Q.push(`You unnecessarily included the extension \`${B}\` with the \`parserOptions.extraFileExtensions\` option. This extension is already handled by the parser by default.`);
            });
            let V = I.default.extname(F.filePath);
            if (!s.includes(V)) {
              let B = `The extension for the file (\`${V}\`) is non-standard`;
              je.length > 0 ? je.includes(V) || (Q.push(`${B}. It should be added to your existing \`parserOptions.extraFileExtensions\`.`), Be = true) : (Q.push(`${B}. You should add \`parserOptions.extraFileExtensions\` to your config.`), Be = true);
            }
            if (!Be) {
              let [B, U] = F.projects.length === 1 ? ["that TSConfig does not", "that TSConfig"] : ["none of those TSConfigs", "one of those TSConfigs"];
              Q.push(`However, ${B} include this file. Either:`, "- Change ESLint's list of included files to not include this file", `- Change ${U} to include this file`, "- Create a new TSConfig that includes this file and include it in your parserOptions.project", "See the TypeScript ESLint docs for more info: https://typescript-eslint.io/docs/linting/troubleshooting##i-get-errors-telling-me-eslint-was-configured-to-run--however-that-tsconfig-does-not--none-of-those-tsconfigs-include-this-file");
            }
            throw new Error(Q.join(`
`));
          }
          a.createProjectProgram = q;
        } }), bT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/createSourceFile.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(t3, w, s, q) {
            q === void 0 && (q = s);
            var F = Object.getOwnPropertyDescriptor(w, s);
            (!F || ("get" in F ? !w.__esModule : F.writable || F.configurable)) && (F = { enumerable: true, get: function() {
              return w[s];
            } }), Object.defineProperty(t3, q, F);
          } : function(t3, w, s, q) {
            q === void 0 && (q = s), t3[q] = w[s];
          }), D = a && a.__setModuleDefault || (Object.create ? function(t3, w) {
            Object.defineProperty(t3, "default", { enumerable: true, value: w });
          } : function(t3, w) {
            t3.default = w;
          }), T = a && a.__importStar || function(t3) {
            if (t3 && t3.__esModule)
              return t3;
            var w = {};
            if (t3 != null)
              for (var s in t3)
                s !== "default" && Object.prototype.hasOwnProperty.call(t3, s) && _(w, t3, s);
            return D(w, t3), w;
          }, ae = a && a.__importDefault || function(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createSourceFile = void 0;
          var z = ae(Ns()), I = T(Di()), E = lf(), N = (0, z.default)("typescript-eslint:typescript-estree:createSourceFile");
          function e(t3) {
            return N("Getting AST without type information in %s mode for: %s", t3.jsx ? "TSX" : "TS", t3.filePath), I.createSourceFile(t3.filePath, t3.code, I.ScriptTarget.Latest, true, (0, E.getScriptKind)(t3.filePath, t3.jsx));
          }
          a.createSourceFile = e;
        } }), Fy = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/create-program/useProvidedPrograms.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(F, fe, Ee, Se) {
            Se === void 0 && (Se = Ee);
            var J = Object.getOwnPropertyDescriptor(fe, Ee);
            (!J || ("get" in J ? !fe.__esModule : J.writable || J.configurable)) && (J = { enumerable: true, get: function() {
              return fe[Ee];
            } }), Object.defineProperty(F, Se, J);
          } : function(F, fe, Ee, Se) {
            Se === void 0 && (Se = Ee), F[Se] = fe[Ee];
          }), D = a && a.__setModuleDefault || (Object.create ? function(F, fe) {
            Object.defineProperty(F, "default", { enumerable: true, value: fe });
          } : function(F, fe) {
            F.default = fe;
          }), T = a && a.__importStar || function(F) {
            if (F && F.__esModule)
              return F;
            var fe = {};
            if (F != null)
              for (var Ee in F)
                Ee !== "default" && Object.prototype.hasOwnProperty.call(F, Ee) && _(fe, F, Ee);
            return D(fe, F), fe;
          }, ae = a && a.__importDefault || function(F) {
            return F && F.__esModule ? F : { default: F };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createProgramFromConfigFile = a.useProvidedPrograms = void 0;
          var z = ae(Ns()), I = T(jy()), E = T(Uc()), N = T(Di()), e = zc(), t3 = (0, z.default)("typescript-eslint:typescript-estree:useProvidedProgram");
          function w(F, fe) {
            t3("Retrieving ast for %s from provided program instance(s)", fe.filePath);
            let Ee;
            for (let Se of F)
              if (Ee = (0, e.getAstFromProgram)(Se, fe), Ee)
                break;
            if (!Ee) {
              let J = ['"parserOptions.programs" has been provided for @typescript-eslint/parser.', `The file was not found in any of the provided program instance(s): ${E.relative(fe.tsconfigRootDir || "/prettier-security-dirname-placeholder", fe.filePath)}`];
              throw new Error(J.join(`
`));
            }
            return Ee.program.getTypeChecker(), Ee;
          }
          a.useProvidedPrograms = w;
          function s(F, fe) {
            if (N.sys === void 0)
              throw new Error("`createProgramFromConfigFile` is only supported in a Node-like environment.");
            let Se = N.getParsedCommandLineOfConfigFile(F, e.CORE_COMPILER_OPTIONS, { onUnRecoverableConfigFileDiagnostic: (se) => {
              throw new Error(q([se]));
            }, fileExists: I.existsSync, getCurrentDirectory: () => fe && E.resolve(fe) || "/prettier-security-dirname-placeholder", readDirectory: N.sys.readDirectory, readFile: (se) => I.readFileSync(se, "utf-8"), useCaseSensitiveFileNames: N.sys.useCaseSensitiveFileNames });
            if (Se.errors.length)
              throw new Error(q(Se.errors));
            let J = N.createCompilerHost(Se.options, true);
            return N.createProgram(Se.fileNames, Se.options, J);
          }
          a.createProgramFromConfigFile = s;
          function q(F) {
            return N.formatDiagnostics(F, { getCanonicalFileName: (fe) => fe, getCurrentDirectory: ba.cwd, getNewLine: () => `
` });
          }
        } }), ET = Ur({ "node_modules/is-extglob/index.js"(a, _) {
          Jr(), _.exports = function(T) {
            if (typeof T != "string" || T === "")
              return false;
            for (var ae; ae = /(\\).|([@?!+*]\(.*\))/g.exec(T); ) {
              if (ae[2])
                return true;
              T = T.slice(ae.index + ae[0].length);
            }
            return false;
          };
        } }), TT = Ur({ "node_modules/is-glob/index.js"(a, _) {
          Jr();
          var D = ET(), T = { "{": "}", "(": ")", "[": "]" }, ae = function(I) {
            if (I[0] === "!")
              return true;
            for (var E = 0, N = -2, e = -2, t3 = -2, w = -2, s = -2; E < I.length; ) {
              if (I[E] === "*" || I[E + 1] === "?" && /[\].+)]/.test(I[E]) || e !== -1 && I[E] === "[" && I[E + 1] !== "]" && (e < E && (e = I.indexOf("]", E)), e > E && (s === -1 || s > e || (s = I.indexOf("\\", E), s === -1 || s > e))) || t3 !== -1 && I[E] === "{" && I[E + 1] !== "}" && (t3 = I.indexOf("}", E), t3 > E && (s = I.indexOf("\\", E), s === -1 || s > t3)) || w !== -1 && I[E] === "(" && I[E + 1] === "?" && /[:!=]/.test(I[E + 2]) && I[E + 3] !== ")" && (w = I.indexOf(")", E), w > E && (s = I.indexOf("\\", E), s === -1 || s > w)) || N !== -1 && I[E] === "(" && I[E + 1] !== "|" && (N < E && (N = I.indexOf("|", E)), N !== -1 && I[N + 1] !== ")" && (w = I.indexOf(")", N), w > N && (s = I.indexOf("\\", N), s === -1 || s > w))))
                return true;
              if (I[E] === "\\") {
                var q = I[E + 1];
                E += 2;
                var F = T[q];
                if (F) {
                  var fe = I.indexOf(F, E);
                  fe !== -1 && (E = fe + 1);
                }
                if (I[E] === "!")
                  return true;
              } else
                E++;
            }
            return false;
          }, z = function(I) {
            if (I[0] === "!")
              return true;
            for (var E = 0; E < I.length; ) {
              if (/[*?{}()[\]]/.test(I[E]))
                return true;
              if (I[E] === "\\") {
                var N = I[E + 1];
                E += 2;
                var e = T[N];
                if (e) {
                  var t3 = I.indexOf(e, E);
                  t3 !== -1 && (E = t3 + 1);
                }
                if (I[E] === "!")
                  return true;
              } else
                E++;
            }
            return false;
          };
          _.exports = function(E, N) {
            if (typeof E != "string" || E === "")
              return false;
            if (D(E))
              return true;
            var e = ae;
            return N && N.strict === false && (e = z), e(E);
          };
        } }), ST = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/parseSettings/inferSingleRun.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.inferSingleRun = void 0;
          var _ = Uc();
          function D(T) {
            return (T == null ? void 0 : T.project) == null || (T == null ? void 0 : T.programs) != null || ba.env.TSESTREE_SINGLE_RUN === "false" ? false : !!(ba.env.TSESTREE_SINGLE_RUN === "true" || T != null && T.allowAutomaticSingleRunInference && (ba.env.CI === "true" || ba.argv[1].endsWith((0, _.normalize)("node_modules/.bin/eslint"))));
          }
          a.inferSingleRun = D;
        } }), CT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/parseSettings/warnAboutTSVersion.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(q, F, fe, Ee) {
            Ee === void 0 && (Ee = fe);
            var Se = Object.getOwnPropertyDescriptor(F, fe);
            (!Se || ("get" in Se ? !F.__esModule : Se.writable || Se.configurable)) && (Se = { enumerable: true, get: function() {
              return F[fe];
            } }), Object.defineProperty(q, Ee, Se);
          } : function(q, F, fe, Ee) {
            Ee === void 0 && (Ee = fe), q[Ee] = F[fe];
          }), D = a && a.__setModuleDefault || (Object.create ? function(q, F) {
            Object.defineProperty(q, "default", { enumerable: true, value: F });
          } : function(q, F) {
            q.default = F;
          }), T = a && a.__importStar || function(q) {
            if (q && q.__esModule)
              return q;
            var F = {};
            if (q != null)
              for (var fe in q)
                fe !== "default" && Object.prototype.hasOwnProperty.call(q, fe) && _(F, q, fe);
            return D(F, q), F;
          }, ae = a && a.__importDefault || function(q) {
            return q && q.__esModule ? q : { default: q };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.warnAboutTSVersion = void 0;
          var z = ae(af()), I = T(Di()), E = ">=3.3.1 <5.0.0", N = [], e = I.version, t3 = z.default.satisfies(e, [E].concat(N).join(" || ")), w = false;
          function s(q) {
            var F;
            if (!t3 && !w) {
              if (typeof ba > "u" ? false : (F = ba.stdout) === null || F === void 0 ? void 0 : F.isTTY) {
                let Ee = "=============", Se = [Ee, "WARNING: You are currently running a version of TypeScript which is not officially supported by @typescript-eslint/typescript-estree.", "You may find that it works just fine, or you may not.", `SUPPORTED TYPESCRIPT VERSIONS: ${E}`, `YOUR TYPESCRIPT VERSION: ${e}`, "Please only submit bug reports when using the officially supported version.", Ee];
                q.log(Se.join(`

`));
              }
              w = true;
            }
          }
          a.warnAboutTSVersion = s;
        } }), DT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/parseSettings/createParseSettings.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__importDefault || function(F) {
            return F && F.__esModule ? F : { default: F };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.createParseSettings = void 0;
          var D = _(Ns()), T = {}, ae = _(TT()), z = zc(), I = ST(), E = CT(), N = (0, D.default)("typescript-eslint:typescript-estree:parser:parseSettings:createParseSettings");
          function e(F) {
            let fe = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            var Ee, Se;
            let J = typeof fe.tsconfigRootDir == "string" ? fe.tsconfigRootDir : "/prettier-security-dirname-placeholder", se = { code: t3(F), comment: fe.comment === true, comments: [], createDefaultProgram: fe.createDefaultProgram === true, debugLevel: fe.debugLevel === true ? /* @__PURE__ */ new Set(["typescript-eslint"]) : Array.isArray(fe.debugLevel) ? new Set(fe.debugLevel) : /* @__PURE__ */ new Set(), errorOnTypeScriptSyntacticAndSemanticIssues: false, errorOnUnknownASTType: fe.errorOnUnknownASTType === true, EXPERIMENTAL_useSourceOfProjectReferenceRedirect: fe.EXPERIMENTAL_useSourceOfProjectReferenceRedirect === true, extraFileExtensions: Array.isArray(fe.extraFileExtensions) && fe.extraFileExtensions.every((Me) => typeof Me == "string") ? fe.extraFileExtensions : [], filePath: (0, z.ensureAbsolutePath)(typeof fe.filePath == "string" && fe.filePath !== "<input>" ? fe.filePath : w(fe.jsx), J), jsx: fe.jsx === true, loc: fe.loc === true, log: typeof fe.loggerFn == "function" ? fe.loggerFn : fe.loggerFn === false ? () => {
            } : console.log, moduleResolver: (Ee = fe.moduleResolver) !== null && Ee !== void 0 ? Ee : "", preserveNodeMaps: fe.preserveNodeMaps !== false, programs: Array.isArray(fe.programs) ? fe.programs : null, projects: [], range: fe.range === true, singleRun: (0, I.inferSingleRun)(fe), tokens: fe.tokens === true ? [] : null, tsconfigRootDir: J };
            if (se.debugLevel.size > 0) {
              let Me = [];
              se.debugLevel.has("typescript-eslint") && Me.push("typescript-eslint:*"), (se.debugLevel.has("eslint") || D.default.enabled("eslint:*,-eslint:code-path")) && Me.push("eslint:*,-eslint:code-path"), D.default.enable(Me.join(","));
            }
            if (Array.isArray(fe.programs)) {
              if (!fe.programs.length)
                throw new Error("You have set parserOptions.programs to an empty array. This will cause all files to not be found in existing programs. Either provide one or more existing TypeScript Program instances in the array, or remove the parserOptions.programs setting.");
              N("parserOptions.programs was provided, so parserOptions.project will be ignored.");
            }
            if (!se.programs) {
              let Me = ((Se = fe.projectFolderIgnoreList) !== null && Se !== void 0 ? Se : ["**/node_modules/**"]).reduce((Q, Be) => (typeof Be == "string" && Q.push(Be), Q), []).map((Q) => Q.startsWith("!") ? Q : `!${Q}`);
              se.projects = q(J, fe.project, Me);
            }
            return (0, E.warnAboutTSVersion)(se), se;
          }
          a.createParseSettings = e;
          function t3(F) {
            return typeof F != "string" ? String(F) : F;
          }
          function w(F) {
            return F ? "estree.tsx" : "estree.ts";
          }
          function s(F, fe) {
            return (0, z.getCanonicalFileName)((0, z.ensureAbsolutePath)(F, fe));
          }
          function q(F, fe, Ee) {
            let Se = [];
            if (typeof fe == "string")
              Se.push(fe);
            else if (Array.isArray(fe))
              for (let Q of fe)
                typeof Q == "string" && Se.push(Q);
            if (Se.length === 0)
              return [];
            let J = Se.filter((Q) => !(0, ae.default)(Q)), se = Se.filter((Q) => (0, ae.default)(Q)), Me = new Set(J.concat((0, T.sync)([...se, ...Ee], { cwd: F })).map((Q) => s(Q, F)));
            return N("parserOptions.project (excluding ignored) matched projects: %s", Me), Array.from(Me);
          }
        } }), xT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/semantic-or-syntactic-errors.js"(a) {
          "use strict";
          Jr(), Object.defineProperty(a, "__esModule", { value: true }), a.getFirstSemanticOrSyntacticError = void 0;
          var _ = Di();
          function D(z, I) {
            try {
              let E = T(z.getSyntacticDiagnostics(I));
              if (E.length)
                return ae(E[0]);
              let N = T(z.getSemanticDiagnostics(I));
              return N.length ? ae(N[0]) : void 0;
            } catch (E) {
              console.warn(`Warning From TSC: "${E.message}`);
              return;
            }
          }
          a.getFirstSemanticOrSyntacticError = D;
          function T(z) {
            return z.filter((I) => {
              switch (I.code) {
                case 1013:
                case 1014:
                case 1044:
                case 1045:
                case 1048:
                case 1049:
                case 1070:
                case 1071:
                case 1085:
                case 1090:
                case 1096:
                case 1097:
                case 1098:
                case 1099:
                case 1117:
                case 1121:
                case 1123:
                case 1141:
                case 1162:
                case 1164:
                case 1172:
                case 1173:
                case 1175:
                case 1176:
                case 1190:
                case 1196:
                case 1200:
                case 1206:
                case 1211:
                case 1242:
                case 1246:
                case 1255:
                case 1308:
                case 2364:
                case 2369:
                case 2452:
                case 2462:
                case 8017:
                case 17012:
                case 17013:
                  return true;
              }
              return false;
            });
          }
          function ae(z) {
            return Object.assign(Object.assign({}, z), { message: (0, _.flattenDiagnosticMessageText)(z.messageText, _.sys.newLine) });
          }
        } }), wT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/parser.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__importDefault || function(Be) {
            return Be && Be.__esModule ? Be : { default: Be };
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.clearParseAndGenerateServicesCalls = a.clearProgramCache = a.parseWithNodeMaps = a.parseAndGenerateServices = a.parse = void 0;
          var D = _(Ns()), T = dT(), ae = yy(), z = gT(), I = yT(), E = vT(), N = bT(), e = Fy(), t3 = DT(), w = xT(), s = (0, D.default)("typescript-eslint:typescript-estree:parser"), q = /* @__PURE__ */ new Map();
          function F() {
            q.clear();
          }
          a.clearProgramCache = F;
          function fe(Be, je) {
            return Be.programs && (0, e.useProvidedPrograms)(Be.programs, Be) || je && (0, E.createProjectProgram)(Be) || je && Be.createDefaultProgram && (0, z.createDefaultProgram)(Be) || (0, I.createIsolatedProgram)(Be);
          }
          function Ee(Be, je) {
            let { ast: V } = Se(Be, je, false);
            return V;
          }
          a.parse = Ee;
          function Se(Be, je, V) {
            let B = (0, t3.createParseSettings)(Be, je);
            if (je != null && je.errorOnTypeScriptSyntacticAndSemanticIssues)
              throw new Error('"errorOnTypeScriptSyntacticAndSemanticIssues" is only supported for parseAndGenerateServices()');
            let U = (0, N.createSourceFile)(B), { estree: m, astMaps: v } = (0, T.astConverter)(U, B, V);
            return { ast: m, esTreeNodeToTSNodeMap: v.esTreeNodeToTSNodeMap, tsNodeToESTreeNodeMap: v.tsNodeToESTreeNodeMap };
          }
          function J(Be, je) {
            return Se(Be, je, true);
          }
          a.parseWithNodeMaps = J;
          var se = {};
          function Me() {
            se = {};
          }
          a.clearParseAndGenerateServicesCalls = Me;
          function Q(Be, je) {
            var V, B;
            let U = (0, t3.createParseSettings)(Be, je);
            typeof je < "u" && typeof je.errorOnTypeScriptSyntacticAndSemanticIssues == "boolean" && je.errorOnTypeScriptSyntacticAndSemanticIssues && (U.errorOnTypeScriptSyntacticAndSemanticIssues = true), U.singleRun && !U.programs && ((V = U.projects) === null || V === void 0 ? void 0 : V.length) > 0 && (U.programs = { *[Symbol.iterator]() {
              for (let Je of U.projects) {
                let qe = q.get(Je);
                if (qe)
                  yield qe;
                else {
                  s("Detected single-run/CLI usage, creating Program once ahead of time for project: %s", Je);
                  let ge = (0, e.createProgramFromConfigFile)(Je);
                  q.set(Je, ge), yield ge;
                }
              }
            } });
            let m = U.programs != null || ((B = U.projects) === null || B === void 0 ? void 0 : B.length) > 0;
            U.singleRun && je.filePath && (se[je.filePath] = (se[je.filePath] || 0) + 1);
            let { ast: v, program: g } = U.singleRun && je.filePath && se[je.filePath] > 1 ? (0, I.createIsolatedProgram)(U) : fe(U, m), O = typeof U.preserveNodeMaps == "boolean" ? U.preserveNodeMaps : true, { estree: S, astMaps: te } = (0, T.astConverter)(v, U, O);
            if (g && U.errorOnTypeScriptSyntacticAndSemanticIssues) {
              let Je = (0, w.getFirstSemanticOrSyntacticError)(g, v);
              if (Je)
                throw (0, ae.convertError)(Je);
            }
            return { ast: S, services: { hasFullTypeInformation: m, program: g, esTreeNodeToTSNodeMap: te.esTreeNodeToTSNodeMap, tsNodeToESTreeNodeMap: te.tsNodeToESTreeNodeMap } };
          }
          a.parseAndGenerateServices = Q;
        } }), AT = Ur({ "node_modules/@typescript-eslint/typescript-estree/package.json"(a, _) {
          _.exports = { name: "@typescript-eslint/typescript-estree", version: "5.45.0", description: "A parser that converts TypeScript source code into an ESTree compatible form", main: "dist/index.js", types: "dist/index.d.ts", files: ["dist", "_ts3.4", "README.md", "LICENSE"], engines: { node: "^12.22.0 || ^14.17.0 || >=16.0.0" }, repository: { type: "git", url: "https://github.com/typescript-eslint/typescript-eslint.git", directory: "packages/typescript-estree" }, bugs: { url: "https://github.com/typescript-eslint/typescript-eslint/issues" }, license: "BSD-2-Clause", keywords: ["ast", "estree", "ecmascript", "javascript", "typescript", "parser", "syntax"], scripts: { build: "tsc -b tsconfig.build.json", postbuild: "downlevel-dts dist _ts3.4/dist", clean: "tsc -b tsconfig.build.json --clean", postclean: "rimraf dist && rimraf _ts3.4 && rimraf coverage", format: 'prettier --write "./**/*.{ts,mts,cts,tsx,js,mjs,cjs,jsx,json,md,css}" --ignore-path ../../.prettierignore', lint: "nx lint", test: "jest --coverage", typecheck: "tsc -p tsconfig.json --noEmit" }, dependencies: { "@typescript-eslint/types": "5.45.0", "@typescript-eslint/visitor-keys": "5.45.0", debug: "^4.3.4", globby: "^11.1.0", "is-glob": "^4.0.3", semver: "^7.3.7", tsutils: "^3.21.0" }, devDependencies: { "@babel/code-frame": "*", "@babel/parser": "*", "@types/babel__code-frame": "*", "@types/debug": "*", "@types/glob": "*", "@types/is-glob": "*", "@types/semver": "*", "@types/tmp": "*", "@typescript-eslint/shared-fixtures": "5.45.0", glob: "*", "jest-specific-snapshot": "*", "make-dir": "*", tmp: "*", typescript: "*" }, peerDependenciesMeta: { typescript: { optional: true } }, funding: { type: "opencollective", url: "https://opencollective.com/typescript-eslint" }, typesVersions: { "<3.8": { "*": ["_ts3.4/*"] } }, gitHead: "267da4e416f7de6892336db8a2360d7af702b73c" };
        } }), kT = Ur({ "node_modules/@typescript-eslint/typescript-estree/dist/index.js"(a) {
          "use strict";
          Jr();
          var _ = a && a.__createBinding || (Object.create ? function(e, t3, w, s) {
            s === void 0 && (s = w);
            var q = Object.getOwnPropertyDescriptor(t3, w);
            (!q || ("get" in q ? !t3.__esModule : q.writable || q.configurable)) && (q = { enumerable: true, get: function() {
              return t3[w];
            } }), Object.defineProperty(e, s, q);
          } : function(e, t3, w, s) {
            s === void 0 && (s = w), e[s] = t3[w];
          }), D = a && a.__exportStar || function(e, t3) {
            for (var w in e)
              w !== "default" && !Object.prototype.hasOwnProperty.call(t3, w) && _(t3, e, w);
          };
          Object.defineProperty(a, "__esModule", { value: true }), a.version = a.visitorKeys = a.typescriptVersionIsAtLeast = a.createProgram = a.clearCaches = a.simpleTraverse = a.clearProgramCache = a.parseWithNodeMaps = a.parseAndGenerateServices = a.parse = void 0;
          var T = wT();
          Object.defineProperty(a, "parse", { enumerable: true, get: function() {
            return T.parse;
          } }), Object.defineProperty(a, "parseAndGenerateServices", { enumerable: true, get: function() {
            return T.parseAndGenerateServices;
          } }), Object.defineProperty(a, "parseWithNodeMaps", { enumerable: true, get: function() {
            return T.parseWithNodeMaps;
          } }), Object.defineProperty(a, "clearProgramCache", { enumerable: true, get: function() {
            return T.clearProgramCache;
          } });
          var ae = Dy();
          Object.defineProperty(a, "simpleTraverse", { enumerable: true, get: function() {
            return ae.simpleTraverse;
          } }), D(kl(), a);
          var z = Jy();
          Object.defineProperty(a, "clearCaches", { enumerable: true, get: function() {
            return z.clearWatchCaches;
          } });
          var I = Fy();
          Object.defineProperty(a, "createProgram", { enumerable: true, get: function() {
            return I.createProgramFromConfigFile;
          } }), D(lf(), a);
          var E = of();
          Object.defineProperty(a, "typescriptVersionIsAtLeast", { enumerable: true, get: function() {
            return E.typescriptVersionIsAtLeast;
          } }), D(sf(), a);
          var N = Cy();
          Object.defineProperty(a, "visitorKeys", { enumerable: true, get: function() {
            return N.visitorKeys;
          } }), a.version = AT().version;
        } });
        Jr();
        var PT = Xg(), NT = qb(), IT = Qb(), OT = Yb(), MT = iE(), Gg = { loc: true, range: true, comment: true, jsx: true, tokens: true, loggerFn: false, project: [] };
        function LT(a) {
          let { message: _, lineNumber: D, column: T } = a;
          return typeof D != "number" ? a : PT(_, { start: { line: D, column: T + 1 } });
        }
        function RT(a, _) {
          let D = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, T = OT(a), ae = jT(a), { parseWithNodeMaps: z } = kT(), { result: I, error: E } = NT(() => z(T, Object.assign(Object.assign({}, Gg), {}, { jsx: ae })), () => z(T, Object.assign(Object.assign({}, Gg), {}, { jsx: !ae })));
          if (!I)
            throw LT(E);
          return D.originalText = a, D.tsParseResult = I, MT(I.ast, D);
        }
        function jT(a) {
          return new RegExp(["(?:^[^\"'`]*</)", "|", "(?:^[^/]{2}.*/>)"].join(""), "m").test(a);
        }
        By.exports = { parsers: { typescript: IT(RT) } };
      });
      return JT();
    });
  }
});

// node_modules/prettier/parser-angular.js
var require_parser_angular = __commonJS({
  "node_modules/prettier/parser-angular.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.angular = e();
      }
    })(function() {
      "use strict";
      var cr = (e, t3) => () => (t3 || e((t3 = { exports: {} }).exports, t3), t3.exports);
      var Br = cr((Mr, ar) => {
        var ze = Object.defineProperty, ur = Object.getOwnPropertyDescriptor, He = Object.getOwnPropertyNames, lr = Object.prototype.hasOwnProperty, Y = (e, t3) => function() {
          return e && (t3 = (0, e[He(e)[0]])(e = 0)), t3;
        }, q = (e, t3) => function() {
          return t3 || (0, e[He(e)[0]])((t3 = { exports: {} }).exports, t3), t3.exports;
        }, Xe = (e, t3) => {
          for (var r in t3)
            ze(e, r, { get: t3[r], enumerable: true });
        }, hr = (e, t3, r, n) => {
          if (t3 && typeof t3 == "object" || typeof t3 == "function")
            for (let s of He(t3))
              !lr.call(e, s) && s !== r && ze(e, s, { get: () => t3[s], enumerable: !(n = ur(t3, s)) || n.enumerable });
          return e;
        }, be = (e) => hr(ze({}, "__esModule", { value: true }), e), L = Y({ "<define:process>"() {
        } }), pr = q({ "src/utils/is-non-empty-array.js"(e, t3) {
          "use strict";
          L();
          function r(n) {
            return Array.isArray(n) && n.length > 0;
          }
          t3.exports = r;
        } }), dr = q({ "src/language-js/loc.js"(e, t3) {
          "use strict";
          L();
          var r = pr();
          function n(l) {
            var P, p;
            let x = l.range ? l.range[0] : l.start, C = (P = (p = l.declaration) === null || p === void 0 ? void 0 : p.decorators) !== null && P !== void 0 ? P : l.decorators;
            return r(C) ? Math.min(n(C[0]), x) : x;
          }
          function s(l) {
            return l.range ? l.range[1] : l.end;
          }
          function a(l, P) {
            let p = n(l);
            return Number.isInteger(p) && p === n(P);
          }
          function i(l, P) {
            let p = s(l);
            return Number.isInteger(p) && p === s(P);
          }
          function h(l, P) {
            return a(l, P) && i(l, P);
          }
          t3.exports = { locStart: n, locEnd: s, hasSameLocStart: a, hasSameLoc: h };
        } }), fr = q({ "node_modules/angular-estree-parser/node_modules/lines-and-columns/build/index.js"(e) {
          "use strict";
          L(), e.__esModule = true, e.LinesAndColumns = void 0;
          var t3 = `
`, r = "\r", n = function() {
            function s(a) {
              this.string = a;
              for (var i = [0], h = 0; h < a.length; )
                switch (a[h]) {
                  case t3:
                    h += t3.length, i.push(h);
                    break;
                  case r:
                    h += r.length, a[h] === t3 && (h += t3.length), i.push(h);
                    break;
                  default:
                    h++;
                    break;
                }
              this.offsets = i;
            }
            return s.prototype.locationForIndex = function(a) {
              if (a < 0 || a > this.string.length)
                return null;
              for (var i = 0, h = this.offsets; h[i + 1] <= a; )
                i++;
              var l = a - h[i];
              return { line: i, column: l };
            }, s.prototype.indexForLocation = function(a) {
              var i = a.line, h = a.column;
              return i < 0 || i >= this.offsets.length || h < 0 || h > this.lengthOfLine(i) ? null : this.offsets[i] + h;
            }, s.prototype.lengthOfLine = function(a) {
              var i = this.offsets[a], h = a === this.offsets.length - 1 ? this.string.length : this.offsets[a + 1];
              return h - i;
            }, s;
          }();
          e.LinesAndColumns = n, e.default = n;
        } }), gr = q({ "node_modules/angular-estree-parser/lib/context.js"(e) {
          "use strict";
          L(), Object.defineProperty(e, "__esModule", { value: true }), e.Context = void 0;
          var t3 = fr(), r = class {
            constructor(s) {
              this.text = s, this.locator = new n(this.text);
            }
          };
          e.Context = r;
          var n = class {
            constructor(s) {
              this._lineAndColumn = new t3.default(s);
            }
            locationForIndex(s) {
              let { line: a, column: i } = this._lineAndColumn.locationForIndex(s);
              return { line: a + 1, column: i };
            }
          };
        } }), Je = {};
        Xe(Je, { AST: () => k, ASTWithName: () => W, ASTWithSource: () => G, AbsoluteSourceSpan: () => U, AstMemoryEfficientTransformer: () => Ct, AstTransformer: () => Pt, Binary: () => B, BindingPipe: () => fe, BoundElementProperty: () => It, Chain: () => oe, Conditional: () => ce, EmptyExpr: () => K, ExpressionBinding: () => Ze, FunctionCall: () => Pe, ImplicitReceiver: () => Oe, Interpolation: () => me, KeyedRead: () => he, KeyedWrite: () => de, LiteralArray: () => ge, LiteralMap: () => ve, LiteralPrimitive: () => $2, MethodCall: () => ye, NonNullAssert: () => Se, ParseSpan: () => V, ParsedEvent: () => At, ParsedProperty: () => Et, ParsedPropertyType: () => se, ParsedVariable: () => _t, ParserError: () => ae, PrefixNot: () => xe, PropertyRead: () => ne, PropertyWrite: () => ue, Quote: () => Le, RecursiveAstVisitor: () => et, SafeKeyedRead: () => pe, SafeMethodCall: () => we, SafePropertyRead: () => le, ThisReceiver: () => Ye, Unary: () => F, VariableBinding: () => Re });
        var ae, V, k, W, Le, K, Oe, Ye, oe, ce, ne, ue, le, he, pe, de, fe, $2, ge, ve, me, B, F, xe, Se, ye, we, Pe, U, G, Re, Ze, et, Pt, Ct, Et, se, At, _t, It, tt = Y({ "node_modules/@angular/compiler/esm2015/src/expression_parser/ast.js"() {
          L(), ae = class {
            constructor(e, t3, r, n) {
              this.input = t3, this.errLocation = r, this.ctxLocation = n, this.message = `Parser Error: ${e} ${r} [${t3}] in ${n}`;
            }
          }, V = class {
            constructor(e, t3) {
              this.start = e, this.end = t3;
            }
            toAbsolute(e) {
              return new U(e + this.start, e + this.end);
            }
          }, k = class {
            constructor(e, t3) {
              this.span = e, this.sourceSpan = t3;
            }
            toString() {
              return "AST";
            }
          }, W = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.nameSpan = r;
            }
          }, Le = class extends k {
            constructor(e, t3, r, n, s) {
              super(e, t3), this.prefix = r, this.uninterpretedExpression = n, this.location = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitQuote(this, t3);
            }
            toString() {
              return "Quote";
            }
          }, K = class extends k {
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
            }
          }, Oe = class extends k {
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitImplicitReceiver(this, t3);
            }
          }, Ye = class extends Oe {
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              var r;
              return (r = e.visitThisReceiver) === null || r === void 0 ? void 0 : r.call(e, this, t3);
            }
          }, oe = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.expressions = r;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitChain(this, t3);
            }
          }, ce = class extends k {
            constructor(e, t3, r, n, s) {
              super(e, t3), this.condition = r, this.trueExp = n, this.falseExp = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitConditional(this, t3);
            }
          }, ne = class extends W {
            constructor(e, t3, r, n, s) {
              super(e, t3, r), this.receiver = n, this.name = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitPropertyRead(this, t3);
            }
          }, ue = class extends W {
            constructor(e, t3, r, n, s, a) {
              super(e, t3, r), this.receiver = n, this.name = s, this.value = a;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitPropertyWrite(this, t3);
            }
          }, le = class extends W {
            constructor(e, t3, r, n, s) {
              super(e, t3, r), this.receiver = n, this.name = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitSafePropertyRead(this, t3);
            }
          }, he = class extends k {
            constructor(e, t3, r, n) {
              super(e, t3), this.receiver = r, this.key = n;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitKeyedRead(this, t3);
            }
          }, pe = class extends k {
            constructor(e, t3, r, n) {
              super(e, t3), this.receiver = r, this.key = n;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitSafeKeyedRead(this, t3);
            }
          }, de = class extends k {
            constructor(e, t3, r, n, s) {
              super(e, t3), this.receiver = r, this.key = n, this.value = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitKeyedWrite(this, t3);
            }
          }, fe = class extends W {
            constructor(e, t3, r, n, s, a) {
              super(e, t3, a), this.exp = r, this.name = n, this.args = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitPipe(this, t3);
            }
          }, $2 = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.value = r;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitLiteralPrimitive(this, t3);
            }
          }, ge = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.expressions = r;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitLiteralArray(this, t3);
            }
          }, ve = class extends k {
            constructor(e, t3, r, n) {
              super(e, t3), this.keys = r, this.values = n;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitLiteralMap(this, t3);
            }
          }, me = class extends k {
            constructor(e, t3, r, n) {
              super(e, t3), this.strings = r, this.expressions = n;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitInterpolation(this, t3);
            }
          }, B = class extends k {
            constructor(e, t3, r, n, s) {
              super(e, t3), this.operation = r, this.left = n, this.right = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitBinary(this, t3);
            }
          }, F = class extends B {
            constructor(e, t3, r, n, s, a, i) {
              super(e, t3, s, a, i), this.operator = r, this.expr = n;
            }
            static createMinus(e, t3, r) {
              return new F(e, t3, "-", r, "-", new $2(e, t3, 0), r);
            }
            static createPlus(e, t3, r) {
              return new F(e, t3, "+", r, "-", r, new $2(e, t3, 0));
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitUnary !== void 0 ? e.visitUnary(this, t3) : e.visitBinary(this, t3);
            }
          }, xe = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.expression = r;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitPrefixNot(this, t3);
            }
          }, Se = class extends k {
            constructor(e, t3, r) {
              super(e, t3), this.expression = r;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitNonNullAssert(this, t3);
            }
          }, ye = class extends W {
            constructor(e, t3, r, n, s, a, i) {
              super(e, t3, r), this.receiver = n, this.name = s, this.args = a, this.argumentSpan = i;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitMethodCall(this, t3);
            }
          }, we = class extends W {
            constructor(e, t3, r, n, s, a, i) {
              super(e, t3, r), this.receiver = n, this.name = s, this.args = a, this.argumentSpan = i;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitSafeMethodCall(this, t3);
            }
          }, Pe = class extends k {
            constructor(e, t3, r, n) {
              super(e, t3), this.target = r, this.args = n;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitFunctionCall(this, t3);
            }
          }, U = class {
            constructor(e, t3) {
              this.start = e, this.end = t3;
            }
          }, G = class extends k {
            constructor(e, t3, r, n, s) {
              super(new V(0, t3 === null ? 0 : t3.length), new U(n, t3 === null ? n : n + t3.length)), this.ast = e, this.source = t3, this.location = r, this.errors = s;
            }
            visit(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              return e.visitASTWithSource ? e.visitASTWithSource(this, t3) : this.ast.visit(e, t3);
            }
            toString() {
              return `${this.source} in ${this.location}`;
            }
          }, Re = class {
            constructor(e, t3, r) {
              this.sourceSpan = e, this.key = t3, this.value = r;
            }
          }, Ze = class {
            constructor(e, t3, r) {
              this.sourceSpan = e, this.key = t3, this.value = r;
            }
          }, et = class {
            visit(e, t3) {
              e.visit(this, t3);
            }
            visitUnary(e, t3) {
              this.visit(e.expr, t3);
            }
            visitBinary(e, t3) {
              this.visit(e.left, t3), this.visit(e.right, t3);
            }
            visitChain(e, t3) {
              this.visitAll(e.expressions, t3);
            }
            visitConditional(e, t3) {
              this.visit(e.condition, t3), this.visit(e.trueExp, t3), this.visit(e.falseExp, t3);
            }
            visitPipe(e, t3) {
              this.visit(e.exp, t3), this.visitAll(e.args, t3);
            }
            visitFunctionCall(e, t3) {
              e.target && this.visit(e.target, t3), this.visitAll(e.args, t3);
            }
            visitImplicitReceiver(e, t3) {
            }
            visitThisReceiver(e, t3) {
            }
            visitInterpolation(e, t3) {
              this.visitAll(e.expressions, t3);
            }
            visitKeyedRead(e, t3) {
              this.visit(e.receiver, t3), this.visit(e.key, t3);
            }
            visitKeyedWrite(e, t3) {
              this.visit(e.receiver, t3), this.visit(e.key, t3), this.visit(e.value, t3);
            }
            visitLiteralArray(e, t3) {
              this.visitAll(e.expressions, t3);
            }
            visitLiteralMap(e, t3) {
              this.visitAll(e.values, t3);
            }
            visitLiteralPrimitive(e, t3) {
            }
            visitMethodCall(e, t3) {
              this.visit(e.receiver, t3), this.visitAll(e.args, t3);
            }
            visitPrefixNot(e, t3) {
              this.visit(e.expression, t3);
            }
            visitNonNullAssert(e, t3) {
              this.visit(e.expression, t3);
            }
            visitPropertyRead(e, t3) {
              this.visit(e.receiver, t3);
            }
            visitPropertyWrite(e, t3) {
              this.visit(e.receiver, t3), this.visit(e.value, t3);
            }
            visitSafePropertyRead(e, t3) {
              this.visit(e.receiver, t3);
            }
            visitSafeMethodCall(e, t3) {
              this.visit(e.receiver, t3), this.visitAll(e.args, t3);
            }
            visitSafeKeyedRead(e, t3) {
              this.visit(e.receiver, t3), this.visit(e.key, t3);
            }
            visitQuote(e, t3) {
            }
            visitAll(e, t3) {
              for (let r of e)
                this.visit(r, t3);
            }
          }, Pt = class {
            visitImplicitReceiver(e, t3) {
              return e;
            }
            visitThisReceiver(e, t3) {
              return e;
            }
            visitInterpolation(e, t3) {
              return new me(e.span, e.sourceSpan, e.strings, this.visitAll(e.expressions));
            }
            visitLiteralPrimitive(e, t3) {
              return new $2(e.span, e.sourceSpan, e.value);
            }
            visitPropertyRead(e, t3) {
              return new ne(e.span, e.sourceSpan, e.nameSpan, e.receiver.visit(this), e.name);
            }
            visitPropertyWrite(e, t3) {
              return new ue(e.span, e.sourceSpan, e.nameSpan, e.receiver.visit(this), e.name, e.value.visit(this));
            }
            visitSafePropertyRead(e, t3) {
              return new le(e.span, e.sourceSpan, e.nameSpan, e.receiver.visit(this), e.name);
            }
            visitMethodCall(e, t3) {
              return new ye(e.span, e.sourceSpan, e.nameSpan, e.receiver.visit(this), e.name, this.visitAll(e.args), e.argumentSpan);
            }
            visitSafeMethodCall(e, t3) {
              return new we(e.span, e.sourceSpan, e.nameSpan, e.receiver.visit(this), e.name, this.visitAll(e.args), e.argumentSpan);
            }
            visitFunctionCall(e, t3) {
              return new Pe(e.span, e.sourceSpan, e.target.visit(this), this.visitAll(e.args));
            }
            visitLiteralArray(e, t3) {
              return new ge(e.span, e.sourceSpan, this.visitAll(e.expressions));
            }
            visitLiteralMap(e, t3) {
              return new ve(e.span, e.sourceSpan, e.keys, this.visitAll(e.values));
            }
            visitUnary(e, t3) {
              switch (e.operator) {
                case "+":
                  return F.createPlus(e.span, e.sourceSpan, e.expr.visit(this));
                case "-":
                  return F.createMinus(e.span, e.sourceSpan, e.expr.visit(this));
                default:
                  throw new Error(`Unknown unary operator ${e.operator}`);
              }
            }
            visitBinary(e, t3) {
              return new B(e.span, e.sourceSpan, e.operation, e.left.visit(this), e.right.visit(this));
            }
            visitPrefixNot(e, t3) {
              return new xe(e.span, e.sourceSpan, e.expression.visit(this));
            }
            visitNonNullAssert(e, t3) {
              return new Se(e.span, e.sourceSpan, e.expression.visit(this));
            }
            visitConditional(e, t3) {
              return new ce(e.span, e.sourceSpan, e.condition.visit(this), e.trueExp.visit(this), e.falseExp.visit(this));
            }
            visitPipe(e, t3) {
              return new fe(e.span, e.sourceSpan, e.exp.visit(this), e.name, this.visitAll(e.args), e.nameSpan);
            }
            visitKeyedRead(e, t3) {
              return new he(e.span, e.sourceSpan, e.receiver.visit(this), e.key.visit(this));
            }
            visitKeyedWrite(e, t3) {
              return new de(e.span, e.sourceSpan, e.receiver.visit(this), e.key.visit(this), e.value.visit(this));
            }
            visitAll(e) {
              let t3 = [];
              for (let r = 0; r < e.length; ++r)
                t3[r] = e[r].visit(this);
              return t3;
            }
            visitChain(e, t3) {
              return new oe(e.span, e.sourceSpan, this.visitAll(e.expressions));
            }
            visitQuote(e, t3) {
              return new Le(e.span, e.sourceSpan, e.prefix, e.uninterpretedExpression, e.location);
            }
            visitSafeKeyedRead(e, t3) {
              return new pe(e.span, e.sourceSpan, e.receiver.visit(this), e.key.visit(this));
            }
          }, Ct = class {
            visitImplicitReceiver(e, t3) {
              return e;
            }
            visitThisReceiver(e, t3) {
              return e;
            }
            visitInterpolation(e, t3) {
              let r = this.visitAll(e.expressions);
              return r !== e.expressions ? new me(e.span, e.sourceSpan, e.strings, r) : e;
            }
            visitLiteralPrimitive(e, t3) {
              return e;
            }
            visitPropertyRead(e, t3) {
              let r = e.receiver.visit(this);
              return r !== e.receiver ? new ne(e.span, e.sourceSpan, e.nameSpan, r, e.name) : e;
            }
            visitPropertyWrite(e, t3) {
              let r = e.receiver.visit(this), n = e.value.visit(this);
              return r !== e.receiver || n !== e.value ? new ue(e.span, e.sourceSpan, e.nameSpan, r, e.name, n) : e;
            }
            visitSafePropertyRead(e, t3) {
              let r = e.receiver.visit(this);
              return r !== e.receiver ? new le(e.span, e.sourceSpan, e.nameSpan, r, e.name) : e;
            }
            visitMethodCall(e, t3) {
              let r = e.receiver.visit(this), n = this.visitAll(e.args);
              return r !== e.receiver || n !== e.args ? new ye(e.span, e.sourceSpan, e.nameSpan, r, e.name, n, e.argumentSpan) : e;
            }
            visitSafeMethodCall(e, t3) {
              let r = e.receiver.visit(this), n = this.visitAll(e.args);
              return r !== e.receiver || n !== e.args ? new we(e.span, e.sourceSpan, e.nameSpan, r, e.name, n, e.argumentSpan) : e;
            }
            visitFunctionCall(e, t3) {
              let r = e.target && e.target.visit(this), n = this.visitAll(e.args);
              return r !== e.target || n !== e.args ? new Pe(e.span, e.sourceSpan, r, n) : e;
            }
            visitLiteralArray(e, t3) {
              let r = this.visitAll(e.expressions);
              return r !== e.expressions ? new ge(e.span, e.sourceSpan, r) : e;
            }
            visitLiteralMap(e, t3) {
              let r = this.visitAll(e.values);
              return r !== e.values ? new ve(e.span, e.sourceSpan, e.keys, r) : e;
            }
            visitUnary(e, t3) {
              let r = e.expr.visit(this);
              if (r !== e.expr)
                switch (e.operator) {
                  case "+":
                    return F.createPlus(e.span, e.sourceSpan, r);
                  case "-":
                    return F.createMinus(e.span, e.sourceSpan, r);
                  default:
                    throw new Error(`Unknown unary operator ${e.operator}`);
                }
              return e;
            }
            visitBinary(e, t3) {
              let r = e.left.visit(this), n = e.right.visit(this);
              return r !== e.left || n !== e.right ? new B(e.span, e.sourceSpan, e.operation, r, n) : e;
            }
            visitPrefixNot(e, t3) {
              let r = e.expression.visit(this);
              return r !== e.expression ? new xe(e.span, e.sourceSpan, r) : e;
            }
            visitNonNullAssert(e, t3) {
              let r = e.expression.visit(this);
              return r !== e.expression ? new Se(e.span, e.sourceSpan, r) : e;
            }
            visitConditional(e, t3) {
              let r = e.condition.visit(this), n = e.trueExp.visit(this), s = e.falseExp.visit(this);
              return r !== e.condition || n !== e.trueExp || s !== e.falseExp ? new ce(e.span, e.sourceSpan, r, n, s) : e;
            }
            visitPipe(e, t3) {
              let r = e.exp.visit(this), n = this.visitAll(e.args);
              return r !== e.exp || n !== e.args ? new fe(e.span, e.sourceSpan, r, e.name, n, e.nameSpan) : e;
            }
            visitKeyedRead(e, t3) {
              let r = e.receiver.visit(this), n = e.key.visit(this);
              return r !== e.receiver || n !== e.key ? new he(e.span, e.sourceSpan, r, n) : e;
            }
            visitKeyedWrite(e, t3) {
              let r = e.receiver.visit(this), n = e.key.visit(this), s = e.value.visit(this);
              return r !== e.receiver || n !== e.key || s !== e.value ? new de(e.span, e.sourceSpan, r, n, s) : e;
            }
            visitAll(e) {
              let t3 = [], r = false;
              for (let n = 0; n < e.length; ++n) {
                let s = e[n], a = s.visit(this);
                t3[n] = a, r = r || a !== s;
              }
              return r ? t3 : e;
            }
            visitChain(e, t3) {
              let r = this.visitAll(e.expressions);
              return r !== e.expressions ? new oe(e.span, e.sourceSpan, r) : e;
            }
            visitQuote(e, t3) {
              return e;
            }
            visitSafeKeyedRead(e, t3) {
              let r = e.receiver.visit(this), n = e.key.visit(this);
              return r !== e.receiver || n !== e.key ? new pe(e.span, e.sourceSpan, r, n) : e;
            }
          }, Et = class {
            constructor(e, t3, r, n, s, a) {
              this.name = e, this.expression = t3, this.type = r, this.sourceSpan = n, this.keySpan = s, this.valueSpan = a, this.isLiteral = this.type === se.LITERAL_ATTR, this.isAnimation = this.type === se.ANIMATION;
            }
          }, function(e) {
            e[e.DEFAULT = 0] = "DEFAULT", e[e.LITERAL_ATTR = 1] = "LITERAL_ATTR", e[e.ANIMATION = 2] = "ANIMATION";
          }(se || (se = {})), At = class {
            constructor(e, t3, r, n, s, a, i) {
              this.name = e, this.targetOrPhase = t3, this.type = r, this.handler = n, this.sourceSpan = s, this.handlerSpan = a, this.keySpan = i;
            }
          }, _t = class {
            constructor(e, t3, r, n, s) {
              this.name = e, this.value = t3, this.sourceSpan = r, this.keySpan = n, this.valueSpan = s;
            }
          }, It = class {
            constructor(e, t3, r, n, s, a, i, h) {
              this.name = e, this.type = t3, this.securityContext = r, this.value = n, this.unit = s, this.sourceSpan = a, this.keySpan = i, this.valueSpan = h;
            }
          };
        } });
        function vr(e) {
          return e >= rt && e <= nt || e == dt;
        }
        function Q(e) {
          return Mt <= e && e <= jt;
        }
        function mr(e) {
          return e >= ht && e <= pt || e >= ut && e <= lt;
        }
        function mt(e) {
          return e === at || e === st || e === Xt;
        }
        var Ce, rt, Ot, kt, Nt, bt, nt, Lt, st, Rt, it2, Tt, je, at, Ee, z, $t, ot, ee, ct, H, Te, X, te, Bt, ie, Kt, Fe, Mt, jt, ut, Ft, lt, Ae, Ut, re, Wt, Be, ht, Gt, Vt, qt, Qt, Dt, zt, Ht, pt, $e, Ue, _e, dt, Xt, Jt = Y({ "node_modules/@angular/compiler/esm2015/src/chars.js"() {
          L(), Ce = 0, rt = 9, Ot = 10, kt = 11, Nt = 12, bt = 13, nt = 32, Lt = 33, st = 34, Rt = 35, it2 = 36, Tt = 37, je = 38, at = 39, Ee = 40, z = 41, $t = 42, ot = 43, ee = 44, ct = 45, H = 46, Te = 47, X = 58, te = 59, Bt = 60, ie = 61, Kt = 62, Fe = 63, Mt = 48, jt = 57, ut = 65, Ft = 69, lt = 90, Ae = 91, Ut = 92, re = 93, Wt = 94, Be = 95, ht = 97, Gt = 101, Vt = 102, qt = 110, Qt = 114, Dt = 116, zt = 117, Ht = 118, pt = 122, $e = 123, Ue = 124, _e = 125, dt = 160, Xt = 96;
        } }), Yt = {};
        Xe(Yt, { EOF: () => Ie, Lexer: () => er, Token: () => M, TokenType: () => S, isIdentifier: () => Zt });
        function xt(e, t3, r) {
          return new M(e, t3, S.Character, r, String.fromCharCode(r));
        }
        function xr(e, t3, r) {
          return new M(e, t3, S.Identifier, 0, r);
        }
        function Sr(e, t3, r) {
          return new M(e, t3, S.PrivateIdentifier, 0, r);
        }
        function yr(e, t3, r) {
          return new M(e, t3, S.Keyword, 0, r);
        }
        function Ke(e, t3, r) {
          return new M(e, t3, S.Operator, 0, r);
        }
        function wr(e, t3, r) {
          return new M(e, t3, S.String, 0, r);
        }
        function Pr(e, t3, r) {
          return new M(e, t3, S.Number, r, "");
        }
        function Cr(e, t3, r) {
          return new M(e, t3, S.Error, 0, r);
        }
        function We(e) {
          return ht <= e && e <= pt || ut <= e && e <= lt || e == Be || e == it2;
        }
        function Zt(e) {
          if (e.length == 0)
            return false;
          let t3 = new Ve(e);
          if (!We(t3.peek))
            return false;
          for (t3.advance(); t3.peek !== Ce; ) {
            if (!Ge(t3.peek))
              return false;
            t3.advance();
          }
          return true;
        }
        function Ge(e) {
          return mr(e) || Q(e) || e == Be || e == it2;
        }
        function Er(e) {
          return e == Gt || e == Ft;
        }
        function Ar(e) {
          return e == ct || e == ot;
        }
        function _r(e) {
          switch (e) {
            case qt:
              return Ot;
            case Vt:
              return Nt;
            case Qt:
              return bt;
            case Dt:
              return rt;
            case Ht:
              return kt;
            default:
              return e;
          }
        }
        function Ir(e) {
          let t3 = parseInt(e);
          if (isNaN(t3))
            throw new Error("Invalid integer literal when parsing " + e);
          return t3;
        }
        var S, St, er, M, Ie, Ve, tr = Y({ "node_modules/@angular/compiler/esm2015/src/expression_parser/lexer.js"() {
          L(), Jt(), function(e) {
            e[e.Character = 0] = "Character", e[e.Identifier = 1] = "Identifier", e[e.PrivateIdentifier = 2] = "PrivateIdentifier", e[e.Keyword = 3] = "Keyword", e[e.String = 4] = "String", e[e.Operator = 5] = "Operator", e[e.Number = 6] = "Number", e[e.Error = 7] = "Error";
          }(S || (S = {})), St = ["var", "let", "as", "null", "undefined", "true", "false", "if", "else", "this"], er = class {
            tokenize(e) {
              let t3 = new Ve(e), r = [], n = t3.scanToken();
              for (; n != null; )
                r.push(n), n = t3.scanToken();
              return r;
            }
          }, M = class {
            constructor(e, t3, r, n, s) {
              this.index = e, this.end = t3, this.type = r, this.numValue = n, this.strValue = s;
            }
            isCharacter(e) {
              return this.type == S.Character && this.numValue == e;
            }
            isNumber() {
              return this.type == S.Number;
            }
            isString() {
              return this.type == S.String;
            }
            isOperator(e) {
              return this.type == S.Operator && this.strValue == e;
            }
            isIdentifier() {
              return this.type == S.Identifier;
            }
            isPrivateIdentifier() {
              return this.type == S.PrivateIdentifier;
            }
            isKeyword() {
              return this.type == S.Keyword;
            }
            isKeywordLet() {
              return this.type == S.Keyword && this.strValue == "let";
            }
            isKeywordAs() {
              return this.type == S.Keyword && this.strValue == "as";
            }
            isKeywordNull() {
              return this.type == S.Keyword && this.strValue == "null";
            }
            isKeywordUndefined() {
              return this.type == S.Keyword && this.strValue == "undefined";
            }
            isKeywordTrue() {
              return this.type == S.Keyword && this.strValue == "true";
            }
            isKeywordFalse() {
              return this.type == S.Keyword && this.strValue == "false";
            }
            isKeywordThis() {
              return this.type == S.Keyword && this.strValue == "this";
            }
            isError() {
              return this.type == S.Error;
            }
            toNumber() {
              return this.type == S.Number ? this.numValue : -1;
            }
            toString() {
              switch (this.type) {
                case S.Character:
                case S.Identifier:
                case S.Keyword:
                case S.Operator:
                case S.PrivateIdentifier:
                case S.String:
                case S.Error:
                  return this.strValue;
                case S.Number:
                  return this.numValue.toString();
                default:
                  return null;
              }
            }
          }, Ie = new M(-1, -1, S.Character, 0, ""), Ve = class {
            constructor(e) {
              this.input = e, this.peek = 0, this.index = -1, this.length = e.length, this.advance();
            }
            advance() {
              this.peek = ++this.index >= this.length ? Ce : this.input.charCodeAt(this.index);
            }
            scanToken() {
              let e = this.input, t3 = this.length, r = this.peek, n = this.index;
              for (; r <= nt; )
                if (++n >= t3) {
                  r = Ce;
                  break;
                } else
                  r = e.charCodeAt(n);
              if (this.peek = r, this.index = n, n >= t3)
                return null;
              if (We(r))
                return this.scanIdentifier();
              if (Q(r))
                return this.scanNumber(n);
              let s = n;
              switch (r) {
                case H:
                  return this.advance(), Q(this.peek) ? this.scanNumber(s) : xt(s, this.index, H);
                case Ee:
                case z:
                case $e:
                case _e:
                case Ae:
                case re:
                case ee:
                case X:
                case te:
                  return this.scanCharacter(s, r);
                case at:
                case st:
                  return this.scanString();
                case Rt:
                  return this.scanPrivateIdentifier();
                case ot:
                case ct:
                case $t:
                case Te:
                case Tt:
                case Wt:
                  return this.scanOperator(s, String.fromCharCode(r));
                case Fe:
                  return this.scanQuestion(s);
                case Bt:
                case Kt:
                  return this.scanComplexOperator(s, String.fromCharCode(r), ie, "=");
                case Lt:
                case ie:
                  return this.scanComplexOperator(s, String.fromCharCode(r), ie, "=", ie, "=");
                case je:
                  return this.scanComplexOperator(s, "&", je, "&");
                case Ue:
                  return this.scanComplexOperator(s, "|", Ue, "|");
                case dt:
                  for (; vr(this.peek); )
                    this.advance();
                  return this.scanToken();
              }
              return this.advance(), this.error(`Unexpected character [${String.fromCharCode(r)}]`, 0);
            }
            scanCharacter(e, t3) {
              return this.advance(), xt(e, this.index, t3);
            }
            scanOperator(e, t3) {
              return this.advance(), Ke(e, this.index, t3);
            }
            scanComplexOperator(e, t3, r, n, s, a) {
              this.advance();
              let i = t3;
              return this.peek == r && (this.advance(), i += n), s != null && this.peek == s && (this.advance(), i += a), Ke(e, this.index, i);
            }
            scanIdentifier() {
              let e = this.index;
              for (this.advance(); Ge(this.peek); )
                this.advance();
              let t3 = this.input.substring(e, this.index);
              return St.indexOf(t3) > -1 ? yr(e, this.index, t3) : xr(e, this.index, t3);
            }
            scanPrivateIdentifier() {
              let e = this.index;
              if (this.advance(), !We(this.peek))
                return this.error("Invalid character [#]", -1);
              for (; Ge(this.peek); )
                this.advance();
              let t3 = this.input.substring(e, this.index);
              return Sr(e, this.index, t3);
            }
            scanNumber(e) {
              let t3 = this.index === e, r = false;
              for (this.advance(); ; ) {
                if (!Q(this.peek))
                  if (this.peek === Be) {
                    if (!Q(this.input.charCodeAt(this.index - 1)) || !Q(this.input.charCodeAt(this.index + 1)))
                      return this.error("Invalid numeric separator", 0);
                    r = true;
                  } else if (this.peek === H)
                    t3 = false;
                  else if (Er(this.peek)) {
                    if (this.advance(), Ar(this.peek) && this.advance(), !Q(this.peek))
                      return this.error("Invalid exponent", -1);
                    t3 = false;
                  } else
                    break;
                this.advance();
              }
              let n = this.input.substring(e, this.index);
              r && (n = n.replace(/_/g, ""));
              let s = t3 ? Ir(n) : parseFloat(n);
              return Pr(e, this.index, s);
            }
            scanString() {
              let e = this.index, t3 = this.peek;
              this.advance();
              let r = "", n = this.index, s = this.input;
              for (; this.peek != t3; )
                if (this.peek == Ut) {
                  r += s.substring(n, this.index), this.advance();
                  let i;
                  if (this.peek = this.peek, this.peek == zt) {
                    let h = s.substring(this.index + 1, this.index + 5);
                    if (/^[0-9a-f]+$/i.test(h))
                      i = parseInt(h, 16);
                    else
                      return this.error(`Invalid unicode escape [\\u${h}]`, 0);
                    for (let l = 0; l < 5; l++)
                      this.advance();
                  } else
                    i = _r(this.peek), this.advance();
                  r += String.fromCharCode(i), n = this.index;
                } else {
                  if (this.peek == Ce)
                    return this.error("Unterminated quote", 0);
                  this.advance();
                }
              let a = s.substring(n, this.index);
              return this.advance(), wr(e, this.index, r + a);
            }
            scanQuestion(e) {
              this.advance();
              let t3 = "?";
              return (this.peek === Fe || this.peek === H) && (t3 += this.peek === H ? "." : "?", this.advance()), Ke(e, this.index, t3);
            }
            error(e, t3) {
              let r = this.index + t3;
              return Cr(r, this.index, `Lexer Error: ${e} at column ${r} in expression [${this.input}]`);
            }
          };
        } });
        function Or(e, t3) {
          if (t3 != null && !(Array.isArray(t3) && t3.length == 2))
            throw new Error(`Expected '${e}' to be an array, [start, end].`);
          if (t3 != null) {
            let r = t3[0], n = t3[1];
            rr.forEach((s) => {
              if (s.test(r) || s.test(n))
                throw new Error(`['${r}', '${n}'] contains unusable interpolation symbol.`);
            });
          }
        }
        var rr, kr = Y({ "node_modules/@angular/compiler/esm2015/src/assertions.js"() {
          L(), rr = [/^\s*$/, /[<>]/, /^[{}]$/, /&(#|[a-z])/i, /^\/\//];
        } }), Me, J, Nr = Y({ "node_modules/@angular/compiler/esm2015/src/ml_parser/interpolation_config.js"() {
          L(), kr(), Me = class {
            constructor(e, t3) {
              this.start = e, this.end = t3;
            }
            static fromArray(e) {
              return e ? (Or("interpolation", e), new Me(e[0], e[1])) : J;
            }
          }, J = new Me("{{", "}}");
        } }), nr = {};
        Xe(nr, { IvyParser: () => sr, Parser: () => De, SplitInterpolation: () => qe, TemplateBindingParseResult: () => Qe, _ParseAST: () => D });
        var qe, Qe, De, sr, Z, D, yt, wt, br = Y({ "node_modules/@angular/compiler/esm2015/src/expression_parser/parser.js"() {
          L(), Jt(), Nr(), tt(), tr(), qe = class {
            constructor(e, t3, r) {
              this.strings = e, this.expressions = t3, this.offsets = r;
            }
          }, Qe = class {
            constructor(e, t3, r) {
              this.templateBindings = e, this.warnings = t3, this.errors = r;
            }
          }, De = class {
            constructor(e) {
              this._lexer = e, this.errors = [], this.simpleExpressionChecker = yt;
            }
            parseAction(e, t3, r) {
              let n = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : J;
              this._checkNoInterpolation(e, t3, n);
              let s = this._stripComments(e), a = this._lexer.tokenize(this._stripComments(e)), i = new D(e, t3, r, a, s.length, true, this.errors, e.length - s.length).parseChain();
              return new G(i, e, t3, r, this.errors);
            }
            parseBinding(e, t3, r) {
              let n = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : J, s = this._parseBindingAst(e, t3, r, n);
              return new G(s, e, t3, r, this.errors);
            }
            checkSimpleExpression(e) {
              let t3 = new this.simpleExpressionChecker();
              return e.visit(t3), t3.errors;
            }
            parseSimpleBinding(e, t3, r) {
              let n = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : J, s = this._parseBindingAst(e, t3, r, n), a = this.checkSimpleExpression(s);
              return a.length > 0 && this._reportError(`Host binding expression cannot contain ${a.join(" ")}`, e, t3), new G(s, e, t3, r, this.errors);
            }
            _reportError(e, t3, r, n) {
              this.errors.push(new ae(e, t3, r, n));
            }
            _parseBindingAst(e, t3, r, n) {
              let s = this._parseQuote(e, t3, r);
              if (s != null)
                return s;
              this._checkNoInterpolation(e, t3, n);
              let a = this._stripComments(e), i = this._lexer.tokenize(a);
              return new D(e, t3, r, i, a.length, false, this.errors, e.length - a.length).parseChain();
            }
            _parseQuote(e, t3, r) {
              if (e == null)
                return null;
              let n = e.indexOf(":");
              if (n == -1)
                return null;
              let s = e.substring(0, n).trim();
              if (!Zt(s))
                return null;
              let a = e.substring(n + 1), i = new V(0, e.length);
              return new Le(i, i.toAbsolute(r), s, a, t3);
            }
            parseTemplateBindings(e, t3, r, n, s) {
              let a = this._lexer.tokenize(t3);
              return new D(t3, r, s, a, t3.length, false, this.errors, 0).parseTemplateBindings({ source: e, span: new U(n, n + e.length) });
            }
            parseInterpolation(e, t3, r) {
              let n = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : J, { strings: s, expressions: a, offsets: i } = this.splitInterpolation(e, t3, n);
              if (a.length === 0)
                return null;
              let h = [];
              for (let l = 0; l < a.length; ++l) {
                let P = a[l].text, p = this._stripComments(P), x = this._lexer.tokenize(p), C = new D(e, t3, r, x, p.length, false, this.errors, i[l] + (P.length - p.length)).parseChain();
                h.push(C);
              }
              return this.createInterpolationAst(s.map((l) => l.text), h, e, t3, r);
            }
            parseInterpolationExpression(e, t3, r) {
              let n = this._stripComments(e), s = this._lexer.tokenize(n), a = new D(e, t3, r, s, n.length, false, this.errors, 0).parseChain(), i = ["", ""];
              return this.createInterpolationAst(i, [a], e, t3, r);
            }
            createInterpolationAst(e, t3, r, n, s) {
              let a = new V(0, r.length), i = new me(a, a.toAbsolute(s), e, t3);
              return new G(i, r, n, s, this.errors);
            }
            splitInterpolation(e, t3) {
              let r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : J, n = [], s = [], a = [], i = 0, h = false, l = false, { start: P, end: p } = r;
              for (; i < e.length; )
                if (h) {
                  let x = i, C = x + P.length, b = this._getInterpolationEndIndex(e, p, C);
                  if (b === -1) {
                    h = false, l = true;
                    break;
                  }
                  let _ = b + p.length, R = e.substring(C, b);
                  R.trim().length === 0 && this._reportError("Blank expressions are not allowed in interpolated strings", e, `at column ${i} in`, t3), s.push({ text: R, start: x, end: _ }), a.push(C), i = _, h = false;
                } else {
                  let x = i;
                  i = e.indexOf(P, i), i === -1 && (i = e.length);
                  let C = e.substring(x, i);
                  n.push({ text: C, start: x, end: i }), h = true;
                }
              if (!h)
                if (l) {
                  let x = n[n.length - 1];
                  x.text += e.substring(i), x.end = e.length;
                } else
                  n.push({ text: e.substring(i), start: i, end: e.length });
              return new qe(n, s, a);
            }
            wrapLiteralPrimitive(e, t3, r) {
              let n = new V(0, e == null ? 0 : e.length);
              return new G(new $2(n, n.toAbsolute(r), e), e, t3, r, this.errors);
            }
            _stripComments(e) {
              let t3 = this._commentStart(e);
              return t3 != null ? e.substring(0, t3).trim() : e;
            }
            _commentStart(e) {
              let t3 = null;
              for (let r = 0; r < e.length - 1; r++) {
                let n = e.charCodeAt(r), s = e.charCodeAt(r + 1);
                if (n === Te && s == Te && t3 == null)
                  return r;
                t3 === n ? t3 = null : t3 == null && mt(n) && (t3 = n);
              }
              return null;
            }
            _checkNoInterpolation(e, t3, r) {
              let { start: n, end: s } = r, a = -1, i = -1;
              for (let h of this._forEachUnquotedChar(e, 0))
                if (a === -1)
                  e.startsWith(n) && (a = h);
                else if (i = this._getInterpolationEndIndex(e, s, h), i > -1)
                  break;
              a > -1 && i > -1 && this._reportError(`Got interpolation (${n}${s}) where expression was expected`, e, `at column ${a} in`, t3);
            }
            _getInterpolationEndIndex(e, t3, r) {
              for (let n of this._forEachUnquotedChar(e, r)) {
                if (e.startsWith(t3, n))
                  return n;
                if (e.startsWith("//", n))
                  return e.indexOf(t3, n);
              }
              return -1;
            }
            *_forEachUnquotedChar(e, t3) {
              let r = null, n = 0;
              for (let s = t3; s < e.length; s++) {
                let a = e[s];
                mt(e.charCodeAt(s)) && (r === null || r === a) && n % 2 === 0 ? r = r === null ? a : null : r === null && (yield s), n = a === "\\" ? n + 1 : 0;
              }
            }
          }, sr = class extends De {
            constructor() {
              super(...arguments), this.simpleExpressionChecker = wt;
            }
          }, function(e) {
            e[e.None = 0] = "None", e[e.Writable = 1] = "Writable";
          }(Z || (Z = {})), D = class {
            constructor(e, t3, r, n, s, a, i, h) {
              this.input = e, this.location = t3, this.absoluteOffset = r, this.tokens = n, this.inputLength = s, this.parseAction = a, this.errors = i, this.offset = h, this.rparensExpected = 0, this.rbracketsExpected = 0, this.rbracesExpected = 0, this.context = Z.None, this.sourceSpanCache = /* @__PURE__ */ new Map(), this.index = 0;
            }
            peek(e) {
              let t3 = this.index + e;
              return t3 < this.tokens.length ? this.tokens[t3] : Ie;
            }
            get next() {
              return this.peek(0);
            }
            get atEOF() {
              return this.index >= this.tokens.length;
            }
            get inputIndex() {
              return this.atEOF ? this.currentEndIndex : this.next.index + this.offset;
            }
            get currentEndIndex() {
              return this.index > 0 ? this.peek(-1).end + this.offset : this.tokens.length === 0 ? this.inputLength + this.offset : this.next.index + this.offset;
            }
            get currentAbsoluteOffset() {
              return this.absoluteOffset + this.inputIndex;
            }
            span(e, t3) {
              let r = this.currentEndIndex;
              if (t3 !== void 0 && t3 > this.currentEndIndex && (r = t3), e > r) {
                let n = r;
                r = e, e = n;
              }
              return new V(e, r);
            }
            sourceSpan(e, t3) {
              let r = `${e}@${this.inputIndex}:${t3}`;
              return this.sourceSpanCache.has(r) || this.sourceSpanCache.set(r, this.span(e, t3).toAbsolute(this.absoluteOffset)), this.sourceSpanCache.get(r);
            }
            advance() {
              this.index++;
            }
            withContext(e, t3) {
              this.context |= e;
              let r = t3();
              return this.context ^= e, r;
            }
            consumeOptionalCharacter(e) {
              return this.next.isCharacter(e) ? (this.advance(), true) : false;
            }
            peekKeywordLet() {
              return this.next.isKeywordLet();
            }
            peekKeywordAs() {
              return this.next.isKeywordAs();
            }
            expectCharacter(e) {
              this.consumeOptionalCharacter(e) || this.error(`Missing expected ${String.fromCharCode(e)}`);
            }
            consumeOptionalOperator(e) {
              return this.next.isOperator(e) ? (this.advance(), true) : false;
            }
            expectOperator(e) {
              this.consumeOptionalOperator(e) || this.error(`Missing expected operator ${e}`);
            }
            prettyPrintToken(e) {
              return e === Ie ? "end of input" : `token ${e}`;
            }
            expectIdentifierOrKeyword() {
              let e = this.next;
              return !e.isIdentifier() && !e.isKeyword() ? (e.isPrivateIdentifier() ? this._reportErrorForPrivateIdentifier(e, "expected identifier or keyword") : this.error(`Unexpected ${this.prettyPrintToken(e)}, expected identifier or keyword`), null) : (this.advance(), e.toString());
            }
            expectIdentifierOrKeywordOrString() {
              let e = this.next;
              return !e.isIdentifier() && !e.isKeyword() && !e.isString() ? (e.isPrivateIdentifier() ? this._reportErrorForPrivateIdentifier(e, "expected identifier, keyword or string") : this.error(`Unexpected ${this.prettyPrintToken(e)}, expected identifier, keyword, or string`), "") : (this.advance(), e.toString());
            }
            parseChain() {
              let e = [], t3 = this.inputIndex;
              for (; this.index < this.tokens.length; ) {
                let r = this.parsePipe();
                if (e.push(r), this.consumeOptionalCharacter(te))
                  for (this.parseAction || this.error("Binding expression cannot contain chained expression"); this.consumeOptionalCharacter(te); )
                    ;
                else
                  this.index < this.tokens.length && this.error(`Unexpected token '${this.next}'`);
              }
              if (e.length == 0) {
                let r = this.offset, n = this.offset + this.inputLength;
                return new K(this.span(r, n), this.sourceSpan(r, n));
              }
              return e.length == 1 ? e[0] : new oe(this.span(t3), this.sourceSpan(t3), e);
            }
            parsePipe() {
              let e = this.inputIndex, t3 = this.parseExpression();
              if (this.consumeOptionalOperator("|")) {
                this.parseAction && this.error("Cannot have a pipe in an action expression");
                do {
                  let r = this.inputIndex, n = this.expectIdentifierOrKeyword(), s, a;
                  n !== null ? s = this.sourceSpan(r) : (n = "", a = this.next.index !== -1 ? this.next.index : this.inputLength + this.offset, s = new V(a, a).toAbsolute(this.absoluteOffset));
                  let i = [];
                  for (; this.consumeOptionalCharacter(X); )
                    i.push(this.parseExpression());
                  t3 = new fe(this.span(e), this.sourceSpan(e, a), t3, n, i, s);
                } while (this.consumeOptionalOperator("|"));
              }
              return t3;
            }
            parseExpression() {
              return this.parseConditional();
            }
            parseConditional() {
              let e = this.inputIndex, t3 = this.parseLogicalOr();
              if (this.consumeOptionalOperator("?")) {
                let r = this.parsePipe(), n;
                if (this.consumeOptionalCharacter(X))
                  n = this.parsePipe();
                else {
                  let s = this.inputIndex, a = this.input.substring(e, s);
                  this.error(`Conditional expression ${a} requires all 3 expressions`), n = new K(this.span(e), this.sourceSpan(e));
                }
                return new ce(this.span(e), this.sourceSpan(e), t3, r, n);
              } else
                return t3;
            }
            parseLogicalOr() {
              let e = this.inputIndex, t3 = this.parseLogicalAnd();
              for (; this.consumeOptionalOperator("||"); ) {
                let r = this.parseLogicalAnd();
                t3 = new B(this.span(e), this.sourceSpan(e), "||", t3, r);
              }
              return t3;
            }
            parseLogicalAnd() {
              let e = this.inputIndex, t3 = this.parseNullishCoalescing();
              for (; this.consumeOptionalOperator("&&"); ) {
                let r = this.parseNullishCoalescing();
                t3 = new B(this.span(e), this.sourceSpan(e), "&&", t3, r);
              }
              return t3;
            }
            parseNullishCoalescing() {
              let e = this.inputIndex, t3 = this.parseEquality();
              for (; this.consumeOptionalOperator("??"); ) {
                let r = this.parseEquality();
                t3 = new B(this.span(e), this.sourceSpan(e), "??", t3, r);
              }
              return t3;
            }
            parseEquality() {
              let e = this.inputIndex, t3 = this.parseRelational();
              for (; this.next.type == S.Operator; ) {
                let r = this.next.strValue;
                switch (r) {
                  case "==":
                  case "===":
                  case "!=":
                  case "!==":
                    this.advance();
                    let n = this.parseRelational();
                    t3 = new B(this.span(e), this.sourceSpan(e), r, t3, n);
                    continue;
                }
                break;
              }
              return t3;
            }
            parseRelational() {
              let e = this.inputIndex, t3 = this.parseAdditive();
              for (; this.next.type == S.Operator; ) {
                let r = this.next.strValue;
                switch (r) {
                  case "<":
                  case ">":
                  case "<=":
                  case ">=":
                    this.advance();
                    let n = this.parseAdditive();
                    t3 = new B(this.span(e), this.sourceSpan(e), r, t3, n);
                    continue;
                }
                break;
              }
              return t3;
            }
            parseAdditive() {
              let e = this.inputIndex, t3 = this.parseMultiplicative();
              for (; this.next.type == S.Operator; ) {
                let r = this.next.strValue;
                switch (r) {
                  case "+":
                  case "-":
                    this.advance();
                    let n = this.parseMultiplicative();
                    t3 = new B(this.span(e), this.sourceSpan(e), r, t3, n);
                    continue;
                }
                break;
              }
              return t3;
            }
            parseMultiplicative() {
              let e = this.inputIndex, t3 = this.parsePrefix();
              for (; this.next.type == S.Operator; ) {
                let r = this.next.strValue;
                switch (r) {
                  case "*":
                  case "%":
                  case "/":
                    this.advance();
                    let n = this.parsePrefix();
                    t3 = new B(this.span(e), this.sourceSpan(e), r, t3, n);
                    continue;
                }
                break;
              }
              return t3;
            }
            parsePrefix() {
              if (this.next.type == S.Operator) {
                let e = this.inputIndex, t3 = this.next.strValue, r;
                switch (t3) {
                  case "+":
                    return this.advance(), r = this.parsePrefix(), F.createPlus(this.span(e), this.sourceSpan(e), r);
                  case "-":
                    return this.advance(), r = this.parsePrefix(), F.createMinus(this.span(e), this.sourceSpan(e), r);
                  case "!":
                    return this.advance(), r = this.parsePrefix(), new xe(this.span(e), this.sourceSpan(e), r);
                }
              }
              return this.parseCallChain();
            }
            parseCallChain() {
              let e = this.inputIndex, t3 = this.parsePrimary();
              for (; ; )
                if (this.consumeOptionalCharacter(H))
                  t3 = this.parseAccessMemberOrMethodCall(t3, e, false);
                else if (this.consumeOptionalOperator("?."))
                  t3 = this.consumeOptionalCharacter(Ae) ? this.parseKeyedReadOrWrite(t3, e, true) : this.parseAccessMemberOrMethodCall(t3, e, true);
                else if (this.consumeOptionalCharacter(Ae))
                  t3 = this.parseKeyedReadOrWrite(t3, e, false);
                else if (this.consumeOptionalCharacter(Ee)) {
                  this.rparensExpected++;
                  let r = this.parseCallArguments();
                  this.rparensExpected--, this.expectCharacter(z), t3 = new Pe(this.span(e), this.sourceSpan(e), t3, r);
                } else if (this.consumeOptionalOperator("!"))
                  t3 = new Se(this.span(e), this.sourceSpan(e), t3);
                else
                  return t3;
            }
            parsePrimary() {
              let e = this.inputIndex;
              if (this.consumeOptionalCharacter(Ee)) {
                this.rparensExpected++;
                let t3 = this.parsePipe();
                return this.rparensExpected--, this.expectCharacter(z), t3;
              } else {
                if (this.next.isKeywordNull())
                  return this.advance(), new $2(this.span(e), this.sourceSpan(e), null);
                if (this.next.isKeywordUndefined())
                  return this.advance(), new $2(this.span(e), this.sourceSpan(e), void 0);
                if (this.next.isKeywordTrue())
                  return this.advance(), new $2(this.span(e), this.sourceSpan(e), true);
                if (this.next.isKeywordFalse())
                  return this.advance(), new $2(this.span(e), this.sourceSpan(e), false);
                if (this.next.isKeywordThis())
                  return this.advance(), new Ye(this.span(e), this.sourceSpan(e));
                if (this.consumeOptionalCharacter(Ae)) {
                  this.rbracketsExpected++;
                  let t3 = this.parseExpressionList(re);
                  return this.rbracketsExpected--, this.expectCharacter(re), new ge(this.span(e), this.sourceSpan(e), t3);
                } else {
                  if (this.next.isCharacter($e))
                    return this.parseLiteralMap();
                  if (this.next.isIdentifier())
                    return this.parseAccessMemberOrMethodCall(new Oe(this.span(e), this.sourceSpan(e)), e, false);
                  if (this.next.isNumber()) {
                    let t3 = this.next.toNumber();
                    return this.advance(), new $2(this.span(e), this.sourceSpan(e), t3);
                  } else if (this.next.isString()) {
                    let t3 = this.next.toString();
                    return this.advance(), new $2(this.span(e), this.sourceSpan(e), t3);
                  } else
                    return this.next.isPrivateIdentifier() ? (this._reportErrorForPrivateIdentifier(this.next, null), new K(this.span(e), this.sourceSpan(e))) : this.index >= this.tokens.length ? (this.error(`Unexpected end of expression: ${this.input}`), new K(this.span(e), this.sourceSpan(e))) : (this.error(`Unexpected token ${this.next}`), new K(this.span(e), this.sourceSpan(e)));
                }
              }
            }
            parseExpressionList(e) {
              let t3 = [];
              do
                if (!this.next.isCharacter(e))
                  t3.push(this.parsePipe());
                else
                  break;
              while (this.consumeOptionalCharacter(ee));
              return t3;
            }
            parseLiteralMap() {
              let e = [], t3 = [], r = this.inputIndex;
              if (this.expectCharacter($e), !this.consumeOptionalCharacter(_e)) {
                this.rbracesExpected++;
                do {
                  let n = this.inputIndex, s = this.next.isString(), a = this.expectIdentifierOrKeywordOrString();
                  if (e.push({ key: a, quoted: s }), s)
                    this.expectCharacter(X), t3.push(this.parsePipe());
                  else if (this.consumeOptionalCharacter(X))
                    t3.push(this.parsePipe());
                  else {
                    let i = this.span(n), h = this.sourceSpan(n);
                    t3.push(new ne(i, h, h, new Oe(i, h), a));
                  }
                } while (this.consumeOptionalCharacter(ee));
                this.rbracesExpected--, this.expectCharacter(_e);
              }
              return new ve(this.span(r), this.sourceSpan(r), e, t3);
            }
            parseAccessMemberOrMethodCall(e, t3, r) {
              let n = this.inputIndex, s = this.withContext(Z.Writable, () => {
                var i;
                let h = (i = this.expectIdentifierOrKeyword()) !== null && i !== void 0 ? i : "";
                return h.length === 0 && this.error("Expected identifier for property access", e.span.end), h;
              }), a = this.sourceSpan(n);
              if (this.consumeOptionalCharacter(Ee)) {
                let i = this.inputIndex;
                this.rparensExpected++;
                let h = this.parseCallArguments(), l = this.span(i, this.inputIndex).toAbsolute(this.absoluteOffset);
                this.expectCharacter(z), this.rparensExpected--;
                let P = this.span(t3), p = this.sourceSpan(t3);
                return r ? new we(P, p, a, e, s, h, l) : new ye(P, p, a, e, s, h, l);
              } else {
                if (r)
                  return this.consumeOptionalOperator("=") ? (this.error("The '?.' operator cannot be used in the assignment"), new K(this.span(t3), this.sourceSpan(t3))) : new le(this.span(t3), this.sourceSpan(t3), a, e, s);
                if (this.consumeOptionalOperator("=")) {
                  if (!this.parseAction)
                    return this.error("Bindings cannot contain assignments"), new K(this.span(t3), this.sourceSpan(t3));
                  let i = this.parseConditional();
                  return new ue(this.span(t3), this.sourceSpan(t3), a, e, s, i);
                } else
                  return new ne(this.span(t3), this.sourceSpan(t3), a, e, s);
              }
            }
            parseCallArguments() {
              if (this.next.isCharacter(z))
                return [];
              let e = [];
              do
                e.push(this.parsePipe());
              while (this.consumeOptionalCharacter(ee));
              return e;
            }
            expectTemplateBindingKey() {
              let e = "", t3 = false, r = this.currentAbsoluteOffset;
              do
                e += this.expectIdentifierOrKeywordOrString(), t3 = this.consumeOptionalOperator("-"), t3 && (e += "-");
              while (t3);
              return { source: e, span: new U(r, r + e.length) };
            }
            parseTemplateBindings(e) {
              let t3 = [];
              for (t3.push(...this.parseDirectiveKeywordBindings(e)); this.index < this.tokens.length; ) {
                let r = this.parseLetBinding();
                if (r)
                  t3.push(r);
                else {
                  let n = this.expectTemplateBindingKey(), s = this.parseAsBinding(n);
                  s ? t3.push(s) : (n.source = e.source + n.source.charAt(0).toUpperCase() + n.source.substring(1), t3.push(...this.parseDirectiveKeywordBindings(n)));
                }
                this.consumeStatementTerminator();
              }
              return new Qe(t3, [], this.errors);
            }
            parseKeyedReadOrWrite(e, t3, r) {
              return this.withContext(Z.Writable, () => {
                this.rbracketsExpected++;
                let n = this.parsePipe();
                if (n instanceof K && this.error("Key access cannot be empty"), this.rbracketsExpected--, this.expectCharacter(re), this.consumeOptionalOperator("="))
                  if (r)
                    this.error("The '?.' operator cannot be used in the assignment");
                  else {
                    let s = this.parseConditional();
                    return new de(this.span(t3), this.sourceSpan(t3), e, n, s);
                  }
                else
                  return r ? new pe(this.span(t3), this.sourceSpan(t3), e, n) : new he(this.span(t3), this.sourceSpan(t3), e, n);
                return new K(this.span(t3), this.sourceSpan(t3));
              });
            }
            parseDirectiveKeywordBindings(e) {
              let t3 = [];
              this.consumeOptionalCharacter(X);
              let r = this.getDirectiveBoundTarget(), n = this.currentAbsoluteOffset, s = this.parseAsBinding(e);
              s || (this.consumeStatementTerminator(), n = this.currentAbsoluteOffset);
              let a = new U(e.span.start, n);
              return t3.push(new Ze(a, e, r)), s && t3.push(s), t3;
            }
            getDirectiveBoundTarget() {
              if (this.next === Ie || this.peekKeywordAs() || this.peekKeywordLet())
                return null;
              let e = this.parsePipe(), { start: t3, end: r } = e.span, n = this.input.substring(t3, r);
              return new G(e, n, this.location, this.absoluteOffset + t3, this.errors);
            }
            parseAsBinding(e) {
              if (!this.peekKeywordAs())
                return null;
              this.advance();
              let t3 = this.expectTemplateBindingKey();
              this.consumeStatementTerminator();
              let r = new U(e.span.start, this.currentAbsoluteOffset);
              return new Re(r, t3, e);
            }
            parseLetBinding() {
              if (!this.peekKeywordLet())
                return null;
              let e = this.currentAbsoluteOffset;
              this.advance();
              let t3 = this.expectTemplateBindingKey(), r = null;
              this.consumeOptionalOperator("=") && (r = this.expectTemplateBindingKey()), this.consumeStatementTerminator();
              let n = new U(e, this.currentAbsoluteOffset);
              return new Re(n, t3, r);
            }
            consumeStatementTerminator() {
              this.consumeOptionalCharacter(te) || this.consumeOptionalCharacter(ee);
            }
            error(e) {
              let t3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              this.errors.push(new ae(e, this.input, this.locationText(t3), this.location)), this.skip();
            }
            locationText() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : null;
              return e == null && (e = this.index), e < this.tokens.length ? `at column ${this.tokens[e].index + 1} in` : "at the end of the expression";
            }
            _reportErrorForPrivateIdentifier(e, t3) {
              let r = `Private identifiers are not supported. Unexpected private identifier: ${e}`;
              t3 !== null && (r += `, ${t3}`), this.error(r);
            }
            skip() {
              let e = this.next;
              for (; this.index < this.tokens.length && !e.isCharacter(te) && !e.isOperator("|") && (this.rparensExpected <= 0 || !e.isCharacter(z)) && (this.rbracesExpected <= 0 || !e.isCharacter(_e)) && (this.rbracketsExpected <= 0 || !e.isCharacter(re)) && (!(this.context & Z.Writable) || !e.isOperator("=")); )
                this.next.isError() && this.errors.push(new ae(this.next.toString(), this.input, this.locationText(), this.location)), this.advance(), e = this.next;
            }
          }, yt = class {
            constructor() {
              this.errors = [];
            }
            visitImplicitReceiver(e, t3) {
            }
            visitThisReceiver(e, t3) {
            }
            visitInterpolation(e, t3) {
            }
            visitLiteralPrimitive(e, t3) {
            }
            visitPropertyRead(e, t3) {
            }
            visitPropertyWrite(e, t3) {
            }
            visitSafePropertyRead(e, t3) {
            }
            visitMethodCall(e, t3) {
            }
            visitSafeMethodCall(e, t3) {
            }
            visitFunctionCall(e, t3) {
            }
            visitLiteralArray(e, t3) {
              this.visitAll(e.expressions, t3);
            }
            visitLiteralMap(e, t3) {
              this.visitAll(e.values, t3);
            }
            visitUnary(e, t3) {
            }
            visitBinary(e, t3) {
            }
            visitPrefixNot(e, t3) {
            }
            visitNonNullAssert(e, t3) {
            }
            visitConditional(e, t3) {
            }
            visitPipe(e, t3) {
              this.errors.push("pipes");
            }
            visitKeyedRead(e, t3) {
            }
            visitKeyedWrite(e, t3) {
            }
            visitAll(e, t3) {
              return e.map((r) => r.visit(this, t3));
            }
            visitChain(e, t3) {
            }
            visitQuote(e, t3) {
            }
            visitSafeKeyedRead(e, t3) {
            }
          }, wt = class extends et {
            constructor() {
              super(...arguments), this.errors = [];
            }
            visitPipe() {
              this.errors.push("pipes");
            }
          };
        } }), ft = q({ "node_modules/angular-estree-parser/lib/utils.js"(e) {
          "use strict";
          L(), Object.defineProperty(e, "__esModule", { value: true }), e.getLast = e.toLowerCamelCase = e.findBackChar = e.findFrontChar = e.fitSpans = e.getNgType = e.parseNgInterpolation = e.parseNgTemplateBindings = e.parseNgAction = e.parseNgSimpleBinding = e.parseNgBinding = e.NG_PARSE_TEMPLATE_BINDINGS_FAKE_PREFIX = void 0;
          var t3 = (tt(), be(Je)), r = (tr(), be(Yt)), n = (br(), be(nr)), s = "angular-estree-parser";
          e.NG_PARSE_TEMPLATE_BINDINGS_FAKE_PREFIX = "NgEstreeParser";
          var a = 0, i = [s, a];
          function h() {
            return new n.Parser(new r.Lexer());
          }
          function l(o, d) {
            let y = h(), { astInput: E, comments: A } = T(o, y), { ast: I, errors: j } = d(E, y);
            return R(j), { ast: I, comments: A };
          }
          function P(o) {
            return l(o, (d, y) => y.parseBinding(d, ...i));
          }
          e.parseNgBinding = P;
          function p(o) {
            return l(o, (d, y) => y.parseSimpleBinding(d, ...i));
          }
          e.parseNgSimpleBinding = p;
          function x(o) {
            return l(o, (d, y) => y.parseAction(d, ...i));
          }
          e.parseNgAction = x;
          function C(o) {
            let d = h(), { templateBindings: y, errors: E } = d.parseTemplateBindings(e.NG_PARSE_TEMPLATE_BINDINGS_FAKE_PREFIX, o, s, a, a);
            return R(E), y;
          }
          e.parseNgTemplateBindings = C;
          function b(o) {
            let d = h(), { astInput: y, comments: E } = T(o, d), A = "{{", I = "}}", { ast: j, errors: or } = d.parseInterpolation(A + y + I, ...i);
            R(or);
            let gt = j.expressions[0], vt = /* @__PURE__ */ new Set();
            return _(gt, (ke) => {
              vt.has(ke) || (ke.start -= A.length, ke.end -= A.length, vt.add(ke));
            }), { ast: gt, comments: E };
          }
          e.parseNgInterpolation = b;
          function _(o, d) {
            if (!(!o || typeof o != "object")) {
              if (Array.isArray(o))
                return o.forEach((y) => _(y, d));
              for (let y of Object.keys(o)) {
                let E = o[y];
                y === "span" ? d(E) : _(E, d);
              }
            }
          }
          function R(o) {
            if (o.length !== 0) {
              let [{ message: d }] = o;
              throw new SyntaxError(d.replace(/^Parser Error: | at column \d+ in [^]*$/g, ""));
            }
          }
          function T(o, d) {
            let y = d._commentStart(o);
            return y === null ? { astInput: o, comments: [] } : { astInput: o.slice(0, y), comments: [{ type: "Comment", value: o.slice(y + 2), span: { start: y, end: o.length } }] };
          }
          function O(o) {
            return t3.Unary && o instanceof t3.Unary ? "Unary" : o instanceof t3.Binary ? "Binary" : o instanceof t3.BindingPipe ? "BindingPipe" : o instanceof t3.Chain ? "Chain" : o instanceof t3.Conditional ? "Conditional" : o instanceof t3.EmptyExpr ? "EmptyExpr" : o instanceof t3.FunctionCall ? "FunctionCall" : o instanceof t3.ImplicitReceiver ? "ImplicitReceiver" : o instanceof t3.KeyedRead ? "KeyedRead" : o instanceof t3.KeyedWrite ? "KeyedWrite" : o instanceof t3.LiteralArray ? "LiteralArray" : o instanceof t3.LiteralMap ? "LiteralMap" : o instanceof t3.LiteralPrimitive ? "LiteralPrimitive" : o instanceof t3.MethodCall ? "MethodCall" : o instanceof t3.NonNullAssert ? "NonNullAssert" : o instanceof t3.PrefixNot ? "PrefixNot" : o instanceof t3.PropertyRead ? "PropertyRead" : o instanceof t3.PropertyWrite ? "PropertyWrite" : o instanceof t3.Quote ? "Quote" : o instanceof t3.SafeMethodCall ? "SafeMethodCall" : o instanceof t3.SafePropertyRead ? "SafePropertyRead" : o.type;
          }
          e.getNgType = O;
          function N(o, d) {
            let { start: y, end: E } = o, A = y, I = E;
            for (; I !== A && /\s/.test(d[I - 1]); )
              I--;
            for (; A !== I && /\s/.test(d[A]); )
              A++;
            return { start: A, end: I };
          }
          function c(o, d) {
            let { start: y, end: E } = o, A = y, I = E;
            for (; I !== d.length && /\s/.test(d[I]); )
              I++;
            for (; A !== 0 && /\s/.test(d[A - 1]); )
              A--;
            return { start: A, end: I };
          }
          function g(o, d) {
            return d[o.start - 1] === "(" && d[o.end] === ")" ? { start: o.start - 1, end: o.end + 1 } : o;
          }
          function u(o, d, y) {
            let E = 0, A = { start: o.start, end: o.end };
            for (; ; ) {
              let I = c(A, d), j = g(I, d);
              if (I.start === j.start && I.end === j.end)
                break;
              A.start = j.start, A.end = j.end, E++;
            }
            return { hasParens: (y ? E - 1 : E) !== 0, outerSpan: N(y ? { start: A.start + 1, end: A.end - 1 } : A, d), innerSpan: N(o, d) };
          }
          e.fitSpans = u;
          function v(o, d, y) {
            let E = d;
            for (; !o.test(y[E]); )
              if (--E < 0)
                throw new Error(`Cannot find front char ${o} from index ${d} in ${JSON.stringify(y)}`);
            return E;
          }
          e.findFrontChar = v;
          function m(o, d, y) {
            let E = d;
            for (; !o.test(y[E]); )
              if (++E >= y.length)
                throw new Error(`Cannot find back char ${o} from index ${d} in ${JSON.stringify(y)}`);
            return E;
          }
          e.findBackChar = m;
          function f(o) {
            return o.slice(0, 1).toLowerCase() + o.slice(1);
          }
          e.toLowerCamelCase = f;
          function w(o) {
            return o.length === 0 ? void 0 : o[o.length - 1];
          }
          e.getLast = w;
        } }), ir = q({ "node_modules/angular-estree-parser/lib/transform.js"(e) {
          "use strict";
          L(), Object.defineProperty(e, "__esModule", { value: true }), e.transformSpan = e.transform = void 0;
          var t3 = ft(), r = function(s, a) {
            let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, h = t3.getNgType(s);
            switch (h) {
              case "Unary": {
                let { operator: c, expr: g } = s, u = l(g);
                return p("UnaryExpression", { prefix: true, argument: u, operator: c }, s.span, { hasParentParens: i });
              }
              case "Binary": {
                let { left: c, operation: g, right: u } = s, v = u.span.start === u.span.end, m = c.span.start === c.span.end;
                if (v || m) {
                  let o = c.span.start === c.span.end ? l(u) : l(c);
                  return p("UnaryExpression", { prefix: true, argument: o, operator: v ? "+" : "-" }, { start: s.span.start, end: N(o) }, { hasParentParens: i });
                }
                let f = l(c), w = l(u);
                return p(g === "&&" || g === "||" ? "LogicalExpression" : "BinaryExpression", { left: f, right: w, operator: g }, { start: O(f), end: N(w) }, { hasParentParens: i });
              }
              case "BindingPipe": {
                let { exp: c, name: g, args: u } = s, v = l(c), m = b(/\S/, b(/\|/, N(v)) + 1), f = p("Identifier", { name: g }, { start: m, end: m + g.length }), w = u.map(l);
                return p("NGPipeExpression", { left: v, right: f, arguments: w }, { start: O(v), end: N(w.length === 0 ? f : t3.getLast(w)) }, { hasParentParens: i });
              }
              case "Chain": {
                let { expressions: c } = s;
                return p("NGChainedExpression", { expressions: c.map(l) }, s.span, { hasParentParens: i });
              }
              case "Comment": {
                let { value: c } = s;
                return p("CommentLine", { value: c }, s.span, { processSpan: false });
              }
              case "Conditional": {
                let { condition: c, trueExp: g, falseExp: u } = s, v = l(c), m = l(g), f = l(u);
                return p("ConditionalExpression", { test: v, consequent: m, alternate: f }, { start: O(v), end: N(f) }, { hasParentParens: i });
              }
              case "EmptyExpr":
                return p("NGEmptyExpression", {}, s.span, { hasParentParens: i });
              case "FunctionCall": {
                let { target: c, args: g } = s, u = g.length === 1 ? [P(g[0])] : g.map(l), v = l(c);
                return p("CallExpression", { callee: v, arguments: u }, { start: O(v), end: s.span.end }, { hasParentParens: i });
              }
              case "ImplicitReceiver":
                return p("ThisExpression", {}, s.span, { hasParentParens: i });
              case "KeyedRead": {
                let { key: c } = s, g = Object.prototype.hasOwnProperty.call(s, "receiver") ? s.receiver : s.obj, u = l(c);
                return x(g, u, { computed: true, optional: false }, { end: s.span.end, hasParentParens: i });
              }
              case "LiteralArray": {
                let { expressions: c } = s;
                return p("ArrayExpression", { elements: c.map(l) }, s.span, { hasParentParens: i });
              }
              case "LiteralMap": {
                let { keys: c, values: g } = s, u = g.map((m) => l(m)), v = c.map((m, f) => {
                  let { key: w, quoted: o } = m, d = u[f], y = b(/\S/, f === 0 ? s.span.start + 1 : b(/,/, N(u[f - 1])) + 1), E = C(/\S/, C(/:/, O(d) - 1) - 1) + 1, A = { start: y, end: E }, I = o ? p("StringLiteral", { value: w }, A) : p("Identifier", { name: w }, A), j = I.end < I.start;
                  return p("ObjectProperty", { key: I, value: d, method: false, shorthand: j, computed: false }, { start: O(I), end: N(d) });
                });
                return p("ObjectExpression", { properties: v }, s.span, { hasParentParens: i });
              }
              case "LiteralPrimitive": {
                let { value: c } = s;
                switch (typeof c) {
                  case "boolean":
                    return p("BooleanLiteral", { value: c }, s.span, { hasParentParens: i });
                  case "number":
                    return p("NumericLiteral", { value: c }, s.span, { hasParentParens: i });
                  case "object":
                    return p("NullLiteral", {}, s.span, { hasParentParens: i });
                  case "string":
                    return p("StringLiteral", { value: c }, s.span, { hasParentParens: i });
                  case "undefined":
                    return p("Identifier", { name: "undefined" }, s.span, { hasParentParens: i });
                  default:
                    throw new Error(`Unexpected LiteralPrimitive value type ${typeof c}`);
                }
              }
              case "MethodCall":
              case "SafeMethodCall": {
                let c = h === "SafeMethodCall", { receiver: g, name: u, args: v } = s, m = v.length === 1 ? [P(v[0])] : v.map(l), f = C(/\S/, C(/\(/, (m.length === 0 ? C(/\)/, s.span.end - 1) : O(m[0])) - 1) - 1) + 1, w = p("Identifier", { name: u }, { start: f - u.length, end: f }), o = x(g, w, { computed: false, optional: c }), d = R(o);
                return p(c || d ? "OptionalCallExpression" : "CallExpression", { callee: o, arguments: m }, { start: O(o), end: s.span.end }, { hasParentParens: i });
              }
              case "NonNullAssert": {
                let { expression: c } = s, g = l(c);
                return p("TSNonNullExpression", { expression: g }, { start: O(g), end: s.span.end }, { hasParentParens: i });
              }
              case "PrefixNot": {
                let { expression: c } = s, g = l(c);
                return p("UnaryExpression", { prefix: true, operator: "!", argument: g }, { start: s.span.start, end: N(g) }, { hasParentParens: i });
              }
              case "PropertyRead":
              case "SafePropertyRead": {
                let c = h === "SafePropertyRead", { receiver: g, name: u } = s, v = C(/\S/, s.span.end - 1) + 1, m = p("Identifier", { name: u }, { start: v - u.length, end: v }, _(g) ? { hasParentParens: i } : {});
                return x(g, m, { computed: false, optional: c }, { hasParentParens: i });
              }
              case "KeyedWrite": {
                let { key: c, value: g } = s, u = Object.prototype.hasOwnProperty.call(s, "receiver") ? s.receiver : s.obj, v = l(c), m = l(g), f = x(u, v, { computed: true, optional: false }, { end: b(/\]/, N(v)) + 1 });
                return p("AssignmentExpression", { left: f, operator: "=", right: m }, { start: O(f), end: N(m) }, { hasParentParens: i });
              }
              case "PropertyWrite": {
                let { receiver: c, name: g, value: u } = s, v = l(u), m = C(/\S/, C(/=/, O(v) - 1) - 1) + 1, f = p("Identifier", { name: g }, { start: m - g.length, end: m }), w = x(c, f, { computed: false, optional: false });
                return p("AssignmentExpression", { left: w, operator: "=", right: v }, { start: O(w), end: N(v) }, { hasParentParens: i });
              }
              case "Quote": {
                let { prefix: c, uninterpretedExpression: g } = s;
                return p("NGQuotedExpression", { prefix: c, value: g }, s.span, { hasParentParens: i });
              }
              default:
                throw new Error(`Unexpected node ${h}`);
            }
            function l(c) {
              return e.transform(c, a);
            }
            function P(c) {
              return e.transform(c, a, true);
            }
            function p(c, g, u) {
              let { processSpan: v = true, hasParentParens: m = false } = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, f = Object.assign(Object.assign({ type: c }, n(u, a, v, m)), g);
              switch (c) {
                case "Identifier": {
                  let w = f;
                  w.loc.identifierName = w.name;
                  break;
                }
                case "NumericLiteral": {
                  let w = f;
                  w.extra = Object.assign(Object.assign({}, w.extra), { raw: a.text.slice(w.start, w.end), rawValue: w.value });
                  break;
                }
                case "StringLiteral": {
                  let w = f;
                  w.extra = Object.assign(Object.assign({}, w.extra), { raw: a.text.slice(w.start, w.end), rawValue: w.value });
                  break;
                }
              }
              return f;
            }
            function x(c, g, u) {
              let { end: v = N(g), hasParentParens: m = false } = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
              if (_(c) || c.span.start === g.start)
                return g;
              let f = l(c), w = R(f);
              return p(u.optional || w ? "OptionalMemberExpression" : "MemberExpression", Object.assign({ object: f, property: g, computed: u.computed }, u.optional ? { optional: true } : w ? { optional: false } : null), { start: O(f), end: v }, { hasParentParens: m });
            }
            function C(c, g) {
              return t3.findFrontChar(c, g, a.text);
            }
            function b(c, g) {
              return t3.findBackChar(c, g, a.text);
            }
            function _(c) {
              return c.span.start >= c.span.end || /^\s+$/.test(a.text.slice(c.span.start, c.span.end));
            }
            function R(c) {
              return (c.type === "OptionalCallExpression" || c.type === "OptionalMemberExpression") && !T(c);
            }
            function T(c) {
              return c.extra && c.extra.parenthesized;
            }
            function O(c) {
              return T(c) ? c.extra.parenStart : c.start;
            }
            function N(c) {
              return T(c) ? c.extra.parenEnd : c.end;
            }
          };
          e.transform = r;
          function n(s, a) {
            let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, h = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false;
            if (!i) {
              let { start: x, end: C } = s;
              return { start: x, end: C, loc: { start: a.locator.locationForIndex(x), end: a.locator.locationForIndex(C) } };
            }
            let { outerSpan: l, innerSpan: P, hasParens: p } = t3.fitSpans(s, a.text, h);
            return Object.assign({ start: P.start, end: P.end, loc: { start: a.locator.locationForIndex(P.start), end: a.locator.locationForIndex(P.end) } }, p && { extra: { parenthesized: true, parenStart: l.start, parenEnd: l.end } });
          }
          e.transformSpan = n;
        } }), Lr = q({ "node_modules/angular-estree-parser/lib/transform-microsyntax.js"(e) {
          "use strict";
          L(), Object.defineProperty(e, "__esModule", { value: true }), e.transformTemplateBindings = void 0;
          var t3 = (tt(), be(Je)), r = ir(), n = ft();
          function s(a, i) {
            a.forEach(N);
            let [h] = a, { key: l } = h, P = i.text.slice(h.sourceSpan.start, h.sourceSpan.end).trim().length === 0 ? a.slice(1) : a, p = [], x = null;
            for (let u = 0; u < P.length; u++) {
              let v = P[u];
              if (x && T(x) && O(v) && v.value && v.value.source === x.key.source) {
                let m = _("NGMicrosyntaxKey", { name: v.key.source }, v.key.span), f = (d, y) => Object.assign(Object.assign({}, d), r.transformSpan({ start: d.start, end: y }, i)), w = (d) => Object.assign(Object.assign({}, f(d, m.end)), { alias: m }), o = p.pop();
                if (o.type === "NGMicrosyntaxExpression")
                  p.push(w(o));
                else if (o.type === "NGMicrosyntaxKeyedExpression") {
                  let d = w(o.expression);
                  p.push(f(Object.assign(Object.assign({}, o), { expression: d }), d.end));
                } else
                  throw new Error(`Unexpected type ${o.type}`);
              } else
                p.push(C(v, u));
              x = v;
            }
            return _("NGMicrosyntax", { body: p }, p.length === 0 ? a[0].sourceSpan : { start: p[0].start, end: p[p.length - 1].end });
            function C(u, v) {
              if (T(u)) {
                let { key: m, value: f } = u;
                return f ? v === 0 ? _("NGMicrosyntaxExpression", { expression: b(f.ast), alias: null }, f.sourceSpan) : _("NGMicrosyntaxKeyedExpression", { key: _("NGMicrosyntaxKey", { name: R(m.source) }, m.span), expression: _("NGMicrosyntaxExpression", { expression: b(f.ast), alias: null }, f.sourceSpan) }, { start: m.span.start, end: f.sourceSpan.end }) : _("NGMicrosyntaxKey", { name: R(m.source) }, m.span);
              } else {
                let { key: m, sourceSpan: f } = u;
                if (/^let\s$/.test(i.text.slice(f.start, f.start + 4))) {
                  let { value: o } = u;
                  return _("NGMicrosyntaxLet", { key: _("NGMicrosyntaxKey", { name: m.source }, m.span), value: o ? _("NGMicrosyntaxKey", { name: o.source }, o.span) : null }, { start: f.start, end: o ? o.span.end : m.span.end });
                } else {
                  let o = g(u);
                  return _("NGMicrosyntaxAs", { key: _("NGMicrosyntaxKey", { name: o.source }, o.span), alias: _("NGMicrosyntaxKey", { name: m.source }, m.span) }, { start: o.span.start, end: m.span.end });
                }
              }
            }
            function b(u) {
              return r.transform(u, i);
            }
            function _(u, v, m) {
              let f = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true;
              return Object.assign(Object.assign({ type: u }, r.transformSpan(m, i, f)), v);
            }
            function R(u) {
              return n.toLowerCamelCase(u.slice(l.source.length));
            }
            function T(u) {
              return u instanceof t3.ExpressionBinding;
            }
            function O(u) {
              return u instanceof t3.VariableBinding;
            }
            function N(u) {
              c(u.key.span), O(u) && u.value && c(u.value.span);
            }
            function c(u) {
              if (i.text[u.start] !== '"' && i.text[u.start] !== "'")
                return;
              let v = i.text[u.start], m = false;
              for (let f = u.start + 1; f < i.text.length; f++)
                switch (i.text[f]) {
                  case v:
                    if (!m) {
                      u.end = f + 1;
                      return;
                    }
                  default:
                    m = false;
                    break;
                  case "\\":
                    m = !m;
                    break;
                }
            }
            function g(u) {
              if (!u.value || u.value.source !== n.NG_PARSE_TEMPLATE_BINDINGS_FAKE_PREFIX)
                return u.value;
              let v = n.findBackChar(/\S/, u.sourceSpan.start, i.text);
              return { source: "$implicit", span: { start: v, end: v } };
            }
          }
          e.transformTemplateBindings = s;
        } }), Rr = q({ "node_modules/angular-estree-parser/lib/index.js"(e) {
          "use strict";
          L(), Object.defineProperty(e, "__esModule", { value: true }), e.parseTemplateBindings = e.parseAction = e.parseInterpolation = e.parseSimpleBinding = e.parseBinding = void 0;
          var t3 = gr(), r = ir(), n = Lr(), s = ft();
          function a(x, C) {
            let { ast: b, comments: _ } = C(x), R = new t3.Context(x), T = (N) => r.transform(N, R), O = T(b);
            return O.comments = _.map(T), O;
          }
          function i(x) {
            return a(x, s.parseNgBinding);
          }
          e.parseBinding = i;
          function h(x) {
            return a(x, s.parseNgSimpleBinding);
          }
          e.parseSimpleBinding = h;
          function l(x) {
            return a(x, s.parseNgInterpolation);
          }
          e.parseInterpolation = l;
          function P(x) {
            return a(x, s.parseNgAction);
          }
          e.parseAction = P;
          function p(x) {
            return n.transformTemplateBindings(s.parseNgTemplateBindings(x), new t3.Context(x));
          }
          e.parseTemplateBindings = p;
        } });
        L();
        var { locStart: Tr, locEnd: $r } = dr();
        function Ne(e) {
          return { astFormat: "estree", parse: (r, n, s) => {
            let a = Rr(), i = e(r, a);
            return { type: "NGRoot", node: s.parser === "__ng_action" && i.type !== "NGChainedExpression" ? Object.assign(Object.assign({}, i), {}, { type: "NGChainedExpression", expressions: [i] }) : i };
          }, locStart: Tr, locEnd: $r };
        }
        ar.exports = { parsers: { __ng_action: Ne((e, t3) => t3.parseAction(e)), __ng_binding: Ne((e, t3) => t3.parseBinding(e)), __ng_interpolation: Ne((e, t3) => t3.parseInterpolation(e)), __ng_directive: Ne((e, t3) => t3.parseTemplateBindings(e)) } };
      });
      return Br();
    });
  }
});

// node_modules/prettier/parser-espree.js
var require_parser_espree = __commonJS({
  "node_modules/prettier/parser-espree.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.espree = e();
      }
    })(function() {
      "use strict";
      var C = (a, u) => () => (u || a((u = { exports: {} }).exports, u), u.exports);
      var oe = C((rl, Wr) => {
        var Ye = function(a) {
          return a && a.Math == Math && a;
        };
        Wr.exports = Ye(typeof globalThis == "object" && globalThis) || Ye(typeof window == "object" && window) || Ye(typeof self == "object" && self) || Ye(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var me = C((il, Gr) => {
        Gr.exports = function(a) {
          try {
            return !!a();
          } catch {
            return true;
          }
        };
      });
      var xe = C((sl, Hr) => {
        var yn = me();
        Hr.exports = !yn(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var bt = C((al, Kr) => {
        var An = me();
        Kr.exports = !An(function() {
          var a = function() {
          }.bind();
          return typeof a != "function" || a.hasOwnProperty("prototype");
        });
      });
      var et = C((nl, Xr) => {
        var Cn = bt(), Ze = Function.prototype.call;
        Xr.exports = Cn ? Ze.bind(Ze) : function() {
          return Ze.apply(Ze, arguments);
        };
      });
      var Yr = C(($r) => {
        "use strict";
        var Jr = {}.propertyIsEnumerable, Qr = Object.getOwnPropertyDescriptor, En = Qr && !Jr.call({ 1: 2 }, 1);
        $r.f = En ? function(u) {
          var o = Qr(this, u);
          return !!o && o.enumerable;
        } : Jr;
      });
      var _t = C((ol, Zr) => {
        Zr.exports = function(a, u) {
          return { enumerable: !(a & 1), configurable: !(a & 2), writable: !(a & 4), value: u };
        };
      });
      var ye = C((hl, ri) => {
        var ei = bt(), ti = Function.prototype, St = ti.call, bn = ei && ti.bind.bind(St, St);
        ri.exports = ei ? bn : function(a) {
          return function() {
            return St.apply(a, arguments);
          };
        };
      });
      var ai = C((ll, si) => {
        var ii = ye(), _n = ii({}.toString), Sn = ii("".slice);
        si.exports = function(a) {
          return Sn(_n(a), 8, -1);
        };
      });
      var ui = C((cl, ni) => {
        var wn = ye(), kn = me(), Fn = ai(), wt = Object, Bn = wn("".split);
        ni.exports = kn(function() {
          return !wt("z").propertyIsEnumerable(0);
        }) ? function(a) {
          return Fn(a) == "String" ? Bn(a, "") : wt(a);
        } : wt;
      });
      var kt = C((pl, oi) => {
        oi.exports = function(a) {
          return a == null;
        };
      });
      var Ft = C((fl, hi) => {
        var In = kt(), Tn = TypeError;
        hi.exports = function(a) {
          if (In(a))
            throw Tn("Can't call method on " + a);
          return a;
        };
      });
      var tt = C((dl, li) => {
        var Pn = ui(), Dn = Ft();
        li.exports = function(a) {
          return Pn(Dn(a));
        };
      });
      var It = C((ml, ci) => {
        var Bt = typeof document == "object" && document.all, Nn = typeof Bt > "u" && Bt !== void 0;
        ci.exports = { all: Bt, IS_HTMLDDA: Nn };
      });
      var le = C((vl, fi) => {
        var pi = It(), On = pi.all;
        fi.exports = pi.IS_HTMLDDA ? function(a) {
          return typeof a == "function" || a === On;
        } : function(a) {
          return typeof a == "function";
        };
      });
      var Pe = C((gl, vi) => {
        var di = le(), mi = It(), Ln = mi.all;
        vi.exports = mi.IS_HTMLDDA ? function(a) {
          return typeof a == "object" ? a !== null : di(a) || a === Ln;
        } : function(a) {
          return typeof a == "object" ? a !== null : di(a);
        };
      });
      var rt = C((xl, gi) => {
        var Tt = oe(), Vn = le(), Rn = function(a) {
          return Vn(a) ? a : void 0;
        };
        gi.exports = function(a, u) {
          return arguments.length < 2 ? Rn(Tt[a]) : Tt[a] && Tt[a][u];
        };
      });
      var yi = C((yl, xi) => {
        var jn = ye();
        xi.exports = jn({}.isPrototypeOf);
      });
      var Ci = C((Al, Ai) => {
        var qn = rt();
        Ai.exports = qn("navigator", "userAgent") || "";
      });
      var Fi = C((Cl, ki) => {
        var wi = oe(), Pt = Ci(), Ei = wi.process, bi = wi.Deno, _i = Ei && Ei.versions || bi && bi.version, Si = _i && _i.v8, ce, it2;
        Si && (ce = Si.split("."), it2 = ce[0] > 0 && ce[0] < 4 ? 1 : +(ce[0] + ce[1]));
        !it2 && Pt && (ce = Pt.match(/Edge\/(\d+)/), (!ce || ce[1] >= 74) && (ce = Pt.match(/Chrome\/(\d+)/), ce && (it2 = +ce[1])));
        ki.exports = it2;
      });
      var Dt = C((El, Ii) => {
        var Bi = Fi(), Mn = me();
        Ii.exports = !!Object.getOwnPropertySymbols && !Mn(function() {
          var a = Symbol();
          return !String(a) || !(Object(a) instanceof Symbol) || !Symbol.sham && Bi && Bi < 41;
        });
      });
      var Nt = C((bl, Ti) => {
        var Un = Dt();
        Ti.exports = Un && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var Ot = C((_l, Pi) => {
        var zn = rt(), Wn = le(), Gn = yi(), Hn = Nt(), Kn = Object;
        Pi.exports = Hn ? function(a) {
          return typeof a == "symbol";
        } : function(a) {
          var u = zn("Symbol");
          return Wn(u) && Gn(u.prototype, Kn(a));
        };
      });
      var Ni = C((Sl, Di) => {
        var Xn = String;
        Di.exports = function(a) {
          try {
            return Xn(a);
          } catch {
            return "Object";
          }
        };
      });
      var Li = C((wl, Oi) => {
        var Jn = le(), Qn = Ni(), $n = TypeError;
        Oi.exports = function(a) {
          if (Jn(a))
            return a;
          throw $n(Qn(a) + " is not a function");
        };
      });
      var Ri = C((kl, Vi) => {
        var Yn = Li(), Zn = kt();
        Vi.exports = function(a, u) {
          var o = a[u];
          return Zn(o) ? void 0 : Yn(o);
        };
      });
      var qi = C((Fl, ji) => {
        var Lt = et(), Vt = le(), Rt = Pe(), eu = TypeError;
        ji.exports = function(a, u) {
          var o, l;
          if (u === "string" && Vt(o = a.toString) && !Rt(l = Lt(o, a)) || Vt(o = a.valueOf) && !Rt(l = Lt(o, a)) || u !== "string" && Vt(o = a.toString) && !Rt(l = Lt(o, a)))
            return l;
          throw eu("Can't convert object to primitive value");
        };
      });
      var Ui = C((Bl, Mi) => {
        Mi.exports = false;
      });
      var st = C((Il, Wi) => {
        var zi = oe(), tu = Object.defineProperty;
        Wi.exports = function(a, u) {
          try {
            tu(zi, a, { value: u, configurable: true, writable: true });
          } catch {
            zi[a] = u;
          }
          return u;
        };
      });
      var at = C((Tl, Hi) => {
        var ru = oe(), iu = st(), Gi = "__core-js_shared__", su = ru[Gi] || iu(Gi, {});
        Hi.exports = su;
      });
      var jt = C((Pl, Xi) => {
        var au = Ui(), Ki = at();
        (Xi.exports = function(a, u) {
          return Ki[a] || (Ki[a] = u !== void 0 ? u : {});
        })("versions", []).push({ version: "3.26.1", mode: au ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var Qi = C((Dl, Ji) => {
        var nu = Ft(), uu = Object;
        Ji.exports = function(a) {
          return uu(nu(a));
        };
      });
      var be = C((Nl, $i) => {
        var ou = ye(), hu = Qi(), lu = ou({}.hasOwnProperty);
        $i.exports = Object.hasOwn || function(u, o) {
          return lu(hu(u), o);
        };
      });
      var qt = C((Ol, Yi) => {
        var cu = ye(), pu = 0, fu = Math.random(), du = cu(1 .toString);
        Yi.exports = function(a) {
          return "Symbol(" + (a === void 0 ? "" : a) + ")_" + du(++pu + fu, 36);
        };
      });
      var ss = C((Ll, is) => {
        var mu = oe(), vu = jt(), Zi = be(), gu = qt(), es = Dt(), rs = Nt(), De = vu("wks"), we = mu.Symbol, ts = we && we.for, xu = rs ? we : we && we.withoutSetter || gu;
        is.exports = function(a) {
          if (!Zi(De, a) || !(es || typeof De[a] == "string")) {
            var u = "Symbol." + a;
            es && Zi(we, a) ? De[a] = we[a] : rs && ts ? De[a] = ts(u) : De[a] = xu(u);
          }
          return De[a];
        };
      });
      var os = C((Vl, us) => {
        var yu = et(), as = Pe(), ns = Ot(), Au = Ri(), Cu = qi(), Eu = ss(), bu = TypeError, _u = Eu("toPrimitive");
        us.exports = function(a, u) {
          if (!as(a) || ns(a))
            return a;
          var o = Au(a, _u), l;
          if (o) {
            if (u === void 0 && (u = "default"), l = yu(o, a, u), !as(l) || ns(l))
              return l;
            throw bu("Can't convert object to primitive value");
          }
          return u === void 0 && (u = "number"), Cu(a, u);
        };
      });
      var Mt = C((Rl, hs) => {
        var Su = os(), wu = Ot();
        hs.exports = function(a) {
          var u = Su(a, "string");
          return wu(u) ? u : u + "";
        };
      });
      var ps = C((jl, cs) => {
        var ku = oe(), ls = Pe(), Ut = ku.document, Fu = ls(Ut) && ls(Ut.createElement);
        cs.exports = function(a) {
          return Fu ? Ut.createElement(a) : {};
        };
      });
      var zt = C((ql, fs2) => {
        var Bu = xe(), Iu = me(), Tu = ps();
        fs2.exports = !Bu && !Iu(function() {
          return Object.defineProperty(Tu("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Wt = C((ms) => {
        var Pu = xe(), Du = et(), Nu = Yr(), Ou = _t(), Lu = tt(), Vu = Mt(), Ru = be(), ju = zt(), ds = Object.getOwnPropertyDescriptor;
        ms.f = Pu ? ds : function(u, o) {
          if (u = Lu(u), o = Vu(o), ju)
            try {
              return ds(u, o);
            } catch {
            }
          if (Ru(u, o))
            return Ou(!Du(Nu.f, u, o), u[o]);
        };
      });
      var gs = C((Ul, vs) => {
        var qu = xe(), Mu = me();
        vs.exports = qu && Mu(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var nt = C((zl, xs) => {
        var Uu = Pe(), zu = String, Wu = TypeError;
        xs.exports = function(a) {
          if (Uu(a))
            return a;
          throw Wu(zu(a) + " is not an object");
        };
      });
      var Me = C((As) => {
        var Gu = xe(), Hu = zt(), Ku = gs(), ut = nt(), ys = Mt(), Xu = TypeError, Gt = Object.defineProperty, Ju = Object.getOwnPropertyDescriptor, Ht = "enumerable", Kt = "configurable", Xt = "writable";
        As.f = Gu ? Ku ? function(u, o, l) {
          if (ut(u), o = ys(o), ut(l), typeof u == "function" && o === "prototype" && "value" in l && Xt in l && !l[Xt]) {
            var d = Ju(u, o);
            d && d[Xt] && (u[o] = l.value, l = { configurable: Kt in l ? l[Kt] : d[Kt], enumerable: Ht in l ? l[Ht] : d[Ht], writable: false });
          }
          return Gt(u, o, l);
        } : Gt : function(u, o, l) {
          if (ut(u), o = ys(o), ut(l), Hu)
            try {
              return Gt(u, o, l);
            } catch {
            }
          if ("get" in l || "set" in l)
            throw Xu("Accessors not supported");
          return "value" in l && (u[o] = l.value), u;
        };
      });
      var Jt = C((Gl, Cs) => {
        var Qu = xe(), $u = Me(), Yu = _t();
        Cs.exports = Qu ? function(a, u, o) {
          return $u.f(a, u, Yu(1, o));
        } : function(a, u, o) {
          return a[u] = o, a;
        };
      });
      var _s = C((Hl, bs) => {
        var Qt = xe(), Zu = be(), Es = Function.prototype, eo = Qt && Object.getOwnPropertyDescriptor, $t = Zu(Es, "name"), to = $t && function() {
        }.name === "something", ro = $t && (!Qt || Qt && eo(Es, "name").configurable);
        bs.exports = { EXISTS: $t, PROPER: to, CONFIGURABLE: ro };
      });
      var ws = C((Kl, Ss) => {
        var io = ye(), so = le(), Yt = at(), ao = io(Function.toString);
        so(Yt.inspectSource) || (Yt.inspectSource = function(a) {
          return ao(a);
        });
        Ss.exports = Yt.inspectSource;
      });
      var Bs = C((Xl, Fs) => {
        var no = oe(), uo = le(), ks = no.WeakMap;
        Fs.exports = uo(ks) && /native code/.test(String(ks));
      });
      var Ps = C((Jl, Ts) => {
        var oo = jt(), ho = qt(), Is = oo("keys");
        Ts.exports = function(a) {
          return Is[a] || (Is[a] = ho(a));
        };
      });
      var Zt = C((Ql, Ds) => {
        Ds.exports = {};
      });
      var Vs = C(($l, Ls) => {
        var lo = Bs(), Os = oe(), co = Pe(), po = Jt(), er = be(), tr = at(), fo = Ps(), mo = Zt(), Ns = "Object already initialized", rr = Os.TypeError, vo = Os.WeakMap, ot, Ue, ht, go = function(a) {
          return ht(a) ? Ue(a) : ot(a, {});
        }, xo = function(a) {
          return function(u) {
            var o;
            if (!co(u) || (o = Ue(u)).type !== a)
              throw rr("Incompatible receiver, " + a + " required");
            return o;
          };
        };
        lo || tr.state ? (pe = tr.state || (tr.state = new vo()), pe.get = pe.get, pe.has = pe.has, pe.set = pe.set, ot = function(a, u) {
          if (pe.has(a))
            throw rr(Ns);
          return u.facade = a, pe.set(a, u), u;
        }, Ue = function(a) {
          return pe.get(a) || {};
        }, ht = function(a) {
          return pe.has(a);
        }) : (ke = fo("state"), mo[ke] = true, ot = function(a, u) {
          if (er(a, ke))
            throw rr(Ns);
          return u.facade = a, po(a, ke, u), u;
        }, Ue = function(a) {
          return er(a, ke) ? a[ke] : {};
        }, ht = function(a) {
          return er(a, ke);
        });
        var pe, ke;
        Ls.exports = { set: ot, get: Ue, has: ht, enforce: go, getterFor: xo };
      });
      var sr = C((Yl, js) => {
        var yo = me(), Ao = le(), lt = be(), ir = xe(), Co = _s().CONFIGURABLE, Eo = ws(), Rs = Vs(), bo = Rs.enforce, _o = Rs.get, ct = Object.defineProperty, So = ir && !yo(function() {
          return ct(function() {
          }, "length", { value: 8 }).length !== 8;
        }), wo = String(String).split("String"), ko = js.exports = function(a, u, o) {
          String(u).slice(0, 7) === "Symbol(" && (u = "[" + String(u).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), o && o.getter && (u = "get " + u), o && o.setter && (u = "set " + u), (!lt(a, "name") || Co && a.name !== u) && (ir ? ct(a, "name", { value: u, configurable: true }) : a.name = u), So && o && lt(o, "arity") && a.length !== o.arity && ct(a, "length", { value: o.arity });
          try {
            o && lt(o, "constructor") && o.constructor ? ir && ct(a, "prototype", { writable: false }) : a.prototype && (a.prototype = void 0);
          } catch {
          }
          var l = bo(a);
          return lt(l, "source") || (l.source = wo.join(typeof u == "string" ? u : "")), a;
        };
        Function.prototype.toString = ko(function() {
          return Ao(this) && _o(this).source || Eo(this);
        }, "toString");
      });
      var Ms = C((Zl, qs) => {
        var Fo = le(), Bo = Me(), Io = sr(), To = st();
        qs.exports = function(a, u, o, l) {
          l || (l = {});
          var d = l.enumerable, E = l.name !== void 0 ? l.name : u;
          if (Fo(o) && Io(o, E, l), l.global)
            d ? a[u] = o : To(u, o);
          else {
            try {
              l.unsafe ? a[u] && (d = true) : delete a[u];
            } catch {
            }
            d ? a[u] = o : Bo.f(a, u, { value: o, enumerable: false, configurable: !l.nonConfigurable, writable: !l.nonWritable });
          }
          return a;
        };
      });
      var zs = C((ec, Us) => {
        var Po = Math.ceil, Do = Math.floor;
        Us.exports = Math.trunc || function(u) {
          var o = +u;
          return (o > 0 ? Do : Po)(o);
        };
      });
      var ar = C((tc, Ws) => {
        var No = zs();
        Ws.exports = function(a) {
          var u = +a;
          return u !== u || u === 0 ? 0 : No(u);
        };
      });
      var Hs = C((rc, Gs) => {
        var Oo = ar(), Lo = Math.max, Vo = Math.min;
        Gs.exports = function(a, u) {
          var o = Oo(a);
          return o < 0 ? Lo(o + u, 0) : Vo(o, u);
        };
      });
      var Xs = C((ic, Ks) => {
        var Ro = ar(), jo = Math.min;
        Ks.exports = function(a) {
          return a > 0 ? jo(Ro(a), 9007199254740991) : 0;
        };
      });
      var Qs = C((sc, Js) => {
        var qo = Xs();
        Js.exports = function(a) {
          return qo(a.length);
        };
      });
      var Zs = C((ac, Ys) => {
        var Mo = tt(), Uo = Hs(), zo = Qs(), $s = function(a) {
          return function(u, o, l) {
            var d = Mo(u), E = zo(d), x = Uo(l, E), B;
            if (a && o != o) {
              for (; E > x; )
                if (B = d[x++], B != B)
                  return true;
            } else
              for (; E > x; x++)
                if ((a || x in d) && d[x] === o)
                  return a || x || 0;
            return !a && -1;
          };
        };
        Ys.exports = { includes: $s(true), indexOf: $s(false) };
      });
      var ra = C((nc, ta) => {
        var Wo = ye(), nr = be(), Go = tt(), Ho = Zs().indexOf, Ko = Zt(), ea = Wo([].push);
        ta.exports = function(a, u) {
          var o = Go(a), l = 0, d = [], E;
          for (E in o)
            !nr(Ko, E) && nr(o, E) && ea(d, E);
          for (; u.length > l; )
            nr(o, E = u[l++]) && (~Ho(d, E) || ea(d, E));
          return d;
        };
      });
      var sa = C((uc, ia) => {
        ia.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var na = C((aa) => {
        var Xo = ra(), Jo = sa(), Qo = Jo.concat("length", "prototype");
        aa.f = Object.getOwnPropertyNames || function(u) {
          return Xo(u, Qo);
        };
      });
      var oa = C((ua) => {
        ua.f = Object.getOwnPropertySymbols;
      });
      var la = C((lc, ha) => {
        var $o = rt(), Yo = ye(), Zo = na(), eh = oa(), th = nt(), rh = Yo([].concat);
        ha.exports = $o("Reflect", "ownKeys") || function(u) {
          var o = Zo.f(th(u)), l = eh.f;
          return l ? rh(o, l(u)) : o;
        };
      });
      var fa = C((cc, pa) => {
        var ca = be(), ih = la(), sh = Wt(), ah = Me();
        pa.exports = function(a, u, o) {
          for (var l = ih(u), d = ah.f, E = sh.f, x = 0; x < l.length; x++) {
            var B = l[x];
            !ca(a, B) && !(o && ca(o, B)) && d(a, B, E(u, B));
          }
        };
      });
      var ma = C((pc, da) => {
        var nh = me(), uh = le(), oh = /#|\.prototype\./, ze = function(a, u) {
          var o = lh[hh(a)];
          return o == ph ? true : o == ch ? false : uh(u) ? nh(u) : !!u;
        }, hh = ze.normalize = function(a) {
          return String(a).replace(oh, ".").toLowerCase();
        }, lh = ze.data = {}, ch = ze.NATIVE = "N", ph = ze.POLYFILL = "P";
        da.exports = ze;
      });
      var ga = C((fc, va) => {
        var ur = oe(), fh = Wt().f, dh = Jt(), mh = Ms(), vh = st(), gh = fa(), xh = ma();
        va.exports = function(a, u) {
          var o = a.target, l = a.global, d = a.stat, E, x, B, P, g, D;
          if (l ? x = ur : d ? x = ur[o] || vh(o, {}) : x = (ur[o] || {}).prototype, x)
            for (B in u) {
              if (g = u[B], a.dontCallGetSet ? (D = fh(x, B), P = D && D.value) : P = x[B], E = xh(l ? B : o + (d ? "." : "#") + B, a.forced), !E && P !== void 0) {
                if (typeof g == typeof P)
                  continue;
                gh(g, P);
              }
              (a.sham || P && P.sham) && dh(g, "sham", true), mh(x, B, g, a);
            }
        };
      });
      var xa = C(() => {
        var yh = ga(), or = oe();
        yh({ global: true, forced: or.globalThis !== or }, { globalThis: or });
      });
      var ya = C(() => {
        xa();
      });
      var Ea = C((xc, Ca) => {
        var Aa = sr(), Ah = Me();
        Ca.exports = function(a, u, o) {
          return o.get && Aa(o.get, u, { getter: true }), o.set && Aa(o.set, u, { setter: true }), Ah.f(a, u, o);
        };
      });
      var _a = C((yc, ba) => {
        "use strict";
        var Ch = nt();
        ba.exports = function() {
          var a = Ch(this), u = "";
          return a.hasIndices && (u += "d"), a.global && (u += "g"), a.ignoreCase && (u += "i"), a.multiline && (u += "m"), a.dotAll && (u += "s"), a.unicode && (u += "u"), a.unicodeSets && (u += "v"), a.sticky && (u += "y"), u;
        };
      });
      var ka = C(() => {
        var Eh = oe(), bh = xe(), _h = Ea(), Sh = _a(), wh = me(), Sa = Eh.RegExp, wa = Sa.prototype, kh = bh && wh(function() {
          var a = true;
          try {
            Sa(".", "d");
          } catch {
            a = false;
          }
          var u = {}, o = "", l = a ? "dgimsy" : "gimsy", d = function(P, g) {
            Object.defineProperty(u, P, { get: function() {
              return o += g, true;
            } });
          }, E = { dotAll: "s", global: "g", ignoreCase: "i", multiline: "m", sticky: "y" };
          a && (E.hasIndices = "d");
          for (var x in E)
            d(x, E[x]);
          var B = Object.getOwnPropertyDescriptor(wa, "flags").get.call(u);
          return B !== l || o !== l;
        });
        kh && _h(wa, "flags", { configurable: true, get: Sh });
      });
      var el = C((bc, Qa) => {
        ya();
        ka();
        var pr = Object.defineProperty, Fh = Object.getOwnPropertyDescriptor, fr = Object.getOwnPropertyNames, Bh = Object.prototype.hasOwnProperty, Fa = (a, u) => function() {
          return a && (u = (0, a[fr(a)[0]])(a = 0)), u;
        }, Q = (a, u) => function() {
          return u || (0, a[fr(a)[0]])((u = { exports: {} }).exports, u), u.exports;
        }, Ih = (a, u) => {
          for (var o in u)
            pr(a, o, { get: u[o], enumerable: true });
        }, Th = (a, u, o, l) => {
          if (u && typeof u == "object" || typeof u == "function")
            for (let d of fr(u))
              !Bh.call(a, d) && d !== o && pr(a, d, { get: () => u[d], enumerable: !(l = Fh(u, d)) || l.enumerable });
          return a;
        }, Ph = (a) => Th(pr({}, "__esModule", { value: true }), a), J = Fa({ "<define:process>"() {
        } }), dr = Q({ "src/common/parser-create-error.js"(a, u) {
          "use strict";
          J();
          function o(l, d) {
            let E = new SyntaxError(l + " (" + d.start.line + ":" + d.start.column + ")");
            return E.loc = d, E;
          }
          u.exports = o;
        } }), Ba = Q({ "src/utils/try-combinations.js"(a, u) {
          "use strict";
          J();
          function o() {
            let l;
            for (var d = arguments.length, E = new Array(d), x = 0; x < d; x++)
              E[x] = arguments[x];
            for (let [B, P] of E.entries())
              try {
                return { result: P() };
              } catch (g) {
                B === 0 && (l = g);
              }
            return { error: l };
          }
          u.exports = o;
        } }), Ia = {};
        Ih(Ia, { EOL: () => cr, arch: () => Dh, cpus: () => Va, default: () => Ua, endianness: () => Ta, freemem: () => Oa, getNetworkInterfaces: () => Ma, hostname: () => Pa, loadavg: () => Da, networkInterfaces: () => qa, platform: () => Nh, release: () => ja, tmpDir: () => hr, tmpdir: () => lr, totalmem: () => La, type: () => Ra, uptime: () => Na });
        function Ta() {
          if (typeof pt > "u") {
            var a = new ArrayBuffer(2), u = new Uint8Array(a), o = new Uint16Array(a);
            if (u[0] = 1, u[1] = 2, o[0] === 258)
              pt = "BE";
            else if (o[0] === 513)
              pt = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return pt;
        }
        function Pa() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function Da() {
          return [];
        }
        function Na() {
          return 0;
        }
        function Oa() {
          return Number.MAX_VALUE;
        }
        function La() {
          return Number.MAX_VALUE;
        }
        function Va() {
          return [];
        }
        function Ra() {
          return "Browser";
        }
        function ja() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function qa() {
        }
        function Ma() {
        }
        function Dh() {
          return "javascript";
        }
        function Nh() {
          return "browser";
        }
        function hr() {
          return "/tmp";
        }
        var pt, lr, cr, Ua, Oh = Fa({ "node-modules-polyfills:os"() {
          J(), lr = hr, cr = `
`, Ua = { EOL: cr, tmpdir: lr, tmpDir: hr, networkInterfaces: qa, getNetworkInterfaces: Ma, release: ja, type: Ra, cpus: Va, totalmem: La, freemem: Oa, uptime: Na, loadavg: Da, hostname: Pa, endianness: Ta };
        } }), Lh = Q({ "node-modules-polyfills-commonjs:os"(a, u) {
          J();
          var o = (Oh(), Ph(Ia));
          if (o && o.default) {
            u.exports = o.default;
            for (let l in o)
              u.exports[l] = o[l];
          } else
            o && (u.exports = o);
        } }), Vh = Q({ "node_modules/detect-newline/index.js"(a, u) {
          "use strict";
          J();
          var o = (l) => {
            if (typeof l != "string")
              throw new TypeError("Expected a string");
            let d = l.match(/(?:\r?\n)/g) || [];
            if (d.length === 0)
              return;
            let E = d.filter((B) => B === `\r
`).length, x = d.length - E;
            return E > x ? `\r
` : `
`;
          };
          u.exports = o, u.exports.graceful = (l) => typeof l == "string" && o(l) || `
`;
        } }), Rh = Q({ "node_modules/jest-docblock/build/index.js"(a) {
          "use strict";
          J(), Object.defineProperty(a, "__esModule", { value: true }), a.extract = N, a.parse = O, a.parseWithComments = S, a.print = _, a.strip = m;
          function u() {
            let A = Lh();
            return u = function() {
              return A;
            }, A;
          }
          function o() {
            let A = l(Vh());
            return o = function() {
              return A;
            }, A;
          }
          function l(A) {
            return A && A.__esModule ? A : { default: A };
          }
          var d = /\*\/$/, E = /^\/\*\*?/, x = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, B = /(^|\s+)\/\/([^\r\n]*)/g, P = /^(\r?\n)+/, g = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, D = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, q = /(\r?\n|^) *\* ?/g, I = [];
          function N(A) {
            let K = A.match(x);
            return K ? K[0].trimLeft() : "";
          }
          function m(A) {
            let K = A.match(x);
            return K && K[0] ? A.substring(K[0].length) : A;
          }
          function O(A) {
            return S(A).pragmas;
          }
          function S(A) {
            let K = (0, o().default)(A) || u().EOL;
            A = A.replace(E, "").replace(d, "").replace(q, "$1");
            let R = "";
            for (; R !== A; )
              R = A, A = A.replace(g, `${K}$1 $2${K}`);
            A = A.replace(P, "").trimRight();
            let i = /* @__PURE__ */ Object.create(null), k = A.replace(D, "").replace(P, "").trimRight(), T;
            for (; T = D.exec(A); ) {
              let M = T[2].replace(B, "");
              typeof i[T[1]] == "string" || Array.isArray(i[T[1]]) ? i[T[1]] = I.concat(i[T[1]], M) : i[T[1]] = M;
            }
            return { comments: k, pragmas: i };
          }
          function _(A) {
            let { comments: K = "", pragmas: R = {} } = A, i = (0, o().default)(K) || u().EOL, k = "/**", T = " *", M = " */", Z = Object.keys(R), ne = Z.map((ie) => F(ie, R[ie])).reduce((ie, Ne) => ie.concat(Ne), []).map((ie) => `${T} ${ie}${i}`).join("");
            if (!K) {
              if (Z.length === 0)
                return "";
              if (Z.length === 1 && !Array.isArray(R[Z[0]])) {
                let ie = R[Z[0]];
                return `${k} ${F(Z[0], ie)[0]}${M}`;
              }
            }
            let ee = K.split(i).map((ie) => `${T} ${ie}`).join(i) + i;
            return k + i + (K ? ee : "") + (K && Z.length ? T + i : "") + ne + M;
          }
          function F(A, K) {
            return I.concat(K).map((R) => `@${A} ${R}`.trim());
          }
        } }), jh = Q({ "src/common/end-of-line.js"(a, u) {
          "use strict";
          J();
          function o(x) {
            let B = x.indexOf("\r");
            return B >= 0 ? x.charAt(B + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function l(x) {
            switch (x) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function d(x, B) {
            let P;
            switch (B) {
              case `
`:
                P = /\n/g;
                break;
              case "\r":
                P = /\r/g;
                break;
              case `\r
`:
                P = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(B)}.`);
            }
            let g = x.match(P);
            return g ? g.length : 0;
          }
          function E(x) {
            return x.replace(/\r\n?/g, `
`);
          }
          u.exports = { guessEndOfLine: o, convertEndOfLineToChars: l, countEndOfLineChars: d, normalizeEndOfLine: E };
        } }), qh = Q({ "src/language-js/utils/get-shebang.js"(a, u) {
          "use strict";
          J();
          function o(l) {
            if (!l.startsWith("#!"))
              return "";
            let d = l.indexOf(`
`);
            return d === -1 ? l : l.slice(0, d);
          }
          u.exports = o;
        } }), Mh = Q({ "src/language-js/pragma.js"(a, u) {
          "use strict";
          J();
          var { parseWithComments: o, strip: l, extract: d, print: E } = Rh(), { normalizeEndOfLine: x } = jh(), B = qh();
          function P(q) {
            let I = B(q);
            I && (q = q.slice(I.length + 1));
            let N = d(q), { pragmas: m, comments: O } = o(N);
            return { shebang: I, text: q, pragmas: m, comments: O };
          }
          function g(q) {
            let I = Object.keys(P(q).pragmas);
            return I.includes("prettier") || I.includes("format");
          }
          function D(q) {
            let { shebang: I, text: N, pragmas: m, comments: O } = P(q), S = l(N), _ = E({ pragmas: Object.assign({ format: "" }, m), comments: O.trimStart() });
            return (I ? `${I}
` : "") + x(_) + (S.startsWith(`
`) ? `
` : `

`) + S;
          }
          u.exports = { hasPragma: g, insertPragma: D };
        } }), za = Q({ "src/utils/is-non-empty-array.js"(a, u) {
          "use strict";
          J();
          function o(l) {
            return Array.isArray(l) && l.length > 0;
          }
          u.exports = o;
        } }), Wa = Q({ "src/language-js/loc.js"(a, u) {
          "use strict";
          J();
          var o = za();
          function l(P) {
            var g, D;
            let q = P.range ? P.range[0] : P.start, I = (g = (D = P.declaration) === null || D === void 0 ? void 0 : D.decorators) !== null && g !== void 0 ? g : P.decorators;
            return o(I) ? Math.min(l(I[0]), q) : q;
          }
          function d(P) {
            return P.range ? P.range[1] : P.end;
          }
          function E(P, g) {
            let D = l(P);
            return Number.isInteger(D) && D === l(g);
          }
          function x(P, g) {
            let D = d(P);
            return Number.isInteger(D) && D === d(g);
          }
          function B(P, g) {
            return E(P, g) && x(P, g);
          }
          u.exports = { locStart: l, locEnd: d, hasSameLocStart: E, hasSameLoc: B };
        } }), Ga = Q({ "src/language-js/parse/utils/create-parser.js"(a, u) {
          "use strict";
          J();
          var { hasPragma: o } = Mh(), { locStart: l, locEnd: d } = Wa();
          function E(x) {
            return x = typeof x == "function" ? { parse: x } : x, Object.assign({ astFormat: "estree", hasPragma: o, locStart: l, locEnd: d }, x);
          }
          u.exports = E;
        } }), Uh = Q({ "src/language-js/utils/is-ts-keyword-type.js"(a, u) {
          "use strict";
          J();
          function o(l) {
            let { type: d } = l;
            return d.startsWith("TS") && d.endsWith("Keyword");
          }
          u.exports = o;
        } }), zh = Q({ "src/language-js/utils/is-block-comment.js"(a, u) {
          "use strict";
          J();
          var o = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]), l = (d) => o.has(d == null ? void 0 : d.type);
          u.exports = l;
        } }), Wh = Q({ "src/language-js/utils/is-type-cast-comment.js"(a, u) {
          "use strict";
          J();
          var o = zh();
          function l(d) {
            return o(d) && d.value[0] === "*" && /@type\b/.test(d.value);
          }
          u.exports = l;
        } }), Gh = Q({ "src/utils/get-last.js"(a, u) {
          "use strict";
          J();
          var o = (l) => l[l.length - 1];
          u.exports = o;
        } }), Ha = Q({ "src/language-js/parse/postprocess/visit-node.js"(a, u) {
          "use strict";
          J();
          function o(l, d) {
            if (Array.isArray(l)) {
              for (let E = 0; E < l.length; E++)
                l[E] = o(l[E], d);
              return l;
            }
            if (l && typeof l == "object" && typeof l.type == "string") {
              let E = Object.keys(l);
              for (let x = 0; x < E.length; x++)
                l[E[x]] = o(l[E[x]], d);
              return d(l) || l;
            }
            return l;
          }
          u.exports = o;
        } }), Ka = Q({ "src/language-js/parse/postprocess/throw-syntax-error.js"(a, u) {
          "use strict";
          J();
          var o = dr();
          function l(d, E) {
            let { start: x, end: B } = d.loc;
            throw o(E, { start: { line: x.line, column: x.column + 1 }, end: { line: B.line, column: B.column + 1 } });
          }
          u.exports = l;
        } }), Hh = Q({ "src/language-js/parse/postprocess/typescript.js"(a, u) {
          "use strict";
          J();
          var o = za(), l = Ha(), d = Ka(), E = { AbstractKeyword: 126, SourceFile: 308, PropertyDeclaration: 169 };
          function x(D) {
            for (; D && D.kind !== E.SourceFile; )
              D = D.parent;
            return D;
          }
          function B(D) {
            let { illegalDecorators: q } = D;
            if (!o(q))
              return;
            let [{ expression: I }] = q, N = x(I), [m, O] = [I.pos, I.end].map((S) => {
              let { line: _, character: F } = N.getLineAndCharacterOfPosition(S);
              return { line: _ + 1, column: F };
            });
            d({ loc: { start: m, end: O } }, "Decorators are not valid here.");
          }
          function P(D, q) {
            D.kind !== E.PropertyDeclaration || D.modifiers && !D.modifiers.some((I) => I.kind === E.AbstractKeyword) || D.initializer && q.value === null && d(q, "Abstract property cannot have an initializer");
          }
          function g(D, q) {
            let { esTreeNodeToTSNodeMap: I, tsNodeToESTreeNodeMap: N } = q.tsParseResult;
            l(D, (m) => {
              let O = I.get(m);
              if (!O)
                return;
              let S = N.get(O);
              S === m && (B(O), P(O, S));
            });
          }
          u.exports = { throwErrorForInvalidNodes: g };
        } }), Xa = Q({ "src/language-js/parse/postprocess/index.js"(a, u) {
          "use strict";
          J();
          var { locStart: o, locEnd: l } = Wa(), d = Uh(), E = Wh(), x = Gh(), B = Ha(), { throwErrorForInvalidNodes: P } = Hh(), g = Ka();
          function D(m, O) {
            if (O.parser === "typescript" && /@|abstract/.test(O.originalText) && P(m, O), O.parser !== "typescript" && O.parser !== "flow" && O.parser !== "acorn" && O.parser !== "espree" && O.parser !== "meriyah") {
              let _ = /* @__PURE__ */ new Set();
              m = B(m, (F) => {
                F.leadingComments && F.leadingComments.some(E) && _.add(o(F));
              }), m = B(m, (F) => {
                if (F.type === "ParenthesizedExpression") {
                  let { expression: A } = F;
                  if (A.type === "TypeCastExpression")
                    return A.range = F.range, A;
                  let K = o(F);
                  if (!_.has(K))
                    return A.extra = Object.assign(Object.assign({}, A.extra), {}, { parenthesized: true }), A;
                }
              });
            }
            return m = B(m, (_) => {
              switch (_.type) {
                case "ChainExpression":
                  return q(_.expression);
                case "LogicalExpression": {
                  if (I(_))
                    return N(_);
                  break;
                }
                case "VariableDeclaration": {
                  let F = x(_.declarations);
                  F && F.init && S(_, F);
                  break;
                }
                case "TSParenthesizedType":
                  return d(_.typeAnnotation) || _.typeAnnotation.type === "TSThisType" || (_.typeAnnotation.range = [o(_), l(_)]), _.typeAnnotation;
                case "TSTypeParameter":
                  if (typeof _.name == "string") {
                    let F = o(_);
                    _.name = { type: "Identifier", name: _.name, range: [F, F + _.name.length] };
                  }
                  break;
                case "ObjectExpression":
                  if (O.parser === "typescript") {
                    let F = _.properties.find((A) => A.type === "Property" && A.value.type === "TSEmptyBodyFunctionExpression");
                    F && g(F.value, "Unexpected token.");
                  }
                  break;
                case "SequenceExpression": {
                  let F = x(_.expressions);
                  _.range = [o(_), Math.min(l(F), l(_))];
                  break;
                }
                case "TopicReference":
                  O.__isUsingHackPipeline = true;
                  break;
                case "ExportAllDeclaration": {
                  let { exported: F } = _;
                  if (O.parser === "meriyah" && F && F.type === "Identifier") {
                    let A = O.originalText.slice(o(F), l(F));
                    (A.startsWith('"') || A.startsWith("'")) && (_.exported = Object.assign(Object.assign({}, _.exported), {}, { type: "Literal", value: _.exported.name, raw: A }));
                  }
                  break;
                }
                case "PropertyDefinition":
                  if (O.parser === "meriyah" && _.static && !_.computed && !_.key) {
                    let F = "static", A = o(_);
                    Object.assign(_, { static: false, key: { type: "Identifier", name: F, range: [A, A + F.length] } });
                  }
                  break;
              }
            }), m;
            function S(_, F) {
              O.originalText[l(F)] !== ";" && (_.range = [o(_), l(F)]);
            }
          }
          function q(m) {
            switch (m.type) {
              case "CallExpression":
                m.type = "OptionalCallExpression", m.callee = q(m.callee);
                break;
              case "MemberExpression":
                m.type = "OptionalMemberExpression", m.object = q(m.object);
                break;
              case "TSNonNullExpression":
                m.expression = q(m.expression);
                break;
            }
            return m;
          }
          function I(m) {
            return m.type === "LogicalExpression" && m.right.type === "LogicalExpression" && m.operator === m.right.operator;
          }
          function N(m) {
            return I(m) ? N({ type: "LogicalExpression", operator: m.operator, left: N({ type: "LogicalExpression", operator: m.operator, left: m.left, right: m.right.left, range: [o(m.left), l(m.right.left)] }), right: m.right.right, range: [o(m), l(m)] }) : m;
          }
          u.exports = D;
        } }), ft = Q({ "node_modules/acorn/dist/acorn.js"(a, u) {
          J(), function(o, l) {
            typeof a == "object" && typeof u < "u" ? l(a) : typeof define == "function" && define.amd ? define(["exports"], l) : (o = typeof globalThis < "u" ? globalThis : o || self, l(o.acorn = {}));
          }(a, function(o) {
            "use strict";
            var l = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 154, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 161, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 19306, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 262, 6, 10, 9, 357, 0, 62, 13, 1495, 6, 110, 6, 6, 9, 4759, 9, 787719, 239], d = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 85, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 190, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1070, 4050, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 46, 2, 18, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 482, 44, 11, 6, 17, 0, 322, 29, 19, 43, 1269, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4152, 8, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938], E = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECD\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F", x = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC", B = { 3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile", 5: "class enum extends super const export import", 6: "enum", strict: "implements interface let package private protected public static yield", strictBind: "eval arguments" }, P = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this", g = { 5: P, "5module": P + " export import", 6: P + " const class extends export import super" }, D = /^in(stanceof)?$/, q = new RegExp("[" + x + "]"), I = new RegExp("[" + x + E + "]");
            function N(e, t3) {
              for (var r = 65536, s = 0; s < t3.length; s += 2) {
                if (r += t3[s], r > e)
                  return false;
                if (r += t3[s + 1], r >= e)
                  return true;
              }
            }
            function m(e, t3) {
              return e < 65 ? e === 36 : e < 91 ? true : e < 97 ? e === 95 : e < 123 ? true : e <= 65535 ? e >= 170 && q.test(String.fromCharCode(e)) : t3 === false ? false : N(e, d);
            }
            function O(e, t3) {
              return e < 48 ? e === 36 : e < 58 ? true : e < 65 ? false : e < 91 ? true : e < 97 ? e === 95 : e < 123 ? true : e <= 65535 ? e >= 170 && I.test(String.fromCharCode(e)) : t3 === false ? false : N(e, d) || N(e, l);
            }
            var S = function(t3, r) {
              r === void 0 && (r = {}), this.label = t3, this.keyword = r.keyword, this.beforeExpr = !!r.beforeExpr, this.startsExpr = !!r.startsExpr, this.isLoop = !!r.isLoop, this.isAssign = !!r.isAssign, this.prefix = !!r.prefix, this.postfix = !!r.postfix, this.binop = r.binop || null, this.updateContext = null;
            };
            function _(e, t3) {
              return new S(e, { beforeExpr: true, binop: t3 });
            }
            var F = { beforeExpr: true }, A = { startsExpr: true }, K = {};
            function R(e, t3) {
              return t3 === void 0 && (t3 = {}), t3.keyword = e, K[e] = new S(e, t3);
            }
            var i = { num: new S("num", A), regexp: new S("regexp", A), string: new S("string", A), name: new S("name", A), privateId: new S("privateId", A), eof: new S("eof"), bracketL: new S("[", { beforeExpr: true, startsExpr: true }), bracketR: new S("]"), braceL: new S("{", { beforeExpr: true, startsExpr: true }), braceR: new S("}"), parenL: new S("(", { beforeExpr: true, startsExpr: true }), parenR: new S(")"), comma: new S(",", F), semi: new S(";", F), colon: new S(":", F), dot: new S("."), question: new S("?", F), questionDot: new S("?."), arrow: new S("=>", F), template: new S("template"), invalidTemplate: new S("invalidTemplate"), ellipsis: new S("...", F), backQuote: new S("`", A), dollarBraceL: new S("${", { beforeExpr: true, startsExpr: true }), eq: new S("=", { beforeExpr: true, isAssign: true }), assign: new S("_=", { beforeExpr: true, isAssign: true }), incDec: new S("++/--", { prefix: true, postfix: true, startsExpr: true }), prefix: new S("!/~", { beforeExpr: true, prefix: true, startsExpr: true }), logicalOR: _("||", 1), logicalAND: _("&&", 2), bitwiseOR: _("|", 3), bitwiseXOR: _("^", 4), bitwiseAND: _("&", 5), equality: _("==/!=/===/!==", 6), relational: _("</>/<=/>=", 7), bitShift: _("<</>>/>>>", 8), plusMin: new S("+/-", { beforeExpr: true, binop: 9, prefix: true, startsExpr: true }), modulo: _("%", 10), star: _("*", 10), slash: _("/", 10), starstar: new S("**", { beforeExpr: true }), coalesce: _("??", 1), _break: R("break"), _case: R("case", F), _catch: R("catch"), _continue: R("continue"), _debugger: R("debugger"), _default: R("default", F), _do: R("do", { isLoop: true, beforeExpr: true }), _else: R("else", F), _finally: R("finally"), _for: R("for", { isLoop: true }), _function: R("function", A), _if: R("if"), _return: R("return", F), _switch: R("switch"), _throw: R("throw", F), _try: R("try"), _var: R("var"), _const: R("const"), _while: R("while", { isLoop: true }), _with: R("with"), _new: R("new", { beforeExpr: true, startsExpr: true }), _this: R("this", A), _super: R("super", A), _class: R("class", A), _extends: R("extends", F), _export: R("export"), _import: R("import", A), _null: R("null", A), _true: R("true", A), _false: R("false", A), _in: R("in", { beforeExpr: true, binop: 7 }), _instanceof: R("instanceof", { beforeExpr: true, binop: 7 }), _typeof: R("typeof", { beforeExpr: true, prefix: true, startsExpr: true }), _void: R("void", { beforeExpr: true, prefix: true, startsExpr: true }), _delete: R("delete", { beforeExpr: true, prefix: true, startsExpr: true }) }, k = /\r\n?|\n|\u2028|\u2029/, T = new RegExp(k.source, "g");
            function M(e) {
              return e === 10 || e === 13 || e === 8232 || e === 8233;
            }
            function Z(e, t3, r) {
              r === void 0 && (r = e.length);
              for (var s = t3; s < r; s++) {
                var n = e.charCodeAt(s);
                if (M(n))
                  return s < r - 1 && n === 13 && e.charCodeAt(s + 1) === 10 ? s + 2 : s + 1;
              }
              return -1;
            }
            var ne = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/, ee = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, ie = Object.prototype, Ne = ie.hasOwnProperty, p = ie.toString, L = Object.hasOwn || function(e, t3) {
              return Ne.call(e, t3);
            }, w = Array.isArray || function(e) {
              return p.call(e) === "[object Array]";
            };
            function f(e) {
              return new RegExp("^(?:" + e.replace(/ /g, "|") + ")$");
            }
            function b(e) {
              return e <= 65535 ? String.fromCharCode(e) : (e -= 65536, String.fromCharCode((e >> 10) + 55296, (e & 1023) + 56320));
            }
            var X = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/, H = function(t3, r) {
              this.line = t3, this.column = r;
            };
            H.prototype.offset = function(t3) {
              return new H(this.line, this.column + t3);
            };
            var te = function(t3, r, s) {
              this.start = r, this.end = s, t3.sourceFile !== null && (this.source = t3.sourceFile);
            };
            function ae(e, t3) {
              for (var r = 1, s = 0; ; ) {
                var n = Z(e, s, t3);
                if (n < 0)
                  return new H(r, t3 - s);
                ++r, s = n;
              }
            }
            var fe = { ecmaVersion: null, sourceType: "script", onInsertedSemicolon: null, onTrailingComma: null, allowReserved: null, allowReturnOutsideFunction: false, allowImportExportEverywhere: false, allowAwaitOutsideFunction: null, allowSuperOutsideMethod: null, allowHashBang: false, locations: false, onToken: null, onComment: null, ranges: false, program: null, sourceFile: null, directSourceFile: null, preserveParens: false }, Ae = false;
            function dt(e) {
              var t3 = {};
              for (var r in fe)
                t3[r] = e && L(e, r) ? e[r] : fe[r];
              if (t3.ecmaVersion === "latest" ? t3.ecmaVersion = 1e8 : t3.ecmaVersion == null ? (!Ae && typeof console == "object" && console.warn && (Ae = true, console.warn(`Since Acorn 8.0.0, options.ecmaVersion is required.
Defaulting to 2020, but this will stop working in the future.`)), t3.ecmaVersion = 11) : t3.ecmaVersion >= 2015 && (t3.ecmaVersion -= 2009), t3.allowReserved == null && (t3.allowReserved = t3.ecmaVersion < 5), e.allowHashBang == null && (t3.allowHashBang = t3.ecmaVersion >= 14), w(t3.onToken)) {
                var s = t3.onToken;
                t3.onToken = function(n) {
                  return s.push(n);
                };
              }
              return w(t3.onComment) && (t3.onComment = mt(t3, t3.onComment)), t3;
            }
            function mt(e, t3) {
              return function(r, s, n, h, c, v) {
                var y = { type: r ? "Block" : "Line", value: s, start: n, end: h };
                e.locations && (y.loc = new te(this, c, v)), e.ranges && (y.range = [n, h]), t3.push(y);
              };
            }
            var _e = 1, Ce = 2, Oe = 4, We = 8, mr = 16, vr = 32, vt = 64, gr = 128, Le = 256, gt = _e | Ce | Le;
            function xt(e, t3) {
              return Ce | (e ? Oe : 0) | (t3 ? We : 0);
            }
            var Ge = 0, yt = 1, ve = 2, xr = 3, yr = 4, Ar = 5, Y = function(t3, r, s) {
              this.options = t3 = dt(t3), this.sourceFile = t3.sourceFile, this.keywords = f(g[t3.ecmaVersion >= 6 ? 6 : t3.sourceType === "module" ? "5module" : 5]);
              var n = "";
              t3.allowReserved !== true && (n = B[t3.ecmaVersion >= 6 ? 6 : t3.ecmaVersion === 5 ? 5 : 3], t3.sourceType === "module" && (n += " await")), this.reservedWords = f(n);
              var h = (n ? n + " " : "") + B.strict;
              this.reservedWordsStrict = f(h), this.reservedWordsStrictBind = f(h + " " + B.strictBind), this.input = String(r), this.containsEsc = false, s ? (this.pos = s, this.lineStart = this.input.lastIndexOf(`
`, s - 1) + 1, this.curLine = this.input.slice(0, this.lineStart).split(k).length) : (this.pos = this.lineStart = 0, this.curLine = 1), this.type = i.eof, this.value = null, this.start = this.end = this.pos, this.startLoc = this.endLoc = this.curPosition(), this.lastTokEndLoc = this.lastTokStartLoc = null, this.lastTokStart = this.lastTokEnd = this.pos, this.context = this.initialContext(), this.exprAllowed = true, this.inModule = t3.sourceType === "module", this.strict = this.inModule || this.strictDirective(this.pos), this.potentialArrowAt = -1, this.potentialArrowInForAwait = false, this.yieldPos = this.awaitPos = this.awaitIdentPos = 0, this.labels = [], this.undefinedExports = /* @__PURE__ */ Object.create(null), this.pos === 0 && t3.allowHashBang && this.input.slice(0, 2) === "#!" && this.skipLineComment(2), this.scopeStack = [], this.enterScope(_e), this.regexpState = null, this.privateNameStack = [];
            }, de = { inFunction: { configurable: true }, inGenerator: { configurable: true }, inAsync: { configurable: true }, canAwait: { configurable: true }, allowSuper: { configurable: true }, allowDirectSuper: { configurable: true }, treatFunctionsAsVar: { configurable: true }, allowNewDotTarget: { configurable: true }, inClassStaticBlock: { configurable: true } };
            Y.prototype.parse = function() {
              var t3 = this.options.program || this.startNode();
              return this.nextToken(), this.parseTopLevel(t3);
            }, de.inFunction.get = function() {
              return (this.currentVarScope().flags & Ce) > 0;
            }, de.inGenerator.get = function() {
              return (this.currentVarScope().flags & We) > 0 && !this.currentVarScope().inClassFieldInit;
            }, de.inAsync.get = function() {
              return (this.currentVarScope().flags & Oe) > 0 && !this.currentVarScope().inClassFieldInit;
            }, de.canAwait.get = function() {
              for (var e = this.scopeStack.length - 1; e >= 0; e--) {
                var t3 = this.scopeStack[e];
                if (t3.inClassFieldInit || t3.flags & Le)
                  return false;
                if (t3.flags & Ce)
                  return (t3.flags & Oe) > 0;
              }
              return this.inModule && this.options.ecmaVersion >= 13 || this.options.allowAwaitOutsideFunction;
            }, de.allowSuper.get = function() {
              var e = this.currentThisScope(), t3 = e.flags, r = e.inClassFieldInit;
              return (t3 & vt) > 0 || r || this.options.allowSuperOutsideMethod;
            }, de.allowDirectSuper.get = function() {
              return (this.currentThisScope().flags & gr) > 0;
            }, de.treatFunctionsAsVar.get = function() {
              return this.treatFunctionsAsVarInScope(this.currentScope());
            }, de.allowNewDotTarget.get = function() {
              var e = this.currentThisScope(), t3 = e.flags, r = e.inClassFieldInit;
              return (t3 & (Ce | Le)) > 0 || r;
            }, de.inClassStaticBlock.get = function() {
              return (this.currentVarScope().flags & Le) > 0;
            }, Y.extend = function() {
              for (var t3 = [], r = arguments.length; r--; )
                t3[r] = arguments[r];
              for (var s = this, n = 0; n < t3.length; n++)
                s = t3[n](s);
              return s;
            }, Y.parse = function(t3, r) {
              return new this(r, t3).parse();
            }, Y.parseExpressionAt = function(t3, r, s) {
              var n = new this(s, t3, r);
              return n.nextToken(), n.parseExpression();
            }, Y.tokenizer = function(t3, r) {
              return new this(r, t3);
            }, Object.defineProperties(Y.prototype, de);
            var se = Y.prototype, $a = /^(?:'((?:\\.|[^'\\])*?)'|"((?:\\.|[^"\\])*?)")/;
            se.strictDirective = function(e) {
              if (this.options.ecmaVersion < 5)
                return false;
              for (; ; ) {
                ee.lastIndex = e, e += ee.exec(this.input)[0].length;
                var t3 = $a.exec(this.input.slice(e));
                if (!t3)
                  return false;
                if ((t3[1] || t3[2]) === "use strict") {
                  ee.lastIndex = e + t3[0].length;
                  var r = ee.exec(this.input), s = r.index + r[0].length, n = this.input.charAt(s);
                  return n === ";" || n === "}" || k.test(r[0]) && !(/[(`.[+\-/*%<>=,?^&]/.test(n) || n === "!" && this.input.charAt(s + 1) === "=");
                }
                e += t3[0].length, ee.lastIndex = e, e += ee.exec(this.input)[0].length, this.input[e] === ";" && e++;
              }
            }, se.eat = function(e) {
              return this.type === e ? (this.next(), true) : false;
            }, se.isContextual = function(e) {
              return this.type === i.name && this.value === e && !this.containsEsc;
            }, se.eatContextual = function(e) {
              return this.isContextual(e) ? (this.next(), true) : false;
            }, se.expectContextual = function(e) {
              this.eatContextual(e) || this.unexpected();
            }, se.canInsertSemicolon = function() {
              return this.type === i.eof || this.type === i.braceR || k.test(this.input.slice(this.lastTokEnd, this.start));
            }, se.insertSemicolon = function() {
              if (this.canInsertSemicolon())
                return this.options.onInsertedSemicolon && this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc), true;
            }, se.semicolon = function() {
              !this.eat(i.semi) && !this.insertSemicolon() && this.unexpected();
            }, se.afterTrailingComma = function(e, t3) {
              if (this.type === e)
                return this.options.onTrailingComma && this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc), t3 || this.next(), true;
            }, se.expect = function(e) {
              this.eat(e) || this.unexpected();
            }, se.unexpected = function(e) {
              this.raise(e != null ? e : this.start, "Unexpected token");
            };
            var He = function() {
              this.shorthandAssign = this.trailingComma = this.parenthesizedAssign = this.parenthesizedBind = this.doubleProto = -1;
            };
            se.checkPatternErrors = function(e, t3) {
              if (e) {
                e.trailingComma > -1 && this.raiseRecoverable(e.trailingComma, "Comma is not permitted after the rest element");
                var r = t3 ? e.parenthesizedAssign : e.parenthesizedBind;
                r > -1 && this.raiseRecoverable(r, t3 ? "Assigning to rvalue" : "Parenthesized pattern");
              }
            }, se.checkExpressionErrors = function(e, t3) {
              if (!e)
                return false;
              var r = e.shorthandAssign, s = e.doubleProto;
              if (!t3)
                return r >= 0 || s >= 0;
              r >= 0 && this.raise(r, "Shorthand property assignments are valid only in destructuring patterns"), s >= 0 && this.raiseRecoverable(s, "Redefinition of __proto__ property");
            }, se.checkYieldAwaitInDefaultParams = function() {
              this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos) && this.raise(this.yieldPos, "Yield expression cannot be a default value"), this.awaitPos && this.raise(this.awaitPos, "Await expression cannot be a default value");
            }, se.isSimpleAssignTarget = function(e) {
              return e.type === "ParenthesizedExpression" ? this.isSimpleAssignTarget(e.expression) : e.type === "Identifier" || e.type === "MemberExpression";
            };
            var j = Y.prototype;
            j.parseTopLevel = function(e) {
              var t3 = /* @__PURE__ */ Object.create(null);
              for (e.body || (e.body = []); this.type !== i.eof; ) {
                var r = this.parseStatement(null, true, t3);
                e.body.push(r);
              }
              if (this.inModule)
                for (var s = 0, n = Object.keys(this.undefinedExports); s < n.length; s += 1) {
                  var h = n[s];
                  this.raiseRecoverable(this.undefinedExports[h].start, "Export '" + h + "' is not defined");
                }
              return this.adaptDirectivePrologue(e.body), this.next(), e.sourceType = this.options.sourceType, this.finishNode(e, "Program");
            };
            var At = { kind: "loop" }, Ya = { kind: "switch" };
            j.isLet = function(e) {
              if (this.options.ecmaVersion < 6 || !this.isContextual("let"))
                return false;
              ee.lastIndex = this.pos;
              var t3 = ee.exec(this.input), r = this.pos + t3[0].length, s = this.input.charCodeAt(r);
              if (s === 91 || s === 92 || s > 55295 && s < 56320)
                return true;
              if (e)
                return false;
              if (s === 123)
                return true;
              if (m(s, true)) {
                for (var n = r + 1; O(s = this.input.charCodeAt(n), true); )
                  ++n;
                if (s === 92 || s > 55295 && s < 56320)
                  return true;
                var h = this.input.slice(r, n);
                if (!D.test(h))
                  return true;
              }
              return false;
            }, j.isAsyncFunction = function() {
              if (this.options.ecmaVersion < 8 || !this.isContextual("async"))
                return false;
              ee.lastIndex = this.pos;
              var e = ee.exec(this.input), t3 = this.pos + e[0].length, r;
              return !k.test(this.input.slice(this.pos, t3)) && this.input.slice(t3, t3 + 8) === "function" && (t3 + 8 === this.input.length || !(O(r = this.input.charCodeAt(t3 + 8)) || r > 55295 && r < 56320));
            }, j.parseStatement = function(e, t3, r) {
              var s = this.type, n = this.startNode(), h;
              switch (this.isLet(e) && (s = i._var, h = "let"), s) {
                case i._break:
                case i._continue:
                  return this.parseBreakContinueStatement(n, s.keyword);
                case i._debugger:
                  return this.parseDebuggerStatement(n);
                case i._do:
                  return this.parseDoStatement(n);
                case i._for:
                  return this.parseForStatement(n);
                case i._function:
                  return e && (this.strict || e !== "if" && e !== "label") && this.options.ecmaVersion >= 6 && this.unexpected(), this.parseFunctionStatement(n, false, !e);
                case i._class:
                  return e && this.unexpected(), this.parseClass(n, true);
                case i._if:
                  return this.parseIfStatement(n);
                case i._return:
                  return this.parseReturnStatement(n);
                case i._switch:
                  return this.parseSwitchStatement(n);
                case i._throw:
                  return this.parseThrowStatement(n);
                case i._try:
                  return this.parseTryStatement(n);
                case i._const:
                case i._var:
                  return h = h || this.value, e && h !== "var" && this.unexpected(), this.parseVarStatement(n, h);
                case i._while:
                  return this.parseWhileStatement(n);
                case i._with:
                  return this.parseWithStatement(n);
                case i.braceL:
                  return this.parseBlock(true, n);
                case i.semi:
                  return this.parseEmptyStatement(n);
                case i._export:
                case i._import:
                  if (this.options.ecmaVersion > 10 && s === i._import) {
                    ee.lastIndex = this.pos;
                    var c = ee.exec(this.input), v = this.pos + c[0].length, y = this.input.charCodeAt(v);
                    if (y === 40 || y === 46)
                      return this.parseExpressionStatement(n, this.parseExpression());
                  }
                  return this.options.allowImportExportEverywhere || (t3 || this.raise(this.start, "'import' and 'export' may only appear at the top level"), this.inModule || this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'")), s === i._import ? this.parseImport(n) : this.parseExport(n, r);
                default:
                  if (this.isAsyncFunction())
                    return e && this.unexpected(), this.next(), this.parseFunctionStatement(n, true, !e);
                  var U = this.value, W = this.parseExpression();
                  return s === i.name && W.type === "Identifier" && this.eat(i.colon) ? this.parseLabeledStatement(n, U, W, e) : this.parseExpressionStatement(n, W);
              }
            }, j.parseBreakContinueStatement = function(e, t3) {
              var r = t3 === "break";
              this.next(), this.eat(i.semi) || this.insertSemicolon() ? e.label = null : this.type !== i.name ? this.unexpected() : (e.label = this.parseIdent(), this.semicolon());
              for (var s = 0; s < this.labels.length; ++s) {
                var n = this.labels[s];
                if ((e.label == null || n.name === e.label.name) && (n.kind != null && (r || n.kind === "loop") || e.label && r))
                  break;
              }
              return s === this.labels.length && this.raise(e.start, "Unsyntactic " + t3), this.finishNode(e, r ? "BreakStatement" : "ContinueStatement");
            }, j.parseDebuggerStatement = function(e) {
              return this.next(), this.semicolon(), this.finishNode(e, "DebuggerStatement");
            }, j.parseDoStatement = function(e) {
              return this.next(), this.labels.push(At), e.body = this.parseStatement("do"), this.labels.pop(), this.expect(i._while), e.test = this.parseParenExpression(), this.options.ecmaVersion >= 6 ? this.eat(i.semi) : this.semicolon(), this.finishNode(e, "DoWhileStatement");
            }, j.parseForStatement = function(e) {
              this.next();
              var t3 = this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await") ? this.lastTokStart : -1;
              if (this.labels.push(At), this.enterScope(0), this.expect(i.parenL), this.type === i.semi)
                return t3 > -1 && this.unexpected(t3), this.parseFor(e, null);
              var r = this.isLet();
              if (this.type === i._var || this.type === i._const || r) {
                var s = this.startNode(), n = r ? "let" : this.value;
                return this.next(), this.parseVar(s, true, n), this.finishNode(s, "VariableDeclaration"), (this.type === i._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) && s.declarations.length === 1 ? (this.options.ecmaVersion >= 9 && (this.type === i._in ? t3 > -1 && this.unexpected(t3) : e.await = t3 > -1), this.parseForIn(e, s)) : (t3 > -1 && this.unexpected(t3), this.parseFor(e, s));
              }
              var h = this.isContextual("let"), c = false, v = new He(), y = this.parseExpression(t3 > -1 ? "await" : true, v);
              return this.type === i._in || (c = this.options.ecmaVersion >= 6 && this.isContextual("of")) ? (this.options.ecmaVersion >= 9 && (this.type === i._in ? t3 > -1 && this.unexpected(t3) : e.await = t3 > -1), h && c && this.raise(y.start, "The left-hand side of a for-of loop may not start with 'let'."), this.toAssignable(y, false, v), this.checkLValPattern(y), this.parseForIn(e, y)) : (this.checkExpressionErrors(v, true), t3 > -1 && this.unexpected(t3), this.parseFor(e, y));
            }, j.parseFunctionStatement = function(e, t3, r) {
              return this.next(), this.parseFunction(e, Ve | (r ? 0 : Ct), false, t3);
            }, j.parseIfStatement = function(e) {
              return this.next(), e.test = this.parseParenExpression(), e.consequent = this.parseStatement("if"), e.alternate = this.eat(i._else) ? this.parseStatement("if") : null, this.finishNode(e, "IfStatement");
            }, j.parseReturnStatement = function(e) {
              return !this.inFunction && !this.options.allowReturnOutsideFunction && this.raise(this.start, "'return' outside of function"), this.next(), this.eat(i.semi) || this.insertSemicolon() ? e.argument = null : (e.argument = this.parseExpression(), this.semicolon()), this.finishNode(e, "ReturnStatement");
            }, j.parseSwitchStatement = function(e) {
              this.next(), e.discriminant = this.parseParenExpression(), e.cases = [], this.expect(i.braceL), this.labels.push(Ya), this.enterScope(0);
              for (var t3, r = false; this.type !== i.braceR; )
                if (this.type === i._case || this.type === i._default) {
                  var s = this.type === i._case;
                  t3 && this.finishNode(t3, "SwitchCase"), e.cases.push(t3 = this.startNode()), t3.consequent = [], this.next(), s ? t3.test = this.parseExpression() : (r && this.raiseRecoverable(this.lastTokStart, "Multiple default clauses"), r = true, t3.test = null), this.expect(i.colon);
                } else
                  t3 || this.unexpected(), t3.consequent.push(this.parseStatement(null));
              return this.exitScope(), t3 && this.finishNode(t3, "SwitchCase"), this.next(), this.labels.pop(), this.finishNode(e, "SwitchStatement");
            }, j.parseThrowStatement = function(e) {
              return this.next(), k.test(this.input.slice(this.lastTokEnd, this.start)) && this.raise(this.lastTokEnd, "Illegal newline after throw"), e.argument = this.parseExpression(), this.semicolon(), this.finishNode(e, "ThrowStatement");
            };
            var Za = [];
            j.parseTryStatement = function(e) {
              if (this.next(), e.block = this.parseBlock(), e.handler = null, this.type === i._catch) {
                var t3 = this.startNode();
                if (this.next(), this.eat(i.parenL)) {
                  t3.param = this.parseBindingAtom();
                  var r = t3.param.type === "Identifier";
                  this.enterScope(r ? vr : 0), this.checkLValPattern(t3.param, r ? yr : ve), this.expect(i.parenR);
                } else
                  this.options.ecmaVersion < 10 && this.unexpected(), t3.param = null, this.enterScope(0);
                t3.body = this.parseBlock(false), this.exitScope(), e.handler = this.finishNode(t3, "CatchClause");
              }
              return e.finalizer = this.eat(i._finally) ? this.parseBlock() : null, !e.handler && !e.finalizer && this.raise(e.start, "Missing catch or finally clause"), this.finishNode(e, "TryStatement");
            }, j.parseVarStatement = function(e, t3) {
              return this.next(), this.parseVar(e, false, t3), this.semicolon(), this.finishNode(e, "VariableDeclaration");
            }, j.parseWhileStatement = function(e) {
              return this.next(), e.test = this.parseParenExpression(), this.labels.push(At), e.body = this.parseStatement("while"), this.labels.pop(), this.finishNode(e, "WhileStatement");
            }, j.parseWithStatement = function(e) {
              return this.strict && this.raise(this.start, "'with' in strict mode"), this.next(), e.object = this.parseParenExpression(), e.body = this.parseStatement("with"), this.finishNode(e, "WithStatement");
            }, j.parseEmptyStatement = function(e) {
              return this.next(), this.finishNode(e, "EmptyStatement");
            }, j.parseLabeledStatement = function(e, t3, r, s) {
              for (var n = 0, h = this.labels; n < h.length; n += 1) {
                var c = h[n];
                c.name === t3 && this.raise(r.start, "Label '" + t3 + "' is already declared");
              }
              for (var v = this.type.isLoop ? "loop" : this.type === i._switch ? "switch" : null, y = this.labels.length - 1; y >= 0; y--) {
                var U = this.labels[y];
                if (U.statementStart === e.start)
                  U.statementStart = this.start, U.kind = v;
                else
                  break;
              }
              return this.labels.push({ name: t3, kind: v, statementStart: this.start }), e.body = this.parseStatement(s ? s.indexOf("label") === -1 ? s + "label" : s : "label"), this.labels.pop(), e.label = r, this.finishNode(e, "LabeledStatement");
            }, j.parseExpressionStatement = function(e, t3) {
              return e.expression = t3, this.semicolon(), this.finishNode(e, "ExpressionStatement");
            }, j.parseBlock = function(e, t3, r) {
              for (e === void 0 && (e = true), t3 === void 0 && (t3 = this.startNode()), t3.body = [], this.expect(i.braceL), e && this.enterScope(0); this.type !== i.braceR; ) {
                var s = this.parseStatement(null);
                t3.body.push(s);
              }
              return r && (this.strict = false), this.next(), e && this.exitScope(), this.finishNode(t3, "BlockStatement");
            }, j.parseFor = function(e, t3) {
              return e.init = t3, this.expect(i.semi), e.test = this.type === i.semi ? null : this.parseExpression(), this.expect(i.semi), e.update = this.type === i.parenR ? null : this.parseExpression(), this.expect(i.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, "ForStatement");
            }, j.parseForIn = function(e, t3) {
              var r = this.type === i._in;
              return this.next(), t3.type === "VariableDeclaration" && t3.declarations[0].init != null && (!r || this.options.ecmaVersion < 8 || this.strict || t3.kind !== "var" || t3.declarations[0].id.type !== "Identifier") && this.raise(t3.start, (r ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"), e.left = t3, e.right = r ? this.parseExpression() : this.parseMaybeAssign(), this.expect(i.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, r ? "ForInStatement" : "ForOfStatement");
            }, j.parseVar = function(e, t3, r) {
              for (e.declarations = [], e.kind = r; ; ) {
                var s = this.startNode();
                if (this.parseVarId(s, r), this.eat(i.eq) ? s.init = this.parseMaybeAssign(t3) : r === "const" && !(this.type === i._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) ? this.unexpected() : s.id.type !== "Identifier" && !(t3 && (this.type === i._in || this.isContextual("of"))) ? this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value") : s.init = null, e.declarations.push(this.finishNode(s, "VariableDeclarator")), !this.eat(i.comma))
                  break;
              }
              return e;
            }, j.parseVarId = function(e, t3) {
              e.id = this.parseBindingAtom(), this.checkLValPattern(e.id, t3 === "var" ? yt : ve, false);
            };
            var Ve = 1, Ct = 2, Cr = 4;
            j.parseFunction = function(e, t3, r, s, n) {
              this.initFunction(e), (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !s) && (this.type === i.star && t3 & Ct && this.unexpected(), e.generator = this.eat(i.star)), this.options.ecmaVersion >= 8 && (e.async = !!s), t3 & Ve && (e.id = t3 & Cr && this.type !== i.name ? null : this.parseIdent(), e.id && !(t3 & Ct) && this.checkLValSimple(e.id, this.strict || e.generator || e.async ? this.treatFunctionsAsVar ? yt : ve : xr));
              var h = this.yieldPos, c = this.awaitPos, v = this.awaitIdentPos;
              return this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(xt(e.async, e.generator)), t3 & Ve || (e.id = this.type === i.name ? this.parseIdent() : null), this.parseFunctionParams(e), this.parseFunctionBody(e, r, false, n), this.yieldPos = h, this.awaitPos = c, this.awaitIdentPos = v, this.finishNode(e, t3 & Ve ? "FunctionDeclaration" : "FunctionExpression");
            }, j.parseFunctionParams = function(e) {
              this.expect(i.parenL), e.params = this.parseBindingList(i.parenR, false, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams();
            }, j.parseClass = function(e, t3) {
              this.next();
              var r = this.strict;
              this.strict = true, this.parseClassId(e, t3), this.parseClassSuper(e);
              var s = this.enterClassBody(), n = this.startNode(), h = false;
              for (n.body = [], this.expect(i.braceL); this.type !== i.braceR; ) {
                var c = this.parseClassElement(e.superClass !== null);
                c && (n.body.push(c), c.type === "MethodDefinition" && c.kind === "constructor" ? (h && this.raise(c.start, "Duplicate constructor in the same class"), h = true) : c.key && c.key.type === "PrivateIdentifier" && en(s, c) && this.raiseRecoverable(c.key.start, "Identifier '#" + c.key.name + "' has already been declared"));
              }
              return this.strict = r, this.next(), e.body = this.finishNode(n, "ClassBody"), this.exitClassBody(), this.finishNode(e, t3 ? "ClassDeclaration" : "ClassExpression");
            }, j.parseClassElement = function(e) {
              if (this.eat(i.semi))
                return null;
              var t3 = this.options.ecmaVersion, r = this.startNode(), s = "", n = false, h = false, c = "method", v = false;
              if (this.eatContextual("static")) {
                if (t3 >= 13 && this.eat(i.braceL))
                  return this.parseClassStaticBlock(r), r;
                this.isClassElementNameStart() || this.type === i.star ? v = true : s = "static";
              }
              if (r.static = v, !s && t3 >= 8 && this.eatContextual("async") && ((this.isClassElementNameStart() || this.type === i.star) && !this.canInsertSemicolon() ? h = true : s = "async"), !s && (t3 >= 9 || !h) && this.eat(i.star) && (n = true), !s && !h && !n) {
                var y = this.value;
                (this.eatContextual("get") || this.eatContextual("set")) && (this.isClassElementNameStart() ? c = y : s = y);
              }
              if (s ? (r.computed = false, r.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc), r.key.name = s, this.finishNode(r.key, "Identifier")) : this.parseClassElementName(r), t3 < 13 || this.type === i.parenL || c !== "method" || n || h) {
                var U = !r.static && Ke(r, "constructor"), W = U && e;
                U && c !== "method" && this.raise(r.key.start, "Constructor can't have get/set modifier"), r.kind = U ? "constructor" : c, this.parseClassMethod(r, n, h, W);
              } else
                this.parseClassField(r);
              return r;
            }, j.isClassElementNameStart = function() {
              return this.type === i.name || this.type === i.privateId || this.type === i.num || this.type === i.string || this.type === i.bracketL || this.type.keyword;
            }, j.parseClassElementName = function(e) {
              this.type === i.privateId ? (this.value === "constructor" && this.raise(this.start, "Classes can't have an element named '#constructor'"), e.computed = false, e.key = this.parsePrivateIdent()) : this.parsePropertyName(e);
            }, j.parseClassMethod = function(e, t3, r, s) {
              var n = e.key;
              e.kind === "constructor" ? (t3 && this.raise(n.start, "Constructor can't be a generator"), r && this.raise(n.start, "Constructor can't be an async method")) : e.static && Ke(e, "prototype") && this.raise(n.start, "Classes may not have a static property named prototype");
              var h = e.value = this.parseMethod(t3, r, s);
              return e.kind === "get" && h.params.length !== 0 && this.raiseRecoverable(h.start, "getter should have no params"), e.kind === "set" && h.params.length !== 1 && this.raiseRecoverable(h.start, "setter should have exactly one param"), e.kind === "set" && h.params[0].type === "RestElement" && this.raiseRecoverable(h.params[0].start, "Setter cannot use rest params"), this.finishNode(e, "MethodDefinition");
            }, j.parseClassField = function(e) {
              if (Ke(e, "constructor") ? this.raise(e.key.start, "Classes can't have a field named 'constructor'") : e.static && Ke(e, "prototype") && this.raise(e.key.start, "Classes can't have a static field named 'prototype'"), this.eat(i.eq)) {
                var t3 = this.currentThisScope(), r = t3.inClassFieldInit;
                t3.inClassFieldInit = true, e.value = this.parseMaybeAssign(), t3.inClassFieldInit = r;
              } else
                e.value = null;
              return this.semicolon(), this.finishNode(e, "PropertyDefinition");
            }, j.parseClassStaticBlock = function(e) {
              e.body = [];
              var t3 = this.labels;
              for (this.labels = [], this.enterScope(Le | vt); this.type !== i.braceR; ) {
                var r = this.parseStatement(null);
                e.body.push(r);
              }
              return this.next(), this.exitScope(), this.labels = t3, this.finishNode(e, "StaticBlock");
            }, j.parseClassId = function(e, t3) {
              this.type === i.name ? (e.id = this.parseIdent(), t3 && this.checkLValSimple(e.id, ve, false)) : (t3 === true && this.unexpected(), e.id = null);
            }, j.parseClassSuper = function(e) {
              e.superClass = this.eat(i._extends) ? this.parseExprSubscripts(false) : null;
            }, j.enterClassBody = function() {
              var e = { declared: /* @__PURE__ */ Object.create(null), used: [] };
              return this.privateNameStack.push(e), e.declared;
            }, j.exitClassBody = function() {
              for (var e = this.privateNameStack.pop(), t3 = e.declared, r = e.used, s = this.privateNameStack.length, n = s === 0 ? null : this.privateNameStack[s - 1], h = 0; h < r.length; ++h) {
                var c = r[h];
                L(t3, c.name) || (n ? n.used.push(c) : this.raiseRecoverable(c.start, "Private field '#" + c.name + "' must be declared in an enclosing class"));
              }
            };
            function en(e, t3) {
              var r = t3.key.name, s = e[r], n = "true";
              return t3.type === "MethodDefinition" && (t3.kind === "get" || t3.kind === "set") && (n = (t3.static ? "s" : "i") + t3.kind), s === "iget" && n === "iset" || s === "iset" && n === "iget" || s === "sget" && n === "sset" || s === "sset" && n === "sget" ? (e[r] = "true", false) : s ? true : (e[r] = n, false);
            }
            function Ke(e, t3) {
              var r = e.computed, s = e.key;
              return !r && (s.type === "Identifier" && s.name === t3 || s.type === "Literal" && s.value === t3);
            }
            j.parseExport = function(e, t3) {
              if (this.next(), this.eat(i.star))
                return this.options.ecmaVersion >= 11 && (this.eatContextual("as") ? (e.exported = this.parseModuleExportName(), this.checkExport(t3, e.exported, this.lastTokStart)) : e.exported = null), this.expectContextual("from"), this.type !== i.string && this.unexpected(), e.source = this.parseExprAtom(), this.semicolon(), this.finishNode(e, "ExportAllDeclaration");
              if (this.eat(i._default)) {
                this.checkExport(t3, "default", this.lastTokStart);
                var r;
                if (this.type === i._function || (r = this.isAsyncFunction())) {
                  var s = this.startNode();
                  this.next(), r && this.next(), e.declaration = this.parseFunction(s, Ve | Cr, false, r);
                } else if (this.type === i._class) {
                  var n = this.startNode();
                  e.declaration = this.parseClass(n, "nullableID");
                } else
                  e.declaration = this.parseMaybeAssign(), this.semicolon();
                return this.finishNode(e, "ExportDefaultDeclaration");
              }
              if (this.shouldParseExportStatement())
                e.declaration = this.parseStatement(null), e.declaration.type === "VariableDeclaration" ? this.checkVariableExport(t3, e.declaration.declarations) : this.checkExport(t3, e.declaration.id, e.declaration.id.start), e.specifiers = [], e.source = null;
              else {
                if (e.declaration = null, e.specifiers = this.parseExportSpecifiers(t3), this.eatContextual("from"))
                  this.type !== i.string && this.unexpected(), e.source = this.parseExprAtom();
                else {
                  for (var h = 0, c = e.specifiers; h < c.length; h += 1) {
                    var v = c[h];
                    this.checkUnreserved(v.local), this.checkLocalExport(v.local), v.local.type === "Literal" && this.raise(v.local.start, "A string literal cannot be used as an exported binding without `from`.");
                  }
                  e.source = null;
                }
                this.semicolon();
              }
              return this.finishNode(e, "ExportNamedDeclaration");
            }, j.checkExport = function(e, t3, r) {
              e && (typeof t3 != "string" && (t3 = t3.type === "Identifier" ? t3.name : t3.value), L(e, t3) && this.raiseRecoverable(r, "Duplicate export '" + t3 + "'"), e[t3] = true);
            }, j.checkPatternExport = function(e, t3) {
              var r = t3.type;
              if (r === "Identifier")
                this.checkExport(e, t3, t3.start);
              else if (r === "ObjectPattern")
                for (var s = 0, n = t3.properties; s < n.length; s += 1) {
                  var h = n[s];
                  this.checkPatternExport(e, h);
                }
              else if (r === "ArrayPattern")
                for (var c = 0, v = t3.elements; c < v.length; c += 1) {
                  var y = v[c];
                  y && this.checkPatternExport(e, y);
                }
              else
                r === "Property" ? this.checkPatternExport(e, t3.value) : r === "AssignmentPattern" ? this.checkPatternExport(e, t3.left) : r === "RestElement" ? this.checkPatternExport(e, t3.argument) : r === "ParenthesizedExpression" && this.checkPatternExport(e, t3.expression);
            }, j.checkVariableExport = function(e, t3) {
              if (e)
                for (var r = 0, s = t3; r < s.length; r += 1) {
                  var n = s[r];
                  this.checkPatternExport(e, n.id);
                }
            }, j.shouldParseExportStatement = function() {
              return this.type.keyword === "var" || this.type.keyword === "const" || this.type.keyword === "class" || this.type.keyword === "function" || this.isLet() || this.isAsyncFunction();
            }, j.parseExportSpecifiers = function(e) {
              var t3 = [], r = true;
              for (this.expect(i.braceL); !this.eat(i.braceR); ) {
                if (r)
                  r = false;
                else if (this.expect(i.comma), this.afterTrailingComma(i.braceR))
                  break;
                var s = this.startNode();
                s.local = this.parseModuleExportName(), s.exported = this.eatContextual("as") ? this.parseModuleExportName() : s.local, this.checkExport(e, s.exported, s.exported.start), t3.push(this.finishNode(s, "ExportSpecifier"));
              }
              return t3;
            }, j.parseImport = function(e) {
              return this.next(), this.type === i.string ? (e.specifiers = Za, e.source = this.parseExprAtom()) : (e.specifiers = this.parseImportSpecifiers(), this.expectContextual("from"), e.source = this.type === i.string ? this.parseExprAtom() : this.unexpected()), this.semicolon(), this.finishNode(e, "ImportDeclaration");
            }, j.parseImportSpecifiers = function() {
              var e = [], t3 = true;
              if (this.type === i.name) {
                var r = this.startNode();
                if (r.local = this.parseIdent(), this.checkLValSimple(r.local, ve), e.push(this.finishNode(r, "ImportDefaultSpecifier")), !this.eat(i.comma))
                  return e;
              }
              if (this.type === i.star) {
                var s = this.startNode();
                return this.next(), this.expectContextual("as"), s.local = this.parseIdent(), this.checkLValSimple(s.local, ve), e.push(this.finishNode(s, "ImportNamespaceSpecifier")), e;
              }
              for (this.expect(i.braceL); !this.eat(i.braceR); ) {
                if (t3)
                  t3 = false;
                else if (this.expect(i.comma), this.afterTrailingComma(i.braceR))
                  break;
                var n = this.startNode();
                n.imported = this.parseModuleExportName(), this.eatContextual("as") ? n.local = this.parseIdent() : (this.checkUnreserved(n.imported), n.local = n.imported), this.checkLValSimple(n.local, ve), e.push(this.finishNode(n, "ImportSpecifier"));
              }
              return e;
            }, j.parseModuleExportName = function() {
              if (this.options.ecmaVersion >= 13 && this.type === i.string) {
                var e = this.parseLiteral(this.value);
                return X.test(e.value) && this.raise(e.start, "An export name cannot include a lone surrogate."), e;
              }
              return this.parseIdent(true);
            }, j.adaptDirectivePrologue = function(e) {
              for (var t3 = 0; t3 < e.length && this.isDirectiveCandidate(e[t3]); ++t3)
                e[t3].directive = e[t3].expression.raw.slice(1, -1);
            }, j.isDirectiveCandidate = function(e) {
              return this.options.ecmaVersion >= 5 && e.type === "ExpressionStatement" && e.expression.type === "Literal" && typeof e.expression.value == "string" && (this.input[e.start] === '"' || this.input[e.start] === "'");
            };
            var he = Y.prototype;
            he.toAssignable = function(e, t3, r) {
              if (this.options.ecmaVersion >= 6 && e)
                switch (e.type) {
                  case "Identifier":
                    this.inAsync && e.name === "await" && this.raise(e.start, "Cannot use 'await' as identifier inside an async function");
                    break;
                  case "ObjectPattern":
                  case "ArrayPattern":
                  case "AssignmentPattern":
                  case "RestElement":
                    break;
                  case "ObjectExpression":
                    e.type = "ObjectPattern", r && this.checkPatternErrors(r, true);
                    for (var s = 0, n = e.properties; s < n.length; s += 1) {
                      var h = n[s];
                      this.toAssignable(h, t3), h.type === "RestElement" && (h.argument.type === "ArrayPattern" || h.argument.type === "ObjectPattern") && this.raise(h.argument.start, "Unexpected token");
                    }
                    break;
                  case "Property":
                    e.kind !== "init" && this.raise(e.key.start, "Object pattern can't contain getter or setter"), this.toAssignable(e.value, t3);
                    break;
                  case "ArrayExpression":
                    e.type = "ArrayPattern", r && this.checkPatternErrors(r, true), this.toAssignableList(e.elements, t3);
                    break;
                  case "SpreadElement":
                    e.type = "RestElement", this.toAssignable(e.argument, t3), e.argument.type === "AssignmentPattern" && this.raise(e.argument.start, "Rest elements cannot have a default value");
                    break;
                  case "AssignmentExpression":
                    e.operator !== "=" && this.raise(e.left.end, "Only '=' operator can be used for specifying default value."), e.type = "AssignmentPattern", delete e.operator, this.toAssignable(e.left, t3);
                    break;
                  case "ParenthesizedExpression":
                    this.toAssignable(e.expression, t3, r);
                    break;
                  case "ChainExpression":
                    this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
                    break;
                  case "MemberExpression":
                    if (!t3)
                      break;
                  default:
                    this.raise(e.start, "Assigning to rvalue");
                }
              else
                r && this.checkPatternErrors(r, true);
              return e;
            }, he.toAssignableList = function(e, t3) {
              for (var r = e.length, s = 0; s < r; s++) {
                var n = e[s];
                n && this.toAssignable(n, t3);
              }
              if (r) {
                var h = e[r - 1];
                this.options.ecmaVersion === 6 && t3 && h && h.type === "RestElement" && h.argument.type !== "Identifier" && this.unexpected(h.argument.start);
              }
              return e;
            }, he.parseSpread = function(e) {
              var t3 = this.startNode();
              return this.next(), t3.argument = this.parseMaybeAssign(false, e), this.finishNode(t3, "SpreadElement");
            }, he.parseRestBinding = function() {
              var e = this.startNode();
              return this.next(), this.options.ecmaVersion === 6 && this.type !== i.name && this.unexpected(), e.argument = this.parseBindingAtom(), this.finishNode(e, "RestElement");
            }, he.parseBindingAtom = function() {
              if (this.options.ecmaVersion >= 6)
                switch (this.type) {
                  case i.bracketL:
                    var e = this.startNode();
                    return this.next(), e.elements = this.parseBindingList(i.bracketR, true, true), this.finishNode(e, "ArrayPattern");
                  case i.braceL:
                    return this.parseObj(true);
                }
              return this.parseIdent();
            }, he.parseBindingList = function(e, t3, r) {
              for (var s = [], n = true; !this.eat(e); )
                if (n ? n = false : this.expect(i.comma), t3 && this.type === i.comma)
                  s.push(null);
                else {
                  if (r && this.afterTrailingComma(e))
                    break;
                  if (this.type === i.ellipsis) {
                    var h = this.parseRestBinding();
                    this.parseBindingListItem(h), s.push(h), this.type === i.comma && this.raise(this.start, "Comma is not permitted after the rest element"), this.expect(e);
                    break;
                  } else {
                    var c = this.parseMaybeDefault(this.start, this.startLoc);
                    this.parseBindingListItem(c), s.push(c);
                  }
                }
              return s;
            }, he.parseBindingListItem = function(e) {
              return e;
            }, he.parseMaybeDefault = function(e, t3, r) {
              if (r = r || this.parseBindingAtom(), this.options.ecmaVersion < 6 || !this.eat(i.eq))
                return r;
              var s = this.startNodeAt(e, t3);
              return s.left = r, s.right = this.parseMaybeAssign(), this.finishNode(s, "AssignmentPattern");
            }, he.checkLValSimple = function(e, t3, r) {
              t3 === void 0 && (t3 = Ge);
              var s = t3 !== Ge;
              switch (e.type) {
                case "Identifier":
                  this.strict && this.reservedWordsStrictBind.test(e.name) && this.raiseRecoverable(e.start, (s ? "Binding " : "Assigning to ") + e.name + " in strict mode"), s && (t3 === ve && e.name === "let" && this.raiseRecoverable(e.start, "let is disallowed as a lexically bound name"), r && (L(r, e.name) && this.raiseRecoverable(e.start, "Argument name clash"), r[e.name] = true), t3 !== Ar && this.declareName(e.name, t3, e.start));
                  break;
                case "ChainExpression":
                  this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
                  break;
                case "MemberExpression":
                  s && this.raiseRecoverable(e.start, "Binding member expression");
                  break;
                case "ParenthesizedExpression":
                  return s && this.raiseRecoverable(e.start, "Binding parenthesized expression"), this.checkLValSimple(e.expression, t3, r);
                default:
                  this.raise(e.start, (s ? "Binding" : "Assigning to") + " rvalue");
              }
            }, he.checkLValPattern = function(e, t3, r) {
              switch (t3 === void 0 && (t3 = Ge), e.type) {
                case "ObjectPattern":
                  for (var s = 0, n = e.properties; s < n.length; s += 1) {
                    var h = n[s];
                    this.checkLValInnerPattern(h, t3, r);
                  }
                  break;
                case "ArrayPattern":
                  for (var c = 0, v = e.elements; c < v.length; c += 1) {
                    var y = v[c];
                    y && this.checkLValInnerPattern(y, t3, r);
                  }
                  break;
                default:
                  this.checkLValSimple(e, t3, r);
              }
            }, he.checkLValInnerPattern = function(e, t3, r) {
              switch (t3 === void 0 && (t3 = Ge), e.type) {
                case "Property":
                  this.checkLValInnerPattern(e.value, t3, r);
                  break;
                case "AssignmentPattern":
                  this.checkLValPattern(e.left, t3, r);
                  break;
                case "RestElement":
                  this.checkLValPattern(e.argument, t3, r);
                  break;
                default:
                  this.checkLValPattern(e, t3, r);
              }
            };
            var ue = function(t3, r, s, n, h) {
              this.token = t3, this.isExpr = !!r, this.preserveSpace = !!s, this.override = n, this.generator = !!h;
            }, $2 = { b_stat: new ue("{", false), b_expr: new ue("{", true), b_tmpl: new ue("${", false), p_stat: new ue("(", false), p_expr: new ue("(", true), q_tmpl: new ue("`", true, true, function(e) {
              return e.tryReadTemplateToken();
            }), f_stat: new ue("function", false), f_expr: new ue("function", true), f_expr_gen: new ue("function", true, false, null, true), f_gen: new ue("function", false, false, null, true) }, Fe = Y.prototype;
            Fe.initialContext = function() {
              return [$2.b_stat];
            }, Fe.curContext = function() {
              return this.context[this.context.length - 1];
            }, Fe.braceIsBlock = function(e) {
              var t3 = this.curContext();
              return t3 === $2.f_expr || t3 === $2.f_stat ? true : e === i.colon && (t3 === $2.b_stat || t3 === $2.b_expr) ? !t3.isExpr : e === i._return || e === i.name && this.exprAllowed ? k.test(this.input.slice(this.lastTokEnd, this.start)) : e === i._else || e === i.semi || e === i.eof || e === i.parenR || e === i.arrow ? true : e === i.braceL ? t3 === $2.b_stat : e === i._var || e === i._const || e === i.name ? false : !this.exprAllowed;
            }, Fe.inGeneratorContext = function() {
              for (var e = this.context.length - 1; e >= 1; e--) {
                var t3 = this.context[e];
                if (t3.token === "function")
                  return t3.generator;
              }
              return false;
            }, Fe.updateContext = function(e) {
              var t3, r = this.type;
              r.keyword && e === i.dot ? this.exprAllowed = false : (t3 = r.updateContext) ? t3.call(this, e) : this.exprAllowed = r.beforeExpr;
            }, Fe.overrideContext = function(e) {
              this.curContext() !== e && (this.context[this.context.length - 1] = e);
            }, i.parenR.updateContext = i.braceR.updateContext = function() {
              if (this.context.length === 1) {
                this.exprAllowed = true;
                return;
              }
              var e = this.context.pop();
              e === $2.b_stat && this.curContext().token === "function" && (e = this.context.pop()), this.exprAllowed = !e.isExpr;
            }, i.braceL.updateContext = function(e) {
              this.context.push(this.braceIsBlock(e) ? $2.b_stat : $2.b_expr), this.exprAllowed = true;
            }, i.dollarBraceL.updateContext = function() {
              this.context.push($2.b_tmpl), this.exprAllowed = true;
            }, i.parenL.updateContext = function(e) {
              var t3 = e === i._if || e === i._for || e === i._with || e === i._while;
              this.context.push(t3 ? $2.p_stat : $2.p_expr), this.exprAllowed = true;
            }, i.incDec.updateContext = function() {
            }, i._function.updateContext = i._class.updateContext = function(e) {
              e.beforeExpr && e !== i._else && !(e === i.semi && this.curContext() !== $2.p_stat) && !(e === i._return && k.test(this.input.slice(this.lastTokEnd, this.start))) && !((e === i.colon || e === i.braceL) && this.curContext() === $2.b_stat) ? this.context.push($2.f_expr) : this.context.push($2.f_stat), this.exprAllowed = false;
            }, i.backQuote.updateContext = function() {
              this.curContext() === $2.q_tmpl ? this.context.pop() : this.context.push($2.q_tmpl), this.exprAllowed = false;
            }, i.star.updateContext = function(e) {
              if (e === i._function) {
                var t3 = this.context.length - 1;
                this.context[t3] === $2.f_expr ? this.context[t3] = $2.f_expr_gen : this.context[t3] = $2.f_gen;
              }
              this.exprAllowed = true;
            }, i.name.updateContext = function(e) {
              var t3 = false;
              this.options.ecmaVersion >= 6 && e !== i.dot && (this.value === "of" && !this.exprAllowed || this.value === "yield" && this.inGeneratorContext()) && (t3 = true), this.exprAllowed = t3;
            };
            var z = Y.prototype;
            z.checkPropClash = function(e, t3, r) {
              if (!(this.options.ecmaVersion >= 9 && e.type === "SpreadElement") && !(this.options.ecmaVersion >= 6 && (e.computed || e.method || e.shorthand))) {
                var s = e.key, n;
                switch (s.type) {
                  case "Identifier":
                    n = s.name;
                    break;
                  case "Literal":
                    n = String(s.value);
                    break;
                  default:
                    return;
                }
                var h = e.kind;
                if (this.options.ecmaVersion >= 6) {
                  n === "__proto__" && h === "init" && (t3.proto && (r ? r.doubleProto < 0 && (r.doubleProto = s.start) : this.raiseRecoverable(s.start, "Redefinition of __proto__ property")), t3.proto = true);
                  return;
                }
                n = "$" + n;
                var c = t3[n];
                if (c) {
                  var v;
                  h === "init" ? v = this.strict && c.init || c.get || c.set : v = c.init || c[h], v && this.raiseRecoverable(s.start, "Redefinition of property");
                } else
                  c = t3[n] = { init: false, get: false, set: false };
                c[h] = true;
              }
            }, z.parseExpression = function(e, t3) {
              var r = this.start, s = this.startLoc, n = this.parseMaybeAssign(e, t3);
              if (this.type === i.comma) {
                var h = this.startNodeAt(r, s);
                for (h.expressions = [n]; this.eat(i.comma); )
                  h.expressions.push(this.parseMaybeAssign(e, t3));
                return this.finishNode(h, "SequenceExpression");
              }
              return n;
            }, z.parseMaybeAssign = function(e, t3, r) {
              if (this.isContextual("yield")) {
                if (this.inGenerator)
                  return this.parseYield(e);
                this.exprAllowed = false;
              }
              var s = false, n = -1, h = -1, c = -1;
              t3 ? (n = t3.parenthesizedAssign, h = t3.trailingComma, c = t3.doubleProto, t3.parenthesizedAssign = t3.trailingComma = -1) : (t3 = new He(), s = true);
              var v = this.start, y = this.startLoc;
              (this.type === i.parenL || this.type === i.name) && (this.potentialArrowAt = this.start, this.potentialArrowInForAwait = e === "await");
              var U = this.parseMaybeConditional(e, t3);
              if (r && (U = r.call(this, U, v, y)), this.type.isAssign) {
                var W = this.startNodeAt(v, y);
                return W.operator = this.value, this.type === i.eq && (U = this.toAssignable(U, false, t3)), s || (t3.parenthesizedAssign = t3.trailingComma = t3.doubleProto = -1), t3.shorthandAssign >= U.start && (t3.shorthandAssign = -1), this.type === i.eq ? this.checkLValPattern(U) : this.checkLValSimple(U), W.left = U, this.next(), W.right = this.parseMaybeAssign(e), c > -1 && (t3.doubleProto = c), this.finishNode(W, "AssignmentExpression");
              } else
                s && this.checkExpressionErrors(t3, true);
              return n > -1 && (t3.parenthesizedAssign = n), h > -1 && (t3.trailingComma = h), U;
            }, z.parseMaybeConditional = function(e, t3) {
              var r = this.start, s = this.startLoc, n = this.parseExprOps(e, t3);
              if (this.checkExpressionErrors(t3))
                return n;
              if (this.eat(i.question)) {
                var h = this.startNodeAt(r, s);
                return h.test = n, h.consequent = this.parseMaybeAssign(), this.expect(i.colon), h.alternate = this.parseMaybeAssign(e), this.finishNode(h, "ConditionalExpression");
              }
              return n;
            }, z.parseExprOps = function(e, t3) {
              var r = this.start, s = this.startLoc, n = this.parseMaybeUnary(t3, false, false, e);
              return this.checkExpressionErrors(t3) || n.start === r && n.type === "ArrowFunctionExpression" ? n : this.parseExprOp(n, r, s, -1, e);
            }, z.parseExprOp = function(e, t3, r, s, n) {
              var h = this.type.binop;
              if (h != null && (!n || this.type !== i._in) && h > s) {
                var c = this.type === i.logicalOR || this.type === i.logicalAND, v = this.type === i.coalesce;
                v && (h = i.logicalAND.binop);
                var y = this.value;
                this.next();
                var U = this.start, W = this.startLoc, re = this.parseExprOp(this.parseMaybeUnary(null, false, false, n), U, W, h, n), Se = this.buildBinary(t3, r, e, re, y, c || v);
                return (c && this.type === i.coalesce || v && (this.type === i.logicalOR || this.type === i.logicalAND)) && this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses"), this.parseExprOp(Se, t3, r, s, n);
              }
              return e;
            }, z.buildBinary = function(e, t3, r, s, n, h) {
              s.type === "PrivateIdentifier" && this.raise(s.start, "Private identifier can only be left side of binary expression");
              var c = this.startNodeAt(e, t3);
              return c.left = r, c.operator = n, c.right = s, this.finishNode(c, h ? "LogicalExpression" : "BinaryExpression");
            }, z.parseMaybeUnary = function(e, t3, r, s) {
              var n = this.start, h = this.startLoc, c;
              if (this.isContextual("await") && this.canAwait)
                c = this.parseAwait(s), t3 = true;
              else if (this.type.prefix) {
                var v = this.startNode(), y = this.type === i.incDec;
                v.operator = this.value, v.prefix = true, this.next(), v.argument = this.parseMaybeUnary(null, true, y, s), this.checkExpressionErrors(e, true), y ? this.checkLValSimple(v.argument) : this.strict && v.operator === "delete" && v.argument.type === "Identifier" ? this.raiseRecoverable(v.start, "Deleting local variable in strict mode") : v.operator === "delete" && Er(v.argument) ? this.raiseRecoverable(v.start, "Private fields can not be deleted") : t3 = true, c = this.finishNode(v, y ? "UpdateExpression" : "UnaryExpression");
              } else if (!t3 && this.type === i.privateId)
                (s || this.privateNameStack.length === 0) && this.unexpected(), c = this.parsePrivateIdent(), this.type !== i._in && this.unexpected();
              else {
                if (c = this.parseExprSubscripts(e, s), this.checkExpressionErrors(e))
                  return c;
                for (; this.type.postfix && !this.canInsertSemicolon(); ) {
                  var U = this.startNodeAt(n, h);
                  U.operator = this.value, U.prefix = false, U.argument = c, this.checkLValSimple(c), this.next(), c = this.finishNode(U, "UpdateExpression");
                }
              }
              if (!r && this.eat(i.starstar))
                if (t3)
                  this.unexpected(this.lastTokStart);
                else
                  return this.buildBinary(n, h, c, this.parseMaybeUnary(null, false, false, s), "**", false);
              else
                return c;
            };
            function Er(e) {
              return e.type === "MemberExpression" && e.property.type === "PrivateIdentifier" || e.type === "ChainExpression" && Er(e.expression);
            }
            z.parseExprSubscripts = function(e, t3) {
              var r = this.start, s = this.startLoc, n = this.parseExprAtom(e, t3);
              if (n.type === "ArrowFunctionExpression" && this.input.slice(this.lastTokStart, this.lastTokEnd) !== ")")
                return n;
              var h = this.parseSubscripts(n, r, s, false, t3);
              return e && h.type === "MemberExpression" && (e.parenthesizedAssign >= h.start && (e.parenthesizedAssign = -1), e.parenthesizedBind >= h.start && (e.parenthesizedBind = -1), e.trailingComma >= h.start && (e.trailingComma = -1)), h;
            }, z.parseSubscripts = function(e, t3, r, s, n) {
              for (var h = this.options.ecmaVersion >= 8 && e.type === "Identifier" && e.name === "async" && this.lastTokEnd === e.end && !this.canInsertSemicolon() && e.end - e.start === 5 && this.potentialArrowAt === e.start, c = false; ; ) {
                var v = this.parseSubscript(e, t3, r, s, h, c, n);
                if (v.optional && (c = true), v === e || v.type === "ArrowFunctionExpression") {
                  if (c) {
                    var y = this.startNodeAt(t3, r);
                    y.expression = v, v = this.finishNode(y, "ChainExpression");
                  }
                  return v;
                }
                e = v;
              }
            }, z.parseSubscript = function(e, t3, r, s, n, h, c) {
              var v = this.options.ecmaVersion >= 11, y = v && this.eat(i.questionDot);
              s && y && this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
              var U = this.eat(i.bracketL);
              if (U || y && this.type !== i.parenL && this.type !== i.backQuote || this.eat(i.dot)) {
                var W = this.startNodeAt(t3, r);
                W.object = e, U ? (W.property = this.parseExpression(), this.expect(i.bracketR)) : this.type === i.privateId && e.type !== "Super" ? W.property = this.parsePrivateIdent() : W.property = this.parseIdent(this.options.allowReserved !== "never"), W.computed = !!U, v && (W.optional = y), e = this.finishNode(W, "MemberExpression");
              } else if (!s && this.eat(i.parenL)) {
                var re = new He(), Se = this.yieldPos, qe = this.awaitPos, Be = this.awaitIdentPos;
                this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0;
                var $e = this.parseExprList(i.parenR, this.options.ecmaVersion >= 8, false, re);
                if (n && !y && !this.canInsertSemicolon() && this.eat(i.arrow))
                  return this.checkPatternErrors(re, false), this.checkYieldAwaitInDefaultParams(), this.awaitIdentPos > 0 && this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function"), this.yieldPos = Se, this.awaitPos = qe, this.awaitIdentPos = Be, this.parseArrowExpression(this.startNodeAt(t3, r), $e, true, c);
                this.checkExpressionErrors(re, true), this.yieldPos = Se || this.yieldPos, this.awaitPos = qe || this.awaitPos, this.awaitIdentPos = Be || this.awaitIdentPos;
                var Ie = this.startNodeAt(t3, r);
                Ie.callee = e, Ie.arguments = $e, v && (Ie.optional = y), e = this.finishNode(Ie, "CallExpression");
              } else if (this.type === i.backQuote) {
                (y || h) && this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
                var Te = this.startNodeAt(t3, r);
                Te.tag = e, Te.quasi = this.parseTemplate({ isTagged: true }), e = this.finishNode(Te, "TaggedTemplateExpression");
              }
              return e;
            }, z.parseExprAtom = function(e, t3) {
              this.type === i.slash && this.readRegexp();
              var r, s = this.potentialArrowAt === this.start;
              switch (this.type) {
                case i._super:
                  return this.allowSuper || this.raise(this.start, "'super' keyword outside a method"), r = this.startNode(), this.next(), this.type === i.parenL && !this.allowDirectSuper && this.raise(r.start, "super() call outside constructor of a subclass"), this.type !== i.dot && this.type !== i.bracketL && this.type !== i.parenL && this.unexpected(), this.finishNode(r, "Super");
                case i._this:
                  return r = this.startNode(), this.next(), this.finishNode(r, "ThisExpression");
                case i.name:
                  var n = this.start, h = this.startLoc, c = this.containsEsc, v = this.parseIdent(false);
                  if (this.options.ecmaVersion >= 8 && !c && v.name === "async" && !this.canInsertSemicolon() && this.eat(i._function))
                    return this.overrideContext($2.f_expr), this.parseFunction(this.startNodeAt(n, h), 0, false, true, t3);
                  if (s && !this.canInsertSemicolon()) {
                    if (this.eat(i.arrow))
                      return this.parseArrowExpression(this.startNodeAt(n, h), [v], false, t3);
                    if (this.options.ecmaVersion >= 8 && v.name === "async" && this.type === i.name && !c && (!this.potentialArrowInForAwait || this.value !== "of" || this.containsEsc))
                      return v = this.parseIdent(false), (this.canInsertSemicolon() || !this.eat(i.arrow)) && this.unexpected(), this.parseArrowExpression(this.startNodeAt(n, h), [v], true, t3);
                  }
                  return v;
                case i.regexp:
                  var y = this.value;
                  return r = this.parseLiteral(y.value), r.regex = { pattern: y.pattern, flags: y.flags }, r;
                case i.num:
                case i.string:
                  return this.parseLiteral(this.value);
                case i._null:
                case i._true:
                case i._false:
                  return r = this.startNode(), r.value = this.type === i._null ? null : this.type === i._true, r.raw = this.type.keyword, this.next(), this.finishNode(r, "Literal");
                case i.parenL:
                  var U = this.start, W = this.parseParenAndDistinguishExpression(s, t3);
                  return e && (e.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(W) && (e.parenthesizedAssign = U), e.parenthesizedBind < 0 && (e.parenthesizedBind = U)), W;
                case i.bracketL:
                  return r = this.startNode(), this.next(), r.elements = this.parseExprList(i.bracketR, true, true, e), this.finishNode(r, "ArrayExpression");
                case i.braceL:
                  return this.overrideContext($2.b_expr), this.parseObj(false, e);
                case i._function:
                  return r = this.startNode(), this.next(), this.parseFunction(r, 0);
                case i._class:
                  return this.parseClass(this.startNode(), false);
                case i._new:
                  return this.parseNew();
                case i.backQuote:
                  return this.parseTemplate();
                case i._import:
                  return this.options.ecmaVersion >= 11 ? this.parseExprImport() : this.unexpected();
                default:
                  this.unexpected();
              }
            }, z.parseExprImport = function() {
              var e = this.startNode();
              this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword import");
              var t3 = this.parseIdent(true);
              switch (this.type) {
                case i.parenL:
                  return this.parseDynamicImport(e);
                case i.dot:
                  return e.meta = t3, this.parseImportMeta(e);
                default:
                  this.unexpected();
              }
            }, z.parseDynamicImport = function(e) {
              if (this.next(), e.source = this.parseMaybeAssign(), !this.eat(i.parenR)) {
                var t3 = this.start;
                this.eat(i.comma) && this.eat(i.parenR) ? this.raiseRecoverable(t3, "Trailing comma is not allowed in import()") : this.unexpected(t3);
              }
              return this.finishNode(e, "ImportExpression");
            }, z.parseImportMeta = function(e) {
              this.next();
              var t3 = this.containsEsc;
              return e.property = this.parseIdent(true), e.property.name !== "meta" && this.raiseRecoverable(e.property.start, "The only valid meta property for import is 'import.meta'"), t3 && this.raiseRecoverable(e.start, "'import.meta' must not contain escaped characters"), this.options.sourceType !== "module" && !this.options.allowImportExportEverywhere && this.raiseRecoverable(e.start, "Cannot use 'import.meta' outside a module"), this.finishNode(e, "MetaProperty");
            }, z.parseLiteral = function(e) {
              var t3 = this.startNode();
              return t3.value = e, t3.raw = this.input.slice(this.start, this.end), t3.raw.charCodeAt(t3.raw.length - 1) === 110 && (t3.bigint = t3.raw.slice(0, -1).replace(/_/g, "")), this.next(), this.finishNode(t3, "Literal");
            }, z.parseParenExpression = function() {
              this.expect(i.parenL);
              var e = this.parseExpression();
              return this.expect(i.parenR), e;
            }, z.parseParenAndDistinguishExpression = function(e, t3) {
              var r = this.start, s = this.startLoc, n, h = this.options.ecmaVersion >= 8;
              if (this.options.ecmaVersion >= 6) {
                this.next();
                var c = this.start, v = this.startLoc, y = [], U = true, W = false, re = new He(), Se = this.yieldPos, qe = this.awaitPos, Be;
                for (this.yieldPos = 0, this.awaitPos = 0; this.type !== i.parenR; )
                  if (U ? U = false : this.expect(i.comma), h && this.afterTrailingComma(i.parenR, true)) {
                    W = true;
                    break;
                  } else if (this.type === i.ellipsis) {
                    Be = this.start, y.push(this.parseParenItem(this.parseRestBinding())), this.type === i.comma && this.raise(this.start, "Comma is not permitted after the rest element");
                    break;
                  } else
                    y.push(this.parseMaybeAssign(false, re, this.parseParenItem));
                var $e = this.lastTokEnd, Ie = this.lastTokEndLoc;
                if (this.expect(i.parenR), e && !this.canInsertSemicolon() && this.eat(i.arrow))
                  return this.checkPatternErrors(re, false), this.checkYieldAwaitInDefaultParams(), this.yieldPos = Se, this.awaitPos = qe, this.parseParenArrowList(r, s, y, t3);
                (!y.length || W) && this.unexpected(this.lastTokStart), Be && this.unexpected(Be), this.checkExpressionErrors(re, true), this.yieldPos = Se || this.yieldPos, this.awaitPos = qe || this.awaitPos, y.length > 1 ? (n = this.startNodeAt(c, v), n.expressions = y, this.finishNodeAt(n, "SequenceExpression", $e, Ie)) : n = y[0];
              } else
                n = this.parseParenExpression();
              if (this.options.preserveParens) {
                var Te = this.startNodeAt(r, s);
                return Te.expression = n, this.finishNode(Te, "ParenthesizedExpression");
              } else
                return n;
            }, z.parseParenItem = function(e) {
              return e;
            }, z.parseParenArrowList = function(e, t3, r, s) {
              return this.parseArrowExpression(this.startNodeAt(e, t3), r, false, s);
            };
            var tn = [];
            z.parseNew = function() {
              this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword new");
              var e = this.startNode(), t3 = this.parseIdent(true);
              if (this.options.ecmaVersion >= 6 && this.eat(i.dot)) {
                e.meta = t3;
                var r = this.containsEsc;
                return e.property = this.parseIdent(true), e.property.name !== "target" && this.raiseRecoverable(e.property.start, "The only valid meta property for new is 'new.target'"), r && this.raiseRecoverable(e.start, "'new.target' must not contain escaped characters"), this.allowNewDotTarget || this.raiseRecoverable(e.start, "'new.target' can only be used in functions and class static block"), this.finishNode(e, "MetaProperty");
              }
              var s = this.start, n = this.startLoc, h = this.type === i._import;
              return e.callee = this.parseSubscripts(this.parseExprAtom(), s, n, true, false), h && e.callee.type === "ImportExpression" && this.raise(s, "Cannot use new with import()"), this.eat(i.parenL) ? e.arguments = this.parseExprList(i.parenR, this.options.ecmaVersion >= 8, false) : e.arguments = tn, this.finishNode(e, "NewExpression");
            }, z.parseTemplateElement = function(e) {
              var t3 = e.isTagged, r = this.startNode();
              return this.type === i.invalidTemplate ? (t3 || this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal"), r.value = { raw: this.value, cooked: null }) : r.value = { raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, `
`), cooked: this.value }, this.next(), r.tail = this.type === i.backQuote, this.finishNode(r, "TemplateElement");
            }, z.parseTemplate = function(e) {
              e === void 0 && (e = {});
              var t3 = e.isTagged;
              t3 === void 0 && (t3 = false);
              var r = this.startNode();
              this.next(), r.expressions = [];
              var s = this.parseTemplateElement({ isTagged: t3 });
              for (r.quasis = [s]; !s.tail; )
                this.type === i.eof && this.raise(this.pos, "Unterminated template literal"), this.expect(i.dollarBraceL), r.expressions.push(this.parseExpression()), this.expect(i.braceR), r.quasis.push(s = this.parseTemplateElement({ isTagged: t3 }));
              return this.next(), this.finishNode(r, "TemplateLiteral");
            }, z.isAsyncProp = function(e) {
              return !e.computed && e.key.type === "Identifier" && e.key.name === "async" && (this.type === i.name || this.type === i.num || this.type === i.string || this.type === i.bracketL || this.type.keyword || this.options.ecmaVersion >= 9 && this.type === i.star) && !k.test(this.input.slice(this.lastTokEnd, this.start));
            }, z.parseObj = function(e, t3) {
              var r = this.startNode(), s = true, n = {};
              for (r.properties = [], this.next(); !this.eat(i.braceR); ) {
                if (s)
                  s = false;
                else if (this.expect(i.comma), this.options.ecmaVersion >= 5 && this.afterTrailingComma(i.braceR))
                  break;
                var h = this.parseProperty(e, t3);
                e || this.checkPropClash(h, n, t3), r.properties.push(h);
              }
              return this.finishNode(r, e ? "ObjectPattern" : "ObjectExpression");
            }, z.parseProperty = function(e, t3) {
              var r = this.startNode(), s, n, h, c;
              if (this.options.ecmaVersion >= 9 && this.eat(i.ellipsis))
                return e ? (r.argument = this.parseIdent(false), this.type === i.comma && this.raise(this.start, "Comma is not permitted after the rest element"), this.finishNode(r, "RestElement")) : (r.argument = this.parseMaybeAssign(false, t3), this.type === i.comma && t3 && t3.trailingComma < 0 && (t3.trailingComma = this.start), this.finishNode(r, "SpreadElement"));
              this.options.ecmaVersion >= 6 && (r.method = false, r.shorthand = false, (e || t3) && (h = this.start, c = this.startLoc), e || (s = this.eat(i.star)));
              var v = this.containsEsc;
              return this.parsePropertyName(r), !e && !v && this.options.ecmaVersion >= 8 && !s && this.isAsyncProp(r) ? (n = true, s = this.options.ecmaVersion >= 9 && this.eat(i.star), this.parsePropertyName(r, t3)) : n = false, this.parsePropertyValue(r, e, s, n, h, c, t3, v), this.finishNode(r, "Property");
            }, z.parsePropertyValue = function(e, t3, r, s, n, h, c, v) {
              if ((r || s) && this.type === i.colon && this.unexpected(), this.eat(i.colon))
                e.value = t3 ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(false, c), e.kind = "init";
              else if (this.options.ecmaVersion >= 6 && this.type === i.parenL)
                t3 && this.unexpected(), e.kind = "init", e.method = true, e.value = this.parseMethod(r, s);
              else if (!t3 && !v && this.options.ecmaVersion >= 5 && !e.computed && e.key.type === "Identifier" && (e.key.name === "get" || e.key.name === "set") && this.type !== i.comma && this.type !== i.braceR && this.type !== i.eq) {
                (r || s) && this.unexpected(), e.kind = e.key.name, this.parsePropertyName(e), e.value = this.parseMethod(false);
                var y = e.kind === "get" ? 0 : 1;
                if (e.value.params.length !== y) {
                  var U = e.value.start;
                  e.kind === "get" ? this.raiseRecoverable(U, "getter should have no params") : this.raiseRecoverable(U, "setter should have exactly one param");
                } else
                  e.kind === "set" && e.value.params[0].type === "RestElement" && this.raiseRecoverable(e.value.params[0].start, "Setter cannot use rest params");
              } else
                this.options.ecmaVersion >= 6 && !e.computed && e.key.type === "Identifier" ? ((r || s) && this.unexpected(), this.checkUnreserved(e.key), e.key.name === "await" && !this.awaitIdentPos && (this.awaitIdentPos = n), e.kind = "init", t3 ? e.value = this.parseMaybeDefault(n, h, this.copyNode(e.key)) : this.type === i.eq && c ? (c.shorthandAssign < 0 && (c.shorthandAssign = this.start), e.value = this.parseMaybeDefault(n, h, this.copyNode(e.key))) : e.value = this.copyNode(e.key), e.shorthand = true) : this.unexpected();
            }, z.parsePropertyName = function(e) {
              if (this.options.ecmaVersion >= 6) {
                if (this.eat(i.bracketL))
                  return e.computed = true, e.key = this.parseMaybeAssign(), this.expect(i.bracketR), e.key;
                e.computed = false;
              }
              return e.key = this.type === i.num || this.type === i.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== "never");
            }, z.initFunction = function(e) {
              e.id = null, this.options.ecmaVersion >= 6 && (e.generator = e.expression = false), this.options.ecmaVersion >= 8 && (e.async = false);
            }, z.parseMethod = function(e, t3, r) {
              var s = this.startNode(), n = this.yieldPos, h = this.awaitPos, c = this.awaitIdentPos;
              return this.initFunction(s), this.options.ecmaVersion >= 6 && (s.generator = e), this.options.ecmaVersion >= 8 && (s.async = !!t3), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(xt(t3, s.generator) | vt | (r ? gr : 0)), this.expect(i.parenL), s.params = this.parseBindingList(i.parenR, false, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams(), this.parseFunctionBody(s, false, true, false), this.yieldPos = n, this.awaitPos = h, this.awaitIdentPos = c, this.finishNode(s, "FunctionExpression");
            }, z.parseArrowExpression = function(e, t3, r, s) {
              var n = this.yieldPos, h = this.awaitPos, c = this.awaitIdentPos;
              return this.enterScope(xt(r, false) | mr), this.initFunction(e), this.options.ecmaVersion >= 8 && (e.async = !!r), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, e.params = this.toAssignableList(t3, true), this.parseFunctionBody(e, true, false, s), this.yieldPos = n, this.awaitPos = h, this.awaitIdentPos = c, this.finishNode(e, "ArrowFunctionExpression");
            }, z.parseFunctionBody = function(e, t3, r, s) {
              var n = t3 && this.type !== i.braceL, h = this.strict, c = false;
              if (n)
                e.body = this.parseMaybeAssign(s), e.expression = true, this.checkParams(e, false);
              else {
                var v = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(e.params);
                (!h || v) && (c = this.strictDirective(this.end), c && v && this.raiseRecoverable(e.start, "Illegal 'use strict' directive in function with non-simple parameter list"));
                var y = this.labels;
                this.labels = [], c && (this.strict = true), this.checkParams(e, !h && !c && !t3 && !r && this.isSimpleParamList(e.params)), this.strict && e.id && this.checkLValSimple(e.id, Ar), e.body = this.parseBlock(false, void 0, c && !h), e.expression = false, this.adaptDirectivePrologue(e.body.body), this.labels = y;
              }
              this.exitScope();
            }, z.isSimpleParamList = function(e) {
              for (var t3 = 0, r = e; t3 < r.length; t3 += 1) {
                var s = r[t3];
                if (s.type !== "Identifier")
                  return false;
              }
              return true;
            }, z.checkParams = function(e, t3) {
              for (var r = /* @__PURE__ */ Object.create(null), s = 0, n = e.params; s < n.length; s += 1) {
                var h = n[s];
                this.checkLValInnerPattern(h, yt, t3 ? null : r);
              }
            }, z.parseExprList = function(e, t3, r, s) {
              for (var n = [], h = true; !this.eat(e); ) {
                if (h)
                  h = false;
                else if (this.expect(i.comma), t3 && this.afterTrailingComma(e))
                  break;
                var c = void 0;
                r && this.type === i.comma ? c = null : this.type === i.ellipsis ? (c = this.parseSpread(s), s && this.type === i.comma && s.trailingComma < 0 && (s.trailingComma = this.start)) : c = this.parseMaybeAssign(false, s), n.push(c);
              }
              return n;
            }, z.checkUnreserved = function(e) {
              var t3 = e.start, r = e.end, s = e.name;
              if (this.inGenerator && s === "yield" && this.raiseRecoverable(t3, "Cannot use 'yield' as identifier inside a generator"), this.inAsync && s === "await" && this.raiseRecoverable(t3, "Cannot use 'await' as identifier inside an async function"), this.currentThisScope().inClassFieldInit && s === "arguments" && this.raiseRecoverable(t3, "Cannot use 'arguments' in class field initializer"), this.inClassStaticBlock && (s === "arguments" || s === "await") && this.raise(t3, "Cannot use " + s + " in class static initialization block"), this.keywords.test(s) && this.raise(t3, "Unexpected keyword '" + s + "'"), !(this.options.ecmaVersion < 6 && this.input.slice(t3, r).indexOf("\\") !== -1)) {
                var n = this.strict ? this.reservedWordsStrict : this.reservedWords;
                n.test(s) && (!this.inAsync && s === "await" && this.raiseRecoverable(t3, "Cannot use keyword 'await' outside an async function"), this.raiseRecoverable(t3, "The keyword '" + s + "' is reserved"));
              }
            }, z.parseIdent = function(e, t3) {
              var r = this.startNode();
              return this.type === i.name ? r.name = this.value : this.type.keyword ? (r.name = this.type.keyword, (r.name === "class" || r.name === "function") && (this.lastTokEnd !== this.lastTokStart + 1 || this.input.charCodeAt(this.lastTokStart) !== 46) && this.context.pop()) : this.unexpected(), this.next(!!e), this.finishNode(r, "Identifier"), e || (this.checkUnreserved(r), r.name === "await" && !this.awaitIdentPos && (this.awaitIdentPos = r.start)), r;
            }, z.parsePrivateIdent = function() {
              var e = this.startNode();
              return this.type === i.privateId ? e.name = this.value : this.unexpected(), this.next(), this.finishNode(e, "PrivateIdentifier"), this.privateNameStack.length === 0 ? this.raise(e.start, "Private field '#" + e.name + "' must be declared in an enclosing class") : this.privateNameStack[this.privateNameStack.length - 1].used.push(e), e;
            }, z.parseYield = function(e) {
              this.yieldPos || (this.yieldPos = this.start);
              var t3 = this.startNode();
              return this.next(), this.type === i.semi || this.canInsertSemicolon() || this.type !== i.star && !this.type.startsExpr ? (t3.delegate = false, t3.argument = null) : (t3.delegate = this.eat(i.star), t3.argument = this.parseMaybeAssign(e)), this.finishNode(t3, "YieldExpression");
            }, z.parseAwait = function(e) {
              this.awaitPos || (this.awaitPos = this.start);
              var t3 = this.startNode();
              return this.next(), t3.argument = this.parseMaybeUnary(null, true, false, e), this.finishNode(t3, "AwaitExpression");
            };
            var Xe = Y.prototype;
            Xe.raise = function(e, t3) {
              var r = ae(this.input, e);
              t3 += " (" + r.line + ":" + r.column + ")";
              var s = new SyntaxError(t3);
              throw s.pos = e, s.loc = r, s.raisedAt = this.pos, s;
            }, Xe.raiseRecoverable = Xe.raise, Xe.curPosition = function() {
              if (this.options.locations)
                return new H(this.curLine, this.pos - this.lineStart);
            };
            var Ee = Y.prototype, rn = function(t3) {
              this.flags = t3, this.var = [], this.lexical = [], this.functions = [], this.inClassFieldInit = false;
            };
            Ee.enterScope = function(e) {
              this.scopeStack.push(new rn(e));
            }, Ee.exitScope = function() {
              this.scopeStack.pop();
            }, Ee.treatFunctionsAsVarInScope = function(e) {
              return e.flags & Ce || !this.inModule && e.flags & _e;
            }, Ee.declareName = function(e, t3, r) {
              var s = false;
              if (t3 === ve) {
                var n = this.currentScope();
                s = n.lexical.indexOf(e) > -1 || n.functions.indexOf(e) > -1 || n.var.indexOf(e) > -1, n.lexical.push(e), this.inModule && n.flags & _e && delete this.undefinedExports[e];
              } else if (t3 === yr) {
                var h = this.currentScope();
                h.lexical.push(e);
              } else if (t3 === xr) {
                var c = this.currentScope();
                this.treatFunctionsAsVar ? s = c.lexical.indexOf(e) > -1 : s = c.lexical.indexOf(e) > -1 || c.var.indexOf(e) > -1, c.functions.push(e);
              } else
                for (var v = this.scopeStack.length - 1; v >= 0; --v) {
                  var y = this.scopeStack[v];
                  if (y.lexical.indexOf(e) > -1 && !(y.flags & vr && y.lexical[0] === e) || !this.treatFunctionsAsVarInScope(y) && y.functions.indexOf(e) > -1) {
                    s = true;
                    break;
                  }
                  if (y.var.push(e), this.inModule && y.flags & _e && delete this.undefinedExports[e], y.flags & gt)
                    break;
                }
              s && this.raiseRecoverable(r, "Identifier '" + e + "' has already been declared");
            }, Ee.checkLocalExport = function(e) {
              this.scopeStack[0].lexical.indexOf(e.name) === -1 && this.scopeStack[0].var.indexOf(e.name) === -1 && (this.undefinedExports[e.name] = e);
            }, Ee.currentScope = function() {
              return this.scopeStack[this.scopeStack.length - 1];
            }, Ee.currentVarScope = function() {
              for (var e = this.scopeStack.length - 1; ; e--) {
                var t3 = this.scopeStack[e];
                if (t3.flags & gt)
                  return t3;
              }
            }, Ee.currentThisScope = function() {
              for (var e = this.scopeStack.length - 1; ; e--) {
                var t3 = this.scopeStack[e];
                if (t3.flags & gt && !(t3.flags & mr))
                  return t3;
              }
            };
            var Re = function(t3, r, s) {
              this.type = "", this.start = r, this.end = 0, t3.options.locations && (this.loc = new te(t3, s)), t3.options.directSourceFile && (this.sourceFile = t3.options.directSourceFile), t3.options.ranges && (this.range = [r, 0]);
            }, je = Y.prototype;
            je.startNode = function() {
              return new Re(this, this.start, this.startLoc);
            }, je.startNodeAt = function(e, t3) {
              return new Re(this, e, t3);
            };
            function br(e, t3, r, s) {
              return e.type = t3, e.end = r, this.options.locations && (e.loc.end = s), this.options.ranges && (e.range[1] = r), e;
            }
            je.finishNode = function(e, t3) {
              return br.call(this, e, t3, this.lastTokEnd, this.lastTokEndLoc);
            }, je.finishNodeAt = function(e, t3, r, s) {
              return br.call(this, e, t3, r, s);
            }, je.copyNode = function(e) {
              var t3 = new Re(this, e.start, this.startLoc);
              for (var r in e)
                t3[r] = e[r];
              return t3;
            };
            var _r = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS", Sr = _r + " Extended_Pictographic", wr = Sr, kr = wr + " EBase EComp EMod EPres ExtPict", sn = kr, an = { 9: _r, 10: Sr, 11: wr, 12: kr, 13: sn }, Fr = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu", Br = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb", Ir = Br + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd", Tr = Ir + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho", Pr = Tr + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi", nn = Pr + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith", un = { 9: Br, 10: Ir, 11: Tr, 12: Pr, 13: nn }, Dr = {};
            function on(e) {
              var t3 = Dr[e] = { binary: f(an[e] + " " + Fr), nonBinary: { General_Category: f(Fr), Script: f(un[e]) } };
              t3.nonBinary.Script_Extensions = t3.nonBinary.Script, t3.nonBinary.gc = t3.nonBinary.General_Category, t3.nonBinary.sc = t3.nonBinary.Script, t3.nonBinary.scx = t3.nonBinary.Script_Extensions;
            }
            for (var Et = 0, Nr = [9, 10, 11, 12, 13]; Et < Nr.length; Et += 1) {
              var hn = Nr[Et];
              on(hn);
            }
            var V = Y.prototype, ge = function(t3) {
              this.parser = t3, this.validFlags = "gim" + (t3.options.ecmaVersion >= 6 ? "uy" : "") + (t3.options.ecmaVersion >= 9 ? "s" : "") + (t3.options.ecmaVersion >= 13 ? "d" : ""), this.unicodeProperties = Dr[t3.options.ecmaVersion >= 13 ? 13 : t3.options.ecmaVersion], this.source = "", this.flags = "", this.start = 0, this.switchU = false, this.switchN = false, this.pos = 0, this.lastIntValue = 0, this.lastStringValue = "", this.lastAssertionIsQuantifiable = false, this.numCapturingParens = 0, this.maxBackReference = 0, this.groupNames = [], this.backReferenceNames = [];
            };
            ge.prototype.reset = function(t3, r, s) {
              var n = s.indexOf("u") !== -1;
              this.start = t3 | 0, this.source = r + "", this.flags = s, this.switchU = n && this.parser.options.ecmaVersion >= 6, this.switchN = n && this.parser.options.ecmaVersion >= 9;
            }, ge.prototype.raise = function(t3) {
              this.parser.raiseRecoverable(this.start, "Invalid regular expression: /" + this.source + "/: " + t3);
            }, ge.prototype.at = function(t3, r) {
              r === void 0 && (r = false);
              var s = this.source, n = s.length;
              if (t3 >= n)
                return -1;
              var h = s.charCodeAt(t3);
              if (!(r || this.switchU) || h <= 55295 || h >= 57344 || t3 + 1 >= n)
                return h;
              var c = s.charCodeAt(t3 + 1);
              return c >= 56320 && c <= 57343 ? (h << 10) + c - 56613888 : h;
            }, ge.prototype.nextIndex = function(t3, r) {
              r === void 0 && (r = false);
              var s = this.source, n = s.length;
              if (t3 >= n)
                return n;
              var h = s.charCodeAt(t3), c;
              return !(r || this.switchU) || h <= 55295 || h >= 57344 || t3 + 1 >= n || (c = s.charCodeAt(t3 + 1)) < 56320 || c > 57343 ? t3 + 1 : t3 + 2;
            }, ge.prototype.current = function(t3) {
              return t3 === void 0 && (t3 = false), this.at(this.pos, t3);
            }, ge.prototype.lookahead = function(t3) {
              return t3 === void 0 && (t3 = false), this.at(this.nextIndex(this.pos, t3), t3);
            }, ge.prototype.advance = function(t3) {
              t3 === void 0 && (t3 = false), this.pos = this.nextIndex(this.pos, t3);
            }, ge.prototype.eat = function(t3, r) {
              return r === void 0 && (r = false), this.current(r) === t3 ? (this.advance(r), true) : false;
            }, V.validateRegExpFlags = function(e) {
              for (var t3 = e.validFlags, r = e.flags, s = 0; s < r.length; s++) {
                var n = r.charAt(s);
                t3.indexOf(n) === -1 && this.raise(e.start, "Invalid regular expression flag"), r.indexOf(n, s + 1) > -1 && this.raise(e.start, "Duplicate regular expression flag");
              }
            }, V.validateRegExpPattern = function(e) {
              this.regexp_pattern(e), !e.switchN && this.options.ecmaVersion >= 9 && e.groupNames.length > 0 && (e.switchN = true, this.regexp_pattern(e));
            }, V.regexp_pattern = function(e) {
              e.pos = 0, e.lastIntValue = 0, e.lastStringValue = "", e.lastAssertionIsQuantifiable = false, e.numCapturingParens = 0, e.maxBackReference = 0, e.groupNames.length = 0, e.backReferenceNames.length = 0, this.regexp_disjunction(e), e.pos !== e.source.length && (e.eat(41) && e.raise("Unmatched ')'"), (e.eat(93) || e.eat(125)) && e.raise("Lone quantifier brackets")), e.maxBackReference > e.numCapturingParens && e.raise("Invalid escape");
              for (var t3 = 0, r = e.backReferenceNames; t3 < r.length; t3 += 1) {
                var s = r[t3];
                e.groupNames.indexOf(s) === -1 && e.raise("Invalid named capture referenced");
              }
            }, V.regexp_disjunction = function(e) {
              for (this.regexp_alternative(e); e.eat(124); )
                this.regexp_alternative(e);
              this.regexp_eatQuantifier(e, true) && e.raise("Nothing to repeat"), e.eat(123) && e.raise("Lone quantifier brackets");
            }, V.regexp_alternative = function(e) {
              for (; e.pos < e.source.length && this.regexp_eatTerm(e); )
                ;
            }, V.regexp_eatTerm = function(e) {
              return this.regexp_eatAssertion(e) ? (e.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(e) && e.switchU && e.raise("Invalid quantifier"), true) : (e.switchU ? this.regexp_eatAtom(e) : this.regexp_eatExtendedAtom(e)) ? (this.regexp_eatQuantifier(e), true) : false;
            }, V.regexp_eatAssertion = function(e) {
              var t3 = e.pos;
              if (e.lastAssertionIsQuantifiable = false, e.eat(94) || e.eat(36))
                return true;
              if (e.eat(92)) {
                if (e.eat(66) || e.eat(98))
                  return true;
                e.pos = t3;
              }
              if (e.eat(40) && e.eat(63)) {
                var r = false;
                if (this.options.ecmaVersion >= 9 && (r = e.eat(60)), e.eat(61) || e.eat(33))
                  return this.regexp_disjunction(e), e.eat(41) || e.raise("Unterminated group"), e.lastAssertionIsQuantifiable = !r, true;
              }
              return e.pos = t3, false;
            }, V.regexp_eatQuantifier = function(e, t3) {
              return t3 === void 0 && (t3 = false), this.regexp_eatQuantifierPrefix(e, t3) ? (e.eat(63), true) : false;
            }, V.regexp_eatQuantifierPrefix = function(e, t3) {
              return e.eat(42) || e.eat(43) || e.eat(63) || this.regexp_eatBracedQuantifier(e, t3);
            }, V.regexp_eatBracedQuantifier = function(e, t3) {
              var r = e.pos;
              if (e.eat(123)) {
                var s = 0, n = -1;
                if (this.regexp_eatDecimalDigits(e) && (s = e.lastIntValue, e.eat(44) && this.regexp_eatDecimalDigits(e) && (n = e.lastIntValue), e.eat(125)))
                  return n !== -1 && n < s && !t3 && e.raise("numbers out of order in {} quantifier"), true;
                e.switchU && !t3 && e.raise("Incomplete quantifier"), e.pos = r;
              }
              return false;
            }, V.regexp_eatAtom = function(e) {
              return this.regexp_eatPatternCharacters(e) || e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e);
            }, V.regexp_eatReverseSolidusAtomEscape = function(e) {
              var t3 = e.pos;
              if (e.eat(92)) {
                if (this.regexp_eatAtomEscape(e))
                  return true;
                e.pos = t3;
              }
              return false;
            }, V.regexp_eatUncapturingGroup = function(e) {
              var t3 = e.pos;
              if (e.eat(40)) {
                if (e.eat(63) && e.eat(58)) {
                  if (this.regexp_disjunction(e), e.eat(41))
                    return true;
                  e.raise("Unterminated group");
                }
                e.pos = t3;
              }
              return false;
            }, V.regexp_eatCapturingGroup = function(e) {
              if (e.eat(40)) {
                if (this.options.ecmaVersion >= 9 ? this.regexp_groupSpecifier(e) : e.current() === 63 && e.raise("Invalid group"), this.regexp_disjunction(e), e.eat(41))
                  return e.numCapturingParens += 1, true;
                e.raise("Unterminated group");
              }
              return false;
            }, V.regexp_eatExtendedAtom = function(e) {
              return e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e) || this.regexp_eatInvalidBracedQuantifier(e) || this.regexp_eatExtendedPatternCharacter(e);
            }, V.regexp_eatInvalidBracedQuantifier = function(e) {
              return this.regexp_eatBracedQuantifier(e, true) && e.raise("Nothing to repeat"), false;
            }, V.regexp_eatSyntaxCharacter = function(e) {
              var t3 = e.current();
              return Or(t3) ? (e.lastIntValue = t3, e.advance(), true) : false;
            };
            function Or(e) {
              return e === 36 || e >= 40 && e <= 43 || e === 46 || e === 63 || e >= 91 && e <= 94 || e >= 123 && e <= 125;
            }
            V.regexp_eatPatternCharacters = function(e) {
              for (var t3 = e.pos, r = 0; (r = e.current()) !== -1 && !Or(r); )
                e.advance();
              return e.pos !== t3;
            }, V.regexp_eatExtendedPatternCharacter = function(e) {
              var t3 = e.current();
              return t3 !== -1 && t3 !== 36 && !(t3 >= 40 && t3 <= 43) && t3 !== 46 && t3 !== 63 && t3 !== 91 && t3 !== 94 && t3 !== 124 ? (e.advance(), true) : false;
            }, V.regexp_groupSpecifier = function(e) {
              if (e.eat(63)) {
                if (this.regexp_eatGroupName(e)) {
                  e.groupNames.indexOf(e.lastStringValue) !== -1 && e.raise("Duplicate capture group name"), e.groupNames.push(e.lastStringValue);
                  return;
                }
                e.raise("Invalid group");
              }
            }, V.regexp_eatGroupName = function(e) {
              if (e.lastStringValue = "", e.eat(60)) {
                if (this.regexp_eatRegExpIdentifierName(e) && e.eat(62))
                  return true;
                e.raise("Invalid capture group name");
              }
              return false;
            }, V.regexp_eatRegExpIdentifierName = function(e) {
              if (e.lastStringValue = "", this.regexp_eatRegExpIdentifierStart(e)) {
                for (e.lastStringValue += b(e.lastIntValue); this.regexp_eatRegExpIdentifierPart(e); )
                  e.lastStringValue += b(e.lastIntValue);
                return true;
              }
              return false;
            }, V.regexp_eatRegExpIdentifierStart = function(e) {
              var t3 = e.pos, r = this.options.ecmaVersion >= 11, s = e.current(r);
              return e.advance(r), s === 92 && this.regexp_eatRegExpUnicodeEscapeSequence(e, r) && (s = e.lastIntValue), ln(s) ? (e.lastIntValue = s, true) : (e.pos = t3, false);
            };
            function ln(e) {
              return m(e, true) || e === 36 || e === 95;
            }
            V.regexp_eatRegExpIdentifierPart = function(e) {
              var t3 = e.pos, r = this.options.ecmaVersion >= 11, s = e.current(r);
              return e.advance(r), s === 92 && this.regexp_eatRegExpUnicodeEscapeSequence(e, r) && (s = e.lastIntValue), cn(s) ? (e.lastIntValue = s, true) : (e.pos = t3, false);
            };
            function cn(e) {
              return O(e, true) || e === 36 || e === 95 || e === 8204 || e === 8205;
            }
            V.regexp_eatAtomEscape = function(e) {
              return this.regexp_eatBackReference(e) || this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e) || e.switchN && this.regexp_eatKGroupName(e) ? true : (e.switchU && (e.current() === 99 && e.raise("Invalid unicode escape"), e.raise("Invalid escape")), false);
            }, V.regexp_eatBackReference = function(e) {
              var t3 = e.pos;
              if (this.regexp_eatDecimalEscape(e)) {
                var r = e.lastIntValue;
                if (e.switchU)
                  return r > e.maxBackReference && (e.maxBackReference = r), true;
                if (r <= e.numCapturingParens)
                  return true;
                e.pos = t3;
              }
              return false;
            }, V.regexp_eatKGroupName = function(e) {
              if (e.eat(107)) {
                if (this.regexp_eatGroupName(e))
                  return e.backReferenceNames.push(e.lastStringValue), true;
                e.raise("Invalid named reference");
              }
              return false;
            }, V.regexp_eatCharacterEscape = function(e) {
              return this.regexp_eatControlEscape(e) || this.regexp_eatCControlLetter(e) || this.regexp_eatZero(e) || this.regexp_eatHexEscapeSequence(e) || this.regexp_eatRegExpUnicodeEscapeSequence(e, false) || !e.switchU && this.regexp_eatLegacyOctalEscapeSequence(e) || this.regexp_eatIdentityEscape(e);
            }, V.regexp_eatCControlLetter = function(e) {
              var t3 = e.pos;
              if (e.eat(99)) {
                if (this.regexp_eatControlLetter(e))
                  return true;
                e.pos = t3;
              }
              return false;
            }, V.regexp_eatZero = function(e) {
              return e.current() === 48 && !Je(e.lookahead()) ? (e.lastIntValue = 0, e.advance(), true) : false;
            }, V.regexp_eatControlEscape = function(e) {
              var t3 = e.current();
              return t3 === 116 ? (e.lastIntValue = 9, e.advance(), true) : t3 === 110 ? (e.lastIntValue = 10, e.advance(), true) : t3 === 118 ? (e.lastIntValue = 11, e.advance(), true) : t3 === 102 ? (e.lastIntValue = 12, e.advance(), true) : t3 === 114 ? (e.lastIntValue = 13, e.advance(), true) : false;
            }, V.regexp_eatControlLetter = function(e) {
              var t3 = e.current();
              return Lr(t3) ? (e.lastIntValue = t3 % 32, e.advance(), true) : false;
            };
            function Lr(e) {
              return e >= 65 && e <= 90 || e >= 97 && e <= 122;
            }
            V.regexp_eatRegExpUnicodeEscapeSequence = function(e, t3) {
              t3 === void 0 && (t3 = false);
              var r = e.pos, s = t3 || e.switchU;
              if (e.eat(117)) {
                if (this.regexp_eatFixedHexDigits(e, 4)) {
                  var n = e.lastIntValue;
                  if (s && n >= 55296 && n <= 56319) {
                    var h = e.pos;
                    if (e.eat(92) && e.eat(117) && this.regexp_eatFixedHexDigits(e, 4)) {
                      var c = e.lastIntValue;
                      if (c >= 56320 && c <= 57343)
                        return e.lastIntValue = (n - 55296) * 1024 + (c - 56320) + 65536, true;
                    }
                    e.pos = h, e.lastIntValue = n;
                  }
                  return true;
                }
                if (s && e.eat(123) && this.regexp_eatHexDigits(e) && e.eat(125) && pn(e.lastIntValue))
                  return true;
                s && e.raise("Invalid unicode escape"), e.pos = r;
              }
              return false;
            };
            function pn(e) {
              return e >= 0 && e <= 1114111;
            }
            V.regexp_eatIdentityEscape = function(e) {
              if (e.switchU)
                return this.regexp_eatSyntaxCharacter(e) ? true : e.eat(47) ? (e.lastIntValue = 47, true) : false;
              var t3 = e.current();
              return t3 !== 99 && (!e.switchN || t3 !== 107) ? (e.lastIntValue = t3, e.advance(), true) : false;
            }, V.regexp_eatDecimalEscape = function(e) {
              e.lastIntValue = 0;
              var t3 = e.current();
              if (t3 >= 49 && t3 <= 57) {
                do
                  e.lastIntValue = 10 * e.lastIntValue + (t3 - 48), e.advance();
                while ((t3 = e.current()) >= 48 && t3 <= 57);
                return true;
              }
              return false;
            }, V.regexp_eatCharacterClassEscape = function(e) {
              var t3 = e.current();
              if (fn(t3))
                return e.lastIntValue = -1, e.advance(), true;
              if (e.switchU && this.options.ecmaVersion >= 9 && (t3 === 80 || t3 === 112)) {
                if (e.lastIntValue = -1, e.advance(), e.eat(123) && this.regexp_eatUnicodePropertyValueExpression(e) && e.eat(125))
                  return true;
                e.raise("Invalid property name");
              }
              return false;
            };
            function fn(e) {
              return e === 100 || e === 68 || e === 115 || e === 83 || e === 119 || e === 87;
            }
            V.regexp_eatUnicodePropertyValueExpression = function(e) {
              var t3 = e.pos;
              if (this.regexp_eatUnicodePropertyName(e) && e.eat(61)) {
                var r = e.lastStringValue;
                if (this.regexp_eatUnicodePropertyValue(e)) {
                  var s = e.lastStringValue;
                  return this.regexp_validateUnicodePropertyNameAndValue(e, r, s), true;
                }
              }
              if (e.pos = t3, this.regexp_eatLoneUnicodePropertyNameOrValue(e)) {
                var n = e.lastStringValue;
                return this.regexp_validateUnicodePropertyNameOrValue(e, n), true;
              }
              return false;
            }, V.regexp_validateUnicodePropertyNameAndValue = function(e, t3, r) {
              L(e.unicodeProperties.nonBinary, t3) || e.raise("Invalid property name"), e.unicodeProperties.nonBinary[t3].test(r) || e.raise("Invalid property value");
            }, V.regexp_validateUnicodePropertyNameOrValue = function(e, t3) {
              e.unicodeProperties.binary.test(t3) || e.raise("Invalid property name");
            }, V.regexp_eatUnicodePropertyName = function(e) {
              var t3 = 0;
              for (e.lastStringValue = ""; Vr(t3 = e.current()); )
                e.lastStringValue += b(t3), e.advance();
              return e.lastStringValue !== "";
            };
            function Vr(e) {
              return Lr(e) || e === 95;
            }
            V.regexp_eatUnicodePropertyValue = function(e) {
              var t3 = 0;
              for (e.lastStringValue = ""; dn(t3 = e.current()); )
                e.lastStringValue += b(t3), e.advance();
              return e.lastStringValue !== "";
            };
            function dn(e) {
              return Vr(e) || Je(e);
            }
            V.regexp_eatLoneUnicodePropertyNameOrValue = function(e) {
              return this.regexp_eatUnicodePropertyValue(e);
            }, V.regexp_eatCharacterClass = function(e) {
              if (e.eat(91)) {
                if (e.eat(94), this.regexp_classRanges(e), e.eat(93))
                  return true;
                e.raise("Unterminated character class");
              }
              return false;
            }, V.regexp_classRanges = function(e) {
              for (; this.regexp_eatClassAtom(e); ) {
                var t3 = e.lastIntValue;
                if (e.eat(45) && this.regexp_eatClassAtom(e)) {
                  var r = e.lastIntValue;
                  e.switchU && (t3 === -1 || r === -1) && e.raise("Invalid character class"), t3 !== -1 && r !== -1 && t3 > r && e.raise("Range out of order in character class");
                }
              }
            }, V.regexp_eatClassAtom = function(e) {
              var t3 = e.pos;
              if (e.eat(92)) {
                if (this.regexp_eatClassEscape(e))
                  return true;
                if (e.switchU) {
                  var r = e.current();
                  (r === 99 || qr(r)) && e.raise("Invalid class escape"), e.raise("Invalid escape");
                }
                e.pos = t3;
              }
              var s = e.current();
              return s !== 93 ? (e.lastIntValue = s, e.advance(), true) : false;
            }, V.regexp_eatClassEscape = function(e) {
              var t3 = e.pos;
              if (e.eat(98))
                return e.lastIntValue = 8, true;
              if (e.switchU && e.eat(45))
                return e.lastIntValue = 45, true;
              if (!e.switchU && e.eat(99)) {
                if (this.regexp_eatClassControlLetter(e))
                  return true;
                e.pos = t3;
              }
              return this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e);
            }, V.regexp_eatClassControlLetter = function(e) {
              var t3 = e.current();
              return Je(t3) || t3 === 95 ? (e.lastIntValue = t3 % 32, e.advance(), true) : false;
            }, V.regexp_eatHexEscapeSequence = function(e) {
              var t3 = e.pos;
              if (e.eat(120)) {
                if (this.regexp_eatFixedHexDigits(e, 2))
                  return true;
                e.switchU && e.raise("Invalid escape"), e.pos = t3;
              }
              return false;
            }, V.regexp_eatDecimalDigits = function(e) {
              var t3 = e.pos, r = 0;
              for (e.lastIntValue = 0; Je(r = e.current()); )
                e.lastIntValue = 10 * e.lastIntValue + (r - 48), e.advance();
              return e.pos !== t3;
            };
            function Je(e) {
              return e >= 48 && e <= 57;
            }
            V.regexp_eatHexDigits = function(e) {
              var t3 = e.pos, r = 0;
              for (e.lastIntValue = 0; Rr(r = e.current()); )
                e.lastIntValue = 16 * e.lastIntValue + jr(r), e.advance();
              return e.pos !== t3;
            };
            function Rr(e) {
              return e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102;
            }
            function jr(e) {
              return e >= 65 && e <= 70 ? 10 + (e - 65) : e >= 97 && e <= 102 ? 10 + (e - 97) : e - 48;
            }
            V.regexp_eatLegacyOctalEscapeSequence = function(e) {
              if (this.regexp_eatOctalDigit(e)) {
                var t3 = e.lastIntValue;
                if (this.regexp_eatOctalDigit(e)) {
                  var r = e.lastIntValue;
                  t3 <= 3 && this.regexp_eatOctalDigit(e) ? e.lastIntValue = t3 * 64 + r * 8 + e.lastIntValue : e.lastIntValue = t3 * 8 + r;
                } else
                  e.lastIntValue = t3;
                return true;
              }
              return false;
            }, V.regexp_eatOctalDigit = function(e) {
              var t3 = e.current();
              return qr(t3) ? (e.lastIntValue = t3 - 48, e.advance(), true) : (e.lastIntValue = 0, false);
            };
            function qr(e) {
              return e >= 48 && e <= 55;
            }
            V.regexp_eatFixedHexDigits = function(e, t3) {
              var r = e.pos;
              e.lastIntValue = 0;
              for (var s = 0; s < t3; ++s) {
                var n = e.current();
                if (!Rr(n))
                  return e.pos = r, false;
                e.lastIntValue = 16 * e.lastIntValue + jr(n), e.advance();
              }
              return true;
            };
            var Qe = function(t3) {
              this.type = t3.type, this.value = t3.value, this.start = t3.start, this.end = t3.end, t3.options.locations && (this.loc = new te(t3, t3.startLoc, t3.endLoc)), t3.options.ranges && (this.range = [t3.start, t3.end]);
            }, G = Y.prototype;
            G.next = function(e) {
              !e && this.type.keyword && this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword), this.options.onToken && this.options.onToken(new Qe(this)), this.lastTokEnd = this.end, this.lastTokStart = this.start, this.lastTokEndLoc = this.endLoc, this.lastTokStartLoc = this.startLoc, this.nextToken();
            }, G.getToken = function() {
              return this.next(), new Qe(this);
            }, typeof Symbol < "u" && (G[Symbol.iterator] = function() {
              var e = this;
              return { next: function() {
                var t3 = e.getToken();
                return { done: t3.type === i.eof, value: t3 };
              } };
            }), G.nextToken = function() {
              var e = this.curContext();
              if ((!e || !e.preserveSpace) && this.skipSpace(), this.start = this.pos, this.options.locations && (this.startLoc = this.curPosition()), this.pos >= this.input.length)
                return this.finishToken(i.eof);
              if (e.override)
                return e.override(this);
              this.readToken(this.fullCharCodeAtPos());
            }, G.readToken = function(e) {
              return m(e, this.options.ecmaVersion >= 6) || e === 92 ? this.readWord() : this.getTokenFromCode(e);
            }, G.fullCharCodeAtPos = function() {
              var e = this.input.charCodeAt(this.pos);
              if (e <= 55295 || e >= 56320)
                return e;
              var t3 = this.input.charCodeAt(this.pos + 1);
              return t3 <= 56319 || t3 >= 57344 ? e : (e << 10) + t3 - 56613888;
            }, G.skipBlockComment = function() {
              var e = this.options.onComment && this.curPosition(), t3 = this.pos, r = this.input.indexOf("*/", this.pos += 2);
              if (r === -1 && this.raise(this.pos - 2, "Unterminated comment"), this.pos = r + 2, this.options.locations)
                for (var s = void 0, n = t3; (s = Z(this.input, n, this.pos)) > -1; )
                  ++this.curLine, n = this.lineStart = s;
              this.options.onComment && this.options.onComment(true, this.input.slice(t3 + 2, r), t3, this.pos, e, this.curPosition());
            }, G.skipLineComment = function(e) {
              for (var t3 = this.pos, r = this.options.onComment && this.curPosition(), s = this.input.charCodeAt(this.pos += e); this.pos < this.input.length && !M(s); )
                s = this.input.charCodeAt(++this.pos);
              this.options.onComment && this.options.onComment(false, this.input.slice(t3 + e, this.pos), t3, this.pos, r, this.curPosition());
            }, G.skipSpace = function() {
              e:
                for (; this.pos < this.input.length; ) {
                  var e = this.input.charCodeAt(this.pos);
                  switch (e) {
                    case 32:
                    case 160:
                      ++this.pos;
                      break;
                    case 13:
                      this.input.charCodeAt(this.pos + 1) === 10 && ++this.pos;
                    case 10:
                    case 8232:
                    case 8233:
                      ++this.pos, this.options.locations && (++this.curLine, this.lineStart = this.pos);
                      break;
                    case 47:
                      switch (this.input.charCodeAt(this.pos + 1)) {
                        case 42:
                          this.skipBlockComment();
                          break;
                        case 47:
                          this.skipLineComment(2);
                          break;
                        default:
                          break e;
                      }
                      break;
                    default:
                      if (e > 8 && e < 14 || e >= 5760 && ne.test(String.fromCharCode(e)))
                        ++this.pos;
                      else
                        break e;
                  }
                }
            }, G.finishToken = function(e, t3) {
              this.end = this.pos, this.options.locations && (this.endLoc = this.curPosition());
              var r = this.type;
              this.type = e, this.value = t3, this.updateContext(r);
            }, G.readToken_dot = function() {
              var e = this.input.charCodeAt(this.pos + 1);
              if (e >= 48 && e <= 57)
                return this.readNumber(true);
              var t3 = this.input.charCodeAt(this.pos + 2);
              return this.options.ecmaVersion >= 6 && e === 46 && t3 === 46 ? (this.pos += 3, this.finishToken(i.ellipsis)) : (++this.pos, this.finishToken(i.dot));
            }, G.readToken_slash = function() {
              var e = this.input.charCodeAt(this.pos + 1);
              return this.exprAllowed ? (++this.pos, this.readRegexp()) : e === 61 ? this.finishOp(i.assign, 2) : this.finishOp(i.slash, 1);
            }, G.readToken_mult_modulo_exp = function(e) {
              var t3 = this.input.charCodeAt(this.pos + 1), r = 1, s = e === 42 ? i.star : i.modulo;
              return this.options.ecmaVersion >= 7 && e === 42 && t3 === 42 && (++r, s = i.starstar, t3 = this.input.charCodeAt(this.pos + 2)), t3 === 61 ? this.finishOp(i.assign, r + 1) : this.finishOp(s, r);
            }, G.readToken_pipe_amp = function(e) {
              var t3 = this.input.charCodeAt(this.pos + 1);
              if (t3 === e) {
                if (this.options.ecmaVersion >= 12) {
                  var r = this.input.charCodeAt(this.pos + 2);
                  if (r === 61)
                    return this.finishOp(i.assign, 3);
                }
                return this.finishOp(e === 124 ? i.logicalOR : i.logicalAND, 2);
              }
              return t3 === 61 ? this.finishOp(i.assign, 2) : this.finishOp(e === 124 ? i.bitwiseOR : i.bitwiseAND, 1);
            }, G.readToken_caret = function() {
              var e = this.input.charCodeAt(this.pos + 1);
              return e === 61 ? this.finishOp(i.assign, 2) : this.finishOp(i.bitwiseXOR, 1);
            }, G.readToken_plus_min = function(e) {
              var t3 = this.input.charCodeAt(this.pos + 1);
              return t3 === e ? t3 === 45 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 62 && (this.lastTokEnd === 0 || k.test(this.input.slice(this.lastTokEnd, this.pos))) ? (this.skipLineComment(3), this.skipSpace(), this.nextToken()) : this.finishOp(i.incDec, 2) : t3 === 61 ? this.finishOp(i.assign, 2) : this.finishOp(i.plusMin, 1);
            }, G.readToken_lt_gt = function(e) {
              var t3 = this.input.charCodeAt(this.pos + 1), r = 1;
              return t3 === e ? (r = e === 62 && this.input.charCodeAt(this.pos + 2) === 62 ? 3 : 2, this.input.charCodeAt(this.pos + r) === 61 ? this.finishOp(i.assign, r + 1) : this.finishOp(i.bitShift, r)) : t3 === 33 && e === 60 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 45 && this.input.charCodeAt(this.pos + 3) === 45 ? (this.skipLineComment(4), this.skipSpace(), this.nextToken()) : (t3 === 61 && (r = 2), this.finishOp(i.relational, r));
            }, G.readToken_eq_excl = function(e) {
              var t3 = this.input.charCodeAt(this.pos + 1);
              return t3 === 61 ? this.finishOp(i.equality, this.input.charCodeAt(this.pos + 2) === 61 ? 3 : 2) : e === 61 && t3 === 62 && this.options.ecmaVersion >= 6 ? (this.pos += 2, this.finishToken(i.arrow)) : this.finishOp(e === 61 ? i.eq : i.prefix, 1);
            }, G.readToken_question = function() {
              var e = this.options.ecmaVersion;
              if (e >= 11) {
                var t3 = this.input.charCodeAt(this.pos + 1);
                if (t3 === 46) {
                  var r = this.input.charCodeAt(this.pos + 2);
                  if (r < 48 || r > 57)
                    return this.finishOp(i.questionDot, 2);
                }
                if (t3 === 63) {
                  if (e >= 12) {
                    var s = this.input.charCodeAt(this.pos + 2);
                    if (s === 61)
                      return this.finishOp(i.assign, 3);
                  }
                  return this.finishOp(i.coalesce, 2);
                }
              }
              return this.finishOp(i.question, 1);
            }, G.readToken_numberSign = function() {
              var e = this.options.ecmaVersion, t3 = 35;
              if (e >= 13 && (++this.pos, t3 = this.fullCharCodeAtPos(), m(t3, true) || t3 === 92))
                return this.finishToken(i.privateId, this.readWord1());
              this.raise(this.pos, "Unexpected character '" + b(t3) + "'");
            }, G.getTokenFromCode = function(e) {
              switch (e) {
                case 46:
                  return this.readToken_dot();
                case 40:
                  return ++this.pos, this.finishToken(i.parenL);
                case 41:
                  return ++this.pos, this.finishToken(i.parenR);
                case 59:
                  return ++this.pos, this.finishToken(i.semi);
                case 44:
                  return ++this.pos, this.finishToken(i.comma);
                case 91:
                  return ++this.pos, this.finishToken(i.bracketL);
                case 93:
                  return ++this.pos, this.finishToken(i.bracketR);
                case 123:
                  return ++this.pos, this.finishToken(i.braceL);
                case 125:
                  return ++this.pos, this.finishToken(i.braceR);
                case 58:
                  return ++this.pos, this.finishToken(i.colon);
                case 96:
                  if (this.options.ecmaVersion < 6)
                    break;
                  return ++this.pos, this.finishToken(i.backQuote);
                case 48:
                  var t3 = this.input.charCodeAt(this.pos + 1);
                  if (t3 === 120 || t3 === 88)
                    return this.readRadixNumber(16);
                  if (this.options.ecmaVersion >= 6) {
                    if (t3 === 111 || t3 === 79)
                      return this.readRadixNumber(8);
                    if (t3 === 98 || t3 === 66)
                      return this.readRadixNumber(2);
                  }
                case 49:
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 55:
                case 56:
                case 57:
                  return this.readNumber(false);
                case 34:
                case 39:
                  return this.readString(e);
                case 47:
                  return this.readToken_slash();
                case 37:
                case 42:
                  return this.readToken_mult_modulo_exp(e);
                case 124:
                case 38:
                  return this.readToken_pipe_amp(e);
                case 94:
                  return this.readToken_caret();
                case 43:
                case 45:
                  return this.readToken_plus_min(e);
                case 60:
                case 62:
                  return this.readToken_lt_gt(e);
                case 61:
                case 33:
                  return this.readToken_eq_excl(e);
                case 63:
                  return this.readToken_question();
                case 126:
                  return this.finishOp(i.prefix, 1);
                case 35:
                  return this.readToken_numberSign();
              }
              this.raise(this.pos, "Unexpected character '" + b(e) + "'");
            }, G.finishOp = function(e, t3) {
              var r = this.input.slice(this.pos, this.pos + t3);
              return this.pos += t3, this.finishToken(e, r);
            }, G.readRegexp = function() {
              for (var e, t3, r = this.pos; ; ) {
                this.pos >= this.input.length && this.raise(r, "Unterminated regular expression");
                var s = this.input.charAt(this.pos);
                if (k.test(s) && this.raise(r, "Unterminated regular expression"), e)
                  e = false;
                else {
                  if (s === "[")
                    t3 = true;
                  else if (s === "]" && t3)
                    t3 = false;
                  else if (s === "/" && !t3)
                    break;
                  e = s === "\\";
                }
                ++this.pos;
              }
              var n = this.input.slice(r, this.pos);
              ++this.pos;
              var h = this.pos, c = this.readWord1();
              this.containsEsc && this.unexpected(h);
              var v = this.regexpState || (this.regexpState = new ge(this));
              v.reset(r, n, c), this.validateRegExpFlags(v), this.validateRegExpPattern(v);
              var y = null;
              try {
                y = new RegExp(n, c);
              } catch {
              }
              return this.finishToken(i.regexp, { pattern: n, flags: c, value: y });
            }, G.readInt = function(e, t3, r) {
              for (var s = this.options.ecmaVersion >= 12 && t3 === void 0, n = r && this.input.charCodeAt(this.pos) === 48, h = this.pos, c = 0, v = 0, y = 0, U = t3 == null ? 1 / 0 : t3; y < U; ++y, ++this.pos) {
                var W = this.input.charCodeAt(this.pos), re = void 0;
                if (s && W === 95) {
                  n && this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals"), v === 95 && this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore"), y === 0 && this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits"), v = W;
                  continue;
                }
                if (W >= 97 ? re = W - 97 + 10 : W >= 65 ? re = W - 65 + 10 : W >= 48 && W <= 57 ? re = W - 48 : re = 1 / 0, re >= e)
                  break;
                v = W, c = c * e + re;
              }
              return s && v === 95 && this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits"), this.pos === h || t3 != null && this.pos - h !== t3 ? null : c;
            };
            function mn(e, t3) {
              return t3 ? parseInt(e, 8) : parseFloat(e.replace(/_/g, ""));
            }
            function Mr(e) {
              return typeof BigInt != "function" ? null : BigInt(e.replace(/_/g, ""));
            }
            G.readRadixNumber = function(e) {
              var t3 = this.pos;
              this.pos += 2;
              var r = this.readInt(e);
              return r == null && this.raise(this.start + 2, "Expected number in radix " + e), this.options.ecmaVersion >= 11 && this.input.charCodeAt(this.pos) === 110 ? (r = Mr(this.input.slice(t3, this.pos)), ++this.pos) : m(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(i.num, r);
            }, G.readNumber = function(e) {
              var t3 = this.pos;
              !e && this.readInt(10, void 0, true) === null && this.raise(t3, "Invalid number");
              var r = this.pos - t3 >= 2 && this.input.charCodeAt(t3) === 48;
              r && this.strict && this.raise(t3, "Invalid number");
              var s = this.input.charCodeAt(this.pos);
              if (!r && !e && this.options.ecmaVersion >= 11 && s === 110) {
                var n = Mr(this.input.slice(t3, this.pos));
                return ++this.pos, m(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(i.num, n);
              }
              r && /[89]/.test(this.input.slice(t3, this.pos)) && (r = false), s === 46 && !r && (++this.pos, this.readInt(10), s = this.input.charCodeAt(this.pos)), (s === 69 || s === 101) && !r && (s = this.input.charCodeAt(++this.pos), (s === 43 || s === 45) && ++this.pos, this.readInt(10) === null && this.raise(t3, "Invalid number")), m(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number");
              var h = mn(this.input.slice(t3, this.pos), r);
              return this.finishToken(i.num, h);
            }, G.readCodePoint = function() {
              var e = this.input.charCodeAt(this.pos), t3;
              if (e === 123) {
                this.options.ecmaVersion < 6 && this.unexpected();
                var r = ++this.pos;
                t3 = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos), ++this.pos, t3 > 1114111 && this.invalidStringToken(r, "Code point out of bounds");
              } else
                t3 = this.readHexChar(4);
              return t3;
            }, G.readString = function(e) {
              for (var t3 = "", r = ++this.pos; ; ) {
                this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
                var s = this.input.charCodeAt(this.pos);
                if (s === e)
                  break;
                s === 92 ? (t3 += this.input.slice(r, this.pos), t3 += this.readEscapedChar(false), r = this.pos) : s === 8232 || s === 8233 ? (this.options.ecmaVersion < 10 && this.raise(this.start, "Unterminated string constant"), ++this.pos, this.options.locations && (this.curLine++, this.lineStart = this.pos)) : (M(s) && this.raise(this.start, "Unterminated string constant"), ++this.pos);
              }
              return t3 += this.input.slice(r, this.pos++), this.finishToken(i.string, t3);
            };
            var Ur = {};
            G.tryReadTemplateToken = function() {
              this.inTemplateElement = true;
              try {
                this.readTmplToken();
              } catch (e) {
                if (e === Ur)
                  this.readInvalidTemplateToken();
                else
                  throw e;
              }
              this.inTemplateElement = false;
            }, G.invalidStringToken = function(e, t3) {
              if (this.inTemplateElement && this.options.ecmaVersion >= 9)
                throw Ur;
              this.raise(e, t3);
            }, G.readTmplToken = function() {
              for (var e = "", t3 = this.pos; ; ) {
                this.pos >= this.input.length && this.raise(this.start, "Unterminated template");
                var r = this.input.charCodeAt(this.pos);
                if (r === 96 || r === 36 && this.input.charCodeAt(this.pos + 1) === 123)
                  return this.pos === this.start && (this.type === i.template || this.type === i.invalidTemplate) ? r === 36 ? (this.pos += 2, this.finishToken(i.dollarBraceL)) : (++this.pos, this.finishToken(i.backQuote)) : (e += this.input.slice(t3, this.pos), this.finishToken(i.template, e));
                if (r === 92)
                  e += this.input.slice(t3, this.pos), e += this.readEscapedChar(true), t3 = this.pos;
                else if (M(r)) {
                  switch (e += this.input.slice(t3, this.pos), ++this.pos, r) {
                    case 13:
                      this.input.charCodeAt(this.pos) === 10 && ++this.pos;
                    case 10:
                      e += `
`;
                      break;
                    default:
                      e += String.fromCharCode(r);
                      break;
                  }
                  this.options.locations && (++this.curLine, this.lineStart = this.pos), t3 = this.pos;
                } else
                  ++this.pos;
              }
            }, G.readInvalidTemplateToken = function() {
              for (; this.pos < this.input.length; this.pos++)
                switch (this.input[this.pos]) {
                  case "\\":
                    ++this.pos;
                    break;
                  case "$":
                    if (this.input[this.pos + 1] !== "{")
                      break;
                  case "`":
                    return this.finishToken(i.invalidTemplate, this.input.slice(this.start, this.pos));
                }
              this.raise(this.start, "Unterminated template");
            }, G.readEscapedChar = function(e) {
              var t3 = this.input.charCodeAt(++this.pos);
              switch (++this.pos, t3) {
                case 110:
                  return `
`;
                case 114:
                  return "\r";
                case 120:
                  return String.fromCharCode(this.readHexChar(2));
                case 117:
                  return b(this.readCodePoint());
                case 116:
                  return "	";
                case 98:
                  return "\b";
                case 118:
                  return "\v";
                case 102:
                  return "\f";
                case 13:
                  this.input.charCodeAt(this.pos) === 10 && ++this.pos;
                case 10:
                  return this.options.locations && (this.lineStart = this.pos, ++this.curLine), "";
                case 56:
                case 57:
                  if (this.strict && this.invalidStringToken(this.pos - 1, "Invalid escape sequence"), e) {
                    var r = this.pos - 1;
                    return this.invalidStringToken(r, "Invalid escape sequence in template string"), null;
                  }
                default:
                  if (t3 >= 48 && t3 <= 55) {
                    var s = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0], n = parseInt(s, 8);
                    return n > 255 && (s = s.slice(0, -1), n = parseInt(s, 8)), this.pos += s.length - 1, t3 = this.input.charCodeAt(this.pos), (s !== "0" || t3 === 56 || t3 === 57) && (this.strict || e) && this.invalidStringToken(this.pos - 1 - s.length, e ? "Octal literal in template string" : "Octal literal in strict mode"), String.fromCharCode(n);
                  }
                  return M(t3) ? "" : String.fromCharCode(t3);
              }
            }, G.readHexChar = function(e) {
              var t3 = this.pos, r = this.readInt(16, e);
              return r === null && this.invalidStringToken(t3, "Bad character escape sequence"), r;
            }, G.readWord1 = function() {
              this.containsEsc = false;
              for (var e = "", t3 = true, r = this.pos, s = this.options.ecmaVersion >= 6; this.pos < this.input.length; ) {
                var n = this.fullCharCodeAtPos();
                if (O(n, s))
                  this.pos += n <= 65535 ? 1 : 2;
                else if (n === 92) {
                  this.containsEsc = true, e += this.input.slice(r, this.pos);
                  var h = this.pos;
                  this.input.charCodeAt(++this.pos) !== 117 && this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX"), ++this.pos;
                  var c = this.readCodePoint();
                  (t3 ? m : O)(c, s) || this.invalidStringToken(h, "Invalid Unicode escape"), e += b(c), r = this.pos;
                } else
                  break;
                t3 = false;
              }
              return e + this.input.slice(r, this.pos);
            }, G.readWord = function() {
              var e = this.readWord1(), t3 = i.name;
              return this.keywords.test(e) && (t3 = K[e]), this.finishToken(t3, e);
            };
            var zr = "8.8.1";
            Y.acorn = { Parser: Y, version: zr, defaultOptions: fe, Position: H, SourceLocation: te, getLineInfo: ae, Node: Re, TokenType: S, tokTypes: i, keywordTypes: K, TokContext: ue, tokContexts: $2, isIdentifierChar: O, isIdentifierStart: m, Token: Qe, isNewLine: M, lineBreak: k, lineBreakG: T, nonASCIIwhitespace: ne };
            function vn(e, t3) {
              return Y.parse(e, t3);
            }
            function gn(e, t3, r) {
              return Y.parseExpressionAt(e, t3, r);
            }
            function xn(e, t3) {
              return Y.tokenizer(e, t3);
            }
            o.Node = Re, o.Parser = Y, o.Position = H, o.SourceLocation = te, o.TokContext = ue, o.Token = Qe, o.TokenType = S, o.defaultOptions = fe, o.getLineInfo = ae, o.isIdentifierChar = O, o.isIdentifierStart = m, o.isNewLine = M, o.keywordTypes = K, o.lineBreak = k, o.lineBreakG = T, o.nonASCIIwhitespace = ne, o.parse = vn, o.parseExpressionAt = gn, o.tokContexts = $2, o.tokTypes = i, o.tokenizer = xn, o.version = zr, Object.defineProperty(o, "__esModule", { value: true });
          });
        } }), Kh = Q({ "node_modules/acorn-jsx/xhtml.js"(a, u) {
          J(), u.exports = { quot: '"', amp: "&", apos: "'", lt: "<", gt: ">", nbsp: "\xA0", iexcl: "\xA1", cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", brvbar: "\xA6", sect: "\xA7", uml: "\xA8", copy: "\xA9", ordf: "\xAA", laquo: "\xAB", not: "\xAC", shy: "\xAD", reg: "\xAE", macr: "\xAF", deg: "\xB0", plusmn: "\xB1", sup2: "\xB2", sup3: "\xB3", acute: "\xB4", micro: "\xB5", para: "\xB6", middot: "\xB7", cedil: "\xB8", sup1: "\xB9", ordm: "\xBA", raquo: "\xBB", frac14: "\xBC", frac12: "\xBD", frac34: "\xBE", iquest: "\xBF", Agrave: "\xC0", Aacute: "\xC1", Acirc: "\xC2", Atilde: "\xC3", Auml: "\xC4", Aring: "\xC5", AElig: "\xC6", Ccedil: "\xC7", Egrave: "\xC8", Eacute: "\xC9", Ecirc: "\xCA", Euml: "\xCB", Igrave: "\xCC", Iacute: "\xCD", Icirc: "\xCE", Iuml: "\xCF", ETH: "\xD0", Ntilde: "\xD1", Ograve: "\xD2", Oacute: "\xD3", Ocirc: "\xD4", Otilde: "\xD5", Ouml: "\xD6", times: "\xD7", Oslash: "\xD8", Ugrave: "\xD9", Uacute: "\xDA", Ucirc: "\xDB", Uuml: "\xDC", Yacute: "\xDD", THORN: "\xDE", szlig: "\xDF", agrave: "\xE0", aacute: "\xE1", acirc: "\xE2", atilde: "\xE3", auml: "\xE4", aring: "\xE5", aelig: "\xE6", ccedil: "\xE7", egrave: "\xE8", eacute: "\xE9", ecirc: "\xEA", euml: "\xEB", igrave: "\xEC", iacute: "\xED", icirc: "\xEE", iuml: "\xEF", eth: "\xF0", ntilde: "\xF1", ograve: "\xF2", oacute: "\xF3", ocirc: "\xF4", otilde: "\xF5", ouml: "\xF6", divide: "\xF7", oslash: "\xF8", ugrave: "\xF9", uacute: "\xFA", ucirc: "\xFB", uuml: "\xFC", yacute: "\xFD", thorn: "\xFE", yuml: "\xFF", OElig: "\u0152", oelig: "\u0153", Scaron: "\u0160", scaron: "\u0161", Yuml: "\u0178", fnof: "\u0192", circ: "\u02C6", tilde: "\u02DC", Alpha: "\u0391", Beta: "\u0392", Gamma: "\u0393", Delta: "\u0394", Epsilon: "\u0395", Zeta: "\u0396", Eta: "\u0397", Theta: "\u0398", Iota: "\u0399", Kappa: "\u039A", Lambda: "\u039B", Mu: "\u039C", Nu: "\u039D", Xi: "\u039E", Omicron: "\u039F", Pi: "\u03A0", Rho: "\u03A1", Sigma: "\u03A3", Tau: "\u03A4", Upsilon: "\u03A5", Phi: "\u03A6", Chi: "\u03A7", Psi: "\u03A8", Omega: "\u03A9", alpha: "\u03B1", beta: "\u03B2", gamma: "\u03B3", delta: "\u03B4", epsilon: "\u03B5", zeta: "\u03B6", eta: "\u03B7", theta: "\u03B8", iota: "\u03B9", kappa: "\u03BA", lambda: "\u03BB", mu: "\u03BC", nu: "\u03BD", xi: "\u03BE", omicron: "\u03BF", pi: "\u03C0", rho: "\u03C1", sigmaf: "\u03C2", sigma: "\u03C3", tau: "\u03C4", upsilon: "\u03C5", phi: "\u03C6", chi: "\u03C7", psi: "\u03C8", omega: "\u03C9", thetasym: "\u03D1", upsih: "\u03D2", piv: "\u03D6", ensp: "\u2002", emsp: "\u2003", thinsp: "\u2009", zwnj: "\u200C", zwj: "\u200D", lrm: "\u200E", rlm: "\u200F", ndash: "\u2013", mdash: "\u2014", lsquo: "\u2018", rsquo: "\u2019", sbquo: "\u201A", ldquo: "\u201C", rdquo: "\u201D", bdquo: "\u201E", dagger: "\u2020", Dagger: "\u2021", bull: "\u2022", hellip: "\u2026", permil: "\u2030", prime: "\u2032", Prime: "\u2033", lsaquo: "\u2039", rsaquo: "\u203A", oline: "\u203E", frasl: "\u2044", euro: "\u20AC", image: "\u2111", weierp: "\u2118", real: "\u211C", trade: "\u2122", alefsym: "\u2135", larr: "\u2190", uarr: "\u2191", rarr: "\u2192", darr: "\u2193", harr: "\u2194", crarr: "\u21B5", lArr: "\u21D0", uArr: "\u21D1", rArr: "\u21D2", dArr: "\u21D3", hArr: "\u21D4", forall: "\u2200", part: "\u2202", exist: "\u2203", empty: "\u2205", nabla: "\u2207", isin: "\u2208", notin: "\u2209", ni: "\u220B", prod: "\u220F", sum: "\u2211", minus: "\u2212", lowast: "\u2217", radic: "\u221A", prop: "\u221D", infin: "\u221E", ang: "\u2220", and: "\u2227", or: "\u2228", cap: "\u2229", cup: "\u222A", int: "\u222B", there4: "\u2234", sim: "\u223C", cong: "\u2245", asymp: "\u2248", ne: "\u2260", equiv: "\u2261", le: "\u2264", ge: "\u2265", sub: "\u2282", sup: "\u2283", nsub: "\u2284", sube: "\u2286", supe: "\u2287", oplus: "\u2295", otimes: "\u2297", perp: "\u22A5", sdot: "\u22C5", lceil: "\u2308", rceil: "\u2309", lfloor: "\u230A", rfloor: "\u230B", lang: "\u2329", rang: "\u232A", loz: "\u25CA", spades: "\u2660", clubs: "\u2663", hearts: "\u2665", diams: "\u2666" };
        } }), Ja = Q({ "node_modules/acorn-jsx/index.js"(a, u) {
          "use strict";
          J();
          var o = Kh(), l = /^[\da-fA-F]+$/, d = /^\d+$/, E = /* @__PURE__ */ new WeakMap();
          function x(g) {
            g = g.Parser.acorn || g;
            let D = E.get(g);
            if (!D) {
              let q = g.tokTypes, I = g.TokContext, N = g.TokenType, m = new I("<tag", false), O = new I("</tag", false), S = new I("<tag>...</tag>", true, true), _ = { tc_oTag: m, tc_cTag: O, tc_expr: S }, F = { jsxName: new N("jsxName"), jsxText: new N("jsxText", { beforeExpr: true }), jsxTagStart: new N("jsxTagStart", { startsExpr: true }), jsxTagEnd: new N("jsxTagEnd") };
              F.jsxTagStart.updateContext = function() {
                this.context.push(S), this.context.push(m), this.exprAllowed = false;
              }, F.jsxTagEnd.updateContext = function(A) {
                let K = this.context.pop();
                K === m && A === q.slash || K === O ? (this.context.pop(), this.exprAllowed = this.curContext() === S) : this.exprAllowed = true;
              }, D = { tokContexts: _, tokTypes: F }, E.set(g, D);
            }
            return D;
          }
          function B(g) {
            if (!g)
              return g;
            if (g.type === "JSXIdentifier")
              return g.name;
            if (g.type === "JSXNamespacedName")
              return g.namespace.name + ":" + g.name.name;
            if (g.type === "JSXMemberExpression")
              return B(g.object) + "." + B(g.property);
          }
          u.exports = function(g) {
            return g = g || {}, function(D) {
              return P({ allowNamespaces: g.allowNamespaces !== false, allowNamespacedObjects: !!g.allowNamespacedObjects }, D);
            };
          }, Object.defineProperty(u.exports, "tokTypes", { get: function() {
            return x(ft()).tokTypes;
          }, configurable: true, enumerable: true });
          function P(g, D) {
            let q = D.acorn || ft(), I = x(q), N = q.tokTypes, m = I.tokTypes, O = q.tokContexts, S = I.tokContexts.tc_oTag, _ = I.tokContexts.tc_cTag, F = I.tokContexts.tc_expr, A = q.isNewLine, K = q.isIdentifierStart, R = q.isIdentifierChar;
            return class extends D {
              static get acornJsx() {
                return I;
              }
              jsx_readToken() {
                let i = "", k = this.pos;
                for (; ; ) {
                  this.pos >= this.input.length && this.raise(this.start, "Unterminated JSX contents");
                  let T = this.input.charCodeAt(this.pos);
                  switch (T) {
                    case 60:
                    case 123:
                      return this.pos === this.start ? T === 60 && this.exprAllowed ? (++this.pos, this.finishToken(m.jsxTagStart)) : this.getTokenFromCode(T) : (i += this.input.slice(k, this.pos), this.finishToken(m.jsxText, i));
                    case 38:
                      i += this.input.slice(k, this.pos), i += this.jsx_readEntity(), k = this.pos;
                      break;
                    case 62:
                    case 125:
                      this.raise(this.pos, "Unexpected token `" + this.input[this.pos] + "`. Did you mean `" + (T === 62 ? "&gt;" : "&rbrace;") + '` or `{"' + this.input[this.pos] + '"}`?');
                    default:
                      A(T) ? (i += this.input.slice(k, this.pos), i += this.jsx_readNewLine(true), k = this.pos) : ++this.pos;
                  }
                }
              }
              jsx_readNewLine(i) {
                let k = this.input.charCodeAt(this.pos), T;
                return ++this.pos, k === 13 && this.input.charCodeAt(this.pos) === 10 ? (++this.pos, T = i ? `
` : `\r
`) : T = String.fromCharCode(k), this.options.locations && (++this.curLine, this.lineStart = this.pos), T;
              }
              jsx_readString(i) {
                let k = "", T = ++this.pos;
                for (; ; ) {
                  this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
                  let M = this.input.charCodeAt(this.pos);
                  if (M === i)
                    break;
                  M === 38 ? (k += this.input.slice(T, this.pos), k += this.jsx_readEntity(), T = this.pos) : A(M) ? (k += this.input.slice(T, this.pos), k += this.jsx_readNewLine(false), T = this.pos) : ++this.pos;
                }
                return k += this.input.slice(T, this.pos++), this.finishToken(N.string, k);
              }
              jsx_readEntity() {
                let i = "", k = 0, T, M = this.input[this.pos];
                M !== "&" && this.raise(this.pos, "Entity must start with an ampersand");
                let Z = ++this.pos;
                for (; this.pos < this.input.length && k++ < 10; ) {
                  if (M = this.input[this.pos++], M === ";") {
                    i[0] === "#" ? i[1] === "x" ? (i = i.substr(2), l.test(i) && (T = String.fromCharCode(parseInt(i, 16)))) : (i = i.substr(1), d.test(i) && (T = String.fromCharCode(parseInt(i, 10)))) : T = o[i];
                    break;
                  }
                  i += M;
                }
                return T || (this.pos = Z, "&");
              }
              jsx_readWord() {
                let i, k = this.pos;
                do
                  i = this.input.charCodeAt(++this.pos);
                while (R(i) || i === 45);
                return this.finishToken(m.jsxName, this.input.slice(k, this.pos));
              }
              jsx_parseIdentifier() {
                let i = this.startNode();
                return this.type === m.jsxName ? i.name = this.value : this.type.keyword ? i.name = this.type.keyword : this.unexpected(), this.next(), this.finishNode(i, "JSXIdentifier");
              }
              jsx_parseNamespacedName() {
                let i = this.start, k = this.startLoc, T = this.jsx_parseIdentifier();
                if (!g.allowNamespaces || !this.eat(N.colon))
                  return T;
                var M = this.startNodeAt(i, k);
                return M.namespace = T, M.name = this.jsx_parseIdentifier(), this.finishNode(M, "JSXNamespacedName");
              }
              jsx_parseElementName() {
                if (this.type === m.jsxTagEnd)
                  return "";
                let i = this.start, k = this.startLoc, T = this.jsx_parseNamespacedName();
                for (this.type === N.dot && T.type === "JSXNamespacedName" && !g.allowNamespacedObjects && this.unexpected(); this.eat(N.dot); ) {
                  let M = this.startNodeAt(i, k);
                  M.object = T, M.property = this.jsx_parseIdentifier(), T = this.finishNode(M, "JSXMemberExpression");
                }
                return T;
              }
              jsx_parseAttributeValue() {
                switch (this.type) {
                  case N.braceL:
                    let i = this.jsx_parseExpressionContainer();
                    return i.expression.type === "JSXEmptyExpression" && this.raise(i.start, "JSX attributes must only be assigned a non-empty expression"), i;
                  case m.jsxTagStart:
                  case N.string:
                    return this.parseExprAtom();
                  default:
                    this.raise(this.start, "JSX value should be either an expression or a quoted JSX text");
                }
              }
              jsx_parseEmptyExpression() {
                let i = this.startNodeAt(this.lastTokEnd, this.lastTokEndLoc);
                return this.finishNodeAt(i, "JSXEmptyExpression", this.start, this.startLoc);
              }
              jsx_parseExpressionContainer() {
                let i = this.startNode();
                return this.next(), i.expression = this.type === N.braceR ? this.jsx_parseEmptyExpression() : this.parseExpression(), this.expect(N.braceR), this.finishNode(i, "JSXExpressionContainer");
              }
              jsx_parseAttribute() {
                let i = this.startNode();
                return this.eat(N.braceL) ? (this.expect(N.ellipsis), i.argument = this.parseMaybeAssign(), this.expect(N.braceR), this.finishNode(i, "JSXSpreadAttribute")) : (i.name = this.jsx_parseNamespacedName(), i.value = this.eat(N.eq) ? this.jsx_parseAttributeValue() : null, this.finishNode(i, "JSXAttribute"));
              }
              jsx_parseOpeningElementAt(i, k) {
                let T = this.startNodeAt(i, k);
                T.attributes = [];
                let M = this.jsx_parseElementName();
                for (M && (T.name = M); this.type !== N.slash && this.type !== m.jsxTagEnd; )
                  T.attributes.push(this.jsx_parseAttribute());
                return T.selfClosing = this.eat(N.slash), this.expect(m.jsxTagEnd), this.finishNode(T, M ? "JSXOpeningElement" : "JSXOpeningFragment");
              }
              jsx_parseClosingElementAt(i, k) {
                let T = this.startNodeAt(i, k), M = this.jsx_parseElementName();
                return M && (T.name = M), this.expect(m.jsxTagEnd), this.finishNode(T, M ? "JSXClosingElement" : "JSXClosingFragment");
              }
              jsx_parseElementAt(i, k) {
                let T = this.startNodeAt(i, k), M = [], Z = this.jsx_parseOpeningElementAt(i, k), ne = null;
                if (!Z.selfClosing) {
                  e:
                    for (; ; )
                      switch (this.type) {
                        case m.jsxTagStart:
                          if (i = this.start, k = this.startLoc, this.next(), this.eat(N.slash)) {
                            ne = this.jsx_parseClosingElementAt(i, k);
                            break e;
                          }
                          M.push(this.jsx_parseElementAt(i, k));
                          break;
                        case m.jsxText:
                          M.push(this.parseExprAtom());
                          break;
                        case N.braceL:
                          M.push(this.jsx_parseExpressionContainer());
                          break;
                        default:
                          this.unexpected();
                      }
                  B(ne.name) !== B(Z.name) && this.raise(ne.start, "Expected corresponding JSX closing tag for <" + B(Z.name) + ">");
                }
                let ee = Z.name ? "Element" : "Fragment";
                return T["opening" + ee] = Z, T["closing" + ee] = ne, T.children = M, this.type === N.relational && this.value === "<" && this.raise(this.start, "Adjacent JSX elements must be wrapped in an enclosing tag"), this.finishNode(T, "JSX" + ee);
              }
              jsx_parseText() {
                let i = this.parseLiteral(this.value);
                return i.type = "JSXText", i;
              }
              jsx_parseElement() {
                let i = this.start, k = this.startLoc;
                return this.next(), this.jsx_parseElementAt(i, k);
              }
              parseExprAtom(i) {
                return this.type === m.jsxText ? this.jsx_parseText() : this.type === m.jsxTagStart ? this.jsx_parseElement() : super.parseExprAtom(i);
              }
              readToken(i) {
                let k = this.curContext();
                if (k === F)
                  return this.jsx_readToken();
                if (k === S || k === _) {
                  if (K(i))
                    return this.jsx_readWord();
                  if (i == 62)
                    return ++this.pos, this.finishToken(m.jsxTagEnd);
                  if ((i === 34 || i === 39) && k == S)
                    return this.jsx_readString(i);
                }
                return i === 60 && this.exprAllowed && this.input.charCodeAt(this.pos + 1) !== 33 ? (++this.pos, this.finishToken(m.jsxTagStart)) : super.readToken(i);
              }
              updateContext(i) {
                if (this.type == N.braceL) {
                  var k = this.curContext();
                  k == S ? this.context.push(O.b_expr) : k == F ? this.context.push(O.b_tmpl) : super.updateContext(i), this.exprAllowed = true;
                } else if (this.type === N.slash && i === m.jsxTagStart)
                  this.context.length -= 2, this.context.push(_), this.exprAllowed = false;
                else
                  return super.updateContext(i);
              }
            };
          }
        } }), Xh = Q({ "src/language-js/parse/acorn.js"(a, u) {
          "use strict";
          J();
          var o = dr(), l = Ba(), d = Ga(), E = Xa(), x = { ecmaVersion: "latest", sourceType: "module", allowReserved: true, allowReturnOutsideFunction: true, allowImportExportEverywhere: true, allowAwaitOutsideFunction: true, allowSuperOutsideMethod: true, allowHashBang: true, locations: true, ranges: true };
          function B(I) {
            let { message: N, loc: m } = I;
            if (!m)
              return I;
            let { line: O, column: S } = m;
            return o(N.replace(/ \(\d+:\d+\)$/, ""), { start: { line: O, column: S + 1 } });
          }
          var P, g = () => {
            if (!P) {
              let { Parser: I } = ft(), N = Ja();
              P = I.extend(N());
            }
            return P;
          };
          function D(I, N) {
            let m = g(), O = [], S = [], _ = m.parse(I, Object.assign(Object.assign({}, x), {}, { sourceType: N, onComment: O, onToken: S }));
            return _.comments = O, _.tokens = S, _;
          }
          function q(I, N) {
            let m = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, { result: O, error: S } = l(() => D(I, "module"), () => D(I, "script"));
            if (!O)
              throw B(S);
            return m.originalText = I, E(O, m);
          }
          u.exports = d(q);
        } }), Jh = Q({ "src/language-js/parse/utils/replace-hashbang.js"(a, u) {
          "use strict";
          J();
          function o(l) {
            return l.charAt(0) === "#" && l.charAt(1) === "!" ? "//" + l.slice(2) : l;
          }
          u.exports = o;
        } }), Qh = Q({ "node_modules/espree/dist/espree.cjs"(a) {
          "use strict";
          J(), Object.defineProperty(a, "__esModule", { value: true });
          var u = ft(), o = Ja(), l;
          function d(p) {
            return p && typeof p == "object" && "default" in p ? p : { default: p };
          }
          function E(p) {
            if (p && p.__esModule)
              return p;
            var L = /* @__PURE__ */ Object.create(null);
            return p && Object.keys(p).forEach(function(w) {
              if (w !== "default") {
                var f = Object.getOwnPropertyDescriptor(p, w);
                Object.defineProperty(L, w, f.get ? f : { enumerable: true, get: function() {
                  return p[w];
                } });
              }
            }), L.default = p, Object.freeze(L);
          }
          var x = E(u), B = d(o), P = E(l), g = { Boolean: "Boolean", EOF: "<end>", Identifier: "Identifier", PrivateIdentifier: "PrivateIdentifier", Keyword: "Keyword", Null: "Null", Numeric: "Numeric", Punctuator: "Punctuator", String: "String", RegularExpression: "RegularExpression", Template: "Template", JSXIdentifier: "JSXIdentifier", JSXText: "JSXText" };
          function D(p, L) {
            let w = p[0], f = p[p.length - 1], b = { type: g.Template, value: L.slice(w.start, f.end) };
            return w.loc && (b.loc = { start: w.loc.start, end: f.loc.end }), w.range && (b.start = w.range[0], b.end = f.range[1], b.range = [b.start, b.end]), b;
          }
          function q(p, L) {
            this._acornTokTypes = p, this._tokens = [], this._curlyBrace = null, this._code = L;
          }
          q.prototype = { constructor: q, translate(p, L) {
            let w = p.type, f = this._acornTokTypes;
            if (w === f.name)
              p.type = g.Identifier, p.value === "static" && (p.type = g.Keyword), L.ecmaVersion > 5 && (p.value === "yield" || p.value === "let") && (p.type = g.Keyword);
            else if (w === f.privateId)
              p.type = g.PrivateIdentifier;
            else if (w === f.semi || w === f.comma || w === f.parenL || w === f.parenR || w === f.braceL || w === f.braceR || w === f.dot || w === f.bracketL || w === f.colon || w === f.question || w === f.bracketR || w === f.ellipsis || w === f.arrow || w === f.jsxTagStart || w === f.incDec || w === f.starstar || w === f.jsxTagEnd || w === f.prefix || w === f.questionDot || w.binop && !w.keyword || w.isAssign)
              p.type = g.Punctuator, p.value = this._code.slice(p.start, p.end);
            else if (w === f.jsxName)
              p.type = g.JSXIdentifier;
            else if (w.label === "jsxText" || w === f.jsxAttrValueToken)
              p.type = g.JSXText;
            else if (w.keyword)
              w.keyword === "true" || w.keyword === "false" ? p.type = g.Boolean : w.keyword === "null" ? p.type = g.Null : p.type = g.Keyword;
            else if (w === f.num)
              p.type = g.Numeric, p.value = this._code.slice(p.start, p.end);
            else if (w === f.string)
              L.jsxAttrValueToken ? (L.jsxAttrValueToken = false, p.type = g.JSXText) : p.type = g.String, p.value = this._code.slice(p.start, p.end);
            else if (w === f.regexp) {
              p.type = g.RegularExpression;
              let b = p.value;
              p.regex = { flags: b.flags, pattern: b.pattern }, p.value = `/${b.pattern}/${b.flags}`;
            }
            return p;
          }, onToken(p, L) {
            let w = this, f = this._acornTokTypes, b = L.tokens, X = this._tokens;
            function H() {
              b.push(D(w._tokens, w._code)), w._tokens = [];
            }
            if (p.type === f.eof) {
              this._curlyBrace && b.push(this.translate(this._curlyBrace, L));
              return;
            }
            if (p.type === f.backQuote) {
              this._curlyBrace && (b.push(this.translate(this._curlyBrace, L)), this._curlyBrace = null), X.push(p), X.length > 1 && H();
              return;
            }
            if (p.type === f.dollarBraceL) {
              X.push(p), H();
              return;
            }
            if (p.type === f.braceR) {
              this._curlyBrace && b.push(this.translate(this._curlyBrace, L)), this._curlyBrace = p;
              return;
            }
            if (p.type === f.template || p.type === f.invalidTemplate) {
              this._curlyBrace && (X.push(this._curlyBrace), this._curlyBrace = null), X.push(p);
              return;
            }
            this._curlyBrace && (b.push(this.translate(this._curlyBrace, L)), this._curlyBrace = null), b.push(this.translate(p, L));
          } };
          var I = [3, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14];
          function N() {
            return I[I.length - 1];
          }
          function m() {
            return [...I];
          }
          function O() {
            let p = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 5, L = p === "latest" ? N() : p;
            if (typeof L != "number")
              throw new Error(`ecmaVersion must be a number or "latest". Received value of type ${typeof p} instead.`);
            if (L >= 2015 && (L -= 2009), !I.includes(L))
              throw new Error("Invalid ecmaVersion.");
            return L;
          }
          function S() {
            let p = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "script";
            if (p === "script" || p === "module")
              return p;
            if (p === "commonjs")
              return "script";
            throw new Error("Invalid sourceType.");
          }
          function _(p) {
            let L = O(p.ecmaVersion), w = S(p.sourceType), f = p.range === true, b = p.loc === true;
            if (L !== 3 && p.allowReserved)
              throw new Error("`allowReserved` is only supported when ecmaVersion is 3");
            if (typeof p.allowReserved < "u" && typeof p.allowReserved != "boolean")
              throw new Error("`allowReserved`, when present, must be `true` or `false`");
            let X = L === 3 ? p.allowReserved || "never" : false, H = p.ecmaFeatures || {}, te = p.sourceType === "commonjs" || Boolean(H.globalReturn);
            if (w === "module" && L < 6)
              throw new Error("sourceType 'module' is not supported when ecmaVersion < 2015. Consider adding `{ ecmaVersion: 2015 }` to the parser options.");
            return Object.assign({}, p, { ecmaVersion: L, sourceType: w, ranges: f, locations: b, allowReserved: X, allowReturnOutsideFunction: te });
          }
          var F = Symbol("espree's internal state"), A = Symbol("espree's esprimaFinishNode");
          function K(p, L, w, f, b, X, H) {
            let te;
            p ? te = "Block" : H.slice(w, w + 2) === "#!" ? te = "Hashbang" : te = "Line";
            let ae = { type: te, value: L };
            return typeof w == "number" && (ae.start = w, ae.end = f, ae.range = [w, f]), typeof b == "object" && (ae.loc = { start: b, end: X }), ae;
          }
          var R = () => (p) => {
            let L = Object.assign({}, p.acorn.tokTypes);
            return p.acornJsx && Object.assign(L, p.acornJsx.tokTypes), class extends p {
              constructor(f, b) {
                (typeof f != "object" || f === null) && (f = {}), typeof b != "string" && !(b instanceof String) && (b = String(b));
                let X = f.sourceType, H = _(f), te = H.ecmaFeatures || {}, ae = H.tokens === true ? new q(L, b) : null, fe = { originalSourceType: X || H.sourceType, tokens: ae ? [] : null, comments: H.comment === true ? [] : null, impliedStrict: te.impliedStrict === true && H.ecmaVersion >= 5, ecmaVersion: H.ecmaVersion, jsxAttrValueToken: false, lastToken: null, templateElements: [] };
                super({ ecmaVersion: H.ecmaVersion, sourceType: H.sourceType, ranges: H.ranges, locations: H.locations, allowReserved: H.allowReserved, allowReturnOutsideFunction: H.allowReturnOutsideFunction, onToken: (Ae) => {
                  ae && ae.onToken(Ae, fe), Ae.type !== L.eof && (fe.lastToken = Ae);
                }, onComment: (Ae, dt, mt, _e, Ce, Oe) => {
                  if (fe.comments) {
                    let We = K(Ae, dt, mt, _e, Ce, Oe, b);
                    fe.comments.push(We);
                  }
                } }, b), this[F] = fe;
              }
              tokenize() {
                do
                  this.next();
                while (this.type !== L.eof);
                this.next();
                let f = this[F], b = f.tokens;
                return f.comments && (b.comments = f.comments), b;
              }
              finishNode() {
                let f = super.finishNode(...arguments);
                return this[A](f);
              }
              finishNodeAt() {
                let f = super.finishNodeAt(...arguments);
                return this[A](f);
              }
              parse() {
                let f = this[F], b = super.parse();
                if (b.sourceType = f.originalSourceType, f.comments && (b.comments = f.comments), f.tokens && (b.tokens = f.tokens), b.body.length) {
                  let [X] = b.body;
                  b.range && (b.range[0] = X.range[0]), b.loc && (b.loc.start = X.loc.start), b.start = X.start;
                }
                return f.lastToken && (b.range && (b.range[1] = f.lastToken.range[1]), b.loc && (b.loc.end = f.lastToken.loc.end), b.end = f.lastToken.end), this[F].templateElements.forEach((X) => {
                  let te = X.tail ? 1 : 2;
                  X.start += -1, X.end += te, X.range && (X.range[0] += -1, X.range[1] += te), X.loc && (X.loc.start.column += -1, X.loc.end.column += te);
                }), b;
              }
              parseTopLevel(f) {
                return this[F].impliedStrict && (this.strict = true), super.parseTopLevel(f);
              }
              raise(f, b) {
                let X = p.acorn.getLineInfo(this.input, f), H = new SyntaxError(b);
                throw H.index = f, H.lineNumber = X.line, H.column = X.column + 1, H;
              }
              raiseRecoverable(f, b) {
                this.raise(f, b);
              }
              unexpected(f) {
                let b = "Unexpected token";
                if (f != null) {
                  if (this.pos = f, this.options.locations)
                    for (; this.pos < this.lineStart; )
                      this.lineStart = this.input.lastIndexOf(`
`, this.lineStart - 2) + 1, --this.curLine;
                  this.nextToken();
                }
                this.end > this.start && (b += ` ${this.input.slice(this.start, this.end)}`), this.raise(this.start, b);
              }
              jsx_readString(f) {
                let b = super.jsx_readString(f);
                return this.type === L.string && (this[F].jsxAttrValueToken = true), b;
              }
              [A](f) {
                return f.type === "TemplateElement" && this[F].templateElements.push(f), f.type.includes("Function") && !f.generator && (f.generator = false), f;
              }
            };
          }, i = "9.4.1", k = { _regular: null, _jsx: null, get regular() {
            return this._regular === null && (this._regular = x.Parser.extend(R())), this._regular;
          }, get jsx() {
            return this._jsx === null && (this._jsx = x.Parser.extend(B.default(), R())), this._jsx;
          }, get(p) {
            return Boolean(p && p.ecmaFeatures && p.ecmaFeatures.jsx) ? this.jsx : this.regular;
          } };
          function T(p, L) {
            let w = k.get(L);
            return (!L || L.tokens !== true) && (L = Object.assign({}, L, { tokens: true })), new w(L, p).tokenize();
          }
          function M(p, L) {
            let w = k.get(L);
            return new w(L, p).parse();
          }
          var Z = i, ne = function() {
            return P.KEYS;
          }(), ee = void 0, ie = N(), Ne = m();
          a.Syntax = ee, a.VisitorKeys = ne, a.latestEcmaVersion = ie, a.parse = M, a.supportedEcmaVersions = Ne, a.tokenize = T, a.version = Z;
        } }), $h = Q({ "src/language-js/parse/espree.js"(a, u) {
          "use strict";
          J();
          var o = dr(), l = Ba(), d = Ga(), E = Jh(), x = Xa(), B = { ecmaVersion: "latest", range: true, loc: true, comment: true, tokens: true, sourceType: "module", ecmaFeatures: { jsx: true, globalReturn: true, impliedStrict: false } };
          function P(D) {
            let { message: q, lineNumber: I, column: N } = D;
            return typeof I != "number" ? D : o(q, { start: { line: I, column: N } });
          }
          function g(D, q) {
            let I = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, { parse: N } = Qh(), m = E(D), { result: O, error: S } = l(() => N(m, Object.assign(Object.assign({}, B), {}, { sourceType: "module" })), () => N(m, Object.assign(Object.assign({}, B), {}, { sourceType: "script" })));
            if (!O)
              throw P(S);
            return I.originalText = D, x(O, I);
          }
          u.exports = d(g);
        } });
        J();
        var Yh = Xh(), Zh = $h();
        Qa.exports = { parsers: { acorn: Yh, espree: Zh } };
      });
      return el();
    });
  }
});

// node_modules/prettier/parser-meriyah.js
var require_parser_meriyah = __commonJS({
  "node_modules/prettier/parser-meriyah.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.meriyah = e();
      }
    })(function() {
      "use strict";
      var B = (a, g) => () => (g || a((g = { exports: {} }).exports, g), g.exports);
      var k2 = B((z3, Fu) => {
        var A1 = function(a) {
          return a && a.Math == Math && a;
        };
        Fu.exports = A1(typeof globalThis == "object" && globalThis) || A1(typeof window == "object" && window) || A1(typeof self == "object" && self) || A1(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var w2 = B((W3, Lu) => {
        Lu.exports = function(a) {
          try {
            return !!a();
          } catch {
            return true;
          }
        };
      });
      var S2 = B((K3, Ou) => {
        var to = w2();
        Ou.exports = !to(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var ue = B((Y3, Tu) => {
        var oo = w2();
        Tu.exports = !oo(function() {
          var a = function() {
          }.bind();
          return typeof a != "function" || a.hasOwnProperty("prototype");
        });
      });
      var E1 = B((Z3, Iu) => {
        var lo = ue(), P1 = Function.prototype.call;
        Iu.exports = lo ? P1.bind(P1) : function() {
          return P1.apply(P1, arguments);
        };
      });
      var ju = B((Vu) => {
        "use strict";
        var Ru = {}.propertyIsEnumerable, Nu = Object.getOwnPropertyDescriptor, fo = Nu && !Ru.call({ 1: 2 }, 1);
        Vu.f = fo ? function(g) {
          var m = Nu(this, g);
          return !!m && m.enumerable;
        } : Ru;
      });
      var ie = B((G3, _u) => {
        _u.exports = function(a, g) {
          return { enumerable: !(a & 1), configurable: !(a & 2), writable: !(a & 4), value: g };
        };
      });
      var F2 = B((x3, Ju) => {
        var Mu = ue(), Uu = Function.prototype, ne = Uu.call, co = Mu && Uu.bind.bind(ne, ne);
        Ju.exports = Mu ? co : function(a) {
          return function() {
            return ne.apply(a, arguments);
          };
        };
      });
      var Xu = B((p3, Hu) => {
        var $u = F2(), so = $u({}.toString), ao = $u("".slice);
        Hu.exports = function(a) {
          return ao(so(a), 8, -1);
        };
      });
      var Wu = B((ef, zu) => {
        var go = F2(), ho = w2(), ro = Xu(), te = Object, mo = go("".split);
        zu.exports = ho(function() {
          return !te("z").propertyIsEnumerable(0);
        }) ? function(a) {
          return ro(a) == "String" ? mo(a, "") : te(a);
        } : te;
      });
      var oe = B((uf, Ku) => {
        Ku.exports = function(a) {
          return a == null;
        };
      });
      var le = B((nf, Yu) => {
        var bo = oe(), ko = TypeError;
        Yu.exports = function(a) {
          if (bo(a))
            throw ko("Can't call method on " + a);
          return a;
        };
      });
      var D1 = B((tf, Zu) => {
        var vo = Wu(), yo = le();
        Zu.exports = function(a) {
          return vo(yo(a));
        };
      });
      var ce = B((of, Qu) => {
        var fe = typeof document == "object" && document.all, Ao = typeof fe > "u" && fe !== void 0;
        Qu.exports = { all: fe, IS_HTMLDDA: Ao };
      });
      var P2 = B((lf, xu) => {
        var Gu = ce(), Po = Gu.all;
        xu.exports = Gu.IS_HTMLDDA ? function(a) {
          return typeof a == "function" || a === Po;
        } : function(a) {
          return typeof a == "function";
        };
      });
      var Z2 = B((ff, ui) => {
        var pu = P2(), ei = ce(), Eo = ei.all;
        ui.exports = ei.IS_HTMLDDA ? function(a) {
          return typeof a == "object" ? a !== null : pu(a) || a === Eo;
        } : function(a) {
          return typeof a == "object" ? a !== null : pu(a);
        };
      });
      var C1 = B((cf, ii) => {
        var se = k2(), Do = P2(), Co = function(a) {
          return Do(a) ? a : void 0;
        };
        ii.exports = function(a, g) {
          return arguments.length < 2 ? Co(se[a]) : se[a] && se[a][g];
        };
      });
      var ti = B((sf, ni) => {
        var wo = F2();
        ni.exports = wo({}.isPrototypeOf);
      });
      var li = B((af, oi) => {
        var qo = C1();
        oi.exports = qo("navigator", "userAgent") || "";
      });
      var hi = B((df, gi) => {
        var di = k2(), ae = li(), fi = di.process, ci = di.Deno, si = fi && fi.versions || ci && ci.version, ai = si && si.v8, E2, w1;
        ai && (E2 = ai.split("."), w1 = E2[0] > 0 && E2[0] < 4 ? 1 : +(E2[0] + E2[1]));
        !w1 && ae && (E2 = ae.match(/Edge\/(\d+)/), (!E2 || E2[1] >= 74) && (E2 = ae.match(/Chrome\/(\d+)/), E2 && (w1 = +E2[1])));
        gi.exports = w1;
      });
      var de = B((gf, mi) => {
        var ri = hi(), Bo = w2();
        mi.exports = !!Object.getOwnPropertySymbols && !Bo(function() {
          var a = Symbol();
          return !String(a) || !(Object(a) instanceof Symbol) || !Symbol.sham && ri && ri < 41;
        });
      });
      var ge = B((hf, bi) => {
        var So = de();
        bi.exports = So && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var he = B((rf, ki) => {
        var Fo = C1(), Lo = P2(), Oo = ti(), To = ge(), Io = Object;
        ki.exports = To ? function(a) {
          return typeof a == "symbol";
        } : function(a) {
          var g = Fo("Symbol");
          return Lo(g) && Oo(g.prototype, Io(a));
        };
      });
      var yi = B((mf, vi) => {
        var Ro = String;
        vi.exports = function(a) {
          try {
            return Ro(a);
          } catch {
            return "Object";
          }
        };
      });
      var Pi = B((bf, Ai) => {
        var No = P2(), Vo = yi(), jo = TypeError;
        Ai.exports = function(a) {
          if (No(a))
            return a;
          throw jo(Vo(a) + " is not a function");
        };
      });
      var Di = B((kf, Ei) => {
        var _o = Pi(), Mo = oe();
        Ei.exports = function(a, g) {
          var m = a[g];
          return Mo(m) ? void 0 : _o(m);
        };
      });
      var wi = B((vf, Ci) => {
        var re = E1(), me = P2(), be = Z2(), Uo = TypeError;
        Ci.exports = function(a, g) {
          var m, f;
          if (g === "string" && me(m = a.toString) && !be(f = re(m, a)) || me(m = a.valueOf) && !be(f = re(m, a)) || g !== "string" && me(m = a.toString) && !be(f = re(m, a)))
            return f;
          throw Uo("Can't convert object to primitive value");
        };
      });
      var Bi = B((yf, qi) => {
        qi.exports = false;
      });
      var q1 = B((Af, Fi) => {
        var Si = k2(), Jo = Object.defineProperty;
        Fi.exports = function(a, g) {
          try {
            Jo(Si, a, { value: g, configurable: true, writable: true });
          } catch {
            Si[a] = g;
          }
          return g;
        };
      });
      var B1 = B((Pf, Oi) => {
        var $o = k2(), Ho = q1(), Li = "__core-js_shared__", Xo = $o[Li] || Ho(Li, {});
        Oi.exports = Xo;
      });
      var ke = B((Ef, Ii) => {
        var zo = Bi(), Ti = B1();
        (Ii.exports = function(a, g) {
          return Ti[a] || (Ti[a] = g !== void 0 ? g : {});
        })("versions", []).push({ version: "3.26.1", mode: zo ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var Ni = B((Df, Ri) => {
        var Wo = le(), Ko = Object;
        Ri.exports = function(a) {
          return Ko(Wo(a));
        };
      });
      var R2 = B((Cf, Vi) => {
        var Yo = F2(), Zo = Ni(), Qo = Yo({}.hasOwnProperty);
        Vi.exports = Object.hasOwn || function(g, m) {
          return Qo(Zo(g), m);
        };
      });
      var ve = B((wf, ji) => {
        var Go = F2(), xo = 0, po = Math.random(), el = Go(1 .toString);
        ji.exports = function(a) {
          return "Symbol(" + (a === void 0 ? "" : a) + ")_" + el(++xo + po, 36);
        };
      });
      var Hi = B((qf, $i) => {
        var ul = k2(), il = ke(), _i = R2(), nl = ve(), Mi = de(), Ji = ge(), Q2 = il("wks"), $2 = ul.Symbol, Ui = $2 && $2.for, tl = Ji ? $2 : $2 && $2.withoutSetter || nl;
        $i.exports = function(a) {
          if (!_i(Q2, a) || !(Mi || typeof Q2[a] == "string")) {
            var g = "Symbol." + a;
            Mi && _i($2, a) ? Q2[a] = $2[a] : Ji && Ui ? Q2[a] = Ui(g) : Q2[a] = tl(g);
          }
          return Q2[a];
        };
      });
      var Ki = B((Bf, Wi) => {
        var ol = E1(), Xi = Z2(), zi = he(), ll = Di(), fl = wi(), cl = Hi(), sl = TypeError, al = cl("toPrimitive");
        Wi.exports = function(a, g) {
          if (!Xi(a) || zi(a))
            return a;
          var m = ll(a, al), f;
          if (m) {
            if (g === void 0 && (g = "default"), f = ol(m, a, g), !Xi(f) || zi(f))
              return f;
            throw sl("Can't convert object to primitive value");
          }
          return g === void 0 && (g = "number"), fl(a, g);
        };
      });
      var ye = B((Sf, Yi) => {
        var dl = Ki(), gl = he();
        Yi.exports = function(a) {
          var g = dl(a, "string");
          return gl(g) ? g : g + "";
        };
      });
      var Gi = B((Ff, Qi) => {
        var hl = k2(), Zi = Z2(), Ae = hl.document, rl = Zi(Ae) && Zi(Ae.createElement);
        Qi.exports = function(a) {
          return rl ? Ae.createElement(a) : {};
        };
      });
      var Pe = B((Lf, xi) => {
        var ml = S2(), bl = w2(), kl = Gi();
        xi.exports = !ml && !bl(function() {
          return Object.defineProperty(kl("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Ee = B((en) => {
        var vl = S2(), yl = E1(), Al = ju(), Pl = ie(), El = D1(), Dl = ye(), Cl = R2(), wl = Pe(), pi = Object.getOwnPropertyDescriptor;
        en.f = vl ? pi : function(g, m) {
          if (g = El(g), m = Dl(m), wl)
            try {
              return pi(g, m);
            } catch {
            }
          if (Cl(g, m))
            return Pl(!yl(Al.f, g, m), g[m]);
        };
      });
      var nn = B((Tf, un) => {
        var ql = S2(), Bl = w2();
        un.exports = ql && Bl(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var S1 = B((If, tn) => {
        var Sl = Z2(), Fl = String, Ll = TypeError;
        tn.exports = function(a) {
          if (Sl(a))
            return a;
          throw Ll(Fl(a) + " is not an object");
        };
      });
      var u1 = B((ln) => {
        var Ol = S2(), Tl = Pe(), Il = nn(), F1 = S1(), on = ye(), Rl = TypeError, De = Object.defineProperty, Nl = Object.getOwnPropertyDescriptor, Ce = "enumerable", we = "configurable", qe = "writable";
        ln.f = Ol ? Il ? function(g, m, f) {
          if (F1(g), m = on(m), F1(f), typeof g == "function" && m === "prototype" && "value" in f && qe in f && !f[qe]) {
            var A = Nl(g, m);
            A && A[qe] && (g[m] = f.value, f = { configurable: we in f ? f[we] : A[we], enumerable: Ce in f ? f[Ce] : A[Ce], writable: false });
          }
          return De(g, m, f);
        } : De : function(g, m, f) {
          if (F1(g), m = on(m), F1(f), Tl)
            try {
              return De(g, m, f);
            } catch {
            }
          if ("get" in f || "set" in f)
            throw Rl("Accessors not supported");
          return "value" in f && (g[m] = f.value), g;
        };
      });
      var Be = B((Nf, fn) => {
        var Vl = S2(), jl = u1(), _l = ie();
        fn.exports = Vl ? function(a, g, m) {
          return jl.f(a, g, _l(1, m));
        } : function(a, g, m) {
          return a[g] = m, a;
        };
      });
      var an = B((Vf, sn) => {
        var Se = S2(), Ml = R2(), cn = Function.prototype, Ul = Se && Object.getOwnPropertyDescriptor, Fe = Ml(cn, "name"), Jl = Fe && function() {
        }.name === "something", $l = Fe && (!Se || Se && Ul(cn, "name").configurable);
        sn.exports = { EXISTS: Fe, PROPER: Jl, CONFIGURABLE: $l };
      });
      var gn = B((jf, dn) => {
        var Hl = F2(), Xl = P2(), Le = B1(), zl = Hl(Function.toString);
        Xl(Le.inspectSource) || (Le.inspectSource = function(a) {
          return zl(a);
        });
        dn.exports = Le.inspectSource;
      });
      var mn = B((_f, rn) => {
        var Wl = k2(), Kl = P2(), hn = Wl.WeakMap;
        rn.exports = Kl(hn) && /native code/.test(String(hn));
      });
      var vn = B((Mf, kn) => {
        var Yl = ke(), Zl = ve(), bn = Yl("keys");
        kn.exports = function(a) {
          return bn[a] || (bn[a] = Zl(a));
        };
      });
      var Oe = B((Uf, yn) => {
        yn.exports = {};
      });
      var Dn = B((Jf, En) => {
        var Ql = mn(), Pn = k2(), Gl = Z2(), xl = Be(), Te = R2(), Ie = B1(), pl = vn(), e4 = Oe(), An = "Object already initialized", Re = Pn.TypeError, u4 = Pn.WeakMap, L1, i1, O1, i4 = function(a) {
          return O1(a) ? i1(a) : L1(a, {});
        }, n4 = function(a) {
          return function(g) {
            var m;
            if (!Gl(g) || (m = i1(g)).type !== a)
              throw Re("Incompatible receiver, " + a + " required");
            return m;
          };
        };
        Ql || Ie.state ? (D2 = Ie.state || (Ie.state = new u4()), D2.get = D2.get, D2.has = D2.has, D2.set = D2.set, L1 = function(a, g) {
          if (D2.has(a))
            throw Re(An);
          return g.facade = a, D2.set(a, g), g;
        }, i1 = function(a) {
          return D2.get(a) || {};
        }, O1 = function(a) {
          return D2.has(a);
        }) : (H2 = pl("state"), e4[H2] = true, L1 = function(a, g) {
          if (Te(a, H2))
            throw Re(An);
          return g.facade = a, xl(a, H2, g), g;
        }, i1 = function(a) {
          return Te(a, H2) ? a[H2] : {};
        }, O1 = function(a) {
          return Te(a, H2);
        });
        var D2, H2;
        En.exports = { set: L1, get: i1, has: O1, enforce: i4, getterFor: n4 };
      });
      var Ve = B(($f, wn) => {
        var t4 = w2(), o4 = P2(), T1 = R2(), Ne = S2(), l4 = an().CONFIGURABLE, f4 = gn(), Cn = Dn(), c4 = Cn.enforce, s4 = Cn.get, I1 = Object.defineProperty, a4 = Ne && !t4(function() {
          return I1(function() {
          }, "length", { value: 8 }).length !== 8;
        }), d4 = String(String).split("String"), g4 = wn.exports = function(a, g, m) {
          String(g).slice(0, 7) === "Symbol(" && (g = "[" + String(g).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), m && m.getter && (g = "get " + g), m && m.setter && (g = "set " + g), (!T1(a, "name") || l4 && a.name !== g) && (Ne ? I1(a, "name", { value: g, configurable: true }) : a.name = g), a4 && m && T1(m, "arity") && a.length !== m.arity && I1(a, "length", { value: m.arity });
          try {
            m && T1(m, "constructor") && m.constructor ? Ne && I1(a, "prototype", { writable: false }) : a.prototype && (a.prototype = void 0);
          } catch {
          }
          var f = c4(a);
          return T1(f, "source") || (f.source = d4.join(typeof g == "string" ? g : "")), a;
        };
        Function.prototype.toString = g4(function() {
          return o4(this) && s4(this).source || f4(this);
        }, "toString");
      });
      var Bn = B((Hf, qn) => {
        var h4 = P2(), r4 = u1(), m4 = Ve(), b4 = q1();
        qn.exports = function(a, g, m, f) {
          f || (f = {});
          var A = f.enumerable, S = f.name !== void 0 ? f.name : g;
          if (h4(m) && m4(m, S, f), f.global)
            A ? a[g] = m : b4(g, m);
          else {
            try {
              f.unsafe ? a[g] && (A = true) : delete a[g];
            } catch {
            }
            A ? a[g] = m : r4.f(a, g, { value: m, enumerable: false, configurable: !f.nonConfigurable, writable: !f.nonWritable });
          }
          return a;
        };
      });
      var Fn = B((Xf, Sn) => {
        var k4 = Math.ceil, v4 = Math.floor;
        Sn.exports = Math.trunc || function(g) {
          var m = +g;
          return (m > 0 ? v4 : k4)(m);
        };
      });
      var je = B((zf, Ln) => {
        var y4 = Fn();
        Ln.exports = function(a) {
          var g = +a;
          return g !== g || g === 0 ? 0 : y4(g);
        };
      });
      var Tn = B((Wf, On) => {
        var A4 = je(), P4 = Math.max, E4 = Math.min;
        On.exports = function(a, g) {
          var m = A4(a);
          return m < 0 ? P4(m + g, 0) : E4(m, g);
        };
      });
      var Rn = B((Kf, In) => {
        var D4 = je(), C4 = Math.min;
        In.exports = function(a) {
          return a > 0 ? C4(D4(a), 9007199254740991) : 0;
        };
      });
      var Vn = B((Yf, Nn) => {
        var w4 = Rn();
        Nn.exports = function(a) {
          return w4(a.length);
        };
      });
      var Mn = B((Zf, _n) => {
        var q4 = D1(), B4 = Tn(), S4 = Vn(), jn = function(a) {
          return function(g, m, f) {
            var A = q4(g), S = S4(A), q = B4(f, S), N;
            if (a && m != m) {
              for (; S > q; )
                if (N = A[q++], N != N)
                  return true;
            } else
              for (; S > q; q++)
                if ((a || q in A) && A[q] === m)
                  return a || q || 0;
            return !a && -1;
          };
        };
        _n.exports = { includes: jn(true), indexOf: jn(false) };
      });
      var $n = B((Qf, Jn) => {
        var F4 = F2(), _e = R2(), L4 = D1(), O4 = Mn().indexOf, T4 = Oe(), Un = F4([].push);
        Jn.exports = function(a, g) {
          var m = L4(a), f = 0, A = [], S;
          for (S in m)
            !_e(T4, S) && _e(m, S) && Un(A, S);
          for (; g.length > f; )
            _e(m, S = g[f++]) && (~O4(A, S) || Un(A, S));
          return A;
        };
      });
      var Xn = B((Gf, Hn) => {
        Hn.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var Wn = B((zn) => {
        var I4 = $n(), R4 = Xn(), N4 = R4.concat("length", "prototype");
        zn.f = Object.getOwnPropertyNames || function(g) {
          return I4(g, N4);
        };
      });
      var Yn = B((Kn) => {
        Kn.f = Object.getOwnPropertySymbols;
      });
      var Qn = B((e6, Zn) => {
        var V4 = C1(), j4 = F2(), _4 = Wn(), M4 = Yn(), U4 = S1(), J4 = j4([].concat);
        Zn.exports = V4("Reflect", "ownKeys") || function(g) {
          var m = _4.f(U4(g)), f = M4.f;
          return f ? J4(m, f(g)) : m;
        };
      });
      var pn = B((u6, xn) => {
        var Gn = R2(), $4 = Qn(), H4 = Ee(), X4 = u1();
        xn.exports = function(a, g, m) {
          for (var f = $4(g), A = X4.f, S = H4.f, q = 0; q < f.length; q++) {
            var N = f[q];
            !Gn(a, N) && !(m && Gn(m, N)) && A(a, N, S(g, N));
          }
        };
      });
      var ut = B((i6, et) => {
        var z4 = w2(), W4 = P2(), K4 = /#|\.prototype\./, n1 = function(a, g) {
          var m = Z4[Y4(a)];
          return m == G4 ? true : m == Q4 ? false : W4(g) ? z4(g) : !!g;
        }, Y4 = n1.normalize = function(a) {
          return String(a).replace(K4, ".").toLowerCase();
        }, Z4 = n1.data = {}, Q4 = n1.NATIVE = "N", G4 = n1.POLYFILL = "P";
        et.exports = n1;
      });
      var nt = B((n6, it2) => {
        var Me = k2(), x4 = Ee().f, p4 = Be(), e3 = Bn(), u3 = q1(), i3 = pn(), n3 = ut();
        it2.exports = function(a, g) {
          var m = a.target, f = a.global, A = a.stat, S, q, N, k, W, $2;
          if (f ? q = Me : A ? q = Me[m] || u3(m, {}) : q = (Me[m] || {}).prototype, q)
            for (N in g) {
              if (W = g[N], a.dontCallGetSet ? ($2 = x4(q, N), k = $2 && $2.value) : k = q[N], S = n3(f ? N : m + (A ? "." : "#") + N, a.forced), !S && k !== void 0) {
                if (typeof W == typeof k)
                  continue;
                i3(W, k);
              }
              (a.sham || k && k.sham) && p4(W, "sham", true), e3(q, N, W, a);
            }
        };
      });
      var tt = B(() => {
        var t3 = nt(), Ue = k2();
        t3({ global: true, forced: Ue.globalThis !== Ue }, { globalThis: Ue });
      });
      var ot = B(() => {
        tt();
      });
      var ct = B((c6, ft) => {
        var lt = Ve(), o3 = u1();
        ft.exports = function(a, g, m) {
          return m.get && lt(m.get, g, { getter: true }), m.set && lt(m.set, g, { setter: true }), o3.f(a, g, m);
        };
      });
      var at = B((s6, st) => {
        "use strict";
        var l3 = S1();
        st.exports = function() {
          var a = l3(this), g = "";
          return a.hasIndices && (g += "d"), a.global && (g += "g"), a.ignoreCase && (g += "i"), a.multiline && (g += "m"), a.dotAll && (g += "s"), a.unicode && (g += "u"), a.unicodeSets && (g += "v"), a.sticky && (g += "y"), g;
        };
      });
      var ht = B(() => {
        var f3 = k2(), c3 = S2(), s3 = ct(), a3 = at(), d3 = w2(), dt = f3.RegExp, gt = dt.prototype, g3 = c3 && d3(function() {
          var a = true;
          try {
            dt(".", "d");
          } catch {
            a = false;
          }
          var g = {}, m = "", f = a ? "dgimsy" : "gimsy", A = function(k, W) {
            Object.defineProperty(g, k, { get: function() {
              return m += W, true;
            } });
          }, S = { dotAll: "s", global: "g", ignoreCase: "i", multiline: "m", sticky: "y" };
          a && (S.hasIndices = "d");
          for (var q in S)
            A(q, S[q]);
          var N = Object.getOwnPropertyDescriptor(gt, "flags").get.call(g);
          return N !== f || m !== f;
        });
        g3 && s3(gt, "flags", { configurable: true, get: a3 });
      });
      var H3 = B((g6, Rt) => {
        ot();
        ht();
        var Xe = Object.defineProperty, h3 = Object.getOwnPropertyDescriptor, ze = Object.getOwnPropertyNames, r3 = Object.prototype.hasOwnProperty, mt = (a, g) => function() {
          return a && (g = (0, a[ze(a)[0]])(a = 0)), g;
        }, o2 = (a, g) => function() {
          return g || (0, a[ze(a)[0]])((g = { exports: {} }).exports, g), g.exports;
        }, m3 = (a, g) => {
          for (var m in g)
            Xe(a, m, { get: g[m], enumerable: true });
        }, b3 = (a, g, m, f) => {
          if (g && typeof g == "object" || typeof g == "function")
            for (let A of ze(g))
              !r3.call(a, A) && A !== m && Xe(a, A, { get: () => g[A], enumerable: !(f = h3(g, A)) || f.enumerable });
          return a;
        }, k3 = (a) => b3(Xe({}, "__esModule", { value: true }), a), n2 = mt({ "<define:process>"() {
        } }), bt = o2({ "src/common/parser-create-error.js"(a, g) {
          "use strict";
          n2();
          function m(f, A) {
            let S = new SyntaxError(f + " (" + A.start.line + ":" + A.start.column + ")");
            return S.loc = A, S;
          }
          g.exports = m;
        } }), v3 = o2({ "src/utils/try-combinations.js"(a, g) {
          "use strict";
          n2();
          function m() {
            let f;
            for (var A = arguments.length, S = new Array(A), q = 0; q < A; q++)
              S[q] = arguments[q];
            for (let [N, k] of S.entries())
              try {
                return { result: k() };
              } catch (W) {
                N === 0 && (f = W);
              }
            return { error: f };
          }
          g.exports = m;
        } }), kt = {};
        m3(kt, { EOL: () => He, arch: () => y3, cpus: () => Ct, default: () => Ft, endianness: () => vt, freemem: () => Et, getNetworkInterfaces: () => St, hostname: () => yt, loadavg: () => At, networkInterfaces: () => Bt, platform: () => A3, release: () => qt, tmpDir: () => Je, tmpdir: () => $e, totalmem: () => Dt, type: () => wt, uptime: () => Pt });
        function vt() {
          if (typeof R1 > "u") {
            var a = new ArrayBuffer(2), g = new Uint8Array(a), m = new Uint16Array(a);
            if (g[0] = 1, g[1] = 2, m[0] === 258)
              R1 = "BE";
            else if (m[0] === 513)
              R1 = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return R1;
        }
        function yt() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function At() {
          return [];
        }
        function Pt() {
          return 0;
        }
        function Et() {
          return Number.MAX_VALUE;
        }
        function Dt() {
          return Number.MAX_VALUE;
        }
        function Ct() {
          return [];
        }
        function wt() {
          return "Browser";
        }
        function qt() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function Bt() {
        }
        function St() {
        }
        function y3() {
          return "javascript";
        }
        function A3() {
          return "browser";
        }
        function Je() {
          return "/tmp";
        }
        var R1, $e, He, Ft, P3 = mt({ "node-modules-polyfills:os"() {
          n2(), $e = Je, He = `
`, Ft = { EOL: He, tmpdir: $e, tmpDir: Je, networkInterfaces: Bt, getNetworkInterfaces: St, release: qt, type: wt, cpus: Ct, totalmem: Dt, freemem: Et, uptime: Pt, loadavg: At, hostname: yt, endianness: vt };
        } }), E3 = o2({ "node-modules-polyfills-commonjs:os"(a, g) {
          n2();
          var m = (P3(), k3(kt));
          if (m && m.default) {
            g.exports = m.default;
            for (let f in m)
              g.exports[f] = m[f];
          } else
            m && (g.exports = m);
        } }), D3 = o2({ "node_modules/detect-newline/index.js"(a, g) {
          "use strict";
          n2();
          var m = (f) => {
            if (typeof f != "string")
              throw new TypeError("Expected a string");
            let A = f.match(/(?:\r?\n)/g) || [];
            if (A.length === 0)
              return;
            let S = A.filter((N) => N === `\r
`).length, q = A.length - S;
            return S > q ? `\r
` : `
`;
          };
          g.exports = m, g.exports.graceful = (f) => typeof f == "string" && m(f) || `
`;
        } }), C3 = o2({ "node_modules/jest-docblock/build/index.js"(a) {
          "use strict";
          n2(), Object.defineProperty(a, "__esModule", { value: true }), a.extract = e2, a.parse = Z, a.parseWithComments = R, a.print = j, a.strip = L;
          function g() {
            let O = E3();
            return g = function() {
              return O;
            }, O;
          }
          function m() {
            let O = f(D3());
            return m = function() {
              return O;
            }, O;
          }
          function f(O) {
            return O && O.__esModule ? O : { default: O };
          }
          var A = /\*\/$/, S = /^\/\*\*?/, q = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, N = /(^|\s+)\/\/([^\r\n]*)/g, k = /^(\r?\n)+/, W = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, $2 = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, z = /(\r?\n|^) *\* ?/g, Q = [];
          function e2(O) {
            let u2 = O.match(q);
            return u2 ? u2[0].trimLeft() : "";
          }
          function L(O) {
            let u2 = O.match(q);
            return u2 && u2[0] ? O.substring(u2[0].length) : O;
          }
          function Z(O) {
            return R(O).pragmas;
          }
          function R(O) {
            let u2 = (0, m().default)(O) || g().EOL;
            O = O.replace(S, "").replace(A, "").replace(z, "$1");
            let h2 = "";
            for (; h2 !== O; )
              h2 = O, O = O.replace(W, `${u2}$1 $2${u2}`);
            O = O.replace(k, "").trimRight();
            let f2 = /* @__PURE__ */ Object.create(null), N2 = O.replace($2, "").replace(k, "").trimRight(), c2;
            for (; c2 = $2.exec(O); ) {
              let V2 = c2[2].replace(N, "");
              typeof f2[c2[1]] == "string" || Array.isArray(f2[c2[1]]) ? f2[c2[1]] = Q.concat(f2[c2[1]], V2) : f2[c2[1]] = V2;
            }
            return { comments: N2, pragmas: f2 };
          }
          function j(O) {
            let { comments: u2 = "", pragmas: h2 = {} } = O, f2 = (0, m().default)(u2) || g().EOL, N2 = "/**", c2 = " *", V2 = " */", q2 = Object.keys(h2), N1 = q2.map((d2) => H(d2, h2[d2])).reduce((d2, t1) => d2.concat(t1), []).map((d2) => `${c2} ${d2}${f2}`).join("");
            if (!u2) {
              if (q2.length === 0)
                return "";
              if (q2.length === 1 && !Array.isArray(h2[q2[0]])) {
                let d2 = h2[q2[0]];
                return `${N2} ${H(q2[0], d2)[0]}${V2}`;
              }
            }
            let V1 = u2.split(f2).map((d2) => `${c2} ${d2}`).join(f2) + f2;
            return N2 + f2 + (u2 ? V1 : "") + (u2 && q2.length ? c2 + f2 : "") + N1 + V2;
          }
          function H(O, u2) {
            return Q.concat(u2).map((h2) => `@${O} ${h2}`.trim());
          }
        } }), w3 = o2({ "src/common/end-of-line.js"(a, g) {
          "use strict";
          n2();
          function m(q) {
            let N = q.indexOf("\r");
            return N >= 0 ? q.charAt(N + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function f(q) {
            switch (q) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function A(q, N) {
            let k;
            switch (N) {
              case `
`:
                k = /\n/g;
                break;
              case "\r":
                k = /\r/g;
                break;
              case `\r
`:
                k = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(N)}.`);
            }
            let W = q.match(k);
            return W ? W.length : 0;
          }
          function S(q) {
            return q.replace(/\r\n?/g, `
`);
          }
          g.exports = { guessEndOfLine: m, convertEndOfLineToChars: f, countEndOfLineChars: A, normalizeEndOfLine: S };
        } }), q3 = o2({ "src/language-js/utils/get-shebang.js"(a, g) {
          "use strict";
          n2();
          function m(f) {
            if (!f.startsWith("#!"))
              return "";
            let A = f.indexOf(`
`);
            return A === -1 ? f : f.slice(0, A);
          }
          g.exports = m;
        } }), B3 = o2({ "src/language-js/pragma.js"(a, g) {
          "use strict";
          n2();
          var { parseWithComments: m, strip: f, extract: A, print: S } = C3(), { normalizeEndOfLine: q } = w3(), N = q3();
          function k(z) {
            let Q = N(z);
            Q && (z = z.slice(Q.length + 1));
            let e2 = A(z), { pragmas: L, comments: Z } = m(e2);
            return { shebang: Q, text: z, pragmas: L, comments: Z };
          }
          function W(z) {
            let Q = Object.keys(k(z).pragmas);
            return Q.includes("prettier") || Q.includes("format");
          }
          function $2(z) {
            let { shebang: Q, text: e2, pragmas: L, comments: Z } = k(z), R = f(e2), j = S({ pragmas: Object.assign({ format: "" }, L), comments: Z.trimStart() });
            return (Q ? `${Q}
` : "") + q(j) + (R.startsWith(`
`) ? `
` : `

`) + R;
          }
          g.exports = { hasPragma: W, insertPragma: $2 };
        } }), Lt = o2({ "src/utils/is-non-empty-array.js"(a, g) {
          "use strict";
          n2();
          function m(f) {
            return Array.isArray(f) && f.length > 0;
          }
          g.exports = m;
        } }), Ot = o2({ "src/language-js/loc.js"(a, g) {
          "use strict";
          n2();
          var m = Lt();
          function f(k) {
            var W, $2;
            let z = k.range ? k.range[0] : k.start, Q = (W = ($2 = k.declaration) === null || $2 === void 0 ? void 0 : $2.decorators) !== null && W !== void 0 ? W : k.decorators;
            return m(Q) ? Math.min(f(Q[0]), z) : z;
          }
          function A(k) {
            return k.range ? k.range[1] : k.end;
          }
          function S(k, W) {
            let $2 = f(k);
            return Number.isInteger($2) && $2 === f(W);
          }
          function q(k, W) {
            let $2 = A(k);
            return Number.isInteger($2) && $2 === A(W);
          }
          function N(k, W) {
            return S(k, W) && q(k, W);
          }
          g.exports = { locStart: f, locEnd: A, hasSameLocStart: S, hasSameLoc: N };
        } }), S3 = o2({ "src/language-js/parse/utils/create-parser.js"(a, g) {
          "use strict";
          n2();
          var { hasPragma: m } = B3(), { locStart: f, locEnd: A } = Ot();
          function S(q) {
            return q = typeof q == "function" ? { parse: q } : q, Object.assign({ astFormat: "estree", hasPragma: m, locStart: f, locEnd: A }, q);
          }
          g.exports = S;
        } }), F3 = o2({ "src/language-js/utils/is-ts-keyword-type.js"(a, g) {
          "use strict";
          n2();
          function m(f) {
            let { type: A } = f;
            return A.startsWith("TS") && A.endsWith("Keyword");
          }
          g.exports = m;
        } }), L3 = o2({ "src/language-js/utils/is-block-comment.js"(a, g) {
          "use strict";
          n2();
          var m = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]), f = (A) => m.has(A == null ? void 0 : A.type);
          g.exports = f;
        } }), O3 = o2({ "src/language-js/utils/is-type-cast-comment.js"(a, g) {
          "use strict";
          n2();
          var m = L3();
          function f(A) {
            return m(A) && A.value[0] === "*" && /@type\b/.test(A.value);
          }
          g.exports = f;
        } }), T3 = o2({ "src/utils/get-last.js"(a, g) {
          "use strict";
          n2();
          var m = (f) => f[f.length - 1];
          g.exports = m;
        } }), Tt = o2({ "src/language-js/parse/postprocess/visit-node.js"(a, g) {
          "use strict";
          n2();
          function m(f, A) {
            if (Array.isArray(f)) {
              for (let S = 0; S < f.length; S++)
                f[S] = m(f[S], A);
              return f;
            }
            if (f && typeof f == "object" && typeof f.type == "string") {
              let S = Object.keys(f);
              for (let q = 0; q < S.length; q++)
                f[S[q]] = m(f[S[q]], A);
              return A(f) || f;
            }
            return f;
          }
          g.exports = m;
        } }), It = o2({ "src/language-js/parse/postprocess/throw-syntax-error.js"(a, g) {
          "use strict";
          n2();
          var m = bt();
          function f(A, S) {
            let { start: q, end: N } = A.loc;
            throw m(S, { start: { line: q.line, column: q.column + 1 }, end: { line: N.line, column: N.column + 1 } });
          }
          g.exports = f;
        } }), I3 = o2({ "src/language-js/parse/postprocess/typescript.js"(a, g) {
          "use strict";
          n2();
          var m = Lt(), f = Tt(), A = It(), S = { AbstractKeyword: 126, SourceFile: 308, PropertyDeclaration: 169 };
          function q($2) {
            for (; $2 && $2.kind !== S.SourceFile; )
              $2 = $2.parent;
            return $2;
          }
          function N($2) {
            let { illegalDecorators: z } = $2;
            if (!m(z))
              return;
            let [{ expression: Q }] = z, e2 = q(Q), [L, Z] = [Q.pos, Q.end].map((R) => {
              let { line: j, character: H } = e2.getLineAndCharacterOfPosition(R);
              return { line: j + 1, column: H };
            });
            A({ loc: { start: L, end: Z } }, "Decorators are not valid here.");
          }
          function k($2, z) {
            $2.kind !== S.PropertyDeclaration || $2.modifiers && !$2.modifiers.some((Q) => Q.kind === S.AbstractKeyword) || $2.initializer && z.value === null && A(z, "Abstract property cannot have an initializer");
          }
          function W($2, z) {
            let { esTreeNodeToTSNodeMap: Q, tsNodeToESTreeNodeMap: e2 } = z.tsParseResult;
            f($2, (L) => {
              let Z = Q.get(L);
              if (!Z)
                return;
              let R = e2.get(Z);
              R === L && (N(Z), k(Z, R));
            });
          }
          g.exports = { throwErrorForInvalidNodes: W };
        } }), R3 = o2({ "src/language-js/parse/postprocess/index.js"(a, g) {
          "use strict";
          n2();
          var { locStart: m, locEnd: f } = Ot(), A = F3(), S = O3(), q = T3(), N = Tt(), { throwErrorForInvalidNodes: k } = I3(), W = It();
          function $2(L, Z) {
            if (Z.parser === "typescript" && /@|abstract/.test(Z.originalText) && k(L, Z), Z.parser !== "typescript" && Z.parser !== "flow" && Z.parser !== "acorn" && Z.parser !== "espree" && Z.parser !== "meriyah") {
              let j = /* @__PURE__ */ new Set();
              L = N(L, (H) => {
                H.leadingComments && H.leadingComments.some(S) && j.add(m(H));
              }), L = N(L, (H) => {
                if (H.type === "ParenthesizedExpression") {
                  let { expression: O } = H;
                  if (O.type === "TypeCastExpression")
                    return O.range = H.range, O;
                  let u2 = m(H);
                  if (!j.has(u2))
                    return O.extra = Object.assign(Object.assign({}, O.extra), {}, { parenthesized: true }), O;
                }
              });
            }
            return L = N(L, (j) => {
              switch (j.type) {
                case "ChainExpression":
                  return z(j.expression);
                case "LogicalExpression": {
                  if (Q(j))
                    return e2(j);
                  break;
                }
                case "VariableDeclaration": {
                  let H = q(j.declarations);
                  H && H.init && R(j, H);
                  break;
                }
                case "TSParenthesizedType":
                  return A(j.typeAnnotation) || j.typeAnnotation.type === "TSThisType" || (j.typeAnnotation.range = [m(j), f(j)]), j.typeAnnotation;
                case "TSTypeParameter":
                  if (typeof j.name == "string") {
                    let H = m(j);
                    j.name = { type: "Identifier", name: j.name, range: [H, H + j.name.length] };
                  }
                  break;
                case "ObjectExpression":
                  if (Z.parser === "typescript") {
                    let H = j.properties.find((O) => O.type === "Property" && O.value.type === "TSEmptyBodyFunctionExpression");
                    H && W(H.value, "Unexpected token.");
                  }
                  break;
                case "SequenceExpression": {
                  let H = q(j.expressions);
                  j.range = [m(j), Math.min(f(H), f(j))];
                  break;
                }
                case "TopicReference":
                  Z.__isUsingHackPipeline = true;
                  break;
                case "ExportAllDeclaration": {
                  let { exported: H } = j;
                  if (Z.parser === "meriyah" && H && H.type === "Identifier") {
                    let O = Z.originalText.slice(m(H), f(H));
                    (O.startsWith('"') || O.startsWith("'")) && (j.exported = Object.assign(Object.assign({}, j.exported), {}, { type: "Literal", value: j.exported.name, raw: O }));
                  }
                  break;
                }
                case "PropertyDefinition":
                  if (Z.parser === "meriyah" && j.static && !j.computed && !j.key) {
                    let H = "static", O = m(j);
                    Object.assign(j, { static: false, key: { type: "Identifier", name: H, range: [O, O + H.length] } });
                  }
                  break;
              }
            }), L;
            function R(j, H) {
              Z.originalText[f(H)] !== ";" && (j.range = [m(j), f(H)]);
            }
          }
          function z(L) {
            switch (L.type) {
              case "CallExpression":
                L.type = "OptionalCallExpression", L.callee = z(L.callee);
                break;
              case "MemberExpression":
                L.type = "OptionalMemberExpression", L.object = z(L.object);
                break;
              case "TSNonNullExpression":
                L.expression = z(L.expression);
                break;
            }
            return L;
          }
          function Q(L) {
            return L.type === "LogicalExpression" && L.right.type === "LogicalExpression" && L.operator === L.right.operator;
          }
          function e2(L) {
            return Q(L) ? e2({ type: "LogicalExpression", operator: L.operator, left: e2({ type: "LogicalExpression", operator: L.operator, left: L.left, right: L.right.left, range: [m(L.left), f(L.right.left)] }), right: L.right.right, range: [m(L), f(L)] }) : L;
          }
          g.exports = $2;
        } }), N3 = o2({ "node_modules/meriyah/dist/meriyah.cjs"(a) {
          "use strict";
          n2(), Object.defineProperty(a, "__esModule", { value: true });
          var g = { [0]: "Unexpected token", [28]: "Unexpected token: '%0'", [1]: "Octal escape sequences are not allowed in strict mode", [2]: "Octal escape sequences are not allowed in template strings", [3]: "Unexpected token `#`", [4]: "Illegal Unicode escape sequence", [5]: "Invalid code point %0", [6]: "Invalid hexadecimal escape sequence", [8]: "Octal literals are not allowed in strict mode", [7]: "Decimal integer literals with a leading zero are forbidden in strict mode", [9]: "Expected number in radix %0", [145]: "Invalid left-hand side assignment to a destructible right-hand side", [10]: "Non-number found after exponent indicator", [11]: "Invalid BigIntLiteral", [12]: "No identifiers allowed directly after numeric literal", [13]: "Escapes \\8 or \\9 are not syntactically valid escapes", [14]: "Unterminated string literal", [15]: "Unterminated template literal", [16]: "Multiline comment was not closed properly", [17]: "The identifier contained dynamic unicode escape that was not closed", [18]: "Illegal character '%0'", [19]: "Missing hexadecimal digits", [20]: "Invalid implicit octal", [21]: "Invalid line break in string literal", [22]: "Only unicode escapes are legal in identifier names", [23]: "Expected '%0'", [24]: "Invalid left-hand side in assignment", [25]: "Invalid left-hand side in async arrow", [26]: 'Calls to super must be in the "constructor" method of a class expression or class declaration that has a superclass', [27]: "Member access on super must be in a method", [29]: "Await expression not allowed in formal parameter", [30]: "Yield expression not allowed in formal parameter", [92]: "Unexpected token: 'escaped keyword'", [31]: "Unary expressions as the left operand of an exponentiation expression must be disambiguated with parentheses", [119]: "Async functions can only be declared at the top level or inside a block", [32]: "Unterminated regular expression", [33]: "Unexpected regular expression flag", [34]: "Duplicate regular expression flag '%0'", [35]: "%0 functions must have exactly %1 argument%2", [36]: "Setter function argument must not be a rest parameter", [37]: "%0 declaration must have a name in this context", [38]: "Function name may not contain any reserved words or be eval or arguments in strict mode", [39]: "The rest operator is missing an argument", [40]: "A getter cannot be a generator", [41]: "A computed property name must be followed by a colon or paren", [130]: "Object literal keys that are strings or numbers must be a method or have a colon", [43]: "Found `* async x(){}` but this should be `async * x(){}`", [42]: "Getters and setters can not be generators", [44]: "'%0' can not be generator method", [45]: "No line break is allowed after '=>'", [46]: "The left-hand side of the arrow can only be destructed through assignment", [47]: "The binding declaration is not destructible", [48]: "Async arrow can not be followed by new expression", [49]: "Classes may not have a static property named 'prototype'", [50]: "Class constructor may not be a %0", [51]: "Duplicate constructor method in class", [52]: "Invalid increment/decrement operand", [53]: "Invalid use of `new` keyword on an increment/decrement expression", [54]: "`=>` is an invalid assignment target", [55]: "Rest element may not have a trailing comma", [56]: "Missing initializer in %0 declaration", [57]: "'for-%0' loop head declarations can not have an initializer", [58]: "Invalid left-hand side in for-%0 loop: Must have a single binding", [59]: "Invalid shorthand property initializer", [60]: "Property name __proto__ appears more than once in object literal", [61]: "Let is disallowed as a lexically bound name", [62]: "Invalid use of '%0' inside new expression", [63]: "Illegal 'use strict' directive in function with non-simple parameter list", [64]: 'Identifier "let" disallowed as left-hand side expression in strict mode', [65]: "Illegal continue statement", [66]: "Illegal break statement", [67]: "Cannot have `let[...]` as a var name in strict mode", [68]: "Invalid destructuring assignment target", [69]: "Rest parameter may not have a default initializer", [70]: "The rest argument must the be last parameter", [71]: "Invalid rest argument", [73]: "In strict mode code, functions can only be declared at top level or inside a block", [74]: "In non-strict mode code, functions can only be declared at top level, inside a block, or as the body of an if statement", [75]: "Without web compatibility enabled functions can not be declared at top level, inside a block, or as the body of an if statement", [76]: "Class declaration can't appear in single-statement context", [77]: "Invalid left-hand side in for-%0", [78]: "Invalid assignment in for-%0", [79]: "for await (... of ...) is only valid in async functions and async generators", [80]: "The first token after the template expression should be a continuation of the template", [82]: "`let` declaration not allowed here and `let` cannot be a regular var name in strict mode", [81]: "`let \n [` is a restricted production at the start of a statement", [83]: "Catch clause requires exactly one parameter, not more (and no trailing comma)", [84]: "Catch clause parameter does not support default values", [85]: "Missing catch or finally after try", [86]: "More than one default clause in switch statement", [87]: "Illegal newline after throw", [88]: "Strict mode code may not include a with statement", [89]: "Illegal return statement", [90]: "The left hand side of the for-header binding declaration is not destructible", [91]: "new.target only allowed within functions", [93]: "'#' not followed by identifier", [99]: "Invalid keyword", [98]: "Can not use 'let' as a class name", [97]: "'A lexical declaration can't define a 'let' binding", [96]: "Can not use `let` as variable name in strict mode", [94]: "'%0' may not be used as an identifier in this context", [95]: "Await is only valid in async functions", [100]: "The %0 keyword can only be used with the module goal", [101]: "Unicode codepoint must not be greater than 0x10FFFF", [102]: "%0 source must be string", [103]: "Only a identifier can be used to indicate alias", [104]: "Only '*' or '{...}' can be imported after default", [105]: "Trailing decorator may be followed by method", [106]: "Decorators can't be used with a constructor", [108]: "HTML comments are only allowed with web compatibility (Annex B)", [109]: "The identifier 'let' must not be in expression position in strict mode", [110]: "Cannot assign to `eval` and `arguments` in strict mode", [111]: "The left-hand side of a for-of loop may not start with 'let'", [112]: "Block body arrows can not be immediately invoked without a group", [113]: "Block body arrows can not be immediately accessed without a group", [114]: "Unexpected strict mode reserved word", [115]: "Unexpected eval or arguments in strict mode", [116]: "Decorators must not be followed by a semicolon", [117]: "Calling delete on expression not allowed in strict mode", [118]: "Pattern can not have a tail", [120]: "Can not have a `yield` expression on the left side of a ternary", [121]: "An arrow function can not have a postfix update operator", [122]: "Invalid object literal key character after generator star", [123]: "Private fields can not be deleted", [125]: "Classes may not have a field called constructor", [124]: "Classes may not have a private element named constructor", [126]: "A class field initializer may not contain arguments", [127]: "Generators can only be declared at the top level or inside a block", [128]: "Async methods are a restricted production and cannot have a newline following it", [129]: "Unexpected character after object literal property name", [131]: "Invalid key token", [132]: "Label '%0' has already been declared", [133]: "continue statement must be nested within an iteration statement", [134]: "Undefined label '%0'", [135]: "Trailing comma is disallowed inside import(...) arguments", [136]: "import() requires exactly one argument", [137]: "Cannot use new with import(...)", [138]: "... is not allowed in import()", [139]: "Expected '=>'", [140]: "Duplicate binding '%0'", [141]: "Cannot export a duplicate name '%0'", [144]: "Duplicate %0 for-binding", [142]: "Exported binding '%0' needs to refer to a top-level declared variable", [143]: "Unexpected private field", [147]: "Numeric separators are not allowed at the end of numeric literals", [146]: "Only one underscore is allowed as numeric separator", [148]: "JSX value should be either an expression or a quoted JSX text", [149]: "Expected corresponding JSX closing tag for %0", [150]: "Adjacent JSX elements must be wrapped in an enclosing tag", [151]: "JSX attributes must only be assigned a non-empty 'expression'", [152]: "'%0' has already been declared", [153]: "'%0' shadowed a catch clause binding", [154]: "Dot property must be an identifier", [155]: "Encountered invalid input after spread/rest argument", [156]: "Catch without try", [157]: "Finally without try", [158]: "Expected corresponding closing tag for JSX fragment", [159]: "Coalescing and logical operators used together in the same expression must be disambiguated with parentheses", [160]: "Invalid tagged template on optional chain", [161]: "Invalid optional chain from super property", [162]: "Invalid optional chain from new expression", [163]: 'Cannot use "import.meta" outside a module', [164]: "Leading decorators must be attached to a class declaration" }, m = class extends SyntaxError {
            constructor(e, u, i, n) {
              for (var t3 = arguments.length, o = new Array(t3 > 4 ? t3 - 4 : 0), l = 4; l < t3; l++)
                o[l - 4] = arguments[l];
              let c = "[" + u + ":" + i + "]: " + g[n].replace(/%(\d+)/g, (s, r) => o[r]);
              super(`${c}`), this.index = e, this.line = u, this.column = i, this.description = c, this.loc = { line: u, column: i };
            }
          };
          function f(e, u) {
            for (var i = arguments.length, n = new Array(i > 2 ? i - 2 : 0), t3 = 2; t3 < i; t3++)
              n[t3 - 2] = arguments[t3];
            throw new m(e.index, e.line, e.column, u, ...n);
          }
          function A(e) {
            throw new m(e.index, e.line, e.column, e.type, e.params);
          }
          function S(e, u, i, n) {
            for (var t3 = arguments.length, o = new Array(t3 > 4 ? t3 - 4 : 0), l = 4; l < t3; l++)
              o[l - 4] = arguments[l];
            throw new m(e, u, i, n, ...o);
          }
          function q(e, u, i, n) {
            throw new m(e, u, i, n);
          }
          var N = ((e, u) => {
            let i = new Uint32Array(104448), n = 0, t3 = 0;
            for (; n < 3540; ) {
              let o = e[n++];
              if (o < 0)
                t3 -= o;
              else {
                let l = e[n++];
                o & 2 && (l = u[l]), o & 1 ? i.fill(l, t3, t3 += e[n++]) : i[t3++] = l;
              }
            }
            return i;
          })([-1, 2, 24, 2, 25, 2, 5, -1, 0, 77595648, 3, 44, 2, 3, 0, 14, 2, 57, 2, 58, 3, 0, 3, 0, 3168796671, 0, 4294956992, 2, 1, 2, 0, 2, 59, 3, 0, 4, 0, 4294966523, 3, 0, 4, 2, 16, 2, 60, 2, 0, 0, 4294836735, 0, 3221225471, 0, 4294901942, 2, 61, 0, 134152192, 3, 0, 2, 0, 4294951935, 3, 0, 2, 0, 2683305983, 0, 2684354047, 2, 17, 2, 0, 0, 4294961151, 3, 0, 2, 2, 19, 2, 0, 0, 608174079, 2, 0, 2, 131, 2, 6, 2, 56, -1, 2, 37, 0, 4294443263, 2, 1, 3, 0, 3, 0, 4294901711, 2, 39, 0, 4089839103, 0, 2961209759, 0, 1342439375, 0, 4294543342, 0, 3547201023, 0, 1577204103, 0, 4194240, 0, 4294688750, 2, 2, 0, 80831, 0, 4261478351, 0, 4294549486, 2, 2, 0, 2967484831, 0, 196559, 0, 3594373100, 0, 3288319768, 0, 8469959, 2, 194, 2, 3, 0, 3825204735, 0, 123747807, 0, 65487, 0, 4294828015, 0, 4092591615, 0, 1080049119, 0, 458703, 2, 3, 2, 0, 0, 2163244511, 0, 4227923919, 0, 4236247022, 2, 66, 0, 4284449919, 0, 851904, 2, 4, 2, 11, 0, 67076095, -1, 2, 67, 0, 1073741743, 0, 4093591391, -1, 0, 50331649, 0, 3265266687, 2, 32, 0, 4294844415, 0, 4278190047, 2, 18, 2, 129, -1, 3, 0, 2, 2, 21, 2, 0, 2, 9, 2, 0, 2, 14, 2, 15, 3, 0, 10, 2, 69, 2, 0, 2, 70, 2, 71, 2, 72, 2, 0, 2, 73, 2, 0, 2, 10, 0, 261632, 2, 23, 3, 0, 2, 2, 12, 2, 4, 3, 0, 18, 2, 74, 2, 5, 3, 0, 2, 2, 75, 0, 2088959, 2, 27, 2, 8, 0, 909311, 3, 0, 2, 0, 814743551, 2, 41, 0, 67057664, 3, 0, 2, 2, 40, 2, 0, 2, 28, 2, 0, 2, 29, 2, 7, 0, 268374015, 2, 26, 2, 49, 2, 0, 2, 76, 0, 134153215, -1, 2, 6, 2, 0, 2, 7, 0, 2684354559, 0, 67044351, 0, 3221160064, 0, 1, -1, 3, 0, 2, 2, 42, 0, 1046528, 3, 0, 3, 2, 8, 2, 0, 2, 51, 0, 4294960127, 2, 9, 2, 38, 2, 10, 0, 4294377472, 2, 11, 3, 0, 7, 0, 4227858431, 3, 0, 8, 2, 12, 2, 0, 2, 78, 2, 9, 2, 0, 2, 79, 2, 80, 2, 81, -1, 2, 124, 0, 1048577, 2, 82, 2, 13, -1, 2, 13, 0, 131042, 2, 83, 2, 84, 2, 85, 2, 0, 2, 33, -83, 2, 0, 2, 53, 2, 7, 3, 0, 4, 0, 1046559, 2, 0, 2, 14, 2, 0, 0, 2147516671, 2, 20, 3, 86, 2, 2, 0, -16, 2, 87, 0, 524222462, 2, 4, 2, 0, 0, 4269801471, 2, 4, 2, 0, 2, 15, 2, 77, 2, 16, 3, 0, 2, 2, 47, 2, 0, -1, 2, 17, -16, 3, 0, 206, -2, 3, 0, 655, 2, 18, 3, 0, 36, 2, 68, -1, 2, 17, 2, 9, 3, 0, 8, 2, 89, 2, 121, 2, 0, 0, 3220242431, 3, 0, 3, 2, 19, 2, 90, 2, 91, 3, 0, 2, 2, 92, 2, 0, 2, 93, 2, 94, 2, 0, 0, 4351, 2, 0, 2, 8, 3, 0, 2, 0, 67043391, 0, 3909091327, 2, 0, 2, 22, 2, 8, 2, 18, 3, 0, 2, 0, 67076097, 2, 7, 2, 0, 2, 20, 0, 67059711, 0, 4236247039, 3, 0, 2, 0, 939524103, 0, 8191999, 2, 97, 2, 98, 2, 15, 2, 21, 3, 0, 3, 0, 67057663, 3, 0, 349, 2, 99, 2, 100, 2, 6, -264, 3, 0, 11, 2, 22, 3, 0, 2, 2, 31, -1, 0, 3774349439, 2, 101, 2, 102, 3, 0, 2, 2, 19, 2, 103, 3, 0, 10, 2, 9, 2, 17, 2, 0, 2, 45, 2, 0, 2, 30, 2, 104, 2, 23, 0, 1638399, 2, 172, 2, 105, 3, 0, 3, 2, 18, 2, 24, 2, 25, 2, 5, 2, 26, 2, 0, 2, 7, 2, 106, -1, 2, 107, 2, 108, 2, 109, -1, 3, 0, 3, 2, 11, -2, 2, 0, 2, 27, -3, 2, 150, -4, 2, 18, 2, 0, 2, 35, 0, 1, 2, 0, 2, 62, 2, 28, 2, 11, 2, 9, 2, 0, 2, 110, -1, 3, 0, 4, 2, 9, 2, 21, 2, 111, 2, 6, 2, 0, 2, 112, 2, 0, 2, 48, -4, 3, 0, 9, 2, 20, 2, 29, 2, 30, -4, 2, 113, 2, 114, 2, 29, 2, 20, 2, 7, -2, 2, 115, 2, 29, 2, 31, -2, 2, 0, 2, 116, -2, 0, 4277137519, 0, 2269118463, -1, 3, 18, 2, -1, 2, 32, 2, 36, 2, 0, 3, 29, 2, 2, 34, 2, 19, -3, 3, 0, 2, 2, 33, -1, 2, 0, 2, 34, 2, 0, 2, 34, 2, 0, 2, 46, -10, 2, 0, 0, 203775, -2, 2, 18, 2, 43, 2, 35, -2, 2, 17, 2, 117, 2, 20, 3, 0, 2, 2, 36, 0, 2147549120, 2, 0, 2, 11, 2, 17, 2, 135, 2, 0, 2, 37, 2, 52, 0, 5242879, 3, 0, 2, 0, 402644511, -1, 2, 120, 0, 1090519039, -2, 2, 122, 2, 38, 2, 0, 0, 67045375, 2, 39, 0, 4226678271, 0, 3766565279, 0, 2039759, -4, 3, 0, 2, 0, 3288270847, 0, 3, 3, 0, 2, 0, 67043519, -5, 2, 0, 0, 4282384383, 0, 1056964609, -1, 3, 0, 2, 0, 67043345, -1, 2, 0, 2, 40, 2, 41, -1, 2, 10, 2, 42, -6, 2, 0, 2, 11, -3, 3, 0, 2, 0, 2147484671, 2, 125, 0, 4190109695, 2, 50, -2, 2, 126, 0, 4244635647, 0, 27, 2, 0, 2, 7, 2, 43, 2, 0, 2, 63, -1, 2, 0, 2, 40, -8, 2, 54, 2, 44, 0, 67043329, 2, 127, 2, 45, 0, 8388351, -2, 2, 128, 0, 3028287487, 2, 46, 2, 130, 0, 33259519, 2, 41, -9, 2, 20, -5, 2, 64, -2, 3, 0, 28, 2, 31, -3, 3, 0, 3, 2, 47, 3, 0, 6, 2, 48, -85, 3, 0, 33, 2, 47, -126, 3, 0, 18, 2, 36, -269, 3, 0, 17, 2, 40, 2, 7, 2, 41, -2, 2, 17, 2, 49, 2, 0, 2, 20, 2, 50, 2, 132, 2, 23, -21, 3, 0, 2, -4, 3, 0, 2, 0, 4294936575, 2, 0, 0, 4294934783, -2, 0, 196635, 3, 0, 191, 2, 51, 3, 0, 38, 2, 29, -1, 2, 33, -279, 3, 0, 8, 2, 7, -1, 2, 133, 2, 52, 3, 0, 11, 2, 6, -72, 3, 0, 3, 2, 134, 0, 1677656575, -166, 0, 4161266656, 0, 4071, 0, 15360, -4, 0, 28, -13, 3, 0, 2, 2, 37, 2, 0, 2, 136, 2, 137, 2, 55, 2, 0, 2, 138, 2, 139, 2, 140, 3, 0, 10, 2, 141, 2, 142, 2, 15, 3, 37, 2, 3, 53, 2, 3, 54, 2, 0, 4294954999, 2, 0, -16, 2, 0, 2, 88, 2, 0, 0, 2105343, 0, 4160749584, 0, 65534, -42, 0, 4194303871, 0, 2011, -6, 2, 0, 0, 1073684479, 0, 17407, -11, 2, 0, 2, 31, -40, 3, 0, 6, 0, 8323103, -1, 3, 0, 2, 2, 42, -37, 2, 55, 2, 144, 2, 145, 2, 146, 2, 147, 2, 148, -105, 2, 24, -32, 3, 0, 1334, 2, 9, -1, 3, 0, 129, 2, 27, 3, 0, 6, 2, 9, 3, 0, 180, 2, 149, 3, 0, 233, 0, 1, -96, 3, 0, 16, 2, 9, -47, 3, 0, 154, 2, 56, -22381, 3, 0, 7, 2, 23, -6130, 3, 5, 2, -1, 0, 69207040, 3, 44, 2, 3, 0, 14, 2, 57, 2, 58, -3, 0, 3168731136, 0, 4294956864, 2, 1, 2, 0, 2, 59, 3, 0, 4, 0, 4294966275, 3, 0, 4, 2, 16, 2, 60, 2, 0, 2, 33, -1, 2, 17, 2, 61, -1, 2, 0, 2, 56, 0, 4294885376, 3, 0, 2, 0, 3145727, 0, 2617294944, 0, 4294770688, 2, 23, 2, 62, 3, 0, 2, 0, 131135, 2, 95, 0, 70256639, 0, 71303167, 0, 272, 2, 40, 2, 56, -1, 2, 37, 2, 30, -1, 2, 96, 2, 63, 0, 4278255616, 0, 4294836227, 0, 4294549473, 0, 600178175, 0, 2952806400, 0, 268632067, 0, 4294543328, 0, 57540095, 0, 1577058304, 0, 1835008, 0, 4294688736, 2, 65, 2, 64, 0, 33554435, 2, 123, 2, 65, 2, 151, 0, 131075, 0, 3594373096, 0, 67094296, 2, 64, -1, 0, 4294828e3, 0, 603979263, 2, 160, 0, 3, 0, 4294828001, 0, 602930687, 2, 183, 0, 393219, 0, 4294828016, 0, 671088639, 0, 2154840064, 0, 4227858435, 0, 4236247008, 2, 66, 2, 36, -1, 2, 4, 0, 917503, 2, 36, -1, 2, 67, 0, 537788335, 0, 4026531935, -1, 0, 1, -1, 2, 32, 2, 68, 0, 7936, -3, 2, 0, 0, 2147485695, 0, 1010761728, 0, 4292984930, 0, 16387, 2, 0, 2, 14, 2, 15, 3, 0, 10, 2, 69, 2, 0, 2, 70, 2, 71, 2, 72, 2, 0, 2, 73, 2, 0, 2, 11, -1, 2, 23, 3, 0, 2, 2, 12, 2, 4, 3, 0, 18, 2, 74, 2, 5, 3, 0, 2, 2, 75, 0, 253951, 3, 19, 2, 0, 122879, 2, 0, 2, 8, 0, 276824064, -2, 3, 0, 2, 2, 40, 2, 0, 0, 4294903295, 2, 0, 2, 29, 2, 7, -1, 2, 17, 2, 49, 2, 0, 2, 76, 2, 41, -1, 2, 20, 2, 0, 2, 27, -2, 0, 128, -2, 2, 77, 2, 8, 0, 4064, -1, 2, 119, 0, 4227907585, 2, 0, 2, 118, 2, 0, 2, 48, 2, 173, 2, 9, 2, 38, 2, 10, -1, 0, 74440192, 3, 0, 6, -2, 3, 0, 8, 2, 12, 2, 0, 2, 78, 2, 9, 2, 0, 2, 79, 2, 80, 2, 81, -3, 2, 82, 2, 13, -3, 2, 83, 2, 84, 2, 85, 2, 0, 2, 33, -83, 2, 0, 2, 53, 2, 7, 3, 0, 4, 0, 817183, 2, 0, 2, 14, 2, 0, 0, 33023, 2, 20, 3, 86, 2, -17, 2, 87, 0, 524157950, 2, 4, 2, 0, 2, 88, 2, 4, 2, 0, 2, 15, 2, 77, 2, 16, 3, 0, 2, 2, 47, 2, 0, -1, 2, 17, -16, 3, 0, 206, -2, 3, 0, 655, 2, 18, 3, 0, 36, 2, 68, -1, 2, 17, 2, 9, 3, 0, 8, 2, 89, 0, 3072, 2, 0, 0, 2147516415, 2, 9, 3, 0, 2, 2, 23, 2, 90, 2, 91, 3, 0, 2, 2, 92, 2, 0, 2, 93, 2, 94, 0, 4294965179, 0, 7, 2, 0, 2, 8, 2, 91, 2, 8, -1, 0, 1761345536, 2, 95, 0, 4294901823, 2, 36, 2, 18, 2, 96, 2, 34, 2, 166, 0, 2080440287, 2, 0, 2, 33, 2, 143, 0, 3296722943, 2, 0, 0, 1046675455, 0, 939524101, 0, 1837055, 2, 97, 2, 98, 2, 15, 2, 21, 3, 0, 3, 0, 7, 3, 0, 349, 2, 99, 2, 100, 2, 6, -264, 3, 0, 11, 2, 22, 3, 0, 2, 2, 31, -1, 0, 2700607615, 2, 101, 2, 102, 3, 0, 2, 2, 19, 2, 103, 3, 0, 10, 2, 9, 2, 17, 2, 0, 2, 45, 2, 0, 2, 30, 2, 104, -3, 2, 105, 3, 0, 3, 2, 18, -1, 3, 5, 2, 2, 26, 2, 0, 2, 7, 2, 106, -1, 2, 107, 2, 108, 2, 109, -1, 3, 0, 3, 2, 11, -2, 2, 0, 2, 27, -8, 2, 18, 2, 0, 2, 35, -1, 2, 0, 2, 62, 2, 28, 2, 29, 2, 9, 2, 0, 2, 110, -1, 3, 0, 4, 2, 9, 2, 17, 2, 111, 2, 6, 2, 0, 2, 112, 2, 0, 2, 48, -4, 3, 0, 9, 2, 20, 2, 29, 2, 30, -4, 2, 113, 2, 114, 2, 29, 2, 20, 2, 7, -2, 2, 115, 2, 29, 2, 31, -2, 2, 0, 2, 116, -2, 0, 4277075969, 2, 29, -1, 3, 18, 2, -1, 2, 32, 2, 117, 2, 0, 3, 29, 2, 2, 34, 2, 19, -3, 3, 0, 2, 2, 33, -1, 2, 0, 2, 34, 2, 0, 2, 34, 2, 0, 2, 48, -10, 2, 0, 0, 197631, -2, 2, 18, 2, 43, 2, 118, -2, 2, 17, 2, 117, 2, 20, 2, 119, 2, 51, -2, 2, 119, 2, 23, 2, 17, 2, 33, 2, 119, 2, 36, 0, 4294901904, 0, 4718591, 2, 119, 2, 34, 0, 335544350, -1, 2, 120, 2, 121, -2, 2, 122, 2, 38, 2, 7, -1, 2, 123, 2, 65, 0, 3758161920, 0, 3, -4, 2, 0, 2, 27, 0, 2147485568, 0, 3, 2, 0, 2, 23, 0, 176, -5, 2, 0, 2, 47, 2, 186, -1, 2, 0, 2, 23, 2, 197, -1, 2, 0, 0, 16779263, -2, 2, 11, -7, 2, 0, 2, 121, -3, 3, 0, 2, 2, 124, 2, 125, 0, 2147549183, 0, 2, -2, 2, 126, 2, 35, 0, 10, 0, 4294965249, 0, 67633151, 0, 4026597376, 2, 0, 0, 536871935, -1, 2, 0, 2, 40, -8, 2, 54, 2, 47, 0, 1, 2, 127, 2, 23, -3, 2, 128, 2, 35, 2, 129, 2, 130, 0, 16778239, -10, 2, 34, -5, 2, 64, -2, 3, 0, 28, 2, 31, -3, 3, 0, 3, 2, 47, 3, 0, 6, 2, 48, -85, 3, 0, 33, 2, 47, -126, 3, 0, 18, 2, 36, -269, 3, 0, 17, 2, 40, 2, 7, -3, 2, 17, 2, 131, 2, 0, 2, 23, 2, 48, 2, 132, 2, 23, -21, 3, 0, 2, -4, 3, 0, 2, 0, 67583, -1, 2, 103, -2, 0, 11, 3, 0, 191, 2, 51, 3, 0, 38, 2, 29, -1, 2, 33, -279, 3, 0, 8, 2, 7, -1, 2, 133, 2, 52, 3, 0, 11, 2, 6, -72, 3, 0, 3, 2, 134, 2, 135, -187, 3, 0, 2, 2, 37, 2, 0, 2, 136, 2, 137, 2, 55, 2, 0, 2, 138, 2, 139, 2, 140, 3, 0, 10, 2, 141, 2, 142, 2, 15, 3, 37, 2, 3, 53, 2, 3, 54, 2, 2, 143, -73, 2, 0, 0, 1065361407, 0, 16384, -11, 2, 0, 2, 121, -40, 3, 0, 6, 2, 117, -1, 3, 0, 2, 0, 2063, -37, 2, 55, 2, 144, 2, 145, 2, 146, 2, 147, 2, 148, -138, 3, 0, 1334, 2, 9, -1, 3, 0, 129, 2, 27, 3, 0, 6, 2, 9, 3, 0, 180, 2, 149, 3, 0, 233, 0, 1, -96, 3, 0, 16, 2, 9, -47, 3, 0, 154, 2, 56, -28517, 2, 0, 0, 1, -1, 2, 124, 2, 0, 0, 8193, -21, 2, 193, 0, 10255, 0, 4, -11, 2, 64, 2, 171, -1, 0, 71680, -1, 2, 161, 0, 4292900864, 0, 805306431, -5, 2, 150, -1, 2, 157, -1, 0, 6144, -2, 2, 127, -1, 2, 154, -1, 0, 2147532800, 2, 151, 2, 165, 2, 0, 2, 164, 0, 524032, 0, 4, -4, 2, 190, 0, 205128192, 0, 1333757536, 0, 2147483696, 0, 423953, 0, 747766272, 0, 2717763192, 0, 4286578751, 0, 278545, 2, 152, 0, 4294886464, 0, 33292336, 0, 417809, 2, 152, 0, 1327482464, 0, 4278190128, 0, 700594195, 0, 1006647527, 0, 4286497336, 0, 4160749631, 2, 153, 0, 469762560, 0, 4171219488, 0, 8323120, 2, 153, 0, 202375680, 0, 3214918176, 0, 4294508592, 2, 153, -1, 0, 983584, 0, 48, 0, 58720273, 0, 3489923072, 0, 10517376, 0, 4293066815, 0, 1, 0, 2013265920, 2, 177, 2, 0, 0, 2089, 0, 3221225552, 0, 201375904, 2, 0, -2, 0, 256, 0, 122880, 0, 16777216, 2, 150, 0, 4160757760, 2, 0, -6, 2, 167, -11, 0, 3263218176, -1, 0, 49664, 0, 2160197632, 0, 8388802, -1, 0, 12713984, -1, 2, 154, 2, 159, 2, 178, -2, 2, 162, -20, 0, 3758096385, -2, 2, 155, 0, 4292878336, 2, 90, 2, 169, 0, 4294057984, -2, 2, 163, 2, 156, 2, 175, -2, 2, 155, -1, 2, 182, -1, 2, 170, 2, 124, 0, 4026593280, 0, 14, 0, 4292919296, -1, 2, 158, 0, 939588608, -1, 0, 805306368, -1, 2, 124, 0, 1610612736, 2, 156, 2, 157, 2, 4, 2, 0, -2, 2, 158, 2, 159, -3, 0, 267386880, -1, 2, 160, 0, 7168, -1, 0, 65024, 2, 154, 2, 161, 2, 179, -7, 2, 168, -8, 2, 162, -1, 0, 1426112704, 2, 163, -1, 2, 164, 0, 271581216, 0, 2149777408, 2, 23, 2, 161, 2, 124, 0, 851967, 2, 180, -1, 2, 23, 2, 181, -4, 2, 158, -20, 2, 195, 2, 165, -56, 0, 3145728, 2, 185, -4, 2, 166, 2, 124, -4, 0, 32505856, -1, 2, 167, -1, 0, 2147385088, 2, 90, 1, 2155905152, 2, -3, 2, 103, 2, 0, 2, 168, -2, 2, 169, -6, 2, 170, 0, 4026597375, 0, 1, -1, 0, 1, -1, 2, 171, -3, 2, 117, 2, 64, -2, 2, 166, -2, 2, 176, 2, 124, -878, 2, 159, -36, 2, 172, -1, 2, 201, -10, 2, 188, -5, 2, 174, -6, 0, 4294965251, 2, 27, -1, 2, 173, -1, 2, 174, -2, 0, 4227874752, -3, 0, 2146435072, 2, 159, -2, 0, 1006649344, 2, 124, -1, 2, 90, 0, 201375744, -3, 0, 134217720, 2, 90, 0, 4286677377, 0, 32896, -1, 2, 158, -3, 2, 175, -349, 2, 176, 0, 1920, 2, 177, 3, 0, 264, -11, 2, 157, -2, 2, 178, 2, 0, 0, 520617856, 0, 2692743168, 0, 36, -3, 0, 524284, -11, 2, 23, -1, 2, 187, -1, 2, 184, 0, 3221291007, 2, 178, -1, 2, 202, 0, 2158720, -3, 2, 159, 0, 1, -4, 2, 124, 0, 3808625411, 0, 3489628288, 2, 200, 0, 1207959680, 0, 3221274624, 2, 0, -3, 2, 179, 0, 120, 0, 7340032, -2, 2, 180, 2, 4, 2, 23, 2, 163, 3, 0, 4, 2, 159, -1, 2, 181, 2, 177, -1, 0, 8176, 2, 182, 2, 179, 2, 183, -1, 0, 4290773232, 2, 0, -4, 2, 163, 2, 189, 0, 15728640, 2, 177, -1, 2, 161, -1, 0, 4294934512, 3, 0, 4, -9, 2, 90, 2, 170, 2, 184, 3, 0, 4, 0, 704, 0, 1849688064, 2, 185, -1, 2, 124, 0, 4294901887, 2, 0, 0, 130547712, 0, 1879048192, 2, 199, 3, 0, 2, -1, 2, 186, 2, 187, -1, 0, 17829776, 0, 2025848832, 0, 4261477888, -2, 2, 0, -1, 0, 4286580608, -1, 0, 29360128, 2, 192, 0, 16252928, 0, 3791388672, 2, 38, 3, 0, 2, -2, 2, 196, 2, 0, -1, 2, 103, -1, 0, 66584576, -1, 2, 191, 3, 0, 9, 2, 124, -1, 0, 4294755328, 3, 0, 2, -1, 2, 161, 2, 178, 3, 0, 2, 2, 23, 2, 188, 2, 90, -2, 0, 245760, 0, 2147418112, -1, 2, 150, 2, 203, 0, 4227923456, -1, 2, 164, 2, 161, 2, 90, -3, 0, 4292870145, 0, 262144, 2, 124, 3, 0, 2, 0, 1073758848, 2, 189, -1, 0, 4227921920, 2, 190, 0, 68289024, 0, 528402016, 0, 4292927536, 3, 0, 4, -2, 0, 268435456, 2, 91, -2, 2, 191, 3, 0, 5, -1, 2, 192, 2, 163, 2, 0, -2, 0, 4227923936, 2, 62, -1, 2, 155, 2, 95, 2, 0, 2, 154, 2, 158, 3, 0, 6, -1, 2, 177, 3, 0, 3, -2, 0, 2146959360, 0, 9440640, 0, 104857600, 0, 4227923840, 3, 0, 2, 0, 768, 2, 193, 2, 77, -2, 2, 161, -2, 2, 119, -1, 2, 155, 3, 0, 8, 0, 512, 0, 8388608, 2, 194, 2, 172, 2, 187, 0, 4286578944, 3, 0, 2, 0, 1152, 0, 1266679808, 2, 191, 0, 576, 0, 4261707776, 2, 95, 3, 0, 9, 2, 155, 3, 0, 5, 2, 16, -1, 0, 2147221504, -28, 2, 178, 3, 0, 3, -3, 0, 4292902912, -6, 2, 96, 3, 0, 85, -33, 0, 4294934528, 3, 0, 126, -18, 2, 195, 3, 0, 269, -17, 2, 155, 2, 124, 2, 198, 3, 0, 2, 2, 23, 0, 4290822144, -2, 0, 67174336, 0, 520093700, 2, 17, 3, 0, 21, -2, 2, 179, 3, 0, 3, -2, 0, 30720, -1, 0, 32512, 3, 0, 2, 0, 4294770656, -191, 2, 174, -38, 2, 170, 2, 0, 2, 196, 3, 0, 279, -8, 2, 124, 2, 0, 0, 4294508543, 0, 65295, -11, 2, 177, 3, 0, 72, -3, 0, 3758159872, 0, 201391616, 3, 0, 155, -7, 2, 170, -1, 0, 384, -1, 0, 133693440, -3, 2, 196, -2, 2, 26, 3, 0, 4, 2, 169, -2, 2, 90, 2, 155, 3, 0, 4, -2, 2, 164, -1, 2, 150, 0, 335552923, 2, 197, -1, 0, 538974272, 0, 2214592512, 0, 132e3, -10, 0, 192, -8, 0, 12288, -21, 0, 134213632, 0, 4294901761, 3, 0, 42, 0, 100663424, 0, 4294965284, 3, 0, 6, -1, 0, 3221282816, 2, 198, 3, 0, 11, -1, 2, 199, 3, 0, 40, -6, 0, 4286578784, 2, 0, -2, 0, 1006694400, 3, 0, 24, 2, 35, -1, 2, 94, 3, 0, 2, 0, 1, 2, 163, 3, 0, 6, 2, 197, 0, 4110942569, 0, 1432950139, 0, 2701658217, 0, 4026532864, 0, 4026532881, 2, 0, 2, 45, 3, 0, 8, -1, 2, 158, -2, 2, 169, 0, 98304, 0, 65537, 2, 170, -5, 0, 4294950912, 2, 0, 2, 118, 0, 65528, 2, 177, 0, 4294770176, 2, 26, 3, 0, 4, -30, 2, 174, 0, 3758153728, -3, 2, 169, -2, 2, 155, 2, 188, 2, 158, -1, 2, 191, -1, 2, 161, 0, 4294754304, 3, 0, 2, -3, 0, 33554432, -2, 2, 200, -3, 2, 169, 0, 4175478784, 2, 201, 0, 4286643712, 0, 4286644216, 2, 0, -4, 2, 202, -1, 2, 165, 0, 4227923967, 3, 0, 32, -1334, 2, 163, 2, 0, -129, 2, 94, -6, 2, 163, -180, 2, 203, -233, 2, 4, 3, 0, 96, -16, 2, 163, 3, 0, 47, -154, 2, 165, 3, 0, 22381, -7, 2, 17, 3, 0, 6128], [4294967295, 4294967291, 4092460543, 4294828031, 4294967294, 134217726, 268435455, 2147483647, 1048575, 1073741823, 3892314111, 134217727, 1061158911, 536805376, 4294910143, 4160749567, 4294901759, 4294901760, 536870911, 262143, 8388607, 4294902783, 4294918143, 65535, 67043328, 2281701374, 4294967232, 2097151, 4294903807, 4194303, 255, 67108863, 4294967039, 511, 524287, 131071, 127, 4292870143, 4294902271, 4294549487, 33554431, 1023, 67047423, 4294901888, 4286578687, 4294770687, 67043583, 32767, 15, 2047999, 67043343, 16777215, 4294902e3, 4294934527, 4294966783, 4294967279, 2047, 262083, 20511, 4290772991, 41943039, 493567, 4294959104, 603979775, 65536, 602799615, 805044223, 4294965206, 8191, 1031749119, 4294917631, 2134769663, 4286578493, 4282253311, 4294942719, 33540095, 4294905855, 4294967264, 2868854591, 1608515583, 265232348, 534519807, 2147614720, 1060109444, 4093640016, 17376, 2139062143, 224, 4169138175, 4294909951, 4286578688, 4294967292, 4294965759, 2044, 4292870144, 4294966272, 4294967280, 8289918, 4294934399, 4294901775, 4294965375, 1602223615, 4294967259, 4294443008, 268369920, 4292804608, 486341884, 4294963199, 3087007615, 1073692671, 4128527, 4279238655, 4294902015, 4294966591, 2445279231, 3670015, 3238002687, 31, 63, 4294967288, 4294705151, 4095, 3221208447, 4294549472, 2147483648, 4285526655, 4294966527, 4294705152, 4294966143, 64, 4294966719, 16383, 3774873592, 458752, 536807423, 67043839, 3758096383, 3959414372, 3755993023, 2080374783, 4294835295, 4294967103, 4160749565, 4087, 184024726, 2862017156, 1593309078, 268434431, 268434414, 4294901763, 536870912, 2952790016, 202506752, 139264, 402653184, 4261412864, 4227922944, 49152, 61440, 3758096384, 117440512, 65280, 3233808384, 3221225472, 2097152, 4294965248, 32768, 57152, 67108864, 4293918720, 4290772992, 25165824, 57344, 4227915776, 4278190080, 4227907584, 65520, 4026531840, 4227858432, 4160749568, 3758129152, 4294836224, 63488, 1073741824, 4294967040, 4194304, 251658240, 196608, 4294963200, 64512, 417808, 4227923712, 12582912, 50331648, 65472, 4294967168, 4294966784, 16, 4294917120, 2080374784, 4096, 65408, 524288, 65532]);
          function k(e) {
            return e.column++, e.currentChar = e.source.charCodeAt(++e.index);
          }
          function W(e, u) {
            if ((u & 64512) !== 55296)
              return 0;
            let i = e.source.charCodeAt(e.index + 1);
            return (i & 64512) !== 56320 ? 0 : (u = e.currentChar = 65536 + ((u & 1023) << 10) + (i & 1023), N[(u >>> 5) + 0] >>> u & 31 & 1 || f(e, 18, e2(u)), e.index++, e.column++, 1);
          }
          function $2(e, u) {
            e.currentChar = e.source.charCodeAt(++e.index), e.flags |= 1, u & 4 || (e.column = 0, e.line++);
          }
          function z(e) {
            e.flags |= 1, e.currentChar = e.source.charCodeAt(++e.index), e.column = 0, e.line++;
          }
          function Q(e) {
            return e === 160 || e === 65279 || e === 133 || e === 5760 || e >= 8192 && e <= 8203 || e === 8239 || e === 8287 || e === 12288 || e === 8201 || e === 65519;
          }
          function e2(e) {
            return e <= 65535 ? String.fromCharCode(e) : String.fromCharCode(e >>> 10) + String.fromCharCode(e & 1023);
          }
          function L(e) {
            return e < 65 ? e - 48 : e - 65 + 10 & 15;
          }
          function Z(e) {
            switch (e) {
              case 134283266:
                return "NumericLiteral";
              case 134283267:
                return "StringLiteral";
              case 86021:
              case 86022:
                return "BooleanLiteral";
              case 86023:
                return "NullLiteral";
              case 65540:
                return "RegularExpression";
              case 67174408:
              case 67174409:
              case 132:
                return "TemplateLiteral";
              default:
                return (e & 143360) === 143360 ? "Identifier" : (e & 4096) === 4096 ? "Keyword" : "Punctuator";
            }
          }
          var R = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1032, 0, 0, 2056, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8192, 0, 3, 0, 0, 8192, 0, 0, 0, 256, 0, 33024, 0, 0, 242, 242, 114, 114, 114, 114, 114, 114, 594, 594, 0, 0, 16384, 0, 0, 0, 0, 67, 67, 67, 67, 67, 67, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 0, 1, 0, 0, 4099, 0, 71, 71, 71, 71, 71, 71, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 16384, 0, 0, 0, 0], j = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0], H = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0];
          function O(e) {
            return e <= 127 ? j[e] : N[(e >>> 5) + 34816] >>> e & 31 & 1;
          }
          function u2(e) {
            return e <= 127 ? H[e] : N[(e >>> 5) + 0] >>> e & 31 & 1 || e === 8204 || e === 8205;
          }
          var h2 = ["SingleLine", "MultiLine", "HTMLOpen", "HTMLClose", "HashbangComment"];
          function f2(e) {
            let u = e.source;
            e.currentChar === 35 && u.charCodeAt(e.index + 1) === 33 && (k(e), k(e), c2(e, u, 0, 4, e.tokenPos, e.linePos, e.colPos));
          }
          function N2(e, u, i, n, t3, o, l, c) {
            return n & 2048 && f(e, 0), c2(e, u, i, t3, o, l, c);
          }
          function c2(e, u, i, n, t3, o, l) {
            let { index: c } = e;
            for (e.tokenPos = e.index, e.linePos = e.line, e.colPos = e.column; e.index < e.end; ) {
              if (R[e.currentChar] & 8) {
                let s = e.currentChar === 13;
                z(e), s && e.index < e.end && e.currentChar === 10 && (e.currentChar = u.charCodeAt(++e.index));
                break;
              } else if ((e.currentChar ^ 8232) <= 1) {
                z(e);
                break;
              }
              k(e), e.tokenPos = e.index, e.linePos = e.line, e.colPos = e.column;
            }
            if (e.onComment) {
              let s = { start: { line: o, column: l }, end: { line: e.linePos, column: e.colPos } };
              e.onComment(h2[n & 255], u.slice(c, e.tokenPos), t3, e.tokenPos, s);
            }
            return i | 1;
          }
          function V2(e, u, i) {
            let { index: n } = e;
            for (; e.index < e.end; )
              if (e.currentChar < 43) {
                let t3 = false;
                for (; e.currentChar === 42; )
                  if (t3 || (i &= -5, t3 = true), k(e) === 47) {
                    if (k(e), e.onComment) {
                      let o = { start: { line: e.linePos, column: e.colPos }, end: { line: e.line, column: e.column } };
                      e.onComment(h2[1], u.slice(n, e.index - 2), n - 2, e.index, o);
                    }
                    return e.tokenPos = e.index, e.linePos = e.line, e.colPos = e.column, i;
                  }
                if (t3)
                  continue;
                R[e.currentChar] & 8 ? e.currentChar === 13 ? (i |= 5, z(e)) : ($2(e, i), i = i & -5 | 1) : k(e);
              } else
                (e.currentChar ^ 8232) <= 1 ? (i = i & -5 | 1, z(e)) : (i &= -5, k(e));
            f(e, 16);
          }
          function q2(e, u) {
            let i = e.index, n = 0;
            e:
              for (; ; ) {
                let b = e.currentChar;
                if (k(e), n & 1)
                  n &= -2;
                else
                  switch (b) {
                    case 47:
                      if (n)
                        break;
                      break e;
                    case 92:
                      n |= 1;
                      break;
                    case 91:
                      n |= 2;
                      break;
                    case 93:
                      n &= 1;
                      break;
                    case 13:
                    case 10:
                    case 8232:
                    case 8233:
                      f(e, 32);
                  }
                if (e.index >= e.source.length)
                  return f(e, 32);
              }
            let t3 = e.index - 1, o = 0, l = e.currentChar, { index: c } = e;
            for (; u2(l); ) {
              switch (l) {
                case 103:
                  o & 2 && f(e, 34, "g"), o |= 2;
                  break;
                case 105:
                  o & 1 && f(e, 34, "i"), o |= 1;
                  break;
                case 109:
                  o & 4 && f(e, 34, "m"), o |= 4;
                  break;
                case 117:
                  o & 16 && f(e, 34, "g"), o |= 16;
                  break;
                case 121:
                  o & 8 && f(e, 34, "y"), o |= 8;
                  break;
                case 115:
                  o & 32 && f(e, 34, "s"), o |= 32;
                  break;
                default:
                  f(e, 33);
              }
              l = k(e);
            }
            let s = e.source.slice(c, e.index), r = e.source.slice(i, t3);
            return e.tokenRegExp = { pattern: r, flags: s }, u & 512 && (e.tokenRaw = e.source.slice(e.tokenPos, e.index)), e.tokenValue = N1(e, r, s), 65540;
          }
          function N1(e, u, i) {
            try {
              return new RegExp(u, i);
            } catch {
              f(e, 32);
            }
          }
          function V1(e, u, i) {
            let { index: n } = e, t3 = "", o = k(e), l = e.index;
            for (; !(R[o] & 8); ) {
              if (o === i)
                return t3 += e.source.slice(l, e.index), k(e), u & 512 && (e.tokenRaw = e.source.slice(n, e.index)), e.tokenValue = t3, 134283267;
              if ((o & 8) === 8 && o === 92) {
                if (t3 += e.source.slice(l, e.index), o = k(e), o < 127 || o === 8232 || o === 8233) {
                  let c = d2(e, u, o);
                  c >= 0 ? t3 += e2(c) : t1(e, c, 0);
                } else
                  t3 += e2(o);
                l = e.index + 1;
              }
              e.index >= e.end && f(e, 14), o = k(e);
            }
            f(e, 14);
          }
          function d2(e, u, i) {
            switch (i) {
              case 98:
                return 8;
              case 102:
                return 12;
              case 114:
                return 13;
              case 110:
                return 10;
              case 116:
                return 9;
              case 118:
                return 11;
              case 13:
                if (e.index < e.end) {
                  let n = e.source.charCodeAt(e.index + 1);
                  n === 10 && (e.index = e.index + 1, e.currentChar = n);
                }
              case 10:
              case 8232:
              case 8233:
                return e.column = -1, e.line++, -1;
              case 48:
              case 49:
              case 50:
              case 51: {
                let n = i - 48, t3 = e.index + 1, o = e.column + 1;
                if (t3 < e.end) {
                  let l = e.source.charCodeAt(t3);
                  if (R[l] & 32) {
                    if (u & 1024)
                      return -2;
                    if (e.currentChar = l, n = n << 3 | l - 48, t3++, o++, t3 < e.end) {
                      let c = e.source.charCodeAt(t3);
                      R[c] & 32 && (e.currentChar = c, n = n << 3 | c - 48, t3++, o++);
                    }
                    e.flags |= 64, e.index = t3 - 1, e.column = o - 1;
                  } else if ((n !== 0 || R[l] & 512) && u & 1024)
                    return -2;
                }
                return n;
              }
              case 52:
              case 53:
              case 54:
              case 55: {
                if (u & 1024)
                  return -2;
                let n = i - 48, t3 = e.index + 1, o = e.column + 1;
                if (t3 < e.end) {
                  let l = e.source.charCodeAt(t3);
                  R[l] & 32 && (n = n << 3 | l - 48, e.currentChar = l, e.index = t3, e.column = o);
                }
                return e.flags |= 64, n;
              }
              case 120: {
                let n = k(e);
                if (!(R[n] & 64))
                  return -4;
                let t3 = L(n), o = k(e);
                if (!(R[o] & 64))
                  return -4;
                let l = L(o);
                return t3 << 4 | l;
              }
              case 117: {
                let n = k(e);
                if (e.currentChar === 123) {
                  let t3 = 0;
                  for (; R[k(e)] & 64; )
                    if (t3 = t3 << 4 | L(e.currentChar), t3 > 1114111)
                      return -5;
                  return e.currentChar < 1 || e.currentChar !== 125 ? -4 : t3;
                } else {
                  if (!(R[n] & 64))
                    return -4;
                  let t3 = e.source.charCodeAt(e.index + 1);
                  if (!(R[t3] & 64))
                    return -4;
                  let o = e.source.charCodeAt(e.index + 2);
                  if (!(R[o] & 64))
                    return -4;
                  let l = e.source.charCodeAt(e.index + 3);
                  return R[l] & 64 ? (e.index += 3, e.column += 3, e.currentChar = e.source.charCodeAt(e.index), L(n) << 12 | L(t3) << 8 | L(o) << 4 | L(l)) : -4;
                }
              }
              case 56:
              case 57:
                if (!(u & 256))
                  return -3;
              default:
                return i;
            }
          }
          function t1(e, u, i) {
            switch (u) {
              case -1:
                return;
              case -2:
                f(e, i ? 2 : 1);
              case -3:
                f(e, 13);
              case -4:
                f(e, 6);
              case -5:
                f(e, 101);
            }
          }
          function We(e, u) {
            let { index: i } = e, n = 67174409, t3 = "", o = k(e);
            for (; o !== 96; ) {
              if (o === 36 && e.source.charCodeAt(e.index + 1) === 123) {
                k(e), n = 67174408;
                break;
              } else if ((o & 8) === 8 && o === 92)
                if (o = k(e), o > 126)
                  t3 += e2(o);
                else {
                  let l = d2(e, u | 1024, o);
                  if (l >= 0)
                    t3 += e2(l);
                  else if (l !== -1 && u & 65536) {
                    t3 = void 0, o = Nt(e, o), o < 0 && (n = 67174408);
                    break;
                  } else
                    t1(e, l, 1);
                }
              else
                e.index < e.end && o === 13 && e.source.charCodeAt(e.index) === 10 && (t3 += e2(o), e.currentChar = e.source.charCodeAt(++e.index)), ((o & 83) < 3 && o === 10 || (o ^ 8232) <= 1) && (e.column = -1, e.line++), t3 += e2(o);
              e.index >= e.end && f(e, 15), o = k(e);
            }
            return k(e), e.tokenValue = t3, e.tokenRaw = e.source.slice(i + 1, e.index - (n === 67174409 ? 1 : 2)), n;
          }
          function Nt(e, u) {
            for (; u !== 96; ) {
              switch (u) {
                case 36: {
                  let i = e.index + 1;
                  if (i < e.end && e.source.charCodeAt(i) === 123)
                    return e.index = i, e.column++, -u;
                  break;
                }
                case 10:
                case 8232:
                case 8233:
                  e.column = -1, e.line++;
              }
              e.index >= e.end && f(e, 15), u = k(e);
            }
            return u;
          }
          function Vt(e, u) {
            return e.index >= e.end && f(e, 0), e.index--, e.column--, We(e, u);
          }
          function Ke(e, u, i) {
            let n = e.currentChar, t3 = 0, o = 9, l = i & 64 ? 0 : 1, c = 0, s = 0;
            if (i & 64)
              t3 = "." + o1(e, n), n = e.currentChar, n === 110 && f(e, 11);
            else {
              if (n === 48)
                if (n = k(e), (n | 32) === 120) {
                  for (i = 136, n = k(e); R[n] & 4160; ) {
                    if (n === 95) {
                      s || f(e, 146), s = 0, n = k(e);
                      continue;
                    }
                    s = 1, t3 = t3 * 16 + L(n), c++, n = k(e);
                  }
                  (c < 1 || !s) && f(e, c < 1 ? 19 : 147);
                } else if ((n | 32) === 111) {
                  for (i = 132, n = k(e); R[n] & 4128; ) {
                    if (n === 95) {
                      s || f(e, 146), s = 0, n = k(e);
                      continue;
                    }
                    s = 1, t3 = t3 * 8 + (n - 48), c++, n = k(e);
                  }
                  (c < 1 || !s) && f(e, c < 1 ? 0 : 147);
                } else if ((n | 32) === 98) {
                  for (i = 130, n = k(e); R[n] & 4224; ) {
                    if (n === 95) {
                      s || f(e, 146), s = 0, n = k(e);
                      continue;
                    }
                    s = 1, t3 = t3 * 2 + (n - 48), c++, n = k(e);
                  }
                  (c < 1 || !s) && f(e, c < 1 ? 0 : 147);
                } else if (R[n] & 32)
                  for (u & 1024 && f(e, 1), i = 1; R[n] & 16; ) {
                    if (R[n] & 512) {
                      i = 32, l = 0;
                      break;
                    }
                    t3 = t3 * 8 + (n - 48), n = k(e);
                  }
                else
                  R[n] & 512 ? (u & 1024 && f(e, 1), e.flags |= 64, i = 32) : n === 95 && f(e, 0);
              if (i & 48) {
                if (l) {
                  for (; o >= 0 && R[n] & 4112; ) {
                    if (n === 95) {
                      n = k(e), (n === 95 || i & 32) && q(e.index, e.line, e.index + 1, 146), s = 1;
                      continue;
                    }
                    s = 0, t3 = 10 * t3 + (n - 48), n = k(e), --o;
                  }
                  if (s && q(e.index, e.line, e.index + 1, 147), o >= 0 && !O(n) && n !== 46)
                    return e.tokenValue = t3, u & 512 && (e.tokenRaw = e.source.slice(e.tokenPos, e.index)), 134283266;
                }
                t3 += o1(e, n), n = e.currentChar, n === 46 && (k(e) === 95 && f(e, 0), i = 64, t3 += "." + o1(e, e.currentChar), n = e.currentChar);
              }
            }
            let r = e.index, b = 0;
            if (n === 110 && i & 128)
              b = 1, n = k(e);
            else if ((n | 32) === 101) {
              n = k(e), R[n] & 256 && (n = k(e));
              let { index: h } = e;
              (R[n] & 16) < 1 && f(e, 10), t3 += e.source.substring(r, h) + o1(e, n), n = e.currentChar;
            }
            return (e.index < e.end && R[n] & 16 || O(n)) && f(e, 12), b ? (e.tokenRaw = e.source.slice(e.tokenPos, e.index), e.tokenValue = BigInt(t3), 134283389) : (e.tokenValue = i & 15 ? t3 : i & 32 ? parseFloat(e.source.substring(e.tokenPos, e.index)) : +t3, u & 512 && (e.tokenRaw = e.source.slice(e.tokenPos, e.index)), 134283266);
          }
          function o1(e, u) {
            let i = 0, n = e.index, t3 = "";
            for (; R[u] & 4112; ) {
              if (u === 95) {
                let { index: o } = e;
                u = k(e), u === 95 && q(e.index, e.line, e.index + 1, 146), i = 1, t3 += e.source.substring(n, o), n = e.index;
                continue;
              }
              i = 0, u = k(e);
            }
            return i && q(e.index, e.line, e.index + 1, 147), t3 + e.source.substring(n, e.index);
          }
          var x = ["end of source", "identifier", "number", "string", "regular expression", "false", "true", "null", "template continuation", "template tail", "=>", "(", "{", ".", "...", "}", ")", ";", ",", "[", "]", ":", "?", "'", '"', "</", "/>", "++", "--", "=", "<<=", ">>=", ">>>=", "**=", "+=", "-=", "*=", "/=", "%=", "^=", "|=", "&=", "||=", "&&=", "??=", "typeof", "delete", "void", "!", "~", "+", "-", "in", "instanceof", "*", "%", "/", "**", "&&", "||", "===", "!==", "==", "!=", "<=", ">=", "<", ">", "<<", ">>", ">>>", "&", "|", "^", "var", "let", "const", "break", "case", "catch", "class", "continue", "debugger", "default", "do", "else", "export", "extends", "finally", "for", "function", "if", "import", "new", "return", "super", "switch", "this", "throw", "try", "while", "with", "implements", "interface", "package", "private", "protected", "public", "static", "yield", "as", "async", "await", "constructor", "get", "set", "from", "of", "enum", "eval", "arguments", "escaped keyword", "escaped future reserved keyword", "reserved if strict", "#", "BigIntLiteral", "??", "?.", "WhiteSpace", "Illegal", "LineTerminator", "PrivateField", "Template", "@", "target", "meta", "LineFeed", "Escaped", "JSXText"], Ye = Object.create(null, { this: { value: 86113 }, function: { value: 86106 }, if: { value: 20571 }, return: { value: 20574 }, var: { value: 86090 }, else: { value: 20565 }, for: { value: 20569 }, new: { value: 86109 }, in: { value: 8738868 }, typeof: { value: 16863277 }, while: { value: 20580 }, case: { value: 20558 }, break: { value: 20557 }, try: { value: 20579 }, catch: { value: 20559 }, delete: { value: 16863278 }, throw: { value: 86114 }, switch: { value: 86112 }, continue: { value: 20561 }, default: { value: 20563 }, instanceof: { value: 8476725 }, do: { value: 20564 }, void: { value: 16863279 }, finally: { value: 20568 }, async: { value: 209007 }, await: { value: 209008 }, class: { value: 86096 }, const: { value: 86092 }, constructor: { value: 12401 }, debugger: { value: 20562 }, export: { value: 20566 }, extends: { value: 20567 }, false: { value: 86021 }, from: { value: 12404 }, get: { value: 12402 }, implements: { value: 36966 }, import: { value: 86108 }, interface: { value: 36967 }, let: { value: 241739 }, null: { value: 86023 }, of: { value: 274549 }, package: { value: 36968 }, private: { value: 36969 }, protected: { value: 36970 }, public: { value: 36971 }, set: { value: 12403 }, static: { value: 36972 }, super: { value: 86111 }, true: { value: 86022 }, with: { value: 20581 }, yield: { value: 241773 }, enum: { value: 86134 }, eval: { value: 537079927 }, as: { value: 77934 }, arguments: { value: 537079928 }, target: { value: 143494 }, meta: { value: 143495 } });
          function Ze(e, u, i) {
            for (; H[k(e)]; )
              ;
            return e.tokenValue = e.source.slice(e.tokenPos, e.index), e.currentChar !== 92 && e.currentChar < 126 ? Ye[e.tokenValue] || 208897 : j1(e, u, 0, i);
          }
          function jt(e, u) {
            let i = Qe(e);
            return u2(i) || f(e, 4), e.tokenValue = e2(i), j1(e, u, 1, R[i] & 4);
          }
          function j1(e, u, i, n) {
            let t3 = e.index;
            for (; e.index < e.end; )
              if (e.currentChar === 92) {
                e.tokenValue += e.source.slice(t3, e.index), i = 1;
                let l = Qe(e);
                u2(l) || f(e, 4), n = n && R[l] & 4, e.tokenValue += e2(l), t3 = e.index;
              } else if (u2(e.currentChar) || W(e, e.currentChar))
                k(e);
              else
                break;
            e.index <= e.end && (e.tokenValue += e.source.slice(t3, e.index));
            let o = e.tokenValue.length;
            if (n && o >= 2 && o <= 11) {
              let l = Ye[e.tokenValue];
              return l === void 0 ? 208897 : i ? u & 1024 ? l === 209008 && !(u & 4196352) ? l : l === 36972 || (l & 36864) === 36864 ? 122 : 121 : u & 1073741824 && !(u & 8192) && (l & 20480) === 20480 ? l : l === 241773 ? u & 1073741824 ? 143483 : u & 2097152 ? 121 : l : l === 209007 && u & 1073741824 ? 143483 : (l & 36864) === 36864 || l === 209008 && !(u & 4194304) ? l : 121 : l;
            }
            return 208897;
          }
          function _t(e) {
            return O(k(e)) || f(e, 93), 131;
          }
          function Qe(e) {
            return e.source.charCodeAt(e.index + 1) !== 117 && f(e, 4), e.currentChar = e.source.charCodeAt(e.index += 2), Mt(e);
          }
          function Mt(e) {
            let u = 0, i = e.currentChar;
            if (i === 123) {
              let l = e.index - 2;
              for (; R[k(e)] & 64; )
                u = u << 4 | L(e.currentChar), u > 1114111 && q(l, e.line, e.index + 1, 101);
              return e.currentChar !== 125 && q(l, e.line, e.index - 1, 6), k(e), u;
            }
            R[i] & 64 || f(e, 6);
            let n = e.source.charCodeAt(e.index + 1);
            R[n] & 64 || f(e, 6);
            let t3 = e.source.charCodeAt(e.index + 2);
            R[t3] & 64 || f(e, 6);
            let o = e.source.charCodeAt(e.index + 3);
            return R[o] & 64 || f(e, 6), u = L(i) << 12 | L(n) << 8 | L(t3) << 4 | L(o), e.currentChar = e.source.charCodeAt(e.index += 4), u;
          }
          var Ge = [129, 129, 129, 129, 129, 129, 129, 129, 129, 128, 136, 128, 128, 130, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 129, 128, 16842800, 134283267, 131, 208897, 8457015, 8455751, 134283267, 67174411, 16, 8457014, 25233970, 18, 25233971, 67108877, 8457016, 134283266, 134283266, 134283266, 134283266, 134283266, 134283266, 134283266, 134283266, 134283266, 134283266, 21, 1074790417, 8456258, 1077936157, 8456259, 22, 133, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 208897, 69271571, 137, 20, 8455497, 208897, 132, 4096, 4096, 4096, 4096, 4096, 4096, 4096, 208897, 4096, 208897, 208897, 4096, 208897, 4096, 208897, 4096, 208897, 4096, 4096, 4096, 208897, 4096, 4096, 208897, 4096, 4096, 2162700, 8455240, 1074790415, 16842801, 129];
          function E(e, u) {
            if (e.flags = (e.flags | 1) ^ 1, e.startPos = e.index, e.startColumn = e.column, e.startLine = e.line, e.token = xe(e, u, 0), e.onToken && e.token !== 1048576) {
              let i = { start: { line: e.linePos, column: e.colPos }, end: { line: e.line, column: e.column } };
              e.onToken(Z(e.token), e.tokenPos, e.index, i);
            }
          }
          function xe(e, u, i) {
            let n = e.index === 0, t3 = e.source, o = e.index, l = e.line, c = e.column;
            for (; e.index < e.end; ) {
              e.tokenPos = e.index, e.colPos = e.column, e.linePos = e.line;
              let s = e.currentChar;
              if (s <= 126) {
                let r = Ge[s];
                switch (r) {
                  case 67174411:
                  case 16:
                  case 2162700:
                  case 1074790415:
                  case 69271571:
                  case 20:
                  case 21:
                  case 1074790417:
                  case 18:
                  case 16842801:
                  case 133:
                  case 129:
                    return k(e), r;
                  case 208897:
                    return Ze(e, u, 0);
                  case 4096:
                    return Ze(e, u, 1);
                  case 134283266:
                    return Ke(e, u, 144);
                  case 134283267:
                    return V1(e, u, s);
                  case 132:
                    return We(e, u);
                  case 137:
                    return jt(e, u);
                  case 131:
                    return _t(e);
                  case 128:
                    k(e);
                    break;
                  case 130:
                    i |= 5, z(e);
                    break;
                  case 136:
                    $2(e, i), i = i & -5 | 1;
                    break;
                  case 8456258:
                    let b = k(e);
                    if (e.index < e.end) {
                      if (b === 60)
                        return e.index < e.end && k(e) === 61 ? (k(e), 4194334) : 8456516;
                      if (b === 61)
                        return k(e), 8456256;
                      if (b === 33) {
                        let d = e.index + 1;
                        if (d + 1 < e.end && t3.charCodeAt(d) === 45 && t3.charCodeAt(d + 1) == 45) {
                          e.column += 3, e.currentChar = t3.charCodeAt(e.index += 3), i = N2(e, t3, i, u, 2, e.tokenPos, e.linePos, e.colPos), o = e.tokenPos, l = e.linePos, c = e.colPos;
                          continue;
                        }
                        return 8456258;
                      }
                      if (b === 47) {
                        if ((u & 16) < 1)
                          return 8456258;
                        let d = e.index + 1;
                        if (d < e.end && (b = t3.charCodeAt(d), b === 42 || b === 47))
                          break;
                        return k(e), 25;
                      }
                    }
                    return 8456258;
                  case 1077936157: {
                    k(e);
                    let d = e.currentChar;
                    return d === 61 ? k(e) === 61 ? (k(e), 8455996) : 8455998 : d === 62 ? (k(e), 10) : 1077936157;
                  }
                  case 16842800:
                    return k(e) !== 61 ? 16842800 : k(e) !== 61 ? 8455999 : (k(e), 8455997);
                  case 8457015:
                    return k(e) !== 61 ? 8457015 : (k(e), 4194342);
                  case 8457014: {
                    if (k(e), e.index >= e.end)
                      return 8457014;
                    let d = e.currentChar;
                    return d === 61 ? (k(e), 4194340) : d !== 42 ? 8457014 : k(e) !== 61 ? 8457273 : (k(e), 4194337);
                  }
                  case 8455497:
                    return k(e) !== 61 ? 8455497 : (k(e), 4194343);
                  case 25233970: {
                    k(e);
                    let d = e.currentChar;
                    return d === 43 ? (k(e), 33619995) : d === 61 ? (k(e), 4194338) : 25233970;
                  }
                  case 25233971: {
                    k(e);
                    let d = e.currentChar;
                    if (d === 45) {
                      if (k(e), (i & 1 || n) && e.currentChar === 62) {
                        u & 256 || f(e, 108), k(e), i = N2(e, t3, i, u, 3, o, l, c), o = e.tokenPos, l = e.linePos, c = e.colPos;
                        continue;
                      }
                      return 33619996;
                    }
                    return d === 61 ? (k(e), 4194339) : 25233971;
                  }
                  case 8457016: {
                    if (k(e), e.index < e.end) {
                      let d = e.currentChar;
                      if (d === 47) {
                        k(e), i = c2(e, t3, i, 0, e.tokenPos, e.linePos, e.colPos), o = e.tokenPos, l = e.linePos, c = e.colPos;
                        continue;
                      }
                      if (d === 42) {
                        k(e), i = V2(e, t3, i), o = e.tokenPos, l = e.linePos, c = e.colPos;
                        continue;
                      }
                      if (u & 32768)
                        return q2(e, u);
                      if (d === 61)
                        return k(e), 4259877;
                    }
                    return 8457016;
                  }
                  case 67108877:
                    let h = k(e);
                    if (h >= 48 && h <= 57)
                      return Ke(e, u, 80);
                    if (h === 46) {
                      let d = e.index + 1;
                      if (d < e.end && t3.charCodeAt(d) === 46)
                        return e.column += 2, e.currentChar = t3.charCodeAt(e.index += 2), 14;
                    }
                    return 67108877;
                  case 8455240: {
                    k(e);
                    let d = e.currentChar;
                    return d === 124 ? (k(e), e.currentChar === 61 ? (k(e), 4194346) : 8979003) : d === 61 ? (k(e), 4194344) : 8455240;
                  }
                  case 8456259: {
                    k(e);
                    let d = e.currentChar;
                    if (d === 61)
                      return k(e), 8456257;
                    if (d !== 62)
                      return 8456259;
                    if (k(e), e.index < e.end) {
                      let y = e.currentChar;
                      if (y === 62)
                        return k(e) === 61 ? (k(e), 4194336) : 8456518;
                      if (y === 61)
                        return k(e), 4194335;
                    }
                    return 8456517;
                  }
                  case 8455751: {
                    k(e);
                    let d = e.currentChar;
                    return d === 38 ? (k(e), e.currentChar === 61 ? (k(e), 4194347) : 8979258) : d === 61 ? (k(e), 4194345) : 8455751;
                  }
                  case 22: {
                    let d = k(e);
                    if (d === 63)
                      return k(e), e.currentChar === 61 ? (k(e), 4194348) : 276889982;
                    if (d === 46) {
                      let y = e.index + 1;
                      if (y < e.end && (d = t3.charCodeAt(y), !(d >= 48 && d <= 57)))
                        return k(e), 67108991;
                    }
                    return 22;
                  }
                }
              } else {
                if ((s ^ 8232) <= 1) {
                  i = i & -5 | 1, z(e);
                  continue;
                }
                if ((s & 64512) === 55296 || N[(s >>> 5) + 34816] >>> s & 31 & 1)
                  return (s & 64512) === 56320 && (s = (s & 1023) << 10 | s & 1023 | 65536, N[(s >>> 5) + 0] >>> s & 31 & 1 || f(e, 18, e2(s)), e.index++, e.currentChar = s), e.column++, e.tokenValue = "", j1(e, u, 0, 0);
                if (Q(s)) {
                  k(e);
                  continue;
                }
                f(e, 18, e2(s));
              }
            }
            return 1048576;
          }
          var Ut = { AElig: "\xC6", AMP: "&", Aacute: "\xC1", Abreve: "\u0102", Acirc: "\xC2", Acy: "\u0410", Afr: "\u{1D504}", Agrave: "\xC0", Alpha: "\u0391", Amacr: "\u0100", And: "\u2A53", Aogon: "\u0104", Aopf: "\u{1D538}", ApplyFunction: "\u2061", Aring: "\xC5", Ascr: "\u{1D49C}", Assign: "\u2254", Atilde: "\xC3", Auml: "\xC4", Backslash: "\u2216", Barv: "\u2AE7", Barwed: "\u2306", Bcy: "\u0411", Because: "\u2235", Bernoullis: "\u212C", Beta: "\u0392", Bfr: "\u{1D505}", Bopf: "\u{1D539}", Breve: "\u02D8", Bscr: "\u212C", Bumpeq: "\u224E", CHcy: "\u0427", COPY: "\xA9", Cacute: "\u0106", Cap: "\u22D2", CapitalDifferentialD: "\u2145", Cayleys: "\u212D", Ccaron: "\u010C", Ccedil: "\xC7", Ccirc: "\u0108", Cconint: "\u2230", Cdot: "\u010A", Cedilla: "\xB8", CenterDot: "\xB7", Cfr: "\u212D", Chi: "\u03A7", CircleDot: "\u2299", CircleMinus: "\u2296", CirclePlus: "\u2295", CircleTimes: "\u2297", ClockwiseContourIntegral: "\u2232", CloseCurlyDoubleQuote: "\u201D", CloseCurlyQuote: "\u2019", Colon: "\u2237", Colone: "\u2A74", Congruent: "\u2261", Conint: "\u222F", ContourIntegral: "\u222E", Copf: "\u2102", Coproduct: "\u2210", CounterClockwiseContourIntegral: "\u2233", Cross: "\u2A2F", Cscr: "\u{1D49E}", Cup: "\u22D3", CupCap: "\u224D", DD: "\u2145", DDotrahd: "\u2911", DJcy: "\u0402", DScy: "\u0405", DZcy: "\u040F", Dagger: "\u2021", Darr: "\u21A1", Dashv: "\u2AE4", Dcaron: "\u010E", Dcy: "\u0414", Del: "\u2207", Delta: "\u0394", Dfr: "\u{1D507}", DiacriticalAcute: "\xB4", DiacriticalDot: "\u02D9", DiacriticalDoubleAcute: "\u02DD", DiacriticalGrave: "`", DiacriticalTilde: "\u02DC", Diamond: "\u22C4", DifferentialD: "\u2146", Dopf: "\u{1D53B}", Dot: "\xA8", DotDot: "\u20DC", DotEqual: "\u2250", DoubleContourIntegral: "\u222F", DoubleDot: "\xA8", DoubleDownArrow: "\u21D3", DoubleLeftArrow: "\u21D0", DoubleLeftRightArrow: "\u21D4", DoubleLeftTee: "\u2AE4", DoubleLongLeftArrow: "\u27F8", DoubleLongLeftRightArrow: "\u27FA", DoubleLongRightArrow: "\u27F9", DoubleRightArrow: "\u21D2", DoubleRightTee: "\u22A8", DoubleUpArrow: "\u21D1", DoubleUpDownArrow: "\u21D5", DoubleVerticalBar: "\u2225", DownArrow: "\u2193", DownArrowBar: "\u2913", DownArrowUpArrow: "\u21F5", DownBreve: "\u0311", DownLeftRightVector: "\u2950", DownLeftTeeVector: "\u295E", DownLeftVector: "\u21BD", DownLeftVectorBar: "\u2956", DownRightTeeVector: "\u295F", DownRightVector: "\u21C1", DownRightVectorBar: "\u2957", DownTee: "\u22A4", DownTeeArrow: "\u21A7", Downarrow: "\u21D3", Dscr: "\u{1D49F}", Dstrok: "\u0110", ENG: "\u014A", ETH: "\xD0", Eacute: "\xC9", Ecaron: "\u011A", Ecirc: "\xCA", Ecy: "\u042D", Edot: "\u0116", Efr: "\u{1D508}", Egrave: "\xC8", Element: "\u2208", Emacr: "\u0112", EmptySmallSquare: "\u25FB", EmptyVerySmallSquare: "\u25AB", Eogon: "\u0118", Eopf: "\u{1D53C}", Epsilon: "\u0395", Equal: "\u2A75", EqualTilde: "\u2242", Equilibrium: "\u21CC", Escr: "\u2130", Esim: "\u2A73", Eta: "\u0397", Euml: "\xCB", Exists: "\u2203", ExponentialE: "\u2147", Fcy: "\u0424", Ffr: "\u{1D509}", FilledSmallSquare: "\u25FC", FilledVerySmallSquare: "\u25AA", Fopf: "\u{1D53D}", ForAll: "\u2200", Fouriertrf: "\u2131", Fscr: "\u2131", GJcy: "\u0403", GT: ">", Gamma: "\u0393", Gammad: "\u03DC", Gbreve: "\u011E", Gcedil: "\u0122", Gcirc: "\u011C", Gcy: "\u0413", Gdot: "\u0120", Gfr: "\u{1D50A}", Gg: "\u22D9", Gopf: "\u{1D53E}", GreaterEqual: "\u2265", GreaterEqualLess: "\u22DB", GreaterFullEqual: "\u2267", GreaterGreater: "\u2AA2", GreaterLess: "\u2277", GreaterSlantEqual: "\u2A7E", GreaterTilde: "\u2273", Gscr: "\u{1D4A2}", Gt: "\u226B", HARDcy: "\u042A", Hacek: "\u02C7", Hat: "^", Hcirc: "\u0124", Hfr: "\u210C", HilbertSpace: "\u210B", Hopf: "\u210D", HorizontalLine: "\u2500", Hscr: "\u210B", Hstrok: "\u0126", HumpDownHump: "\u224E", HumpEqual: "\u224F", IEcy: "\u0415", IJlig: "\u0132", IOcy: "\u0401", Iacute: "\xCD", Icirc: "\xCE", Icy: "\u0418", Idot: "\u0130", Ifr: "\u2111", Igrave: "\xCC", Im: "\u2111", Imacr: "\u012A", ImaginaryI: "\u2148", Implies: "\u21D2", Int: "\u222C", Integral: "\u222B", Intersection: "\u22C2", InvisibleComma: "\u2063", InvisibleTimes: "\u2062", Iogon: "\u012E", Iopf: "\u{1D540}", Iota: "\u0399", Iscr: "\u2110", Itilde: "\u0128", Iukcy: "\u0406", Iuml: "\xCF", Jcirc: "\u0134", Jcy: "\u0419", Jfr: "\u{1D50D}", Jopf: "\u{1D541}", Jscr: "\u{1D4A5}", Jsercy: "\u0408", Jukcy: "\u0404", KHcy: "\u0425", KJcy: "\u040C", Kappa: "\u039A", Kcedil: "\u0136", Kcy: "\u041A", Kfr: "\u{1D50E}", Kopf: "\u{1D542}", Kscr: "\u{1D4A6}", LJcy: "\u0409", LT: "<", Lacute: "\u0139", Lambda: "\u039B", Lang: "\u27EA", Laplacetrf: "\u2112", Larr: "\u219E", Lcaron: "\u013D", Lcedil: "\u013B", Lcy: "\u041B", LeftAngleBracket: "\u27E8", LeftArrow: "\u2190", LeftArrowBar: "\u21E4", LeftArrowRightArrow: "\u21C6", LeftCeiling: "\u2308", LeftDoubleBracket: "\u27E6", LeftDownTeeVector: "\u2961", LeftDownVector: "\u21C3", LeftDownVectorBar: "\u2959", LeftFloor: "\u230A", LeftRightArrow: "\u2194", LeftRightVector: "\u294E", LeftTee: "\u22A3", LeftTeeArrow: "\u21A4", LeftTeeVector: "\u295A", LeftTriangle: "\u22B2", LeftTriangleBar: "\u29CF", LeftTriangleEqual: "\u22B4", LeftUpDownVector: "\u2951", LeftUpTeeVector: "\u2960", LeftUpVector: "\u21BF", LeftUpVectorBar: "\u2958", LeftVector: "\u21BC", LeftVectorBar: "\u2952", Leftarrow: "\u21D0", Leftrightarrow: "\u21D4", LessEqualGreater: "\u22DA", LessFullEqual: "\u2266", LessGreater: "\u2276", LessLess: "\u2AA1", LessSlantEqual: "\u2A7D", LessTilde: "\u2272", Lfr: "\u{1D50F}", Ll: "\u22D8", Lleftarrow: "\u21DA", Lmidot: "\u013F", LongLeftArrow: "\u27F5", LongLeftRightArrow: "\u27F7", LongRightArrow: "\u27F6", Longleftarrow: "\u27F8", Longleftrightarrow: "\u27FA", Longrightarrow: "\u27F9", Lopf: "\u{1D543}", LowerLeftArrow: "\u2199", LowerRightArrow: "\u2198", Lscr: "\u2112", Lsh: "\u21B0", Lstrok: "\u0141", Lt: "\u226A", Map: "\u2905", Mcy: "\u041C", MediumSpace: "\u205F", Mellintrf: "\u2133", Mfr: "\u{1D510}", MinusPlus: "\u2213", Mopf: "\u{1D544}", Mscr: "\u2133", Mu: "\u039C", NJcy: "\u040A", Nacute: "\u0143", Ncaron: "\u0147", Ncedil: "\u0145", Ncy: "\u041D", NegativeMediumSpace: "\u200B", NegativeThickSpace: "\u200B", NegativeThinSpace: "\u200B", NegativeVeryThinSpace: "\u200B", NestedGreaterGreater: "\u226B", NestedLessLess: "\u226A", NewLine: `
`, Nfr: "\u{1D511}", NoBreak: "\u2060", NonBreakingSpace: "\xA0", Nopf: "\u2115", Not: "\u2AEC", NotCongruent: "\u2262", NotCupCap: "\u226D", NotDoubleVerticalBar: "\u2226", NotElement: "\u2209", NotEqual: "\u2260", NotEqualTilde: "\u2242\u0338", NotExists: "\u2204", NotGreater: "\u226F", NotGreaterEqual: "\u2271", NotGreaterFullEqual: "\u2267\u0338", NotGreaterGreater: "\u226B\u0338", NotGreaterLess: "\u2279", NotGreaterSlantEqual: "\u2A7E\u0338", NotGreaterTilde: "\u2275", NotHumpDownHump: "\u224E\u0338", NotHumpEqual: "\u224F\u0338", NotLeftTriangle: "\u22EA", NotLeftTriangleBar: "\u29CF\u0338", NotLeftTriangleEqual: "\u22EC", NotLess: "\u226E", NotLessEqual: "\u2270", NotLessGreater: "\u2278", NotLessLess: "\u226A\u0338", NotLessSlantEqual: "\u2A7D\u0338", NotLessTilde: "\u2274", NotNestedGreaterGreater: "\u2AA2\u0338", NotNestedLessLess: "\u2AA1\u0338", NotPrecedes: "\u2280", NotPrecedesEqual: "\u2AAF\u0338", NotPrecedesSlantEqual: "\u22E0", NotReverseElement: "\u220C", NotRightTriangle: "\u22EB", NotRightTriangleBar: "\u29D0\u0338", NotRightTriangleEqual: "\u22ED", NotSquareSubset: "\u228F\u0338", NotSquareSubsetEqual: "\u22E2", NotSquareSuperset: "\u2290\u0338", NotSquareSupersetEqual: "\u22E3", NotSubset: "\u2282\u20D2", NotSubsetEqual: "\u2288", NotSucceeds: "\u2281", NotSucceedsEqual: "\u2AB0\u0338", NotSucceedsSlantEqual: "\u22E1", NotSucceedsTilde: "\u227F\u0338", NotSuperset: "\u2283\u20D2", NotSupersetEqual: "\u2289", NotTilde: "\u2241", NotTildeEqual: "\u2244", NotTildeFullEqual: "\u2247", NotTildeTilde: "\u2249", NotVerticalBar: "\u2224", Nscr: "\u{1D4A9}", Ntilde: "\xD1", Nu: "\u039D", OElig: "\u0152", Oacute: "\xD3", Ocirc: "\xD4", Ocy: "\u041E", Odblac: "\u0150", Ofr: "\u{1D512}", Ograve: "\xD2", Omacr: "\u014C", Omega: "\u03A9", Omicron: "\u039F", Oopf: "\u{1D546}", OpenCurlyDoubleQuote: "\u201C", OpenCurlyQuote: "\u2018", Or: "\u2A54", Oscr: "\u{1D4AA}", Oslash: "\xD8", Otilde: "\xD5", Otimes: "\u2A37", Ouml: "\xD6", OverBar: "\u203E", OverBrace: "\u23DE", OverBracket: "\u23B4", OverParenthesis: "\u23DC", PartialD: "\u2202", Pcy: "\u041F", Pfr: "\u{1D513}", Phi: "\u03A6", Pi: "\u03A0", PlusMinus: "\xB1", Poincareplane: "\u210C", Popf: "\u2119", Pr: "\u2ABB", Precedes: "\u227A", PrecedesEqual: "\u2AAF", PrecedesSlantEqual: "\u227C", PrecedesTilde: "\u227E", Prime: "\u2033", Product: "\u220F", Proportion: "\u2237", Proportional: "\u221D", Pscr: "\u{1D4AB}", Psi: "\u03A8", QUOT: '"', Qfr: "\u{1D514}", Qopf: "\u211A", Qscr: "\u{1D4AC}", RBarr: "\u2910", REG: "\xAE", Racute: "\u0154", Rang: "\u27EB", Rarr: "\u21A0", Rarrtl: "\u2916", Rcaron: "\u0158", Rcedil: "\u0156", Rcy: "\u0420", Re: "\u211C", ReverseElement: "\u220B", ReverseEquilibrium: "\u21CB", ReverseUpEquilibrium: "\u296F", Rfr: "\u211C", Rho: "\u03A1", RightAngleBracket: "\u27E9", RightArrow: "\u2192", RightArrowBar: "\u21E5", RightArrowLeftArrow: "\u21C4", RightCeiling: "\u2309", RightDoubleBracket: "\u27E7", RightDownTeeVector: "\u295D", RightDownVector: "\u21C2", RightDownVectorBar: "\u2955", RightFloor: "\u230B", RightTee: "\u22A2", RightTeeArrow: "\u21A6", RightTeeVector: "\u295B", RightTriangle: "\u22B3", RightTriangleBar: "\u29D0", RightTriangleEqual: "\u22B5", RightUpDownVector: "\u294F", RightUpTeeVector: "\u295C", RightUpVector: "\u21BE", RightUpVectorBar: "\u2954", RightVector: "\u21C0", RightVectorBar: "\u2953", Rightarrow: "\u21D2", Ropf: "\u211D", RoundImplies: "\u2970", Rrightarrow: "\u21DB", Rscr: "\u211B", Rsh: "\u21B1", RuleDelayed: "\u29F4", SHCHcy: "\u0429", SHcy: "\u0428", SOFTcy: "\u042C", Sacute: "\u015A", Sc: "\u2ABC", Scaron: "\u0160", Scedil: "\u015E", Scirc: "\u015C", Scy: "\u0421", Sfr: "\u{1D516}", ShortDownArrow: "\u2193", ShortLeftArrow: "\u2190", ShortRightArrow: "\u2192", ShortUpArrow: "\u2191", Sigma: "\u03A3", SmallCircle: "\u2218", Sopf: "\u{1D54A}", Sqrt: "\u221A", Square: "\u25A1", SquareIntersection: "\u2293", SquareSubset: "\u228F", SquareSubsetEqual: "\u2291", SquareSuperset: "\u2290", SquareSupersetEqual: "\u2292", SquareUnion: "\u2294", Sscr: "\u{1D4AE}", Star: "\u22C6", Sub: "\u22D0", Subset: "\u22D0", SubsetEqual: "\u2286", Succeeds: "\u227B", SucceedsEqual: "\u2AB0", SucceedsSlantEqual: "\u227D", SucceedsTilde: "\u227F", SuchThat: "\u220B", Sum: "\u2211", Sup: "\u22D1", Superset: "\u2283", SupersetEqual: "\u2287", Supset: "\u22D1", THORN: "\xDE", TRADE: "\u2122", TSHcy: "\u040B", TScy: "\u0426", Tab: "	", Tau: "\u03A4", Tcaron: "\u0164", Tcedil: "\u0162", Tcy: "\u0422", Tfr: "\u{1D517}", Therefore: "\u2234", Theta: "\u0398", ThickSpace: "\u205F\u200A", ThinSpace: "\u2009", Tilde: "\u223C", TildeEqual: "\u2243", TildeFullEqual: "\u2245", TildeTilde: "\u2248", Topf: "\u{1D54B}", TripleDot: "\u20DB", Tscr: "\u{1D4AF}", Tstrok: "\u0166", Uacute: "\xDA", Uarr: "\u219F", Uarrocir: "\u2949", Ubrcy: "\u040E", Ubreve: "\u016C", Ucirc: "\xDB", Ucy: "\u0423", Udblac: "\u0170", Ufr: "\u{1D518}", Ugrave: "\xD9", Umacr: "\u016A", UnderBar: "_", UnderBrace: "\u23DF", UnderBracket: "\u23B5", UnderParenthesis: "\u23DD", Union: "\u22C3", UnionPlus: "\u228E", Uogon: "\u0172", Uopf: "\u{1D54C}", UpArrow: "\u2191", UpArrowBar: "\u2912", UpArrowDownArrow: "\u21C5", UpDownArrow: "\u2195", UpEquilibrium: "\u296E", UpTee: "\u22A5", UpTeeArrow: "\u21A5", Uparrow: "\u21D1", Updownarrow: "\u21D5", UpperLeftArrow: "\u2196", UpperRightArrow: "\u2197", Upsi: "\u03D2", Upsilon: "\u03A5", Uring: "\u016E", Uscr: "\u{1D4B0}", Utilde: "\u0168", Uuml: "\xDC", VDash: "\u22AB", Vbar: "\u2AEB", Vcy: "\u0412", Vdash: "\u22A9", Vdashl: "\u2AE6", Vee: "\u22C1", Verbar: "\u2016", Vert: "\u2016", VerticalBar: "\u2223", VerticalLine: "|", VerticalSeparator: "\u2758", VerticalTilde: "\u2240", VeryThinSpace: "\u200A", Vfr: "\u{1D519}", Vopf: "\u{1D54D}", Vscr: "\u{1D4B1}", Vvdash: "\u22AA", Wcirc: "\u0174", Wedge: "\u22C0", Wfr: "\u{1D51A}", Wopf: "\u{1D54E}", Wscr: "\u{1D4B2}", Xfr: "\u{1D51B}", Xi: "\u039E", Xopf: "\u{1D54F}", Xscr: "\u{1D4B3}", YAcy: "\u042F", YIcy: "\u0407", YUcy: "\u042E", Yacute: "\xDD", Ycirc: "\u0176", Ycy: "\u042B", Yfr: "\u{1D51C}", Yopf: "\u{1D550}", Yscr: "\u{1D4B4}", Yuml: "\u0178", ZHcy: "\u0416", Zacute: "\u0179", Zcaron: "\u017D", Zcy: "\u0417", Zdot: "\u017B", ZeroWidthSpace: "\u200B", Zeta: "\u0396", Zfr: "\u2128", Zopf: "\u2124", Zscr: "\u{1D4B5}", aacute: "\xE1", abreve: "\u0103", ac: "\u223E", acE: "\u223E\u0333", acd: "\u223F", acirc: "\xE2", acute: "\xB4", acy: "\u0430", aelig: "\xE6", af: "\u2061", afr: "\u{1D51E}", agrave: "\xE0", alefsym: "\u2135", aleph: "\u2135", alpha: "\u03B1", amacr: "\u0101", amalg: "\u2A3F", amp: "&", and: "\u2227", andand: "\u2A55", andd: "\u2A5C", andslope: "\u2A58", andv: "\u2A5A", ang: "\u2220", ange: "\u29A4", angle: "\u2220", angmsd: "\u2221", angmsdaa: "\u29A8", angmsdab: "\u29A9", angmsdac: "\u29AA", angmsdad: "\u29AB", angmsdae: "\u29AC", angmsdaf: "\u29AD", angmsdag: "\u29AE", angmsdah: "\u29AF", angrt: "\u221F", angrtvb: "\u22BE", angrtvbd: "\u299D", angsph: "\u2222", angst: "\xC5", angzarr: "\u237C", aogon: "\u0105", aopf: "\u{1D552}", ap: "\u2248", apE: "\u2A70", apacir: "\u2A6F", ape: "\u224A", apid: "\u224B", apos: "'", approx: "\u2248", approxeq: "\u224A", aring: "\xE5", ascr: "\u{1D4B6}", ast: "*", asymp: "\u2248", asympeq: "\u224D", atilde: "\xE3", auml: "\xE4", awconint: "\u2233", awint: "\u2A11", bNot: "\u2AED", backcong: "\u224C", backepsilon: "\u03F6", backprime: "\u2035", backsim: "\u223D", backsimeq: "\u22CD", barvee: "\u22BD", barwed: "\u2305", barwedge: "\u2305", bbrk: "\u23B5", bbrktbrk: "\u23B6", bcong: "\u224C", bcy: "\u0431", bdquo: "\u201E", becaus: "\u2235", because: "\u2235", bemptyv: "\u29B0", bepsi: "\u03F6", bernou: "\u212C", beta: "\u03B2", beth: "\u2136", between: "\u226C", bfr: "\u{1D51F}", bigcap: "\u22C2", bigcirc: "\u25EF", bigcup: "\u22C3", bigodot: "\u2A00", bigoplus: "\u2A01", bigotimes: "\u2A02", bigsqcup: "\u2A06", bigstar: "\u2605", bigtriangledown: "\u25BD", bigtriangleup: "\u25B3", biguplus: "\u2A04", bigvee: "\u22C1", bigwedge: "\u22C0", bkarow: "\u290D", blacklozenge: "\u29EB", blacksquare: "\u25AA", blacktriangle: "\u25B4", blacktriangledown: "\u25BE", blacktriangleleft: "\u25C2", blacktriangleright: "\u25B8", blank: "\u2423", blk12: "\u2592", blk14: "\u2591", blk34: "\u2593", block: "\u2588", bne: "=\u20E5", bnequiv: "\u2261\u20E5", bnot: "\u2310", bopf: "\u{1D553}", bot: "\u22A5", bottom: "\u22A5", bowtie: "\u22C8", boxDL: "\u2557", boxDR: "\u2554", boxDl: "\u2556", boxDr: "\u2553", boxH: "\u2550", boxHD: "\u2566", boxHU: "\u2569", boxHd: "\u2564", boxHu: "\u2567", boxUL: "\u255D", boxUR: "\u255A", boxUl: "\u255C", boxUr: "\u2559", boxV: "\u2551", boxVH: "\u256C", boxVL: "\u2563", boxVR: "\u2560", boxVh: "\u256B", boxVl: "\u2562", boxVr: "\u255F", boxbox: "\u29C9", boxdL: "\u2555", boxdR: "\u2552", boxdl: "\u2510", boxdr: "\u250C", boxh: "\u2500", boxhD: "\u2565", boxhU: "\u2568", boxhd: "\u252C", boxhu: "\u2534", boxminus: "\u229F", boxplus: "\u229E", boxtimes: "\u22A0", boxuL: "\u255B", boxuR: "\u2558", boxul: "\u2518", boxur: "\u2514", boxv: "\u2502", boxvH: "\u256A", boxvL: "\u2561", boxvR: "\u255E", boxvh: "\u253C", boxvl: "\u2524", boxvr: "\u251C", bprime: "\u2035", breve: "\u02D8", brvbar: "\xA6", bscr: "\u{1D4B7}", bsemi: "\u204F", bsim: "\u223D", bsime: "\u22CD", bsol: "\\", bsolb: "\u29C5", bsolhsub: "\u27C8", bull: "\u2022", bullet: "\u2022", bump: "\u224E", bumpE: "\u2AAE", bumpe: "\u224F", bumpeq: "\u224F", cacute: "\u0107", cap: "\u2229", capand: "\u2A44", capbrcup: "\u2A49", capcap: "\u2A4B", capcup: "\u2A47", capdot: "\u2A40", caps: "\u2229\uFE00", caret: "\u2041", caron: "\u02C7", ccaps: "\u2A4D", ccaron: "\u010D", ccedil: "\xE7", ccirc: "\u0109", ccups: "\u2A4C", ccupssm: "\u2A50", cdot: "\u010B", cedil: "\xB8", cemptyv: "\u29B2", cent: "\xA2", centerdot: "\xB7", cfr: "\u{1D520}", chcy: "\u0447", check: "\u2713", checkmark: "\u2713", chi: "\u03C7", cir: "\u25CB", cirE: "\u29C3", circ: "\u02C6", circeq: "\u2257", circlearrowleft: "\u21BA", circlearrowright: "\u21BB", circledR: "\xAE", circledS: "\u24C8", circledast: "\u229B", circledcirc: "\u229A", circleddash: "\u229D", cire: "\u2257", cirfnint: "\u2A10", cirmid: "\u2AEF", cirscir: "\u29C2", clubs: "\u2663", clubsuit: "\u2663", colon: ":", colone: "\u2254", coloneq: "\u2254", comma: ",", commat: "@", comp: "\u2201", compfn: "\u2218", complement: "\u2201", complexes: "\u2102", cong: "\u2245", congdot: "\u2A6D", conint: "\u222E", copf: "\u{1D554}", coprod: "\u2210", copy: "\xA9", copysr: "\u2117", crarr: "\u21B5", cross: "\u2717", cscr: "\u{1D4B8}", csub: "\u2ACF", csube: "\u2AD1", csup: "\u2AD0", csupe: "\u2AD2", ctdot: "\u22EF", cudarrl: "\u2938", cudarrr: "\u2935", cuepr: "\u22DE", cuesc: "\u22DF", cularr: "\u21B6", cularrp: "\u293D", cup: "\u222A", cupbrcap: "\u2A48", cupcap: "\u2A46", cupcup: "\u2A4A", cupdot: "\u228D", cupor: "\u2A45", cups: "\u222A\uFE00", curarr: "\u21B7", curarrm: "\u293C", curlyeqprec: "\u22DE", curlyeqsucc: "\u22DF", curlyvee: "\u22CE", curlywedge: "\u22CF", curren: "\xA4", curvearrowleft: "\u21B6", curvearrowright: "\u21B7", cuvee: "\u22CE", cuwed: "\u22CF", cwconint: "\u2232", cwint: "\u2231", cylcty: "\u232D", dArr: "\u21D3", dHar: "\u2965", dagger: "\u2020", daleth: "\u2138", darr: "\u2193", dash: "\u2010", dashv: "\u22A3", dbkarow: "\u290F", dblac: "\u02DD", dcaron: "\u010F", dcy: "\u0434", dd: "\u2146", ddagger: "\u2021", ddarr: "\u21CA", ddotseq: "\u2A77", deg: "\xB0", delta: "\u03B4", demptyv: "\u29B1", dfisht: "\u297F", dfr: "\u{1D521}", dharl: "\u21C3", dharr: "\u21C2", diam: "\u22C4", diamond: "\u22C4", diamondsuit: "\u2666", diams: "\u2666", die: "\xA8", digamma: "\u03DD", disin: "\u22F2", div: "\xF7", divide: "\xF7", divideontimes: "\u22C7", divonx: "\u22C7", djcy: "\u0452", dlcorn: "\u231E", dlcrop: "\u230D", dollar: "$", dopf: "\u{1D555}", dot: "\u02D9", doteq: "\u2250", doteqdot: "\u2251", dotminus: "\u2238", dotplus: "\u2214", dotsquare: "\u22A1", doublebarwedge: "\u2306", downarrow: "\u2193", downdownarrows: "\u21CA", downharpoonleft: "\u21C3", downharpoonright: "\u21C2", drbkarow: "\u2910", drcorn: "\u231F", drcrop: "\u230C", dscr: "\u{1D4B9}", dscy: "\u0455", dsol: "\u29F6", dstrok: "\u0111", dtdot: "\u22F1", dtri: "\u25BF", dtrif: "\u25BE", duarr: "\u21F5", duhar: "\u296F", dwangle: "\u29A6", dzcy: "\u045F", dzigrarr: "\u27FF", eDDot: "\u2A77", eDot: "\u2251", eacute: "\xE9", easter: "\u2A6E", ecaron: "\u011B", ecir: "\u2256", ecirc: "\xEA", ecolon: "\u2255", ecy: "\u044D", edot: "\u0117", ee: "\u2147", efDot: "\u2252", efr: "\u{1D522}", eg: "\u2A9A", egrave: "\xE8", egs: "\u2A96", egsdot: "\u2A98", el: "\u2A99", elinters: "\u23E7", ell: "\u2113", els: "\u2A95", elsdot: "\u2A97", emacr: "\u0113", empty: "\u2205", emptyset: "\u2205", emptyv: "\u2205", emsp13: "\u2004", emsp14: "\u2005", emsp: "\u2003", eng: "\u014B", ensp: "\u2002", eogon: "\u0119", eopf: "\u{1D556}", epar: "\u22D5", eparsl: "\u29E3", eplus: "\u2A71", epsi: "\u03B5", epsilon: "\u03B5", epsiv: "\u03F5", eqcirc: "\u2256", eqcolon: "\u2255", eqsim: "\u2242", eqslantgtr: "\u2A96", eqslantless: "\u2A95", equals: "=", equest: "\u225F", equiv: "\u2261", equivDD: "\u2A78", eqvparsl: "\u29E5", erDot: "\u2253", erarr: "\u2971", escr: "\u212F", esdot: "\u2250", esim: "\u2242", eta: "\u03B7", eth: "\xF0", euml: "\xEB", euro: "\u20AC", excl: "!", exist: "\u2203", expectation: "\u2130", exponentiale: "\u2147", fallingdotseq: "\u2252", fcy: "\u0444", female: "\u2640", ffilig: "\uFB03", fflig: "\uFB00", ffllig: "\uFB04", ffr: "\u{1D523}", filig: "\uFB01", fjlig: "fj", flat: "\u266D", fllig: "\uFB02", fltns: "\u25B1", fnof: "\u0192", fopf: "\u{1D557}", forall: "\u2200", fork: "\u22D4", forkv: "\u2AD9", fpartint: "\u2A0D", frac12: "\xBD", frac13: "\u2153", frac14: "\xBC", frac15: "\u2155", frac16: "\u2159", frac18: "\u215B", frac23: "\u2154", frac25: "\u2156", frac34: "\xBE", frac35: "\u2157", frac38: "\u215C", frac45: "\u2158", frac56: "\u215A", frac58: "\u215D", frac78: "\u215E", frasl: "\u2044", frown: "\u2322", fscr: "\u{1D4BB}", gE: "\u2267", gEl: "\u2A8C", gacute: "\u01F5", gamma: "\u03B3", gammad: "\u03DD", gap: "\u2A86", gbreve: "\u011F", gcirc: "\u011D", gcy: "\u0433", gdot: "\u0121", ge: "\u2265", gel: "\u22DB", geq: "\u2265", geqq: "\u2267", geqslant: "\u2A7E", ges: "\u2A7E", gescc: "\u2AA9", gesdot: "\u2A80", gesdoto: "\u2A82", gesdotol: "\u2A84", gesl: "\u22DB\uFE00", gesles: "\u2A94", gfr: "\u{1D524}", gg: "\u226B", ggg: "\u22D9", gimel: "\u2137", gjcy: "\u0453", gl: "\u2277", glE: "\u2A92", gla: "\u2AA5", glj: "\u2AA4", gnE: "\u2269", gnap: "\u2A8A", gnapprox: "\u2A8A", gne: "\u2A88", gneq: "\u2A88", gneqq: "\u2269", gnsim: "\u22E7", gopf: "\u{1D558}", grave: "`", gscr: "\u210A", gsim: "\u2273", gsime: "\u2A8E", gsiml: "\u2A90", gt: ">", gtcc: "\u2AA7", gtcir: "\u2A7A", gtdot: "\u22D7", gtlPar: "\u2995", gtquest: "\u2A7C", gtrapprox: "\u2A86", gtrarr: "\u2978", gtrdot: "\u22D7", gtreqless: "\u22DB", gtreqqless: "\u2A8C", gtrless: "\u2277", gtrsim: "\u2273", gvertneqq: "\u2269\uFE00", gvnE: "\u2269\uFE00", hArr: "\u21D4", hairsp: "\u200A", half: "\xBD", hamilt: "\u210B", hardcy: "\u044A", harr: "\u2194", harrcir: "\u2948", harrw: "\u21AD", hbar: "\u210F", hcirc: "\u0125", hearts: "\u2665", heartsuit: "\u2665", hellip: "\u2026", hercon: "\u22B9", hfr: "\u{1D525}", hksearow: "\u2925", hkswarow: "\u2926", hoarr: "\u21FF", homtht: "\u223B", hookleftarrow: "\u21A9", hookrightarrow: "\u21AA", hopf: "\u{1D559}", horbar: "\u2015", hscr: "\u{1D4BD}", hslash: "\u210F", hstrok: "\u0127", hybull: "\u2043", hyphen: "\u2010", iacute: "\xED", ic: "\u2063", icirc: "\xEE", icy: "\u0438", iecy: "\u0435", iexcl: "\xA1", iff: "\u21D4", ifr: "\u{1D526}", igrave: "\xEC", ii: "\u2148", iiiint: "\u2A0C", iiint: "\u222D", iinfin: "\u29DC", iiota: "\u2129", ijlig: "\u0133", imacr: "\u012B", image: "\u2111", imagline: "\u2110", imagpart: "\u2111", imath: "\u0131", imof: "\u22B7", imped: "\u01B5", in: "\u2208", incare: "\u2105", infin: "\u221E", infintie: "\u29DD", inodot: "\u0131", int: "\u222B", intcal: "\u22BA", integers: "\u2124", intercal: "\u22BA", intlarhk: "\u2A17", intprod: "\u2A3C", iocy: "\u0451", iogon: "\u012F", iopf: "\u{1D55A}", iota: "\u03B9", iprod: "\u2A3C", iquest: "\xBF", iscr: "\u{1D4BE}", isin: "\u2208", isinE: "\u22F9", isindot: "\u22F5", isins: "\u22F4", isinsv: "\u22F3", isinv: "\u2208", it: "\u2062", itilde: "\u0129", iukcy: "\u0456", iuml: "\xEF", jcirc: "\u0135", jcy: "\u0439", jfr: "\u{1D527}", jmath: "\u0237", jopf: "\u{1D55B}", jscr: "\u{1D4BF}", jsercy: "\u0458", jukcy: "\u0454", kappa: "\u03BA", kappav: "\u03F0", kcedil: "\u0137", kcy: "\u043A", kfr: "\u{1D528}", kgreen: "\u0138", khcy: "\u0445", kjcy: "\u045C", kopf: "\u{1D55C}", kscr: "\u{1D4C0}", lAarr: "\u21DA", lArr: "\u21D0", lAtail: "\u291B", lBarr: "\u290E", lE: "\u2266", lEg: "\u2A8B", lHar: "\u2962", lacute: "\u013A", laemptyv: "\u29B4", lagran: "\u2112", lambda: "\u03BB", lang: "\u27E8", langd: "\u2991", langle: "\u27E8", lap: "\u2A85", laquo: "\xAB", larr: "\u2190", larrb: "\u21E4", larrbfs: "\u291F", larrfs: "\u291D", larrhk: "\u21A9", larrlp: "\u21AB", larrpl: "\u2939", larrsim: "\u2973", larrtl: "\u21A2", lat: "\u2AAB", latail: "\u2919", late: "\u2AAD", lates: "\u2AAD\uFE00", lbarr: "\u290C", lbbrk: "\u2772", lbrace: "{", lbrack: "[", lbrke: "\u298B", lbrksld: "\u298F", lbrkslu: "\u298D", lcaron: "\u013E", lcedil: "\u013C", lceil: "\u2308", lcub: "{", lcy: "\u043B", ldca: "\u2936", ldquo: "\u201C", ldquor: "\u201E", ldrdhar: "\u2967", ldrushar: "\u294B", ldsh: "\u21B2", le: "\u2264", leftarrow: "\u2190", leftarrowtail: "\u21A2", leftharpoondown: "\u21BD", leftharpoonup: "\u21BC", leftleftarrows: "\u21C7", leftrightarrow: "\u2194", leftrightarrows: "\u21C6", leftrightharpoons: "\u21CB", leftrightsquigarrow: "\u21AD", leftthreetimes: "\u22CB", leg: "\u22DA", leq: "\u2264", leqq: "\u2266", leqslant: "\u2A7D", les: "\u2A7D", lescc: "\u2AA8", lesdot: "\u2A7F", lesdoto: "\u2A81", lesdotor: "\u2A83", lesg: "\u22DA\uFE00", lesges: "\u2A93", lessapprox: "\u2A85", lessdot: "\u22D6", lesseqgtr: "\u22DA", lesseqqgtr: "\u2A8B", lessgtr: "\u2276", lesssim: "\u2272", lfisht: "\u297C", lfloor: "\u230A", lfr: "\u{1D529}", lg: "\u2276", lgE: "\u2A91", lhard: "\u21BD", lharu: "\u21BC", lharul: "\u296A", lhblk: "\u2584", ljcy: "\u0459", ll: "\u226A", llarr: "\u21C7", llcorner: "\u231E", llhard: "\u296B", lltri: "\u25FA", lmidot: "\u0140", lmoust: "\u23B0", lmoustache: "\u23B0", lnE: "\u2268", lnap: "\u2A89", lnapprox: "\u2A89", lne: "\u2A87", lneq: "\u2A87", lneqq: "\u2268", lnsim: "\u22E6", loang: "\u27EC", loarr: "\u21FD", lobrk: "\u27E6", longleftarrow: "\u27F5", longleftrightarrow: "\u27F7", longmapsto: "\u27FC", longrightarrow: "\u27F6", looparrowleft: "\u21AB", looparrowright: "\u21AC", lopar: "\u2985", lopf: "\u{1D55D}", loplus: "\u2A2D", lotimes: "\u2A34", lowast: "\u2217", lowbar: "_", loz: "\u25CA", lozenge: "\u25CA", lozf: "\u29EB", lpar: "(", lparlt: "\u2993", lrarr: "\u21C6", lrcorner: "\u231F", lrhar: "\u21CB", lrhard: "\u296D", lrm: "\u200E", lrtri: "\u22BF", lsaquo: "\u2039", lscr: "\u{1D4C1}", lsh: "\u21B0", lsim: "\u2272", lsime: "\u2A8D", lsimg: "\u2A8F", lsqb: "[", lsquo: "\u2018", lsquor: "\u201A", lstrok: "\u0142", lt: "<", ltcc: "\u2AA6", ltcir: "\u2A79", ltdot: "\u22D6", lthree: "\u22CB", ltimes: "\u22C9", ltlarr: "\u2976", ltquest: "\u2A7B", ltrPar: "\u2996", ltri: "\u25C3", ltrie: "\u22B4", ltrif: "\u25C2", lurdshar: "\u294A", luruhar: "\u2966", lvertneqq: "\u2268\uFE00", lvnE: "\u2268\uFE00", mDDot: "\u223A", macr: "\xAF", male: "\u2642", malt: "\u2720", maltese: "\u2720", map: "\u21A6", mapsto: "\u21A6", mapstodown: "\u21A7", mapstoleft: "\u21A4", mapstoup: "\u21A5", marker: "\u25AE", mcomma: "\u2A29", mcy: "\u043C", mdash: "\u2014", measuredangle: "\u2221", mfr: "\u{1D52A}", mho: "\u2127", micro: "\xB5", mid: "\u2223", midast: "*", midcir: "\u2AF0", middot: "\xB7", minus: "\u2212", minusb: "\u229F", minusd: "\u2238", minusdu: "\u2A2A", mlcp: "\u2ADB", mldr: "\u2026", mnplus: "\u2213", models: "\u22A7", mopf: "\u{1D55E}", mp: "\u2213", mscr: "\u{1D4C2}", mstpos: "\u223E", mu: "\u03BC", multimap: "\u22B8", mumap: "\u22B8", nGg: "\u22D9\u0338", nGt: "\u226B\u20D2", nGtv: "\u226B\u0338", nLeftarrow: "\u21CD", nLeftrightarrow: "\u21CE", nLl: "\u22D8\u0338", nLt: "\u226A\u20D2", nLtv: "\u226A\u0338", nRightarrow: "\u21CF", nVDash: "\u22AF", nVdash: "\u22AE", nabla: "\u2207", nacute: "\u0144", nang: "\u2220\u20D2", nap: "\u2249", napE: "\u2A70\u0338", napid: "\u224B\u0338", napos: "\u0149", napprox: "\u2249", natur: "\u266E", natural: "\u266E", naturals: "\u2115", nbsp: "\xA0", nbump: "\u224E\u0338", nbumpe: "\u224F\u0338", ncap: "\u2A43", ncaron: "\u0148", ncedil: "\u0146", ncong: "\u2247", ncongdot: "\u2A6D\u0338", ncup: "\u2A42", ncy: "\u043D", ndash: "\u2013", ne: "\u2260", neArr: "\u21D7", nearhk: "\u2924", nearr: "\u2197", nearrow: "\u2197", nedot: "\u2250\u0338", nequiv: "\u2262", nesear: "\u2928", nesim: "\u2242\u0338", nexist: "\u2204", nexists: "\u2204", nfr: "\u{1D52B}", ngE: "\u2267\u0338", nge: "\u2271", ngeq: "\u2271", ngeqq: "\u2267\u0338", ngeqslant: "\u2A7E\u0338", nges: "\u2A7E\u0338", ngsim: "\u2275", ngt: "\u226F", ngtr: "\u226F", nhArr: "\u21CE", nharr: "\u21AE", nhpar: "\u2AF2", ni: "\u220B", nis: "\u22FC", nisd: "\u22FA", niv: "\u220B", njcy: "\u045A", nlArr: "\u21CD", nlE: "\u2266\u0338", nlarr: "\u219A", nldr: "\u2025", nle: "\u2270", nleftarrow: "\u219A", nleftrightarrow: "\u21AE", nleq: "\u2270", nleqq: "\u2266\u0338", nleqslant: "\u2A7D\u0338", nles: "\u2A7D\u0338", nless: "\u226E", nlsim: "\u2274", nlt: "\u226E", nltri: "\u22EA", nltrie: "\u22EC", nmid: "\u2224", nopf: "\u{1D55F}", not: "\xAC", notin: "\u2209", notinE: "\u22F9\u0338", notindot: "\u22F5\u0338", notinva: "\u2209", notinvb: "\u22F7", notinvc: "\u22F6", notni: "\u220C", notniva: "\u220C", notnivb: "\u22FE", notnivc: "\u22FD", npar: "\u2226", nparallel: "\u2226", nparsl: "\u2AFD\u20E5", npart: "\u2202\u0338", npolint: "\u2A14", npr: "\u2280", nprcue: "\u22E0", npre: "\u2AAF\u0338", nprec: "\u2280", npreceq: "\u2AAF\u0338", nrArr: "\u21CF", nrarr: "\u219B", nrarrc: "\u2933\u0338", nrarrw: "\u219D\u0338", nrightarrow: "\u219B", nrtri: "\u22EB", nrtrie: "\u22ED", nsc: "\u2281", nsccue: "\u22E1", nsce: "\u2AB0\u0338", nscr: "\u{1D4C3}", nshortmid: "\u2224", nshortparallel: "\u2226", nsim: "\u2241", nsime: "\u2244", nsimeq: "\u2244", nsmid: "\u2224", nspar: "\u2226", nsqsube: "\u22E2", nsqsupe: "\u22E3", nsub: "\u2284", nsubE: "\u2AC5\u0338", nsube: "\u2288", nsubset: "\u2282\u20D2", nsubseteq: "\u2288", nsubseteqq: "\u2AC5\u0338", nsucc: "\u2281", nsucceq: "\u2AB0\u0338", nsup: "\u2285", nsupE: "\u2AC6\u0338", nsupe: "\u2289", nsupset: "\u2283\u20D2", nsupseteq: "\u2289", nsupseteqq: "\u2AC6\u0338", ntgl: "\u2279", ntilde: "\xF1", ntlg: "\u2278", ntriangleleft: "\u22EA", ntrianglelefteq: "\u22EC", ntriangleright: "\u22EB", ntrianglerighteq: "\u22ED", nu: "\u03BD", num: "#", numero: "\u2116", numsp: "\u2007", nvDash: "\u22AD", nvHarr: "\u2904", nvap: "\u224D\u20D2", nvdash: "\u22AC", nvge: "\u2265\u20D2", nvgt: ">\u20D2", nvinfin: "\u29DE", nvlArr: "\u2902", nvle: "\u2264\u20D2", nvlt: "<\u20D2", nvltrie: "\u22B4\u20D2", nvrArr: "\u2903", nvrtrie: "\u22B5\u20D2", nvsim: "\u223C\u20D2", nwArr: "\u21D6", nwarhk: "\u2923", nwarr: "\u2196", nwarrow: "\u2196", nwnear: "\u2927", oS: "\u24C8", oacute: "\xF3", oast: "\u229B", ocir: "\u229A", ocirc: "\xF4", ocy: "\u043E", odash: "\u229D", odblac: "\u0151", odiv: "\u2A38", odot: "\u2299", odsold: "\u29BC", oelig: "\u0153", ofcir: "\u29BF", ofr: "\u{1D52C}", ogon: "\u02DB", ograve: "\xF2", ogt: "\u29C1", ohbar: "\u29B5", ohm: "\u03A9", oint: "\u222E", olarr: "\u21BA", olcir: "\u29BE", olcross: "\u29BB", oline: "\u203E", olt: "\u29C0", omacr: "\u014D", omega: "\u03C9", omicron: "\u03BF", omid: "\u29B6", ominus: "\u2296", oopf: "\u{1D560}", opar: "\u29B7", operp: "\u29B9", oplus: "\u2295", or: "\u2228", orarr: "\u21BB", ord: "\u2A5D", order: "\u2134", orderof: "\u2134", ordf: "\xAA", ordm: "\xBA", origof: "\u22B6", oror: "\u2A56", orslope: "\u2A57", orv: "\u2A5B", oscr: "\u2134", oslash: "\xF8", osol: "\u2298", otilde: "\xF5", otimes: "\u2297", otimesas: "\u2A36", ouml: "\xF6", ovbar: "\u233D", par: "\u2225", para: "\xB6", parallel: "\u2225", parsim: "\u2AF3", parsl: "\u2AFD", part: "\u2202", pcy: "\u043F", percnt: "%", period: ".", permil: "\u2030", perp: "\u22A5", pertenk: "\u2031", pfr: "\u{1D52D}", phi: "\u03C6", phiv: "\u03D5", phmmat: "\u2133", phone: "\u260E", pi: "\u03C0", pitchfork: "\u22D4", piv: "\u03D6", planck: "\u210F", planckh: "\u210E", plankv: "\u210F", plus: "+", plusacir: "\u2A23", plusb: "\u229E", pluscir: "\u2A22", plusdo: "\u2214", plusdu: "\u2A25", pluse: "\u2A72", plusmn: "\xB1", plussim: "\u2A26", plustwo: "\u2A27", pm: "\xB1", pointint: "\u2A15", popf: "\u{1D561}", pound: "\xA3", pr: "\u227A", prE: "\u2AB3", prap: "\u2AB7", prcue: "\u227C", pre: "\u2AAF", prec: "\u227A", precapprox: "\u2AB7", preccurlyeq: "\u227C", preceq: "\u2AAF", precnapprox: "\u2AB9", precneqq: "\u2AB5", precnsim: "\u22E8", precsim: "\u227E", prime: "\u2032", primes: "\u2119", prnE: "\u2AB5", prnap: "\u2AB9", prnsim: "\u22E8", prod: "\u220F", profalar: "\u232E", profline: "\u2312", profsurf: "\u2313", prop: "\u221D", propto: "\u221D", prsim: "\u227E", prurel: "\u22B0", pscr: "\u{1D4C5}", psi: "\u03C8", puncsp: "\u2008", qfr: "\u{1D52E}", qint: "\u2A0C", qopf: "\u{1D562}", qprime: "\u2057", qscr: "\u{1D4C6}", quaternions: "\u210D", quatint: "\u2A16", quest: "?", questeq: "\u225F", quot: '"', rAarr: "\u21DB", rArr: "\u21D2", rAtail: "\u291C", rBarr: "\u290F", rHar: "\u2964", race: "\u223D\u0331", racute: "\u0155", radic: "\u221A", raemptyv: "\u29B3", rang: "\u27E9", rangd: "\u2992", range: "\u29A5", rangle: "\u27E9", raquo: "\xBB", rarr: "\u2192", rarrap: "\u2975", rarrb: "\u21E5", rarrbfs: "\u2920", rarrc: "\u2933", rarrfs: "\u291E", rarrhk: "\u21AA", rarrlp: "\u21AC", rarrpl: "\u2945", rarrsim: "\u2974", rarrtl: "\u21A3", rarrw: "\u219D", ratail: "\u291A", ratio: "\u2236", rationals: "\u211A", rbarr: "\u290D", rbbrk: "\u2773", rbrace: "}", rbrack: "]", rbrke: "\u298C", rbrksld: "\u298E", rbrkslu: "\u2990", rcaron: "\u0159", rcedil: "\u0157", rceil: "\u2309", rcub: "}", rcy: "\u0440", rdca: "\u2937", rdldhar: "\u2969", rdquo: "\u201D", rdquor: "\u201D", rdsh: "\u21B3", real: "\u211C", realine: "\u211B", realpart: "\u211C", reals: "\u211D", rect: "\u25AD", reg: "\xAE", rfisht: "\u297D", rfloor: "\u230B", rfr: "\u{1D52F}", rhard: "\u21C1", rharu: "\u21C0", rharul: "\u296C", rho: "\u03C1", rhov: "\u03F1", rightarrow: "\u2192", rightarrowtail: "\u21A3", rightharpoondown: "\u21C1", rightharpoonup: "\u21C0", rightleftarrows: "\u21C4", rightleftharpoons: "\u21CC", rightrightarrows: "\u21C9", rightsquigarrow: "\u219D", rightthreetimes: "\u22CC", ring: "\u02DA", risingdotseq: "\u2253", rlarr: "\u21C4", rlhar: "\u21CC", rlm: "\u200F", rmoust: "\u23B1", rmoustache: "\u23B1", rnmid: "\u2AEE", roang: "\u27ED", roarr: "\u21FE", robrk: "\u27E7", ropar: "\u2986", ropf: "\u{1D563}", roplus: "\u2A2E", rotimes: "\u2A35", rpar: ")", rpargt: "\u2994", rppolint: "\u2A12", rrarr: "\u21C9", rsaquo: "\u203A", rscr: "\u{1D4C7}", rsh: "\u21B1", rsqb: "]", rsquo: "\u2019", rsquor: "\u2019", rthree: "\u22CC", rtimes: "\u22CA", rtri: "\u25B9", rtrie: "\u22B5", rtrif: "\u25B8", rtriltri: "\u29CE", ruluhar: "\u2968", rx: "\u211E", sacute: "\u015B", sbquo: "\u201A", sc: "\u227B", scE: "\u2AB4", scap: "\u2AB8", scaron: "\u0161", sccue: "\u227D", sce: "\u2AB0", scedil: "\u015F", scirc: "\u015D", scnE: "\u2AB6", scnap: "\u2ABA", scnsim: "\u22E9", scpolint: "\u2A13", scsim: "\u227F", scy: "\u0441", sdot: "\u22C5", sdotb: "\u22A1", sdote: "\u2A66", seArr: "\u21D8", searhk: "\u2925", searr: "\u2198", searrow: "\u2198", sect: "\xA7", semi: ";", seswar: "\u2929", setminus: "\u2216", setmn: "\u2216", sext: "\u2736", sfr: "\u{1D530}", sfrown: "\u2322", sharp: "\u266F", shchcy: "\u0449", shcy: "\u0448", shortmid: "\u2223", shortparallel: "\u2225", shy: "\xAD", sigma: "\u03C3", sigmaf: "\u03C2", sigmav: "\u03C2", sim: "\u223C", simdot: "\u2A6A", sime: "\u2243", simeq: "\u2243", simg: "\u2A9E", simgE: "\u2AA0", siml: "\u2A9D", simlE: "\u2A9F", simne: "\u2246", simplus: "\u2A24", simrarr: "\u2972", slarr: "\u2190", smallsetminus: "\u2216", smashp: "\u2A33", smeparsl: "\u29E4", smid: "\u2223", smile: "\u2323", smt: "\u2AAA", smte: "\u2AAC", smtes: "\u2AAC\uFE00", softcy: "\u044C", sol: "/", solb: "\u29C4", solbar: "\u233F", sopf: "\u{1D564}", spades: "\u2660", spadesuit: "\u2660", spar: "\u2225", sqcap: "\u2293", sqcaps: "\u2293\uFE00", sqcup: "\u2294", sqcups: "\u2294\uFE00", sqsub: "\u228F", sqsube: "\u2291", sqsubset: "\u228F", sqsubseteq: "\u2291", sqsup: "\u2290", sqsupe: "\u2292", sqsupset: "\u2290", sqsupseteq: "\u2292", squ: "\u25A1", square: "\u25A1", squarf: "\u25AA", squf: "\u25AA", srarr: "\u2192", sscr: "\u{1D4C8}", ssetmn: "\u2216", ssmile: "\u2323", sstarf: "\u22C6", star: "\u2606", starf: "\u2605", straightepsilon: "\u03F5", straightphi: "\u03D5", strns: "\xAF", sub: "\u2282", subE: "\u2AC5", subdot: "\u2ABD", sube: "\u2286", subedot: "\u2AC3", submult: "\u2AC1", subnE: "\u2ACB", subne: "\u228A", subplus: "\u2ABF", subrarr: "\u2979", subset: "\u2282", subseteq: "\u2286", subseteqq: "\u2AC5", subsetneq: "\u228A", subsetneqq: "\u2ACB", subsim: "\u2AC7", subsub: "\u2AD5", subsup: "\u2AD3", succ: "\u227B", succapprox: "\u2AB8", succcurlyeq: "\u227D", succeq: "\u2AB0", succnapprox: "\u2ABA", succneqq: "\u2AB6", succnsim: "\u22E9", succsim: "\u227F", sum: "\u2211", sung: "\u266A", sup1: "\xB9", sup2: "\xB2", sup3: "\xB3", sup: "\u2283", supE: "\u2AC6", supdot: "\u2ABE", supdsub: "\u2AD8", supe: "\u2287", supedot: "\u2AC4", suphsol: "\u27C9", suphsub: "\u2AD7", suplarr: "\u297B", supmult: "\u2AC2", supnE: "\u2ACC", supne: "\u228B", supplus: "\u2AC0", supset: "\u2283", supseteq: "\u2287", supseteqq: "\u2AC6", supsetneq: "\u228B", supsetneqq: "\u2ACC", supsim: "\u2AC8", supsub: "\u2AD4", supsup: "\u2AD6", swArr: "\u21D9", swarhk: "\u2926", swarr: "\u2199", swarrow: "\u2199", swnwar: "\u292A", szlig: "\xDF", target: "\u2316", tau: "\u03C4", tbrk: "\u23B4", tcaron: "\u0165", tcedil: "\u0163", tcy: "\u0442", tdot: "\u20DB", telrec: "\u2315", tfr: "\u{1D531}", there4: "\u2234", therefore: "\u2234", theta: "\u03B8", thetasym: "\u03D1", thetav: "\u03D1", thickapprox: "\u2248", thicksim: "\u223C", thinsp: "\u2009", thkap: "\u2248", thksim: "\u223C", thorn: "\xFE", tilde: "\u02DC", times: "\xD7", timesb: "\u22A0", timesbar: "\u2A31", timesd: "\u2A30", tint: "\u222D", toea: "\u2928", top: "\u22A4", topbot: "\u2336", topcir: "\u2AF1", topf: "\u{1D565}", topfork: "\u2ADA", tosa: "\u2929", tprime: "\u2034", trade: "\u2122", triangle: "\u25B5", triangledown: "\u25BF", triangleleft: "\u25C3", trianglelefteq: "\u22B4", triangleq: "\u225C", triangleright: "\u25B9", trianglerighteq: "\u22B5", tridot: "\u25EC", trie: "\u225C", triminus: "\u2A3A", triplus: "\u2A39", trisb: "\u29CD", tritime: "\u2A3B", trpezium: "\u23E2", tscr: "\u{1D4C9}", tscy: "\u0446", tshcy: "\u045B", tstrok: "\u0167", twixt: "\u226C", twoheadleftarrow: "\u219E", twoheadrightarrow: "\u21A0", uArr: "\u21D1", uHar: "\u2963", uacute: "\xFA", uarr: "\u2191", ubrcy: "\u045E", ubreve: "\u016D", ucirc: "\xFB", ucy: "\u0443", udarr: "\u21C5", udblac: "\u0171", udhar: "\u296E", ufisht: "\u297E", ufr: "\u{1D532}", ugrave: "\xF9", uharl: "\u21BF", uharr: "\u21BE", uhblk: "\u2580", ulcorn: "\u231C", ulcorner: "\u231C", ulcrop: "\u230F", ultri: "\u25F8", umacr: "\u016B", uml: "\xA8", uogon: "\u0173", uopf: "\u{1D566}", uparrow: "\u2191", updownarrow: "\u2195", upharpoonleft: "\u21BF", upharpoonright: "\u21BE", uplus: "\u228E", upsi: "\u03C5", upsih: "\u03D2", upsilon: "\u03C5", upuparrows: "\u21C8", urcorn: "\u231D", urcorner: "\u231D", urcrop: "\u230E", uring: "\u016F", urtri: "\u25F9", uscr: "\u{1D4CA}", utdot: "\u22F0", utilde: "\u0169", utri: "\u25B5", utrif: "\u25B4", uuarr: "\u21C8", uuml: "\xFC", uwangle: "\u29A7", vArr: "\u21D5", vBar: "\u2AE8", vBarv: "\u2AE9", vDash: "\u22A8", vangrt: "\u299C", varepsilon: "\u03F5", varkappa: "\u03F0", varnothing: "\u2205", varphi: "\u03D5", varpi: "\u03D6", varpropto: "\u221D", varr: "\u2195", varrho: "\u03F1", varsigma: "\u03C2", varsubsetneq: "\u228A\uFE00", varsubsetneqq: "\u2ACB\uFE00", varsupsetneq: "\u228B\uFE00", varsupsetneqq: "\u2ACC\uFE00", vartheta: "\u03D1", vartriangleleft: "\u22B2", vartriangleright: "\u22B3", vcy: "\u0432", vdash: "\u22A2", vee: "\u2228", veebar: "\u22BB", veeeq: "\u225A", vellip: "\u22EE", verbar: "|", vert: "|", vfr: "\u{1D533}", vltri: "\u22B2", vnsub: "\u2282\u20D2", vnsup: "\u2283\u20D2", vopf: "\u{1D567}", vprop: "\u221D", vrtri: "\u22B3", vscr: "\u{1D4CB}", vsubnE: "\u2ACB\uFE00", vsubne: "\u228A\uFE00", vsupnE: "\u2ACC\uFE00", vsupne: "\u228B\uFE00", vzigzag: "\u299A", wcirc: "\u0175", wedbar: "\u2A5F", wedge: "\u2227", wedgeq: "\u2259", weierp: "\u2118", wfr: "\u{1D534}", wopf: "\u{1D568}", wp: "\u2118", wr: "\u2240", wreath: "\u2240", wscr: "\u{1D4CC}", xcap: "\u22C2", xcirc: "\u25EF", xcup: "\u22C3", xdtri: "\u25BD", xfr: "\u{1D535}", xhArr: "\u27FA", xharr: "\u27F7", xi: "\u03BE", xlArr: "\u27F8", xlarr: "\u27F5", xmap: "\u27FC", xnis: "\u22FB", xodot: "\u2A00", xopf: "\u{1D569}", xoplus: "\u2A01", xotime: "\u2A02", xrArr: "\u27F9", xrarr: "\u27F6", xscr: "\u{1D4CD}", xsqcup: "\u2A06", xuplus: "\u2A04", xutri: "\u25B3", xvee: "\u22C1", xwedge: "\u22C0", yacute: "\xFD", yacy: "\u044F", ycirc: "\u0177", ycy: "\u044B", yen: "\xA5", yfr: "\u{1D536}", yicy: "\u0457", yopf: "\u{1D56A}", yscr: "\u{1D4CE}", yucy: "\u044E", yuml: "\xFF", zacute: "\u017A", zcaron: "\u017E", zcy: "\u0437", zdot: "\u017C", zeetrf: "\u2128", zeta: "\u03B6", zfr: "\u{1D537}", zhcy: "\u0436", zigrarr: "\u21DD", zopf: "\u{1D56B}", zscr: "\u{1D4CF}", zwj: "\u200D", zwnj: "\u200C" }, pe = { 0: 65533, 128: 8364, 130: 8218, 131: 402, 132: 8222, 133: 8230, 134: 8224, 135: 8225, 136: 710, 137: 8240, 138: 352, 139: 8249, 140: 338, 142: 381, 145: 8216, 146: 8217, 147: 8220, 148: 8221, 149: 8226, 150: 8211, 151: 8212, 152: 732, 153: 8482, 154: 353, 155: 8250, 156: 339, 158: 382, 159: 376 };
          function Jt(e) {
            return e.replace(/&(?:[a-zA-Z]+|#[xX][\da-fA-F]+|#\d+);/g, (u) => {
              if (u.charAt(1) === "#") {
                let i = u.charAt(2), n = i === "X" || i === "x" ? parseInt(u.slice(3), 16) : parseInt(u.slice(2), 10);
                return $t(n);
              }
              return Ut[u.slice(1, -1)] || u;
            });
          }
          function $t(e) {
            return e >= 55296 && e <= 57343 || e > 1114111 ? "\uFFFD" : (e in pe && (e = pe[e]), String.fromCodePoint(e));
          }
          function Ht(e, u) {
            return e.startPos = e.tokenPos = e.index, e.startColumn = e.colPos = e.column, e.startLine = e.linePos = e.line, e.token = R[e.currentChar] & 8192 ? Xt(e, u) : xe(e, u, 0), e.token;
          }
          function Xt(e, u) {
            let i = e.currentChar, n = k(e), t3 = e.index;
            for (; n !== i; )
              e.index >= e.end && f(e, 14), n = k(e);
            return n !== i && f(e, 14), e.tokenValue = e.source.slice(t3, e.index), k(e), u & 512 && (e.tokenRaw = e.source.slice(e.tokenPos, e.index)), 134283267;
          }
          function j2(e, u) {
            if (e.startPos = e.tokenPos = e.index, e.startColumn = e.colPos = e.column, e.startLine = e.linePos = e.line, e.index >= e.end)
              return e.token = 1048576;
            switch (Ge[e.source.charCodeAt(e.index)]) {
              case 8456258: {
                k(e), e.currentChar === 47 ? (k(e), e.token = 25) : e.token = 8456258;
                break;
              }
              case 2162700: {
                k(e), e.token = 2162700;
                break;
              }
              default: {
                let n = 0;
                for (; e.index < e.end; ) {
                  let o = R[e.source.charCodeAt(e.index)];
                  if (o & 1024 ? (n |= 5, z(e)) : o & 2048 ? ($2(e, n), n = n & -5 | 1) : k(e), R[e.currentChar] & 16384)
                    break;
                }
                let t3 = e.source.slice(e.tokenPos, e.index);
                u & 512 && (e.tokenRaw = t3), e.tokenValue = Jt(t3), e.token = 138;
              }
            }
            return e.token;
          }
          function _1(e) {
            if ((e.token & 143360) === 143360) {
              let { index: u } = e, i = e.currentChar;
              for (; R[i] & 32770; )
                i = k(e);
              e.tokenValue += e.source.slice(u, e.index);
            }
            return e.token = 208897, e.token;
          }
          function a2(e, u, i) {
            !(e.flags & 1) && (e.token & 1048576) !== 1048576 && !i && f(e, 28, x[e.token & 255]), J(e, u, 1074790417);
          }
          function eu(e, u, i, n) {
            return u - i < 13 && n === "use strict" && ((e.token & 1048576) === 1048576 || e.flags & 1) ? 1 : 0;
          }
          function M1(e, u, i) {
            return e.token !== i ? 0 : (E(e, u), 1);
          }
          function J(e, u, i) {
            return e.token !== i ? false : (E(e, u), true);
          }
          function w(e, u, i) {
            e.token !== i && f(e, 23, x[i & 255]), E(e, u);
          }
          function v2(e, u) {
            switch (u.type) {
              case "ArrayExpression":
                u.type = "ArrayPattern";
                let i = u.elements;
                for (let t3 = 0, o = i.length; t3 < o; ++t3) {
                  let l = i[t3];
                  l && v2(e, l);
                }
                return;
              case "ObjectExpression":
                u.type = "ObjectPattern";
                let n = u.properties;
                for (let t3 = 0, o = n.length; t3 < o; ++t3)
                  v2(e, n[t3]);
                return;
              case "AssignmentExpression":
                u.type = "AssignmentPattern", u.operator !== "=" && f(e, 68), delete u.operator, v2(e, u.left);
                return;
              case "Property":
                v2(e, u.value);
                return;
              case "SpreadElement":
                u.type = "RestElement", v2(e, u.argument);
            }
          }
          function l1(e, u, i, n, t3) {
            u & 1024 && ((n & 36864) === 36864 && f(e, 114), !t3 && (n & 537079808) === 537079808 && f(e, 115)), (n & 20480) === 20480 && f(e, 99), i & 24 && n === 241739 && f(e, 97), u & 4196352 && n === 209008 && f(e, 95), u & 2098176 && n === 241773 && f(e, 94, "yield");
          }
          function uu(e, u, i) {
            u & 1024 && ((i & 36864) === 36864 && f(e, 114), (i & 537079808) === 537079808 && f(e, 115), i === 122 && f(e, 92), i === 121 && f(e, 92)), (i & 20480) === 20480 && f(e, 99), u & 4196352 && i === 209008 && f(e, 95), u & 2098176 && i === 241773 && f(e, 94, "yield");
          }
          function iu(e, u, i) {
            return i === 209008 && (u & 4196352 && f(e, 95), e.destructible |= 128), i === 241773 && u & 2097152 && f(e, 94, "yield"), (i & 20480) === 20480 || (i & 36864) === 36864 || i == 122;
          }
          function zt(e) {
            return e.property ? e.property.type === "PrivateIdentifier" : false;
          }
          function nu(e, u, i, n) {
            for (; u; ) {
              if (u["$" + i])
                return n && f(e, 133), 1;
              n && u.loop && (n = 0), u = u.$;
            }
            return 0;
          }
          function Wt(e, u, i) {
            let n = u;
            for (; n; )
              n["$" + i] && f(e, 132, i), n = n.$;
            u["$" + i] = 1;
          }
          function v(e, u, i, n, t3, o) {
            return u & 2 && (o.start = i, o.end = e.startPos, o.range = [i, e.startPos]), u & 4 && (o.loc = { start: { line: n, column: t3 }, end: { line: e.startLine, column: e.startColumn } }, e.sourceFile && (o.loc.source = e.sourceFile)), o;
          }
          function f1(e) {
            switch (e.type) {
              case "JSXIdentifier":
                return e.name;
              case "JSXNamespacedName":
                return e.namespace + ":" + e.name;
              case "JSXMemberExpression":
                return f1(e.object) + "." + f1(e.property);
            }
          }
          function c1(e, u, i) {
            let n = t22(_2(), 1024);
            return L2(e, u, n, i, 1, 0), n;
          }
          function U1(e, u) {
            let { index: i, line: n, column: t3 } = e;
            for (var o = arguments.length, l = new Array(o > 2 ? o - 2 : 0), c = 2; c < o; c++)
              l[c - 2] = arguments[c];
            return { type: u, params: l, index: i, line: n, column: t3 };
          }
          function _2() {
            return { parent: void 0, type: 2 };
          }
          function t22(e, u) {
            return { parent: e, type: u, scopeError: void 0 };
          }
          function B2(e, u, i, n, t3, o) {
            t3 & 4 ? tu(e, u, i, n, t3) : L2(e, u, i, n, t3, o), o & 64 && M2(e, n);
          }
          function L2(e, u, i, n, t3, o) {
            let l = i["#" + n];
            l && !(l & 2) && (t3 & 1 ? i.scopeError = U1(e, 140, n) : u & 256 && l & 64 && o & 2 || f(e, 140, n)), i.type & 128 && i.parent["#" + n] && !(i.parent["#" + n] & 2) && f(e, 140, n), i.type & 1024 && l && !(l & 2) && t3 & 1 && (i.scopeError = U1(e, 140, n)), i.type & 64 && i.parent["#" + n] & 768 && f(e, 153, n), i["#" + n] = t3;
          }
          function tu(e, u, i, n, t3) {
            let o = i;
            for (; o && !(o.type & 256); ) {
              let l = o["#" + n];
              l & 248 && (u & 256 && !(u & 1024) && (t3 & 128 && l & 68 || l & 128 && t3 & 68) || f(e, 140, n)), o === i && l & 1 && t3 & 1 && (o.scopeError = U1(e, 140, n)), l & 768 && (!(l & 512) || !(u & 256) || u & 1024) && f(e, 140, n), o["#" + n] = t3, o = o.parent;
            }
          }
          function M2(e, u) {
            e.exportedNames !== void 0 && u !== "" && (e.exportedNames["#" + u] && f(e, 141, u), e.exportedNames["#" + u] = 1);
          }
          function Kt(e, u) {
            e.exportedBindings !== void 0 && u !== "" && (e.exportedBindings["#" + u] = 1);
          }
          function Yt(e, u) {
            return function(i, n, t3, o, l) {
              let c = { type: i, value: n };
              e & 2 && (c.start = t3, c.end = o, c.range = [t3, o]), e & 4 && (c.loc = l), u.push(c);
            };
          }
          function Zt(e, u) {
            return function(i, n, t3, o) {
              let l = { token: i };
              e & 2 && (l.start = n, l.end = t3, l.range = [n, t3]), e & 4 && (l.loc = o), u.push(l);
            };
          }
          function J1(e, u) {
            return e & 2098176 ? e & 2048 && u === 209008 || e & 2097152 && u === 241773 ? false : (u & 143360) === 143360 || (u & 12288) === 12288 : (u & 143360) === 143360 || (u & 12288) === 12288 || (u & 36864) === 36864;
          }
          function $1(e, u, i, n) {
            (i & 537079808) === 537079808 && (u & 1024 && f(e, 115), n && (e.flags |= 512)), J1(u, i) || f(e, 0);
          }
          function Qt(e, u, i, n) {
            return { source: e, flags: 0, index: 0, line: 1, column: 0, startPos: 0, end: e.length, tokenPos: 0, startColumn: 0, colPos: 0, linePos: 1, startLine: 1, sourceFile: u, tokenValue: "", token: 1048576, tokenRaw: "", tokenRegExp: void 0, currentChar: e.charCodeAt(0), exportedNames: [], exportedBindings: [], assignable: 1, destructible: 0, onComment: i, onToken: n, leadingDecorators: [] };
          }
          function H1(e, u, i) {
            let n = "", t3, o;
            u != null && (u.module && (i |= 3072), u.next && (i |= 1), u.loc && (i |= 4), u.ranges && (i |= 2), u.uniqueKeyInPattern && (i |= -2147483648), u.lexical && (i |= 64), u.webcompat && (i |= 256), u.directives && (i |= 520), u.globalReturn && (i |= 32), u.raw && (i |= 512), u.preserveParens && (i |= 128), u.impliedStrict && (i |= 1024), u.jsx && (i |= 16), u.identifierPattern && (i |= 268435456), u.specDeviation && (i |= 536870912), u.source && (n = u.source), u.onComment != null && (t3 = Array.isArray(u.onComment) ? Yt(i, u.onComment) : u.onComment), u.onToken != null && (o = Array.isArray(u.onToken) ? Zt(i, u.onToken) : u.onToken));
            let l = Qt(e, n, t3, o);
            i & 1 && f2(l);
            let c = i & 64 ? _2() : void 0, s = [], r = "script";
            if (i & 2048) {
              if (r = "module", s = xt(l, i | 8192, c), c)
                for (let h in l.exportedBindings)
                  h[0] === "#" && !c[h] && f(l, 142, h.slice(1));
            } else
              s = Gt(l, i | 8192, c);
            let b = { type: "Program", sourceType: r, body: s };
            return i & 2 && (b.start = 0, b.end = e.length, b.range = [0, e.length]), i & 4 && (b.loc = { start: { line: 1, column: 0 }, end: { line: l.line, column: l.column } }, l.sourceFile && (b.loc.source = n)), b;
          }
          function Gt(e, u, i) {
            E(e, u | 32768 | 1073741824);
            let n = [];
            for (; e.token === 134283267; ) {
              let { index: t3, tokenPos: o, tokenValue: l, linePos: c, colPos: s, token: r } = e, b = s2(e, u);
              eu(e, t3, o, l) && (u |= 1024), n.push(z1(e, u, b, r, o, c, s));
            }
            for (; e.token !== 1048576; )
              n.push(G2(e, u, i, 4, {}));
            return n;
          }
          function xt(e, u, i) {
            E(e, u | 32768);
            let n = [];
            if (u & 8)
              for (; e.token === 134283267; ) {
                let { tokenPos: t3, linePos: o, colPos: l, token: c } = e;
                n.push(z1(e, u, s2(e, u), c, t3, o, l));
              }
            for (; e.token !== 1048576; )
              n.push(pt(e, u, i));
            return n;
          }
          function pt(e, u, i) {
            e.leadingDecorators = b1(e, u);
            let n;
            switch (e.token) {
              case 20566:
                n = v0(e, u, i);
                break;
              case 86108:
                n = b0(e, u, i);
                break;
              default:
                n = G2(e, u, i, 4, {});
            }
            return e.leadingDecorators.length && f(e, 164), n;
          }
          function G2(e, u, i, n, t3) {
            let o = e.tokenPos, l = e.linePos, c = e.colPos;
            switch (e.token) {
              case 86106:
                return I2(e, u, i, n, 1, 0, 0, o, l, c);
              case 133:
              case 86096:
                return x1(e, u, i, 0, o, l, c);
              case 86092:
                return W1(e, u, i, 16, 0, o, l, c);
              case 241739:
                return r0(e, u, i, n, o, l, c);
              case 20566:
                f(e, 100, "export");
              case 86108:
                switch (E(e, u), e.token) {
                  case 67174411:
                    return hu(e, u, o, l, c);
                  case 67108877:
                    return gu(e, u, o, l, c);
                  default:
                    f(e, 100, "import");
                }
              case 209007:
                return ou(e, u, i, n, t3, 1, o, l, c);
              default:
                return x2(e, u, i, n, t3, 1, o, l, c);
            }
          }
          function x2(e, u, i, n, t3, o, l, c, s) {
            switch (e.token) {
              case 86090:
                return fu(e, u, i, 0, l, c, s);
              case 20574:
                return u0(e, u, l, c, s);
              case 20571:
                return t0(e, u, i, t3, l, c, s);
              case 20569:
                return m0(e, u, i, t3, l, c, s);
              case 20564:
                return h0(e, u, i, t3, l, c, s);
              case 20580:
                return l0(e, u, i, t3, l, c, s);
              case 86112:
                return o0(e, u, i, t3, l, c, s);
              case 1074790417:
                return i0(e, u, l, c, s);
              case 2162700:
                return s1(e, u, i && t22(i, 2), t3, l, c, s);
              case 86114:
                return n0(e, u, l, c, s);
              case 20557:
                return c0(e, u, t3, l, c, s);
              case 20561:
                return f0(e, u, t3, l, c, s);
              case 20579:
                return d0(e, u, i, t3, l, c, s);
              case 20581:
                return s0(e, u, i, t3, l, c, s);
              case 20562:
                return a0(e, u, l, c, s);
              case 209007:
                return ou(e, u, i, n, t3, 0, l, c, s);
              case 20559:
                f(e, 156);
              case 20568:
                f(e, 157);
              case 86106:
                f(e, u & 1024 ? 73 : (u & 256) < 1 ? 75 : 74);
              case 86096:
                f(e, 76);
              default:
                return e0(e, u, i, n, t3, o, l, c, s);
            }
          }
          function e0(e, u, i, n, t3, o, l, c, s) {
            let { tokenValue: r, token: b } = e, h;
            switch (b) {
              case 241739:
                h = X(e, u, 0), u & 1024 && f(e, 82), e.token === 69271571 && f(e, 81);
                break;
              default:
                h = g2(e, u, 2, 0, 1, 0, 0, 1, e.tokenPos, e.linePos, e.colPos);
            }
            return b & 143360 && e.token === 21 ? X1(e, u, i, n, t3, r, h, b, o, l, c, s) : (h = K(e, u, h, 0, 0, l, c, s), h = p(e, u, 0, 0, l, c, s, h), e.token === 18 && (h = O2(e, u, 0, l, c, s, h)), X2(e, u, h, l, c, s));
          }
          function s1(e, u, i, n, t3, o, l) {
            let c = [];
            for (w(e, u | 32768, 2162700); e.token !== 1074790415; )
              c.push(G2(e, u, i, 2, { $: n }));
            return w(e, u | 32768, 1074790415), v(e, u, t3, o, l, { type: "BlockStatement", body: c });
          }
          function u0(e, u, i, n, t3) {
            (u & 32) < 1 && u & 8192 && f(e, 89), E(e, u | 32768);
            let o = e.flags & 1 || e.token & 1048576 ? null : l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            return a2(e, u | 32768), v(e, u, i, n, t3, { type: "ReturnStatement", argument: o });
          }
          function X2(e, u, i, n, t3, o) {
            return a2(e, u | 32768), v(e, u, n, t3, o, { type: "ExpressionStatement", expression: i });
          }
          function X1(e, u, i, n, t3, o, l, c, s, r, b, h) {
            l1(e, u, 0, c, 1), Wt(e, t3, o), E(e, u | 32768);
            let d = s && (u & 1024) < 1 && u & 256 && e.token === 86106 ? I2(e, u, t22(i, 2), n, 0, 0, 0, e.tokenPos, e.linePos, e.colPos) : x2(e, u, i, n, t3, s, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, r, b, h, { type: "LabeledStatement", label: l, body: d });
          }
          function ou(e, u, i, n, t3, o, l, c, s) {
            let { token: r, tokenValue: b } = e, h = X(e, u, 0);
            if (e.token === 21)
              return X1(e, u, i, n, t3, b, h, r, 1, l, c, s);
            let d = e.flags & 1;
            if (!d) {
              if (e.token === 86106)
                return o || f(e, 119), I2(e, u, i, n, 1, 0, 1, l, c, s);
              if ((e.token & 143360) === 143360)
                return h = Pu(e, u, 1, l, c, s), e.token === 18 && (h = O2(e, u, 0, l, c, s, h)), X2(e, u, h, l, c, s);
            }
            return e.token === 67174411 ? h = G1(e, u, h, 1, 1, 0, d, l, c, s) : (e.token === 10 && ($1(e, u, r, 1), h = h1(e, u, e.tokenValue, h, 0, 1, 0, l, c, s)), e.assignable = 1), h = K(e, u, h, 0, 0, l, c, s), e.token === 18 && (h = O2(e, u, 0, l, c, s, h)), h = p(e, u, 0, 0, l, c, s, h), e.assignable = 1, X2(e, u, h, l, c, s);
          }
          function z1(e, u, i, n, t3, o, l) {
            return n !== 1074790417 && (e.assignable = 2, i = K(e, u, i, 0, 0, t3, o, l), e.token !== 1074790417 && (i = p(e, u, 0, 0, t3, o, l, i), e.token === 18 && (i = O2(e, u, 0, t3, o, l, i))), a2(e, u | 32768)), u & 8 && i.type === "Literal" && typeof i.value == "string" ? v(e, u, t3, o, l, { type: "ExpressionStatement", expression: i, directive: i.raw.slice(1, -1) }) : v(e, u, t3, o, l, { type: "ExpressionStatement", expression: i });
          }
          function i0(e, u, i, n, t3) {
            return E(e, u | 32768), v(e, u, i, n, t3, { type: "EmptyStatement" });
          }
          function n0(e, u, i, n, t3) {
            E(e, u | 32768), e.flags & 1 && f(e, 87);
            let o = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            return a2(e, u | 32768), v(e, u, i, n, t3, { type: "ThrowStatement", argument: o });
          }
          function t0(e, u, i, n, t3, o, l) {
            E(e, u), w(e, u | 32768, 67174411), e.assignable = 1;
            let c = l2(e, u, 0, 1, e.tokenPos, e.line, e.colPos);
            w(e, u | 32768, 16);
            let s = lu(e, u, i, n, e.tokenPos, e.linePos, e.colPos), r = null;
            return e.token === 20565 && (E(e, u | 32768), r = lu(e, u, i, n, e.tokenPos, e.linePos, e.colPos)), v(e, u, t3, o, l, { type: "IfStatement", test: c, consequent: s, alternate: r });
          }
          function lu(e, u, i, n, t3, o, l) {
            return u & 1024 || (u & 256) < 1 || e.token !== 86106 ? x2(e, u, i, 0, { $: n }, 0, e.tokenPos, e.linePos, e.colPos) : I2(e, u, t22(i, 2), 0, 0, 0, 0, t3, o, l);
          }
          function o0(e, u, i, n, t3, o, l) {
            E(e, u), w(e, u | 32768, 67174411);
            let c = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            w(e, u, 16), w(e, u, 2162700);
            let s = [], r = 0;
            for (i && (i = t22(i, 8)); e.token !== 1074790415; ) {
              let { tokenPos: b, linePos: h, colPos: d } = e, y = null, C = [];
              for (J(e, u | 32768, 20558) ? y = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos) : (w(e, u | 32768, 20563), r && f(e, 86), r = 1), w(e, u | 32768, 21); e.token !== 20558 && e.token !== 1074790415 && e.token !== 20563; )
                C.push(G2(e, u | 4096, i, 2, { $: n }));
              s.push(v(e, u, b, h, d, { type: "SwitchCase", test: y, consequent: C }));
            }
            return w(e, u | 32768, 1074790415), v(e, u, t3, o, l, { type: "SwitchStatement", discriminant: c, cases: s });
          }
          function l0(e, u, i, n, t3, o, l) {
            E(e, u), w(e, u | 32768, 67174411);
            let c = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            w(e, u | 32768, 16);
            let s = p2(e, u, i, n);
            return v(e, u, t3, o, l, { type: "WhileStatement", test: c, body: s });
          }
          function p2(e, u, i, n) {
            return x2(e, (u | 134217728) ^ 134217728 | 131072, i, 0, { loop: 1, $: n }, 0, e.tokenPos, e.linePos, e.colPos);
          }
          function f0(e, u, i, n, t3, o) {
            (u & 131072) < 1 && f(e, 65), E(e, u);
            let l = null;
            if ((e.flags & 1) < 1 && e.token & 143360) {
              let { tokenValue: c } = e;
              l = X(e, u | 32768, 0), nu(e, i, c, 1) || f(e, 134, c);
            }
            return a2(e, u | 32768), v(e, u, n, t3, o, { type: "ContinueStatement", label: l });
          }
          function c0(e, u, i, n, t3, o) {
            E(e, u | 32768);
            let l = null;
            if ((e.flags & 1) < 1 && e.token & 143360) {
              let { tokenValue: c } = e;
              l = X(e, u | 32768, 0), nu(e, i, c, 0) || f(e, 134, c);
            } else
              (u & 135168) < 1 && f(e, 66);
            return a2(e, u | 32768), v(e, u, n, t3, o, { type: "BreakStatement", label: l });
          }
          function s0(e, u, i, n, t3, o, l) {
            E(e, u), u & 1024 && f(e, 88), w(e, u | 32768, 67174411);
            let c = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            w(e, u | 32768, 16);
            let s = x2(e, u, i, 2, n, 0, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, t3, o, l, { type: "WithStatement", object: c, body: s });
          }
          function a0(e, u, i, n, t3) {
            return E(e, u | 32768), a2(e, u | 32768), v(e, u, i, n, t3, { type: "DebuggerStatement" });
          }
          function d0(e, u, i, n, t3, o, l) {
            E(e, u | 32768);
            let c = i ? t22(i, 32) : void 0, s = s1(e, u, c, { $: n }, e.tokenPos, e.linePos, e.colPos), { tokenPos: r, linePos: b, colPos: h } = e, d = J(e, u | 32768, 20559) ? g0(e, u, i, n, r, b, h) : null, y = null;
            if (e.token === 20568) {
              E(e, u | 32768);
              let C = c ? t22(i, 4) : void 0;
              y = s1(e, u, C, { $: n }, e.tokenPos, e.linePos, e.colPos);
            }
            return !d && !y && f(e, 85), v(e, u, t3, o, l, { type: "TryStatement", block: s, handler: d, finalizer: y });
          }
          function g0(e, u, i, n, t3, o, l) {
            let c = null, s = i;
            J(e, u, 67174411) && (i && (i = t22(i, 4)), c = Cu(e, u, i, (e.token & 2097152) === 2097152 ? 256 : 512, 0, e.tokenPos, e.linePos, e.colPos), e.token === 18 ? f(e, 83) : e.token === 1077936157 && f(e, 84), w(e, u | 32768, 16), i && (s = t22(i, 64)));
            let r = s1(e, u, s, { $: n }, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, t3, o, l, { type: "CatchClause", param: c, body: r });
          }
          function h0(e, u, i, n, t3, o, l) {
            E(e, u | 32768);
            let c = p2(e, u, i, n);
            w(e, u, 20580), w(e, u | 32768, 67174411);
            let s = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos);
            return w(e, u | 32768, 16), J(e, u, 1074790417), v(e, u, t3, o, l, { type: "DoWhileStatement", body: c, test: s });
          }
          function r0(e, u, i, n, t3, o, l) {
            let { token: c, tokenValue: s } = e, r = X(e, u, 0);
            if (e.token & 2240512) {
              let b = z2(e, u, i, 8, 0);
              return a2(e, u | 32768), v(e, u, t3, o, l, { type: "VariableDeclaration", kind: "let", declarations: b });
            }
            if (e.assignable = 1, u & 1024 && f(e, 82), e.token === 21)
              return X1(e, u, i, n, {}, s, r, c, 0, t3, o, l);
            if (e.token === 10) {
              let b;
              u & 64 && (b = c1(e, u, s)), e.flags = (e.flags | 128) ^ 128, r = e1(e, u, b, [r], 0, t3, o, l);
            } else
              r = K(e, u, r, 0, 0, t3, o, l), r = p(e, u, 0, 0, t3, o, l, r);
            return e.token === 18 && (r = O2(e, u, 0, t3, o, l, r)), X2(e, u, r, t3, o, l);
          }
          function W1(e, u, i, n, t3, o, l, c) {
            E(e, u);
            let s = z2(e, u, i, n, t3);
            return a2(e, u | 32768), v(e, u, o, l, c, { type: "VariableDeclaration", kind: n & 8 ? "let" : "const", declarations: s });
          }
          function fu(e, u, i, n, t3, o, l) {
            E(e, u);
            let c = z2(e, u, i, 4, n);
            return a2(e, u | 32768), v(e, u, t3, o, l, { type: "VariableDeclaration", kind: "var", declarations: c });
          }
          function z2(e, u, i, n, t3) {
            let o = 1, l = [cu(e, u, i, n, t3)];
            for (; J(e, u, 18); )
              o++, l.push(cu(e, u, i, n, t3));
            return o > 1 && t3 & 32 && e.token & 262144 && f(e, 58, x[e.token & 255]), l;
          }
          function cu(e, u, i, n, t3) {
            let { token: o, tokenPos: l, linePos: c, colPos: s } = e, r = null, b = Cu(e, u, i, n, t3, l, c, s);
            return e.token === 1077936157 ? (E(e, u | 32768), r = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos), (t3 & 32 || (o & 2097152) < 1) && (e.token === 274549 || e.token === 8738868 && (o & 2097152 || (n & 4) < 1 || u & 1024)) && S(l, e.line, e.index - 3, 57, e.token === 274549 ? "of" : "in")) : (n & 16 || (o & 2097152) > 0) && (e.token & 262144) !== 262144 && f(e, 56, n & 16 ? "const" : "destructuring"), v(e, u, l, c, s, { type: "VariableDeclarator", id: b, init: r });
          }
          function m0(e, u, i, n, t3, o, l) {
            E(e, u);
            let c = (u & 4194304) > 0 && J(e, u, 209008);
            w(e, u | 32768, 67174411), i && (i = t22(i, 1));
            let s = null, r = null, b = 0, h = null, d = e.token === 86090 || e.token === 241739 || e.token === 86092, y, { token: C, tokenPos: D, linePos: F, colPos: T } = e;
            if (d ? C === 241739 ? (h = X(e, u, 0), e.token & 2240512 ? (e.token === 8738868 ? u & 1024 && f(e, 64) : h = v(e, u, D, F, T, { type: "VariableDeclaration", kind: "let", declarations: z2(e, u | 134217728, i, 8, 32) }), e.assignable = 1) : u & 1024 ? f(e, 64) : (d = false, e.assignable = 1, h = K(e, u, h, 0, 0, D, F, T), e.token === 274549 && f(e, 111))) : (E(e, u), h = v(e, u, D, F, T, C === 86090 ? { type: "VariableDeclaration", kind: "var", declarations: z2(e, u | 134217728, i, 4, 32) } : { type: "VariableDeclaration", kind: "const", declarations: z2(e, u | 134217728, i, 16, 32) }), e.assignable = 1) : C === 1074790417 ? c && f(e, 79) : (C & 2097152) === 2097152 ? (h = C === 2162700 ? b2(e, u, void 0, 1, 0, 0, 2, 32, D, F, T) : m2(e, u, void 0, 1, 0, 0, 2, 32, D, F, T), b = e.destructible, u & 256 && b & 64 && f(e, 60), e.assignable = b & 16 ? 2 : 1, h = K(e, u | 134217728, h, 0, 0, e.tokenPos, e.linePos, e.colPos)) : h = r2(e, u | 134217728, 1, 0, 1, D, F, T), (e.token & 262144) === 262144) {
              if (e.token === 274549) {
                e.assignable & 2 && f(e, 77, c ? "await" : "of"), v2(e, h), E(e, u | 32768), y = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos), w(e, u | 32768, 16);
                let I = p2(e, u, i, n);
                return v(e, u, t3, o, l, { type: "ForOfStatement", left: h, right: y, body: I, await: c });
              }
              e.assignable & 2 && f(e, 77, "in"), v2(e, h), E(e, u | 32768), c && f(e, 79), y = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos), w(e, u | 32768, 16);
              let i2 = p2(e, u, i, n);
              return v(e, u, t3, o, l, { type: "ForInStatement", body: i2, left: h, right: y });
            }
            c && f(e, 79), d || (b & 8 && e.token !== 1077936157 && f(e, 77, "loop"), h = p(e, u | 134217728, 0, 0, D, F, T, h)), e.token === 18 && (h = O2(e, u, 0, e.tokenPos, e.linePos, e.colPos, h)), w(e, u | 32768, 1074790417), e.token !== 1074790417 && (s = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos)), w(e, u | 32768, 1074790417), e.token !== 16 && (r = l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos)), w(e, u | 32768, 16);
            let _ = p2(e, u, i, n);
            return v(e, u, t3, o, l, { type: "ForStatement", init: h, test: s, update: r, body: _ });
          }
          function su(e, u, i) {
            return J1(u, e.token) || f(e, 114), (e.token & 537079808) === 537079808 && f(e, 115), i && L2(e, u, i, e.tokenValue, 8, 0), X(e, u, 0);
          }
          function b0(e, u, i) {
            let n = e.tokenPos, t3 = e.linePos, o = e.colPos;
            E(e, u);
            let l = null, { tokenPos: c, linePos: s, colPos: r } = e, b = [];
            if (e.token === 134283267)
              l = s2(e, u);
            else {
              if (e.token & 143360) {
                let h = su(e, u, i);
                if (b = [v(e, u, c, s, r, { type: "ImportDefaultSpecifier", local: h })], J(e, u, 18))
                  switch (e.token) {
                    case 8457014:
                      b.push(au(e, u, i));
                      break;
                    case 2162700:
                      du(e, u, i, b);
                      break;
                    default:
                      f(e, 104);
                  }
              } else
                switch (e.token) {
                  case 8457014:
                    b = [au(e, u, i)];
                    break;
                  case 2162700:
                    du(e, u, i, b);
                    break;
                  case 67174411:
                    return hu(e, u, n, t3, o);
                  case 67108877:
                    return gu(e, u, n, t3, o);
                  default:
                    f(e, 28, x[e.token & 255]);
                }
              l = k0(e, u);
            }
            return a2(e, u | 32768), v(e, u, n, t3, o, { type: "ImportDeclaration", specifiers: b, source: l });
          }
          function au(e, u, i) {
            let { tokenPos: n, linePos: t3, colPos: o } = e;
            return E(e, u), w(e, u, 77934), (e.token & 134217728) === 134217728 && S(n, e.line, e.index, 28, x[e.token & 255]), v(e, u, n, t3, o, { type: "ImportNamespaceSpecifier", local: su(e, u, i) });
          }
          function k0(e, u) {
            return J(e, u, 12404), e.token !== 134283267 && f(e, 102, "Import"), s2(e, u);
          }
          function du(e, u, i, n) {
            for (E(e, u); e.token & 143360; ) {
              let { token: t3, tokenValue: o, tokenPos: l, linePos: c, colPos: s } = e, r = X(e, u, 0), b;
              J(e, u, 77934) ? ((e.token & 134217728) === 134217728 || e.token === 18 ? f(e, 103) : l1(e, u, 16, e.token, 0), o = e.tokenValue, b = X(e, u, 0)) : (l1(e, u, 16, t3, 0), b = r), i && L2(e, u, i, o, 8, 0), n.push(v(e, u, l, c, s, { type: "ImportSpecifier", local: b, imported: r })), e.token !== 1074790415 && w(e, u, 18);
            }
            return w(e, u, 1074790415), n;
          }
          function gu(e, u, i, n, t3) {
            let o = mu(e, u, v(e, u, i, n, t3, { type: "Identifier", name: "import" }), i, n, t3);
            return o = K(e, u, o, 0, 0, i, n, t3), o = p(e, u, 0, 0, i, n, t3, o), X2(e, u, o, i, n, t3);
          }
          function hu(e, u, i, n, t3) {
            let o = bu(e, u, 0, i, n, t3);
            return o = K(e, u, o, 0, 0, i, n, t3), X2(e, u, o, i, n, t3);
          }
          function v0(e, u, i) {
            let n = e.tokenPos, t3 = e.linePos, o = e.colPos;
            E(e, u | 32768);
            let l = [], c = null, s = null, r;
            if (J(e, u | 32768, 20563)) {
              switch (e.token) {
                case 86106: {
                  c = I2(e, u, i, 4, 1, 1, 0, e.tokenPos, e.linePos, e.colPos);
                  break;
                }
                case 133:
                case 86096:
                  c = x1(e, u, i, 1, e.tokenPos, e.linePos, e.colPos);
                  break;
                case 209007:
                  let { tokenPos: b, linePos: h, colPos: d } = e;
                  c = X(e, u, 0);
                  let { flags: y } = e;
                  (y & 1) < 1 && (e.token === 86106 ? c = I2(e, u, i, 4, 1, 1, 1, b, h, d) : e.token === 67174411 ? (c = G1(e, u, c, 1, 1, 0, y, b, h, d), c = K(e, u, c, 0, 0, b, h, d), c = p(e, u, 0, 0, b, h, d, c)) : e.token & 143360 && (i && (i = c1(e, u, e.tokenValue)), c = X(e, u, 0), c = e1(e, u, i, [c], 1, b, h, d)));
                  break;
                default:
                  c = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos), a2(e, u | 32768);
              }
              return i && M2(e, "default"), v(e, u, n, t3, o, { type: "ExportDefaultDeclaration", declaration: c });
            }
            switch (e.token) {
              case 8457014: {
                E(e, u);
                let y = null;
                return J(e, u, 77934) && (i && M2(e, e.tokenValue), y = X(e, u, 0)), w(e, u, 12404), e.token !== 134283267 && f(e, 102, "Export"), s = s2(e, u), a2(e, u | 32768), v(e, u, n, t3, o, { type: "ExportAllDeclaration", source: s, exported: y });
              }
              case 2162700: {
                E(e, u);
                let y = [], C = [];
                for (; e.token & 143360; ) {
                  let { tokenPos: D, tokenValue: F, linePos: T, colPos: _ } = e, i2 = X(e, u, 0), I;
                  e.token === 77934 ? (E(e, u), (e.token & 134217728) === 134217728 && f(e, 103), i && (y.push(e.tokenValue), C.push(F)), I = X(e, u, 0)) : (i && (y.push(e.tokenValue), C.push(e.tokenValue)), I = i2), l.push(v(e, u, D, T, _, { type: "ExportSpecifier", local: i2, exported: I })), e.token !== 1074790415 && w(e, u, 18);
                }
                if (w(e, u, 1074790415), J(e, u, 12404))
                  e.token !== 134283267 && f(e, 102, "Export"), s = s2(e, u);
                else if (i) {
                  let D = 0, F = y.length;
                  for (; D < F; D++)
                    M2(e, y[D]);
                  for (D = 0, F = C.length; D < F; D++)
                    Kt(e, C[D]);
                }
                a2(e, u | 32768);
                break;
              }
              case 86096:
                c = x1(e, u, i, 2, e.tokenPos, e.linePos, e.colPos);
                break;
              case 86106:
                c = I2(e, u, i, 4, 1, 2, 0, e.tokenPos, e.linePos, e.colPos);
                break;
              case 241739:
                c = W1(e, u, i, 8, 64, e.tokenPos, e.linePos, e.colPos);
                break;
              case 86092:
                c = W1(e, u, i, 16, 64, e.tokenPos, e.linePos, e.colPos);
                break;
              case 86090:
                c = fu(e, u, i, 64, e.tokenPos, e.linePos, e.colPos);
                break;
              case 209007:
                let { tokenPos: b, linePos: h, colPos: d } = e;
                if (E(e, u), (e.flags & 1) < 1 && e.token === 86106) {
                  c = I2(e, u, i, 4, 1, 2, 1, b, h, d), i && (r = c.id ? c.id.name : "", M2(e, r));
                  break;
                }
              default:
                f(e, 28, x[e.token & 255]);
            }
            return v(e, u, n, t3, o, { type: "ExportNamedDeclaration", declaration: c, specifiers: l, source: s });
          }
          function G(e, u, i, n, t3, o, l, c) {
            let s = g2(e, u, 2, 0, i, n, t3, 1, o, l, c);
            return s = K(e, u, s, t3, 0, o, l, c), p(e, u, t3, 0, o, l, c, s);
          }
          function O2(e, u, i, n, t3, o, l) {
            let c = [l];
            for (; J(e, u | 32768, 18); )
              c.push(G(e, u, 1, 0, i, e.tokenPos, e.linePos, e.colPos));
            return v(e, u, n, t3, o, { type: "SequenceExpression", expressions: c });
          }
          function l2(e, u, i, n, t3, o, l) {
            let c = G(e, u, n, 0, i, t3, o, l);
            return e.token === 18 ? O2(e, u, i, t3, o, l, c) : c;
          }
          function p(e, u, i, n, t3, o, l, c) {
            let { token: s } = e;
            if ((s & 4194304) === 4194304) {
              e.assignable & 2 && f(e, 24), (!n && s === 1077936157 && c.type === "ArrayExpression" || c.type === "ObjectExpression") && v2(e, c), E(e, u | 32768);
              let r = G(e, u, 1, 1, i, e.tokenPos, e.linePos, e.colPos);
              return e.assignable = 2, v(e, u, t3, o, l, n ? { type: "AssignmentPattern", left: c, right: r } : { type: "AssignmentExpression", left: c, operator: x[s & 255], right: r });
            }
            return (s & 8454144) === 8454144 && (c = T2(e, u, i, t3, o, l, 4, s, c)), J(e, u | 32768, 22) && (c = U2(e, u, c, t3, o, l)), c;
          }
          function a1(e, u, i, n, t3, o, l, c) {
            let { token: s } = e;
            E(e, u | 32768);
            let r = G(e, u, 1, 1, i, e.tokenPos, e.linePos, e.colPos);
            return c = v(e, u, t3, o, l, n ? { type: "AssignmentPattern", left: c, right: r } : { type: "AssignmentExpression", left: c, operator: x[s & 255], right: r }), e.assignable = 2, c;
          }
          function U2(e, u, i, n, t3, o) {
            let l = G(e, (u | 134217728) ^ 134217728, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            w(e, u | 32768, 21), e.assignable = 1;
            let c = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            return e.assignable = 2, v(e, u, n, t3, o, { type: "ConditionalExpression", test: i, consequent: l, alternate: c });
          }
          function T2(e, u, i, n, t3, o, l, c, s) {
            let r = -((u & 134217728) > 0) & 8738868, b, h;
            for (e.assignable = 2; e.token & 8454144 && (b = e.token, h = b & 3840, (b & 524288 && c & 268435456 || c & 524288 && b & 268435456) && f(e, 159), !(h + ((b === 8457273) << 8) - ((r === b) << 12) <= l)); )
              E(e, u | 32768), s = v(e, u, n, t3, o, { type: b & 524288 || b & 268435456 ? "LogicalExpression" : "BinaryExpression", left: s, right: T2(e, u, i, e.tokenPos, e.linePos, e.colPos, h, b, r2(e, u, 0, i, 1, e.tokenPos, e.linePos, e.colPos)), operator: x[b & 255] });
            return e.token === 1077936157 && f(e, 24), s;
          }
          function y0(e, u, i, n, t3, o, l) {
            i || f(e, 0);
            let c = e.token;
            E(e, u | 32768);
            let s = r2(e, u, 0, l, 1, e.tokenPos, e.linePos, e.colPos);
            return e.token === 8457273 && f(e, 31), u & 1024 && c === 16863278 && (s.type === "Identifier" ? f(e, 117) : zt(s) && f(e, 123)), e.assignable = 2, v(e, u, n, t3, o, { type: "UnaryExpression", operator: x[c & 255], argument: s, prefix: true });
          }
          function A0(e, u, i, n, t3, o, l, c, s, r) {
            let { token: b } = e, h = X(e, u, o), { flags: d } = e;
            if ((d & 1) < 1) {
              if (e.token === 86106)
                return vu(e, u, 1, i, c, s, r);
              if ((e.token & 143360) === 143360)
                return n || f(e, 0), Pu(e, u, t3, c, s, r);
            }
            return !l && e.token === 67174411 ? G1(e, u, h, t3, 1, 0, d, c, s, r) : e.token === 10 ? ($1(e, u, b, 1), l && f(e, 48), h1(e, u, e.tokenValue, h, l, t3, 0, c, s, r)) : h;
          }
          function P0(e, u, i, n, t3, o, l) {
            if (i && (e.destructible |= 256), u & 2097152) {
              E(e, u | 32768), u & 8388608 && f(e, 30), n || f(e, 24), e.token === 22 && f(e, 120);
              let c = null, s = false;
              return (e.flags & 1) < 1 && (s = J(e, u | 32768, 8457014), (e.token & 77824 || s) && (c = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos))), e.assignable = 2, v(e, u, t3, o, l, { type: "YieldExpression", argument: c, delegate: s });
            }
            return u & 1024 && f(e, 94, "yield"), Q1(e, u, t3, o, l);
          }
          function E0(e, u, i, n, t3, o, l) {
            if (n && (e.destructible |= 128), u & 4194304 || u & 2048 && u & 8192) {
              i && f(e, 0), u & 8388608 && S(e.index, e.line, e.index, 29), E(e, u | 32768);
              let c = r2(e, u, 0, 0, 1, e.tokenPos, e.linePos, e.colPos);
              return e.token === 8457273 && f(e, 31), e.assignable = 2, v(e, u, t3, o, l, { type: "AwaitExpression", argument: c });
            }
            return u & 2048 && f(e, 95), Q1(e, u, t3, o, l);
          }
          function d1(e, u, i, n, t3, o) {
            let { tokenPos: l, linePos: c, colPos: s } = e;
            w(e, u | 32768, 2162700);
            let r = [], b = u;
            if (e.token !== 1074790415) {
              for (; e.token === 134283267; ) {
                let { index: h, tokenPos: d, tokenValue: y, token: C } = e, D = s2(e, u);
                eu(e, h, d, y) && (u |= 1024, e.flags & 128 && S(e.index, e.line, e.tokenPos, 63), e.flags & 64 && S(e.index, e.line, e.tokenPos, 8)), r.push(z1(e, u, D, C, d, e.linePos, e.colPos));
              }
              u & 1024 && (t3 && ((t3 & 537079808) === 537079808 && f(e, 115), (t3 & 36864) === 36864 && f(e, 38)), e.flags & 512 && f(e, 115), e.flags & 256 && f(e, 114)), u & 64 && i && o !== void 0 && (b & 1024) < 1 && (u & 8192) < 1 && A(o);
            }
            for (e.flags = (e.flags | 512 | 256 | 64) ^ 832, e.destructible = (e.destructible | 256) ^ 256; e.token !== 1074790415; )
              r.push(G2(e, u, i, 4, {}));
            return w(e, n & 24 ? u | 32768 : u, 1074790415), e.flags &= -193, e.token === 1077936157 && f(e, 24), v(e, u, l, c, s, { type: "BlockStatement", body: r });
          }
          function D0(e, u, i, n, t3) {
            switch (E(e, u), e.token) {
              case 67108991:
                f(e, 161);
              case 67174411: {
                (u & 524288) < 1 && f(e, 26), u & 16384 && f(e, 27), e.assignable = 2;
                break;
              }
              case 69271571:
              case 67108877: {
                (u & 262144) < 1 && f(e, 27), u & 16384 && f(e, 27), e.assignable = 1;
                break;
              }
              default:
                f(e, 28, "super");
            }
            return v(e, u, i, n, t3, { type: "Super" });
          }
          function r2(e, u, i, n, t3, o, l, c) {
            let s = g2(e, u, 2, 0, i, 0, n, t3, o, l, c);
            return K(e, u, s, n, 0, o, l, c);
          }
          function C0(e, u, i, n, t3, o) {
            e.assignable & 2 && f(e, 52);
            let { token: l } = e;
            return E(e, u), e.assignable = 2, v(e, u, n, t3, o, { type: "UpdateExpression", argument: i, operator: x[l & 255], prefix: false });
          }
          function K(e, u, i, n, t3, o, l, c) {
            if ((e.token & 33619968) === 33619968 && (e.flags & 1) < 1)
              i = C0(e, u, i, o, l, c);
            else if ((e.token & 67108864) === 67108864) {
              switch (u = (u | 134217728) ^ 134217728, e.token) {
                case 67108877: {
                  E(e, (u | 1073741824 | 8192) ^ 8192), e.assignable = 1;
                  let s = ru(e, u);
                  i = v(e, u, o, l, c, { type: "MemberExpression", object: i, computed: false, property: s });
                  break;
                }
                case 69271571: {
                  let s = false;
                  (e.flags & 2048) === 2048 && (s = true, e.flags = (e.flags | 2048) ^ 2048), E(e, u | 32768);
                  let { tokenPos: r, linePos: b, colPos: h } = e, d = l2(e, u, n, 1, r, b, h);
                  w(e, u, 20), e.assignable = 1, i = v(e, u, o, l, c, { type: "MemberExpression", object: i, computed: true, property: d }), s && (e.flags |= 2048);
                  break;
                }
                case 67174411: {
                  if ((e.flags & 1024) === 1024)
                    return e.flags = (e.flags | 1024) ^ 1024, i;
                  let s = false;
                  (e.flags & 2048) === 2048 && (s = true, e.flags = (e.flags | 2048) ^ 2048);
                  let r = Z1(e, u, n);
                  e.assignable = 2, i = v(e, u, o, l, c, { type: "CallExpression", callee: i, arguments: r }), s && (e.flags |= 2048);
                  break;
                }
                case 67108991: {
                  E(e, (u | 1073741824 | 8192) ^ 8192), e.flags |= 2048, e.assignable = 2, i = w0(e, u, i, o, l, c);
                  break;
                }
                default:
                  (e.flags & 2048) === 2048 && f(e, 160), e.assignable = 2, i = v(e, u, o, l, c, { type: "TaggedTemplateExpression", tag: i, quasi: e.token === 67174408 ? Y1(e, u | 65536) : K1(e, u, e.tokenPos, e.linePos, e.colPos) });
              }
              i = K(e, u, i, 0, 1, o, l, c);
            }
            return t3 === 0 && (e.flags & 2048) === 2048 && (e.flags = (e.flags | 2048) ^ 2048, i = v(e, u, o, l, c, { type: "ChainExpression", expression: i })), i;
          }
          function w0(e, u, i, n, t3, o) {
            let l = false, c;
            if ((e.token === 69271571 || e.token === 67174411) && (e.flags & 2048) === 2048 && (l = true, e.flags = (e.flags | 2048) ^ 2048), e.token === 69271571) {
              E(e, u | 32768);
              let { tokenPos: s, linePos: r, colPos: b } = e, h = l2(e, u, 0, 1, s, r, b);
              w(e, u, 20), e.assignable = 2, c = v(e, u, n, t3, o, { type: "MemberExpression", object: i, computed: true, optional: true, property: h });
            } else if (e.token === 67174411) {
              let s = Z1(e, u, 0);
              e.assignable = 2, c = v(e, u, n, t3, o, { type: "CallExpression", callee: i, arguments: s, optional: true });
            } else {
              (e.token & 143360) < 1 && f(e, 154);
              let s = X(e, u, 0);
              e.assignable = 2, c = v(e, u, n, t3, o, { type: "MemberExpression", object: i, computed: false, optional: true, property: s });
            }
            return l && (e.flags |= 2048), c;
          }
          function ru(e, u) {
            return (e.token & 143360) < 1 && e.token !== 131 && f(e, 154), u & 1 && e.token === 131 ? k1(e, u, e.tokenPos, e.linePos, e.colPos) : X(e, u, 0);
          }
          function q0(e, u, i, n, t3, o, l) {
            i && f(e, 53), n || f(e, 0);
            let { token: c } = e;
            E(e, u | 32768);
            let s = r2(e, u, 0, 0, 1, e.tokenPos, e.linePos, e.colPos);
            return e.assignable & 2 && f(e, 52), e.assignable = 2, v(e, u, t3, o, l, { type: "UpdateExpression", argument: s, operator: x[c & 255], prefix: true });
          }
          function g2(e, u, i, n, t3, o, l, c, s, r, b) {
            if ((e.token & 143360) === 143360) {
              switch (e.token) {
                case 209008:
                  return E0(e, u, n, l, s, r, b);
                case 241773:
                  return P0(e, u, l, t3, s, r, b);
                case 209007:
                  return A0(e, u, l, c, t3, o, n, s, r, b);
              }
              let { token: h, tokenValue: d } = e, y = X(e, u | 65536, o);
              return e.token === 10 ? (c || f(e, 0), $1(e, u, h, 1), h1(e, u, d, y, n, t3, 0, s, r, b)) : (u & 16384 && h === 537079928 && f(e, 126), h === 241739 && (u & 1024 && f(e, 109), i & 24 && f(e, 97)), e.assignable = u & 1024 && (h & 537079808) === 537079808 ? 2 : 1, y);
            }
            if ((e.token & 134217728) === 134217728)
              return s2(e, u);
            switch (e.token) {
              case 33619995:
              case 33619996:
                return q0(e, u, n, c, s, r, b);
              case 16863278:
              case 16842800:
              case 16842801:
              case 25233970:
              case 25233971:
              case 16863277:
              case 16863279:
                return y0(e, u, c, s, r, b, l);
              case 86106:
                return vu(e, u, 0, l, s, r, b);
              case 2162700:
                return T0(e, u, t3 ? 0 : 1, l, s, r, b);
              case 69271571:
                return O0(e, u, t3 ? 0 : 1, l, s, r, b);
              case 67174411:
                return R0(e, u, t3, 1, 0, s, r, b);
              case 86021:
              case 86022:
              case 86023:
                return F0(e, u, s, r, b);
              case 86113:
                return L0(e, u);
              case 65540:
                return j0(e, u, s, r, b);
              case 133:
              case 86096:
                return _0(e, u, l, s, r, b);
              case 86111:
                return D0(e, u, s, r, b);
              case 67174409:
                return K1(e, u, s, r, b);
              case 67174408:
                return Y1(e, u);
              case 86109:
                return N0(e, u, l, s, r, b);
              case 134283389:
                return ku(e, u, s, r, b);
              case 131:
                return k1(e, u, s, r, b);
              case 86108:
                return B0(e, u, n, l, s, r, b);
              case 8456258:
                if (u & 16)
                  return ee(e, u, 1, s, r, b);
              default:
                if (J1(u, e.token))
                  return Q1(e, u, s, r, b);
                f(e, 28, x[e.token & 255]);
            }
          }
          function B0(e, u, i, n, t3, o, l) {
            let c = X(e, u, 0);
            return e.token === 67108877 ? mu(e, u, c, t3, o, l) : (i && f(e, 137), c = bu(e, u, n, t3, o, l), e.assignable = 2, K(e, u, c, n, 0, t3, o, l));
          }
          function mu(e, u, i, n, t3, o) {
            return u & 2048 || f(e, 163), E(e, u), e.token !== 143495 && e.tokenValue !== "meta" && f(e, 28, x[e.token & 255]), e.assignable = 2, v(e, u, n, t3, o, { type: "MetaProperty", meta: i, property: X(e, u, 0) });
          }
          function bu(e, u, i, n, t3, o) {
            w(e, u | 32768, 67174411), e.token === 14 && f(e, 138);
            let l = G(e, u, 1, 0, i, e.tokenPos, e.linePos, e.colPos);
            return w(e, u, 16), v(e, u, n, t3, o, { type: "ImportExpression", source: l });
          }
          function ku(e, u, i, n, t3) {
            let { tokenRaw: o, tokenValue: l } = e;
            return E(e, u), e.assignable = 2, v(e, u, i, n, t3, u & 512 ? { type: "Literal", value: l, bigint: o.slice(0, -1), raw: o } : { type: "Literal", value: l, bigint: o.slice(0, -1) });
          }
          function K1(e, u, i, n, t3) {
            e.assignable = 2;
            let { tokenValue: o, tokenRaw: l, tokenPos: c, linePos: s, colPos: r } = e;
            w(e, u, 67174409);
            let b = [g1(e, u, o, l, c, s, r, true)];
            return v(e, u, i, n, t3, { type: "TemplateLiteral", expressions: [], quasis: b });
          }
          function Y1(e, u) {
            u = (u | 134217728) ^ 134217728;
            let { tokenValue: i, tokenRaw: n, tokenPos: t3, linePos: o, colPos: l } = e;
            w(e, u | 32768, 67174408);
            let c = [g1(e, u, i, n, t3, o, l, false)], s = [l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos)];
            for (e.token !== 1074790415 && f(e, 80); (e.token = Vt(e, u)) !== 67174409; ) {
              let { tokenValue: r, tokenRaw: b, tokenPos: h, linePos: d, colPos: y } = e;
              w(e, u | 32768, 67174408), c.push(g1(e, u, r, b, h, d, y, false)), s.push(l2(e, u, 0, 1, e.tokenPos, e.linePos, e.colPos)), e.token !== 1074790415 && f(e, 80);
            }
            {
              let { tokenValue: r, tokenRaw: b, tokenPos: h, linePos: d, colPos: y } = e;
              w(e, u, 67174409), c.push(g1(e, u, r, b, h, d, y, true));
            }
            return v(e, u, t3, o, l, { type: "TemplateLiteral", expressions: s, quasis: c });
          }
          function g1(e, u, i, n, t3, o, l, c) {
            let s = v(e, u, t3, o, l, { type: "TemplateElement", value: { cooked: i, raw: n }, tail: c }), r = c ? 1 : 2;
            return u & 2 && (s.start += 1, s.range[0] += 1, s.end -= r, s.range[1] -= r), u & 4 && (s.loc.start.column += 1, s.loc.end.column -= r), s;
          }
          function S0(e, u, i, n, t3) {
            u = (u | 134217728) ^ 134217728, w(e, u | 32768, 14);
            let o = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            return e.assignable = 1, v(e, u, i, n, t3, { type: "SpreadElement", argument: o });
          }
          function Z1(e, u, i) {
            E(e, u | 32768);
            let n = [];
            if (e.token === 16)
              return E(e, u), n;
            for (; e.token !== 16 && (e.token === 14 ? n.push(S0(e, u, e.tokenPos, e.linePos, e.colPos)) : n.push(G(e, u, 1, 0, i, e.tokenPos, e.linePos, e.colPos)), !(e.token !== 18 || (E(e, u | 32768), e.token === 16))); )
              ;
            return w(e, u, 16), n;
          }
          function X(e, u, i) {
            let { tokenValue: n, tokenPos: t3, linePos: o, colPos: l } = e;
            return E(e, u), v(e, u, t3, o, l, u & 268435456 ? { type: "Identifier", name: n, pattern: i === 1 } : { type: "Identifier", name: n });
          }
          function s2(e, u) {
            let { tokenValue: i, tokenRaw: n, tokenPos: t3, linePos: o, colPos: l } = e;
            return e.token === 134283389 ? ku(e, u, t3, o, l) : (E(e, u), e.assignable = 2, v(e, u, t3, o, l, u & 512 ? { type: "Literal", value: i, raw: n } : { type: "Literal", value: i }));
          }
          function F0(e, u, i, n, t3) {
            let o = x[e.token & 255], l = e.token === 86023 ? null : o === "true";
            return E(e, u), e.assignable = 2, v(e, u, i, n, t3, u & 512 ? { type: "Literal", value: l, raw: o } : { type: "Literal", value: l });
          }
          function L0(e, u) {
            let { tokenPos: i, linePos: n, colPos: t3 } = e;
            return E(e, u), e.assignable = 2, v(e, u, i, n, t3, { type: "ThisExpression" });
          }
          function I2(e, u, i, n, t3, o, l, c, s, r) {
            E(e, u | 32768);
            let b = t3 ? M1(e, u, 8457014) : 0, h = null, d, y = i ? _2() : void 0;
            if (e.token === 67174411)
              (o & 1) < 1 && f(e, 37, "Function");
            else {
              let F = n & 4 && ((u & 8192) < 1 || (u & 2048) < 1) ? 4 : 64;
              uu(e, u | (u & 3072) << 11, e.token), i && (F & 4 ? tu(e, u, i, e.tokenValue, F) : L2(e, u, i, e.tokenValue, F, n), y = t22(y, 256), o && o & 2 && M2(e, e.tokenValue)), d = e.token, e.token & 143360 ? h = X(e, u, 0) : f(e, 28, x[e.token & 255]);
            }
            u = (u | 32243712) ^ 32243712 | 67108864 | l * 2 + b << 21 | (b ? 0 : 1073741824), i && (y = t22(y, 512));
            let C = Au(e, u | 8388608, y, 0, 1), D = d1(e, (u | 8192 | 4096 | 131072) ^ 143360, i ? t22(y, 128) : y, 8, d, i ? y.scopeError : void 0);
            return v(e, u, c, s, r, { type: "FunctionDeclaration", id: h, params: C, body: D, async: l === 1, generator: b === 1 });
          }
          function vu(e, u, i, n, t3, o, l) {
            E(e, u | 32768);
            let c = M1(e, u, 8457014), s = i * 2 + c << 21, r = null, b, h = u & 64 ? _2() : void 0;
            (e.token & 176128) > 0 && (uu(e, (u | 32243712) ^ 32243712 | s, e.token), h && (h = t22(h, 256)), b = e.token, r = X(e, u, 0)), u = (u | 32243712) ^ 32243712 | 67108864 | s | (c ? 0 : 1073741824), h && (h = t22(h, 512));
            let d = Au(e, u | 8388608, h, n, 1), y = d1(e, u & -134377473, h && t22(h, 128), 0, b, void 0);
            return e.assignable = 2, v(e, u, t3, o, l, { type: "FunctionExpression", id: r, params: d, body: y, async: i === 1, generator: c === 1 });
          }
          function O0(e, u, i, n, t3, o, l) {
            let c = m2(e, u, void 0, i, n, 0, 2, 0, t3, o, l);
            return u & 256 && e.destructible & 64 && f(e, 60), e.destructible & 8 && f(e, 59), c;
          }
          function m2(e, u, i, n, t3, o, l, c, s, r, b) {
            E(e, u | 32768);
            let h = [], d = 0;
            for (u = (u | 134217728) ^ 134217728; e.token !== 20; )
              if (J(e, u | 32768, 18))
                h.push(null);
              else {
                let C, { token: D, tokenPos: F, linePos: T, colPos: _, tokenValue: i2 } = e;
                if (D & 143360)
                  if (C = g2(e, u, l, 0, 1, 0, t3, 1, F, T, _), e.token === 1077936157) {
                    e.assignable & 2 && f(e, 24), E(e, u | 32768), i && B2(e, u, i, i2, l, c);
                    let I = G(e, u, 1, 1, t3, e.tokenPos, e.linePos, e.colPos);
                    C = v(e, u, F, T, _, o ? { type: "AssignmentPattern", left: C, right: I } : { type: "AssignmentExpression", operator: "=", left: C, right: I }), d |= e.destructible & 256 ? 256 : 0 | e.destructible & 128 ? 128 : 0;
                  } else
                    e.token === 18 || e.token === 20 ? (e.assignable & 2 ? d |= 16 : i && B2(e, u, i, i2, l, c), d |= e.destructible & 256 ? 256 : 0 | e.destructible & 128 ? 128 : 0) : (d |= l & 1 ? 32 : (l & 2) < 1 ? 16 : 0, C = K(e, u, C, t3, 0, F, T, _), e.token !== 18 && e.token !== 20 ? (e.token !== 1077936157 && (d |= 16), C = p(e, u, t3, o, F, T, _, C)) : e.token !== 1077936157 && (d |= e.assignable & 2 ? 16 : 32));
                else
                  D & 2097152 ? (C = e.token === 2162700 ? b2(e, u, i, 0, t3, o, l, c, F, T, _) : m2(e, u, i, 0, t3, o, l, c, F, T, _), d |= e.destructible, e.assignable = e.destructible & 16 ? 2 : 1, e.token === 18 || e.token === 20 ? e.assignable & 2 && (d |= 16) : e.destructible & 8 ? f(e, 68) : (C = K(e, u, C, t3, 0, F, T, _), d = e.assignable & 2 ? 16 : 0, e.token !== 18 && e.token !== 20 ? C = p(e, u, t3, o, F, T, _, C) : e.token !== 1077936157 && (d |= e.assignable & 2 ? 16 : 32))) : D === 14 ? (C = W2(e, u, i, 20, l, c, 0, t3, o, F, T, _), d |= e.destructible, e.token !== 18 && e.token !== 20 && f(e, 28, x[e.token & 255])) : (C = r2(e, u, 1, 0, 1, F, T, _), e.token !== 18 && e.token !== 20 ? (C = p(e, u, t3, o, F, T, _, C), (l & 3) < 1 && D === 67174411 && (d |= 16)) : e.assignable & 2 ? d |= 16 : D === 67174411 && (d |= e.assignable & 1 && l & 3 ? 32 : 16));
                if (h.push(C), J(e, u | 32768, 18)) {
                  if (e.token === 20)
                    break;
                } else
                  break;
              }
            w(e, u, 20);
            let y = v(e, u, s, r, b, { type: o ? "ArrayPattern" : "ArrayExpression", elements: h });
            return !n && e.token & 4194304 ? yu(e, u, d, t3, o, s, r, b, y) : (e.destructible = d, y);
          }
          function yu(e, u, i, n, t3, o, l, c, s) {
            e.token !== 1077936157 && f(e, 24), E(e, u | 32768), i & 16 && f(e, 24), t3 || v2(e, s);
            let { tokenPos: r, linePos: b, colPos: h } = e, d = G(e, u, 1, 1, n, r, b, h);
            return e.destructible = (i | 64 | 8) ^ 72 | (e.destructible & 128 ? 128 : 0) | (e.destructible & 256 ? 256 : 0), v(e, u, o, l, c, t3 ? { type: "AssignmentPattern", left: s, right: d } : { type: "AssignmentExpression", left: s, operator: "=", right: d });
          }
          function W2(e, u, i, n, t3, o, l, c, s, r, b, h) {
            E(e, u | 32768);
            let d = null, y = 0, { token: C, tokenValue: D, tokenPos: F, linePos: T, colPos: _ } = e;
            if (C & 143360)
              e.assignable = 1, d = g2(e, u, t3, 0, 1, 0, c, 1, F, T, _), C = e.token, d = K(e, u, d, c, 0, F, T, _), e.token !== 18 && e.token !== n && (e.assignable & 2 && e.token === 1077936157 && f(e, 68), y |= 16, d = p(e, u, c, s, F, T, _, d)), e.assignable & 2 ? y |= 16 : C === n || C === 18 ? i && B2(e, u, i, D, t3, o) : y |= 32, y |= e.destructible & 128 ? 128 : 0;
            else if (C === n)
              f(e, 39);
            else if (C & 2097152)
              d = e.token === 2162700 ? b2(e, u, i, 1, c, s, t3, o, F, T, _) : m2(e, u, i, 1, c, s, t3, o, F, T, _), C = e.token, C !== 1077936157 && C !== n && C !== 18 ? (e.destructible & 8 && f(e, 68), d = K(e, u, d, c, 0, F, T, _), y |= e.assignable & 2 ? 16 : 0, (e.token & 4194304) === 4194304 ? (e.token !== 1077936157 && (y |= 16), d = p(e, u, c, s, F, T, _, d)) : ((e.token & 8454144) === 8454144 && (d = T2(e, u, 1, F, T, _, 4, C, d)), J(e, u | 32768, 22) && (d = U2(e, u, d, F, T, _)), y |= e.assignable & 2 ? 16 : 32)) : y |= n === 1074790415 && C !== 1077936157 ? 16 : e.destructible;
            else {
              y |= 32, d = r2(e, u, 1, c, 1, e.tokenPos, e.linePos, e.colPos);
              let { token: i2, tokenPos: I, linePos: Y, colPos: P } = e;
              return i2 === 1077936157 && i2 !== n && i2 !== 18 ? (e.assignable & 2 && f(e, 24), d = p(e, u, c, s, I, Y, P, d), y |= 16) : (i2 === 18 ? y |= 16 : i2 !== n && (d = p(e, u, c, s, I, Y, P, d)), y |= e.assignable & 1 ? 32 : 16), e.destructible = y, e.token !== n && e.token !== 18 && f(e, 155), v(e, u, r, b, h, { type: s ? "RestElement" : "SpreadElement", argument: d });
            }
            if (e.token !== n)
              if (t3 & 1 && (y |= l ? 16 : 32), J(e, u | 32768, 1077936157)) {
                y & 16 && f(e, 24), v2(e, d);
                let i2 = G(e, u, 1, 1, c, e.tokenPos, e.linePos, e.colPos);
                d = v(e, u, F, T, _, s ? { type: "AssignmentPattern", left: d, right: i2 } : { type: "AssignmentExpression", left: d, operator: "=", right: i2 }), y = 16;
              } else
                y |= 16;
            return e.destructible = y, v(e, u, r, b, h, { type: s ? "RestElement" : "SpreadElement", argument: d });
          }
          function y2(e, u, i, n, t3, o, l) {
            let c = (i & 64) < 1 ? 31981568 : 14680064;
            u = (u | c) ^ c | (i & 88) << 18 | 100925440;
            let s = u & 64 ? t22(_2(), 512) : void 0, r = I0(e, u | 8388608, s, i, 1, n);
            s && (s = t22(s, 128));
            let b = d1(e, u & -134230017, s, 0, void 0, void 0);
            return v(e, u, t3, o, l, { type: "FunctionExpression", params: r, body: b, async: (i & 16) > 0, generator: (i & 8) > 0, id: null });
          }
          function T0(e, u, i, n, t3, o, l) {
            let c = b2(e, u, void 0, i, n, 0, 2, 0, t3, o, l);
            return u & 256 && e.destructible & 64 && f(e, 60), e.destructible & 8 && f(e, 59), c;
          }
          function b2(e, u, i, n, t3, o, l, c, s, r, b) {
            E(e, u);
            let h = [], d = 0, y = 0;
            for (u = (u | 134217728) ^ 134217728; e.token !== 1074790415; ) {
              let { token: D, tokenValue: F, linePos: T, colPos: _, tokenPos: i2 } = e;
              if (D === 14)
                h.push(W2(e, u, i, 1074790415, l, c, 0, t3, o, i2, T, _));
              else {
                let I = 0, Y = null, P, A2 = e.token;
                if (e.token & 143360 || e.token === 121)
                  if (Y = X(e, u, 0), e.token === 18 || e.token === 1074790415 || e.token === 1077936157)
                    if (I |= 4, u & 1024 && (D & 537079808) === 537079808 ? d |= 16 : l1(e, u, l, D, 0), i && B2(e, u, i, F, l, c), J(e, u | 32768, 1077936157)) {
                      d |= 8;
                      let V = G(e, u, 1, 1, t3, e.tokenPos, e.linePos, e.colPos);
                      d |= e.destructible & 256 ? 256 : 0 | e.destructible & 128 ? 128 : 0, P = v(e, u, i2, T, _, { type: "AssignmentPattern", left: u & -2147483648 ? Object.assign({}, Y) : Y, right: V });
                    } else
                      d |= (D === 209008 ? 128 : 0) | (D === 121 ? 16 : 0), P = u & -2147483648 ? Object.assign({}, Y) : Y;
                  else if (J(e, u | 32768, 21)) {
                    let { tokenPos: V, linePos: U, colPos: M } = e;
                    if (F === "__proto__" && y++, e.token & 143360) {
                      let J2 = e.token, Y2 = e.tokenValue;
                      d |= A2 === 121 ? 16 : 0, P = g2(e, u, l, 0, 1, 0, t3, 1, V, U, M);
                      let { token: C2 } = e;
                      P = K(e, u, P, t3, 0, V, U, M), e.token === 18 || e.token === 1074790415 ? C2 === 1077936157 || C2 === 1074790415 || C2 === 18 ? (d |= e.destructible & 128 ? 128 : 0, e.assignable & 2 ? d |= 16 : i && (J2 & 143360) === 143360 && B2(e, u, i, Y2, l, c)) : d |= e.assignable & 1 ? 32 : 16 : (e.token & 4194304) === 4194304 ? (e.assignable & 2 ? d |= 16 : C2 !== 1077936157 ? d |= 32 : i && B2(e, u, i, Y2, l, c), P = p(e, u, t3, o, V, U, M, P)) : (d |= 16, (e.token & 8454144) === 8454144 && (P = T2(e, u, 1, V, U, M, 4, C2, P)), J(e, u | 32768, 22) && (P = U2(e, u, P, V, U, M)));
                    } else
                      (e.token & 2097152) === 2097152 ? (P = e.token === 69271571 ? m2(e, u, i, 0, t3, o, l, c, V, U, M) : b2(e, u, i, 0, t3, o, l, c, V, U, M), d = e.destructible, e.assignable = d & 16 ? 2 : 1, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : e.destructible & 8 ? f(e, 68) : (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 2 ? 16 : 0, (e.token & 4194304) === 4194304 ? P = a1(e, u, t3, o, V, U, M, P) : ((e.token & 8454144) === 8454144 && (P = T2(e, u, 1, V, U, M, 4, D, P)), J(e, u | 32768, 22) && (P = U2(e, u, P, V, U, M)), d |= e.assignable & 2 ? 16 : 32))) : (P = r2(e, u, 1, t3, 1, V, U, M), d |= e.assignable & 1 ? 32 : 16, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 2 ? 16 : 0, e.token !== 18 && D !== 1074790415 && (e.token !== 1077936157 && (d |= 16), P = p(e, u, t3, o, V, U, M, P))));
                  } else
                    e.token === 69271571 ? (d |= 16, D === 209007 && (I |= 16), I |= (D === 12402 ? 256 : D === 12403 ? 512 : 1) | 2, Y = K2(e, u, t3), d |= e.assignable, P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : e.token & 143360 ? (d |= 16, D === 121 && f(e, 92), D === 209007 && (e.flags & 1 && f(e, 128), I |= 16), Y = X(e, u, 0), I |= D === 12402 ? 256 : D === 12403 ? 512 : 1, P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : e.token === 67174411 ? (d |= 16, I |= 1, P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : e.token === 8457014 ? (d |= 16, D === 12402 || D === 12403 ? f(e, 40) : D === 143483 && f(e, 92), E(e, u), I |= 9 | (D === 209007 ? 16 : 0), e.token & 143360 ? Y = X(e, u, 0) : (e.token & 134217728) === 134217728 ? Y = s2(e, u) : e.token === 69271571 ? (I |= 2, Y = K2(e, u, t3), d |= e.assignable) : f(e, 28, x[e.token & 255]), P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : (e.token & 134217728) === 134217728 ? (D === 209007 && (I |= 16), I |= D === 12402 ? 256 : D === 12403 ? 512 : 1, d |= 16, Y = s2(e, u), P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : f(e, 129);
                else if ((e.token & 134217728) === 134217728)
                  if (Y = s2(e, u), e.token === 21) {
                    w(e, u | 32768, 21);
                    let { tokenPos: V, linePos: U, colPos: M } = e;
                    if (F === "__proto__" && y++, e.token & 143360) {
                      P = g2(e, u, l, 0, 1, 0, t3, 1, V, U, M);
                      let { token: J2, tokenValue: Y2 } = e;
                      P = K(e, u, P, t3, 0, V, U, M), e.token === 18 || e.token === 1074790415 ? J2 === 1077936157 || J2 === 1074790415 || J2 === 18 ? e.assignable & 2 ? d |= 16 : i && B2(e, u, i, Y2, l, c) : d |= e.assignable & 1 ? 32 : 16 : e.token === 1077936157 ? (e.assignable & 2 && (d |= 16), P = p(e, u, t3, o, V, U, M, P)) : (d |= 16, P = p(e, u, t3, o, V, U, M, P));
                    } else
                      (e.token & 2097152) === 2097152 ? (P = e.token === 69271571 ? m2(e, u, i, 0, t3, o, l, c, V, U, M) : b2(e, u, i, 0, t3, o, l, c, V, U, M), d = e.destructible, e.assignable = d & 16 ? 2 : 1, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : (e.destructible & 8) !== 8 && (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 2 ? 16 : 0, (e.token & 4194304) === 4194304 ? P = a1(e, u, t3, o, V, U, M, P) : ((e.token & 8454144) === 8454144 && (P = T2(e, u, 1, V, U, M, 4, D, P)), J(e, u | 32768, 22) && (P = U2(e, u, P, V, U, M)), d |= e.assignable & 2 ? 16 : 32))) : (P = r2(e, u, 1, 0, 1, V, U, M), d |= e.assignable & 1 ? 32 : 16, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 1 ? 0 : 16, e.token !== 18 && e.token !== 1074790415 && (e.token !== 1077936157 && (d |= 16), P = p(e, u, t3, o, V, U, M, P))));
                  } else
                    e.token === 67174411 ? (I |= 1, P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos), d = e.assignable | 16) : f(e, 130);
                else if (e.token === 69271571)
                  if (Y = K2(e, u, t3), d |= e.destructible & 256 ? 256 : 0, I |= 2, e.token === 21) {
                    E(e, u | 32768);
                    let { tokenPos: V, linePos: U, colPos: M, tokenValue: J2, token: Y2 } = e;
                    if (e.token & 143360) {
                      P = g2(e, u, l, 0, 1, 0, t3, 1, V, U, M);
                      let { token: C2 } = e;
                      P = K(e, u, P, t3, 0, V, U, M), (e.token & 4194304) === 4194304 ? (d |= e.assignable & 2 ? 16 : C2 === 1077936157 ? 0 : 32, P = a1(e, u, t3, o, V, U, M, P)) : e.token === 18 || e.token === 1074790415 ? C2 === 1077936157 || C2 === 1074790415 || C2 === 18 ? e.assignable & 2 ? d |= 16 : i && (Y2 & 143360) === 143360 && B2(e, u, i, J2, l, c) : d |= e.assignable & 1 ? 32 : 16 : (d |= 16, P = p(e, u, t3, o, V, U, M, P));
                    } else
                      (e.token & 2097152) === 2097152 ? (P = e.token === 69271571 ? m2(e, u, i, 0, t3, o, l, c, V, U, M) : b2(e, u, i, 0, t3, o, l, c, V, U, M), d = e.destructible, e.assignable = d & 16 ? 2 : 1, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : d & 8 ? f(e, 59) : (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 2 ? d | 16 : 0, (e.token & 4194304) === 4194304 ? (e.token !== 1077936157 && (d |= 16), P = a1(e, u, t3, o, V, U, M, P)) : ((e.token & 8454144) === 8454144 && (P = T2(e, u, 1, V, U, M, 4, D, P)), J(e, u | 32768, 22) && (P = U2(e, u, P, V, U, M)), d |= e.assignable & 2 ? 16 : 32))) : (P = r2(e, u, 1, 0, 1, V, U, M), d |= e.assignable & 1 ? 32 : 16, e.token === 18 || e.token === 1074790415 ? e.assignable & 2 && (d |= 16) : (P = K(e, u, P, t3, 0, V, U, M), d = e.assignable & 1 ? 0 : 16, e.token !== 18 && e.token !== 1074790415 && (e.token !== 1077936157 && (d |= 16), P = p(e, u, t3, o, V, U, M, P))));
                  } else
                    e.token === 67174411 ? (I |= 1, P = y2(e, u, I, t3, e.tokenPos, T, _), d = 16) : f(e, 41);
                else if (D === 8457014)
                  if (w(e, u | 32768, 8457014), I |= 8, e.token & 143360) {
                    let { token: V, line: U, index: M } = e;
                    Y = X(e, u, 0), I |= 1, e.token === 67174411 ? (d |= 16, P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : S(M, U, M, V === 209007 ? 43 : V === 12402 || e.token === 12403 ? 42 : 44, x[V & 255]);
                  } else
                    (e.token & 134217728) === 134217728 ? (d |= 16, Y = s2(e, u), I |= 1, P = y2(e, u, I, t3, i2, T, _)) : e.token === 69271571 ? (d |= 16, I |= 3, Y = K2(e, u, t3), P = y2(e, u, I, t3, e.tokenPos, e.linePos, e.colPos)) : f(e, 122);
                else
                  f(e, 28, x[D & 255]);
                d |= e.destructible & 128 ? 128 : 0, e.destructible = d, h.push(v(e, u, i2, T, _, { type: "Property", key: Y, value: P, kind: I & 768 ? I & 512 ? "set" : "get" : "init", computed: (I & 2) > 0, method: (I & 1) > 0, shorthand: (I & 4) > 0 }));
              }
              if (d |= e.destructible, e.token !== 18)
                break;
              E(e, u);
            }
            w(e, u, 1074790415), y > 1 && (d |= 64);
            let C = v(e, u, s, r, b, { type: o ? "ObjectPattern" : "ObjectExpression", properties: h });
            return !n && e.token & 4194304 ? yu(e, u, d, t3, o, s, r, b, C) : (e.destructible = d, C);
          }
          function I0(e, u, i, n, t3, o) {
            w(e, u, 67174411);
            let l = [];
            if (e.flags = (e.flags | 128) ^ 128, e.token === 16)
              return n & 512 && f(e, 35, "Setter", "one", ""), E(e, u), l;
            n & 256 && f(e, 35, "Getter", "no", "s"), n & 512 && e.token === 14 && f(e, 36), u = (u | 134217728) ^ 134217728;
            let c = 0, s = 0;
            for (; e.token !== 18; ) {
              let r = null, { tokenPos: b, linePos: h, colPos: d } = e;
              if (e.token & 143360 ? ((u & 1024) < 1 && ((e.token & 36864) === 36864 && (e.flags |= 256), (e.token & 537079808) === 537079808 && (e.flags |= 512)), r = p1(e, u, i, n | 1, 0, b, h, d)) : (e.token === 2162700 ? r = b2(e, u, i, 1, o, 1, t3, 0, b, h, d) : e.token === 69271571 ? r = m2(e, u, i, 1, o, 1, t3, 0, b, h, d) : e.token === 14 && (r = W2(e, u, i, 16, t3, 0, 0, o, 1, b, h, d)), s = 1, e.destructible & 48 && f(e, 47)), e.token === 1077936157) {
                E(e, u | 32768), s = 1;
                let y = G(e, u, 1, 1, 0, e.tokenPos, e.linePos, e.colPos);
                r = v(e, u, b, h, d, { type: "AssignmentPattern", left: r, right: y });
              }
              if (c++, l.push(r), !J(e, u, 18) || e.token === 16)
                break;
            }
            return n & 512 && c !== 1 && f(e, 35, "Setter", "one", ""), i && i.scopeError !== void 0 && A(i.scopeError), s && (e.flags |= 128), w(e, u, 16), l;
          }
          function K2(e, u, i) {
            E(e, u | 32768);
            let n = G(e, (u | 134217728) ^ 134217728, 1, 0, i, e.tokenPos, e.linePos, e.colPos);
            return w(e, u, 20), n;
          }
          function R0(e, u, i, n, t3, o, l, c) {
            e.flags = (e.flags | 128) ^ 128;
            let { tokenPos: s, linePos: r, colPos: b } = e;
            E(e, u | 32768 | 1073741824);
            let h = u & 64 ? t22(_2(), 1024) : void 0;
            if (u = (u | 134217728) ^ 134217728, J(e, u, 16))
              return r1(e, u, h, [], i, 0, o, l, c);
            let d = 0;
            e.destructible &= -385;
            let y, C = [], D = 0, F = 0, { tokenPos: T, linePos: _, colPos: i2 } = e;
            for (e.assignable = 1; e.token !== 16; ) {
              let { token: I, tokenPos: Y, linePos: P, colPos: A2 } = e;
              if (I & 143360)
                h && L2(e, u, h, e.tokenValue, 1, 0), y = g2(e, u, n, 0, 1, 0, 1, 1, Y, P, A2), e.token === 16 || e.token === 18 ? e.assignable & 2 ? (d |= 16, F = 1) : ((I & 537079808) === 537079808 || (I & 36864) === 36864) && (F = 1) : (e.token === 1077936157 ? F = 1 : d |= 16, y = K(e, u, y, 1, 0, Y, P, A2), e.token !== 16 && e.token !== 18 && (y = p(e, u, 1, 0, Y, P, A2, y)));
              else if ((I & 2097152) === 2097152)
                y = I === 2162700 ? b2(e, u | 1073741824, h, 0, 1, 0, n, t3, Y, P, A2) : m2(e, u | 1073741824, h, 0, 1, 0, n, t3, Y, P, A2), d |= e.destructible, F = 1, e.assignable = 2, e.token !== 16 && e.token !== 18 && (d & 8 && f(e, 118), y = K(e, u, y, 0, 0, Y, P, A2), d |= 16, e.token !== 16 && e.token !== 18 && (y = p(e, u, 0, 0, Y, P, A2, y)));
              else if (I === 14) {
                y = W2(e, u, h, 16, n, t3, 0, 1, 0, Y, P, A2), e.destructible & 16 && f(e, 71), F = 1, D && (e.token === 16 || e.token === 18) && C.push(y), d |= 8;
                break;
              } else {
                if (d |= 16, y = G(e, u, 1, 0, 1, Y, P, A2), D && (e.token === 16 || e.token === 18) && C.push(y), e.token === 18 && (D || (D = 1, C = [y])), D) {
                  for (; J(e, u | 32768, 18); )
                    C.push(G(e, u, 1, 0, 1, e.tokenPos, e.linePos, e.colPos));
                  e.assignable = 2, y = v(e, u, T, _, i2, { type: "SequenceExpression", expressions: C });
                }
                return w(e, u, 16), e.destructible = d, y;
              }
              if (D && (e.token === 16 || e.token === 18) && C.push(y), !J(e, u | 32768, 18))
                break;
              if (D || (D = 1, C = [y]), e.token === 16) {
                d |= 8;
                break;
              }
            }
            return D && (e.assignable = 2, y = v(e, u, T, _, i2, { type: "SequenceExpression", expressions: C })), w(e, u, 16), d & 16 && d & 8 && f(e, 145), d |= e.destructible & 256 ? 256 : 0 | e.destructible & 128 ? 128 : 0, e.token === 10 ? (d & 48 && f(e, 46), u & 4196352 && d & 128 && f(e, 29), u & 2098176 && d & 256 && f(e, 30), F && (e.flags |= 128), r1(e, u, h, D ? C : [y], i, 0, o, l, c)) : (d & 8 && f(e, 139), e.destructible = (e.destructible | 256) ^ 256 | d, u & 128 ? v(e, u, s, r, b, { type: "ParenthesizedExpression", expression: y }) : y);
          }
          function Q1(e, u, i, n, t3) {
            let { tokenValue: o } = e, l = X(e, u, 0);
            if (e.assignable = 1, e.token === 10) {
              let c;
              return u & 64 && (c = c1(e, u, o)), e.flags = (e.flags | 128) ^ 128, e1(e, u, c, [l], 0, i, n, t3);
            }
            return l;
          }
          function h1(e, u, i, n, t3, o, l, c, s, r) {
            o || f(e, 54), t3 && f(e, 48), e.flags &= -129;
            let b = u & 64 ? c1(e, u, i) : void 0;
            return e1(e, u, b, [n], l, c, s, r);
          }
          function r1(e, u, i, n, t3, o, l, c, s) {
            t3 || f(e, 54);
            for (let r = 0; r < n.length; ++r)
              v2(e, n[r]);
            return e1(e, u, i, n, o, l, c, s);
          }
          function e1(e, u, i, n, t3, o, l, c) {
            e.flags & 1 && f(e, 45), w(e, u | 32768, 10), u = (u | 15728640) ^ 15728640 | t3 << 22;
            let s = e.token !== 2162700, r;
            if (i && i.scopeError !== void 0 && A(i.scopeError), s)
              r = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            else {
              switch (i && (i = t22(i, 128)), r = d1(e, (u | 134221824 | 8192 | 16384) ^ 134246400, i, 16, void 0, void 0), e.token) {
                case 69271571:
                  (e.flags & 1) < 1 && f(e, 112);
                  break;
                case 67108877:
                case 67174409:
                case 22:
                  f(e, 113);
                case 67174411:
                  (e.flags & 1) < 1 && f(e, 112), e.flags |= 1024;
                  break;
              }
              (e.token & 8454144) === 8454144 && (e.flags & 1) < 1 && f(e, 28, x[e.token & 255]), (e.token & 33619968) === 33619968 && f(e, 121);
            }
            return e.assignable = 2, v(e, u, o, l, c, { type: "ArrowFunctionExpression", params: n, body: r, async: t3 === 1, expression: s });
          }
          function Au(e, u, i, n, t3) {
            w(e, u, 67174411), e.flags = (e.flags | 128) ^ 128;
            let o = [];
            if (J(e, u, 16))
              return o;
            u = (u | 134217728) ^ 134217728;
            let l = 0;
            for (; e.token !== 18; ) {
              let c, { tokenPos: s, linePos: r, colPos: b } = e;
              if (e.token & 143360 ? ((u & 1024) < 1 && ((e.token & 36864) === 36864 && (e.flags |= 256), (e.token & 537079808) === 537079808 && (e.flags |= 512)), c = p1(e, u, i, t3 | 1, 0, s, r, b)) : (e.token === 2162700 ? c = b2(e, u, i, 1, n, 1, t3, 0, s, r, b) : e.token === 69271571 ? c = m2(e, u, i, 1, n, 1, t3, 0, s, r, b) : e.token === 14 ? c = W2(e, u, i, 16, t3, 0, 0, n, 1, s, r, b) : f(e, 28, x[e.token & 255]), l = 1, e.destructible & 48 && f(e, 47)), e.token === 1077936157) {
                E(e, u | 32768), l = 1;
                let h = G(e, u, 1, 1, n, e.tokenPos, e.linePos, e.colPos);
                c = v(e, u, s, r, b, { type: "AssignmentPattern", left: c, right: h });
              }
              if (o.push(c), !J(e, u, 18) || e.token === 16)
                break;
            }
            return l && (e.flags |= 128), i && (l || u & 1024) && i.scopeError !== void 0 && A(i.scopeError), w(e, u, 16), o;
          }
          function m1(e, u, i, n, t3, o, l) {
            let { token: c } = e;
            if (c & 67108864) {
              if (c === 67108877) {
                E(e, u | 1073741824), e.assignable = 1;
                let s = ru(e, u);
                return m1(e, u, v(e, u, t3, o, l, { type: "MemberExpression", object: i, computed: false, property: s }), 0, t3, o, l);
              } else if (c === 69271571) {
                E(e, u | 32768);
                let { tokenPos: s, linePos: r, colPos: b } = e, h = l2(e, u, n, 1, s, r, b);
                return w(e, u, 20), e.assignable = 1, m1(e, u, v(e, u, t3, o, l, { type: "MemberExpression", object: i, computed: true, property: h }), 0, t3, o, l);
              } else if (c === 67174408 || c === 67174409)
                return e.assignable = 2, m1(e, u, v(e, u, t3, o, l, { type: "TaggedTemplateExpression", tag: i, quasi: e.token === 67174408 ? Y1(e, u | 65536) : K1(e, u, e.tokenPos, e.linePos, e.colPos) }), 0, t3, o, l);
            }
            return i;
          }
          function N0(e, u, i, n, t3, o) {
            let l = X(e, u | 32768, 0), { tokenPos: c, linePos: s, colPos: r } = e;
            if (J(e, u, 67108877)) {
              if (u & 67108864 && e.token === 143494)
                return e.assignable = 2, V0(e, u, l, n, t3, o);
              f(e, 91);
            }
            e.assignable = 2, (e.token & 16842752) === 16842752 && f(e, 62, x[e.token & 255]);
            let b = g2(e, u, 2, 1, 0, 0, i, 1, c, s, r);
            u = (u | 134217728) ^ 134217728, e.token === 67108991 && f(e, 162);
            let h = m1(e, u, b, i, c, s, r);
            return e.assignable = 2, v(e, u, n, t3, o, { type: "NewExpression", callee: h, arguments: e.token === 67174411 ? Z1(e, u, i) : [] });
          }
          function V0(e, u, i, n, t3, o) {
            let l = X(e, u, 0);
            return v(e, u, n, t3, o, { type: "MetaProperty", meta: i, property: l });
          }
          function Pu(e, u, i, n, t3, o) {
            return e.token === 209008 && f(e, 29), u & 2098176 && e.token === 241773 && f(e, 30), (e.token & 537079808) === 537079808 && (e.flags |= 512), h1(e, u, e.tokenValue, X(e, u, 0), 0, i, 1, n, t3, o);
          }
          function G1(e, u, i, n, t3, o, l, c, s, r) {
            E(e, u | 32768);
            let b = u & 64 ? t22(_2(), 1024) : void 0;
            if (u = (u | 134217728) ^ 134217728, J(e, u, 16))
              return e.token === 10 ? (l & 1 && f(e, 45), r1(e, u, b, [], n, 1, c, s, r)) : v(e, u, c, s, r, { type: "CallExpression", callee: i, arguments: [] });
            let h = 0, d = null, y = 0;
            e.destructible = (e.destructible | 256 | 128) ^ 384;
            let C = [];
            for (; e.token !== 16; ) {
              let { token: D, tokenPos: F, linePos: T, colPos: _ } = e;
              if (D & 143360)
                b && L2(e, u, b, e.tokenValue, t3, 0), d = g2(e, u, t3, 0, 1, 0, 1, 1, F, T, _), e.token === 16 || e.token === 18 ? e.assignable & 2 ? (h |= 16, y = 1) : (D & 537079808) === 537079808 ? e.flags |= 512 : (D & 36864) === 36864 && (e.flags |= 256) : (e.token === 1077936157 ? y = 1 : h |= 16, d = K(e, u, d, 1, 0, F, T, _), e.token !== 16 && e.token !== 18 && (d = p(e, u, 1, 0, F, T, _, d)));
              else if (D & 2097152)
                d = D === 2162700 ? b2(e, u, b, 0, 1, 0, t3, o, F, T, _) : m2(e, u, b, 0, 1, 0, t3, o, F, T, _), h |= e.destructible, y = 1, e.token !== 16 && e.token !== 18 && (h & 8 && f(e, 118), d = K(e, u, d, 0, 0, F, T, _), h |= 16, (e.token & 8454144) === 8454144 && (d = T2(e, u, 1, c, s, r, 4, D, d)), J(e, u | 32768, 22) && (d = U2(e, u, d, c, s, r)));
              else if (D === 14)
                d = W2(e, u, b, 16, t3, o, 1, 1, 0, F, T, _), h |= (e.token === 16 ? 0 : 16) | e.destructible, y = 1;
              else {
                for (d = G(e, u, 1, 0, 0, F, T, _), h = e.assignable, C.push(d); J(e, u | 32768, 18); )
                  C.push(G(e, u, 1, 0, 0, F, T, _));
                return h |= e.assignable, w(e, u, 16), e.destructible = h | 16, e.assignable = 2, v(e, u, c, s, r, { type: "CallExpression", callee: i, arguments: C });
              }
              if (C.push(d), !J(e, u | 32768, 18))
                break;
            }
            return w(e, u, 16), h |= e.destructible & 256 ? 256 : 0 | e.destructible & 128 ? 128 : 0, e.token === 10 ? (h & 48 && f(e, 25), (e.flags & 1 || l & 1) && f(e, 45), h & 128 && f(e, 29), u & 2098176 && h & 256 && f(e, 30), y && (e.flags |= 128), r1(e, u, b, C, n, 1, c, s, r)) : (h & 8 && f(e, 59), e.assignable = 2, v(e, u, c, s, r, { type: "CallExpression", callee: i, arguments: C }));
          }
          function j0(e, u, i, n, t3) {
            let { tokenRaw: o, tokenRegExp: l, tokenValue: c } = e;
            return E(e, u), e.assignable = 2, u & 512 ? v(e, u, i, n, t3, { type: "Literal", value: c, regex: l, raw: o }) : v(e, u, i, n, t3, { type: "Literal", value: c, regex: l });
          }
          function x1(e, u, i, n, t3, o, l) {
            u = (u | 16777216 | 1024) ^ 16777216;
            let c = b1(e, u);
            c.length && (t3 = e.tokenPos, o = e.linePos, l = e.colPos), e.leadingDecorators.length && (e.leadingDecorators.push(...c), c = e.leadingDecorators, e.leadingDecorators = []), E(e, u);
            let s = null, r = null, { tokenValue: b } = e;
            e.token & 4096 && e.token !== 20567 ? (iu(e, u, e.token) && f(e, 114), (e.token & 537079808) === 537079808 && f(e, 115), i && (L2(e, u, i, b, 32, 0), n && n & 2 && M2(e, b)), s = X(e, u, 0)) : (n & 1) < 1 && f(e, 37, "Class");
            let h = u;
            J(e, u | 32768, 20567) ? (r = r2(e, u, 0, 0, 0, e.tokenPos, e.linePos, e.colPos), h |= 524288) : h = (h | 524288) ^ 524288;
            let d = Eu(e, h, u, i, 2, 8, 0);
            return v(e, u, t3, o, l, u & 1 ? { type: "ClassDeclaration", id: s, superClass: r, decorators: c, body: d } : { type: "ClassDeclaration", id: s, superClass: r, body: d });
          }
          function _0(e, u, i, n, t3, o) {
            let l = null, c = null;
            u = (u | 1024 | 16777216) ^ 16777216;
            let s = b1(e, u);
            s.length && (n = e.tokenPos, t3 = e.linePos, o = e.colPos), E(e, u), e.token & 4096 && e.token !== 20567 && (iu(e, u, e.token) && f(e, 114), (e.token & 537079808) === 537079808 && f(e, 115), l = X(e, u, 0));
            let r = u;
            J(e, u | 32768, 20567) ? (c = r2(e, u, 0, i, 0, e.tokenPos, e.linePos, e.colPos), r |= 524288) : r = (r | 524288) ^ 524288;
            let b = Eu(e, r, u, void 0, 2, 0, i);
            return e.assignable = 2, v(e, u, n, t3, o, u & 1 ? { type: "ClassExpression", id: l, superClass: c, decorators: s, body: b } : { type: "ClassExpression", id: l, superClass: c, body: b });
          }
          function b1(e, u) {
            let i = [];
            if (u & 1)
              for (; e.token === 133; )
                i.push(M0(e, u, e.tokenPos, e.linePos, e.colPos));
            return i;
          }
          function M0(e, u, i, n, t3) {
            E(e, u | 32768);
            let o = g2(e, u, 2, 0, 1, 0, 0, 1, i, n, t3);
            return o = K(e, u, o, 0, 0, i, n, t3), v(e, u, i, n, t3, { type: "Decorator", expression: o });
          }
          function Eu(e, u, i, n, t3, o, l) {
            let { tokenPos: c, linePos: s, colPos: r } = e;
            w(e, u | 32768, 2162700), u = (u | 134217728) ^ 134217728, e.flags = (e.flags | 32) ^ 32;
            let b = [], h;
            for (; e.token !== 1074790415; ) {
              let d = 0;
              if (h = b1(e, u), d = h.length, d > 0 && e.tokenValue === "constructor" && f(e, 106), e.token === 1074790415 && f(e, 105), J(e, u, 1074790417)) {
                d > 0 && f(e, 116);
                continue;
              }
              b.push(Du(e, u, n, i, t3, h, 0, l, e.tokenPos, e.linePos, e.colPos));
            }
            return w(e, o & 8 ? u | 32768 : u, 1074790415), v(e, u, c, s, r, { type: "ClassBody", body: b });
          }
          function Du(e, u, i, n, t3, o, l, c, s, r, b) {
            let h = l ? 32 : 0, d = null, { token: y, tokenPos: C, linePos: D, colPos: F } = e;
            if (y & 176128)
              switch (d = X(e, u, 0), y) {
                case 36972:
                  if (!l && e.token !== 67174411)
                    return Du(e, u, i, n, t3, o, 1, c, s, r, b);
                  break;
                case 209007:
                  if (e.token !== 67174411 && (e.flags & 1) < 1) {
                    if (u & 1 && (e.token & 1073741824) === 1073741824)
                      return v1(e, u, d, h, o, C, D, F);
                    h |= 16 | (M1(e, u, 8457014) ? 8 : 0);
                  }
                  break;
                case 12402:
                  if (e.token !== 67174411) {
                    if (u & 1 && (e.token & 1073741824) === 1073741824)
                      return v1(e, u, d, h, o, C, D, F);
                    h |= 256;
                  }
                  break;
                case 12403:
                  if (e.token !== 67174411) {
                    if (u & 1 && (e.token & 1073741824) === 1073741824)
                      return v1(e, u, d, h, o, C, D, F);
                    h |= 512;
                  }
                  break;
              }
            else
              y === 69271571 ? (h |= 2, d = K2(e, n, c)) : (y & 134217728) === 134217728 ? d = s2(e, u) : y === 8457014 ? (h |= 8, E(e, u)) : u & 1 && e.token === 131 ? (h |= 4096, d = k1(e, u | 16384, C, D, F)) : u & 1 && (e.token & 1073741824) === 1073741824 ? h |= 128 : y === 122 ? (d = X(e, u, 0), e.token !== 67174411 && f(e, 28, x[e.token & 255])) : f(e, 28, x[e.token & 255]);
            if (h & 792 && (e.token & 143360 ? d = X(e, u, 0) : (e.token & 134217728) === 134217728 ? d = s2(e, u) : e.token === 69271571 ? (h |= 2, d = K2(e, u, 0)) : e.token === 122 ? d = X(e, u, 0) : u & 1 && e.token === 131 ? (h |= 4096, d = k1(e, u, C, D, F)) : f(e, 131)), (h & 2) < 1 && (e.tokenValue === "constructor" ? ((e.token & 1073741824) === 1073741824 ? f(e, 125) : (h & 32) < 1 && e.token === 67174411 && (h & 920 ? f(e, 50, "accessor") : (u & 524288) < 1 && (e.flags & 32 ? f(e, 51) : e.flags |= 32)), h |= 64) : (h & 4096) < 1 && h & 824 && e.tokenValue === "prototype" && f(e, 49)), u & 1 && e.token !== 67174411)
              return v1(e, u, d, h, o, C, D, F);
            let T = y2(e, u, h, c, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, s, r, b, u & 1 ? { type: "MethodDefinition", kind: (h & 32) < 1 && h & 64 ? "constructor" : h & 256 ? "get" : h & 512 ? "set" : "method", static: (h & 32) > 0, computed: (h & 2) > 0, key: d, decorators: o, value: T } : { type: "MethodDefinition", kind: (h & 32) < 1 && h & 64 ? "constructor" : h & 256 ? "get" : h & 512 ? "set" : "method", static: (h & 32) > 0, computed: (h & 2) > 0, key: d, value: T });
          }
          function k1(e, u, i, n, t3) {
            E(e, u);
            let { tokenValue: o } = e;
            return o === "constructor" && f(e, 124), E(e, u), v(e, u, i, n, t3, { type: "PrivateIdentifier", name: o });
          }
          function v1(e, u, i, n, t3, o, l, c) {
            let s = null;
            if (n & 8 && f(e, 0), e.token === 1077936157) {
              E(e, u | 32768);
              let { tokenPos: r, linePos: b, colPos: h } = e;
              e.token === 537079928 && f(e, 115), s = g2(e, u | 16384, 2, 0, 1, 0, 0, 1, r, b, h), (e.token & 1073741824) !== 1073741824 && (s = K(e, u | 16384, s, 0, 0, r, b, h), s = p(e, u | 16384, 0, 0, r, b, h, s), e.token === 18 && (s = O2(e, u, 0, o, l, c, s)));
            }
            return v(e, u, o, l, c, { type: "PropertyDefinition", key: i, value: s, static: (n & 32) > 0, computed: (n & 2) > 0, decorators: t3 });
          }
          function Cu(e, u, i, n, t3, o, l, c) {
            if (e.token & 143360)
              return p1(e, u, i, n, t3, o, l, c);
            (e.token & 2097152) !== 2097152 && f(e, 28, x[e.token & 255]);
            let s = e.token === 69271571 ? m2(e, u, i, 1, 0, 1, n, t3, o, l, c) : b2(e, u, i, 1, 0, 1, n, t3, o, l, c);
            return e.destructible & 16 && f(e, 47), e.destructible & 32 && f(e, 47), s;
          }
          function p1(e, u, i, n, t3, o, l, c) {
            let { tokenValue: s, token: r } = e;
            return u & 1024 && ((r & 537079808) === 537079808 ? f(e, 115) : (r & 36864) === 36864 && f(e, 114)), (r & 20480) === 20480 && f(e, 99), u & 2099200 && r === 241773 && f(e, 30), r === 241739 && n & 24 && f(e, 97), u & 4196352 && r === 209008 && f(e, 95), E(e, u), i && B2(e, u, i, s, n, t3), v(e, u, o, l, c, { type: "Identifier", name: s });
          }
          function ee(e, u, i, n, t3, o) {
            if (E(e, u), e.token === 8456259)
              return v(e, u, n, t3, o, { type: "JSXFragment", openingFragment: U0(e, u, n, t3, o), children: wu(e, u), closingFragment: $0(e, u, i, e.tokenPos, e.linePos, e.colPos) });
            let l = null, c = [], s = z0(e, u, i, n, t3, o);
            if (!s.selfClosing) {
              c = wu(e, u), l = J0(e, u, i, e.tokenPos, e.linePos, e.colPos);
              let r = f1(l.name);
              f1(s.name) !== r && f(e, 149, r);
            }
            return v(e, u, n, t3, o, { type: "JSXElement", children: c, openingElement: s, closingElement: l });
          }
          function U0(e, u, i, n, t3) {
            return j2(e, u), v(e, u, i, n, t3, { type: "JSXOpeningFragment" });
          }
          function J0(e, u, i, n, t3, o) {
            w(e, u, 25);
            let l = qu(e, u, e.tokenPos, e.linePos, e.colPos);
            return i ? w(e, u, 8456259) : e.token = j2(e, u), v(e, u, n, t3, o, { type: "JSXClosingElement", name: l });
          }
          function $0(e, u, i, n, t3, o) {
            return w(e, u, 25), w(e, u, 8456259), v(e, u, n, t3, o, { type: "JSXClosingFragment" });
          }
          function wu(e, u) {
            let i = [];
            for (; e.token !== 25; )
              e.index = e.tokenPos = e.startPos, e.column = e.colPos = e.startColumn, e.line = e.linePos = e.startLine, j2(e, u), i.push(H0(e, u, e.tokenPos, e.linePos, e.colPos));
            return i;
          }
          function H0(e, u, i, n, t3) {
            if (e.token === 138)
              return X0(e, u, i, n, t3);
            if (e.token === 2162700)
              return Su(e, u, 0, 0, i, n, t3);
            if (e.token === 8456258)
              return ee(e, u, 0, i, n, t3);
            f(e, 0);
          }
          function X0(e, u, i, n, t3) {
            j2(e, u);
            let o = { type: "JSXText", value: e.tokenValue };
            return u & 512 && (o.raw = e.tokenRaw), v(e, u, i, n, t3, o);
          }
          function z0(e, u, i, n, t3, o) {
            (e.token & 143360) !== 143360 && (e.token & 4096) !== 4096 && f(e, 0);
            let l = qu(e, u, e.tokenPos, e.linePos, e.colPos), c = K0(e, u), s = e.token === 8457016;
            return e.token === 8456259 ? j2(e, u) : (w(e, u, 8457016), i ? w(e, u, 8456259) : j2(e, u)), v(e, u, n, t3, o, { type: "JSXOpeningElement", name: l, attributes: c, selfClosing: s });
          }
          function qu(e, u, i, n, t3) {
            _1(e);
            let o = y1(e, u, i, n, t3);
            if (e.token === 21)
              return Bu(e, u, o, i, n, t3);
            for (; J(e, u, 67108877); )
              _1(e), o = W0(e, u, o, i, n, t3);
            return o;
          }
          function W0(e, u, i, n, t3, o) {
            let l = y1(e, u, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, n, t3, o, { type: "JSXMemberExpression", object: i, property: l });
          }
          function K0(e, u) {
            let i = [];
            for (; e.token !== 8457016 && e.token !== 8456259 && e.token !== 1048576; )
              i.push(Z0(e, u, e.tokenPos, e.linePos, e.colPos));
            return i;
          }
          function Y0(e, u, i, n, t3) {
            E(e, u), w(e, u, 14);
            let o = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            return w(e, u, 1074790415), v(e, u, i, n, t3, { type: "JSXSpreadAttribute", argument: o });
          }
          function Z0(e, u, i, n, t3) {
            if (e.token === 2162700)
              return Y0(e, u, i, n, t3);
            _1(e);
            let o = null, l = y1(e, u, i, n, t3);
            if (e.token === 21 && (l = Bu(e, u, l, i, n, t3)), e.token === 1077936157) {
              let c = Ht(e, u), { tokenPos: s, linePos: r, colPos: b } = e;
              switch (c) {
                case 134283267:
                  o = s2(e, u);
                  break;
                case 8456258:
                  o = ee(e, u, 1, s, r, b);
                  break;
                case 2162700:
                  o = Su(e, u, 1, 1, s, r, b);
                  break;
                default:
                  f(e, 148);
              }
            }
            return v(e, u, i, n, t3, { type: "JSXAttribute", value: o, name: l });
          }
          function Bu(e, u, i, n, t3, o) {
            w(e, u, 21);
            let l = y1(e, u, e.tokenPos, e.linePos, e.colPos);
            return v(e, u, n, t3, o, { type: "JSXNamespacedName", namespace: i, name: l });
          }
          function Su(e, u, i, n, t3, o, l) {
            E(e, u | 32768);
            let { tokenPos: c, linePos: s, colPos: r } = e;
            if (e.token === 14)
              return Q0(e, u, c, s, r);
            let b = null;
            return e.token === 1074790415 ? (n && f(e, 151), b = G0(e, u, e.startPos, e.startLine, e.startColumn)) : b = G(e, u, 1, 0, 0, c, s, r), i ? w(e, u, 1074790415) : j2(e, u), v(e, u, t3, o, l, { type: "JSXExpressionContainer", expression: b });
          }
          function Q0(e, u, i, n, t3) {
            w(e, u, 14);
            let o = G(e, u, 1, 0, 0, e.tokenPos, e.linePos, e.colPos);
            return w(e, u, 1074790415), v(e, u, i, n, t3, { type: "JSXSpreadChild", expression: o });
          }
          function G0(e, u, i, n, t3) {
            return e.startPos = e.tokenPos, e.startLine = e.linePos, e.startColumn = e.colPos, v(e, u, i, n, t3, { type: "JSXEmptyExpression" });
          }
          function y1(e, u, i, n, t3) {
            let { tokenValue: o } = e;
            return E(e, u), v(e, u, i, n, t3, { type: "JSXIdentifier", name: o });
          }
          var x0 = Object.freeze({ __proto__: null }), p0 = "4.2.1", eo = p0;
          function uo(e, u) {
            return H1(e, u, 0);
          }
          function io(e, u) {
            return H1(e, u, 3072);
          }
          function no(e, u) {
            return H1(e, u, 0);
          }
          a.ESTree = x0, a.parse = no, a.parseModule = io, a.parseScript = uo, a.version = eo;
        } });
        n2();
        var V3 = bt(), j3 = v3(), _3 = S3(), M3 = R3(), U3 = { module: true, next: true, ranges: true, webcompat: true, loc: true, raw: true, directives: true, globalReturn: true, impliedStrict: false, preserveParens: false, lexical: false, identifierPattern: false, jsx: true, specDeviation: true, uniqueKeyInPattern: false };
        function rt(a, g) {
          let { parse: m } = N3(), f = [], A = [], S = m(a, Object.assign(Object.assign({}, U3), {}, { module: g, onComment: f, onToken: A }));
          return S.comments = f, S.tokens = A, S;
        }
        function J3(a) {
          let { message: g, line: m, column: f } = a, A = (g.match(/^\[(?<line>\d+):(?<column>\d+)]: (?<message>.*)$/) || {}).groups;
          return A && (g = A.message, typeof m != "number" && (m = Number(A.line), f = Number(A.column))), typeof m != "number" ? a : V3(g, { start: { line: m, column: f } });
        }
        function $3(a, g) {
          let m = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, { result: f, error: A } = j3(() => rt(a, true), () => rt(a, false));
          if (!f)
            throw J3(A);
          return m.originalText = a, M3(f, m);
        }
        Rt.exports = { parsers: { meriyah: _3($3) } };
      });
      return H3();
    });
  }
});

// node_modules/prettier/parser-postcss.js
var require_parser_postcss = __commonJS({
  "node_modules/prettier/parser-postcss.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.postcss = e();
      }
    })(function() {
      "use strict";
      var U = (e, n) => () => (n || e((n = { exports: {} }).exports, n), n.exports);
      var pe = U((wp, Gt) => {
        var er = function(e) {
          return e && e.Math == Math && e;
        };
        Gt.exports = er(typeof globalThis == "object" && globalThis) || er(typeof window == "object" && window) || er(typeof self == "object" && self) || er(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var be = U((_p, Ht) => {
        Ht.exports = function(e) {
          try {
            return !!e();
          } catch {
            return true;
          }
        };
      });
      var Oe = U((bp, Jt) => {
        var _a = be();
        Jt.exports = !_a(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var Tr = U((xp, Kt) => {
        var ba = be();
        Kt.exports = !ba(function() {
          var e = function() {
          }.bind();
          return typeof e != "function" || e.hasOwnProperty("prototype");
        });
      });
      var tr = U((Sp, Qt) => {
        var xa = Tr(), rr = Function.prototype.call;
        Qt.exports = xa ? rr.bind(rr) : function() {
          return rr.apply(rr, arguments);
        };
      });
      var en = U((Zt) => {
        "use strict";
        var Yt = {}.propertyIsEnumerable, Xt = Object.getOwnPropertyDescriptor, Sa = Xt && !Yt.call({ 1: 2 }, 1);
        Zt.f = Sa ? function(n) {
          var i = Xt(this, n);
          return !!i && i.enumerable;
        } : Yt;
      });
      var Er = U((Op, rn) => {
        rn.exports = function(e, n) {
          return { enumerable: !(e & 1), configurable: !(e & 2), writable: !(e & 4), value: n };
        };
      });
      var xe = U((Tp, sn) => {
        var tn = Tr(), nn = Function.prototype, qr = nn.call, ka = tn && nn.bind.bind(qr, qr);
        sn.exports = tn ? ka : function(e) {
          return function() {
            return qr.apply(e, arguments);
          };
        };
      });
      var un = U((Ep, an) => {
        var on = xe(), Oa = on({}.toString), Ta = on("".slice);
        an.exports = function(e) {
          return Ta(Oa(e), 8, -1);
        };
      });
      var ln = U((qp, cn) => {
        var Ea = xe(), qa = be(), Aa = un(), Ar = Object, Pa = Ea("".split);
        cn.exports = qa(function() {
          return !Ar("z").propertyIsEnumerable(0);
        }) ? function(e) {
          return Aa(e) == "String" ? Pa(e, "") : Ar(e);
        } : Ar;
      });
      var Pr = U((Ap, fn) => {
        fn.exports = function(e) {
          return e == null;
        };
      });
      var Ir = U((Pp, pn) => {
        var Ia = Pr(), Ra = TypeError;
        pn.exports = function(e) {
          if (Ia(e))
            throw Ra("Can't call method on " + e);
          return e;
        };
      });
      var nr = U((Ip, hn) => {
        var Ca = ln(), Na = Ir();
        hn.exports = function(e) {
          return Ca(Na(e));
        };
      });
      var Cr = U((Rp, dn) => {
        var Rr = typeof document == "object" && document.all, ja = typeof Rr > "u" && Rr !== void 0;
        dn.exports = { all: Rr, IS_HTMLDDA: ja };
      });
      var he = U((Cp, mn) => {
        var vn = Cr(), Ma = vn.all;
        mn.exports = vn.IS_HTMLDDA ? function(e) {
          return typeof e == "function" || e === Ma;
        } : function(e) {
          return typeof e == "function";
        };
      });
      var Me = U((Np, wn) => {
        var gn = he(), yn = Cr(), Da = yn.all;
        wn.exports = yn.IS_HTMLDDA ? function(e) {
          return typeof e == "object" ? e !== null : gn(e) || e === Da;
        } : function(e) {
          return typeof e == "object" ? e !== null : gn(e);
        };
      });
      var ir = U((jp, _n) => {
        var Nr = pe(), La = he(), za = function(e) {
          return La(e) ? e : void 0;
        };
        _n.exports = function(e, n) {
          return arguments.length < 2 ? za(Nr[e]) : Nr[e] && Nr[e][n];
        };
      });
      var xn = U((Mp, bn) => {
        var Ba = xe();
        bn.exports = Ba({}.isPrototypeOf);
      });
      var kn = U((Dp, Sn) => {
        var Fa = ir();
        Sn.exports = Fa("navigator", "userAgent") || "";
      });
      var In = U((Lp, Pn) => {
        var An = pe(), jr = kn(), On = An.process, Tn = An.Deno, En = On && On.versions || Tn && Tn.version, qn = En && En.v8, de, sr;
        qn && (de = qn.split("."), sr = de[0] > 0 && de[0] < 4 ? 1 : +(de[0] + de[1]));
        !sr && jr && (de = jr.match(/Edge\/(\d+)/), (!de || de[1] >= 74) && (de = jr.match(/Chrome\/(\d+)/), de && (sr = +de[1])));
        Pn.exports = sr;
      });
      var Mr = U((zp, Cn) => {
        var Rn = In(), Ua = be();
        Cn.exports = !!Object.getOwnPropertySymbols && !Ua(function() {
          var e = Symbol();
          return !String(e) || !(Object(e) instanceof Symbol) || !Symbol.sham && Rn && Rn < 41;
        });
      });
      var Dr = U((Bp, Nn) => {
        var $a = Mr();
        Nn.exports = $a && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var Lr = U((Fp, jn) => {
        var Wa = ir(), Va = he(), Ga = xn(), Ha = Dr(), Ja = Object;
        jn.exports = Ha ? function(e) {
          return typeof e == "symbol";
        } : function(e) {
          var n = Wa("Symbol");
          return Va(n) && Ga(n.prototype, Ja(e));
        };
      });
      var Dn = U((Up, Mn) => {
        var Ka = String;
        Mn.exports = function(e) {
          try {
            return Ka(e);
          } catch {
            return "Object";
          }
        };
      });
      var zn = U(($p, Ln) => {
        var Qa = he(), Ya = Dn(), Xa = TypeError;
        Ln.exports = function(e) {
          if (Qa(e))
            return e;
          throw Xa(Ya(e) + " is not a function");
        };
      });
      var Fn = U((Wp, Bn) => {
        var Za = zn(), eu = Pr();
        Bn.exports = function(e, n) {
          var i = e[n];
          return eu(i) ? void 0 : Za(i);
        };
      });
      var $n = U((Vp, Un) => {
        var zr = tr(), Br = he(), Fr = Me(), ru = TypeError;
        Un.exports = function(e, n) {
          var i, u;
          if (n === "string" && Br(i = e.toString) && !Fr(u = zr(i, e)) || Br(i = e.valueOf) && !Fr(u = zr(i, e)) || n !== "string" && Br(i = e.toString) && !Fr(u = zr(i, e)))
            return u;
          throw ru("Can't convert object to primitive value");
        };
      });
      var Vn = U((Gp, Wn) => {
        Wn.exports = false;
      });
      var or = U((Hp, Hn) => {
        var Gn = pe(), tu = Object.defineProperty;
        Hn.exports = function(e, n) {
          try {
            tu(Gn, e, { value: n, configurable: true, writable: true });
          } catch {
            Gn[e] = n;
          }
          return n;
        };
      });
      var ar = U((Jp, Kn) => {
        var nu = pe(), iu = or(), Jn = "__core-js_shared__", su = nu[Jn] || iu(Jn, {});
        Kn.exports = su;
      });
      var Ur = U((Kp, Yn) => {
        var ou = Vn(), Qn = ar();
        (Yn.exports = function(e, n) {
          return Qn[e] || (Qn[e] = n !== void 0 ? n : {});
        })("versions", []).push({ version: "3.26.1", mode: ou ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var Zn = U((Qp, Xn) => {
        var au = Ir(), uu = Object;
        Xn.exports = function(e) {
          return uu(au(e));
        };
      });
      var Te = U((Yp, ei) => {
        var cu = xe(), lu = Zn(), fu = cu({}.hasOwnProperty);
        ei.exports = Object.hasOwn || function(n, i) {
          return fu(lu(n), i);
        };
      });
      var $r = U((Xp, ri) => {
        var pu = xe(), hu = 0, du = Math.random(), vu = pu(1 .toString);
        ri.exports = function(e) {
          return "Symbol(" + (e === void 0 ? "" : e) + ")_" + vu(++hu + du, 36);
        };
      });
      var ai = U((Zp, oi) => {
        var mu = pe(), gu = Ur(), ti = Te(), yu = $r(), ni = Mr(), si = Dr(), De = gu("wks"), Ee = mu.Symbol, ii = Ee && Ee.for, wu = si ? Ee : Ee && Ee.withoutSetter || yu;
        oi.exports = function(e) {
          if (!ti(De, e) || !(ni || typeof De[e] == "string")) {
            var n = "Symbol." + e;
            ni && ti(Ee, e) ? De[e] = Ee[e] : si && ii ? De[e] = ii(n) : De[e] = wu(n);
          }
          return De[e];
        };
      });
      var fi = U((eh, li) => {
        var _u = tr(), ui = Me(), ci = Lr(), bu = Fn(), xu = $n(), Su = ai(), ku = TypeError, Ou = Su("toPrimitive");
        li.exports = function(e, n) {
          if (!ui(e) || ci(e))
            return e;
          var i = bu(e, Ou), u;
          if (i) {
            if (n === void 0 && (n = "default"), u = _u(i, e, n), !ui(u) || ci(u))
              return u;
            throw ku("Can't convert object to primitive value");
          }
          return n === void 0 && (n = "number"), xu(e, n);
        };
      });
      var Wr = U((rh, pi) => {
        var Tu = fi(), Eu = Lr();
        pi.exports = function(e) {
          var n = Tu(e, "string");
          return Eu(n) ? n : n + "";
        };
      });
      var vi = U((th, di) => {
        var qu = pe(), hi = Me(), Vr = qu.document, Au = hi(Vr) && hi(Vr.createElement);
        di.exports = function(e) {
          return Au ? Vr.createElement(e) : {};
        };
      });
      var Gr = U((nh, mi) => {
        var Pu = Oe(), Iu = be(), Ru = vi();
        mi.exports = !Pu && !Iu(function() {
          return Object.defineProperty(Ru("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Hr = U((yi) => {
        var Cu = Oe(), Nu = tr(), ju = en(), Mu = Er(), Du = nr(), Lu = Wr(), zu = Te(), Bu = Gr(), gi = Object.getOwnPropertyDescriptor;
        yi.f = Cu ? gi : function(n, i) {
          if (n = Du(n), i = Lu(i), Bu)
            try {
              return gi(n, i);
            } catch {
            }
          if (zu(n, i))
            return Mu(!Nu(ju.f, n, i), n[i]);
        };
      });
      var _i = U((sh, wi) => {
        var Fu = Oe(), Uu = be();
        wi.exports = Fu && Uu(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var Jr = U((oh, bi) => {
        var $u = Me(), Wu = String, Vu = TypeError;
        bi.exports = function(e) {
          if ($u(e))
            return e;
          throw Vu(Wu(e) + " is not an object");
        };
      });
      var cr = U((Si) => {
        var Gu = Oe(), Hu = Gr(), Ju = _i(), ur = Jr(), xi = Wr(), Ku = TypeError, Kr = Object.defineProperty, Qu = Object.getOwnPropertyDescriptor, Qr = "enumerable", Yr = "configurable", Xr = "writable";
        Si.f = Gu ? Ju ? function(n, i, u) {
          if (ur(n), i = xi(i), ur(u), typeof n == "function" && i === "prototype" && "value" in u && Xr in u && !u[Xr]) {
            var o = Qu(n, i);
            o && o[Xr] && (n[i] = u.value, u = { configurable: Yr in u ? u[Yr] : o[Yr], enumerable: Qr in u ? u[Qr] : o[Qr], writable: false });
          }
          return Kr(n, i, u);
        } : Kr : function(n, i, u) {
          if (ur(n), i = xi(i), ur(u), Hu)
            try {
              return Kr(n, i, u);
            } catch {
            }
          if ("get" in u || "set" in u)
            throw Ku("Accessors not supported");
          return "value" in u && (n[i] = u.value), n;
        };
      });
      var Zr = U((uh, ki) => {
        var Yu = Oe(), Xu = cr(), Zu = Er();
        ki.exports = Yu ? function(e, n, i) {
          return Xu.f(e, n, Zu(1, i));
        } : function(e, n, i) {
          return e[n] = i, e;
        };
      });
      var Ei = U((ch, Ti) => {
        var et = Oe(), ec = Te(), Oi = Function.prototype, rc = et && Object.getOwnPropertyDescriptor, rt = ec(Oi, "name"), tc = rt && function() {
        }.name === "something", nc = rt && (!et || et && rc(Oi, "name").configurable);
        Ti.exports = { EXISTS: rt, PROPER: tc, CONFIGURABLE: nc };
      });
      var Ai = U((lh, qi) => {
        var ic = xe(), sc = he(), tt = ar(), oc = ic(Function.toString);
        sc(tt.inspectSource) || (tt.inspectSource = function(e) {
          return oc(e);
        });
        qi.exports = tt.inspectSource;
      });
      var Ri = U((fh, Ii) => {
        var ac = pe(), uc = he(), Pi = ac.WeakMap;
        Ii.exports = uc(Pi) && /native code/.test(String(Pi));
      });
      var ji = U((ph, Ni) => {
        var cc = Ur(), lc = $r(), Ci = cc("keys");
        Ni.exports = function(e) {
          return Ci[e] || (Ci[e] = lc(e));
        };
      });
      var nt = U((hh, Mi) => {
        Mi.exports = {};
      });
      var Bi = U((dh, zi) => {
        var fc = Ri(), Li = pe(), pc = Me(), hc = Zr(), it2 = Te(), st = ar(), dc = ji(), vc = nt(), Di = "Object already initialized", ot = Li.TypeError, mc = Li.WeakMap, lr, Fe, fr, gc = function(e) {
          return fr(e) ? Fe(e) : lr(e, {});
        }, yc = function(e) {
          return function(n) {
            var i;
            if (!pc(n) || (i = Fe(n)).type !== e)
              throw ot("Incompatible receiver, " + e + " required");
            return i;
          };
        };
        fc || st.state ? (ve = st.state || (st.state = new mc()), ve.get = ve.get, ve.has = ve.has, ve.set = ve.set, lr = function(e, n) {
          if (ve.has(e))
            throw ot(Di);
          return n.facade = e, ve.set(e, n), n;
        }, Fe = function(e) {
          return ve.get(e) || {};
        }, fr = function(e) {
          return ve.has(e);
        }) : (qe = dc("state"), vc[qe] = true, lr = function(e, n) {
          if (it2(e, qe))
            throw ot(Di);
          return n.facade = e, hc(e, qe, n), n;
        }, Fe = function(e) {
          return it2(e, qe) ? e[qe] : {};
        }, fr = function(e) {
          return it2(e, qe);
        });
        var ve, qe;
        zi.exports = { set: lr, get: Fe, has: fr, enforce: gc, getterFor: yc };
      });
      var $i = U((vh, Ui) => {
        var wc = be(), _c = he(), pr = Te(), at = Oe(), bc = Ei().CONFIGURABLE, xc = Ai(), Fi = Bi(), Sc = Fi.enforce, kc = Fi.get, hr = Object.defineProperty, Oc = at && !wc(function() {
          return hr(function() {
          }, "length", { value: 8 }).length !== 8;
        }), Tc = String(String).split("String"), Ec = Ui.exports = function(e, n, i) {
          String(n).slice(0, 7) === "Symbol(" && (n = "[" + String(n).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), i && i.getter && (n = "get " + n), i && i.setter && (n = "set " + n), (!pr(e, "name") || bc && e.name !== n) && (at ? hr(e, "name", { value: n, configurable: true }) : e.name = n), Oc && i && pr(i, "arity") && e.length !== i.arity && hr(e, "length", { value: i.arity });
          try {
            i && pr(i, "constructor") && i.constructor ? at && hr(e, "prototype", { writable: false }) : e.prototype && (e.prototype = void 0);
          } catch {
          }
          var u = Sc(e);
          return pr(u, "source") || (u.source = Tc.join(typeof n == "string" ? n : "")), e;
        };
        Function.prototype.toString = Ec(function() {
          return _c(this) && kc(this).source || xc(this);
        }, "toString");
      });
      var Vi = U((mh, Wi) => {
        var qc = he(), Ac = cr(), Pc = $i(), Ic = or();
        Wi.exports = function(e, n, i, u) {
          u || (u = {});
          var o = u.enumerable, h = u.name !== void 0 ? u.name : n;
          if (qc(i) && Pc(i, h, u), u.global)
            o ? e[n] = i : Ic(n, i);
          else {
            try {
              u.unsafe ? e[n] && (o = true) : delete e[n];
            } catch {
            }
            o ? e[n] = i : Ac.f(e, n, { value: i, enumerable: false, configurable: !u.nonConfigurable, writable: !u.nonWritable });
          }
          return e;
        };
      });
      var Hi = U((gh, Gi) => {
        var Rc = Math.ceil, Cc = Math.floor;
        Gi.exports = Math.trunc || function(n) {
          var i = +n;
          return (i > 0 ? Cc : Rc)(i);
        };
      });
      var ut = U((yh, Ji) => {
        var Nc = Hi();
        Ji.exports = function(e) {
          var n = +e;
          return n !== n || n === 0 ? 0 : Nc(n);
        };
      });
      var Qi = U((wh, Ki) => {
        var jc = ut(), Mc = Math.max, Dc = Math.min;
        Ki.exports = function(e, n) {
          var i = jc(e);
          return i < 0 ? Mc(i + n, 0) : Dc(i, n);
        };
      });
      var Xi = U((_h, Yi) => {
        var Lc = ut(), zc = Math.min;
        Yi.exports = function(e) {
          return e > 0 ? zc(Lc(e), 9007199254740991) : 0;
        };
      });
      var es = U((bh, Zi) => {
        var Bc = Xi();
        Zi.exports = function(e) {
          return Bc(e.length);
        };
      });
      var ns = U((xh, ts) => {
        var Fc = nr(), Uc = Qi(), $c = es(), rs = function(e) {
          return function(n, i, u) {
            var o = Fc(n), h = $c(o), l = Uc(u, h), p;
            if (e && i != i) {
              for (; h > l; )
                if (p = o[l++], p != p)
                  return true;
            } else
              for (; h > l; l++)
                if ((e || l in o) && o[l] === i)
                  return e || l || 0;
            return !e && -1;
          };
        };
        ts.exports = { includes: rs(true), indexOf: rs(false) };
      });
      var os = U((Sh, ss) => {
        var Wc = xe(), ct = Te(), Vc = nr(), Gc = ns().indexOf, Hc = nt(), is = Wc([].push);
        ss.exports = function(e, n) {
          var i = Vc(e), u = 0, o = [], h;
          for (h in i)
            !ct(Hc, h) && ct(i, h) && is(o, h);
          for (; n.length > u; )
            ct(i, h = n[u++]) && (~Gc(o, h) || is(o, h));
          return o;
        };
      });
      var us = U((kh, as) => {
        as.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var ls = U((cs) => {
        var Jc = os(), Kc = us(), Qc = Kc.concat("length", "prototype");
        cs.f = Object.getOwnPropertyNames || function(n) {
          return Jc(n, Qc);
        };
      });
      var ps = U((fs2) => {
        fs2.f = Object.getOwnPropertySymbols;
      });
      var ds = U((Eh, hs) => {
        var Yc = ir(), Xc = xe(), Zc = ls(), el = ps(), rl = Jr(), tl = Xc([].concat);
        hs.exports = Yc("Reflect", "ownKeys") || function(n) {
          var i = Zc.f(rl(n)), u = el.f;
          return u ? tl(i, u(n)) : i;
        };
      });
      var gs = U((qh, ms) => {
        var vs = Te(), nl = ds(), il = Hr(), sl = cr();
        ms.exports = function(e, n, i) {
          for (var u = nl(n), o = sl.f, h = il.f, l = 0; l < u.length; l++) {
            var p = u[l];
            !vs(e, p) && !(i && vs(i, p)) && o(e, p, h(n, p));
          }
        };
      });
      var ws = U((Ah, ys) => {
        var ol = be(), al = he(), ul = /#|\.prototype\./, Ue = function(e, n) {
          var i = ll[cl(e)];
          return i == pl ? true : i == fl ? false : al(n) ? ol(n) : !!n;
        }, cl = Ue.normalize = function(e) {
          return String(e).replace(ul, ".").toLowerCase();
        }, ll = Ue.data = {}, fl = Ue.NATIVE = "N", pl = Ue.POLYFILL = "P";
        ys.exports = Ue;
      });
      var bs = U((Ph, _s) => {
        var lt = pe(), hl = Hr().f, dl = Zr(), vl = Vi(), ml = or(), gl = gs(), yl = ws();
        _s.exports = function(e, n) {
          var i = e.target, u = e.global, o = e.stat, h, l, p, m, c, t3;
          if (u ? l = lt : o ? l = lt[i] || ml(i, {}) : l = (lt[i] || {}).prototype, l)
            for (p in n) {
              if (c = n[p], e.dontCallGetSet ? (t3 = hl(l, p), m = t3 && t3.value) : m = l[p], h = yl(u ? p : i + (o ? "." : "#") + p, e.forced), !h && m !== void 0) {
                if (typeof c == typeof m)
                  continue;
                gl(c, m);
              }
              (e.sham || m && m.sham) && dl(c, "sham", true), vl(l, p, c, e);
            }
        };
      });
      var xs = U(() => {
        var wl = bs(), ft = pe();
        wl({ global: true, forced: ft.globalThis !== ft }, { globalThis: ft });
      });
      var Ss = U(() => {
        xs();
      });
      var gp = U((Fh, wa) => {
        Ss();
        var Et = Object.defineProperty, _l = Object.getOwnPropertyDescriptor, qt = Object.getOwnPropertyNames, bl = Object.prototype.hasOwnProperty, Le = (e, n) => function() {
          return e && (n = (0, e[qt(e)[0]])(e = 0)), n;
        }, P = (e, n) => function() {
          return n || (0, e[qt(e)[0]])((n = { exports: {} }).exports, n), n.exports;
        }, At = (e, n) => {
          for (var i in n)
            Et(e, i, { get: n[i], enumerable: true });
        }, xl = (e, n, i, u) => {
          if (n && typeof n == "object" || typeof n == "function")
            for (let o of qt(n))
              !bl.call(e, o) && o !== i && Et(e, o, { get: () => n[o], enumerable: !(u = _l(n, o)) || u.enumerable });
          return e;
        }, Pt = (e) => xl(Et({}, "__esModule", { value: true }), e), A = Le({ "<define:process>"() {
        } }), Sl = P({ "src/common/parser-create-error.js"(e, n) {
          "use strict";
          A();
          function i(u, o) {
            let h = new SyntaxError(u + " (" + o.start.line + ":" + o.start.column + ")");
            return h.loc = o, h;
          }
          n.exports = i;
        } }), Us = P({ "src/utils/get-last.js"(e, n) {
          "use strict";
          A();
          var i = (u) => u[u.length - 1];
          n.exports = i;
        } }), $s = P({ "src/utils/front-matter/parse.js"(e, n) {
          "use strict";
          A();
          var i = new RegExp("^(?<startDelimiter>-{3}|\\+{3})(?<language>[^\\n]*)\\n(?:|(?<value>.*?)\\n)(?<endDelimiter>\\k<startDelimiter>|\\.{3})[^\\S\\n]*(?:\\n|$)", "s");
          function u(o) {
            let h = o.match(i);
            if (!h)
              return { content: o };
            let { startDelimiter: l, language: p, value: m = "", endDelimiter: c } = h.groups, t3 = p.trim() || "yaml";
            if (l === "+++" && (t3 = "toml"), t3 !== "yaml" && l !== c)
              return { content: o };
            let [r] = h;
            return { frontMatter: { type: "front-matter", lang: t3, value: m, startDelimiter: l, endDelimiter: c, raw: r.replace(/\n$/, "") }, content: r.replace(/[^\n]/g, " ") + o.slice(r.length) };
          }
          n.exports = u;
        } }), Ws = {};
        At(Ws, { EOL: () => bt, arch: () => kl, cpus: () => Ys, default: () => to, endianness: () => Vs, freemem: () => Ks, getNetworkInterfaces: () => ro, hostname: () => Gs, loadavg: () => Hs, networkInterfaces: () => eo, platform: () => Ol, release: () => Zs, tmpDir: () => wt, tmpdir: () => _t, totalmem: () => Qs, type: () => Xs, uptime: () => Js });
        function Vs() {
          if (typeof dr > "u") {
            var e = new ArrayBuffer(2), n = new Uint8Array(e), i = new Uint16Array(e);
            if (n[0] = 1, n[1] = 2, i[0] === 258)
              dr = "BE";
            else if (i[0] === 513)
              dr = "LE";
            else
              throw new Error("unable to figure out endianess");
          }
          return dr;
        }
        function Gs() {
          return typeof globalThis.location < "u" ? globalThis.location.hostname : "";
        }
        function Hs() {
          return [];
        }
        function Js() {
          return 0;
        }
        function Ks() {
          return Number.MAX_VALUE;
        }
        function Qs() {
          return Number.MAX_VALUE;
        }
        function Ys() {
          return [];
        }
        function Xs() {
          return "Browser";
        }
        function Zs() {
          return typeof globalThis.navigator < "u" ? globalThis.navigator.appVersion : "";
        }
        function eo() {
        }
        function ro() {
        }
        function kl() {
          return "javascript";
        }
        function Ol() {
          return "browser";
        }
        function wt() {
          return "/tmp";
        }
        var dr, _t, bt, to, Tl = Le({ "node-modules-polyfills:os"() {
          A(), _t = wt, bt = `
`, to = { EOL: bt, tmpdir: _t, tmpDir: wt, networkInterfaces: eo, getNetworkInterfaces: ro, release: Zs, type: Xs, cpus: Ys, totalmem: Qs, freemem: Ks, uptime: Js, loadavg: Hs, hostname: Gs, endianness: Vs };
        } }), El = P({ "node-modules-polyfills-commonjs:os"(e, n) {
          A();
          var i = (Tl(), Pt(Ws));
          if (i && i.default) {
            n.exports = i.default;
            for (let u in i)
              n.exports[u] = i[u];
          } else
            i && (n.exports = i);
        } }), ql = P({ "node_modules/detect-newline/index.js"(e, n) {
          "use strict";
          A();
          var i = (u) => {
            if (typeof u != "string")
              throw new TypeError("Expected a string");
            let o = u.match(/(?:\r?\n)/g) || [];
            if (o.length === 0)
              return;
            let h = o.filter((p) => p === `\r
`).length, l = o.length - h;
            return h > l ? `\r
` : `
`;
          };
          n.exports = i, n.exports.graceful = (u) => typeof u == "string" && i(u) || `
`;
        } }), Al = P({ "node_modules/jest-docblock/build/index.js"(e) {
          "use strict";
          A(), Object.defineProperty(e, "__esModule", { value: true }), e.extract = s, e.parse = g, e.parseWithComments = v, e.print = y, e.strip = f;
          function n() {
            let d = El();
            return n = function() {
              return d;
            }, d;
          }
          function i() {
            let d = u(ql());
            return i = function() {
              return d;
            }, d;
          }
          function u(d) {
            return d && d.__esModule ? d : { default: d };
          }
          var o = /\*\/$/, h = /^\/\*\*?/, l = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, p = /(^|\s+)\/\/([^\r\n]*)/g, m = /^(\r?\n)+/, c = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g, t3 = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g, r = /(\r?\n|^) *\* ?/g, a = [];
          function s(d) {
            let _ = d.match(l);
            return _ ? _[0].trimLeft() : "";
          }
          function f(d) {
            let _ = d.match(l);
            return _ && _[0] ? d.substring(_[0].length) : d;
          }
          function g(d) {
            return v(d).pragmas;
          }
          function v(d) {
            let _ = (0, i().default)(d) || n().EOL;
            d = d.replace(h, "").replace(o, "").replace(r, "$1");
            let k = "";
            for (; k !== d; )
              k = d, d = d.replace(c, `${_}$1 $2${_}`);
            d = d.replace(m, "").trimRight();
            let x = /* @__PURE__ */ Object.create(null), N = d.replace(t3, "").replace(m, "").trimRight(), I;
            for (; I = t3.exec(d); ) {
              let W = I[2].replace(p, "");
              typeof x[I[1]] == "string" || Array.isArray(x[I[1]]) ? x[I[1]] = a.concat(x[I[1]], W) : x[I[1]] = W;
            }
            return { comments: N, pragmas: x };
          }
          function y(d) {
            let { comments: _ = "", pragmas: k = {} } = d, x = (0, i().default)(_) || n().EOL, N = "/**", I = " *", W = " */", $2 = Object.keys(k), H = $2.map((V) => w(V, k[V])).reduce((V, B) => V.concat(B), []).map((V) => `${I} ${V}${x}`).join("");
            if (!_) {
              if ($2.length === 0)
                return "";
              if ($2.length === 1 && !Array.isArray(k[$2[0]])) {
                let V = k[$2[0]];
                return `${N} ${w($2[0], V)[0]}${W}`;
              }
            }
            let D = _.split(x).map((V) => `${I} ${V}`).join(x) + x;
            return N + x + (_ ? D : "") + (_ && $2.length ? I + x : "") + H + W;
          }
          function w(d, _) {
            return a.concat(_).map((k) => `@${d} ${k}`.trim());
          }
        } }), Pl = P({ "src/common/end-of-line.js"(e, n) {
          "use strict";
          A();
          function i(l) {
            let p = l.indexOf("\r");
            return p >= 0 ? l.charAt(p + 1) === `
` ? "crlf" : "cr" : "lf";
          }
          function u(l) {
            switch (l) {
              case "cr":
                return "\r";
              case "crlf":
                return `\r
`;
              default:
                return `
`;
            }
          }
          function o(l, p) {
            let m;
            switch (p) {
              case `
`:
                m = /\n/g;
                break;
              case "\r":
                m = /\r/g;
                break;
              case `\r
`:
                m = /\r\n/g;
                break;
              default:
                throw new Error(`Unexpected "eol" ${JSON.stringify(p)}.`);
            }
            let c = l.match(m);
            return c ? c.length : 0;
          }
          function h(l) {
            return l.replace(/\r\n?/g, `
`);
          }
          n.exports = { guessEndOfLine: i, convertEndOfLineToChars: u, countEndOfLineChars: o, normalizeEndOfLine: h };
        } }), Il = P({ "src/language-js/utils/get-shebang.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            if (!u.startsWith("#!"))
              return "";
            let o = u.indexOf(`
`);
            return o === -1 ? u : u.slice(0, o);
          }
          n.exports = i;
        } }), Rl = P({ "src/language-js/pragma.js"(e, n) {
          "use strict";
          A();
          var { parseWithComments: i, strip: u, extract: o, print: h } = Al(), { normalizeEndOfLine: l } = Pl(), p = Il();
          function m(r) {
            let a = p(r);
            a && (r = r.slice(a.length + 1));
            let s = o(r), { pragmas: f, comments: g } = i(s);
            return { shebang: a, text: r, pragmas: f, comments: g };
          }
          function c(r) {
            let a = Object.keys(m(r).pragmas);
            return a.includes("prettier") || a.includes("format");
          }
          function t3(r) {
            let { shebang: a, text: s, pragmas: f, comments: g } = m(r), v = u(s), y = h({ pragmas: Object.assign({ format: "" }, f), comments: g.trimStart() });
            return (a ? `${a}
` : "") + l(y) + (v.startsWith(`
`) ? `
` : `

`) + v;
          }
          n.exports = { hasPragma: c, insertPragma: t3 };
        } }), Cl = P({ "src/language-css/pragma.js"(e, n) {
          "use strict";
          A();
          var i = Rl(), u = $s();
          function o(l) {
            return i.hasPragma(u(l).content);
          }
          function h(l) {
            let { frontMatter: p, content: m } = u(l);
            return (p ? p.raw + `

` : "") + i.insertPragma(m);
          }
          n.exports = { hasPragma: o, insertPragma: h };
        } }), Nl = P({ "src/utils/text/skip.js"(e, n) {
          "use strict";
          A();
          function i(p) {
            return (m, c, t3) => {
              let r = t3 && t3.backwards;
              if (c === false)
                return false;
              let { length: a } = m, s = c;
              for (; s >= 0 && s < a; ) {
                let f = m.charAt(s);
                if (p instanceof RegExp) {
                  if (!p.test(f))
                    return s;
                } else if (!p.includes(f))
                  return s;
                r ? s-- : s++;
              }
              return s === -1 || s === a ? s : false;
            };
          }
          var u = i(/\s/), o = i(" 	"), h = i(",; 	"), l = i(/[^\n\r]/);
          n.exports = { skipWhitespace: u, skipSpaces: o, skipToLineEnd: h, skipEverythingButNewLine: l };
        } }), jl = P({ "src/utils/line-column-to-index.js"(e, n) {
          "use strict";
          A(), n.exports = function(i, u) {
            let o = 0;
            for (let h = 0; h < i.line - 1; ++h)
              o = u.indexOf(`
`, o) + 1;
            return o + i.column;
          };
        } }), no = P({ "src/language-css/loc.js"(e, n) {
          "use strict";
          A();
          var { skipEverythingButNewLine: i } = Nl(), u = Us(), o = jl();
          function h(s, f) {
            return typeof s.sourceIndex == "number" ? s.sourceIndex : s.source ? o(s.source.start, f) - 1 : null;
          }
          function l(s, f) {
            if (s.type === "css-comment" && s.inline)
              return i(f, s.source.startOffset);
            let g = s.nodes && u(s.nodes);
            return g && s.source && !s.source.end && (s = g), s.source && s.source.end ? o(s.source.end, f) : null;
          }
          function p(s, f) {
            s.source && (s.source.startOffset = h(s, f), s.source.endOffset = l(s, f));
            for (let g in s) {
              let v = s[g];
              g === "source" || !v || typeof v != "object" || (v.type === "value-root" || v.type === "value-unknown" ? m(v, c(s), v.text || v.value) : p(v, f));
            }
          }
          function m(s, f, g) {
            s.source && (s.source.startOffset = h(s, g) + f, s.source.endOffset = l(s, g) + f);
            for (let v in s) {
              let y = s[v];
              v === "source" || !y || typeof y != "object" || m(y, f, g);
            }
          }
          function c(s) {
            let f = s.source.startOffset;
            return typeof s.prop == "string" && (f += s.prop.length), s.type === "css-atrule" && typeof s.name == "string" && (f += 1 + s.name.length + s.raws.afterName.match(/^\s*:?\s*/)[0].length), s.type !== "css-atrule" && s.raws && typeof s.raws.between == "string" && (f += s.raws.between.length), f;
          }
          function t3(s) {
            let f = "initial", g = "initial", v, y = false, w = [];
            for (let d = 0; d < s.length; d++) {
              let _ = s[d];
              switch (f) {
                case "initial":
                  if (_ === "'") {
                    f = "single-quotes";
                    continue;
                  }
                  if (_ === '"') {
                    f = "double-quotes";
                    continue;
                  }
                  if ((_ === "u" || _ === "U") && s.slice(d, d + 4).toLowerCase() === "url(") {
                    f = "url", d += 3;
                    continue;
                  }
                  if (_ === "*" && s[d - 1] === "/") {
                    f = "comment-block";
                    continue;
                  }
                  if (_ === "/" && s[d - 1] === "/") {
                    f = "comment-inline", v = d - 1;
                    continue;
                  }
                  continue;
                case "single-quotes":
                  if (_ === "'" && s[d - 1] !== "\\" && (f = g, g = "initial"), _ === `
` || _ === "\r")
                    return s;
                  continue;
                case "double-quotes":
                  if (_ === '"' && s[d - 1] !== "\\" && (f = g, g = "initial"), _ === `
` || _ === "\r")
                    return s;
                  continue;
                case "url":
                  if (_ === ")" && (f = "initial"), _ === `
` || _ === "\r")
                    return s;
                  if (_ === "'") {
                    f = "single-quotes", g = "url";
                    continue;
                  }
                  if (_ === '"') {
                    f = "double-quotes", g = "url";
                    continue;
                  }
                  continue;
                case "comment-block":
                  _ === "/" && s[d - 1] === "*" && (f = "initial");
                  continue;
                case "comment-inline":
                  (_ === '"' || _ === "'" || _ === "*") && (y = true), (_ === `
` || _ === "\r") && (y && w.push([v, d]), f = "initial", y = false);
                  continue;
              }
            }
            for (let [d, _] of w)
              s = s.slice(0, d) + s.slice(d, _).replace(/["'*]/g, " ") + s.slice(_);
            return s;
          }
          function r(s) {
            return s.source.startOffset;
          }
          function a(s) {
            return s.source.endOffset;
          }
          n.exports = { locStart: r, locEnd: a, calculateLoc: p, replaceQuotesInInlineComments: t3 };
        } }), Ml = P({ "src/utils/is-non-empty-array.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            return Array.isArray(u) && u.length > 0;
          }
          n.exports = i;
        } }), Dl = P({ "src/language-css/utils/has-scss-interpolation.js"(e, n) {
          "use strict";
          A();
          var i = Ml();
          function u(o) {
            if (i(o)) {
              for (let h = o.length - 1; h > 0; h--)
                if (o[h].type === "word" && o[h].value === "{" && o[h - 1].type === "word" && o[h - 1].value.endsWith("#"))
                  return true;
            }
            return false;
          }
          n.exports = u;
        } }), Ll = P({ "src/language-css/utils/has-string-or-function.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            return u.some((o) => o.type === "string" || o.type === "func");
          }
          n.exports = i;
        } }), zl = P({ "src/language-css/utils/is-less-parser.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            return u.parser === "css" || u.parser === "less";
          }
          n.exports = i;
        } }), Bl = P({ "src/language-css/utils/is-scss.js"(e, n) {
          "use strict";
          A();
          function i(u, o) {
            return u === "less" || u === "scss" ? u === "scss" : /(?:\w\s*:\s*[^:}]+|#){|@import[^\n]+(?:url|,)/.test(o);
          }
          n.exports = i;
        } }), Fl = P({ "src/language-css/utils/is-scss-nested-property-node.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            return u.selector ? u.selector.replace(/\/\*.*?\*\//, "").replace(/\/\/.*\n/, "").trim().endsWith(":") : false;
          }
          n.exports = i;
        } }), Ul = P({ "src/language-css/utils/is-scss-variable.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            return Boolean((u == null ? void 0 : u.type) === "word" && u.value.startsWith("$"));
          }
          n.exports = i;
        } }), $l = P({ "src/language-css/utils/stringify-node.js"(e, n) {
          "use strict";
          A();
          function i(u) {
            var o, h, l;
            if (u.groups) {
              var p, m, c;
              let y = ((p = u.open) === null || p === void 0 ? void 0 : p.value) || "", w = u.groups.map((_) => i(_)).join(((m = u.groups[0]) === null || m === void 0 ? void 0 : m.type) === "comma_group" ? "," : ""), d = ((c = u.close) === null || c === void 0 ? void 0 : c.value) || "";
              return y + w + d;
            }
            let t3 = ((o = u.raws) === null || o === void 0 ? void 0 : o.before) || "", r = ((h = u.raws) === null || h === void 0 ? void 0 : h.quote) || "", a = u.type === "atword" ? "@" : "", s = u.value || "", f = u.unit || "", g = u.group ? i(u.group) : "", v = ((l = u.raws) === null || l === void 0 ? void 0 : l.after) || "";
            return t3 + r + a + s + r + f + g + v;
          }
          n.exports = i;
        } }), Wl = P({ "src/language-css/utils/is-module-rule-name.js"(e, n) {
          "use strict";
          A();
          var i = /* @__PURE__ */ new Set(["import", "use", "forward"]);
          function u(o) {
            return i.has(o);
          }
          n.exports = u;
        } }), we = P({ "node_modules/postcss-values-parser/lib/node.js"(e, n) {
          "use strict";
          A();
          var i = function(u, o) {
            let h = new u.constructor();
            for (let l in u) {
              if (!u.hasOwnProperty(l))
                continue;
              let p = u[l], m = typeof p;
              l === "parent" && m === "object" ? o && (h[l] = o) : l === "source" ? h[l] = p : p instanceof Array ? h[l] = p.map((c) => i(c, h)) : l !== "before" && l !== "after" && l !== "between" && l !== "semicolon" && (m === "object" && p !== null && (p = i(p)), h[l] = p);
            }
            return h;
          };
          n.exports = class {
            constructor(o) {
              o = o || {}, this.raws = { before: "", after: "" };
              for (let h in o)
                this[h] = o[h];
            }
            remove() {
              return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
            }
            toString() {
              return [this.raws.before, String(this.value), this.raws.after].join("");
            }
            clone(o) {
              o = o || {};
              let h = i(this);
              for (let l in o)
                h[l] = o[l];
              return h;
            }
            cloneBefore(o) {
              o = o || {};
              let h = this.clone(o);
              return this.parent.insertBefore(this, h), h;
            }
            cloneAfter(o) {
              o = o || {};
              let h = this.clone(o);
              return this.parent.insertAfter(this, h), h;
            }
            replaceWith() {
              let o = Array.prototype.slice.call(arguments);
              if (this.parent) {
                for (let h of o)
                  this.parent.insertBefore(this, h);
                this.remove();
              }
              return this;
            }
            moveTo(o) {
              return this.cleanRaws(this.root() === o.root()), this.remove(), o.append(this), this;
            }
            moveBefore(o) {
              return this.cleanRaws(this.root() === o.root()), this.remove(), o.parent.insertBefore(o, this), this;
            }
            moveAfter(o) {
              return this.cleanRaws(this.root() === o.root()), this.remove(), o.parent.insertAfter(o, this), this;
            }
            next() {
              let o = this.parent.index(this);
              return this.parent.nodes[o + 1];
            }
            prev() {
              let o = this.parent.index(this);
              return this.parent.nodes[o - 1];
            }
            toJSON() {
              let o = {};
              for (let h in this) {
                if (!this.hasOwnProperty(h) || h === "parent")
                  continue;
                let l = this[h];
                l instanceof Array ? o[h] = l.map((p) => typeof p == "object" && p.toJSON ? p.toJSON() : p) : typeof l == "object" && l.toJSON ? o[h] = l.toJSON() : o[h] = l;
              }
              return o;
            }
            root() {
              let o = this;
              for (; o.parent; )
                o = o.parent;
              return o;
            }
            cleanRaws(o) {
              delete this.raws.before, delete this.raws.after, o || delete this.raws.between;
            }
            positionInside(o) {
              let h = this.toString(), l = this.source.start.column, p = this.source.start.line;
              for (let m = 0; m < o; m++)
                h[m] === `
` ? (l = 1, p += 1) : l += 1;
              return { line: p, column: l };
            }
            positionBy(o) {
              let h = this.source.start;
              if (Object(o).index)
                h = this.positionInside(o.index);
              else if (Object(o).word) {
                let l = this.toString().indexOf(o.word);
                l !== -1 && (h = this.positionInside(l));
              }
              return h;
            }
          };
        } }), ae = P({ "node_modules/postcss-values-parser/lib/container.js"(e, n) {
          "use strict";
          A();
          var i = we(), u = class extends i {
            constructor(o) {
              super(o), this.nodes || (this.nodes = []);
            }
            push(o) {
              return o.parent = this, this.nodes.push(o), this;
            }
            each(o) {
              this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach += 1;
              let h = this.lastEach, l, p;
              if (this.indexes[h] = 0, !!this.nodes) {
                for (; this.indexes[h] < this.nodes.length && (l = this.indexes[h], p = o(this.nodes[l], l), p !== false); )
                  this.indexes[h] += 1;
                return delete this.indexes[h], p;
              }
            }
            walk(o) {
              return this.each((h, l) => {
                let p = o(h, l);
                return p !== false && h.walk && (p = h.walk(o)), p;
              });
            }
            walkType(o, h) {
              if (!o || !h)
                throw new Error("Parameters {type} and {callback} are required.");
              let l = typeof o == "function";
              return this.walk((p, m) => {
                if (l && p instanceof o || !l && p.type === o)
                  return h.call(this, p, m);
              });
            }
            append(o) {
              return o.parent = this, this.nodes.push(o), this;
            }
            prepend(o) {
              return o.parent = this, this.nodes.unshift(o), this;
            }
            cleanRaws(o) {
              if (super.cleanRaws(o), this.nodes)
                for (let h of this.nodes)
                  h.cleanRaws(o);
            }
            insertAfter(o, h) {
              let l = this.index(o), p;
              this.nodes.splice(l + 1, 0, h);
              for (let m in this.indexes)
                p = this.indexes[m], l <= p && (this.indexes[m] = p + this.nodes.length);
              return this;
            }
            insertBefore(o, h) {
              let l = this.index(o), p;
              this.nodes.splice(l, 0, h);
              for (let m in this.indexes)
                p = this.indexes[m], l <= p && (this.indexes[m] = p + this.nodes.length);
              return this;
            }
            removeChild(o) {
              o = this.index(o), this.nodes[o].parent = void 0, this.nodes.splice(o, 1);
              let h;
              for (let l in this.indexes)
                h = this.indexes[l], h >= o && (this.indexes[l] = h - 1);
              return this;
            }
            removeAll() {
              for (let o of this.nodes)
                o.parent = void 0;
              return this.nodes = [], this;
            }
            every(o) {
              return this.nodes.every(o);
            }
            some(o) {
              return this.nodes.some(o);
            }
            index(o) {
              return typeof o == "number" ? o : this.nodes.indexOf(o);
            }
            get first() {
              if (this.nodes)
                return this.nodes[0];
            }
            get last() {
              if (this.nodes)
                return this.nodes[this.nodes.length - 1];
            }
            toString() {
              let o = this.nodes.map(String).join("");
              return this.value && (o = this.value + o), this.raws.before && (o = this.raws.before + o), this.raws.after && (o += this.raws.after), o;
            }
          };
          u.registerWalker = (o) => {
            let h = "walk" + o.name;
            h.lastIndexOf("s") !== h.length - 1 && (h += "s"), !u.prototype[h] && (u.prototype[h] = function(l) {
              return this.walkType(o, l);
            });
          }, n.exports = u;
        } }), Vl = P({ "node_modules/postcss-values-parser/lib/root.js"(e, n) {
          "use strict";
          A();
          var i = ae();
          n.exports = class extends i {
            constructor(o) {
              super(o), this.type = "root";
            }
          };
        } }), io = P({ "node_modules/postcss-values-parser/lib/value.js"(e, n) {
          "use strict";
          A();
          var i = ae();
          n.exports = class extends i {
            constructor(o) {
              super(o), this.type = "value", this.unbalanced = 0;
            }
          };
        } }), so = P({ "node_modules/postcss-values-parser/lib/atword.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = class extends i {
            constructor(o) {
              super(o), this.type = "atword";
            }
            toString() {
              let o = this.quoted ? this.raws.quote : "";
              return [this.raws.before, "@", String.prototype.toString.call(this.value), this.raws.after].join("");
            }
          };
          i.registerWalker(u), n.exports = u;
        } }), oo = P({ "node_modules/postcss-values-parser/lib/colon.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "colon";
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), ao = P({ "node_modules/postcss-values-parser/lib/comma.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "comma";
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), uo = P({ "node_modules/postcss-values-parser/lib/comment.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "comment", this.inline = Object(h).inline || false;
            }
            toString() {
              return [this.raws.before, this.inline ? "//" : "/*", String(this.value), this.inline ? "" : "*/", this.raws.after].join("");
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), co = P({ "node_modules/postcss-values-parser/lib/function.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = class extends i {
            constructor(o) {
              super(o), this.type = "func", this.unbalanced = -1;
            }
          };
          i.registerWalker(u), n.exports = u;
        } }), lo = P({ "node_modules/postcss-values-parser/lib/number.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "number", this.unit = Object(h).unit || "";
            }
            toString() {
              return [this.raws.before, String(this.value), this.unit, this.raws.after].join("");
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), fo = P({ "node_modules/postcss-values-parser/lib/operator.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "operator";
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), po = P({ "node_modules/postcss-values-parser/lib/paren.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "paren", this.parenType = "";
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), ho = P({ "node_modules/postcss-values-parser/lib/string.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "string";
            }
            toString() {
              let h = this.quoted ? this.raws.quote : "";
              return [this.raws.before, h, this.value + "", h, this.raws.after].join("");
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), vo = P({ "node_modules/postcss-values-parser/lib/word.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "word";
            }
          };
          i.registerWalker(o), n.exports = o;
        } }), mo = P({ "node_modules/postcss-values-parser/lib/unicode-range.js"(e, n) {
          "use strict";
          A();
          var i = ae(), u = we(), o = class extends u {
            constructor(h) {
              super(h), this.type = "unicode-range";
            }
          };
          i.registerWalker(o), n.exports = o;
        } });
        function go() {
          throw new Error("setTimeout has not been defined");
        }
        function yo() {
          throw new Error("clearTimeout has not been defined");
        }
        function wo(e) {
          if (Se === setTimeout)
            return setTimeout(e, 0);
          if ((Se === go || !Se) && setTimeout)
            return Se = setTimeout, setTimeout(e, 0);
          try {
            return Se(e, 0);
          } catch {
            try {
              return Se.call(null, e, 0);
            } catch {
              return Se.call(this, e, 0);
            }
          }
        }
        function Gl(e) {
          if (ke === clearTimeout)
            return clearTimeout(e);
          if ((ke === yo || !ke) && clearTimeout)
            return ke = clearTimeout, clearTimeout(e);
          try {
            return ke(e);
          } catch {
            try {
              return ke.call(null, e);
            } catch {
              return ke.call(this, e);
            }
          }
        }
        function Hl() {
          !Ne || !Ce || (Ne = false, Ce.length ? me = Ce.concat(me) : We = -1, me.length && _o());
        }
        function _o() {
          if (!Ne) {
            var e = wo(Hl);
            Ne = true;
            for (var n = me.length; n; ) {
              for (Ce = me, me = []; ++We < n; )
                Ce && Ce[We].run();
              We = -1, n = me.length;
            }
            Ce = null, Ne = false, Gl(e);
          }
        }
        function Jl(e) {
          var n = new Array(arguments.length - 1);
          if (arguments.length > 1)
            for (var i = 1; i < arguments.length; i++)
              n[i - 1] = arguments[i];
          me.push(new bo(e, n)), me.length === 1 && !Ne && wo(_o);
        }
        function bo(e, n) {
          this.fun = e, this.array = n;
        }
        function Ae() {
        }
        function Kl(e) {
          throw new Error("process.binding is not supported");
        }
        function Ql() {
          return "/";
        }
        function Yl(e) {
          throw new Error("process.chdir is not supported");
        }
        function Xl() {
          return 0;
        }
        function Zl(e) {
          var n = xo.call(Ie) * 1e-3, i = Math.floor(n), u = Math.floor(n % 1 * 1e9);
          return e && (i = i - e[0], u = u - e[1], u < 0 && (i--, u += 1e9)), [i, u];
        }
        function ef() {
          var e = /* @__PURE__ */ new Date(), n = e - So;
          return n / 1e3;
        }
        var Se, ke, me, Ne, Ce, We, ks, Os, Ts, Es, qs, As, Ps, Is, Rs, Cs, Ns, js, Ms, Ds, Ls, zs, Ie, xo, So, Bs, Ve, rf = Le({ "node-modules-polyfills:process"() {
          A(), Se = go, ke = yo, typeof globalThis.setTimeout == "function" && (Se = setTimeout), typeof globalThis.clearTimeout == "function" && (ke = clearTimeout), me = [], Ne = false, We = -1, bo.prototype.run = function() {
            this.fun.apply(null, this.array);
          }, ks = "browser", Os = "browser", Ts = true, Es = {}, qs = [], As = "", Ps = {}, Is = {}, Rs = {}, Cs = Ae, Ns = Ae, js = Ae, Ms = Ae, Ds = Ae, Ls = Ae, zs = Ae, Ie = globalThis.performance || {}, xo = Ie.now || Ie.mozNow || Ie.msNow || Ie.oNow || Ie.webkitNow || function() {
            return (/* @__PURE__ */ new Date()).getTime();
          }, So = /* @__PURE__ */ new Date(), Bs = { nextTick: Jl, title: ks, browser: Ts, env: Es, argv: qs, version: As, versions: Ps, on: Cs, addListener: Ns, once: js, off: Ms, removeListener: Ds, removeAllListeners: Ls, emit: zs, binding: Kl, cwd: Ql, chdir: Yl, umask: Xl, hrtime: Zl, platform: Os, release: Is, config: Rs, uptime: ef }, Ve = Bs;
        } }), pt, It, tf = Le({ "node_modules/rollup-plugin-node-polyfills/polyfills/inherits.js"() {
          A(), typeof Object.create == "function" ? pt = function(n, i) {
            n.super_ = i, n.prototype = Object.create(i.prototype, { constructor: { value: n, enumerable: false, writable: true, configurable: true } });
          } : pt = function(n, i) {
            n.super_ = i;
            var u = function() {
            };
            u.prototype = i.prototype, n.prototype = new u(), n.prototype.constructor = n;
          }, It = pt;
        } }), ko = {};
        At(ko, { _extend: () => Mt, debuglog: () => Oo, default: () => No, deprecate: () => Rt, format: () => wr, inherits: () => It, inspect: () => ye, isArray: () => Ct, isBoolean: () => _r, isBuffer: () => Ao, isDate: () => gr, isError: () => He, isFunction: () => Je, isNull: () => Ke, isNullOrUndefined: () => To, isNumber: () => Nt, isObject: () => je, isPrimitive: () => qo, isRegExp: () => Ge, isString: () => Qe, isSymbol: () => Eo, isUndefined: () => ge, log: () => Po });
        function wr(e) {
          if (!Qe(e)) {
            for (var n = [], i = 0; i < arguments.length; i++)
              n.push(ye(arguments[i]));
            return n.join(" ");
          }
          for (var i = 1, u = arguments, o = u.length, h = String(e).replace(Ro, function(p) {
            if (p === "%%")
              return "%";
            if (i >= o)
              return p;
            switch (p) {
              case "%s":
                return String(u[i++]);
              case "%d":
                return Number(u[i++]);
              case "%j":
                try {
                  return JSON.stringify(u[i++]);
                } catch {
                  return "[Circular]";
                }
              default:
                return p;
            }
          }), l = u[i]; i < o; l = u[++i])
            Ke(l) || !je(l) ? h += " " + l : h += " " + ye(l);
          return h;
        }
        function Rt(e, n) {
          if (ge(globalThis.process))
            return function() {
              return Rt(e, n).apply(this, arguments);
            };
          if (Ve.noDeprecation === true)
            return e;
          var i = false;
          function u() {
            if (!i) {
              if (Ve.throwDeprecation)
                throw new Error(n);
              Ve.traceDeprecation ? console.trace(n) : console.error(n), i = true;
            }
            return e.apply(this, arguments);
          }
          return u;
        }
        function Oo(e) {
          if (ge(vt) && (vt = Ve.env.NODE_DEBUG || ""), e = e.toUpperCase(), !$e[e])
            if (new RegExp("\\b" + e + "\\b", "i").test(vt)) {
              var n = 0;
              $e[e] = function() {
                var i = wr.apply(null, arguments);
                console.error("%s %d: %s", e, n, i);
              };
            } else
              $e[e] = function() {
              };
          return $e[e];
        }
        function ye(e, n) {
          var i = { seen: [], stylize: sf };
          return arguments.length >= 3 && (i.depth = arguments[2]), arguments.length >= 4 && (i.colors = arguments[3]), _r(n) ? i.showHidden = n : n && Mt(i, n), ge(i.showHidden) && (i.showHidden = false), ge(i.depth) && (i.depth = 2), ge(i.colors) && (i.colors = false), ge(i.customInspect) && (i.customInspect = true), i.colors && (i.stylize = nf), mr(i, e, i.depth);
        }
        function nf(e, n) {
          var i = ye.styles[n];
          return i ? "\x1B[" + ye.colors[i][0] + "m" + e + "\x1B[" + ye.colors[i][1] + "m" : e;
        }
        function sf(e, n) {
          return e;
        }
        function of(e) {
          var n = {};
          return e.forEach(function(i, u) {
            n[i] = true;
          }), n;
        }
        function mr(e, n, i) {
          if (e.customInspect && n && Je(n.inspect) && n.inspect !== ye && !(n.constructor && n.constructor.prototype === n)) {
            var u = n.inspect(i, e);
            return Qe(u) || (u = mr(e, u, i)), u;
          }
          var o = af(e, n);
          if (o)
            return o;
          var h = Object.keys(n), l = of(h);
          if (e.showHidden && (h = Object.getOwnPropertyNames(n)), He(n) && (h.indexOf("message") >= 0 || h.indexOf("description") >= 0))
            return ht(n);
          if (h.length === 0) {
            if (Je(n)) {
              var p = n.name ? ": " + n.name : "";
              return e.stylize("[Function" + p + "]", "special");
            }
            if (Ge(n))
              return e.stylize(RegExp.prototype.toString.call(n), "regexp");
            if (gr(n))
              return e.stylize(Date.prototype.toString.call(n), "date");
            if (He(n))
              return ht(n);
          }
          var m = "", c = false, t3 = ["{", "}"];
          if (Ct(n) && (c = true, t3 = ["[", "]"]), Je(n)) {
            var r = n.name ? ": " + n.name : "";
            m = " [Function" + r + "]";
          }
          if (Ge(n) && (m = " " + RegExp.prototype.toString.call(n)), gr(n) && (m = " " + Date.prototype.toUTCString.call(n)), He(n) && (m = " " + ht(n)), h.length === 0 && (!c || n.length == 0))
            return t3[0] + m + t3[1];
          if (i < 0)
            return Ge(n) ? e.stylize(RegExp.prototype.toString.call(n), "regexp") : e.stylize("[Object]", "special");
          e.seen.push(n);
          var a;
          return c ? a = uf(e, n, i, l, h) : a = h.map(function(s) {
            return xt(e, n, i, l, s, c);
          }), e.seen.pop(), cf(a, m, t3);
        }
        function af(e, n) {
          if (ge(n))
            return e.stylize("undefined", "undefined");
          if (Qe(n)) {
            var i = "'" + JSON.stringify(n).replace(/^"|"$/g, "").replace(/'/g, "\\'").replace(/\\"/g, '"') + "'";
            return e.stylize(i, "string");
          }
          if (Nt(n))
            return e.stylize("" + n, "number");
          if (_r(n))
            return e.stylize("" + n, "boolean");
          if (Ke(n))
            return e.stylize("null", "null");
        }
        function ht(e) {
          return "[" + Error.prototype.toString.call(e) + "]";
        }
        function uf(e, n, i, u, o) {
          for (var h = [], l = 0, p = n.length; l < p; ++l)
            Io(n, String(l)) ? h.push(xt(e, n, i, u, String(l), true)) : h.push("");
          return o.forEach(function(m) {
            m.match(/^\d+$/) || h.push(xt(e, n, i, u, m, true));
          }), h;
        }
        function xt(e, n, i, u, o, h) {
          var l, p, m;
          if (m = Object.getOwnPropertyDescriptor(n, o) || { value: n[o] }, m.get ? m.set ? p = e.stylize("[Getter/Setter]", "special") : p = e.stylize("[Getter]", "special") : m.set && (p = e.stylize("[Setter]", "special")), Io(u, o) || (l = "[" + o + "]"), p || (e.seen.indexOf(m.value) < 0 ? (Ke(i) ? p = mr(e, m.value, null) : p = mr(e, m.value, i - 1), p.indexOf(`
`) > -1 && (h ? p = p.split(`
`).map(function(c) {
            return "  " + c;
          }).join(`
`).substr(2) : p = `
` + p.split(`
`).map(function(c) {
            return "   " + c;
          }).join(`
`))) : p = e.stylize("[Circular]", "special")), ge(l)) {
            if (h && o.match(/^\d+$/))
              return p;
            l = JSON.stringify("" + o), l.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/) ? (l = l.substr(1, l.length - 2), l = e.stylize(l, "name")) : (l = l.replace(/'/g, "\\'").replace(/\\"/g, '"').replace(/(^"|"$)/g, "'"), l = e.stylize(l, "string"));
          }
          return l + ": " + p;
        }
        function cf(e, n, i) {
          var u = 0, o = e.reduce(function(h, l) {
            return u++, l.indexOf(`
`) >= 0 && u++, h + l.replace(/\u001b\[\d\d?m/g, "").length + 1;
          }, 0);
          return o > 60 ? i[0] + (n === "" ? "" : n + `
 `) + " " + e.join(`,
  `) + " " + i[1] : i[0] + n + " " + e.join(", ") + " " + i[1];
        }
        function Ct(e) {
          return Array.isArray(e);
        }
        function _r(e) {
          return typeof e == "boolean";
        }
        function Ke(e) {
          return e === null;
        }
        function To(e) {
          return e == null;
        }
        function Nt(e) {
          return typeof e == "number";
        }
        function Qe(e) {
          return typeof e == "string";
        }
        function Eo(e) {
          return typeof e == "symbol";
        }
        function ge(e) {
          return e === void 0;
        }
        function Ge(e) {
          return je(e) && jt(e) === "[object RegExp]";
        }
        function je(e) {
          return typeof e == "object" && e !== null;
        }
        function gr(e) {
          return je(e) && jt(e) === "[object Date]";
        }
        function He(e) {
          return je(e) && (jt(e) === "[object Error]" || e instanceof Error);
        }
        function Je(e) {
          return typeof e == "function";
        }
        function qo(e) {
          return e === null || typeof e == "boolean" || typeof e == "number" || typeof e == "string" || typeof e == "symbol" || typeof e > "u";
        }
        function Ao(e) {
          return Buffer.isBuffer(e);
        }
        function jt(e) {
          return Object.prototype.toString.call(e);
        }
        function dt(e) {
          return e < 10 ? "0" + e.toString(10) : e.toString(10);
        }
        function lf() {
          var e = /* @__PURE__ */ new Date(), n = [dt(e.getHours()), dt(e.getMinutes()), dt(e.getSeconds())].join(":");
          return [e.getDate(), Co[e.getMonth()], n].join(" ");
        }
        function Po() {
          console.log("%s - %s", lf(), wr.apply(null, arguments));
        }
        function Mt(e, n) {
          if (!n || !je(n))
            return e;
          for (var i = Object.keys(n), u = i.length; u--; )
            e[i[u]] = n[i[u]];
          return e;
        }
        function Io(e, n) {
          return Object.prototype.hasOwnProperty.call(e, n);
        }
        var Ro, $e, vt, Co, No, ff = Le({ "node-modules-polyfills:util"() {
          A(), rf(), tf(), Ro = /%[sdj%]/g, $e = {}, ye.colors = { bold: [1, 22], italic: [3, 23], underline: [4, 24], inverse: [7, 27], white: [37, 39], grey: [90, 39], black: [30, 39], blue: [34, 39], cyan: [36, 39], green: [32, 39], magenta: [35, 39], red: [31, 39], yellow: [33, 39] }, ye.styles = { special: "cyan", number: "yellow", boolean: "yellow", undefined: "grey", null: "bold", string: "green", date: "magenta", regexp: "red" }, Co = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"], No = { inherits: It, _extend: Mt, log: Po, isBuffer: Ao, isPrimitive: qo, isFunction: Je, isError: He, isDate: gr, isObject: je, isRegExp: Ge, isUndefined: ge, isSymbol: Eo, isString: Qe, isNumber: Nt, isNullOrUndefined: To, isNull: Ke, isBoolean: _r, isArray: Ct, inspect: ye, deprecate: Rt, format: wr, debuglog: Oo };
        } }), pf = P({ "node-modules-polyfills-commonjs:util"(e, n) {
          A();
          var i = (ff(), Pt(ko));
          if (i && i.default) {
            n.exports = i.default;
            for (let u in i)
              n.exports[u] = i[u];
          } else
            i && (n.exports = i);
        } }), hf = P({ "node_modules/postcss-values-parser/lib/errors/TokenizeError.js"(e, n) {
          "use strict";
          A();
          var i = class extends Error {
            constructor(u) {
              super(u), this.name = this.constructor.name, this.message = u || "An error ocurred while tokzenizing.", typeof Error.captureStackTrace == "function" ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(u).stack;
            }
          };
          n.exports = i;
        } }), df = P({ "node_modules/postcss-values-parser/lib/tokenize.js"(e, n) {
          "use strict";
          A();
          var i = "{".charCodeAt(0), u = "}".charCodeAt(0), o = "(".charCodeAt(0), h = ")".charCodeAt(0), l = "'".charCodeAt(0), p = '"'.charCodeAt(0), m = "\\".charCodeAt(0), c = "/".charCodeAt(0), t3 = ".".charCodeAt(0), r = ",".charCodeAt(0), a = ":".charCodeAt(0), s = "*".charCodeAt(0), f = "-".charCodeAt(0), g = "+".charCodeAt(0), v = "#".charCodeAt(0), y = `
`.charCodeAt(0), w = " ".charCodeAt(0), d = "\f".charCodeAt(0), _ = "	".charCodeAt(0), k = "\r".charCodeAt(0), x = "@".charCodeAt(0), N = "e".charCodeAt(0), I = "E".charCodeAt(0), W = "0".charCodeAt(0), $2 = "9".charCodeAt(0), H = "u".charCodeAt(0), D = "U".charCodeAt(0), V = /[ \n\t\r\{\(\)'"\\;,/]/g, B = /[ \n\t\r\(\)\{\}\*:;@!&'"\+\|~>,\[\]\\]|\/(?=\*)/g, O = /[ \n\t\r\(\)\{\}\*:;@!&'"\-\+\|~>,\[\]\\]|\//g, j = /^[a-z0-9]/i, C = /^[a-f0-9?\-]/i, R = pf(), X = hf();
          n.exports = function(Q, K) {
            K = K || {};
            let J = [], M = Q.valueOf(), Y = M.length, G = -1, E = 1, S = 0, b = 0, L = null, q, T, F, z, ee, te, ue, le, re, ne, oe, ie;
            function ce(Ze) {
              let _e = R.format("Unclosed %s at line: %d, column: %d, token: %d", Ze, E, S - G, S);
              throw new X(_e);
            }
            function fe() {
              let Ze = R.format("Syntax error at line: %d, column: %d, token: %d", E, S - G, S);
              throw new X(Ze);
            }
            for (; S < Y; ) {
              switch (q = M.charCodeAt(S), q === y && (G = S, E += 1), q) {
                case y:
                case w:
                case _:
                case k:
                case d:
                  T = S;
                  do
                    T += 1, q = M.charCodeAt(T), q === y && (G = T, E += 1);
                  while (q === w || q === y || q === _ || q === k || q === d);
                  J.push(["space", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  break;
                case a:
                  T = S + 1, J.push(["colon", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  break;
                case r:
                  T = S + 1, J.push(["comma", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  break;
                case i:
                  J.push(["{", "{", E, S - G, E, T - G, S]);
                  break;
                case u:
                  J.push(["}", "}", E, S - G, E, T - G, S]);
                  break;
                case o:
                  b++, L = !L && b === 1 && J.length > 0 && J[J.length - 1][0] === "word" && J[J.length - 1][1] === "url", J.push(["(", "(", E, S - G, E, T - G, S]);
                  break;
                case h:
                  b--, L = L && b > 0, J.push([")", ")", E, S - G, E, T - G, S]);
                  break;
                case l:
                case p:
                  F = q === l ? "'" : '"', T = S;
                  do
                    for (ne = false, T = M.indexOf(F, T + 1), T === -1 && ce("quote", F), oe = T; M.charCodeAt(oe - 1) === m; )
                      oe -= 1, ne = !ne;
                  while (ne);
                  J.push(["string", M.slice(S, T + 1), E, S - G, E, T - G, S]), S = T;
                  break;
                case x:
                  V.lastIndex = S + 1, V.test(M), V.lastIndex === 0 ? T = M.length - 1 : T = V.lastIndex - 2, J.push(["atword", M.slice(S, T + 1), E, S - G, E, T - G, S]), S = T;
                  break;
                case m:
                  T = S, q = M.charCodeAt(T + 1), ue && q !== c && q !== w && q !== y && q !== _ && q !== k && q !== d && (T += 1), J.push(["word", M.slice(S, T + 1), E, S - G, E, T - G, S]), S = T;
                  break;
                case g:
                case f:
                case s:
                  T = S + 1, ie = M.slice(S + 1, T + 1);
                  let Ze = M.slice(S - 1, S);
                  if (q === f && ie.charCodeAt(0) === f) {
                    T++, J.push(["word", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                    break;
                  }
                  J.push(["operator", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  break;
                default:
                  if (q === c && (M.charCodeAt(S + 1) === s || K.loose && !L && M.charCodeAt(S + 1) === c)) {
                    if (M.charCodeAt(S + 1) === s)
                      T = M.indexOf("*/", S + 2) + 1, T === 0 && ce("comment", "*/");
                    else {
                      let Be = M.indexOf(`
`, S + 2);
                      T = Be !== -1 ? Be - 1 : Y;
                    }
                    te = M.slice(S, T + 1), z = te.split(`
`), ee = z.length - 1, ee > 0 ? (le = E + ee, re = T - z[ee].length) : (le = E, re = G), J.push(["comment", te, E, S - G, le, T - re, S]), G = re, E = le, S = T;
                  } else if (q === v && !j.test(M.slice(S + 1, S + 2)))
                    T = S + 1, J.push(["#", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  else if ((q === H || q === D) && M.charCodeAt(S + 1) === g) {
                    T = S + 2;
                    do
                      T += 1, q = M.charCodeAt(T);
                    while (T < Y && C.test(M.slice(T, T + 1)));
                    J.push(["unicoderange", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  } else if (q === c)
                    T = S + 1, J.push(["operator", M.slice(S, T), E, S - G, E, T - G, S]), S = T - 1;
                  else {
                    let _e = B;
                    if (q >= W && q <= $2 && (_e = O), _e.lastIndex = S + 1, _e.test(M), _e.lastIndex === 0 ? T = M.length - 1 : T = _e.lastIndex - 2, _e === O || q === t3) {
                      let Be = M.charCodeAt(T), Wt = M.charCodeAt(T + 1), Vt = M.charCodeAt(T + 2);
                      (Be === N || Be === I) && (Wt === f || Wt === g) && Vt >= W && Vt <= $2 && (O.lastIndex = T + 2, O.test(M), O.lastIndex === 0 ? T = M.length - 1 : T = O.lastIndex - 2);
                    }
                    J.push(["word", M.slice(S, T + 1), E, S - G, E, T - G, S]), S = T;
                  }
                  break;
              }
              S++;
            }
            return J;
          };
        } }), jo = P({ "node_modules/flatten/index.js"(e, n) {
          A(), n.exports = function(u, o) {
            if (o = typeof o == "number" ? o : 1 / 0, !o)
              return Array.isArray(u) ? u.map(function(l) {
                return l;
              }) : u;
            return h(u, 1);
            function h(l, p) {
              return l.reduce(function(m, c) {
                return Array.isArray(c) && p < o ? m.concat(h(c, p + 1)) : m.concat(c);
              }, []);
            }
          };
        } }), Mo = P({ "node_modules/indexes-of/index.js"(e, n) {
          A(), n.exports = function(i, u) {
            for (var o = -1, h = []; (o = i.indexOf(u, o + 1)) !== -1; )
              h.push(o);
            return h;
          };
        } }), Do = P({ "node_modules/uniq/uniq.js"(e, n) {
          "use strict";
          A();
          function i(h, l) {
            for (var p = 1, m = h.length, c = h[0], t3 = h[0], r = 1; r < m; ++r)
              if (t3 = c, c = h[r], l(c, t3)) {
                if (r === p) {
                  p++;
                  continue;
                }
                h[p++] = c;
              }
            return h.length = p, h;
          }
          function u(h) {
            for (var l = 1, p = h.length, m = h[0], c = h[0], t3 = 1; t3 < p; ++t3, c = m)
              if (c = m, m = h[t3], m !== c) {
                if (t3 === l) {
                  l++;
                  continue;
                }
                h[l++] = m;
              }
            return h.length = l, h;
          }
          function o(h, l, p) {
            return h.length === 0 ? h : l ? (p || h.sort(l), i(h, l)) : (p || h.sort(), u(h));
          }
          n.exports = o;
        } }), vf = P({ "node_modules/postcss-values-parser/lib/errors/ParserError.js"(e, n) {
          "use strict";
          A();
          var i = class extends Error {
            constructor(u) {
              super(u), this.name = this.constructor.name, this.message = u || "An error ocurred while parsing.", typeof Error.captureStackTrace == "function" ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error(u).stack;
            }
          };
          n.exports = i;
        } }), mf = P({ "node_modules/postcss-values-parser/lib/parser.js"(e, n) {
          "use strict";
          A();
          var i = Vl(), u = io(), o = so(), h = oo(), l = ao(), p = uo(), m = co(), c = lo(), t3 = fo(), r = po(), a = ho(), s = vo(), f = mo(), g = df(), v = jo(), y = Mo(), w = Do(), d = vf();
          function _(k) {
            return k.sort((x, N) => x - N);
          }
          n.exports = class {
            constructor(x, N) {
              let I = { loose: false };
              this.cache = [], this.input = x, this.options = Object.assign({}, I, N), this.position = 0, this.unbalanced = 0, this.root = new i();
              let W = new u();
              this.root.append(W), this.current = W, this.tokens = g(x, this.options);
            }
            parse() {
              return this.loop();
            }
            colon() {
              let x = this.currToken;
              this.newNode(new h({ value: x[1], source: { start: { line: x[2], column: x[3] }, end: { line: x[4], column: x[5] } }, sourceIndex: x[6] })), this.position++;
            }
            comma() {
              let x = this.currToken;
              this.newNode(new l({ value: x[1], source: { start: { line: x[2], column: x[3] }, end: { line: x[4], column: x[5] } }, sourceIndex: x[6] })), this.position++;
            }
            comment() {
              let x = false, N = this.currToken[1].replace(/\/\*|\*\//g, ""), I;
              this.options.loose && N.startsWith("//") && (N = N.substring(2), x = true), I = new p({ value: N, inline: x, source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[4], column: this.currToken[5] } }, sourceIndex: this.currToken[6] }), this.newNode(I), this.position++;
            }
            error(x, N) {
              throw new d(x + ` at line: ${N[2]}, column ${N[3]}`);
            }
            loop() {
              for (; this.position < this.tokens.length; )
                this.parseTokens();
              return !this.current.last && this.spaces ? this.current.raws.before += this.spaces : this.spaces && (this.current.last.raws.after += this.spaces), this.spaces = "", this.root;
            }
            operator() {
              let x = this.currToken[1], N;
              if (x === "+" || x === "-") {
                if (this.options.loose || this.position > 0 && (this.current.type === "func" && this.current.value === "calc" ? this.prevToken[0] !== "space" && this.prevToken[0] !== "(" ? this.error("Syntax Error", this.currToken) : this.nextToken[0] !== "space" && this.nextToken[0] !== "word" ? this.error("Syntax Error", this.currToken) : this.nextToken[0] === "word" && this.current.last.type !== "operator" && this.current.last.value !== "(" && this.error("Syntax Error", this.currToken) : (this.nextToken[0] === "space" || this.nextToken[0] === "operator" || this.prevToken[0] === "operator") && this.error("Syntax Error", this.currToken)), this.options.loose) {
                  if ((!this.current.nodes.length || this.current.last && this.current.last.type === "operator") && this.nextToken[0] === "word")
                    return this.word();
                } else if (this.nextToken[0] === "word")
                  return this.word();
              }
              return N = new t3({ value: this.currToken[1], source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[2], column: this.currToken[3] } }, sourceIndex: this.currToken[4] }), this.position++, this.newNode(N);
            }
            parseTokens() {
              switch (this.currToken[0]) {
                case "space":
                  this.space();
                  break;
                case "colon":
                  this.colon();
                  break;
                case "comma":
                  this.comma();
                  break;
                case "comment":
                  this.comment();
                  break;
                case "(":
                  this.parenOpen();
                  break;
                case ")":
                  this.parenClose();
                  break;
                case "atword":
                case "word":
                  this.word();
                  break;
                case "operator":
                  this.operator();
                  break;
                case "string":
                  this.string();
                  break;
                case "unicoderange":
                  this.unicodeRange();
                  break;
                default:
                  this.word();
                  break;
              }
            }
            parenOpen() {
              let x = 1, N = this.position + 1, I = this.currToken, W;
              for (; N < this.tokens.length && x; ) {
                let $2 = this.tokens[N];
                $2[0] === "(" && x++, $2[0] === ")" && x--, N++;
              }
              if (x && this.error("Expected closing parenthesis", I), W = this.current.last, W && W.type === "func" && W.unbalanced < 0 && (W.unbalanced = 0, this.current = W), this.current.unbalanced++, this.newNode(new r({ value: I[1], source: { start: { line: I[2], column: I[3] }, end: { line: I[4], column: I[5] } }, sourceIndex: I[6] })), this.position++, this.current.type === "func" && this.current.unbalanced && this.current.value === "url" && this.currToken[0] !== "string" && this.currToken[0] !== ")" && !this.options.loose) {
                let $2 = this.nextToken, H = this.currToken[1], D = { line: this.currToken[2], column: this.currToken[3] };
                for (; $2 && $2[0] !== ")" && this.current.unbalanced; )
                  this.position++, H += this.currToken[1], $2 = this.nextToken;
                this.position !== this.tokens.length - 1 && (this.position++, this.newNode(new s({ value: H, source: { start: D, end: { line: this.currToken[4], column: this.currToken[5] } }, sourceIndex: this.currToken[6] })));
              }
            }
            parenClose() {
              let x = this.currToken;
              this.newNode(new r({ value: x[1], source: { start: { line: x[2], column: x[3] }, end: { line: x[4], column: x[5] } }, sourceIndex: x[6] })), this.position++, !(this.position >= this.tokens.length - 1 && !this.current.unbalanced) && (this.current.unbalanced--, this.current.unbalanced < 0 && this.error("Expected opening parenthesis", x), !this.current.unbalanced && this.cache.length && (this.current = this.cache.pop()));
            }
            space() {
              let x = this.currToken;
              this.position === this.tokens.length - 1 || this.nextToken[0] === "," || this.nextToken[0] === ")" ? (this.current.last.raws.after += x[1], this.position++) : (this.spaces = x[1], this.position++);
            }
            unicodeRange() {
              let x = this.currToken;
              this.newNode(new f({ value: x[1], source: { start: { line: x[2], column: x[3] }, end: { line: x[4], column: x[5] } }, sourceIndex: x[6] })), this.position++;
            }
            splitWord() {
              let x = this.nextToken, N = this.currToken[1], I = /^[\+\-]?((\d+(\.\d*)?)|(\.\d+))([eE][\+\-]?\d+)?/, W = /^(?!\#([a-z0-9]+))[\#\{\}]/gi, $2, H;
              if (!W.test(N))
                for (; x && x[0] === "word"; ) {
                  this.position++;
                  let D = this.currToken[1];
                  N += D, x = this.nextToken;
                }
              $2 = y(N, "@"), H = _(w(v([[0], $2]))), H.forEach((D, V) => {
                let B = H[V + 1] || N.length, O = N.slice(D, B), j;
                if (~$2.indexOf(D))
                  j = new o({ value: O.slice(1), source: { start: { line: this.currToken[2], column: this.currToken[3] + D }, end: { line: this.currToken[4], column: this.currToken[3] + (B - 1) } }, sourceIndex: this.currToken[6] + H[V] });
                else if (I.test(this.currToken[1])) {
                  let C = O.replace(I, "");
                  j = new c({ value: O.replace(C, ""), source: { start: { line: this.currToken[2], column: this.currToken[3] + D }, end: { line: this.currToken[4], column: this.currToken[3] + (B - 1) } }, sourceIndex: this.currToken[6] + H[V], unit: C });
                } else
                  j = new (x && x[0] === "(" ? m : s)({ value: O, source: { start: { line: this.currToken[2], column: this.currToken[3] + D }, end: { line: this.currToken[4], column: this.currToken[3] + (B - 1) } }, sourceIndex: this.currToken[6] + H[V] }), j.type === "word" ? (j.isHex = /^#(.+)/.test(O), j.isColor = /^#([0-9a-f]{3}|[0-9a-f]{4}|[0-9a-f]{6}|[0-9a-f]{8})$/i.test(O)) : this.cache.push(this.current);
                this.newNode(j);
              }), this.position++;
            }
            string() {
              let x = this.currToken, N = this.currToken[1], I = /^(\"|\')/, W = I.test(N), $2 = "", H;
              W && ($2 = N.match(I)[0], N = N.slice(1, N.length - 1)), H = new a({ value: N, source: { start: { line: x[2], column: x[3] }, end: { line: x[4], column: x[5] } }, sourceIndex: x[6], quoted: W }), H.raws.quote = $2, this.newNode(H), this.position++;
            }
            word() {
              return this.splitWord();
            }
            newNode(x) {
              return this.spaces && (x.raws.before += this.spaces, this.spaces = ""), this.current.append(x);
            }
            get currToken() {
              return this.tokens[this.position];
            }
            get nextToken() {
              return this.tokens[this.position + 1];
            }
            get prevToken() {
              return this.tokens[this.position - 1];
            }
          };
        } }), gf = P({ "node_modules/postcss-values-parser/lib/index.js"(e, n) {
          "use strict";
          A();
          var i = mf(), u = so(), o = oo(), h = ao(), l = uo(), p = co(), m = lo(), c = fo(), t3 = po(), r = ho(), a = mo(), s = io(), f = vo(), g = function(v, y) {
            return new i(v, y);
          };
          g.atword = function(v) {
            return new u(v);
          }, g.colon = function(v) {
            return new o(Object.assign({ value: ":" }, v));
          }, g.comma = function(v) {
            return new h(Object.assign({ value: "," }, v));
          }, g.comment = function(v) {
            return new l(v);
          }, g.func = function(v) {
            return new p(v);
          }, g.number = function(v) {
            return new m(v);
          }, g.operator = function(v) {
            return new c(v);
          }, g.paren = function(v) {
            return new t3(Object.assign({ value: "(" }, v));
          }, g.string = function(v) {
            return new r(Object.assign({ quote: "'" }, v));
          }, g.value = function(v) {
            return new s(v);
          }, g.word = function(v) {
            return new f(v);
          }, g.unicodeRange = function(v) {
            return new a(v);
          }, n.exports = g;
        } }), ze = P({ "node_modules/postcss-selector-parser/dist/selectors/node.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(l) {
            return typeof l;
          } : function(l) {
            return l && typeof Symbol == "function" && l.constructor === Symbol && l !== Symbol.prototype ? "symbol" : typeof l;
          };
          function u(l, p) {
            if (!(l instanceof p))
              throw new TypeError("Cannot call a class as a function");
          }
          var o = function l(p, m) {
            if ((typeof p > "u" ? "undefined" : i(p)) !== "object")
              return p;
            var c = new p.constructor();
            for (var t3 in p)
              if (p.hasOwnProperty(t3)) {
                var r = p[t3], a = typeof r > "u" ? "undefined" : i(r);
                t3 === "parent" && a === "object" ? m && (c[t3] = m) : r instanceof Array ? c[t3] = r.map(function(s) {
                  return l(s, c);
                }) : c[t3] = l(r, c);
              }
            return c;
          }, h = function() {
            function l() {
              var p = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
              u(this, l);
              for (var m in p)
                this[m] = p[m];
              var c = p.spaces;
              c = c === void 0 ? {} : c;
              var t3 = c.before, r = t3 === void 0 ? "" : t3, a = c.after, s = a === void 0 ? "" : a;
              this.spaces = { before: r, after: s };
            }
            return l.prototype.remove = function() {
              return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
            }, l.prototype.replaceWith = function() {
              if (this.parent) {
                for (var m in arguments)
                  this.parent.insertBefore(this, arguments[m]);
                this.remove();
              }
              return this;
            }, l.prototype.next = function() {
              return this.parent.at(this.parent.index(this) + 1);
            }, l.prototype.prev = function() {
              return this.parent.at(this.parent.index(this) - 1);
            }, l.prototype.clone = function() {
              var m = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, c = o(this);
              for (var t3 in m)
                c[t3] = m[t3];
              return c;
            }, l.prototype.toString = function() {
              return [this.spaces.before, String(this.value), this.spaces.after].join("");
            }, l;
          }();
          e.default = h, n.exports = e.default;
        } }), se = P({ "node_modules/postcss-selector-parser/dist/selectors/types.js"(e) {
          "use strict";
          A(), e.__esModule = true;
          var n = e.TAG = "tag", i = e.STRING = "string", u = e.SELECTOR = "selector", o = e.ROOT = "root", h = e.PSEUDO = "pseudo", l = e.NESTING = "nesting", p = e.ID = "id", m = e.COMMENT = "comment", c = e.COMBINATOR = "combinator", t3 = e.CLASS = "class", r = e.ATTRIBUTE = "attribute", a = e.UNIVERSAL = "universal";
        } }), Dt = P({ "node_modules/postcss-selector-parser/dist/selectors/container.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = function() {
            function s(f, g) {
              for (var v = 0; v < g.length; v++) {
                var y = g[v];
                y.enumerable = y.enumerable || false, y.configurable = true, "value" in y && (y.writable = true), Object.defineProperty(f, y.key, y);
              }
            }
            return function(f, g, v) {
              return g && s(f.prototype, g), v && s(f, v), f;
            };
          }(), u = ze(), o = m(u), h = se(), l = p(h);
          function p(s) {
            if (s && s.__esModule)
              return s;
            var f = {};
            if (s != null)
              for (var g in s)
                Object.prototype.hasOwnProperty.call(s, g) && (f[g] = s[g]);
            return f.default = s, f;
          }
          function m(s) {
            return s && s.__esModule ? s : { default: s };
          }
          function c(s, f) {
            if (!(s instanceof f))
              throw new TypeError("Cannot call a class as a function");
          }
          function t3(s, f) {
            if (!s)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return f && (typeof f == "object" || typeof f == "function") ? f : s;
          }
          function r(s, f) {
            if (typeof f != "function" && f !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof f);
            s.prototype = Object.create(f && f.prototype, { constructor: { value: s, enumerable: false, writable: true, configurable: true } }), f && (Object.setPrototypeOf ? Object.setPrototypeOf(s, f) : s.__proto__ = f);
          }
          var a = function(s) {
            r(f, s);
            function f(g) {
              c(this, f);
              var v = t3(this, s.call(this, g));
              return v.nodes || (v.nodes = []), v;
            }
            return f.prototype.append = function(v) {
              return v.parent = this, this.nodes.push(v), this;
            }, f.prototype.prepend = function(v) {
              return v.parent = this, this.nodes.unshift(v), this;
            }, f.prototype.at = function(v) {
              return this.nodes[v];
            }, f.prototype.index = function(v) {
              return typeof v == "number" ? v : this.nodes.indexOf(v);
            }, f.prototype.removeChild = function(v) {
              v = this.index(v), this.at(v).parent = void 0, this.nodes.splice(v, 1);
              var y = void 0;
              for (var w in this.indexes)
                y = this.indexes[w], y >= v && (this.indexes[w] = y - 1);
              return this;
            }, f.prototype.removeAll = function() {
              for (var w = this.nodes, v = Array.isArray(w), y = 0, w = v ? w : w[Symbol.iterator](); ; ) {
                var d;
                if (v) {
                  if (y >= w.length)
                    break;
                  d = w[y++];
                } else {
                  if (y = w.next(), y.done)
                    break;
                  d = y.value;
                }
                var _ = d;
                _.parent = void 0;
              }
              return this.nodes = [], this;
            }, f.prototype.empty = function() {
              return this.removeAll();
            }, f.prototype.insertAfter = function(v, y) {
              var w = this.index(v);
              this.nodes.splice(w + 1, 0, y);
              var d = void 0;
              for (var _ in this.indexes)
                d = this.indexes[_], w <= d && (this.indexes[_] = d + this.nodes.length);
              return this;
            }, f.prototype.insertBefore = function(v, y) {
              var w = this.index(v);
              this.nodes.splice(w, 0, y);
              var d = void 0;
              for (var _ in this.indexes)
                d = this.indexes[_], w <= d && (this.indexes[_] = d + this.nodes.length);
              return this;
            }, f.prototype.each = function(v) {
              this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach++;
              var y = this.lastEach;
              if (this.indexes[y] = 0, !!this.length) {
                for (var w = void 0, d = void 0; this.indexes[y] < this.length && (w = this.indexes[y], d = v(this.at(w), w), d !== false); )
                  this.indexes[y] += 1;
                if (delete this.indexes[y], d === false)
                  return false;
              }
            }, f.prototype.walk = function(v) {
              return this.each(function(y, w) {
                var d = v(y, w);
                if (d !== false && y.length && (d = y.walk(v)), d === false)
                  return false;
              });
            }, f.prototype.walkAttributes = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.ATTRIBUTE)
                  return v.call(y, w);
              });
            }, f.prototype.walkClasses = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.CLASS)
                  return v.call(y, w);
              });
            }, f.prototype.walkCombinators = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.COMBINATOR)
                  return v.call(y, w);
              });
            }, f.prototype.walkComments = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.COMMENT)
                  return v.call(y, w);
              });
            }, f.prototype.walkIds = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.ID)
                  return v.call(y, w);
              });
            }, f.prototype.walkNesting = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.NESTING)
                  return v.call(y, w);
              });
            }, f.prototype.walkPseudos = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.PSEUDO)
                  return v.call(y, w);
              });
            }, f.prototype.walkTags = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.TAG)
                  return v.call(y, w);
              });
            }, f.prototype.walkUniversals = function(v) {
              var y = this;
              return this.walk(function(w) {
                if (w.type === l.UNIVERSAL)
                  return v.call(y, w);
              });
            }, f.prototype.split = function(v) {
              var y = this, w = [];
              return this.reduce(function(d, _, k) {
                var x = v.call(y, _);
                return w.push(_), x ? (d.push(w), w = []) : k === y.length - 1 && d.push(w), d;
              }, []);
            }, f.prototype.map = function(v) {
              return this.nodes.map(v);
            }, f.prototype.reduce = function(v, y) {
              return this.nodes.reduce(v, y);
            }, f.prototype.every = function(v) {
              return this.nodes.every(v);
            }, f.prototype.some = function(v) {
              return this.nodes.some(v);
            }, f.prototype.filter = function(v) {
              return this.nodes.filter(v);
            }, f.prototype.sort = function(v) {
              return this.nodes.sort(v);
            }, f.prototype.toString = function() {
              return this.map(String).join("");
            }, i(f, [{ key: "first", get: function() {
              return this.at(0);
            } }, { key: "last", get: function() {
              return this.at(this.length - 1);
            } }, { key: "length", get: function() {
              return this.nodes.length;
            } }]), f;
          }(o.default);
          e.default = a, n.exports = e.default;
        } }), Lo = P({ "node_modules/postcss-selector-parser/dist/selectors/root.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Dt(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.ROOT, s;
            }
            return r.prototype.toString = function() {
              var s = this.reduce(function(f, g) {
                var v = String(g);
                return v ? f + v + "," : "";
              }, "").slice(0, -1);
              return this.trailingComma ? s + "," : s;
            }, r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), zo = P({ "node_modules/postcss-selector-parser/dist/selectors/selector.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Dt(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.SELECTOR, s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Ye = P({ "node_modules/postcss-selector-parser/dist/selectors/namespace.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = function() {
            function t3(r, a) {
              for (var s = 0; s < a.length; s++) {
                var f = a[s];
                f.enumerable = f.enumerable || false, f.configurable = true, "value" in f && (f.writable = true), Object.defineProperty(r, f.key, f);
              }
            }
            return function(r, a, s) {
              return a && t3(r.prototype, a), s && t3(r, s), r;
            };
          }(), u = ze(), o = h(u);
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r() {
              return l(this, r), p(this, t3.apply(this, arguments));
            }
            return r.prototype.toString = function() {
              return [this.spaces.before, this.ns, String(this.value), this.spaces.after].join("");
            }, i(r, [{ key: "ns", get: function() {
              var s = this.namespace;
              return s ? (typeof s == "string" ? s : "") + "|" : "";
            } }]), r;
          }(o.default);
          e.default = c, n.exports = e.default;
        } }), Bo = P({ "node_modules/postcss-selector-parser/dist/selectors/className.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Ye(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.CLASS, s;
            }
            return r.prototype.toString = function() {
              return [this.spaces.before, this.ns, String("." + this.value), this.spaces.after].join("");
            }, r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Fo = P({ "node_modules/postcss-selector-parser/dist/selectors/comment.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = ze(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.COMMENT, s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Uo = P({ "node_modules/postcss-selector-parser/dist/selectors/id.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Ye(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.ID, s;
            }
            return r.prototype.toString = function() {
              return [this.spaces.before, this.ns, String("#" + this.value), this.spaces.after].join("");
            }, r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), $o = P({ "node_modules/postcss-selector-parser/dist/selectors/tag.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Ye(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.TAG, s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Wo = P({ "node_modules/postcss-selector-parser/dist/selectors/string.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = ze(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.STRING, s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Vo = P({ "node_modules/postcss-selector-parser/dist/selectors/pseudo.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Dt(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.PSEUDO, s;
            }
            return r.prototype.toString = function() {
              var s = this.length ? "(" + this.map(String).join(",") + ")" : "";
              return [this.spaces.before, String(this.value), s, this.spaces.after].join("");
            }, r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Go = P({ "node_modules/postcss-selector-parser/dist/selectors/attribute.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Ye(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.ATTRIBUTE, s.raws = {}, s;
            }
            return r.prototype.toString = function() {
              var s = [this.spaces.before, "[", this.ns, this.attribute];
              return this.operator && s.push(this.operator), this.value && s.push(this.value), this.raws.insensitive ? s.push(this.raws.insensitive) : this.insensitive && s.push(" i"), s.push("]"), s.concat(this.spaces.after).join("");
            }, r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Ho = P({ "node_modules/postcss-selector-parser/dist/selectors/universal.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = Ye(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.UNIVERSAL, s.value = "*", s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Jo = P({ "node_modules/postcss-selector-parser/dist/selectors/combinator.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = ze(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.COMBINATOR, s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), Ko = P({ "node_modules/postcss-selector-parser/dist/selectors/nesting.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = ze(), u = h(i), o = se();
          function h(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function l(t3, r) {
            if (!(t3 instanceof r))
              throw new TypeError("Cannot call a class as a function");
          }
          function p(t3, r) {
            if (!t3)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return r && (typeof r == "object" || typeof r == "function") ? r : t3;
          }
          function m(t3, r) {
            if (typeof r != "function" && r !== null)
              throw new TypeError("Super expression must either be null or a function, not " + typeof r);
            t3.prototype = Object.create(r && r.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }), r && (Object.setPrototypeOf ? Object.setPrototypeOf(t3, r) : t3.__proto__ = r);
          }
          var c = function(t3) {
            m(r, t3);
            function r(a) {
              l(this, r);
              var s = p(this, t3.call(this, a));
              return s.type = o.NESTING, s.value = "&", s;
            }
            return r;
          }(u.default);
          e.default = c, n.exports = e.default;
        } }), yf = P({ "node_modules/postcss-selector-parser/dist/sortAscending.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = i;
          function i(u) {
            return u.sort(function(o, h) {
              return o - h;
            });
          }
          n.exports = e.default;
        } }), wf = P({ "node_modules/postcss-selector-parser/dist/tokenize.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = H;
          var i = 39, u = 34, o = 92, h = 47, l = 10, p = 32, m = 12, c = 9, t3 = 13, r = 43, a = 62, s = 126, f = 124, g = 44, v = 40, y = 41, w = 91, d = 93, _ = 59, k = 42, x = 58, N = 38, I = 64, W = /[ \n\t\r\{\(\)'"\\;/]/g, $2 = /[ \n\t\r\(\)\*:;@!&'"\+\|~>,\[\]\\]|\/(?=\*)/g;
          function H(D) {
            for (var V = [], B = D.css.valueOf(), O = void 0, j = void 0, C = void 0, R = void 0, X = void 0, Z = void 0, Q = void 0, K = void 0, J = void 0, M = void 0, Y = void 0, G = B.length, E = -1, S = 1, b = 0, L = function(T, F) {
              if (D.safe)
                B += F, j = B.length - 1;
              else
                throw D.error("Unclosed " + T, S, b - E, b);
            }; b < G; ) {
              switch (O = B.charCodeAt(b), O === l && (E = b, S += 1), O) {
                case l:
                case p:
                case c:
                case t3:
                case m:
                  j = b;
                  do
                    j += 1, O = B.charCodeAt(j), O === l && (E = j, S += 1);
                  while (O === p || O === l || O === c || O === t3 || O === m);
                  V.push(["space", B.slice(b, j), S, b - E, b]), b = j - 1;
                  break;
                case r:
                case a:
                case s:
                case f:
                  j = b;
                  do
                    j += 1, O = B.charCodeAt(j);
                  while (O === r || O === a || O === s || O === f);
                  V.push(["combinator", B.slice(b, j), S, b - E, b]), b = j - 1;
                  break;
                case k:
                  V.push(["*", "*", S, b - E, b]);
                  break;
                case N:
                  V.push(["&", "&", S, b - E, b]);
                  break;
                case g:
                  V.push([",", ",", S, b - E, b]);
                  break;
                case w:
                  V.push(["[", "[", S, b - E, b]);
                  break;
                case d:
                  V.push(["]", "]", S, b - E, b]);
                  break;
                case x:
                  V.push([":", ":", S, b - E, b]);
                  break;
                case _:
                  V.push([";", ";", S, b - E, b]);
                  break;
                case v:
                  V.push(["(", "(", S, b - E, b]);
                  break;
                case y:
                  V.push([")", ")", S, b - E, b]);
                  break;
                case i:
                case u:
                  C = O === i ? "'" : '"', j = b;
                  do
                    for (M = false, j = B.indexOf(C, j + 1), j === -1 && L("quote", C), Y = j; B.charCodeAt(Y - 1) === o; )
                      Y -= 1, M = !M;
                  while (M);
                  V.push(["string", B.slice(b, j + 1), S, b - E, S, j - E, b]), b = j;
                  break;
                case I:
                  W.lastIndex = b + 1, W.test(B), W.lastIndex === 0 ? j = B.length - 1 : j = W.lastIndex - 2, V.push(["at-word", B.slice(b, j + 1), S, b - E, S, j - E, b]), b = j;
                  break;
                case o:
                  for (j = b, Q = true; B.charCodeAt(j + 1) === o; )
                    j += 1, Q = !Q;
                  O = B.charCodeAt(j + 1), Q && O !== h && O !== p && O !== l && O !== c && O !== t3 && O !== m && (j += 1), V.push(["word", B.slice(b, j + 1), S, b - E, S, j - E, b]), b = j;
                  break;
                default:
                  O === h && B.charCodeAt(b + 1) === k ? (j = B.indexOf("*/", b + 2) + 1, j === 0 && L("comment", "*/"), Z = B.slice(b, j + 1), R = Z.split(`
`), X = R.length - 1, X > 0 ? (K = S + X, J = j - R[X].length) : (K = S, J = E), V.push(["comment", Z, S, b - E, K, j - J, b]), E = J, S = K, b = j) : ($2.lastIndex = b + 1, $2.test(B), $2.lastIndex === 0 ? j = B.length - 1 : j = $2.lastIndex - 2, V.push(["word", B.slice(b, j + 1), S, b - E, S, j - E, b]), b = j);
                  break;
              }
              b++;
            }
            return V;
          }
          n.exports = e.default;
        } }), _f = P({ "node_modules/postcss-selector-parser/dist/parser.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = function() {
            function E(S, b) {
              for (var L = 0; L < b.length; L++) {
                var q = b[L];
                q.enumerable = q.enumerable || false, q.configurable = true, "value" in q && (q.writable = true), Object.defineProperty(S, q.key, q);
              }
            }
            return function(S, b, L) {
              return b && E(S.prototype, b), L && E(S, L), S;
            };
          }(), u = jo(), o = M(u), h = Mo(), l = M(h), p = Do(), m = M(p), c = Lo(), t3 = M(c), r = zo(), a = M(r), s = Bo(), f = M(s), g = Fo(), v = M(g), y = Uo(), w = M(y), d = $o(), _ = M(d), k = Wo(), x = M(k), N = Vo(), I = M(N), W = Go(), $2 = M(W), H = Ho(), D = M(H), V = Jo(), B = M(V), O = Ko(), j = M(O), C = yf(), R = M(C), X = wf(), Z = M(X), Q = se(), K = J(Q);
          function J(E) {
            if (E && E.__esModule)
              return E;
            var S = {};
            if (E != null)
              for (var b in E)
                Object.prototype.hasOwnProperty.call(E, b) && (S[b] = E[b]);
            return S.default = E, S;
          }
          function M(E) {
            return E && E.__esModule ? E : { default: E };
          }
          function Y(E, S) {
            if (!(E instanceof S))
              throw new TypeError("Cannot call a class as a function");
          }
          var G = function() {
            function E(S) {
              Y(this, E), this.input = S, this.lossy = S.options.lossless === false, this.position = 0, this.root = new t3.default();
              var b = new a.default();
              return this.root.append(b), this.current = b, this.lossy ? this.tokens = (0, Z.default)({ safe: S.safe, css: S.css.trim() }) : this.tokens = (0, Z.default)(S), this.loop();
            }
            return E.prototype.attribute = function() {
              var b = "", L = void 0, q = this.currToken;
              for (this.position++; this.position < this.tokens.length && this.currToken[0] !== "]"; )
                b += this.tokens[this.position][1], this.position++;
              this.position === this.tokens.length && !~b.indexOf("]") && this.error("Expected a closing square bracket.");
              var T = b.split(/((?:[*~^$|]?=))([^]*)/), F = T[0].split(/(\|)/g), z = { operator: T[1], value: T[2], source: { start: { line: q[2], column: q[3] }, end: { line: this.currToken[2], column: this.currToken[3] } }, sourceIndex: q[4] };
              if (F.length > 1 ? (F[0] === "" && (F[0] = true), z.attribute = this.parseValue(F[2]), z.namespace = this.parseNamespace(F[0])) : z.attribute = this.parseValue(T[0]), L = new $2.default(z), T[2]) {
                var ee = T[2].split(/(\s+i\s*?)$/), te = ee[0].trim();
                L.value = this.lossy ? te : ee[0], ee[1] && (L.insensitive = true, this.lossy || (L.raws.insensitive = ee[1])), L.quoted = te[0] === "'" || te[0] === '"', L.raws.unquoted = L.quoted ? te.slice(1, -1) : te;
              }
              this.newNode(L), this.position++;
            }, E.prototype.combinator = function() {
              if (this.currToken[1] === "|")
                return this.namespace();
              for (var b = new B.default({ value: "", source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[2], column: this.currToken[3] } }, sourceIndex: this.currToken[4] }); this.position < this.tokens.length && this.currToken && (this.currToken[0] === "space" || this.currToken[0] === "combinator"); )
                this.nextToken && this.nextToken[0] === "combinator" ? (b.spaces.before = this.parseSpace(this.currToken[1]), b.source.start.line = this.nextToken[2], b.source.start.column = this.nextToken[3], b.source.end.column = this.nextToken[3], b.source.end.line = this.nextToken[2], b.sourceIndex = this.nextToken[4]) : this.prevToken && this.prevToken[0] === "combinator" ? b.spaces.after = this.parseSpace(this.currToken[1]) : this.currToken[0] === "combinator" ? b.value = this.currToken[1] : this.currToken[0] === "space" && (b.value = this.parseSpace(this.currToken[1], " ")), this.position++;
              return this.newNode(b);
            }, E.prototype.comma = function() {
              if (this.position === this.tokens.length - 1) {
                this.root.trailingComma = true, this.position++;
                return;
              }
              var b = new a.default();
              this.current.parent.append(b), this.current = b, this.position++;
            }, E.prototype.comment = function() {
              var b = new v.default({ value: this.currToken[1], source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[4], column: this.currToken[5] } }, sourceIndex: this.currToken[6] });
              this.newNode(b), this.position++;
            }, E.prototype.error = function(b) {
              throw new this.input.error(b);
            }, E.prototype.missingBackslash = function() {
              return this.error("Expected a backslash preceding the semicolon.");
            }, E.prototype.missingParenthesis = function() {
              return this.error("Expected opening parenthesis.");
            }, E.prototype.missingSquareBracket = function() {
              return this.error("Expected opening square bracket.");
            }, E.prototype.namespace = function() {
              var b = this.prevToken && this.prevToken[1] || true;
              if (this.nextToken[0] === "word")
                return this.position++, this.word(b);
              if (this.nextToken[0] === "*")
                return this.position++, this.universal(b);
            }, E.prototype.nesting = function() {
              this.newNode(new j.default({ value: this.currToken[1], source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[2], column: this.currToken[3] } }, sourceIndex: this.currToken[4] })), this.position++;
            }, E.prototype.parentheses = function() {
              var b = this.current.last;
              if (b && b.type === K.PSEUDO) {
                var L = new a.default(), q = this.current;
                b.append(L), this.current = L;
                var T = 1;
                for (this.position++; this.position < this.tokens.length && T; )
                  this.currToken[0] === "(" && T++, this.currToken[0] === ")" && T--, T ? this.parse() : (L.parent.source.end.line = this.currToken[2], L.parent.source.end.column = this.currToken[3], this.position++);
                T && this.error("Expected closing parenthesis."), this.current = q;
              } else {
                var F = 1;
                for (this.position++, b.value += "("; this.position < this.tokens.length && F; )
                  this.currToken[0] === "(" && F++, this.currToken[0] === ")" && F--, b.value += this.parseParenthesisToken(this.currToken), this.position++;
                F && this.error("Expected closing parenthesis.");
              }
            }, E.prototype.pseudo = function() {
              for (var b = this, L = "", q = this.currToken; this.currToken && this.currToken[0] === ":"; )
                L += this.currToken[1], this.position++;
              if (!this.currToken)
                return this.error("Expected pseudo-class or pseudo-element");
              if (this.currToken[0] === "word") {
                var T = void 0;
                this.splitWord(false, function(F, z) {
                  L += F, T = new I.default({ value: L, source: { start: { line: q[2], column: q[3] }, end: { line: b.currToken[4], column: b.currToken[5] } }, sourceIndex: q[4] }), b.newNode(T), z > 1 && b.nextToken && b.nextToken[0] === "(" && b.error("Misplaced parenthesis.");
                });
              } else
                this.error('Unexpected "' + this.currToken[0] + '" found.');
            }, E.prototype.space = function() {
              var b = this.currToken;
              this.position === 0 || this.prevToken[0] === "," || this.prevToken[0] === "(" ? (this.spaces = this.parseSpace(b[1]), this.position++) : this.position === this.tokens.length - 1 || this.nextToken[0] === "," || this.nextToken[0] === ")" ? (this.current.last.spaces.after = this.parseSpace(b[1]), this.position++) : this.combinator();
            }, E.prototype.string = function() {
              var b = this.currToken;
              this.newNode(new x.default({ value: this.currToken[1], source: { start: { line: b[2], column: b[3] }, end: { line: b[4], column: b[5] } }, sourceIndex: b[6] })), this.position++;
            }, E.prototype.universal = function(b) {
              var L = this.nextToken;
              if (L && L[1] === "|")
                return this.position++, this.namespace();
              this.newNode(new D.default({ value: this.currToken[1], source: { start: { line: this.currToken[2], column: this.currToken[3] }, end: { line: this.currToken[2], column: this.currToken[3] } }, sourceIndex: this.currToken[4] }), b), this.position++;
            }, E.prototype.splitWord = function(b, L) {
              for (var q = this, T = this.nextToken, F = this.currToken[1]; T && T[0] === "word"; ) {
                this.position++;
                var z = this.currToken[1];
                if (F += z, z.lastIndexOf("\\") === z.length - 1) {
                  var ee = this.nextToken;
                  ee && ee[0] === "space" && (F += this.parseSpace(ee[1], " "), this.position++);
                }
                T = this.nextToken;
              }
              var te = (0, l.default)(F, "."), ue = (0, l.default)(F, "#"), le = (0, l.default)(F, "#{");
              le.length && (ue = ue.filter(function(ne) {
                return !~le.indexOf(ne);
              }));
              var re = (0, R.default)((0, m.default)((0, o.default)([[0], te, ue])));
              re.forEach(function(ne, oe) {
                var ie = re[oe + 1] || F.length, ce = F.slice(ne, ie);
                if (oe === 0 && L)
                  return L.call(q, ce, re.length);
                var fe = void 0;
                ~te.indexOf(ne) ? fe = new f.default({ value: ce.slice(1), source: { start: { line: q.currToken[2], column: q.currToken[3] + ne }, end: { line: q.currToken[4], column: q.currToken[3] + (ie - 1) } }, sourceIndex: q.currToken[6] + re[oe] }) : ~ue.indexOf(ne) ? fe = new w.default({ value: ce.slice(1), source: { start: { line: q.currToken[2], column: q.currToken[3] + ne }, end: { line: q.currToken[4], column: q.currToken[3] + (ie - 1) } }, sourceIndex: q.currToken[6] + re[oe] }) : fe = new _.default({ value: ce, source: { start: { line: q.currToken[2], column: q.currToken[3] + ne }, end: { line: q.currToken[4], column: q.currToken[3] + (ie - 1) } }, sourceIndex: q.currToken[6] + re[oe] }), q.newNode(fe, b);
              }), this.position++;
            }, E.prototype.word = function(b) {
              var L = this.nextToken;
              return L && L[1] === "|" ? (this.position++, this.namespace()) : this.splitWord(b);
            }, E.prototype.loop = function() {
              for (; this.position < this.tokens.length; )
                this.parse(true);
              return this.root;
            }, E.prototype.parse = function(b) {
              switch (this.currToken[0]) {
                case "space":
                  this.space();
                  break;
                case "comment":
                  this.comment();
                  break;
                case "(":
                  this.parentheses();
                  break;
                case ")":
                  b && this.missingParenthesis();
                  break;
                case "[":
                  this.attribute();
                  break;
                case "]":
                  this.missingSquareBracket();
                  break;
                case "at-word":
                case "word":
                  this.word();
                  break;
                case ":":
                  this.pseudo();
                  break;
                case ";":
                  this.missingBackslash();
                  break;
                case ",":
                  this.comma();
                  break;
                case "*":
                  this.universal();
                  break;
                case "&":
                  this.nesting();
                  break;
                case "combinator":
                  this.combinator();
                  break;
                case "string":
                  this.string();
                  break;
              }
            }, E.prototype.parseNamespace = function(b) {
              if (this.lossy && typeof b == "string") {
                var L = b.trim();
                return L.length ? L : true;
              }
              return b;
            }, E.prototype.parseSpace = function(b, L) {
              return this.lossy ? L || "" : b;
            }, E.prototype.parseValue = function(b) {
              return this.lossy && b && typeof b == "string" ? b.trim() : b;
            }, E.prototype.parseParenthesisToken = function(b) {
              return this.lossy ? b[0] === "space" ? this.parseSpace(b[1], " ") : this.parseValue(b[1]) : b[1];
            }, E.prototype.newNode = function(b, L) {
              return L && (b.namespace = this.parseNamespace(L)), this.spaces && (b.spaces.before = this.spaces, this.spaces = ""), this.current.append(b);
            }, i(E, [{ key: "currToken", get: function() {
              return this.tokens[this.position];
            } }, { key: "nextToken", get: function() {
              return this.tokens[this.position + 1];
            } }, { key: "prevToken", get: function() {
              return this.tokens[this.position - 1];
            } }]), E;
          }();
          e.default = G, n.exports = e.default;
        } }), bf = P({ "node_modules/postcss-selector-parser/dist/processor.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = function() {
            function m(c, t3) {
              for (var r = 0; r < t3.length; r++) {
                var a = t3[r];
                a.enumerable = a.enumerable || false, a.configurable = true, "value" in a && (a.writable = true), Object.defineProperty(c, a.key, a);
              }
            }
            return function(c, t3, r) {
              return t3 && m(c.prototype, t3), r && m(c, r), c;
            };
          }(), u = _f(), o = h(u);
          function h(m) {
            return m && m.__esModule ? m : { default: m };
          }
          function l(m, c) {
            if (!(m instanceof c))
              throw new TypeError("Cannot call a class as a function");
          }
          var p = function() {
            function m(c) {
              return l(this, m), this.func = c || function() {
              }, this;
            }
            return m.prototype.process = function(t3) {
              var r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, a = new o.default({ css: t3, error: function(f) {
                throw new Error(f);
              }, options: r });
              return this.res = a, this.func(a), this;
            }, i(m, [{ key: "result", get: function() {
              return String(this.res);
            } }]), m;
          }();
          e.default = p, n.exports = e.default;
        } }), xf = P({ "node_modules/postcss-selector-parser/dist/index.js"(e, n) {
          "use strict";
          A(), e.__esModule = true;
          var i = bf(), u = O(i), o = Go(), h = O(o), l = Bo(), p = O(l), m = Jo(), c = O(m), t3 = Fo(), r = O(t3), a = Uo(), s = O(a), f = Ko(), g = O(f), v = Vo(), y = O(v), w = Lo(), d = O(w), _ = zo(), k = O(_), x = Wo(), N = O(x), I = $o(), W = O(I), $2 = Ho(), H = O($2), D = se(), V = B(D);
          function B(C) {
            if (C && C.__esModule)
              return C;
            var R = {};
            if (C != null)
              for (var X in C)
                Object.prototype.hasOwnProperty.call(C, X) && (R[X] = C[X]);
            return R.default = C, R;
          }
          function O(C) {
            return C && C.__esModule ? C : { default: C };
          }
          var j = function(R) {
            return new u.default(R);
          };
          j.attribute = function(C) {
            return new h.default(C);
          }, j.className = function(C) {
            return new p.default(C);
          }, j.combinator = function(C) {
            return new c.default(C);
          }, j.comment = function(C) {
            return new r.default(C);
          }, j.id = function(C) {
            return new s.default(C);
          }, j.nesting = function(C) {
            return new g.default(C);
          }, j.pseudo = function(C) {
            return new y.default(C);
          }, j.root = function(C) {
            return new d.default(C);
          }, j.selector = function(C) {
            return new k.default(C);
          }, j.string = function(C) {
            return new N.default(C);
          }, j.tag = function(C) {
            return new W.default(C);
          }, j.universal = function(C) {
            return new H.default(C);
          }, Object.keys(V).forEach(function(C) {
            C !== "__esModule" && (j[C] = V[C]);
          }), e.default = j, n.exports = e.default;
        } }), Qo = P({ "node_modules/postcss-media-query-parser/dist/nodes/Node.js"(e) {
          "use strict";
          A(), Object.defineProperty(e, "__esModule", { value: true });
          function n(i) {
            this.after = i.after, this.before = i.before, this.type = i.type, this.value = i.value, this.sourceIndex = i.sourceIndex;
          }
          e.default = n;
        } }), Yo = P({ "node_modules/postcss-media-query-parser/dist/nodes/Container.js"(e) {
          "use strict";
          A(), Object.defineProperty(e, "__esModule", { value: true });
          var n = Qo(), i = u(n);
          function u(h) {
            return h && h.__esModule ? h : { default: h };
          }
          function o(h) {
            var l = this;
            this.constructor(h), this.nodes = h.nodes, this.after === void 0 && (this.after = this.nodes.length > 0 ? this.nodes[this.nodes.length - 1].after : ""), this.before === void 0 && (this.before = this.nodes.length > 0 ? this.nodes[0].before : ""), this.sourceIndex === void 0 && (this.sourceIndex = this.before.length), this.nodes.forEach(function(p) {
              p.parent = l;
            });
          }
          o.prototype = Object.create(i.default.prototype), o.constructor = i.default, o.prototype.walk = function(l, p) {
            for (var m = typeof l == "string" || l instanceof RegExp, c = m ? p : l, t3 = typeof l == "string" ? new RegExp(l) : l, r = 0; r < this.nodes.length; r++) {
              var a = this.nodes[r], s = m ? t3.test(a.type) : true;
              if (s && c && c(a, r, this.nodes) === false || a.nodes && a.walk(l, p) === false)
                return false;
            }
            return true;
          }, o.prototype.each = function() {
            for (var l = arguments.length <= 0 || arguments[0] === void 0 ? function() {
            } : arguments[0], p = 0; p < this.nodes.length; p++) {
              var m = this.nodes[p];
              if (l(m, p, this.nodes) === false)
                return false;
            }
            return true;
          }, e.default = o;
        } }), Sf = P({ "node_modules/postcss-media-query-parser/dist/parsers.js"(e) {
          "use strict";
          A(), Object.defineProperty(e, "__esModule", { value: true }), e.parseMediaFeature = l, e.parseMediaQuery = p, e.parseMediaList = m;
          var n = Qo(), i = h(n), u = Yo(), o = h(u);
          function h(c) {
            return c && c.__esModule ? c : { default: c };
          }
          function l(c) {
            var t3 = arguments.length <= 1 || arguments[1] === void 0 ? 0 : arguments[1], r = [{ mode: "normal", character: null }], a = [], s = 0, f = "", g = null, v = null, y = t3, w = c;
            c[0] === "(" && c[c.length - 1] === ")" && (w = c.substring(1, c.length - 1), y++);
            for (var d = 0; d < w.length; d++) {
              var _ = w[d];
              if ((_ === "'" || _ === '"') && (r[s].isCalculationEnabled === true ? (r.push({ mode: "string", isCalculationEnabled: false, character: _ }), s++) : r[s].mode === "string" && r[s].character === _ && w[d - 1] !== "\\" && (r.pop(), s--)), _ === "{" ? (r.push({ mode: "interpolation", isCalculationEnabled: true }), s++) : _ === "}" && (r.pop(), s--), r[s].mode === "normal" && _ === ":") {
                var k = w.substring(d + 1);
                v = { type: "value", before: /^(\s*)/.exec(k)[1], after: /(\s*)$/.exec(k)[1], value: k.trim() }, v.sourceIndex = v.before.length + d + 1 + y, g = { type: "colon", sourceIndex: d + y, after: v.before, value: ":" };
                break;
              }
              f += _;
            }
            return f = { type: "media-feature", before: /^(\s*)/.exec(f)[1], after: /(\s*)$/.exec(f)[1], value: f.trim() }, f.sourceIndex = f.before.length + y, a.push(f), g !== null && (g.before = f.after, a.push(g)), v !== null && a.push(v), a;
          }
          function p(c) {
            var t3 = arguments.length <= 1 || arguments[1] === void 0 ? 0 : arguments[1], r = [], a = 0, s = false, f = void 0;
            function g() {
              return { before: "", after: "", value: "" };
            }
            f = g();
            for (var v = 0; v < c.length; v++) {
              var y = c[v];
              s ? (f.value += y, (y === "{" || y === "(") && a++, (y === ")" || y === "}") && a--) : y.search(/\s/) !== -1 ? f.before += y : (y === "(" && (f.type = "media-feature-expression", a++), f.value = y, f.sourceIndex = t3 + v, s = true), s && a === 0 && (y === ")" || v === c.length - 1 || c[v + 1].search(/\s/) !== -1) && (["not", "only", "and"].indexOf(f.value) !== -1 && (f.type = "keyword"), f.type === "media-feature-expression" && (f.nodes = l(f.value, f.sourceIndex)), r.push(Array.isArray(f.nodes) ? new o.default(f) : new i.default(f)), f = g(), s = false);
            }
            for (var w = 0; w < r.length; w++)
              if (f = r[w], w > 0 && (r[w - 1].after = f.before), f.type === void 0) {
                if (w > 0) {
                  if (r[w - 1].type === "media-feature-expression") {
                    f.type = "keyword";
                    continue;
                  }
                  if (r[w - 1].value === "not" || r[w - 1].value === "only") {
                    f.type = "media-type";
                    continue;
                  }
                  if (r[w - 1].value === "and") {
                    f.type = "media-feature-expression";
                    continue;
                  }
                  r[w - 1].type === "media-type" && (r[w + 1] ? f.type = r[w + 1].type === "media-feature-expression" ? "keyword" : "media-feature-expression" : f.type = "media-feature-expression");
                }
                if (w === 0) {
                  if (!r[w + 1]) {
                    f.type = "media-type";
                    continue;
                  }
                  if (r[w + 1] && (r[w + 1].type === "media-feature-expression" || r[w + 1].type === "keyword")) {
                    f.type = "media-type";
                    continue;
                  }
                  if (r[w + 2]) {
                    if (r[w + 2].type === "media-feature-expression") {
                      f.type = "media-type", r[w + 1].type = "keyword";
                      continue;
                    }
                    if (r[w + 2].type === "keyword") {
                      f.type = "keyword", r[w + 1].type = "media-type";
                      continue;
                    }
                  }
                  if (r[w + 3] && r[w + 3].type === "media-feature-expression") {
                    f.type = "keyword", r[w + 1].type = "media-type", r[w + 2].type = "keyword";
                    continue;
                  }
                }
              }
            return r;
          }
          function m(c) {
            var t3 = [], r = 0, a = 0, s = /^(\s*)url\s*\(/.exec(c);
            if (s !== null) {
              for (var f = s[0].length, g = 1; g > 0; ) {
                var v = c[f];
                v === "(" && g++, v === ")" && g--, f++;
              }
              t3.unshift(new i.default({ type: "url", value: c.substring(0, f).trim(), sourceIndex: s[1].length, before: s[1], after: /^(\s*)/.exec(c.substring(f))[1] })), r = f;
            }
            for (var y = r; y < c.length; y++) {
              var w = c[y];
              if (w === "(" && a++, w === ")" && a--, a === 0 && w === ",") {
                var d = c.substring(r, y), _ = /^(\s*)/.exec(d)[1];
                t3.push(new o.default({ type: "media-query", value: d.trim(), sourceIndex: r + _.length, nodes: p(d, r), before: _, after: /(\s*)$/.exec(d)[1] })), r = y + 1;
              }
            }
            var k = c.substring(r), x = /^(\s*)/.exec(k)[1];
            return t3.push(new o.default({ type: "media-query", value: k.trim(), sourceIndex: r + x.length, nodes: p(k, r), before: x, after: /(\s*)$/.exec(k)[1] })), t3;
          }
        } }), kf = P({ "node_modules/postcss-media-query-parser/dist/index.js"(e) {
          "use strict";
          A(), Object.defineProperty(e, "__esModule", { value: true }), e.default = h;
          var n = Yo(), i = o(n), u = Sf();
          function o(l) {
            return l && l.__esModule ? l : { default: l };
          }
          function h(l) {
            return new i.default({ nodes: (0, u.parseMediaList)(l), type: "media-query-list", value: l.trim() });
          }
        } }), Xo = {};
        At(Xo, { basename: () => na, default: () => sa, delimiter: () => kt, dirname: () => ta, extname: () => ia, isAbsolute: () => zt, join: () => ea, normalize: () => Lt, relative: () => ra, resolve: () => yr, sep: () => St });
        function Zo(e, n) {
          for (var i = 0, u = e.length - 1; u >= 0; u--) {
            var o = e[u];
            o === "." ? e.splice(u, 1) : o === ".." ? (e.splice(u, 1), i++) : i && (e.splice(u, 1), i--);
          }
          if (n)
            for (; i--; i)
              e.unshift("..");
          return e;
        }
        function yr() {
          for (var e = "", n = false, i = arguments.length - 1; i >= -1 && !n; i--) {
            var u = i >= 0 ? arguments[i] : "/";
            if (typeof u != "string")
              throw new TypeError("Arguments to path.resolve must be strings");
            if (!u)
              continue;
            e = u + "/" + e, n = u.charAt(0) === "/";
          }
          return e = Zo(Bt(e.split("/"), function(o) {
            return !!o;
          }), !n).join("/"), (n ? "/" : "") + e || ".";
        }
        function Lt(e) {
          var n = zt(e), i = oa(e, -1) === "/";
          return e = Zo(Bt(e.split("/"), function(u) {
            return !!u;
          }), !n).join("/"), !e && !n && (e = "."), e && i && (e += "/"), (n ? "/" : "") + e;
        }
        function zt(e) {
          return e.charAt(0) === "/";
        }
        function ea() {
          var e = Array.prototype.slice.call(arguments, 0);
          return Lt(Bt(e, function(n, i) {
            if (typeof n != "string")
              throw new TypeError("Arguments to path.join must be strings");
            return n;
          }).join("/"));
        }
        function ra(e, n) {
          e = yr(e).substr(1), n = yr(n).substr(1);
          function i(c) {
            for (var t3 = 0; t3 < c.length && c[t3] === ""; t3++)
              ;
            for (var r = c.length - 1; r >= 0 && c[r] === ""; r--)
              ;
            return t3 > r ? [] : c.slice(t3, r - t3 + 1);
          }
          for (var u = i(e.split("/")), o = i(n.split("/")), h = Math.min(u.length, o.length), l = h, p = 0; p < h; p++)
            if (u[p] !== o[p]) {
              l = p;
              break;
            }
          for (var m = [], p = l; p < u.length; p++)
            m.push("..");
          return m = m.concat(o.slice(l)), m.join("/");
        }
        function ta(e) {
          var n = br(e), i = n[0], u = n[1];
          return !i && !u ? "." : (u && (u = u.substr(0, u.length - 1)), i + u);
        }
        function na(e, n) {
          var i = br(e)[2];
          return n && i.substr(-1 * n.length) === n && (i = i.substr(0, i.length - n.length)), i;
        }
        function ia(e) {
          return br(e)[3];
        }
        function Bt(e, n) {
          if (e.filter)
            return e.filter(n);
          for (var i = [], u = 0; u < e.length; u++)
            n(e[u], u, e) && i.push(e[u]);
          return i;
        }
        var Fs, br, St, kt, sa, oa, Of = Le({ "node-modules-polyfills:path"() {
          A(), Fs = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/, br = function(e) {
            return Fs.exec(e).slice(1);
          }, St = "/", kt = ":", sa = { extname: ia, basename: na, dirname: ta, sep: St, delimiter: kt, relative: ra, join: ea, isAbsolute: zt, normalize: Lt, resolve: yr }, oa = "ab".substr(-1) === "b" ? function(e, n, i) {
            return e.substr(n, i);
          } : function(e, n, i) {
            return n < 0 && (n = e.length + n), e.substr(n, i);
          };
        } }), Tf = P({ "node-modules-polyfills-commonjs:path"(e, n) {
          A();
          var i = (Of(), Pt(Xo));
          if (i && i.default) {
            n.exports = i.default;
            for (let u in i)
              n.exports[u] = i[u];
          } else
            i && (n.exports = i);
        } }), Ef = P({ "node_modules/picocolors/picocolors.browser.js"(e, n) {
          A();
          var i = String, u = function() {
            return { isColorSupported: false, reset: i, bold: i, dim: i, italic: i, underline: i, inverse: i, hidden: i, strikethrough: i, black: i, red: i, green: i, yellow: i, blue: i, magenta: i, cyan: i, white: i, gray: i, bgBlack: i, bgRed: i, bgGreen: i, bgYellow: i, bgBlue: i, bgMagenta: i, bgCyan: i, bgWhite: i };
          };
          n.exports = u(), n.exports.createColors = u;
        } }), qf = P({ "(disabled):node_modules/postcss/lib/terminal-highlight"() {
          A();
        } }), aa = P({ "node_modules/postcss/lib/css-syntax-error.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = o(Ef()), u = o(qf());
          function o(g) {
            return g && g.__esModule ? g : { default: g };
          }
          function h(g) {
            if (g === void 0)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return g;
          }
          function l(g, v) {
            g.prototype = Object.create(v.prototype), g.prototype.constructor = g, g.__proto__ = v;
          }
          function p(g) {
            var v = typeof Map == "function" ? /* @__PURE__ */ new Map() : void 0;
            return p = function(w) {
              if (w === null || !t3(w))
                return w;
              if (typeof w != "function")
                throw new TypeError("Super expression must either be null or a function");
              if (typeof v < "u") {
                if (v.has(w))
                  return v.get(w);
                v.set(w, d);
              }
              function d() {
                return m(w, arguments, a(this).constructor);
              }
              return d.prototype = Object.create(w.prototype, { constructor: { value: d, enumerable: false, writable: true, configurable: true } }), r(d, w);
            }, p(g);
          }
          function m(g, v, y) {
            return c() ? m = Reflect.construct : m = function(d, _, k) {
              var x = [null];
              x.push.apply(x, _);
              var N = Function.bind.apply(d, x), I = new N();
              return k && r(I, k.prototype), I;
            }, m.apply(null, arguments);
          }
          function c() {
            if (typeof Reflect > "u" || !Reflect.construct || Reflect.construct.sham)
              return false;
            if (typeof Proxy == "function")
              return true;
            try {
              return Date.prototype.toString.call(Reflect.construct(Date, [], function() {
              })), true;
            } catch {
              return false;
            }
          }
          function t3(g) {
            return Function.toString.call(g).indexOf("[native code]") !== -1;
          }
          function r(g, v) {
            return r = Object.setPrototypeOf || function(w, d) {
              return w.__proto__ = d, w;
            }, r(g, v);
          }
          function a(g) {
            return a = Object.setPrototypeOf ? Object.getPrototypeOf : function(y) {
              return y.__proto__ || Object.getPrototypeOf(y);
            }, a(g);
          }
          var s = function(g) {
            l(v, g);
            function v(w, d, _, k, x, N) {
              var I;
              return I = g.call(this, w) || this, I.name = "CssSyntaxError", I.reason = w, x && (I.file = x), k && (I.source = k), N && (I.plugin = N), typeof d < "u" && typeof _ < "u" && (I.line = d, I.column = _), I.setMessage(), Error.captureStackTrace && Error.captureStackTrace(h(I), v), I;
            }
            var y = v.prototype;
            return y.setMessage = function() {
              this.message = this.plugin ? this.plugin + ": " : "", this.message += this.file ? this.file : "<css input>", typeof this.line < "u" && (this.message += ":" + this.line + ":" + this.column), this.message += ": " + this.reason;
            }, y.showSourceCode = function(d) {
              var _ = this;
              if (!this.source)
                return "";
              var k = this.source;
              u.default && (typeof d > "u" && (d = i.default.isColorSupported), d && (k = (0, u.default)(k)));
              var x = k.split(/\r?\n/), N = Math.max(this.line - 3, 0), I = Math.min(this.line + 2, x.length), W = String(I).length;
              function $2(D) {
                return d && i.default.red ? i.default.red(i.default.bold(D)) : D;
              }
              function H(D) {
                return d && i.default.gray ? i.default.gray(D) : D;
              }
              return x.slice(N, I).map(function(D, V) {
                var B = N + 1 + V, O = " " + (" " + B).slice(-W) + " | ";
                if (B === _.line) {
                  var j = H(O.replace(/\d/g, " ")) + D.slice(0, _.column - 1).replace(/[^\t]/g, " ");
                  return $2(">") + H(O) + D + `
 ` + j + $2("^");
                }
                return " " + H(O) + D;
              }).join(`
`);
            }, y.toString = function() {
              var d = this.showSourceCode();
              return d && (d = `

` + d + `
`), this.name + ": " + this.message + d;
            }, v;
          }(p(Error)), f = s;
          e.default = f, n.exports = e.default;
        } }), Af = P({ "node_modules/postcss/lib/previous-map.js"(e, n) {
          A(), n.exports = class {
          };
        } }), xr = P({ "node_modules/postcss/lib/input.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = h(Tf()), u = h(aa()), o = h(Af());
          function h(r) {
            return r && r.__esModule ? r : { default: r };
          }
          function l(r, a) {
            for (var s = 0; s < a.length; s++) {
              var f = a[s];
              f.enumerable = f.enumerable || false, f.configurable = true, "value" in f && (f.writable = true), Object.defineProperty(r, f.key, f);
            }
          }
          function p(r, a, s) {
            return a && l(r.prototype, a), s && l(r, s), r;
          }
          var m = 0, c = function() {
            function r(s, f) {
              if (f === void 0 && (f = {}), s === null || typeof s > "u" || typeof s == "object" && !s.toString)
                throw new Error("PostCSS received " + s + " instead of CSS string");
              this.css = s.toString(), this.css[0] === "\uFEFF" || this.css[0] === "\uFFFE" ? (this.hasBOM = true, this.css = this.css.slice(1)) : this.hasBOM = false, f.from && (/^\w+:\/\//.test(f.from) || i.default.isAbsolute(f.from) ? this.file = f.from : this.file = i.default.resolve(f.from));
              var g = new o.default(this.css, f);
              if (g.text) {
                this.map = g;
                var v = g.consumer().file;
                !this.file && v && (this.file = this.mapResolve(v));
              }
              this.file || (m += 1, this.id = "<input css " + m + ">"), this.map && (this.map.file = this.from);
            }
            var a = r.prototype;
            return a.error = function(f, g, v, y) {
              y === void 0 && (y = {});
              var w, d = this.origin(g, v);
              return d ? w = new u.default(f, d.line, d.column, d.source, d.file, y.plugin) : w = new u.default(f, g, v, this.css, this.file, y.plugin), w.input = { line: g, column: v, source: this.css }, this.file && (w.input.file = this.file), w;
            }, a.origin = function(f, g) {
              if (!this.map)
                return false;
              var v = this.map.consumer(), y = v.originalPositionFor({ line: f, column: g });
              if (!y.source)
                return false;
              var w = { file: this.mapResolve(y.source), line: y.line, column: y.column }, d = v.sourceContentFor(y.source);
              return d && (w.source = d), w;
            }, a.mapResolve = function(f) {
              return /^\w+:\/\//.test(f) ? f : i.default.resolve(this.map.consumer().sourceRoot || ".", f);
            }, p(r, [{ key: "from", get: function() {
              return this.file || this.id;
            } }]), r;
          }(), t3 = c;
          e.default = t3, n.exports = e.default;
        } }), Sr = P({ "node_modules/postcss/lib/stringifier.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = { colon: ": ", indent: "    ", beforeDecl: `
`, beforeRule: `
`, beforeOpen: " ", beforeClose: `
`, beforeComment: `
`, after: `
`, emptyBody: "", commentLeft: " ", commentRight: " ", semicolon: false };
          function u(l) {
            return l[0].toUpperCase() + l.slice(1);
          }
          var o = function() {
            function l(m) {
              this.builder = m;
            }
            var p = l.prototype;
            return p.stringify = function(c, t3) {
              this[c.type](c, t3);
            }, p.root = function(c) {
              this.body(c), c.raws.after && this.builder(c.raws.after);
            }, p.comment = function(c) {
              var t3 = this.raw(c, "left", "commentLeft"), r = this.raw(c, "right", "commentRight");
              this.builder("/*" + t3 + c.text + r + "*/", c);
            }, p.decl = function(c, t3) {
              var r = this.raw(c, "between", "colon"), a = c.prop + r + this.rawValue(c, "value");
              c.important && (a += c.raws.important || " !important"), t3 && (a += ";"), this.builder(a, c);
            }, p.rule = function(c) {
              this.block(c, this.rawValue(c, "selector")), c.raws.ownSemicolon && this.builder(c.raws.ownSemicolon, c, "end");
            }, p.atrule = function(c, t3) {
              var r = "@" + c.name, a = c.params ? this.rawValue(c, "params") : "";
              if (typeof c.raws.afterName < "u" ? r += c.raws.afterName : a && (r += " "), c.nodes)
                this.block(c, r + a);
              else {
                var s = (c.raws.between || "") + (t3 ? ";" : "");
                this.builder(r + a + s, c);
              }
            }, p.body = function(c) {
              for (var t3 = c.nodes.length - 1; t3 > 0 && c.nodes[t3].type === "comment"; )
                t3 -= 1;
              for (var r = this.raw(c, "semicolon"), a = 0; a < c.nodes.length; a++) {
                var s = c.nodes[a], f = this.raw(s, "before");
                f && this.builder(f), this.stringify(s, t3 !== a || r);
              }
            }, p.block = function(c, t3) {
              var r = this.raw(c, "between", "beforeOpen");
              this.builder(t3 + r + "{", c, "start");
              var a;
              c.nodes && c.nodes.length ? (this.body(c), a = this.raw(c, "after")) : a = this.raw(c, "after", "emptyBody"), a && this.builder(a), this.builder("}", c, "end");
            }, p.raw = function(c, t3, r) {
              var a;
              if (r || (r = t3), t3 && (a = c.raws[t3], typeof a < "u"))
                return a;
              var s = c.parent;
              if (r === "before" && (!s || s.type === "root" && s.first === c))
                return "";
              if (!s)
                return i[r];
              var f = c.root();
              if (f.rawCache || (f.rawCache = {}), typeof f.rawCache[r] < "u")
                return f.rawCache[r];
              if (r === "before" || r === "after")
                return this.beforeAfter(c, r);
              var g = "raw" + u(r);
              return this[g] ? a = this[g](f, c) : f.walk(function(v) {
                if (a = v.raws[t3], typeof a < "u")
                  return false;
              }), typeof a > "u" && (a = i[r]), f.rawCache[r] = a, a;
            }, p.rawSemicolon = function(c) {
              var t3;
              return c.walk(function(r) {
                if (r.nodes && r.nodes.length && r.last.type === "decl" && (t3 = r.raws.semicolon, typeof t3 < "u"))
                  return false;
              }), t3;
            }, p.rawEmptyBody = function(c) {
              var t3;
              return c.walk(function(r) {
                if (r.nodes && r.nodes.length === 0 && (t3 = r.raws.after, typeof t3 < "u"))
                  return false;
              }), t3;
            }, p.rawIndent = function(c) {
              if (c.raws.indent)
                return c.raws.indent;
              var t3;
              return c.walk(function(r) {
                var a = r.parent;
                if (a && a !== c && a.parent && a.parent === c && typeof r.raws.before < "u") {
                  var s = r.raws.before.split(`
`);
                  return t3 = s[s.length - 1], t3 = t3.replace(/[^\s]/g, ""), false;
                }
              }), t3;
            }, p.rawBeforeComment = function(c, t3) {
              var r;
              return c.walkComments(function(a) {
                if (typeof a.raws.before < "u")
                  return r = a.raws.before, r.indexOf(`
`) !== -1 && (r = r.replace(/[^\n]+$/, "")), false;
              }), typeof r > "u" ? r = this.raw(t3, null, "beforeDecl") : r && (r = r.replace(/[^\s]/g, "")), r;
            }, p.rawBeforeDecl = function(c, t3) {
              var r;
              return c.walkDecls(function(a) {
                if (typeof a.raws.before < "u")
                  return r = a.raws.before, r.indexOf(`
`) !== -1 && (r = r.replace(/[^\n]+$/, "")), false;
              }), typeof r > "u" ? r = this.raw(t3, null, "beforeRule") : r && (r = r.replace(/[^\s]/g, "")), r;
            }, p.rawBeforeRule = function(c) {
              var t3;
              return c.walk(function(r) {
                if (r.nodes && (r.parent !== c || c.first !== r) && typeof r.raws.before < "u")
                  return t3 = r.raws.before, t3.indexOf(`
`) !== -1 && (t3 = t3.replace(/[^\n]+$/, "")), false;
              }), t3 && (t3 = t3.replace(/[^\s]/g, "")), t3;
            }, p.rawBeforeClose = function(c) {
              var t3;
              return c.walk(function(r) {
                if (r.nodes && r.nodes.length > 0 && typeof r.raws.after < "u")
                  return t3 = r.raws.after, t3.indexOf(`
`) !== -1 && (t3 = t3.replace(/[^\n]+$/, "")), false;
              }), t3 && (t3 = t3.replace(/[^\s]/g, "")), t3;
            }, p.rawBeforeOpen = function(c) {
              var t3;
              return c.walk(function(r) {
                if (r.type !== "decl" && (t3 = r.raws.between, typeof t3 < "u"))
                  return false;
              }), t3;
            }, p.rawColon = function(c) {
              var t3;
              return c.walkDecls(function(r) {
                if (typeof r.raws.between < "u")
                  return t3 = r.raws.between.replace(/[^\s:]/g, ""), false;
              }), t3;
            }, p.beforeAfter = function(c, t3) {
              var r;
              c.type === "decl" ? r = this.raw(c, null, "beforeDecl") : c.type === "comment" ? r = this.raw(c, null, "beforeComment") : t3 === "before" ? r = this.raw(c, null, "beforeRule") : r = this.raw(c, null, "beforeClose");
              for (var a = c.parent, s = 0; a && a.type !== "root"; )
                s += 1, a = a.parent;
              if (r.indexOf(`
`) !== -1) {
                var f = this.raw(c, null, "indent");
                if (f.length)
                  for (var g = 0; g < s; g++)
                    r += f;
              }
              return r;
            }, p.rawValue = function(c, t3) {
              var r = c[t3], a = c.raws[t3];
              return a && a.value === r ? a.raw : r;
            }, l;
          }(), h = o;
          e.default = h, n.exports = e.default;
        } }), ua = P({ "node_modules/postcss/lib/stringify.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Sr());
          function u(l) {
            return l && l.__esModule ? l : { default: l };
          }
          function o(l, p) {
            var m = new i.default(p);
            m.stringify(l);
          }
          var h = o;
          e.default = h, n.exports = e.default;
        } }), Ft = P({ "node_modules/postcss/lib/node.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = h(aa()), u = h(Sr()), o = h(ua());
          function h(c) {
            return c && c.__esModule ? c : { default: c };
          }
          function l(c, t3) {
            var r = new c.constructor();
            for (var a in c)
              if (c.hasOwnProperty(a)) {
                var s = c[a], f = typeof s;
                a === "parent" && f === "object" ? t3 && (r[a] = t3) : a === "source" ? r[a] = s : s instanceof Array ? r[a] = s.map(function(g) {
                  return l(g, r);
                }) : (f === "object" && s !== null && (s = l(s)), r[a] = s);
              }
            return r;
          }
          var p = function() {
            function c(r) {
              r === void 0 && (r = {}), this.raws = {};
              for (var a in r)
                this[a] = r[a];
            }
            var t3 = c.prototype;
            return t3.error = function(a, s) {
              if (s === void 0 && (s = {}), this.source) {
                var f = this.positionBy(s);
                return this.source.input.error(a, f.line, f.column, s);
              }
              return new i.default(a);
            }, t3.warn = function(a, s, f) {
              var g = { node: this };
              for (var v in f)
                g[v] = f[v];
              return a.warn(s, g);
            }, t3.remove = function() {
              return this.parent && this.parent.removeChild(this), this.parent = void 0, this;
            }, t3.toString = function(a) {
              a === void 0 && (a = o.default), a.stringify && (a = a.stringify);
              var s = "";
              return a(this, function(f) {
                s += f;
              }), s;
            }, t3.clone = function(a) {
              a === void 0 && (a = {});
              var s = l(this);
              for (var f in a)
                s[f] = a[f];
              return s;
            }, t3.cloneBefore = function(a) {
              a === void 0 && (a = {});
              var s = this.clone(a);
              return this.parent.insertBefore(this, s), s;
            }, t3.cloneAfter = function(a) {
              a === void 0 && (a = {});
              var s = this.clone(a);
              return this.parent.insertAfter(this, s), s;
            }, t3.replaceWith = function() {
              if (this.parent) {
                for (var a = arguments.length, s = new Array(a), f = 0; f < a; f++)
                  s[f] = arguments[f];
                for (var g = 0, v = s; g < v.length; g++) {
                  var y = v[g];
                  this.parent.insertBefore(this, y);
                }
                this.remove();
              }
              return this;
            }, t3.next = function() {
              if (this.parent) {
                var a = this.parent.index(this);
                return this.parent.nodes[a + 1];
              }
            }, t3.prev = function() {
              if (this.parent) {
                var a = this.parent.index(this);
                return this.parent.nodes[a - 1];
              }
            }, t3.before = function(a) {
              return this.parent.insertBefore(this, a), this;
            }, t3.after = function(a) {
              return this.parent.insertAfter(this, a), this;
            }, t3.toJSON = function() {
              var a = {};
              for (var s in this)
                if (this.hasOwnProperty(s) && s !== "parent") {
                  var f = this[s];
                  f instanceof Array ? a[s] = f.map(function(g) {
                    return typeof g == "object" && g.toJSON ? g.toJSON() : g;
                  }) : typeof f == "object" && f.toJSON ? a[s] = f.toJSON() : a[s] = f;
                }
              return a;
            }, t3.raw = function(a, s) {
              var f = new u.default();
              return f.raw(this, a, s);
            }, t3.root = function() {
              for (var a = this; a.parent; )
                a = a.parent;
              return a;
            }, t3.cleanRaws = function(a) {
              delete this.raws.before, delete this.raws.after, a || delete this.raws.between;
            }, t3.positionInside = function(a) {
              for (var s = this.toString(), f = this.source.start.column, g = this.source.start.line, v = 0; v < a; v++)
                s[v] === `
` ? (f = 1, g += 1) : f += 1;
              return { line: g, column: f };
            }, t3.positionBy = function(a) {
              var s = this.source.start;
              if (a.index)
                s = this.positionInside(a.index);
              else if (a.word) {
                var f = this.toString().indexOf(a.word);
                f !== -1 && (s = this.positionInside(f));
              }
              return s;
            }, c;
          }(), m = p;
          e.default = m, n.exports = e.default;
        } }), kr = P({ "node_modules/postcss/lib/comment.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Ft());
          function u(p) {
            return p && p.__esModule ? p : { default: p };
          }
          function o(p, m) {
            p.prototype = Object.create(m.prototype), p.prototype.constructor = p, p.__proto__ = m;
          }
          var h = function(p) {
            o(m, p);
            function m(c) {
              var t3;
              return t3 = p.call(this, c) || this, t3.type = "comment", t3;
            }
            return m;
          }(i.default), l = h;
          e.default = l, n.exports = e.default;
        } }), ca = P({ "node_modules/postcss/lib/declaration.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Ft());
          function u(p) {
            return p && p.__esModule ? p : { default: p };
          }
          function o(p, m) {
            p.prototype = Object.create(m.prototype), p.prototype.constructor = p, p.__proto__ = m;
          }
          var h = function(p) {
            o(m, p);
            function m(c) {
              var t3;
              return t3 = p.call(this, c) || this, t3.type = "decl", t3;
            }
            return m;
          }(i.default), l = h;
          e.default = l, n.exports = e.default;
        } }), Ut = P({ "node_modules/postcss/lib/tokenize.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = W;
          var i = "'".charCodeAt(0), u = '"'.charCodeAt(0), o = "\\".charCodeAt(0), h = "/".charCodeAt(0), l = `
`.charCodeAt(0), p = " ".charCodeAt(0), m = "\f".charCodeAt(0), c = "	".charCodeAt(0), t3 = "\r".charCodeAt(0), r = "[".charCodeAt(0), a = "]".charCodeAt(0), s = "(".charCodeAt(0), f = ")".charCodeAt(0), g = "{".charCodeAt(0), v = "}".charCodeAt(0), y = ";".charCodeAt(0), w = "*".charCodeAt(0), d = ":".charCodeAt(0), _ = "@".charCodeAt(0), k = /[ \n\t\r\f{}()'"\\;/[\]#]/g, x = /[ \n\t\r\f(){}:;@!'"\\\][#]|\/(?=\*)/g, N = /.[\\/("'\n]/, I = /[a-f0-9]/i;
          function W($2, H) {
            H === void 0 && (H = {});
            var D = $2.css.valueOf(), V = H.ignoreErrors, B, O, j, C, R, X, Z, Q, K, J, M, Y, G, E, S = D.length, b = -1, L = 1, q = 0, T = [], F = [];
            function z() {
              return q;
            }
            function ee(re) {
              throw $2.error("Unclosed " + re, L, q - b);
            }
            function te() {
              return F.length === 0 && q >= S;
            }
            function ue(re) {
              if (F.length)
                return F.pop();
              if (!(q >= S)) {
                var ne = re ? re.ignoreUnclosed : false;
                switch (B = D.charCodeAt(q), (B === l || B === m || B === t3 && D.charCodeAt(q + 1) !== l) && (b = q, L += 1), B) {
                  case l:
                  case p:
                  case c:
                  case t3:
                  case m:
                    O = q;
                    do
                      O += 1, B = D.charCodeAt(O), B === l && (b = O, L += 1);
                    while (B === p || B === l || B === c || B === t3 || B === m);
                    E = ["space", D.slice(q, O)], q = O - 1;
                    break;
                  case r:
                  case a:
                  case g:
                  case v:
                  case d:
                  case y:
                  case f:
                    var oe = String.fromCharCode(B);
                    E = [oe, oe, L, q - b];
                    break;
                  case s:
                    if (Y = T.length ? T.pop()[1] : "", G = D.charCodeAt(q + 1), Y === "url" && G !== i && G !== u && G !== p && G !== l && G !== c && G !== m && G !== t3) {
                      O = q;
                      do {
                        if (J = false, O = D.indexOf(")", O + 1), O === -1)
                          if (V || ne) {
                            O = q;
                            break;
                          } else
                            ee("bracket");
                        for (M = O; D.charCodeAt(M - 1) === o; )
                          M -= 1, J = !J;
                      } while (J);
                      E = ["brackets", D.slice(q, O + 1), L, q - b, L, O - b], q = O;
                    } else
                      O = D.indexOf(")", q + 1), X = D.slice(q, O + 1), O === -1 || N.test(X) ? E = ["(", "(", L, q - b] : (E = ["brackets", X, L, q - b, L, O - b], q = O);
                    break;
                  case i:
                  case u:
                    j = B === i ? "'" : '"', O = q;
                    do {
                      if (J = false, O = D.indexOf(j, O + 1), O === -1)
                        if (V || ne) {
                          O = q + 1;
                          break;
                        } else
                          ee("string");
                      for (M = O; D.charCodeAt(M - 1) === o; )
                        M -= 1, J = !J;
                    } while (J);
                    X = D.slice(q, O + 1), C = X.split(`
`), R = C.length - 1, R > 0 ? (Q = L + R, K = O - C[R].length) : (Q = L, K = b), E = ["string", D.slice(q, O + 1), L, q - b, Q, O - K], b = K, L = Q, q = O;
                    break;
                  case _:
                    k.lastIndex = q + 1, k.test(D), k.lastIndex === 0 ? O = D.length - 1 : O = k.lastIndex - 2, E = ["at-word", D.slice(q, O + 1), L, q - b, L, O - b], q = O;
                    break;
                  case o:
                    for (O = q, Z = true; D.charCodeAt(O + 1) === o; )
                      O += 1, Z = !Z;
                    if (B = D.charCodeAt(O + 1), Z && B !== h && B !== p && B !== l && B !== c && B !== t3 && B !== m && (O += 1, I.test(D.charAt(O)))) {
                      for (; I.test(D.charAt(O + 1)); )
                        O += 1;
                      D.charCodeAt(O + 1) === p && (O += 1);
                    }
                    E = ["word", D.slice(q, O + 1), L, q - b, L, O - b], q = O;
                    break;
                  default:
                    B === h && D.charCodeAt(q + 1) === w ? (O = D.indexOf("*/", q + 2) + 1, O === 0 && (V || ne ? O = D.length : ee("comment")), X = D.slice(q, O + 1), C = X.split(`
`), R = C.length - 1, R > 0 ? (Q = L + R, K = O - C[R].length) : (Q = L, K = b), E = ["comment", X, L, q - b, Q, O - K], b = K, L = Q, q = O) : (x.lastIndex = q + 1, x.test(D), x.lastIndex === 0 ? O = D.length - 1 : O = x.lastIndex - 2, E = ["word", D.slice(q, O + 1), L, q - b, L, O - b], T.push(E), q = O);
                    break;
                }
                return q++, E;
              }
            }
            function le(re) {
              F.push(re);
            }
            return { back: le, nextToken: ue, endOfFile: te, position: z };
          }
          n.exports = e.default;
        } }), la = P({ "node_modules/postcss/lib/parse.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = o($t()), u = o(xr());
          function o(p) {
            return p && p.__esModule ? p : { default: p };
          }
          function h(p, m) {
            var c = new u.default(p, m), t3 = new i.default(c);
            try {
              t3.parse();
            } catch (r) {
              throw r;
            }
            return t3.root;
          }
          var l = h;
          e.default = l, n.exports = e.default;
        } }), Pf = P({ "node_modules/postcss/lib/list.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = { split: function(h, l, p) {
            for (var m = [], c = "", t3 = false, r = 0, a = false, s = false, f = 0; f < h.length; f++) {
              var g = h[f];
              a ? s ? s = false : g === "\\" ? s = true : g === a && (a = false) : g === '"' || g === "'" ? a = g : g === "(" ? r += 1 : g === ")" ? r > 0 && (r -= 1) : r === 0 && l.indexOf(g) !== -1 && (t3 = true), t3 ? (c !== "" && m.push(c.trim()), c = "", t3 = false) : c += g;
            }
            return (p || c !== "") && m.push(c.trim()), m;
          }, space: function(h) {
            var l = [" ", `
`, "	"];
            return i.split(h, l);
          }, comma: function(h) {
            return i.split(h, [","], true);
          } }, u = i;
          e.default = u, n.exports = e.default;
        } }), fa = P({ "node_modules/postcss/lib/rule.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = o(Or()), u = o(Pf());
          function o(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function h(t3, r) {
            for (var a = 0; a < r.length; a++) {
              var s = r[a];
              s.enumerable = s.enumerable || false, s.configurable = true, "value" in s && (s.writable = true), Object.defineProperty(t3, s.key, s);
            }
          }
          function l(t3, r, a) {
            return r && h(t3.prototype, r), a && h(t3, a), t3;
          }
          function p(t3, r) {
            t3.prototype = Object.create(r.prototype), t3.prototype.constructor = t3, t3.__proto__ = r;
          }
          var m = function(t3) {
            p(r, t3);
            function r(a) {
              var s;
              return s = t3.call(this, a) || this, s.type = "rule", s.nodes || (s.nodes = []), s;
            }
            return l(r, [{ key: "selectors", get: function() {
              return u.default.comma(this.selector);
            }, set: function(s) {
              var f = this.selector ? this.selector.match(/,\s*/) : null, g = f ? f[0] : "," + this.raw("between", "beforeOpen");
              this.selector = s.join(g);
            } }]), r;
          }(i.default), c = m;
          e.default = c, n.exports = e.default;
        } }), Or = P({ "node_modules/postcss/lib/container.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = h(ca()), u = h(kr()), o = h(Ft());
          function h(g) {
            return g && g.__esModule ? g : { default: g };
          }
          function l(g, v) {
            var y;
            if (typeof Symbol > "u" || g[Symbol.iterator] == null) {
              if (Array.isArray(g) || (y = p(g)) || v && g && typeof g.length == "number") {
                y && (g = y);
                var w = 0;
                return function() {
                  return w >= g.length ? { done: true } : { done: false, value: g[w++] };
                };
              }
              throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
            }
            return y = g[Symbol.iterator](), y.next.bind(y);
          }
          function p(g, v) {
            if (g) {
              if (typeof g == "string")
                return m(g, v);
              var y = Object.prototype.toString.call(g).slice(8, -1);
              if (y === "Object" && g.constructor && (y = g.constructor.name), y === "Map" || y === "Set")
                return Array.from(g);
              if (y === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(y))
                return m(g, v);
            }
          }
          function m(g, v) {
            (v == null || v > g.length) && (v = g.length);
            for (var y = 0, w = new Array(v); y < v; y++)
              w[y] = g[y];
            return w;
          }
          function c(g, v) {
            for (var y = 0; y < v.length; y++) {
              var w = v[y];
              w.enumerable = w.enumerable || false, w.configurable = true, "value" in w && (w.writable = true), Object.defineProperty(g, w.key, w);
            }
          }
          function t3(g, v, y) {
            return v && c(g.prototype, v), y && c(g, y), g;
          }
          function r(g, v) {
            g.prototype = Object.create(v.prototype), g.prototype.constructor = g, g.__proto__ = v;
          }
          function a(g) {
            return g.map(function(v) {
              return v.nodes && (v.nodes = a(v.nodes)), delete v.source, v;
            });
          }
          var s = function(g) {
            r(v, g);
            function v() {
              return g.apply(this, arguments) || this;
            }
            var y = v.prototype;
            return y.push = function(d) {
              return d.parent = this, this.nodes.push(d), this;
            }, y.each = function(d) {
              this.lastEach || (this.lastEach = 0), this.indexes || (this.indexes = {}), this.lastEach += 1;
              var _ = this.lastEach;
              if (this.indexes[_] = 0, !!this.nodes) {
                for (var k, x; this.indexes[_] < this.nodes.length && (k = this.indexes[_], x = d(this.nodes[k], k), x !== false); )
                  this.indexes[_] += 1;
                return delete this.indexes[_], x;
              }
            }, y.walk = function(d) {
              return this.each(function(_, k) {
                var x;
                try {
                  x = d(_, k);
                } catch (I) {
                  if (I.postcssNode = _, I.stack && _.source && /\n\s{4}at /.test(I.stack)) {
                    var N = _.source;
                    I.stack = I.stack.replace(/\n\s{4}at /, "$&" + N.input.from + ":" + N.start.line + ":" + N.start.column + "$&");
                  }
                  throw I;
                }
                return x !== false && _.walk && (x = _.walk(d)), x;
              });
            }, y.walkDecls = function(d, _) {
              return _ ? d instanceof RegExp ? this.walk(function(k, x) {
                if (k.type === "decl" && d.test(k.prop))
                  return _(k, x);
              }) : this.walk(function(k, x) {
                if (k.type === "decl" && k.prop === d)
                  return _(k, x);
              }) : (_ = d, this.walk(function(k, x) {
                if (k.type === "decl")
                  return _(k, x);
              }));
            }, y.walkRules = function(d, _) {
              return _ ? d instanceof RegExp ? this.walk(function(k, x) {
                if (k.type === "rule" && d.test(k.selector))
                  return _(k, x);
              }) : this.walk(function(k, x) {
                if (k.type === "rule" && k.selector === d)
                  return _(k, x);
              }) : (_ = d, this.walk(function(k, x) {
                if (k.type === "rule")
                  return _(k, x);
              }));
            }, y.walkAtRules = function(d, _) {
              return _ ? d instanceof RegExp ? this.walk(function(k, x) {
                if (k.type === "atrule" && d.test(k.name))
                  return _(k, x);
              }) : this.walk(function(k, x) {
                if (k.type === "atrule" && k.name === d)
                  return _(k, x);
              }) : (_ = d, this.walk(function(k, x) {
                if (k.type === "atrule")
                  return _(k, x);
              }));
            }, y.walkComments = function(d) {
              return this.walk(function(_, k) {
                if (_.type === "comment")
                  return d(_, k);
              });
            }, y.append = function() {
              for (var d = arguments.length, _ = new Array(d), k = 0; k < d; k++)
                _[k] = arguments[k];
              for (var x = 0, N = _; x < N.length; x++)
                for (var I = N[x], W = this.normalize(I, this.last), $2 = l(W), H; !(H = $2()).done; ) {
                  var D = H.value;
                  this.nodes.push(D);
                }
              return this;
            }, y.prepend = function() {
              for (var d = arguments.length, _ = new Array(d), k = 0; k < d; k++)
                _[k] = arguments[k];
              _ = _.reverse();
              for (var x = l(_), N; !(N = x()).done; ) {
                for (var I = N.value, W = this.normalize(I, this.first, "prepend").reverse(), $2 = l(W), H; !(H = $2()).done; ) {
                  var D = H.value;
                  this.nodes.unshift(D);
                }
                for (var V in this.indexes)
                  this.indexes[V] = this.indexes[V] + W.length;
              }
              return this;
            }, y.cleanRaws = function(d) {
              if (g.prototype.cleanRaws.call(this, d), this.nodes)
                for (var _ = l(this.nodes), k; !(k = _()).done; ) {
                  var x = k.value;
                  x.cleanRaws(d);
                }
            }, y.insertBefore = function(d, _) {
              d = this.index(d);
              for (var k = d === 0 ? "prepend" : false, x = this.normalize(_, this.nodes[d], k).reverse(), N = l(x), I; !(I = N()).done; ) {
                var W = I.value;
                this.nodes.splice(d, 0, W);
              }
              var $2;
              for (var H in this.indexes)
                $2 = this.indexes[H], d <= $2 && (this.indexes[H] = $2 + x.length);
              return this;
            }, y.insertAfter = function(d, _) {
              d = this.index(d);
              for (var k = this.normalize(_, this.nodes[d]).reverse(), x = l(k), N; !(N = x()).done; ) {
                var I = N.value;
                this.nodes.splice(d + 1, 0, I);
              }
              var W;
              for (var $2 in this.indexes)
                W = this.indexes[$2], d < W && (this.indexes[$2] = W + k.length);
              return this;
            }, y.removeChild = function(d) {
              d = this.index(d), this.nodes[d].parent = void 0, this.nodes.splice(d, 1);
              var _;
              for (var k in this.indexes)
                _ = this.indexes[k], _ >= d && (this.indexes[k] = _ - 1);
              return this;
            }, y.removeAll = function() {
              for (var d = l(this.nodes), _; !(_ = d()).done; ) {
                var k = _.value;
                k.parent = void 0;
              }
              return this.nodes = [], this;
            }, y.replaceValues = function(d, _, k) {
              return k || (k = _, _ = {}), this.walkDecls(function(x) {
                _.props && _.props.indexOf(x.prop) === -1 || _.fast && x.value.indexOf(_.fast) === -1 || (x.value = x.value.replace(d, k));
              }), this;
            }, y.every = function(d) {
              return this.nodes.every(d);
            }, y.some = function(d) {
              return this.nodes.some(d);
            }, y.index = function(d) {
              return typeof d == "number" ? d : this.nodes.indexOf(d);
            }, y.normalize = function(d, _) {
              var k = this;
              if (typeof d == "string") {
                var x = la();
                d = a(x(d).nodes);
              } else if (Array.isArray(d)) {
                d = d.slice(0);
                for (var N = l(d), I; !(I = N()).done; ) {
                  var W = I.value;
                  W.parent && W.parent.removeChild(W, "ignore");
                }
              } else if (d.type === "root") {
                d = d.nodes.slice(0);
                for (var $2 = l(d), H; !(H = $2()).done; ) {
                  var D = H.value;
                  D.parent && D.parent.removeChild(D, "ignore");
                }
              } else if (d.type)
                d = [d];
              else if (d.prop) {
                if (typeof d.value > "u")
                  throw new Error("Value field is missed in node creation");
                typeof d.value != "string" && (d.value = String(d.value)), d = [new i.default(d)];
              } else if (d.selector) {
                var V = fa();
                d = [new V(d)];
              } else if (d.name) {
                var B = pa();
                d = [new B(d)];
              } else if (d.text)
                d = [new u.default(d)];
              else
                throw new Error("Unknown node type in node creation");
              var O = d.map(function(j) {
                return j.parent && j.parent.removeChild(j), typeof j.raws.before > "u" && _ && typeof _.raws.before < "u" && (j.raws.before = _.raws.before.replace(/[^\s]/g, "")), j.parent = k, j;
              });
              return O;
            }, t3(v, [{ key: "first", get: function() {
              if (this.nodes)
                return this.nodes[0];
            } }, { key: "last", get: function() {
              if (this.nodes)
                return this.nodes[this.nodes.length - 1];
            } }]), v;
          }(o.default), f = s;
          e.default = f, n.exports = e.default;
        } }), pa = P({ "node_modules/postcss/lib/at-rule.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Or());
          function u(p) {
            return p && p.__esModule ? p : { default: p };
          }
          function o(p, m) {
            p.prototype = Object.create(m.prototype), p.prototype.constructor = p, p.__proto__ = m;
          }
          var h = function(p) {
            o(m, p);
            function m(t3) {
              var r;
              return r = p.call(this, t3) || this, r.type = "atrule", r;
            }
            var c = m.prototype;
            return c.append = function() {
              var r;
              this.nodes || (this.nodes = []);
              for (var a = arguments.length, s = new Array(a), f = 0; f < a; f++)
                s[f] = arguments[f];
              return (r = p.prototype.append).call.apply(r, [this].concat(s));
            }, c.prepend = function() {
              var r;
              this.nodes || (this.nodes = []);
              for (var a = arguments.length, s = new Array(a), f = 0; f < a; f++)
                s[f] = arguments[f];
              return (r = p.prototype.prepend).call.apply(r, [this].concat(s));
            }, m;
          }(i.default), l = h;
          e.default = l, n.exports = e.default;
        } }), If = P({ "node_modules/postcss/lib/map-generator.js"(e, n) {
          A(), n.exports = class {
            generate() {
            }
          };
        } }), Rf = P({ "node_modules/postcss/lib/warn-once.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = u;
          var i = {};
          function u(o) {
            i[o] || (i[o] = true, typeof console < "u" && console.warn && console.warn(o));
          }
          n.exports = e.default;
        } }), Cf = P({ "node_modules/postcss/lib/warning.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = function() {
            function o(l, p) {
              if (p === void 0 && (p = {}), this.type = "warning", this.text = l, p.node && p.node.source) {
                var m = p.node.positionBy(p);
                this.line = m.line, this.column = m.column;
              }
              for (var c in p)
                this[c] = p[c];
            }
            var h = o.prototype;
            return h.toString = function() {
              return this.node ? this.node.error(this.text, { plugin: this.plugin, index: this.index, word: this.word }).message : this.plugin ? this.plugin + ": " + this.text : this.text;
            }, o;
          }(), u = i;
          e.default = u, n.exports = e.default;
        } }), Nf = P({ "node_modules/postcss/lib/result.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Cf());
          function u(m) {
            return m && m.__esModule ? m : { default: m };
          }
          function o(m, c) {
            for (var t3 = 0; t3 < c.length; t3++) {
              var r = c[t3];
              r.enumerable = r.enumerable || false, r.configurable = true, "value" in r && (r.writable = true), Object.defineProperty(m, r.key, r);
            }
          }
          function h(m, c, t3) {
            return c && o(m.prototype, c), t3 && o(m, t3), m;
          }
          var l = function() {
            function m(t3, r, a) {
              this.processor = t3, this.messages = [], this.root = r, this.opts = a, this.css = void 0, this.map = void 0;
            }
            var c = m.prototype;
            return c.toString = function() {
              return this.css;
            }, c.warn = function(r, a) {
              a === void 0 && (a = {}), a.plugin || this.lastPlugin && this.lastPlugin.postcssPlugin && (a.plugin = this.lastPlugin.postcssPlugin);
              var s = new i.default(r, a);
              return this.messages.push(s), s;
            }, c.warnings = function() {
              return this.messages.filter(function(r) {
                return r.type === "warning";
              });
            }, h(m, [{ key: "content", get: function() {
              return this.css;
            } }]), m;
          }(), p = l;
          e.default = p, n.exports = e.default;
        } }), ha = P({ "node_modules/postcss/lib/lazy-result.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = p(If()), u = p(ua()), o = p(Rf()), h = p(Nf()), l = p(la());
          function p(v) {
            return v && v.__esModule ? v : { default: v };
          }
          function m(v, y) {
            var w;
            if (typeof Symbol > "u" || v[Symbol.iterator] == null) {
              if (Array.isArray(v) || (w = c(v)) || y && v && typeof v.length == "number") {
                w && (v = w);
                var d = 0;
                return function() {
                  return d >= v.length ? { done: true } : { done: false, value: v[d++] };
                };
              }
              throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
            }
            return w = v[Symbol.iterator](), w.next.bind(w);
          }
          function c(v, y) {
            if (v) {
              if (typeof v == "string")
                return t3(v, y);
              var w = Object.prototype.toString.call(v).slice(8, -1);
              if (w === "Object" && v.constructor && (w = v.constructor.name), w === "Map" || w === "Set")
                return Array.from(v);
              if (w === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(w))
                return t3(v, y);
            }
          }
          function t3(v, y) {
            (y == null || y > v.length) && (y = v.length);
            for (var w = 0, d = new Array(y); w < y; w++)
              d[w] = v[w];
            return d;
          }
          function r(v, y) {
            for (var w = 0; w < y.length; w++) {
              var d = y[w];
              d.enumerable = d.enumerable || false, d.configurable = true, "value" in d && (d.writable = true), Object.defineProperty(v, d.key, d);
            }
          }
          function a(v, y, w) {
            return y && r(v.prototype, y), w && r(v, w), v;
          }
          function s(v) {
            return typeof v == "object" && typeof v.then == "function";
          }
          var f = function() {
            function v(w, d, _) {
              this.stringified = false, this.processed = false;
              var k;
              if (typeof d == "object" && d !== null && d.type === "root")
                k = d;
              else if (d instanceof v || d instanceof h.default)
                k = d.root, d.map && (typeof _.map > "u" && (_.map = {}), _.map.inline || (_.map.inline = false), _.map.prev = d.map);
              else {
                var x = l.default;
                _.syntax && (x = _.syntax.parse), _.parser && (x = _.parser), x.parse && (x = x.parse);
                try {
                  k = x(d, _);
                } catch (N) {
                  this.error = N;
                }
              }
              this.result = new h.default(w, k, _);
            }
            var y = v.prototype;
            return y.warnings = function() {
              return this.sync().warnings();
            }, y.toString = function() {
              return this.css;
            }, y.then = function(d, _) {
              return this.async().then(d, _);
            }, y.catch = function(d) {
              return this.async().catch(d);
            }, y.finally = function(d) {
              return this.async().then(d, d);
            }, y.handleError = function(d, _) {
              try {
                if (this.error = d, d.name === "CssSyntaxError" && !d.plugin)
                  d.plugin = _.postcssPlugin, d.setMessage();
                else if (_.postcssVersion && false)
                  var k, x, N, I, W;
              } catch ($2) {
                console && console.error && console.error($2);
              }
            }, y.asyncTick = function(d, _) {
              var k = this;
              if (this.plugin >= this.processor.plugins.length)
                return this.processed = true, d();
              try {
                var x = this.processor.plugins[this.plugin], N = this.run(x);
                this.plugin += 1, s(N) ? N.then(function() {
                  k.asyncTick(d, _);
                }).catch(function(I) {
                  k.handleError(I, x), k.processed = true, _(I);
                }) : this.asyncTick(d, _);
              } catch (I) {
                this.processed = true, _(I);
              }
            }, y.async = function() {
              var d = this;
              return this.processed ? new Promise(function(_, k) {
                d.error ? k(d.error) : _(d.stringify());
              }) : this.processing ? this.processing : (this.processing = new Promise(function(_, k) {
                if (d.error)
                  return k(d.error);
                d.plugin = 0, d.asyncTick(_, k);
              }).then(function() {
                return d.processed = true, d.stringify();
              }), this.processing);
            }, y.sync = function() {
              if (this.processed)
                return this.result;
              if (this.processed = true, this.processing)
                throw new Error("Use process(css).then(cb) to work with async plugins");
              if (this.error)
                throw this.error;
              for (var d = m(this.result.processor.plugins), _; !(_ = d()).done; ) {
                var k = _.value, x = this.run(k);
                if (s(x))
                  throw new Error("Use process(css).then(cb) to work with async plugins");
              }
              return this.result;
            }, y.run = function(d) {
              this.result.lastPlugin = d;
              try {
                return d(this.result.root, this.result);
              } catch (_) {
                throw this.handleError(_, d), _;
              }
            }, y.stringify = function() {
              if (this.stringified)
                return this.result;
              this.stringified = true, this.sync();
              var d = this.result.opts, _ = u.default;
              d.syntax && (_ = d.syntax.stringify), d.stringifier && (_ = d.stringifier), _.stringify && (_ = _.stringify);
              var k = new i.default(_, this.result.root, this.result.opts), x = k.generate();
              return this.result.css = x[0], this.result.map = x[1], this.result;
            }, a(v, [{ key: "processor", get: function() {
              return this.result.processor;
            } }, { key: "opts", get: function() {
              return this.result.opts;
            } }, { key: "css", get: function() {
              return this.stringify().css;
            } }, { key: "content", get: function() {
              return this.stringify().content;
            } }, { key: "map", get: function() {
              return this.stringify().map;
            } }, { key: "root", get: function() {
              return this.sync().root;
            } }, { key: "messages", get: function() {
              return this.sync().messages;
            } }]), v;
          }(), g = f;
          e.default = g, n.exports = e.default;
        } }), jf = P({ "node_modules/postcss/lib/processor.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(ha());
          function u(c) {
            return c && c.__esModule ? c : { default: c };
          }
          function o(c, t3) {
            var r;
            if (typeof Symbol > "u" || c[Symbol.iterator] == null) {
              if (Array.isArray(c) || (r = h(c)) || t3 && c && typeof c.length == "number") {
                r && (c = r);
                var a = 0;
                return function() {
                  return a >= c.length ? { done: true } : { done: false, value: c[a++] };
                };
              }
              throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
            }
            return r = c[Symbol.iterator](), r.next.bind(r);
          }
          function h(c, t3) {
            if (c) {
              if (typeof c == "string")
                return l(c, t3);
              var r = Object.prototype.toString.call(c).slice(8, -1);
              if (r === "Object" && c.constructor && (r = c.constructor.name), r === "Map" || r === "Set")
                return Array.from(c);
              if (r === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))
                return l(c, t3);
            }
          }
          function l(c, t3) {
            (t3 == null || t3 > c.length) && (t3 = c.length);
            for (var r = 0, a = new Array(t3); r < t3; r++)
              a[r] = c[r];
            return a;
          }
          var p = function() {
            function c(r) {
              r === void 0 && (r = []), this.version = "7.0.39", this.plugins = this.normalize(r);
            }
            var t3 = c.prototype;
            return t3.use = function(a) {
              return this.plugins = this.plugins.concat(this.normalize([a])), this;
            }, t3.process = function(r) {
              function a(s) {
                return r.apply(this, arguments);
              }
              return a.toString = function() {
                return r.toString();
              }, a;
            }(function(r, a) {
              return a === void 0 && (a = {}), this.plugins.length === 0 && (a.parser, a.stringifier), new i.default(this, r, a);
            }), t3.normalize = function(a) {
              for (var s = [], f = o(a), g; !(g = f()).done; ) {
                var v = g.value;
                if (v.postcss === true) {
                  var y = v();
                  throw new Error("PostCSS plugin " + y.postcssPlugin + ` requires PostCSS 8.
Migration guide for end-users:
https://github.com/postcss/postcss/wiki/PostCSS-8-for-end-users`);
                }
                if (v.postcss && (v = v.postcss), typeof v == "object" && Array.isArray(v.plugins))
                  s = s.concat(v.plugins);
                else if (typeof v == "function")
                  s.push(v);
                else if (!(typeof v == "object" && (v.parse || v.stringify)))
                  throw typeof v == "object" && v.postcssPlugin ? new Error("PostCSS plugin " + v.postcssPlugin + ` requires PostCSS 8.
Migration guide for end-users:
https://github.com/postcss/postcss/wiki/PostCSS-8-for-end-users`) : new Error(v + " is not a PostCSS plugin");
              }
              return s;
            }, c;
          }(), m = p;
          e.default = m, n.exports = e.default;
        } }), Mf = P({ "node_modules/postcss/lib/root.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = u(Or());
          function u(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          function o(t3, r) {
            var a;
            if (typeof Symbol > "u" || t3[Symbol.iterator] == null) {
              if (Array.isArray(t3) || (a = h(t3)) || r && t3 && typeof t3.length == "number") {
                a && (t3 = a);
                var s = 0;
                return function() {
                  return s >= t3.length ? { done: true } : { done: false, value: t3[s++] };
                };
              }
              throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
            }
            return a = t3[Symbol.iterator](), a.next.bind(a);
          }
          function h(t3, r) {
            if (t3) {
              if (typeof t3 == "string")
                return l(t3, r);
              var a = Object.prototype.toString.call(t3).slice(8, -1);
              if (a === "Object" && t3.constructor && (a = t3.constructor.name), a === "Map" || a === "Set")
                return Array.from(t3);
              if (a === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(a))
                return l(t3, r);
            }
          }
          function l(t3, r) {
            (r == null || r > t3.length) && (r = t3.length);
            for (var a = 0, s = new Array(r); a < r; a++)
              s[a] = t3[a];
            return s;
          }
          function p(t3, r) {
            t3.prototype = Object.create(r.prototype), t3.prototype.constructor = t3, t3.__proto__ = r;
          }
          var m = function(t3) {
            p(r, t3);
            function r(s) {
              var f;
              return f = t3.call(this, s) || this, f.type = "root", f.nodes || (f.nodes = []), f;
            }
            var a = r.prototype;
            return a.removeChild = function(f, g) {
              var v = this.index(f);
              return !g && v === 0 && this.nodes.length > 1 && (this.nodes[1].raws.before = this.nodes[v].raws.before), t3.prototype.removeChild.call(this, f);
            }, a.normalize = function(f, g, v) {
              var y = t3.prototype.normalize.call(this, f);
              if (g) {
                if (v === "prepend")
                  this.nodes.length > 1 ? g.raws.before = this.nodes[1].raws.before : delete g.raws.before;
                else if (this.first !== g)
                  for (var w = o(y), d; !(d = w()).done; ) {
                    var _ = d.value;
                    _.raws.before = g.raws.before;
                  }
              }
              return y;
            }, a.toResult = function(f) {
              f === void 0 && (f = {});
              var g = ha(), v = jf(), y = new g(new v(), this, f);
              return y.stringify();
            }, r;
          }(i.default), c = m;
          e.default = c, n.exports = e.default;
        } }), $t = P({ "node_modules/postcss/lib/parser.js"(e, n) {
          "use strict";
          A(), e.__esModule = true, e.default = void 0;
          var i = m(ca()), u = m(Ut()), o = m(kr()), h = m(pa()), l = m(Mf()), p = m(fa());
          function m(t3) {
            return t3 && t3.__esModule ? t3 : { default: t3 };
          }
          var c = function() {
            function t3(a) {
              this.input = a, this.root = new l.default(), this.current = this.root, this.spaces = "", this.semicolon = false, this.createTokenizer(), this.root.source = { input: a, start: { line: 1, column: 1 } };
            }
            var r = t3.prototype;
            return r.createTokenizer = function() {
              this.tokenizer = (0, u.default)(this.input);
            }, r.parse = function() {
              for (var s; !this.tokenizer.endOfFile(); )
                switch (s = this.tokenizer.nextToken(), s[0]) {
                  case "space":
                    this.spaces += s[1];
                    break;
                  case ";":
                    this.freeSemicolon(s);
                    break;
                  case "}":
                    this.end(s);
                    break;
                  case "comment":
                    this.comment(s);
                    break;
                  case "at-word":
                    this.atrule(s);
                    break;
                  case "{":
                    this.emptyRule(s);
                    break;
                  default:
                    this.other(s);
                    break;
                }
              this.endFile();
            }, r.comment = function(s) {
              var f = new o.default();
              this.init(f, s[2], s[3]), f.source.end = { line: s[4], column: s[5] };
              var g = s[1].slice(2, -2);
              if (/^\s*$/.test(g))
                f.text = "", f.raws.left = g, f.raws.right = "";
              else {
                var v = g.match(/^(\s*)([^]*[^\s])(\s*)$/);
                f.text = v[2], f.raws.left = v[1], f.raws.right = v[3];
              }
            }, r.emptyRule = function(s) {
              var f = new p.default();
              this.init(f, s[2], s[3]), f.selector = "", f.raws.between = "", this.current = f;
            }, r.other = function(s) {
              for (var f = false, g = null, v = false, y = null, w = [], d = [], _ = s; _; ) {
                if (g = _[0], d.push(_), g === "(" || g === "[")
                  y || (y = _), w.push(g === "(" ? ")" : "]");
                else if (w.length === 0)
                  if (g === ";")
                    if (v) {
                      this.decl(d);
                      return;
                    } else
                      break;
                  else if (g === "{") {
                    this.rule(d);
                    return;
                  } else if (g === "}") {
                    this.tokenizer.back(d.pop()), f = true;
                    break;
                  } else
                    g === ":" && (v = true);
                else
                  g === w[w.length - 1] && (w.pop(), w.length === 0 && (y = null));
                _ = this.tokenizer.nextToken();
              }
              if (this.tokenizer.endOfFile() && (f = true), w.length > 0 && this.unclosedBracket(y), f && v) {
                for (; d.length && (_ = d[d.length - 1][0], !(_ !== "space" && _ !== "comment")); )
                  this.tokenizer.back(d.pop());
                this.decl(d);
              } else
                this.unknownWord(d);
            }, r.rule = function(s) {
              s.pop();
              var f = new p.default();
              this.init(f, s[0][2], s[0][3]), f.raws.between = this.spacesAndCommentsFromEnd(s), this.raw(f, "selector", s), this.current = f;
            }, r.decl = function(s) {
              var f = new i.default();
              this.init(f);
              var g = s[s.length - 1];
              for (g[0] === ";" && (this.semicolon = true, s.pop()), g[4] ? f.source.end = { line: g[4], column: g[5] } : f.source.end = { line: g[2], column: g[3] }; s[0][0] !== "word"; )
                s.length === 1 && this.unknownWord(s), f.raws.before += s.shift()[1];
              for (f.source.start = { line: s[0][2], column: s[0][3] }, f.prop = ""; s.length; ) {
                var v = s[0][0];
                if (v === ":" || v === "space" || v === "comment")
                  break;
                f.prop += s.shift()[1];
              }
              f.raws.between = "";
              for (var y; s.length; )
                if (y = s.shift(), y[0] === ":") {
                  f.raws.between += y[1];
                  break;
                } else
                  y[0] === "word" && /\w/.test(y[1]) && this.unknownWord([y]), f.raws.between += y[1];
              (f.prop[0] === "_" || f.prop[0] === "*") && (f.raws.before += f.prop[0], f.prop = f.prop.slice(1)), f.raws.between += this.spacesAndCommentsFromStart(s), this.precheckMissedSemicolon(s);
              for (var w = s.length - 1; w > 0; w--) {
                if (y = s[w], y[1].toLowerCase() === "!important") {
                  f.important = true;
                  var d = this.stringFrom(s, w);
                  d = this.spacesFromEnd(s) + d, d !== " !important" && (f.raws.important = d);
                  break;
                } else if (y[1].toLowerCase() === "important") {
                  for (var _ = s.slice(0), k = "", x = w; x > 0; x--) {
                    var N = _[x][0];
                    if (k.trim().indexOf("!") === 0 && N !== "space")
                      break;
                    k = _.pop()[1] + k;
                  }
                  k.trim().indexOf("!") === 0 && (f.important = true, f.raws.important = k, s = _);
                }
                if (y[0] !== "space" && y[0] !== "comment")
                  break;
              }
              this.raw(f, "value", s), f.value.indexOf(":") !== -1 && this.checkMissedSemicolon(s);
            }, r.atrule = function(s) {
              var f = new h.default();
              f.name = s[1].slice(1), f.name === "" && this.unnamedAtrule(f, s), this.init(f, s[2], s[3]);
              for (var g, v, y = false, w = false, d = []; !this.tokenizer.endOfFile(); ) {
                if (s = this.tokenizer.nextToken(), s[0] === ";") {
                  f.source.end = { line: s[2], column: s[3] }, this.semicolon = true;
                  break;
                } else if (s[0] === "{") {
                  w = true;
                  break;
                } else if (s[0] === "}") {
                  if (d.length > 0) {
                    for (v = d.length - 1, g = d[v]; g && g[0] === "space"; )
                      g = d[--v];
                    g && (f.source.end = { line: g[4], column: g[5] });
                  }
                  this.end(s);
                  break;
                } else
                  d.push(s);
                if (this.tokenizer.endOfFile()) {
                  y = true;
                  break;
                }
              }
              f.raws.between = this.spacesAndCommentsFromEnd(d), d.length ? (f.raws.afterName = this.spacesAndCommentsFromStart(d), this.raw(f, "params", d), y && (s = d[d.length - 1], f.source.end = { line: s[4], column: s[5] }, this.spaces = f.raws.between, f.raws.between = "")) : (f.raws.afterName = "", f.params = ""), w && (f.nodes = [], this.current = f);
            }, r.end = function(s) {
              this.current.nodes && this.current.nodes.length && (this.current.raws.semicolon = this.semicolon), this.semicolon = false, this.current.raws.after = (this.current.raws.after || "") + this.spaces, this.spaces = "", this.current.parent ? (this.current.source.end = { line: s[2], column: s[3] }, this.current = this.current.parent) : this.unexpectedClose(s);
            }, r.endFile = function() {
              this.current.parent && this.unclosedBlock(), this.current.nodes && this.current.nodes.length && (this.current.raws.semicolon = this.semicolon), this.current.raws.after = (this.current.raws.after || "") + this.spaces;
            }, r.freeSemicolon = function(s) {
              if (this.spaces += s[1], this.current.nodes) {
                var f = this.current.nodes[this.current.nodes.length - 1];
                f && f.type === "rule" && !f.raws.ownSemicolon && (f.raws.ownSemicolon = this.spaces, this.spaces = "");
              }
            }, r.init = function(s, f, g) {
              this.current.push(s), s.source = { start: { line: f, column: g }, input: this.input }, s.raws.before = this.spaces, this.spaces = "", s.type !== "comment" && (this.semicolon = false);
            }, r.raw = function(s, f, g) {
              for (var v, y, w = g.length, d = "", _ = true, k, x, N = /^([.|#])?([\w])+/i, I = 0; I < w; I += 1) {
                if (v = g[I], y = v[0], y === "comment" && s.type === "rule") {
                  x = g[I - 1], k = g[I + 1], x[0] !== "space" && k[0] !== "space" && N.test(x[1]) && N.test(k[1]) ? d += v[1] : _ = false;
                  continue;
                }
                y === "comment" || y === "space" && I === w - 1 ? _ = false : d += v[1];
              }
              if (!_) {
                var W = g.reduce(function($2, H) {
                  return $2 + H[1];
                }, "");
                s.raws[f] = { value: d, raw: W };
              }
              s[f] = d;
            }, r.spacesAndCommentsFromEnd = function(s) {
              for (var f, g = ""; s.length && (f = s[s.length - 1][0], !(f !== "space" && f !== "comment")); )
                g = s.pop()[1] + g;
              return g;
            }, r.spacesAndCommentsFromStart = function(s) {
              for (var f, g = ""; s.length && (f = s[0][0], !(f !== "space" && f !== "comment")); )
                g += s.shift()[1];
              return g;
            }, r.spacesFromEnd = function(s) {
              for (var f, g = ""; s.length && (f = s[s.length - 1][0], f === "space"); )
                g = s.pop()[1] + g;
              return g;
            }, r.stringFrom = function(s, f) {
              for (var g = "", v = f; v < s.length; v++)
                g += s[v][1];
              return s.splice(f, s.length - f), g;
            }, r.colon = function(s) {
              for (var f = 0, g, v, y, w = 0; w < s.length; w++) {
                if (g = s[w], v = g[0], v === "(" && (f += 1), v === ")" && (f -= 1), f === 0 && v === ":")
                  if (!y)
                    this.doubleColon(g);
                  else {
                    if (y[0] === "word" && y[1] === "progid")
                      continue;
                    return w;
                  }
                y = g;
              }
              return false;
            }, r.unclosedBracket = function(s) {
              throw this.input.error("Unclosed bracket", s[2], s[3]);
            }, r.unknownWord = function(s) {
              throw this.input.error("Unknown word", s[0][2], s[0][3]);
            }, r.unexpectedClose = function(s) {
              throw this.input.error("Unexpected }", s[2], s[3]);
            }, r.unclosedBlock = function() {
              var s = this.current.source.start;
              throw this.input.error("Unclosed block", s.line, s.column);
            }, r.doubleColon = function(s) {
              throw this.input.error("Double colon", s[2], s[3]);
            }, r.unnamedAtrule = function(s, f) {
              throw this.input.error("At-rule without name", f[2], f[3]);
            }, r.precheckMissedSemicolon = function() {
            }, r.checkMissedSemicolon = function(s) {
              var f = this.colon(s);
              if (f !== false) {
                for (var g = 0, v, y = f - 1; y >= 0 && (v = s[y], !(v[0] !== "space" && (g += 1, g === 2))); y--)
                  ;
                throw this.input.error("Missed semicolon", v[2], v[3]);
              }
            }, t3;
          }();
          e.default = c, n.exports = e.default;
        } }), Df = P({ "node_modules/postcss-less/lib/nodes/inline-comment.js"(e, n) {
          A();
          var i = Ut(), u = xr();
          n.exports = { isInlineComment(o) {
            if (o[0] === "word" && o[1].slice(0, 2) === "//") {
              let h = o, l = [], p;
              for (; o; ) {
                if (/\r?\n/.test(o[1])) {
                  if (/['"].*\r?\n/.test(o[1])) {
                    l.push(o[1].substring(0, o[1].indexOf(`
`)));
                    let c = o[1].substring(o[1].indexOf(`
`));
                    c += this.input.css.valueOf().substring(this.tokenizer.position()), this.input = new u(c), this.tokenizer = i(this.input);
                  } else
                    this.tokenizer.back(o);
                  break;
                }
                l.push(o[1]), p = o, o = this.tokenizer.nextToken({ ignoreUnclosed: true });
              }
              let m = ["comment", l.join(""), h[2], h[3], p[2], p[3]];
              return this.inlineComment(m), true;
            } else if (o[1] === "/") {
              let h = this.tokenizer.nextToken({ ignoreUnclosed: true });
              if (h[0] === "comment" && /^\/\*/.test(h[1]))
                return h[0] = "word", h[1] = h[1].slice(1), o[1] = "//", this.tokenizer.back(h), n.exports.isInlineComment.bind(this)(o);
            }
            return false;
          } };
        } }), Lf = P({ "node_modules/postcss-less/lib/nodes/interpolation.js"(e, n) {
          A(), n.exports = { interpolation(i) {
            let u = i, o = [i], h = ["word", "{", "}"];
            if (i = this.tokenizer.nextToken(), u[1].length > 1 || i[0] !== "{")
              return this.tokenizer.back(i), false;
            for (; i && h.includes(i[0]); )
              o.push(i), i = this.tokenizer.nextToken();
            let l = o.map((r) => r[1]);
            [u] = o;
            let p = o.pop(), m = [u[2], u[3]], c = [p[4] || p[2], p[5] || p[3]], t3 = ["word", l.join("")].concat(m, c);
            return this.tokenizer.back(i), this.tokenizer.back(t3), true;
          } };
        } }), zf = P({ "node_modules/postcss-less/lib/nodes/mixin.js"(e, n) {
          A();
          var i = /^#[0-9a-fA-F]{6}$|^#[0-9a-fA-F]{3}$/, u = /\.[0-9]/, o = (h) => {
            let [, l] = h, [p] = l;
            return (p === "." || p === "#") && i.test(l) === false && u.test(l) === false;
          };
          n.exports = { isMixinToken: o };
        } }), Bf = P({ "node_modules/postcss-less/lib/nodes/import.js"(e, n) {
          A();
          var i = Ut(), u = /^url\((.+)\)/;
          n.exports = (o) => {
            let { name: h, params: l = "" } = o;
            if (h === "import" && l.length) {
              o.import = true;
              let p = i({ css: l });
              for (o.filename = l.replace(u, "$1"); !p.endOfFile(); ) {
                let [m, c] = p.nextToken();
                if (m === "word" && c === "url")
                  return;
                if (m === "brackets") {
                  o.options = c, o.filename = l.replace(c, "").trim();
                  break;
                }
              }
            }
          };
        } }), Ff = P({ "node_modules/postcss-less/lib/nodes/variable.js"(e, n) {
          A();
          var i = /:$/, u = /^:(\s+)?/;
          n.exports = (o) => {
            let { name: h, params: l = "" } = o;
            if (o.name.slice(-1) === ":") {
              if (i.test(h)) {
                let [p] = h.match(i);
                o.name = h.replace(p, ""), o.raws.afterName = p + (o.raws.afterName || ""), o.variable = true, o.value = o.params;
              }
              if (u.test(l)) {
                let [p] = l.match(u);
                o.value = l.replace(p, ""), o.raws.afterName = (o.raws.afterName || "") + p, o.variable = true;
              }
            }
          };
        } }), Uf = P({ "node_modules/postcss-less/lib/LessParser.js"(e, n) {
          A();
          var i = kr(), u = $t(), { isInlineComment: o } = Df(), { interpolation: h } = Lf(), { isMixinToken: l } = zf(), p = Bf(), m = Ff(), c = /(!\s*important)$/i;
          n.exports = class extends u {
            constructor() {
              super(...arguments), this.lastNode = null;
            }
            atrule(r) {
              h.bind(this)(r) || (super.atrule(r), p(this.lastNode), m(this.lastNode));
            }
            decl() {
              super.decl(...arguments), /extend\(.+\)/i.test(this.lastNode.value) && (this.lastNode.extend = true);
            }
            each(r) {
              r[0][1] = ` ${r[0][1]}`;
              let a = r.findIndex((y) => y[0] === "("), s = r.reverse().find((y) => y[0] === ")"), f = r.reverse().indexOf(s), v = r.splice(a, f).map((y) => y[1]).join("");
              for (let y of r.reverse())
                this.tokenizer.back(y);
              this.atrule(this.tokenizer.nextToken()), this.lastNode.function = true, this.lastNode.params = v;
            }
            init(r, a, s) {
              super.init(r, a, s), this.lastNode = r;
            }
            inlineComment(r) {
              let a = new i(), s = r[1].slice(2);
              if (this.init(a, r[2], r[3]), a.source.end = { line: r[4], column: r[5] }, a.inline = true, a.raws.begin = "//", /^\s*$/.test(s))
                a.text = "", a.raws.left = s, a.raws.right = "";
              else {
                let f = s.match(/^(\s*)([^]*[^\s])(\s*)$/);
                [, a.raws.left, a.text, a.raws.right] = f;
              }
            }
            mixin(r) {
              let [a] = r, s = a[1].slice(0, 1), f = r.findIndex((d) => d[0] === "brackets"), g = r.findIndex((d) => d[0] === "("), v = "";
              if ((f < 0 || f > 3) && g > 0) {
                let d = r.reduce((V, B, O) => B[0] === ")" ? O : V), k = r.slice(g, d + g).map((V) => V[1]).join(""), [x] = r.slice(g), N = [x[2], x[3]], [I] = r.slice(d, d + 1), W = [I[2], I[3]], $2 = ["brackets", k].concat(N, W), H = r.slice(0, g), D = r.slice(d + 1);
                r = H, r.push($2), r = r.concat(D);
              }
              let y = [];
              for (let d of r)
                if ((d[1] === "!" || y.length) && y.push(d), d[1] === "important")
                  break;
              if (y.length) {
                let [d] = y, _ = r.indexOf(d), k = y[y.length - 1], x = [d[2], d[3]], N = [k[4], k[5]], W = ["word", y.map(($2) => $2[1]).join("")].concat(x, N);
                r.splice(_, y.length, W);
              }
              let w = r.findIndex((d) => c.test(d[1]));
              w > 0 && ([, v] = r[w], r.splice(w, 1));
              for (let d of r.reverse())
                this.tokenizer.back(d);
              this.atrule(this.tokenizer.nextToken()), this.lastNode.mixin = true, this.lastNode.raws.identifier = s, v && (this.lastNode.important = true, this.lastNode.raws.important = v);
            }
            other(r) {
              o.bind(this)(r) || super.other(r);
            }
            rule(r) {
              let a = r[r.length - 1], s = r[r.length - 2];
              if (s[0] === "at-word" && a[0] === "{" && (this.tokenizer.back(a), h.bind(this)(s))) {
                let g = this.tokenizer.nextToken();
                r = r.slice(0, r.length - 2).concat([g]);
                for (let v of r.reverse())
                  this.tokenizer.back(v);
                return;
              }
              super.rule(r), /:extend\(.+\)/i.test(this.lastNode.selector) && (this.lastNode.extend = true);
            }
            unknownWord(r) {
              let [a] = r;
              if (r[0][1] === "each" && r[1][0] === "(") {
                this.each(r);
                return;
              }
              if (l(a)) {
                this.mixin(r);
                return;
              }
              super.unknownWord(r);
            }
          };
        } }), $f = P({ "node_modules/postcss-less/lib/LessStringifier.js"(e, n) {
          A();
          var i = Sr();
          n.exports = class extends i {
            atrule(o, h) {
              if (!o.mixin && !o.variable && !o.function) {
                super.atrule(o, h);
                return;
              }
              let p = `${o.function ? "" : o.raws.identifier || "@"}${o.name}`, m = o.params ? this.rawValue(o, "params") : "", c = o.raws.important || "";
              if (o.variable && (m = o.value), typeof o.raws.afterName < "u" ? p += o.raws.afterName : m && (p += " "), o.nodes)
                this.block(o, p + m + c);
              else {
                let t3 = (o.raws.between || "") + c + (h ? ";" : "");
                this.builder(p + m + t3, o);
              }
            }
            comment(o) {
              if (o.inline) {
                let h = this.raw(o, "left", "commentLeft"), l = this.raw(o, "right", "commentRight");
                this.builder(`//${h}${o.text}${l}`, o);
              } else
                super.comment(o);
            }
          };
        } }), Wf = P({ "node_modules/postcss-less/lib/index.js"(e, n) {
          A();
          var i = xr(), u = Uf(), o = $f();
          n.exports = { parse(h, l) {
            let p = new i(h, l), m = new u(p);
            return m.parse(), m.root;
          }, stringify(h, l) {
            new o(l).stringify(h);
          }, nodeToString(h) {
            let l = "";
            return n.exports.stringify(h, (p) => {
              l += p;
            }), l;
          } };
        } }), Vf = P({ "node_modules/postcss-scss/lib/scss-stringifier.js"(e, n) {
          "use strict";
          A();
          function i(h, l) {
            h.prototype = Object.create(l.prototype), h.prototype.constructor = h, h.__proto__ = l;
          }
          var u = Sr(), o = function(h) {
            i(l, h);
            function l() {
              return h.apply(this, arguments) || this;
            }
            var p = l.prototype;
            return p.comment = function(c) {
              var t3 = this.raw(c, "left", "commentLeft"), r = this.raw(c, "right", "commentRight");
              if (c.raws.inline) {
                var a = c.raws.text || c.text;
                this.builder("//" + t3 + a + r, c);
              } else
                this.builder("/*" + t3 + c.text + r + "*/", c);
            }, p.decl = function(c, t3) {
              if (!c.isNested)
                h.prototype.decl.call(this, c, t3);
              else {
                var r = this.raw(c, "between", "colon"), a = c.prop + r + this.rawValue(c, "value");
                c.important && (a += c.raws.important || " !important"), this.builder(a + "{", c, "start");
                var s;
                c.nodes && c.nodes.length ? (this.body(c), s = this.raw(c, "after")) : s = this.raw(c, "after", "emptyBody"), s && this.builder(s), this.builder("}", c, "end");
              }
            }, p.rawValue = function(c, t3) {
              var r = c[t3], a = c.raws[t3];
              return a && a.value === r ? a.scss ? a.scss : a.raw : r;
            }, l;
          }(u);
          n.exports = o;
        } }), Gf = P({ "node_modules/postcss-scss/lib/scss-stringify.js"(e, n) {
          "use strict";
          A();
          var i = Vf();
          n.exports = function(o, h) {
            var l = new i(h);
            l.stringify(o);
          };
        } }), Hf = P({ "node_modules/postcss-scss/lib/nested-declaration.js"(e, n) {
          "use strict";
          A();
          function i(h, l) {
            h.prototype = Object.create(l.prototype), h.prototype.constructor = h, h.__proto__ = l;
          }
          var u = Or(), o = function(h) {
            i(l, h);
            function l(p) {
              var m;
              return m = h.call(this, p) || this, m.type = "decl", m.isNested = true, m.nodes || (m.nodes = []), m;
            }
            return l;
          }(u);
          n.exports = o;
        } }), Jf = P({ "node_modules/postcss-scss/lib/scss-tokenize.js"(e, n) {
          "use strict";
          A();
          var i = "'".charCodeAt(0), u = '"'.charCodeAt(0), o = "\\".charCodeAt(0), h = "/".charCodeAt(0), l = `
`.charCodeAt(0), p = " ".charCodeAt(0), m = "\f".charCodeAt(0), c = "	".charCodeAt(0), t3 = "\r".charCodeAt(0), r = "[".charCodeAt(0), a = "]".charCodeAt(0), s = "(".charCodeAt(0), f = ")".charCodeAt(0), g = "{".charCodeAt(0), v = "}".charCodeAt(0), y = ";".charCodeAt(0), w = "*".charCodeAt(0), d = ":".charCodeAt(0), _ = "@".charCodeAt(0), k = ",".charCodeAt(0), x = "#".charCodeAt(0), N = /[ \n\t\r\f{}()'"\\;/[\]#]/g, I = /[ \n\t\r\f(){}:;@!'"\\\][#]|\/(?=\*)/g, W = /.[\\/("'\n]/, $2 = /[a-f0-9]/i, H = /[\r\f\n]/g;
          n.exports = function(V, B) {
            B === void 0 && (B = {});
            var O = V.css.valueOf(), j = B.ignoreErrors, C, R, X, Z, Q, K, J, M, Y, G, E, S, b, L, q = O.length, T = -1, F = 1, z = 0, ee = [], te = [];
            function ue(ie) {
              throw V.error("Unclosed " + ie, F, z - T);
            }
            function le() {
              return te.length === 0 && z >= q;
            }
            function re() {
              for (var ie = 1, ce = false, fe = false; ie > 0; )
                R += 1, O.length <= R && ue("interpolation"), C = O.charCodeAt(R), S = O.charCodeAt(R + 1), ce ? !fe && C === ce ? (ce = false, fe = false) : C === o ? fe = !G : fe && (fe = false) : C === i || C === u ? ce = C : C === v ? ie -= 1 : C === x && S === g && (ie += 1);
            }
            function ne() {
              if (te.length)
                return te.pop();
              if (!(z >= q)) {
                switch (C = O.charCodeAt(z), (C === l || C === m || C === t3 && O.charCodeAt(z + 1) !== l) && (T = z, F += 1), C) {
                  case l:
                  case p:
                  case c:
                  case t3:
                  case m:
                    R = z;
                    do
                      R += 1, C = O.charCodeAt(R), C === l && (T = R, F += 1);
                    while (C === p || C === l || C === c || C === t3 || C === m);
                    b = ["space", O.slice(z, R)], z = R - 1;
                    break;
                  case r:
                    b = ["[", "[", F, z - T];
                    break;
                  case a:
                    b = ["]", "]", F, z - T];
                    break;
                  case g:
                    b = ["{", "{", F, z - T];
                    break;
                  case v:
                    b = ["}", "}", F, z - T];
                    break;
                  case k:
                    b = ["word", ",", F, z - T, F, z - T + 1];
                    break;
                  case d:
                    b = [":", ":", F, z - T];
                    break;
                  case y:
                    b = [";", ";", F, z - T];
                    break;
                  case s:
                    if (E = ee.length ? ee.pop()[1] : "", S = O.charCodeAt(z + 1), E === "url" && S !== i && S !== u) {
                      for (L = 1, G = false, R = z + 1; R <= O.length - 1; ) {
                        if (S = O.charCodeAt(R), S === o)
                          G = !G;
                        else if (S === s)
                          L += 1;
                        else if (S === f && (L -= 1, L === 0))
                          break;
                        R += 1;
                      }
                      K = O.slice(z, R + 1), Z = K.split(`
`), Q = Z.length - 1, Q > 0 ? (M = F + Q, Y = R - Z[Q].length) : (M = F, Y = T), b = ["brackets", K, F, z - T, M, R - Y], T = Y, F = M, z = R;
                    } else
                      R = O.indexOf(")", z + 1), K = O.slice(z, R + 1), R === -1 || W.test(K) ? b = ["(", "(", F, z - T] : (b = ["brackets", K, F, z - T, F, R - T], z = R);
                    break;
                  case f:
                    b = [")", ")", F, z - T];
                    break;
                  case i:
                  case u:
                    for (X = C, R = z, G = false; R < q && (R++, R === q && ue("string"), C = O.charCodeAt(R), S = O.charCodeAt(R + 1), !(!G && C === X)); )
                      C === o ? G = !G : G ? G = false : C === x && S === g && re();
                    K = O.slice(z, R + 1), Z = K.split(`
`), Q = Z.length - 1, Q > 0 ? (M = F + Q, Y = R - Z[Q].length) : (M = F, Y = T), b = ["string", O.slice(z, R + 1), F, z - T, M, R - Y], T = Y, F = M, z = R;
                    break;
                  case _:
                    N.lastIndex = z + 1, N.test(O), N.lastIndex === 0 ? R = O.length - 1 : R = N.lastIndex - 2, b = ["at-word", O.slice(z, R + 1), F, z - T, F, R - T], z = R;
                    break;
                  case o:
                    for (R = z, J = true; O.charCodeAt(R + 1) === o; )
                      R += 1, J = !J;
                    if (C = O.charCodeAt(R + 1), J && C !== h && C !== p && C !== l && C !== c && C !== t3 && C !== m && (R += 1, $2.test(O.charAt(R)))) {
                      for (; $2.test(O.charAt(R + 1)); )
                        R += 1;
                      O.charCodeAt(R + 1) === p && (R += 1);
                    }
                    b = ["word", O.slice(z, R + 1), F, z - T, F, R - T], z = R;
                    break;
                  default:
                    S = O.charCodeAt(z + 1), C === x && S === g ? (R = z, re(), K = O.slice(z, R + 1), Z = K.split(`
`), Q = Z.length - 1, Q > 0 ? (M = F + Q, Y = R - Z[Q].length) : (M = F, Y = T), b = ["word", K, F, z - T, M, R - Y], T = Y, F = M, z = R) : C === h && S === w ? (R = O.indexOf("*/", z + 2) + 1, R === 0 && (j ? R = O.length : ue("comment")), K = O.slice(z, R + 1), Z = K.split(`
`), Q = Z.length - 1, Q > 0 ? (M = F + Q, Y = R - Z[Q].length) : (M = F, Y = T), b = ["comment", K, F, z - T, M, R - Y], T = Y, F = M, z = R) : C === h && S === h ? (H.lastIndex = z + 1, H.test(O), H.lastIndex === 0 ? R = O.length - 1 : R = H.lastIndex - 2, K = O.slice(z, R + 1), b = ["comment", K, F, z - T, F, R - T, "inline"], z = R) : (I.lastIndex = z + 1, I.test(O), I.lastIndex === 0 ? R = O.length - 1 : R = I.lastIndex - 2, b = ["word", O.slice(z, R + 1), F, z - T, F, R - T], ee.push(b), z = R);
                    break;
                }
                return z++, b;
              }
            }
            function oe(ie) {
              te.push(ie);
            }
            return { back: oe, nextToken: ne, endOfFile: le };
          };
        } }), Kf = P({ "node_modules/postcss-scss/lib/scss-parser.js"(e, n) {
          "use strict";
          A();
          function i(m, c) {
            m.prototype = Object.create(c.prototype), m.prototype.constructor = m, m.__proto__ = c;
          }
          var u = kr(), o = $t(), h = Hf(), l = Jf(), p = function(m) {
            i(c, m);
            function c() {
              return m.apply(this, arguments) || this;
            }
            var t3 = c.prototype;
            return t3.createTokenizer = function() {
              this.tokenizer = l(this.input);
            }, t3.rule = function(a) {
              for (var s = false, f = 0, g = "", w = a, v = Array.isArray(w), y = 0, w = v ? w : w[Symbol.iterator](); ; ) {
                var d;
                if (v) {
                  if (y >= w.length)
                    break;
                  d = w[y++];
                } else {
                  if (y = w.next(), y.done)
                    break;
                  d = y.value;
                }
                var _ = d;
                if (s)
                  _[0] !== "comment" && _[0] !== "{" && (g += _[1]);
                else {
                  if (_[0] === "space" && _[1].indexOf(`
`) !== -1)
                    break;
                  _[0] === "(" ? f += 1 : _[0] === ")" ? f -= 1 : f === 0 && _[0] === ":" && (s = true);
                }
              }
              if (!s || g.trim() === "" || /^[a-zA-Z-:#]/.test(g))
                m.prototype.rule.call(this, a);
              else {
                a.pop();
                var k = new h();
                this.init(k);
                var x = a[a.length - 1];
                for (x[4] ? k.source.end = { line: x[4], column: x[5] } : k.source.end = { line: x[2], column: x[3] }; a[0][0] !== "word"; )
                  k.raws.before += a.shift()[1];
                for (k.source.start = { line: a[0][2], column: a[0][3] }, k.prop = ""; a.length; ) {
                  var N = a[0][0];
                  if (N === ":" || N === "space" || N === "comment")
                    break;
                  k.prop += a.shift()[1];
                }
                k.raws.between = "";
                for (var I; a.length; )
                  if (I = a.shift(), I[0] === ":") {
                    k.raws.between += I[1];
                    break;
                  } else
                    k.raws.between += I[1];
                (k.prop[0] === "_" || k.prop[0] === "*") && (k.raws.before += k.prop[0], k.prop = k.prop.slice(1)), k.raws.between += this.spacesAndCommentsFromStart(a), this.precheckMissedSemicolon(a);
                for (var W = a.length - 1; W > 0; W--) {
                  if (I = a[W], I[1] === "!important") {
                    k.important = true;
                    var $2 = this.stringFrom(a, W);
                    $2 = this.spacesFromEnd(a) + $2, $2 !== " !important" && (k.raws.important = $2);
                    break;
                  } else if (I[1] === "important") {
                    for (var H = a.slice(0), D = "", V = W; V > 0; V--) {
                      var B = H[V][0];
                      if (D.trim().indexOf("!") === 0 && B !== "space")
                        break;
                      D = H.pop()[1] + D;
                    }
                    D.trim().indexOf("!") === 0 && (k.important = true, k.raws.important = D, a = H);
                  }
                  if (I[0] !== "space" && I[0] !== "comment")
                    break;
                }
                this.raw(k, "value", a), k.value.indexOf(":") !== -1 && this.checkMissedSemicolon(a), this.current = k;
              }
            }, t3.comment = function(a) {
              if (a[6] === "inline") {
                var s = new u();
                this.init(s, a[2], a[3]), s.raws.inline = true, s.source.end = { line: a[4], column: a[5] };
                var f = a[1].slice(2);
                if (/^\s*$/.test(f))
                  s.text = "", s.raws.left = f, s.raws.right = "";
                else {
                  var g = f.match(/^(\s*)([^]*[^\s])(\s*)$/), v = g[2].replace(/(\*\/|\/\*)/g, "*//*");
                  s.text = v, s.raws.left = g[1], s.raws.right = g[3], s.raws.text = g[2];
                }
              } else
                m.prototype.comment.call(this, a);
            }, t3.raw = function(a, s, f) {
              if (m.prototype.raw.call(this, a, s, f), a.raws[s]) {
                var g = a.raws[s].raw;
                a.raws[s].raw = f.reduce(function(v, y) {
                  if (y[0] === "comment" && y[6] === "inline") {
                    var w = y[1].slice(2).replace(/(\*\/|\/\*)/g, "*//*");
                    return v + "/*" + w + "*/";
                  } else
                    return v + y[1];
                }, ""), g !== a.raws[s].raw && (a.raws[s].scss = g);
              }
            }, c;
          }(o);
          n.exports = p;
        } }), Qf = P({ "node_modules/postcss-scss/lib/scss-parse.js"(e, n) {
          "use strict";
          A();
          var i = xr(), u = Kf();
          n.exports = function(h, l) {
            var p = new i(h, l), m = new u(p);
            return m.parse(), m.root;
          };
        } }), Yf = P({ "node_modules/postcss-scss/lib/scss-syntax.js"(e, n) {
          "use strict";
          A();
          var i = Gf(), u = Qf();
          n.exports = { parse: u, stringify: i };
        } });
        A();
        var Xf = Sl(), mt = Us(), Zf = $s(), { hasPragma: ep } = Cl(), { locStart: rp, locEnd: tp } = no(), { calculateLoc: np, replaceQuotesInInlineComments: ip } = no(), sp = Dl(), op = Ll(), gt = zl(), da = Bl(), ap = Fl(), up = Ul(), cp = $l(), lp = Wl(), fp = (e) => {
          for (; e.parent; )
            e = e.parent;
          return e;
        };
        function pp(e, n) {
          let { nodes: i } = e, u = { open: null, close: null, groups: [], type: "paren_group" }, o = [u], h = u, l = { groups: [], type: "comma_group" }, p = [l];
          for (let m = 0; m < i.length; ++m) {
            let c = i[m];
            if (da(n.parser, c.value) && c.type === "number" && c.unit === ".." && mt(c.value) === "." && (c.value = c.value.slice(0, -1), c.unit = "..."), c.type === "func" && c.value === "selector" && (c.group.groups = [Re(fp(e).text.slice(c.group.open.sourceIndex + 1, c.group.close.sourceIndex))]), c.type === "func" && c.value === "url") {
              let t3 = c.group && c.group.groups || [], r = [];
              for (let a = 0; a < t3.length; a++) {
                let s = t3[a];
                s.type === "comma_group" ? r = [...r, ...s.groups] : r.push(s);
              }
              if (sp(r) || !op(r) && !up(r[0])) {
                let a = cp({ groups: c.group.groups });
                c.group.groups = [a.trim()];
              }
            }
            if (c.type === "paren" && c.value === "(")
              u = { open: c, close: null, groups: [], type: "paren_group" }, o.push(u), l = { groups: [], type: "comma_group" }, p.push(l);
            else if (c.type === "paren" && c.value === ")") {
              if (l.groups.length > 0 && u.groups.push(l), u.close = c, p.length === 1)
                throw new Error("Unbalanced parenthesis");
              p.pop(), l = mt(p), l.groups.push(u), o.pop(), u = mt(o);
            } else
              c.type === "comma" ? (u.groups.push(l), l = { groups: [], type: "comma_group" }, p[p.length - 1] = l) : l.groups.push(c);
          }
          return l.groups.length > 0 && u.groups.push(l), h;
        }
        function vr(e) {
          return e.type === "paren_group" && !e.open && !e.close && e.groups.length === 1 || e.type === "comma_group" && e.groups.length === 1 ? vr(e.groups[0]) : e.type === "paren_group" || e.type === "comma_group" ? Object.assign(Object.assign({}, e), {}, { groups: e.groups.map(vr) }) : e;
        }
        function Xe(e, n, i) {
          if (e && typeof e == "object") {
            delete e.parent;
            for (let u in e)
              Xe(e[u], n, i), u === "type" && typeof e[u] == "string" && !e[u].startsWith(n) && (!i || !i.test(e[u])) && (e[u] = n + e[u]);
          }
          return e;
        }
        function va(e) {
          if (e && typeof e == "object") {
            delete e.parent;
            for (let n in e)
              va(e[n]);
            !Array.isArray(e) && e.value && !e.type && (e.type = "unknown");
          }
          return e;
        }
        function ma(e, n) {
          if (e && typeof e == "object") {
            for (let i in e)
              i !== "parent" && (ma(e[i], n), i === "nodes" && (e.group = vr(pp(e, n)), delete e[i]));
            delete e.parent;
          }
          return e;
        }
        function Pe(e, n) {
          let i = gf(), u = null;
          try {
            u = i(e, { loose: true }).parse();
          } catch {
            return { type: "value-unknown", value: e };
          }
          u.text = e;
          let o = ma(u, n);
          return Xe(o, "value-", /^selector-/);
        }
        function Re(e) {
          if (/\/\/|\/\*/.test(e))
            return { type: "selector-unknown", value: e.trim() };
          let n = xf(), i = null;
          try {
            n((u) => {
              i = u;
            }).process(e);
          } catch {
            return { type: "selector-unknown", value: e };
          }
          return Xe(i, "selector-");
        }
        function hp(e) {
          let n = kf().default, i = null;
          try {
            i = n(e);
          } catch {
            return { type: "selector-unknown", value: e };
          }
          return Xe(va(i), "media-");
        }
        var dp = /(\s*)(!default).*$/, vp = /(\s*)(!global).*$/;
        function ga(e, n) {
          if (e && typeof e == "object") {
            delete e.parent;
            for (let m in e)
              ga(e[m], n);
            if (!e.type)
              return e;
            e.raws || (e.raws = {});
            let h = "";
            if (typeof e.selector == "string") {
              var i;
              h = e.raws.selector ? (i = e.raws.selector.scss) !== null && i !== void 0 ? i : e.raws.selector.raw : e.selector, e.raws.between && e.raws.between.trim().length > 0 && (h += e.raws.between), e.raws.selector = h;
            }
            let l = "";
            if (typeof e.value == "string") {
              var u;
              l = e.raws.value ? (u = e.raws.value.scss) !== null && u !== void 0 ? u : e.raws.value.raw : e.value, l = l.trim(), e.raws.value = l;
            }
            let p = "";
            if (typeof e.params == "string") {
              var o;
              p = e.raws.params ? (o = e.raws.params.scss) !== null && o !== void 0 ? o : e.raws.params.raw : e.params, e.raws.afterName && e.raws.afterName.trim().length > 0 && (p = e.raws.afterName + p), e.raws.between && e.raws.between.trim().length > 0 && (p = p + e.raws.between), p = p.trim(), e.raws.params = p;
            }
            if (h.trim().length > 0)
              return h.startsWith("@") && h.endsWith(":") ? e : e.mixin ? (e.selector = Pe(h, n), e) : (ap(e) && (e.isSCSSNesterProperty = true), e.selector = Re(h), e);
            if (l.length > 0) {
              let m = l.match(dp);
              m && (l = l.slice(0, m.index), e.scssDefault = true, m[0].trim() !== "!default" && (e.raws.scssDefault = m[0]));
              let c = l.match(vp);
              if (c && (l = l.slice(0, c.index), e.scssGlobal = true, c[0].trim() !== "!global" && (e.raws.scssGlobal = c[0])), l.startsWith("progid:"))
                return { type: "value-unknown", value: l };
              e.value = Pe(l, n);
            }
            if (gt(n) && e.type === "css-decl" && l.startsWith("extend(") && (e.extend || (e.extend = e.raws.between === ":"), e.extend && !e.selector && (delete e.value, e.selector = Re(l.slice(7, -1)))), e.type === "css-atrule") {
              if (gt(n)) {
                if (e.mixin) {
                  let m = e.raws.identifier + e.name + e.raws.afterName + e.raws.params;
                  return e.selector = Re(m), delete e.params, e;
                }
                if (e.function)
                  return e;
              }
              if (n.parser === "css" && e.name === "custom-selector") {
                let m = e.params.match(/:--\S+\s+/)[0].trim();
                return e.customSelector = m, e.selector = Re(e.params.slice(m.length).trim()), delete e.params, e;
              }
              if (gt(n)) {
                if (e.name.includes(":") && !e.params) {
                  e.variable = true;
                  let m = e.name.split(":");
                  e.name = m[0], e.value = Pe(m.slice(1).join(":"), n);
                }
                if (!["page", "nest", "keyframes"].includes(e.name) && e.params && e.params[0] === ":") {
                  e.variable = true;
                  let m = e.params.slice(1);
                  m && (e.value = Pe(m, n)), e.raws.afterName += ":";
                }
                if (e.variable)
                  return delete e.params, e.value || delete e.value, e;
              }
            }
            if (e.type === "css-atrule" && p.length > 0) {
              let { name: m } = e, c = e.name.toLowerCase();
              return m === "warn" || m === "error" ? (e.params = { type: "media-unknown", value: p }, e) : m === "extend" || m === "nest" ? (e.selector = Re(p), delete e.params, e) : m === "at-root" ? (/^\(\s*(?:without|with)\s*:.+\)$/s.test(p) ? e.params = Pe(p, n) : (e.selector = Re(p), delete e.params), e) : lp(c) ? (e.import = true, delete e.filename, e.params = Pe(p, n), e) : ["namespace", "supports", "if", "else", "for", "each", "while", "debug", "mixin", "include", "function", "return", "define-mixin", "add-mixin"].includes(m) ? (p = p.replace(/(\$\S+?)(\s+)?\.{3}/, "$1...$2"), p = p.replace(/^(?!if)(\S+)(\s+)\(/, "$1($2"), e.value = Pe(p, n), delete e.params, e) : ["media", "custom-media"].includes(c) ? p.includes("#{") ? { type: "media-unknown", value: p } : (e.params = hp(p), e) : (e.params = p, e);
            }
          }
          return e;
        }
        function ya(e, n, i) {
          let u = Zf(n), { frontMatter: o } = u;
          n = u.content;
          let h;
          try {
            h = e(n);
          } catch (l) {
            let { name: p, reason: m, line: c, column: t3 } = l;
            throw typeof c != "number" ? l : Xf(`${p}: ${m}`, { start: { line: c, column: t3 } });
          }
          return h = ga(Xe(h, "css-"), i), np(h, n), o && (o.source = { startOffset: 0, endOffset: o.raw.length }, h.nodes.unshift(o)), h;
        }
        function mp(e, n) {
          let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, o = da(i.parser, e) ? [Tt, Ot] : [Ot, Tt], h;
          for (let l of o)
            try {
              return l(e, n, i);
            } catch (p) {
              h = h || p;
            }
          if (h)
            throw h;
        }
        function Ot(e, n) {
          let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, u = Wf();
          return ya((o) => u.parse(ip(o)), e, i);
        }
        function Tt(e, n) {
          let i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, { parse: u } = Yf();
          return ya(u, e, i);
        }
        var yt = { astFormat: "postcss", hasPragma: ep, locStart: rp, locEnd: tp };
        wa.exports = { parsers: { css: Object.assign(Object.assign({}, yt), {}, { parse: mp }), less: Object.assign(Object.assign({}, yt), {}, { parse: Ot }), scss: Object.assign(Object.assign({}, yt), {}, { parse: Tt }) } };
      });
      return gp();
    });
  }
});

// node_modules/prettier/parser-glimmer.js
var require_parser_glimmer = __commonJS({
  "node_modules/prettier/parser-glimmer.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.glimmer = e();
      }
    })(function() {
      "use strict";
      var it2 = (t3, f) => () => (f || t3((f = { exports: {} }).exports, f), f.exports);
      var Zt = it2((nr, $e) => {
        var xe = Object.getOwnPropertyNames, st = (t3, f) => function() {
          return t3 && (f = (0, t3[xe(t3)[0]])(t3 = 0)), f;
        }, I = (t3, f) => function() {
          return f || (0, t3[xe(t3)[0]])((f = { exports: {} }).exports, f), f.exports;
        }, F = st({ "<define:process>"() {
        } }), at = I({ "node_modules/lines-and-columns/build/index.cjs"(t3) {
          "use strict";
          F(), t3.__esModule = true, t3.LinesAndColumns = void 0;
          var f = `
`, h = "\r", d = function() {
            function c(o) {
              this.length = o.length;
              for (var e = [0], r = 0; r < o.length; )
                switch (o[r]) {
                  case f:
                    r += f.length, e.push(r);
                    break;
                  case h:
                    r += h.length, o[r] === f && (r += f.length), e.push(r);
                    break;
                  default:
                    r++;
                    break;
                }
              this.offsets = e;
            }
            return c.prototype.locationForIndex = function(o) {
              if (o < 0 || o > this.length)
                return null;
              for (var e = 0, r = this.offsets; r[e + 1] <= o; )
                e++;
              var a = o - r[e];
              return { line: e, column: a };
            }, c.prototype.indexForLocation = function(o) {
              var e = o.line, r = o.column;
              return e < 0 || e >= this.offsets.length || r < 0 || r > this.lengthOfLine(e) ? null : this.offsets[e] + r;
            }, c.prototype.lengthOfLine = function(o) {
              var e = this.offsets[o], r = o === this.offsets.length - 1 ? this.length : this.offsets[o + 1];
              return r - e;
            }, c;
          }();
          t3.LinesAndColumns = d;
        } }), ut = I({ "src/common/parser-create-error.js"(t3, f) {
          "use strict";
          F();
          function h(d, c) {
            let o = new SyntaxError(d + " (" + c.start.line + ":" + c.start.column + ")");
            return o.loc = c, o;
          }
          f.exports = h;
        } }), ot = I({ "src/language-handlebars/loc.js"(t3, f) {
          "use strict";
          F();
          function h(c) {
            return c.loc.start.offset;
          }
          function d(c) {
            return c.loc.end.offset;
          }
          f.exports = { locStart: h, locEnd: d };
        } }), fe = I({ "node_modules/@glimmer/env/dist/commonjs/es5/index.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = t3.DEBUG = false, h = t3.CI = false;
        } }), lt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/array-utils.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.emptyArray = h, t3.isEmptyArray = o, t3.EMPTY_NUMBER_ARRAY = t3.EMPTY_STRING_ARRAY = t3.EMPTY_ARRAY = void 0;
          var f = Object.freeze([]);
          t3.EMPTY_ARRAY = f;
          function h() {
            return f;
          }
          var d = h();
          t3.EMPTY_STRING_ARRAY = d;
          var c = h();
          t3.EMPTY_NUMBER_ARRAY = c;
          function o(e) {
            return e === f;
          }
        } }), Pe = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/assert.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.debugAssert = h, t3.prodAssert = d, t3.deprecate = c, t3.default = void 0;
          var f = X();
          function h(e, r) {
            if (!e)
              throw new Error(r || "assertion failure");
          }
          function d() {
          }
          function c(e) {
            f.LOCAL_LOGGER.warn(`DEPRECATION: ${e}`);
          }
          var o = h;
          t3.default = o;
        } }), ct = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/collections.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.dict = f, t3.isDict = h, t3.isObject = d, t3.StackImpl = void 0;
          function f() {
            return /* @__PURE__ */ Object.create(null);
          }
          function h(o) {
            return o != null;
          }
          function d(o) {
            return typeof o == "function" || typeof o == "object" && o !== null;
          }
          var c = class {
            constructor() {
              let o = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [];
              this.current = null, this.stack = o;
            }
            get size() {
              return this.stack.length;
            }
            push(o) {
              this.current = o, this.stack.push(o);
            }
            pop() {
              let o = this.stack.pop(), e = this.stack.length;
              return this.current = e === 0 ? null : this.stack[e - 1], o === void 0 ? null : o;
            }
            nth(o) {
              let e = this.stack.length;
              return e < o ? null : this.stack[e - o];
            }
            isEmpty() {
              return this.stack.length === 0;
            }
            toArray() {
              return this.stack;
            }
          };
          t3.StackImpl = c;
        } }), ht = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/dom.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.clearElement = f;
          function f(h) {
            let d = h.firstChild;
            for (; d; ) {
              let c = d.nextSibling;
              h.removeChild(d), d = c;
            }
          }
        } }), dt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/is-serialization-first-node.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isSerializationFirstNode = h, t3.SERIALIZATION_FIRST_NODE_STRING = void 0;
          var f = "%+b:0%";
          t3.SERIALIZATION_FIRST_NODE_STRING = f;
          function h(d) {
            return d.nodeValue === f;
          }
        } }), pt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/object-utils.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.fillNulls = h, t3.values = d, t3.assign = void 0;
          var f = Object.assign;
          t3.assign = f;
          function h(c) {
            let o = new Array(c);
            for (let e = 0; e < c; e++)
              o[e] = null;
            return o;
          }
          function d(c) {
            let o = [];
            for (let e in c)
              o.push(c[e]);
            return o;
          }
        } }), je = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/intern.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = f;
          function f(h) {
            let d = {};
            d[h] = 1;
            for (let c in d)
              if (c === h)
                return c;
            return h;
          }
        } }), me = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/platform-utils.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.keys = o, t3.unwrap = e, t3.expect = r, t3.unreachable = a, t3.exhausted = p, t3.enumerableSymbol = s, t3.symbol = t3.tuple = t3.HAS_NATIVE_SYMBOL = t3.HAS_NATIVE_PROXY = void 0;
          var f = h(je());
          function h(i) {
            return i && i.__esModule ? i : { default: i };
          }
          var d = typeof Proxy == "function";
          t3.HAS_NATIVE_PROXY = d;
          var c = function() {
            return typeof Symbol != "function" ? false : typeof Symbol() == "symbol";
          }();
          t3.HAS_NATIVE_SYMBOL = c;
          function o(i) {
            return Object.keys(i);
          }
          function e(i) {
            if (i == null)
              throw new Error("Expected value to be present");
            return i;
          }
          function r(i, l) {
            if (i == null)
              throw new Error(l);
            return i;
          }
          function a() {
            let i = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "unreachable";
            return new Error(i);
          }
          function p(i) {
            throw new Error(`Exhausted ${i}`);
          }
          var n = function() {
            for (var i = arguments.length, l = new Array(i), b = 0; b < i; b++)
              l[b] = arguments[b];
            return l;
          };
          t3.tuple = n;
          function s(i) {
            return (0, f.default)(`__${i}${Math.floor(Math.random() * Date.now())}__`);
          }
          var u = c ? Symbol : s;
          t3.symbol = u;
        } }), ft = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/string.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.strip = f;
          function f(h) {
            let d = "";
            for (var c = arguments.length, o = new Array(c > 1 ? c - 1 : 0), e = 1; e < c; e++)
              o[e - 1] = arguments[e];
            for (let n = 0; n < h.length; n++) {
              let s = h[n], u = o[n] !== void 0 ? String(o[n]) : "";
              d += `${s}${u}`;
            }
            let r = d.split(`
`);
            for (; r.length && r[0].match(/^\s*$/); )
              r.shift();
            for (; r.length && r[r.length - 1].match(/^\s*$/); )
              r.pop();
            let a = 1 / 0;
            for (let n of r) {
              let s = n.match(/^\s*/)[0].length;
              a = Math.min(a, s);
            }
            let p = [];
            for (let n of r)
              p.push(n.slice(a));
            return p.join(`
`);
          }
        } }), mt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/immediate.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isHandle = h, t3.isNonPrimitiveHandle = d, t3.constants = c, t3.isSmallInt = o, t3.encodeNegative = e, t3.decodeNegative = r, t3.encodePositive = a, t3.decodePositive = p, t3.encodeHandle = n, t3.decodeHandle = s, t3.encodeImmediate = u, t3.decodeImmediate = i;
          var f = Pe();
          function h(l) {
            return l >= 0;
          }
          function d(l) {
            return l > 3;
          }
          function c() {
            for (var l = arguments.length, b = new Array(l), P = 0; P < l; P++)
              b[P] = arguments[P];
            return [false, true, null, void 0, ...b];
          }
          function o(l) {
            return l % 1 === 0 && l <= 536870911 && l >= -536870912;
          }
          function e(l) {
            return l & -536870913;
          }
          function r(l) {
            return l | 536870912;
          }
          function a(l) {
            return ~l;
          }
          function p(l) {
            return ~l;
          }
          function n(l) {
            return l;
          }
          function s(l) {
            return l;
          }
          function u(l) {
            return l |= 0, l < 0 ? e(l) : a(l);
          }
          function i(l) {
            return l |= 0, l > -536870913 ? p(l) : r(l);
          }
          [1, 2, 3].forEach((l) => l), [1, -1].forEach((l) => i(u(l)));
        } }), gt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/template.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.unwrapHandle = f, t3.unwrapTemplate = h, t3.extractHandle = d, t3.isOkHandle = c, t3.isErrHandle = o;
          function f(e) {
            if (typeof e == "number")
              return e;
            {
              let r = e.errors[0];
              throw new Error(`Compile Error: ${r.problem} @ ${r.span.start}..${r.span.end}`);
            }
          }
          function h(e) {
            if (e.result === "error")
              throw new Error(`Compile Error: ${e.problem} @ ${e.span.start}..${e.span.end}`);
            return e;
          }
          function d(e) {
            return typeof e == "number" ? e : e.handle;
          }
          function c(e) {
            return typeof e == "number";
          }
          function o(e) {
            return typeof e == "number";
          }
        } }), bt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/weak-set.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = typeof WeakSet == "function" ? WeakSet : class {
            constructor() {
              this._map = /* @__PURE__ */ new WeakMap();
            }
            add(d) {
              return this._map.set(d, true), this;
            }
            delete(d) {
              return this._map.delete(d);
            }
            has(d) {
              return this._map.has(d);
            }
          };
          t3.default = f;
        } }), vt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/simple-cast.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.castToSimple = h, t3.castToBrowser = d, t3.checkNode = r;
          var f = me();
          function h(p) {
            return o(p) || e(p), p;
          }
          function d(p, n) {
            if (p == null)
              return null;
            if (typeof document === void 0)
              throw new Error("Attempted to cast to a browser node in a non-browser context");
            if (o(p))
              return p;
            if (p.ownerDocument !== document)
              throw new Error("Attempted to cast to a browser node with a node that was not created from this document");
            return r(p, n);
          }
          function c(p, n) {
            return new Error(`cannot cast a ${p} into ${n}`);
          }
          function o(p) {
            return p.nodeType === 9;
          }
          function e(p) {
            return p.nodeType === 1;
          }
          function r(p, n) {
            let s = false;
            if (p !== null)
              if (typeof n == "string")
                s = a(p, n);
              else if (Array.isArray(n))
                s = n.some((u) => a(p, u));
              else
                throw (0, f.unreachable)();
            if (s)
              return p;
            throw c(`SimpleElement(${p})`, n);
          }
          function a(p, n) {
            switch (n) {
              case "NODE":
                return true;
              case "HTML":
                return p instanceof HTMLElement;
              case "SVG":
                return p instanceof SVGElement;
              case "ELEMENT":
                return p instanceof Element;
              default:
                if (n.toUpperCase() === n)
                  throw new Error("BUG: this code is missing handling for a generic node type");
                return p instanceof Element && p.tagName.toLowerCase() === n;
            }
          }
        } }), yt = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/present.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isPresent = f, t3.ifPresent = h, t3.toPresentOption = d, t3.assertPresent = c, t3.mapPresent = o;
          function f(e) {
            return e.length > 0;
          }
          function h(e, r, a) {
            return f(e) ? r(e) : a();
          }
          function d(e) {
            return f(e) ? e : null;
          }
          function c(e) {
            let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "unexpected empty list";
            if (!f(e))
              throw new Error(r);
          }
          function o(e, r) {
            if (e === null)
              return null;
            let a = [];
            for (let p of e)
              a.push(r(p));
            return a;
          }
        } }), At = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/untouchable-this.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = d;
          var f = fe(), h = me();
          function d(c) {
            let o = null;
            if (f.DEBUG && h.HAS_NATIVE_PROXY) {
              let e = (r) => {
                throw new Error(`You accessed \`this.${String(r)}\` from a function passed to the ${c}, but the function itself was not bound to a valid \`this\` context. Consider updating to use a bound function (for instance, use an arrow function, \`() => {}\`).`);
              };
              o = new Proxy({}, { get(r, a) {
                e(a);
              }, set(r, a) {
                return e(a), false;
              }, has(r, a) {
                return e(a), false;
              } });
            }
            return o;
          }
        } }), Et = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/debug-to-string.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = fe(), h;
          if (f.DEBUG) {
            let c = (r) => {
              let a = r.name;
              if (a === void 0) {
                let p = Function.prototype.toString.call(r).match(/function (\w+)\s*\(/);
                a = p && p[1] || "";
              }
              return a.replace(/^bound /, "");
            }, o = (r) => {
              let a, p;
              return r.constructor && typeof r.constructor == "function" && (p = c(r.constructor)), "toString" in r && r.toString !== Object.prototype.toString && r.toString !== Function.prototype.toString && (a = r.toString()), a && a.match(/<.*:ember\d+>/) && p && p[0] !== "_" && p.length > 2 && p !== "Class" ? a.replace(/<.*:/, `<${p}:`) : a || p;
            }, e = (r) => String(r);
            h = (r) => typeof r == "function" ? c(r) || "(unknown function)" : typeof r == "object" && r !== null ? o(r) || "(unknown object)" : e(r);
          }
          var d = h;
          t3.default = d;
        } }), _t = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/lib/debug-steps.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.logStep = t3.verifySteps = t3.endTestSteps = t3.beginTestSteps = void 0;
          var f = d(Pe()), h = me();
          function d(a) {
            return a && a.__esModule ? a : { default: a };
          }
          var c;
          t3.beginTestSteps = c;
          var o;
          t3.endTestSteps = o;
          var e;
          t3.verifySteps = e;
          var r;
          t3.logStep = r;
        } }), X = I({ "node_modules/@glimmer/util/dist/commonjs/es2017/index.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = { LOCAL_LOGGER: true, LOGGER: true, assertNever: true, assert: true, deprecate: true, dict: true, isDict: true, isObject: true, Stack: true, isSerializationFirstNode: true, SERIALIZATION_FIRST_NODE_STRING: true, assign: true, fillNulls: true, values: true, _WeakSet: true, castToSimple: true, castToBrowser: true, checkNode: true, intern: true, buildUntouchableThis: true, debugToString: true, beginTestSteps: true, endTestSteps: true, logStep: true, verifySteps: true };
          t3.assertNever = x, Object.defineProperty(t3, "assert", { enumerable: true, get: function() {
            return d.default;
          } }), Object.defineProperty(t3, "deprecate", { enumerable: true, get: function() {
            return d.deprecate;
          } }), Object.defineProperty(t3, "dict", { enumerable: true, get: function() {
            return c.dict;
          } }), Object.defineProperty(t3, "isDict", { enumerable: true, get: function() {
            return c.isDict;
          } }), Object.defineProperty(t3, "isObject", { enumerable: true, get: function() {
            return c.isObject;
          } }), Object.defineProperty(t3, "Stack", { enumerable: true, get: function() {
            return c.StackImpl;
          } }), Object.defineProperty(t3, "isSerializationFirstNode", { enumerable: true, get: function() {
            return e.isSerializationFirstNode;
          } }), Object.defineProperty(t3, "SERIALIZATION_FIRST_NODE_STRING", { enumerable: true, get: function() {
            return e.SERIALIZATION_FIRST_NODE_STRING;
          } }), Object.defineProperty(t3, "assign", { enumerable: true, get: function() {
            return r.assign;
          } }), Object.defineProperty(t3, "fillNulls", { enumerable: true, get: function() {
            return r.fillNulls;
          } }), Object.defineProperty(t3, "values", { enumerable: true, get: function() {
            return r.values;
          } }), Object.defineProperty(t3, "_WeakSet", { enumerable: true, get: function() {
            return u.default;
          } }), Object.defineProperty(t3, "castToSimple", { enumerable: true, get: function() {
            return i.castToSimple;
          } }), Object.defineProperty(t3, "castToBrowser", { enumerable: true, get: function() {
            return i.castToBrowser;
          } }), Object.defineProperty(t3, "checkNode", { enumerable: true, get: function() {
            return i.checkNode;
          } }), Object.defineProperty(t3, "intern", { enumerable: true, get: function() {
            return b.default;
          } }), Object.defineProperty(t3, "buildUntouchableThis", { enumerable: true, get: function() {
            return P.default;
          } }), Object.defineProperty(t3, "debugToString", { enumerable: true, get: function() {
            return E.default;
          } }), Object.defineProperty(t3, "beginTestSteps", { enumerable: true, get: function() {
            return v.beginTestSteps;
          } }), Object.defineProperty(t3, "endTestSteps", { enumerable: true, get: function() {
            return v.endTestSteps;
          } }), Object.defineProperty(t3, "logStep", { enumerable: true, get: function() {
            return v.logStep;
          } }), Object.defineProperty(t3, "verifySteps", { enumerable: true, get: function() {
            return v.verifySteps;
          } }), t3.LOGGER = t3.LOCAL_LOGGER = void 0;
          var h = lt();
          Object.keys(h).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return h[w];
            } });
          });
          var d = g(Pe()), c = ct(), o = ht();
          Object.keys(o).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return o[w];
            } });
          });
          var e = dt(), r = pt(), a = me();
          Object.keys(a).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return a[w];
            } });
          });
          var p = ft();
          Object.keys(p).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return p[w];
            } });
          });
          var n = mt();
          Object.keys(n).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return n[w];
            } });
          });
          var s = gt();
          Object.keys(s).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return s[w];
            } });
          });
          var u = _(bt()), i = vt(), l = yt();
          Object.keys(l).forEach(function(w) {
            w === "default" || w === "__esModule" || Object.prototype.hasOwnProperty.call(f, w) || Object.defineProperty(t3, w, { enumerable: true, get: function() {
              return l[w];
            } });
          });
          var b = _(je()), P = _(At()), E = _(Et()), v = _t();
          function _(w) {
            return w && w.__esModule ? w : { default: w };
          }
          function y() {
            if (typeof WeakMap != "function")
              return null;
            var w = /* @__PURE__ */ new WeakMap();
            return y = function() {
              return w;
            }, w;
          }
          function g(w) {
            if (w && w.__esModule)
              return w;
            if (w === null || typeof w != "object" && typeof w != "function")
              return { default: w };
            var H = y();
            if (H && H.has(w))
              return H.get(w);
            var m = {}, C = Object.defineProperty && Object.getOwnPropertyDescriptor;
            for (var S in w)
              if (Object.prototype.hasOwnProperty.call(w, S)) {
                var R = C ? Object.getOwnPropertyDescriptor(w, S) : null;
                R && (R.get || R.set) ? Object.defineProperty(m, S, R) : m[S] = w[S];
              }
            return m.default = w, H && H.set(w, m), m;
          }
          var L = console;
          t3.LOCAL_LOGGER = L;
          var j = console;
          t3.LOGGER = j;
          function x(w) {
            let H = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "unexpected unreachable branch";
            throw j.log("unreachable", w), j.log(`${H} :: ${JSON.stringify(w)} (${w})`), new Error("code reached unreachable");
          }
        } }), ge = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/location.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isLocatedWithPositionsArray = a, t3.isLocatedWithPositions = p, t3.BROKEN_LOCATION = t3.NON_EXISTENT_LOCATION = t3.TEMPORARY_LOCATION = t3.SYNTHETIC = t3.SYNTHETIC_LOCATION = t3.UNKNOWN_POSITION = void 0;
          var f = X(), h = Object.freeze({ line: 1, column: 0 });
          t3.UNKNOWN_POSITION = h;
          var d = Object.freeze({ source: "(synthetic)", start: h, end: h });
          t3.SYNTHETIC_LOCATION = d;
          var c = d;
          t3.SYNTHETIC = c;
          var o = Object.freeze({ source: "(temporary)", start: h, end: h });
          t3.TEMPORARY_LOCATION = o;
          var e = Object.freeze({ source: "(nonexistent)", start: h, end: h });
          t3.NON_EXISTENT_LOCATION = e;
          var r = Object.freeze({ source: "(broken)", start: h, end: h });
          t3.BROKEN_LOCATION = r;
          function a(n) {
            return (0, f.isPresent)(n) && n.every(p);
          }
          function p(n) {
            return n.loc !== void 0;
          }
        } }), le = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/slice.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.SourceSlice = void 0;
          var f = ue(), h = class {
            constructor(d) {
              this.loc = d.loc, this.chars = d.chars;
            }
            static synthetic(d) {
              let c = f.SourceSpan.synthetic(d);
              return new h({ loc: c, chars: d });
            }
            static load(d, c) {
              return new h({ loc: f.SourceSpan.load(d, c[1]), chars: c[0] });
            }
            getString() {
              return this.chars;
            }
            serialize() {
              return [this.chars, this.loc.serialize()];
            }
          };
          t3.SourceSlice = h;
        } }), Me = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/loc/match.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.match = e, t3.IsInvisible = t3.MatchAny = void 0;
          var f = X(), h = "MATCH_ANY";
          t3.MatchAny = h;
          var d = "IS_INVISIBLE";
          t3.IsInvisible = d;
          var c = class {
            constructor(p) {
              this._whens = p;
            }
            first(p) {
              for (let n of this._whens) {
                let s = n.match(p);
                if ((0, f.isPresent)(s))
                  return s[0];
              }
              return null;
            }
          }, o = class {
            constructor() {
              this._map = /* @__PURE__ */ new Map();
            }
            get(p, n) {
              let s = this._map.get(p);
              return s || (s = n(), this._map.set(p, s), s);
            }
            add(p, n) {
              this._map.set(p, n);
            }
            match(p) {
              let n = a(p), s = [], u = this._map.get(n), i = this._map.get(h);
              return u && s.push(u), i && s.push(i), s;
            }
          };
          function e(p) {
            return p(new r()).check();
          }
          var r = class {
            constructor() {
              this._whens = new o();
            }
            check() {
              return (p, n) => this.matchFor(p.kind, n.kind)(p, n);
            }
            matchFor(p, n) {
              let s = this._whens.match(p);
              return new c(s).first(n);
            }
            when(p, n, s) {
              return this._whens.get(p, () => new o()).add(n, s), this;
            }
          };
          function a(p) {
            switch (p) {
              case "Broken":
              case "InternalsSynthetic":
              case "NonExistent":
                return d;
              default:
                return p;
            }
          }
        } }), He = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/loc/offset.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.InvisiblePosition = t3.HbsPosition = t3.CharPosition = t3.SourceOffset = t3.BROKEN = void 0;
          var f = ge(), h = Me(), d = Ve(), c = "BROKEN";
          t3.BROKEN = c;
          var o = class {
            constructor(n) {
              this.data = n;
            }
            static forHbsPos(n, s) {
              return new r(n, s, null).wrap();
            }
            static broken() {
              let n = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : f.UNKNOWN_POSITION;
              return new a("Broken", n).wrap();
            }
            get offset() {
              let n = this.data.toCharPos();
              return n === null ? null : n.offset;
            }
            eql(n) {
              return p(this.data, n.data);
            }
            until(n) {
              return (0, d.span)(this.data, n.data);
            }
            move(n) {
              let s = this.data.toCharPos();
              if (s === null)
                return o.broken();
              {
                let u = s.offset + n;
                return s.source.check(u) ? new e(s.source, u).wrap() : o.broken();
              }
            }
            collapsed() {
              return (0, d.span)(this.data, this.data);
            }
            toJSON() {
              return this.data.toJSON();
            }
          };
          t3.SourceOffset = o;
          var e = class {
            constructor(n, s) {
              this.source = n, this.charPos = s, this.kind = "CharPosition", this._locPos = null;
            }
            toCharPos() {
              return this;
            }
            toJSON() {
              let n = this.toHbsPos();
              return n === null ? f.UNKNOWN_POSITION : n.toJSON();
            }
            wrap() {
              return new o(this);
            }
            get offset() {
              return this.charPos;
            }
            toHbsPos() {
              let n = this._locPos;
              if (n === null) {
                let s = this.source.hbsPosFor(this.charPos);
                s === null ? this._locPos = n = c : this._locPos = n = new r(this.source, s, this.charPos);
              }
              return n === c ? null : n;
            }
          };
          t3.CharPosition = e;
          var r = class {
            constructor(n, s) {
              let u = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
              this.source = n, this.hbsPos = s, this.kind = "HbsPosition", this._charPos = u === null ? null : new e(n, u);
            }
            toCharPos() {
              let n = this._charPos;
              if (n === null) {
                let s = this.source.charPosFor(this.hbsPos);
                s === null ? this._charPos = n = c : this._charPos = n = new e(this.source, s);
              }
              return n === c ? null : n;
            }
            toJSON() {
              return this.hbsPos;
            }
            wrap() {
              return new o(this);
            }
            toHbsPos() {
              return this;
            }
          };
          t3.HbsPosition = r;
          var a = class {
            constructor(n, s) {
              this.kind = n, this.pos = s;
            }
            toCharPos() {
              return null;
            }
            toJSON() {
              return this.pos;
            }
            wrap() {
              return new o(this);
            }
            get offset() {
              return null;
            }
          };
          t3.InvisiblePosition = a;
          var p = (0, h.match)((n) => n.when("HbsPosition", "HbsPosition", (s, u) => {
            let { hbsPos: i } = s, { hbsPos: l } = u;
            return i.column === l.column && i.line === l.line;
          }).when("CharPosition", "CharPosition", (s, u) => {
            let { charPos: i } = s, { charPos: l } = u;
            return i === l;
          }).when("CharPosition", "HbsPosition", (s, u) => {
            let { offset: i } = s;
            var l;
            return i === ((l = u.toCharPos()) === null || l === void 0 ? void 0 : l.offset);
          }).when("HbsPosition", "CharPosition", (s, u) => {
            let { offset: i } = u;
            var l;
            return ((l = s.toCharPos()) === null || l === void 0 ? void 0 : l.offset) === i;
          }).when(h.MatchAny, h.MatchAny, () => false));
        } }), Ve = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/loc/span.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.span = t3.HbsSpan = t3.SourceSpan = void 0;
          var f = fe(), h = X(), d = ge(), c = le(), o = Me(), e = He(), r = class {
            constructor(u) {
              this.data = u, this.isInvisible = u.kind !== "CharPosition" && u.kind !== "HbsPosition";
            }
            static get NON_EXISTENT() {
              return new n("NonExistent", d.NON_EXISTENT_LOCATION).wrap();
            }
            static load(u, i) {
              if (typeof i == "number")
                return r.forCharPositions(u, i, i);
              if (typeof i == "string")
                return r.synthetic(i);
              if (Array.isArray(i))
                return r.forCharPositions(u, i[0], i[1]);
              if (i === "NonExistent")
                return r.NON_EXISTENT;
              if (i === "Broken")
                return r.broken(d.BROKEN_LOCATION);
              (0, h.assertNever)(i);
            }
            static forHbsLoc(u, i) {
              let l = new e.HbsPosition(u, i.start), b = new e.HbsPosition(u, i.end);
              return new p(u, { start: l, end: b }, i).wrap();
            }
            static forCharPositions(u, i, l) {
              let b = new e.CharPosition(u, i), P = new e.CharPosition(u, l);
              return new a(u, { start: b, end: P }).wrap();
            }
            static synthetic(u) {
              return new n("InternalsSynthetic", d.NON_EXISTENT_LOCATION, u).wrap();
            }
            static broken() {
              let u = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : d.BROKEN_LOCATION;
              return new n("Broken", u).wrap();
            }
            getStart() {
              return this.data.getStart().wrap();
            }
            getEnd() {
              return this.data.getEnd().wrap();
            }
            get loc() {
              let u = this.data.toHbsSpan();
              return u === null ? d.BROKEN_LOCATION : u.toHbsLoc();
            }
            get module() {
              return this.data.getModule();
            }
            get startPosition() {
              return this.loc.start;
            }
            get endPosition() {
              return this.loc.end;
            }
            toJSON() {
              return this.loc;
            }
            withStart(u) {
              return s(u.data, this.data.getEnd());
            }
            withEnd(u) {
              return s(this.data.getStart(), u.data);
            }
            asString() {
              return this.data.asString();
            }
            toSlice(u) {
              let i = this.data.asString();
              return f.DEBUG && u !== void 0 && i !== u && console.warn(`unexpectedly found ${JSON.stringify(i)} when slicing source, but expected ${JSON.stringify(u)}`), new c.SourceSlice({ loc: this, chars: u || i });
            }
            get start() {
              return this.loc.start;
            }
            set start(u) {
              this.data.locDidUpdate({ start: u });
            }
            get end() {
              return this.loc.end;
            }
            set end(u) {
              this.data.locDidUpdate({ end: u });
            }
            get source() {
              return this.module;
            }
            collapse(u) {
              switch (u) {
                case "start":
                  return this.getStart().collapsed();
                case "end":
                  return this.getEnd().collapsed();
              }
            }
            extend(u) {
              return s(this.data.getStart(), u.data.getEnd());
            }
            serialize() {
              return this.data.serialize();
            }
            slice(u) {
              let { skipStart: i = 0, skipEnd: l = 0 } = u;
              return s(this.getStart().move(i).data, this.getEnd().move(-l).data);
            }
            sliceStartChars(u) {
              let { skipStart: i = 0, chars: l } = u;
              return s(this.getStart().move(i).data, this.getStart().move(i + l).data);
            }
            sliceEndChars(u) {
              let { skipEnd: i = 0, chars: l } = u;
              return s(this.getEnd().move(i - l).data, this.getStart().move(-i).data);
            }
          };
          t3.SourceSpan = r;
          var a = class {
            constructor(u, i) {
              this.source = u, this.charPositions = i, this.kind = "CharPosition", this._locPosSpan = null;
            }
            wrap() {
              return new r(this);
            }
            asString() {
              return this.source.slice(this.charPositions.start.charPos, this.charPositions.end.charPos);
            }
            getModule() {
              return this.source.module;
            }
            getStart() {
              return this.charPositions.start;
            }
            getEnd() {
              return this.charPositions.end;
            }
            locDidUpdate() {
            }
            toHbsSpan() {
              let u = this._locPosSpan;
              if (u === null) {
                let i = this.charPositions.start.toHbsPos(), l = this.charPositions.end.toHbsPos();
                i === null || l === null ? u = this._locPosSpan = e.BROKEN : u = this._locPosSpan = new p(this.source, { start: i, end: l });
              }
              return u === e.BROKEN ? null : u;
            }
            serialize() {
              let { start: { charPos: u }, end: { charPos: i } } = this.charPositions;
              return u === i ? u : [u, i];
            }
            toCharPosSpan() {
              return this;
            }
          }, p = class {
            constructor(u, i) {
              let l = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
              this.source = u, this.hbsPositions = i, this.kind = "HbsPosition", this._charPosSpan = null, this._providedHbsLoc = l;
            }
            serialize() {
              let u = this.toCharPosSpan();
              return u === null ? "Broken" : u.wrap().serialize();
            }
            wrap() {
              return new r(this);
            }
            updateProvided(u, i) {
              this._providedHbsLoc && (this._providedHbsLoc[i] = u), this._charPosSpan = null, this._providedHbsLoc = { start: u, end: u };
            }
            locDidUpdate(u) {
              let { start: i, end: l } = u;
              i !== void 0 && (this.updateProvided(i, "start"), this.hbsPositions.start = new e.HbsPosition(this.source, i, null)), l !== void 0 && (this.updateProvided(l, "end"), this.hbsPositions.end = new e.HbsPosition(this.source, l, null));
            }
            asString() {
              let u = this.toCharPosSpan();
              return u === null ? "" : u.asString();
            }
            getModule() {
              return this.source.module;
            }
            getStart() {
              return this.hbsPositions.start;
            }
            getEnd() {
              return this.hbsPositions.end;
            }
            toHbsLoc() {
              return { start: this.hbsPositions.start.hbsPos, end: this.hbsPositions.end.hbsPos };
            }
            toHbsSpan() {
              return this;
            }
            toCharPosSpan() {
              let u = this._charPosSpan;
              if (u === null) {
                let i = this.hbsPositions.start.toCharPos(), l = this.hbsPositions.end.toCharPos();
                if (i && l)
                  u = this._charPosSpan = new a(this.source, { start: i, end: l });
                else
                  return u = this._charPosSpan = e.BROKEN, null;
              }
              return u === e.BROKEN ? null : u;
            }
          };
          t3.HbsSpan = p;
          var n = class {
            constructor(u, i) {
              let l = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
              this.kind = u, this.loc = i, this.string = l;
            }
            serialize() {
              switch (this.kind) {
                case "Broken":
                case "NonExistent":
                  return this.kind;
                case "InternalsSynthetic":
                  return this.string || "";
              }
            }
            wrap() {
              return new r(this);
            }
            asString() {
              return this.string || "";
            }
            locDidUpdate(u) {
              let { start: i, end: l } = u;
              i !== void 0 && (this.loc.start = i), l !== void 0 && (this.loc.end = l);
            }
            getModule() {
              return "an unknown module";
            }
            getStart() {
              return new e.InvisiblePosition(this.kind, this.loc.start);
            }
            getEnd() {
              return new e.InvisiblePosition(this.kind, this.loc.end);
            }
            toCharPosSpan() {
              return this;
            }
            toHbsSpan() {
              return null;
            }
            toHbsLoc() {
              return d.BROKEN_LOCATION;
            }
          }, s = (0, o.match)((u) => u.when("HbsPosition", "HbsPosition", (i, l) => new p(i.source, { start: i, end: l }).wrap()).when("CharPosition", "CharPosition", (i, l) => new a(i.source, { start: i, end: l }).wrap()).when("CharPosition", "HbsPosition", (i, l) => {
            let b = l.toCharPos();
            return b === null ? new n("Broken", d.BROKEN_LOCATION).wrap() : s(i, b);
          }).when("HbsPosition", "CharPosition", (i, l) => {
            let b = i.toCharPos();
            return b === null ? new n("Broken", d.BROKEN_LOCATION).wrap() : s(b, l);
          }).when(o.IsInvisible, o.MatchAny, (i) => new n(i.kind, d.BROKEN_LOCATION).wrap()).when(o.MatchAny, o.IsInvisible, (i, l) => new n(l.kind, d.BROKEN_LOCATION).wrap()));
          t3.span = s;
        } }), ue = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/span.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), Object.defineProperty(t3, "SourceSpan", { enumerable: true, get: function() {
            return f.SourceSpan;
          } }), Object.defineProperty(t3, "SourceOffset", { enumerable: true, get: function() {
            return h.SourceOffset;
          } });
          var f = Ve(), h = He();
        } }), De = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/source.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.Source = void 0;
          var f = fe(), h = X(), d = ue(), c = class {
            constructor(o) {
              let e = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "an unknown module";
              this.source = o, this.module = e;
            }
            check(o) {
              return o >= 0 && o <= this.source.length;
            }
            slice(o, e) {
              return this.source.slice(o, e);
            }
            offsetFor(o, e) {
              return d.SourceOffset.forHbsPos(this, { line: o, column: e });
            }
            spanFor(o) {
              let { start: e, end: r } = o;
              return d.SourceSpan.forHbsLoc(this, { start: { line: e.line, column: e.column }, end: { line: r.line, column: r.column } });
            }
            hbsPosFor(o) {
              let e = 0, r = 0;
              if (o > this.source.length)
                return null;
              for (; ; ) {
                let a = this.source.indexOf(`
`, r);
                if (o <= a || a === -1)
                  return { line: e + 1, column: o - r };
                e += 1, r = a + 1;
              }
            }
            charPosFor(o) {
              let { line: e, column: r } = o, p = this.source.length, n = 0, s = 0;
              for (; ; ) {
                if (s >= p)
                  return p;
                let u = this.source.indexOf(`
`, s);
                if (u === -1 && (u = this.source.length), n === e - 1) {
                  if (s + r > u)
                    return u;
                  if (f.DEBUG) {
                    let i = this.hbsPosFor(s + r);
                  }
                  return s + r;
                } else {
                  if (u === -1)
                    return 0;
                  n += 1, s = u + 1;
                }
              }
            }
          };
          t3.Source = c;
        } }), we = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/legacy-interop.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.PathExpressionImplV1 = void 0;
          var f = h(ke());
          function h(c) {
            return c && c.__esModule ? c : { default: c };
          }
          var d = class {
            constructor(c, o, e, r) {
              this.original = c, this.loc = r, this.type = "PathExpression", this.this = false, this.data = false, this._head = void 0;
              let a = e.slice();
              o.type === "ThisHead" ? this.this = true : o.type === "AtHead" ? (this.data = true, a.unshift(o.name.slice(1))) : a.unshift(o.name), this.parts = a;
            }
            get head() {
              if (this._head)
                return this._head;
              let c;
              this.this ? c = "this" : this.data ? c = `@${this.parts[0]}` : c = this.parts[0];
              let o = this.loc.collapse("start").sliceStartChars({ chars: c.length }).loc;
              return this._head = f.default.head(c, o);
            }
            get tail() {
              return this.this ? this.parts : this.parts.slice(1);
            }
          };
          t3.PathExpressionImplV1 = d;
        } }), ke = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/public-builders.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = X(), h = ge(), d = De(), c = ue(), o = we(), e;
          function r() {
            return e || (e = new d.Source("", "(synthetic)")), e;
          }
          function a(T, N, k, B, O, q) {
            return typeof T == "string" && (T = m(T)), { type: "MustacheStatement", path: T, params: N || [], hash: k || S([]), escaped: !B, trusting: !!B, loc: U(O || null), strip: q || { open: false, close: false } };
          }
          function p(T, N, k, B, O, q, z, A, Q) {
            let D, $2;
            return B.type === "Template" ? D = (0, f.assign)({}, B, { type: "Block" }) : D = B, O != null && O.type === "Template" ? $2 = (0, f.assign)({}, O, { type: "Block" }) : $2 = O, { type: "BlockStatement", path: m(T), params: N || [], hash: k || S([]), program: D || null, inverse: $2 || null, loc: U(q || null), openStrip: z || { open: false, close: false }, inverseStrip: A || { open: false, close: false }, closeStrip: Q || { open: false, close: false } };
          }
          function n(T, N, k, B) {
            return { type: "ElementModifierStatement", path: m(T), params: N || [], hash: k || S([]), loc: U(B || null) };
          }
          function s(T, N, k, B, O) {
            return { type: "PartialStatement", name: T, params: N || [], hash: k || S([]), indent: B || "", strip: { open: false, close: false }, loc: U(O || null) };
          }
          function u(T, N) {
            return { type: "CommentStatement", value: T, loc: U(N || null) };
          }
          function i(T, N) {
            return { type: "MustacheCommentStatement", value: T, loc: U(N || null) };
          }
          function l(T, N) {
            if (!(0, f.isPresent)(T))
              throw new Error("b.concat requires at least one part");
            return { type: "ConcatStatement", parts: T || [], loc: U(N || null) };
          }
          function b(T) {
            let N = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, { attrs: k, blockParams: B, modifiers: O, comments: q, children: z, loc: A } = N, Q, D = false;
            return typeof T == "object" ? (D = T.selfClosing, Q = T.name) : T.slice(-1) === "/" ? (Q = T.slice(0, -1), D = true) : Q = T, { type: "ElementNode", tag: Q, selfClosing: D, attributes: k || [], blockParams: B || [], modifiers: O || [], comments: q || [], children: z || [], loc: U(A || null) };
          }
          function P(T, N, k) {
            return { type: "AttrNode", name: T, value: N, loc: U(k || null) };
          }
          function E(T, N) {
            return { type: "TextNode", chars: T || "", loc: U(N || null) };
          }
          function v(T, N, k, B) {
            return { type: "SubExpression", path: m(T), params: N || [], hash: k || S([]), loc: U(B || null) };
          }
          function _(T) {
            switch (T.type) {
              case "AtHead":
                return { original: T.name, parts: [T.name] };
              case "ThisHead":
                return { original: "this", parts: [] };
              case "VarHead":
                return { original: T.name, parts: [T.name] };
            }
          }
          function y(T, N) {
            let [k, ...B] = T.split("."), O;
            return k === "this" ? O = { type: "ThisHead", loc: U(N || null) } : k[0] === "@" ? O = { type: "AtHead", name: k, loc: U(N || null) } : O = { type: "VarHead", name: k, loc: U(N || null) }, { head: O, tail: B };
          }
          function g(T) {
            return { type: "ThisHead", loc: U(T || null) };
          }
          function L(T, N) {
            return { type: "AtHead", name: T, loc: U(N || null) };
          }
          function j(T, N) {
            return { type: "VarHead", name: T, loc: U(N || null) };
          }
          function x(T, N) {
            return T[0] === "@" ? L(T, N) : T === "this" ? g(N) : j(T, N);
          }
          function w(T, N) {
            return { type: "NamedBlockName", name: T, loc: U(N || null) };
          }
          function H(T, N, k) {
            let { original: B, parts: O } = _(T), q = [...O, ...N], z = [...B, ...q].join(".");
            return new o.PathExpressionImplV1(z, T, N, U(k || null));
          }
          function m(T, N) {
            if (typeof T != "string") {
              if ("type" in T)
                return T;
              {
                let { head: O, tail: q } = y(T.head, c.SourceSpan.broken()), { original: z } = _(O);
                return new o.PathExpressionImplV1([z, ...q].join("."), O, q, U(N || null));
              }
            }
            let { head: k, tail: B } = y(T, c.SourceSpan.broken());
            return new o.PathExpressionImplV1(T, k, B, U(N || null));
          }
          function C(T, N, k) {
            return { type: T, value: N, original: N, loc: U(k || null) };
          }
          function S(T, N) {
            return { type: "Hash", pairs: T || [], loc: U(N || null) };
          }
          function R(T, N, k) {
            return { type: "HashPair", key: T, value: N, loc: U(k || null) };
          }
          function M(T, N, k) {
            return { type: "Template", body: T || [], blockParams: N || [], loc: U(k || null) };
          }
          function V(T, N) {
            let k = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, B = arguments.length > 3 ? arguments[3] : void 0;
            return { type: "Block", body: T || [], blockParams: N || [], chained: k, loc: U(B || null) };
          }
          function G(T, N, k) {
            return { type: "Template", body: T || [], blockParams: N || [], loc: U(k || null) };
          }
          function K(T, N) {
            return { line: T, column: N };
          }
          function U() {
            for (var T = arguments.length, N = new Array(T), k = 0; k < T; k++)
              N[k] = arguments[k];
            if (N.length === 1) {
              let B = N[0];
              return B && typeof B == "object" ? c.SourceSpan.forHbsLoc(r(), B) : c.SourceSpan.forHbsLoc(r(), h.SYNTHETIC_LOCATION);
            } else {
              let [B, O, q, z, A] = N, Q = A ? new d.Source("", A) : r();
              return c.SourceSpan.forHbsLoc(Q, { start: { line: B, column: O }, end: { line: q, column: z } });
            }
          }
          var Z = { mustache: a, block: p, partial: s, comment: u, mustacheComment: i, element: b, elementModifier: n, attr: P, text: E, sexpr: v, concat: l, hash: S, pair: R, literal: C, program: M, blockItself: V, template: G, loc: U, pos: K, path: m, fullPath: H, head: x, at: L, var: j, this: g, blockName: w, string: W("StringLiteral"), boolean: W("BooleanLiteral"), number: W("NumberLiteral"), undefined() {
            return C("UndefinedLiteral", void 0);
          }, null() {
            return C("NullLiteral", null);
          } };
          t3.default = Z;
          function W(T) {
            return function(N, k) {
              return C(T, N, k);
            };
          }
        } }), St = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/nodes-v1.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
        } }), Ct = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/api.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = St();
          Object.keys(f).forEach(function(h) {
            h === "default" || h === "__esModule" || Object.defineProperty(t3, h, { enumerable: true, get: function() {
              return f[h];
            } });
          });
        } }), Pt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/resolution.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.loadResolution = o, t3.ARGUMENT_RESOLUTION = t3.LooseModeResolution = t3.STRICT_RESOLUTION = t3.StrictResolution = void 0;
          var f = class {
            constructor() {
              this.isAngleBracket = false;
            }
            resolution() {
              return 31;
            }
            serialize() {
              return "Strict";
            }
          };
          t3.StrictResolution = f;
          var h = new f();
          t3.STRICT_RESOLUTION = h;
          var d = class {
            constructor(e) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              this.ambiguity = e, this.isAngleBracket = r;
            }
            static namespaced(e) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              return new d({ namespaces: [e], fallback: false }, r);
            }
            static fallback() {
              return new d({ namespaces: [], fallback: true });
            }
            static append(e) {
              let { invoke: r } = e;
              return new d({ namespaces: ["Component", "Helper"], fallback: !r });
            }
            static trustingAppend(e) {
              let { invoke: r } = e;
              return new d({ namespaces: ["Helper"], fallback: !r });
            }
            static attr() {
              return new d({ namespaces: ["Helper"], fallback: true });
            }
            resolution() {
              if (this.ambiguity.namespaces.length === 0)
                return 31;
              if (this.ambiguity.namespaces.length === 1) {
                if (this.ambiguity.fallback)
                  return 36;
                switch (this.ambiguity.namespaces[0]) {
                  case "Helper":
                    return 37;
                  case "Modifier":
                    return 38;
                  case "Component":
                    return 39;
                }
              } else
                return this.ambiguity.fallback ? 34 : 35;
            }
            serialize() {
              return this.ambiguity.namespaces.length === 0 ? "Loose" : this.ambiguity.namespaces.length === 1 ? this.ambiguity.fallback ? ["ambiguous", "Attr"] : ["ns", this.ambiguity.namespaces[0]] : this.ambiguity.fallback ? ["ambiguous", "Append"] : ["ambiguous", "Invoke"];
            }
          };
          t3.LooseModeResolution = d;
          var c = d.fallback();
          t3.ARGUMENT_RESOLUTION = c;
          function o(e) {
            if (typeof e == "string")
              switch (e) {
                case "Loose":
                  return d.fallback();
                case "Strict":
                  return h;
              }
            switch (e[0]) {
              case "ambiguous":
                switch (e[1]) {
                  case "Append":
                    return d.append({ invoke: false });
                  case "Attr":
                    return d.attr();
                  case "Invoke":
                    return d.append({ invoke: true });
                }
              case "ns":
                return d.namespaced(e[1]);
            }
          }
        } }), ne = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/node.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.node = h;
          var f = X();
          function h(d) {
            if (d !== void 0) {
              let c = d;
              return { fields() {
                return class {
                  constructor(o) {
                    this.type = c, (0, f.assign)(this, o);
                  }
                };
              } };
            } else
              return { fields() {
                return class {
                  constructor(c) {
                    (0, f.assign)(this, c);
                  }
                };
              } };
          }
        } }), be = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/args.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.NamedArgument = t3.NamedArguments = t3.PositionalArguments = t3.Args = void 0;
          var f = ne(), h = class extends (0, f.node)().fields() {
            static empty(e) {
              return new h({ loc: e, positional: d.empty(e), named: c.empty(e) });
            }
            static named(e) {
              return new h({ loc: e.loc, positional: d.empty(e.loc.collapse("end")), named: e });
            }
            nth(e) {
              return this.positional.nth(e);
            }
            get(e) {
              return this.named.get(e);
            }
            isEmpty() {
              return this.positional.isEmpty() && this.named.isEmpty();
            }
          };
          t3.Args = h;
          var d = class extends (0, f.node)().fields() {
            static empty(e) {
              return new d({ loc: e, exprs: [] });
            }
            get size() {
              return this.exprs.length;
            }
            nth(e) {
              return this.exprs[e] || null;
            }
            isEmpty() {
              return this.exprs.length === 0;
            }
          };
          t3.PositionalArguments = d;
          var c = class extends (0, f.node)().fields() {
            static empty(e) {
              return new c({ loc: e, entries: [] });
            }
            get size() {
              return this.entries.length;
            }
            get(e) {
              let r = this.entries.filter((a) => a.name.chars === e)[0];
              return r ? r.value : null;
            }
            isEmpty() {
              return this.entries.length === 0;
            }
          };
          t3.NamedArguments = c;
          var o = class {
            constructor(e) {
              this.loc = e.name.loc.extend(e.value.loc), this.name = e.name, this.value = e.value;
            }
          };
          t3.NamedArgument = o;
        } }), Dt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/attr-block.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.ElementModifier = t3.ComponentArg = t3.SplatAttr = t3.HtmlAttr = void 0;
          var f = be(), h = ne(), d = class extends (0, h.node)("HtmlAttr").fields() {
          };
          t3.HtmlAttr = d;
          var c = class extends (0, h.node)("SplatAttr").fields() {
          };
          t3.SplatAttr = c;
          var o = class extends (0, h.node)().fields() {
            toNamedArgument() {
              return new f.NamedArgument({ name: this.name, value: this.value });
            }
          };
          t3.ComponentArg = o;
          var e = class extends (0, h.node)("ElementModifier").fields() {
          };
          t3.ElementModifier = e;
        } }), wt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/base.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
        } }), ce = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/source/span-list.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.loc = d, t3.hasSpan = c, t3.maybeLoc = o, t3.SpanList = void 0;
          var f = ue(), h = class {
            constructor() {
              let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [];
              this._span = e;
            }
            static range(e) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : f.SourceSpan.NON_EXISTENT;
              return new h(e.map(d)).getRangeOffset(r);
            }
            add(e) {
              this._span.push(e);
            }
            getRangeOffset(e) {
              if (this._span.length === 0)
                return e;
              {
                let r = this._span[0], a = this._span[this._span.length - 1];
                return r.extend(a);
              }
            }
          };
          t3.SpanList = h;
          function d(e) {
            if (Array.isArray(e)) {
              let r = e[0], a = e[e.length - 1];
              return d(r).extend(d(a));
            } else
              return e instanceof f.SourceSpan ? e : e.loc;
          }
          function c(e) {
            return !(Array.isArray(e) && e.length === 0);
          }
          function o(e, r) {
            return c(e) ? d(e) : r;
          }
        } }), kt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/content.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.SimpleElement = t3.InvokeComponent = t3.InvokeBlock = t3.AppendContent = t3.HtmlComment = t3.HtmlText = t3.GlimmerComment = void 0;
          var f = ce(), h = be(), d = ne(), c = class extends (0, d.node)("GlimmerComment").fields() {
          };
          t3.GlimmerComment = c;
          var o = class extends (0, d.node)("HtmlText").fields() {
          };
          t3.HtmlText = o;
          var e = class extends (0, d.node)("HtmlComment").fields() {
          };
          t3.HtmlComment = e;
          var r = class extends (0, d.node)("AppendContent").fields() {
            get callee() {
              return this.value.type === "Call" ? this.value.callee : this.value;
            }
            get args() {
              return this.value.type === "Call" ? this.value.args : h.Args.empty(this.value.loc.collapse("end"));
            }
          };
          t3.AppendContent = r;
          var a = class extends (0, d.node)("InvokeBlock").fields() {
          };
          t3.InvokeBlock = a;
          var p = class extends (0, d.node)("InvokeComponent").fields() {
            get args() {
              let s = this.componentArgs.map((u) => u.toNamedArgument());
              return h.Args.named(new h.NamedArguments({ loc: f.SpanList.range(s, this.callee.loc.collapse("end")), entries: s }));
            }
          };
          t3.InvokeComponent = p;
          var n = class extends (0, d.node)("SimpleElement").fields() {
            get args() {
              let s = this.componentArgs.map((u) => u.toNamedArgument());
              return h.Args.named(new h.NamedArguments({ loc: f.SpanList.range(s, this.tag.loc.collapse("end")), entries: s }));
            }
          };
          t3.SimpleElement = n;
        } }), Tt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/expr.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isLiteral = c, t3.InterpolateExpression = t3.DeprecatedCallExpression = t3.CallExpression = t3.PathExpression = t3.LiteralExpression = void 0;
          var f = le(), h = ne(), d = class extends (0, h.node)("Literal").fields() {
            toSlice() {
              return new f.SourceSlice({ loc: this.loc, chars: this.value });
            }
          };
          t3.LiteralExpression = d;
          function c(p, n) {
            return p.type === "Literal" ? n === void 0 ? true : n === "null" ? p.value === null : typeof p.value === n : false;
          }
          var o = class extends (0, h.node)("Path").fields() {
          };
          t3.PathExpression = o;
          var e = class extends (0, h.node)("Call").fields() {
          };
          t3.CallExpression = e;
          var r = class extends (0, h.node)("DeprecatedCall").fields() {
          };
          t3.DeprecatedCallExpression = r;
          var a = class extends (0, h.node)("Interpolate").fields() {
          };
          t3.InterpolateExpression = a;
        } }), Bt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/refs.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.FreeVarReference = t3.LocalVarReference = t3.ArgReference = t3.ThisReference = void 0;
          var f = ne(), h = class extends (0, f.node)("This").fields() {
          };
          t3.ThisReference = h;
          var d = class extends (0, f.node)("Arg").fields() {
          };
          t3.ArgReference = d;
          var c = class extends (0, f.node)("Local").fields() {
          };
          t3.LocalVarReference = c;
          var o = class extends (0, f.node)("Free").fields() {
          };
          t3.FreeVarReference = o;
        } }), Ot = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/objects/internal-node.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.NamedBlock = t3.NamedBlocks = t3.Block = t3.Template = void 0;
          var f = ce(), h = be(), d = ne(), c = class extends (0, d.node)().fields() {
          };
          t3.Template = c;
          var o = class extends (0, d.node)().fields() {
          };
          t3.Block = o;
          var e = class extends (0, d.node)().fields() {
            get(a) {
              return this.blocks.filter((p) => p.name.chars === a)[0] || null;
            }
          };
          t3.NamedBlocks = e;
          var r = class extends (0, d.node)().fields() {
            get args() {
              let a = this.componentArgs.map((p) => p.toNamedArgument());
              return h.Args.named(new h.NamedArguments({ loc: f.SpanList.range(a, this.name.loc.collapse("end")), entries: a }));
            }
          };
          t3.NamedBlock = r;
        } }), ve = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/api.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = Pt();
          Object.keys(f).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return f[n];
            } });
          });
          var h = ne();
          Object.keys(h).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return h[n];
            } });
          });
          var d = be();
          Object.keys(d).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return d[n];
            } });
          });
          var c = Dt();
          Object.keys(c).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return c[n];
            } });
          });
          var o = wt();
          Object.keys(o).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return o[n];
            } });
          });
          var e = kt();
          Object.keys(e).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return e[n];
            } });
          });
          var r = Tt();
          Object.keys(r).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return r[n];
            } });
          });
          var a = Bt();
          Object.keys(a).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return a[n];
            } });
          });
          var p = Ot();
          Object.keys(p).forEach(function(n) {
            n === "default" || n === "__esModule" || Object.defineProperty(t3, n, { enumerable: true, get: function() {
              return p[n];
            } });
          });
        } }), Ue = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/generation/util.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.escapeAttrValue = r, t3.escapeText = a, t3.sortByLoc = p;
          var f = /[\xA0"&]/, h = new RegExp(f.source, "g"), d = /[\xA0&<>]/, c = new RegExp(d.source, "g");
          function o(n) {
            switch (n.charCodeAt(0)) {
              case 160:
                return "&nbsp;";
              case 34:
                return "&quot;";
              case 38:
                return "&amp;";
              default:
                return n;
            }
          }
          function e(n) {
            switch (n.charCodeAt(0)) {
              case 160:
                return "&nbsp;";
              case 38:
                return "&amp;";
              case 60:
                return "&lt;";
              case 62:
                return "&gt;";
              default:
                return n;
            }
          }
          function r(n) {
            return f.test(n) ? n.replace(h, o) : n;
          }
          function a(n) {
            return d.test(n) ? n.replace(c, e) : n;
          }
          function p(n, s) {
            return n.loc.isInvisible || s.loc.isInvisible ? 0 : n.loc.startPosition.line < s.loc.startPosition.line || n.loc.startPosition.line === s.loc.startPosition.line && n.loc.startPosition.column < s.loc.startPosition.column ? -1 : n.loc.startPosition.line === s.loc.startPosition.line && n.loc.startPosition.column === s.loc.startPosition.column ? 0 : 1;
          }
        } }), Te = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/generation/printer.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = t3.voidMap = void 0;
          var f = Ue(), h = /* @__PURE__ */ Object.create(null);
          t3.voidMap = h;
          var d = "area base br col command embed hr img input keygen link meta param source track wbr";
          d.split(" ").forEach((e) => {
            h[e] = true;
          });
          var c = /\S/, o = class {
            constructor(e) {
              this.buffer = "", this.options = e;
            }
            handledByOverride(e) {
              let r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
              if (this.options.override !== void 0) {
                let a = this.options.override(e, this.options);
                if (typeof a == "string")
                  return r && a !== "" && c.test(a[0]) && (a = ` ${a}`), this.buffer += a, true;
              }
              return false;
            }
            Node(e) {
              switch (e.type) {
                case "MustacheStatement":
                case "BlockStatement":
                case "PartialStatement":
                case "MustacheCommentStatement":
                case "CommentStatement":
                case "TextNode":
                case "ElementNode":
                case "AttrNode":
                case "Block":
                case "Template":
                  return this.TopLevelStatement(e);
                case "StringLiteral":
                case "BooleanLiteral":
                case "NumberLiteral":
                case "UndefinedLiteral":
                case "NullLiteral":
                case "PathExpression":
                case "SubExpression":
                  return this.Expression(e);
                case "Program":
                  return this.Block(e);
                case "ConcatStatement":
                  return this.ConcatStatement(e);
                case "Hash":
                  return this.Hash(e);
                case "HashPair":
                  return this.HashPair(e);
                case "ElementModifierStatement":
                  return this.ElementModifierStatement(e);
              }
            }
            Expression(e) {
              switch (e.type) {
                case "StringLiteral":
                case "BooleanLiteral":
                case "NumberLiteral":
                case "UndefinedLiteral":
                case "NullLiteral":
                  return this.Literal(e);
                case "PathExpression":
                  return this.PathExpression(e);
                case "SubExpression":
                  return this.SubExpression(e);
              }
            }
            Literal(e) {
              switch (e.type) {
                case "StringLiteral":
                  return this.StringLiteral(e);
                case "BooleanLiteral":
                  return this.BooleanLiteral(e);
                case "NumberLiteral":
                  return this.NumberLiteral(e);
                case "UndefinedLiteral":
                  return this.UndefinedLiteral(e);
                case "NullLiteral":
                  return this.NullLiteral(e);
              }
            }
            TopLevelStatement(e) {
              switch (e.type) {
                case "MustacheStatement":
                  return this.MustacheStatement(e);
                case "BlockStatement":
                  return this.BlockStatement(e);
                case "PartialStatement":
                  return this.PartialStatement(e);
                case "MustacheCommentStatement":
                  return this.MustacheCommentStatement(e);
                case "CommentStatement":
                  return this.CommentStatement(e);
                case "TextNode":
                  return this.TextNode(e);
                case "ElementNode":
                  return this.ElementNode(e);
                case "Block":
                case "Template":
                  return this.Block(e);
                case "AttrNode":
                  return this.AttrNode(e);
              }
            }
            Block(e) {
              if (e.chained) {
                let r = e.body[0];
                r.chained = true;
              }
              this.handledByOverride(e) || this.TopLevelStatements(e.body);
            }
            TopLevelStatements(e) {
              e.forEach((r) => this.TopLevelStatement(r));
            }
            ElementNode(e) {
              this.handledByOverride(e) || (this.OpenElementNode(e), this.TopLevelStatements(e.children), this.CloseElementNode(e));
            }
            OpenElementNode(e) {
              this.buffer += `<${e.tag}`;
              let r = [...e.attributes, ...e.modifiers, ...e.comments].sort(f.sortByLoc);
              for (let a of r)
                switch (this.buffer += " ", a.type) {
                  case "AttrNode":
                    this.AttrNode(a);
                    break;
                  case "ElementModifierStatement":
                    this.ElementModifierStatement(a);
                    break;
                  case "MustacheCommentStatement":
                    this.MustacheCommentStatement(a);
                    break;
                }
              e.blockParams.length && this.BlockParams(e.blockParams), e.selfClosing && (this.buffer += " /"), this.buffer += ">";
            }
            CloseElementNode(e) {
              e.selfClosing || h[e.tag.toLowerCase()] || (this.buffer += `</${e.tag}>`);
            }
            AttrNode(e) {
              if (this.handledByOverride(e))
                return;
              let { name: r, value: a } = e;
              this.buffer += r, (a.type !== "TextNode" || a.chars.length > 0) && (this.buffer += "=", this.AttrNodeValue(a));
            }
            AttrNodeValue(e) {
              e.type === "TextNode" ? (this.buffer += '"', this.TextNode(e, true), this.buffer += '"') : this.Node(e);
            }
            TextNode(e, r) {
              this.handledByOverride(e) || (this.options.entityEncoding === "raw" ? this.buffer += e.chars : r ? this.buffer += (0, f.escapeAttrValue)(e.chars) : this.buffer += (0, f.escapeText)(e.chars));
            }
            MustacheStatement(e) {
              this.handledByOverride(e) || (this.buffer += e.escaped ? "{{" : "{{{", e.strip.open && (this.buffer += "~"), this.Expression(e.path), this.Params(e.params), this.Hash(e.hash), e.strip.close && (this.buffer += "~"), this.buffer += e.escaped ? "}}" : "}}}");
            }
            BlockStatement(e) {
              this.handledByOverride(e) || (e.chained ? (this.buffer += e.inverseStrip.open ? "{{~" : "{{", this.buffer += "else ") : this.buffer += e.openStrip.open ? "{{~#" : "{{#", this.Expression(e.path), this.Params(e.params), this.Hash(e.hash), e.program.blockParams.length && this.BlockParams(e.program.blockParams), e.chained ? this.buffer += e.inverseStrip.close ? "~}}" : "}}" : this.buffer += e.openStrip.close ? "~}}" : "}}", this.Block(e.program), e.inverse && (e.inverse.chained || (this.buffer += e.inverseStrip.open ? "{{~" : "{{", this.buffer += "else", this.buffer += e.inverseStrip.close ? "~}}" : "}}"), this.Block(e.inverse)), e.chained || (this.buffer += e.closeStrip.open ? "{{~/" : "{{/", this.Expression(e.path), this.buffer += e.closeStrip.close ? "~}}" : "}}"));
            }
            BlockParams(e) {
              this.buffer += ` as |${e.join(" ")}|`;
            }
            PartialStatement(e) {
              this.handledByOverride(e) || (this.buffer += "{{>", this.Expression(e.name), this.Params(e.params), this.Hash(e.hash), this.buffer += "}}");
            }
            ConcatStatement(e) {
              this.handledByOverride(e) || (this.buffer += '"', e.parts.forEach((r) => {
                r.type === "TextNode" ? this.TextNode(r, true) : this.Node(r);
              }), this.buffer += '"');
            }
            MustacheCommentStatement(e) {
              this.handledByOverride(e) || (this.buffer += `{{!--${e.value}--}}`);
            }
            ElementModifierStatement(e) {
              this.handledByOverride(e) || (this.buffer += "{{", this.Expression(e.path), this.Params(e.params), this.Hash(e.hash), this.buffer += "}}");
            }
            CommentStatement(e) {
              this.handledByOverride(e) || (this.buffer += `<!--${e.value}-->`);
            }
            PathExpression(e) {
              this.handledByOverride(e) || (this.buffer += e.original);
            }
            SubExpression(e) {
              this.handledByOverride(e) || (this.buffer += "(", this.Expression(e.path), this.Params(e.params), this.Hash(e.hash), this.buffer += ")");
            }
            Params(e) {
              e.length && e.forEach((r) => {
                this.buffer += " ", this.Expression(r);
              });
            }
            Hash(e) {
              this.handledByOverride(e, true) || e.pairs.forEach((r) => {
                this.buffer += " ", this.HashPair(r);
              });
            }
            HashPair(e) {
              this.handledByOverride(e) || (this.buffer += e.key, this.buffer += "=", this.Node(e.value));
            }
            StringLiteral(e) {
              this.handledByOverride(e) || (this.buffer += JSON.stringify(e.value));
            }
            BooleanLiteral(e) {
              this.handledByOverride(e) || (this.buffer += e.value);
            }
            NumberLiteral(e) {
              this.handledByOverride(e) || (this.buffer += e.value);
            }
            UndefinedLiteral(e) {
              this.handledByOverride(e) || (this.buffer += "undefined");
            }
            NullLiteral(e) {
              this.handledByOverride(e) || (this.buffer += "null");
            }
            print(e) {
              let { options: r } = this;
              if (r.override) {
                let a = r.override(e, r);
                if (a !== void 0)
                  return a;
              }
              return this.buffer = "", this.Node(e), this.buffer;
            }
          };
          t3.default = o;
        } }), Be = I({ "node_modules/@handlebars/parser/dist/cjs/exception.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = ["description", "fileName", "lineNumber", "endLineNumber", "message", "name", "number", "stack"];
          function h(d, c) {
            var o = c && c.loc, e, r, a, p;
            o && (e = o.start.line, r = o.end.line, a = o.start.column, p = o.end.column, d += " - " + e + ":" + a);
            for (var n = Error.prototype.constructor.call(this, d), s = 0; s < f.length; s++)
              this[f[s]] = n[f[s]];
            Error.captureStackTrace && Error.captureStackTrace(this, h);
            try {
              o && (this.lineNumber = e, this.endLineNumber = r, Object.defineProperty ? (Object.defineProperty(this, "column", { value: a, enumerable: true }), Object.defineProperty(this, "endColumn", { value: p, enumerable: true })) : (this.column = a, this.endColumn = p));
            } catch {
            }
          }
          h.prototype = new Error(), t3.default = h;
        } }), Oe = I({ "node_modules/@handlebars/parser/dist/cjs/visitor.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__importDefault || function(r) {
            return r && r.__esModule ? r : { default: r };
          };
          Object.defineProperty(t3, "__esModule", { value: true });
          var h = f(Be());
          function d() {
            this.parents = [];
          }
          d.prototype = { constructor: d, mutating: false, acceptKey: function(r, a) {
            var p = this.accept(r[a]);
            if (this.mutating) {
              if (p && !d.prototype[p.type])
                throw new h.default('Unexpected node type "' + p.type + '" found when accepting ' + a + " on " + r.type);
              r[a] = p;
            }
          }, acceptRequired: function(r, a) {
            if (this.acceptKey(r, a), !r[a])
              throw new h.default(r.type + " requires " + a);
          }, acceptArray: function(r) {
            for (var a = 0, p = r.length; a < p; a++)
              this.acceptKey(r, a), r[a] || (r.splice(a, 1), a--, p--);
          }, accept: function(r) {
            if (r) {
              if (!this[r.type])
                throw new h.default("Unknown type: " + r.type, r);
              this.current && this.parents.unshift(this.current), this.current = r;
              var a = this[r.type](r);
              if (this.current = this.parents.shift(), !this.mutating || a)
                return a;
              if (a !== false)
                return r;
            }
          }, Program: function(r) {
            this.acceptArray(r.body);
          }, MustacheStatement: c, Decorator: c, BlockStatement: o, DecoratorBlock: o, PartialStatement: e, PartialBlockStatement: function(r) {
            e.call(this, r), this.acceptKey(r, "program");
          }, ContentStatement: function() {
          }, CommentStatement: function() {
          }, SubExpression: c, PathExpression: function() {
          }, StringLiteral: function() {
          }, NumberLiteral: function() {
          }, BooleanLiteral: function() {
          }, UndefinedLiteral: function() {
          }, NullLiteral: function() {
          }, Hash: function(r) {
            this.acceptArray(r.pairs);
          }, HashPair: function(r) {
            this.acceptRequired(r, "value");
          } };
          function c(r) {
            this.acceptRequired(r, "path"), this.acceptArray(r.params), this.acceptKey(r, "hash");
          }
          function o(r) {
            c.call(this, r), this.acceptKey(r, "program"), this.acceptKey(r, "inverse");
          }
          function e(r) {
            this.acceptRequired(r, "name"), this.acceptArray(r.params), this.acceptKey(r, "hash");
          }
          t3.default = d;
        } }), ze = I({ "node_modules/@handlebars/parser/dist/cjs/whitespace-control.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__importDefault || function(a) {
            return a && a.__esModule ? a : { default: a };
          };
          Object.defineProperty(t3, "__esModule", { value: true });
          var h = f(Oe());
          function d(a) {
            a === void 0 && (a = {}), this.options = a;
          }
          d.prototype = new h.default(), d.prototype.Program = function(a) {
            var p = !this.options.ignoreStandalone, n = !this.isRootSeen;
            this.isRootSeen = true;
            for (var s = a.body, u = 0, i = s.length; u < i; u++) {
              var l = s[u], b = this.accept(l);
              if (b) {
                var P = c(s, u, n), E = o(s, u, n), v = b.openStandalone && P, _ = b.closeStandalone && E, y = b.inlineStandalone && P && E;
                b.close && e(s, u, true), b.open && r(s, u, true), p && y && (e(s, u), r(s, u) && l.type === "PartialStatement" && (l.indent = /([ \t]+$)/.exec(s[u - 1].original)[1])), p && v && (e((l.program || l.inverse).body), r(s, u)), p && _ && (e(s, u), r((l.inverse || l.program).body));
              }
            }
            return a;
          }, d.prototype.BlockStatement = d.prototype.DecoratorBlock = d.prototype.PartialBlockStatement = function(a) {
            this.accept(a.program), this.accept(a.inverse);
            var p = a.program || a.inverse, n = a.program && a.inverse, s = n, u = n;
            if (n && n.chained)
              for (s = n.body[0].program; u.chained; )
                u = u.body[u.body.length - 1].program;
            var i = { open: a.openStrip.open, close: a.closeStrip.close, openStandalone: o(p.body), closeStandalone: c((s || p).body) };
            if (a.openStrip.close && e(p.body, null, true), n) {
              var l = a.inverseStrip;
              l.open && r(p.body, null, true), l.close && e(s.body, null, true), a.closeStrip.open && r(u.body, null, true), !this.options.ignoreStandalone && c(p.body) && o(s.body) && (r(p.body), e(s.body));
            } else
              a.closeStrip.open && r(p.body, null, true);
            return i;
          }, d.prototype.Decorator = d.prototype.MustacheStatement = function(a) {
            return a.strip;
          }, d.prototype.PartialStatement = d.prototype.CommentStatement = function(a) {
            var p = a.strip || {};
            return { inlineStandalone: true, open: p.open, close: p.close };
          };
          function c(a, p, n) {
            p === void 0 && (p = a.length);
            var s = a[p - 1], u = a[p - 2];
            if (!s)
              return n;
            if (s.type === "ContentStatement")
              return (u || !n ? /\r?\n\s*?$/ : /(^|\r?\n)\s*?$/).test(s.original);
          }
          function o(a, p, n) {
            p === void 0 && (p = -1);
            var s = a[p + 1], u = a[p + 2];
            if (!s)
              return n;
            if (s.type === "ContentStatement")
              return (u || !n ? /^\s*?\r?\n/ : /^\s*?(\r?\n|$)/).test(s.original);
          }
          function e(a, p, n) {
            var s = a[p == null ? 0 : p + 1];
            if (!(!s || s.type !== "ContentStatement" || !n && s.rightStripped)) {
              var u = s.value;
              s.value = s.value.replace(n ? /^\s+/ : /^[ \t]*\r?\n?/, ""), s.rightStripped = s.value !== u;
            }
          }
          function r(a, p, n) {
            var s = a[p == null ? a.length - 1 : p - 1];
            if (!(!s || s.type !== "ContentStatement" || !n && s.leftStripped)) {
              var u = s.value;
              return s.value = s.value.replace(n ? /\s+$/ : /[ \t]+$/, ""), s.leftStripped = s.value !== u, s.leftStripped;
            }
          }
          t3.default = d;
        } }), Ge = I({ "node_modules/@handlebars/parser/dist/cjs/parser.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true });
          var f = function() {
            var h = function(N, k, B, O) {
              for (B = B || {}, O = N.length; O--; B[N[O]] = k)
                ;
              return B;
            }, d = [2, 44], c = [1, 20], o = [5, 14, 15, 19, 29, 34, 39, 44, 47, 48, 52, 56, 60], e = [1, 35], r = [1, 38], a = [1, 30], p = [1, 31], n = [1, 32], s = [1, 33], u = [1, 34], i = [1, 37], l = [14, 15, 19, 29, 34, 39, 44, 47, 48, 52, 56, 60], b = [14, 15, 19, 29, 34, 44, 47, 48, 52, 56, 60], P = [15, 18], E = [14, 15, 19, 29, 34, 47, 48, 52, 56, 60], v = [33, 64, 71, 79, 80, 81, 82, 83, 84], _ = [23, 33, 55, 64, 67, 71, 74, 79, 80, 81, 82, 83, 84], y = [1, 51], g = [23, 33, 55, 64, 67, 71, 74, 79, 80, 81, 82, 83, 84, 86], L = [2, 43], j = [55, 64, 71, 79, 80, 81, 82, 83, 84], x = [1, 58], w = [1, 59], H = [1, 66], m = [33, 64, 71, 74, 79, 80, 81, 82, 83, 84], C = [23, 64, 71, 79, 80, 81, 82, 83, 84], S = [1, 76], R = [64, 67, 71, 79, 80, 81, 82, 83, 84], M = [33, 74], V = [23, 33, 55, 67, 71, 74], G = [1, 106], K = [1, 118], U = [71, 76], Z = { trace: function() {
            }, yy: {}, symbols_: { error: 2, root: 3, program: 4, EOF: 5, program_repetition0: 6, statement: 7, mustache: 8, block: 9, rawBlock: 10, partial: 11, partialBlock: 12, content: 13, COMMENT: 14, CONTENT: 15, openRawBlock: 16, rawBlock_repetition0: 17, END_RAW_BLOCK: 18, OPEN_RAW_BLOCK: 19, helperName: 20, openRawBlock_repetition0: 21, openRawBlock_option0: 22, CLOSE_RAW_BLOCK: 23, openBlock: 24, block_option0: 25, closeBlock: 26, openInverse: 27, block_option1: 28, OPEN_BLOCK: 29, openBlock_repetition0: 30, openBlock_option0: 31, openBlock_option1: 32, CLOSE: 33, OPEN_INVERSE: 34, openInverse_repetition0: 35, openInverse_option0: 36, openInverse_option1: 37, openInverseChain: 38, OPEN_INVERSE_CHAIN: 39, openInverseChain_repetition0: 40, openInverseChain_option0: 41, openInverseChain_option1: 42, inverseAndProgram: 43, INVERSE: 44, inverseChain: 45, inverseChain_option0: 46, OPEN_ENDBLOCK: 47, OPEN: 48, expr: 49, mustache_repetition0: 50, mustache_option0: 51, OPEN_UNESCAPED: 52, mustache_repetition1: 53, mustache_option1: 54, CLOSE_UNESCAPED: 55, OPEN_PARTIAL: 56, partial_repetition0: 57, partial_option0: 58, openPartialBlock: 59, OPEN_PARTIAL_BLOCK: 60, openPartialBlock_repetition0: 61, openPartialBlock_option0: 62, sexpr: 63, OPEN_SEXPR: 64, sexpr_repetition0: 65, sexpr_option0: 66, CLOSE_SEXPR: 67, hash: 68, hash_repetition_plus0: 69, hashSegment: 70, ID: 71, EQUALS: 72, blockParams: 73, OPEN_BLOCK_PARAMS: 74, blockParams_repetition_plus0: 75, CLOSE_BLOCK_PARAMS: 76, path: 77, dataName: 78, STRING: 79, NUMBER: 80, BOOLEAN: 81, UNDEFINED: 82, NULL: 83, DATA: 84, pathSegments: 85, SEP: 86, $accept: 0, $end: 1 }, terminals_: { 2: "error", 5: "EOF", 14: "COMMENT", 15: "CONTENT", 18: "END_RAW_BLOCK", 19: "OPEN_RAW_BLOCK", 23: "CLOSE_RAW_BLOCK", 29: "OPEN_BLOCK", 33: "CLOSE", 34: "OPEN_INVERSE", 39: "OPEN_INVERSE_CHAIN", 44: "INVERSE", 47: "OPEN_ENDBLOCK", 48: "OPEN", 52: "OPEN_UNESCAPED", 55: "CLOSE_UNESCAPED", 56: "OPEN_PARTIAL", 60: "OPEN_PARTIAL_BLOCK", 64: "OPEN_SEXPR", 67: "CLOSE_SEXPR", 71: "ID", 72: "EQUALS", 74: "OPEN_BLOCK_PARAMS", 76: "CLOSE_BLOCK_PARAMS", 79: "STRING", 80: "NUMBER", 81: "BOOLEAN", 82: "UNDEFINED", 83: "NULL", 84: "DATA", 86: "SEP" }, productions_: [0, [3, 2], [4, 1], [7, 1], [7, 1], [7, 1], [7, 1], [7, 1], [7, 1], [7, 1], [13, 1], [10, 3], [16, 5], [9, 4], [9, 4], [24, 6], [27, 6], [38, 6], [43, 2], [45, 3], [45, 1], [26, 3], [8, 5], [8, 5], [11, 5], [12, 3], [59, 5], [49, 1], [49, 1], [63, 5], [68, 1], [70, 3], [73, 3], [20, 1], [20, 1], [20, 1], [20, 1], [20, 1], [20, 1], [20, 1], [78, 2], [77, 1], [85, 3], [85, 1], [6, 0], [6, 2], [17, 0], [17, 2], [21, 0], [21, 2], [22, 0], [22, 1], [25, 0], [25, 1], [28, 0], [28, 1], [30, 0], [30, 2], [31, 0], [31, 1], [32, 0], [32, 1], [35, 0], [35, 2], [36, 0], [36, 1], [37, 0], [37, 1], [40, 0], [40, 2], [41, 0], [41, 1], [42, 0], [42, 1], [46, 0], [46, 1], [50, 0], [50, 2], [51, 0], [51, 1], [53, 0], [53, 2], [54, 0], [54, 1], [57, 0], [57, 2], [58, 0], [58, 1], [61, 0], [61, 2], [62, 0], [62, 1], [65, 0], [65, 2], [66, 0], [66, 1], [69, 1], [69, 2], [75, 1], [75, 2]], performAction: function(k, B, O, q, z, A, Q) {
              var D = A.length - 1;
              switch (z) {
                case 1:
                  return A[D - 1];
                case 2:
                  this.$ = q.prepareProgram(A[D]);
                  break;
                case 3:
                case 4:
                case 5:
                case 6:
                case 7:
                case 8:
                case 20:
                case 27:
                case 28:
                case 33:
                case 34:
                  this.$ = A[D];
                  break;
                case 9:
                  this.$ = { type: "CommentStatement", value: q.stripComment(A[D]), strip: q.stripFlags(A[D], A[D]), loc: q.locInfo(this._$) };
                  break;
                case 10:
                  this.$ = { type: "ContentStatement", original: A[D], value: A[D], loc: q.locInfo(this._$) };
                  break;
                case 11:
                  this.$ = q.prepareRawBlock(A[D - 2], A[D - 1], A[D], this._$);
                  break;
                case 12:
                  this.$ = { path: A[D - 3], params: A[D - 2], hash: A[D - 1] };
                  break;
                case 13:
                  this.$ = q.prepareBlock(A[D - 3], A[D - 2], A[D - 1], A[D], false, this._$);
                  break;
                case 14:
                  this.$ = q.prepareBlock(A[D - 3], A[D - 2], A[D - 1], A[D], true, this._$);
                  break;
                case 15:
                  this.$ = { open: A[D - 5], path: A[D - 4], params: A[D - 3], hash: A[D - 2], blockParams: A[D - 1], strip: q.stripFlags(A[D - 5], A[D]) };
                  break;
                case 16:
                case 17:
                  this.$ = { path: A[D - 4], params: A[D - 3], hash: A[D - 2], blockParams: A[D - 1], strip: q.stripFlags(A[D - 5], A[D]) };
                  break;
                case 18:
                  this.$ = { strip: q.stripFlags(A[D - 1], A[D - 1]), program: A[D] };
                  break;
                case 19:
                  var $2 = q.prepareBlock(A[D - 2], A[D - 1], A[D], A[D], false, this._$), oe = q.prepareProgram([$2], A[D - 1].loc);
                  oe.chained = true, this.$ = { strip: A[D - 2].strip, program: oe, chain: true };
                  break;
                case 21:
                  this.$ = { path: A[D - 1], strip: q.stripFlags(A[D - 2], A[D]) };
                  break;
                case 22:
                case 23:
                  this.$ = q.prepareMustache(A[D - 3], A[D - 2], A[D - 1], A[D - 4], q.stripFlags(A[D - 4], A[D]), this._$);
                  break;
                case 24:
                  this.$ = { type: "PartialStatement", name: A[D - 3], params: A[D - 2], hash: A[D - 1], indent: "", strip: q.stripFlags(A[D - 4], A[D]), loc: q.locInfo(this._$) };
                  break;
                case 25:
                  this.$ = q.preparePartialBlock(A[D - 2], A[D - 1], A[D], this._$);
                  break;
                case 26:
                  this.$ = { path: A[D - 3], params: A[D - 2], hash: A[D - 1], strip: q.stripFlags(A[D - 4], A[D]) };
                  break;
                case 29:
                  this.$ = { type: "SubExpression", path: A[D - 3], params: A[D - 2], hash: A[D - 1], loc: q.locInfo(this._$) };
                  break;
                case 30:
                  this.$ = { type: "Hash", pairs: A[D], loc: q.locInfo(this._$) };
                  break;
                case 31:
                  this.$ = { type: "HashPair", key: q.id(A[D - 2]), value: A[D], loc: q.locInfo(this._$) };
                  break;
                case 32:
                  this.$ = q.id(A[D - 1]);
                  break;
                case 35:
                  this.$ = { type: "StringLiteral", value: A[D], original: A[D], loc: q.locInfo(this._$) };
                  break;
                case 36:
                  this.$ = { type: "NumberLiteral", value: Number(A[D]), original: Number(A[D]), loc: q.locInfo(this._$) };
                  break;
                case 37:
                  this.$ = { type: "BooleanLiteral", value: A[D] === "true", original: A[D] === "true", loc: q.locInfo(this._$) };
                  break;
                case 38:
                  this.$ = { type: "UndefinedLiteral", original: void 0, value: void 0, loc: q.locInfo(this._$) };
                  break;
                case 39:
                  this.$ = { type: "NullLiteral", original: null, value: null, loc: q.locInfo(this._$) };
                  break;
                case 40:
                  this.$ = q.preparePath(true, A[D], this._$);
                  break;
                case 41:
                  this.$ = q.preparePath(false, A[D], this._$);
                  break;
                case 42:
                  A[D - 2].push({ part: q.id(A[D]), original: A[D], separator: A[D - 1] }), this.$ = A[D - 2];
                  break;
                case 43:
                  this.$ = [{ part: q.id(A[D]), original: A[D] }];
                  break;
                case 44:
                case 46:
                case 48:
                case 56:
                case 62:
                case 68:
                case 76:
                case 80:
                case 84:
                case 88:
                case 92:
                  this.$ = [];
                  break;
                case 45:
                case 47:
                case 49:
                case 57:
                case 63:
                case 69:
                case 77:
                case 81:
                case 85:
                case 89:
                case 93:
                case 97:
                case 99:
                  A[D - 1].push(A[D]);
                  break;
                case 96:
                case 98:
                  this.$ = [A[D]];
                  break;
              }
            }, table: [h([5, 14, 15, 19, 29, 34, 48, 52, 56, 60], d, { 3: 1, 4: 2, 6: 3 }), { 1: [3] }, { 5: [1, 4] }, h([5, 39, 44, 47], [2, 2], { 7: 5, 8: 6, 9: 7, 10: 8, 11: 9, 12: 10, 13: 11, 24: 15, 27: 16, 16: 17, 59: 19, 14: [1, 12], 15: c, 19: [1, 23], 29: [1, 21], 34: [1, 22], 48: [1, 13], 52: [1, 14], 56: [1, 18], 60: [1, 24] }), { 1: [2, 1] }, h(o, [2, 45]), h(o, [2, 3]), h(o, [2, 4]), h(o, [2, 5]), h(o, [2, 6]), h(o, [2, 7]), h(o, [2, 8]), h(o, [2, 9]), { 20: 26, 49: 25, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 20: 26, 49: 39, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(l, d, { 6: 3, 4: 40 }), h(b, d, { 6: 3, 4: 41 }), h(P, [2, 46], { 17: 42 }), { 20: 26, 49: 43, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(E, d, { 6: 3, 4: 44 }), h([5, 14, 15, 18, 19, 29, 34, 39, 44, 47, 48, 52, 56, 60], [2, 10]), { 20: 45, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 20: 46, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 20: 47, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 20: 26, 49: 48, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(v, [2, 76], { 50: 49 }), h(_, [2, 27]), h(_, [2, 28]), h(_, [2, 33]), h(_, [2, 34]), h(_, [2, 35]), h(_, [2, 36]), h(_, [2, 37]), h(_, [2, 38]), h(_, [2, 39]), { 20: 26, 49: 50, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(_, [2, 41], { 86: y }), { 71: r, 85: 52 }, h(g, L), h(j, [2, 80], { 53: 53 }), { 25: 54, 38: 56, 39: x, 43: 57, 44: w, 45: 55, 47: [2, 52] }, { 28: 60, 43: 61, 44: w, 47: [2, 54] }, { 13: 63, 15: c, 18: [1, 62] }, h(v, [2, 84], { 57: 64 }), { 26: 65, 47: H }, h(m, [2, 56], { 30: 67 }), h(m, [2, 62], { 35: 68 }), h(C, [2, 48], { 21: 69 }), h(v, [2, 88], { 61: 70 }), { 20: 26, 33: [2, 78], 49: 72, 51: 71, 63: 27, 64: e, 68: 73, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(R, [2, 92], { 65: 77 }), { 71: [1, 78] }, h(_, [2, 40], { 86: y }), { 20: 26, 49: 80, 54: 79, 55: [2, 82], 63: 27, 64: e, 68: 81, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 26: 82, 47: H }, { 47: [2, 53] }, h(l, d, { 6: 3, 4: 83 }), { 47: [2, 20] }, { 20: 84, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(E, d, { 6: 3, 4: 85 }), { 26: 86, 47: H }, { 47: [2, 55] }, h(o, [2, 11]), h(P, [2, 47]), { 20: 26, 33: [2, 86], 49: 88, 58: 87, 63: 27, 64: e, 68: 89, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(o, [2, 25]), { 20: 90, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(M, [2, 58], { 20: 26, 63: 27, 77: 28, 78: 29, 85: 36, 69: 74, 70: 75, 31: 91, 49: 92, 68: 93, 64: e, 71: S, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i }), h(M, [2, 64], { 20: 26, 63: 27, 77: 28, 78: 29, 85: 36, 69: 74, 70: 75, 36: 94, 49: 95, 68: 96, 64: e, 71: S, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i }), { 20: 26, 22: 97, 23: [2, 50], 49: 98, 63: 27, 64: e, 68: 99, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 20: 26, 33: [2, 90], 49: 101, 62: 100, 63: 27, 64: e, 68: 102, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 33: [1, 103] }, h(v, [2, 77]), { 33: [2, 79] }, h([23, 33, 55, 67, 74], [2, 30], { 70: 104, 71: [1, 105] }), h(V, [2, 96]), h(g, L, { 72: G }), { 20: 26, 49: 108, 63: 27, 64: e, 66: 107, 67: [2, 94], 68: 109, 69: 74, 70: 75, 71: S, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, h(g, [2, 42]), { 55: [1, 110] }, h(j, [2, 81]), { 55: [2, 83] }, h(o, [2, 13]), { 38: 56, 39: x, 43: 57, 44: w, 45: 112, 46: 111, 47: [2, 74] }, h(m, [2, 68], { 40: 113 }), { 47: [2, 18] }, h(o, [2, 14]), { 33: [1, 114] }, h(v, [2, 85]), { 33: [2, 87] }, { 33: [1, 115] }, { 32: 116, 33: [2, 60], 73: 117, 74: K }, h(m, [2, 57]), h(M, [2, 59]), { 33: [2, 66], 37: 119, 73: 120, 74: K }, h(m, [2, 63]), h(M, [2, 65]), { 23: [1, 121] }, h(C, [2, 49]), { 23: [2, 51] }, { 33: [1, 122] }, h(v, [2, 89]), { 33: [2, 91] }, h(o, [2, 22]), h(V, [2, 97]), { 72: G }, { 20: 26, 49: 123, 63: 27, 64: e, 71: r, 77: 28, 78: 29, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i, 85: 36 }, { 67: [1, 124] }, h(R, [2, 93]), { 67: [2, 95] }, h(o, [2, 23]), { 47: [2, 19] }, { 47: [2, 75] }, h(M, [2, 70], { 20: 26, 63: 27, 77: 28, 78: 29, 85: 36, 69: 74, 70: 75, 41: 125, 49: 126, 68: 127, 64: e, 71: S, 79: a, 80: p, 81: n, 82: s, 83: u, 84: i }), h(o, [2, 24]), h(o, [2, 21]), { 33: [1, 128] }, { 33: [2, 61] }, { 71: [1, 130], 75: 129 }, { 33: [1, 131] }, { 33: [2, 67] }, h(P, [2, 12]), h(E, [2, 26]), h(V, [2, 31]), h(_, [2, 29]), { 33: [2, 72], 42: 132, 73: 133, 74: K }, h(m, [2, 69]), h(M, [2, 71]), h(l, [2, 15]), { 71: [1, 135], 76: [1, 134] }, h(U, [2, 98]), h(b, [2, 16]), { 33: [1, 136] }, { 33: [2, 73] }, { 33: [2, 32] }, h(U, [2, 99]), h(l, [2, 17])], defaultActions: { 4: [2, 1], 55: [2, 53], 57: [2, 20], 61: [2, 55], 73: [2, 79], 81: [2, 83], 85: [2, 18], 89: [2, 87], 99: [2, 51], 102: [2, 91], 109: [2, 95], 111: [2, 19], 112: [2, 75], 117: [2, 61], 120: [2, 67], 133: [2, 73], 134: [2, 32] }, parseError: function(k, B) {
              if (B.recoverable)
                this.trace(k);
              else {
                var O = new Error(k);
                throw O.hash = B, O;
              }
            }, parse: function(k) {
              var B = this, O = [0], q = [], z = [null], A = [], Q = this.table, D = "", $2 = 0, oe = 0, Ie = 0, et = 2, Re = 1, tt = A.slice.call(arguments, 1), Y = Object.create(this.lexer), ie = { yy: {} };
              for (var Ae in this.yy)
                Object.prototype.hasOwnProperty.call(this.yy, Ae) && (ie.yy[Ae] = this.yy[Ae]);
              Y.setInput(k, ie.yy), ie.yy.lexer = Y, ie.yy.parser = this, typeof Y.yylloc > "u" && (Y.yylloc = {});
              var Ee = Y.yylloc;
              A.push(Ee);
              var rt = Y.options && Y.options.ranges;
              typeof ie.yy.parseError == "function" ? this.parseError = ie.yy.parseError : this.parseError = Object.getPrototypeOf(this).parseError;
              function $t(te) {
                O.length = O.length - 2 * te, z.length = z.length - te, A.length = A.length - te;
              }
              e:
                var nt = function() {
                  var te;
                  return te = Y.lex() || Re, typeof te != "number" && (te = B.symbols_[te] || te), te;
                };
              for (var J, _e, se, ee, er, Se, ae = {}, de, re, qe, pe; ; ) {
                if (se = O[O.length - 1], this.defaultActions[se] ? ee = this.defaultActions[se] : ((J === null || typeof J > "u") && (J = nt()), ee = Q[se] && Q[se][J]), typeof ee > "u" || !ee.length || !ee[0]) {
                  var Ce = "";
                  pe = [];
                  for (de in Q[se])
                    this.terminals_[de] && de > et && pe.push("'" + this.terminals_[de] + "'");
                  Y.showPosition ? Ce = "Parse error on line " + ($2 + 1) + `:
` + Y.showPosition() + `
Expecting ` + pe.join(", ") + ", got '" + (this.terminals_[J] || J) + "'" : Ce = "Parse error on line " + ($2 + 1) + ": Unexpected " + (J == Re ? "end of input" : "'" + (this.terminals_[J] || J) + "'"), this.parseError(Ce, { text: Y.match, token: this.terminals_[J] || J, line: Y.yylineno, loc: Ee, expected: pe });
                }
                if (ee[0] instanceof Array && ee.length > 1)
                  throw new Error("Parse Error: multiple actions possible at state: " + se + ", token: " + J);
                switch (ee[0]) {
                  case 1:
                    O.push(J), z.push(Y.yytext), A.push(Y.yylloc), O.push(ee[1]), J = null, _e ? (J = _e, _e = null) : (oe = Y.yyleng, D = Y.yytext, $2 = Y.yylineno, Ee = Y.yylloc, Ie > 0 && Ie--);
                    break;
                  case 2:
                    if (re = this.productions_[ee[1]][1], ae.$ = z[z.length - re], ae._$ = { first_line: A[A.length - (re || 1)].first_line, last_line: A[A.length - 1].last_line, first_column: A[A.length - (re || 1)].first_column, last_column: A[A.length - 1].last_column }, rt && (ae._$.range = [A[A.length - (re || 1)].range[0], A[A.length - 1].range[1]]), Se = this.performAction.apply(ae, [D, oe, $2, ie.yy, ee[1], z, A].concat(tt)), typeof Se < "u")
                      return Se;
                    re && (O = O.slice(0, -1 * re * 2), z = z.slice(0, -1 * re), A = A.slice(0, -1 * re)), O.push(this.productions_[ee[1]][0]), z.push(ae.$), A.push(ae._$), qe = Q[O[O.length - 2]][O[O.length - 1]], O.push(qe);
                    break;
                  case 3:
                    return true;
                }
              }
              return true;
            } }, W = function() {
              var N = { EOF: 1, parseError: function(B, O) {
                if (this.yy.parser)
                  this.yy.parser.parseError(B, O);
                else
                  throw new Error(B);
              }, setInput: function(k, B) {
                return this.yy = B || this.yy || {}, this._input = k, this._more = this._backtrack = this.done = false, this.yylineno = this.yyleng = 0, this.yytext = this.matched = this.match = "", this.conditionStack = ["INITIAL"], this.yylloc = { first_line: 1, first_column: 0, last_line: 1, last_column: 0 }, this.options.ranges && (this.yylloc.range = [0, 0]), this.offset = 0, this;
              }, input: function() {
                var k = this._input[0];
                this.yytext += k, this.yyleng++, this.offset++, this.match += k, this.matched += k;
                var B = k.match(/(?:\r\n?|\n).*/g);
                return B ? (this.yylineno++, this.yylloc.last_line++) : this.yylloc.last_column++, this.options.ranges && this.yylloc.range[1]++, this._input = this._input.slice(1), k;
              }, unput: function(k) {
                var B = k.length, O = k.split(/(?:\r\n?|\n)/g);
                this._input = k + this._input, this.yytext = this.yytext.substr(0, this.yytext.length - B), this.offset -= B;
                var q = this.match.split(/(?:\r\n?|\n)/g);
                this.match = this.match.substr(0, this.match.length - 1), this.matched = this.matched.substr(0, this.matched.length - 1), O.length - 1 && (this.yylineno -= O.length - 1);
                var z = this.yylloc.range;
                return this.yylloc = { first_line: this.yylloc.first_line, last_line: this.yylineno + 1, first_column: this.yylloc.first_column, last_column: O ? (O.length === q.length ? this.yylloc.first_column : 0) + q[q.length - O.length].length - O[0].length : this.yylloc.first_column - B }, this.options.ranges && (this.yylloc.range = [z[0], z[0] + this.yyleng - B]), this.yyleng = this.yytext.length, this;
              }, more: function() {
                return this._more = true, this;
              }, reject: function() {
                if (this.options.backtrack_lexer)
                  this._backtrack = true;
                else
                  return this.parseError("Lexical error on line " + (this.yylineno + 1) + `. You can only invoke reject() in the lexer when the lexer is of the backtracking persuasion (options.backtrack_lexer = true).
` + this.showPosition(), { text: "", token: null, line: this.yylineno });
                return this;
              }, less: function(k) {
                this.unput(this.match.slice(k));
              }, pastInput: function() {
                var k = this.matched.substr(0, this.matched.length - this.match.length);
                return (k.length > 20 ? "..." : "") + k.substr(-20).replace(/\n/g, "");
              }, upcomingInput: function() {
                var k = this.match;
                return k.length < 20 && (k += this._input.substr(0, 20 - k.length)), (k.substr(0, 20) + (k.length > 20 ? "..." : "")).replace(/\n/g, "");
              }, showPosition: function() {
                var k = this.pastInput(), B = new Array(k.length + 1).join("-");
                return k + this.upcomingInput() + `
` + B + "^";
              }, test_match: function(k, B) {
                var O, q, z;
                if (this.options.backtrack_lexer && (z = { yylineno: this.yylineno, yylloc: { first_line: this.yylloc.first_line, last_line: this.last_line, first_column: this.yylloc.first_column, last_column: this.yylloc.last_column }, yytext: this.yytext, match: this.match, matches: this.matches, matched: this.matched, yyleng: this.yyleng, offset: this.offset, _more: this._more, _input: this._input, yy: this.yy, conditionStack: this.conditionStack.slice(0), done: this.done }, this.options.ranges && (z.yylloc.range = this.yylloc.range.slice(0))), q = k[0].match(/(?:\r\n?|\n).*/g), q && (this.yylineno += q.length), this.yylloc = { first_line: this.yylloc.last_line, last_line: this.yylineno + 1, first_column: this.yylloc.last_column, last_column: q ? q[q.length - 1].length - q[q.length - 1].match(/\r?\n?/)[0].length : this.yylloc.last_column + k[0].length }, this.yytext += k[0], this.match += k[0], this.matches = k, this.yyleng = this.yytext.length, this.options.ranges && (this.yylloc.range = [this.offset, this.offset += this.yyleng]), this._more = false, this._backtrack = false, this._input = this._input.slice(k[0].length), this.matched += k[0], O = this.performAction.call(this, this.yy, this, B, this.conditionStack[this.conditionStack.length - 1]), this.done && this._input && (this.done = false), O)
                  return O;
                if (this._backtrack) {
                  for (var A in z)
                    this[A] = z[A];
                  return false;
                }
                return false;
              }, next: function() {
                if (this.done)
                  return this.EOF;
                this._input || (this.done = true);
                var k, B, O, q;
                this._more || (this.yytext = "", this.match = "");
                for (var z = this._currentRules(), A = 0; A < z.length; A++)
                  if (O = this._input.match(this.rules[z[A]]), O && (!B || O[0].length > B[0].length)) {
                    if (B = O, q = A, this.options.backtrack_lexer) {
                      if (k = this.test_match(O, z[A]), k !== false)
                        return k;
                      if (this._backtrack) {
                        B = false;
                        continue;
                      } else
                        return false;
                    } else if (!this.options.flex)
                      break;
                  }
                return B ? (k = this.test_match(B, z[q]), k !== false ? k : false) : this._input === "" ? this.EOF : this.parseError("Lexical error on line " + (this.yylineno + 1) + `. Unrecognized text.
` + this.showPosition(), { text: "", token: null, line: this.yylineno });
              }, lex: function() {
                var B = this.next();
                return B || this.lex();
              }, begin: function(B) {
                this.conditionStack.push(B);
              }, popState: function() {
                var B = this.conditionStack.length - 1;
                return B > 0 ? this.conditionStack.pop() : this.conditionStack[0];
              }, _currentRules: function() {
                return this.conditionStack.length && this.conditionStack[this.conditionStack.length - 1] ? this.conditions[this.conditionStack[this.conditionStack.length - 1]].rules : this.conditions.INITIAL.rules;
              }, topState: function(B) {
                return B = this.conditionStack.length - 1 - Math.abs(B || 0), B >= 0 ? this.conditionStack[B] : "INITIAL";
              }, pushState: function(B) {
                this.begin(B);
              }, stateStackSize: function() {
                return this.conditionStack.length;
              }, options: {}, performAction: function(B, O, q, z) {
                function A(D, $2) {
                  return O.yytext = O.yytext.substring(D, O.yyleng - $2 + D);
                }
                var Q = z;
                switch (q) {
                  case 0:
                    if (O.yytext.slice(-2) === "\\\\" ? (A(0, 1), this.begin("mu")) : O.yytext.slice(-1) === "\\" ? (A(0, 1), this.begin("emu")) : this.begin("mu"), O.yytext)
                      return 15;
                    break;
                  case 1:
                    return 15;
                  case 2:
                    return this.popState(), 15;
                    break;
                  case 3:
                    return this.begin("raw"), 15;
                    break;
                  case 4:
                    return this.popState(), this.conditionStack[this.conditionStack.length - 1] === "raw" ? 15 : (A(5, 9), 18);
                  case 5:
                    return 15;
                  case 6:
                    return this.popState(), 14;
                    break;
                  case 7:
                    return 64;
                  case 8:
                    return 67;
                  case 9:
                    return 19;
                  case 10:
                    return this.popState(), this.begin("raw"), 23;
                    break;
                  case 11:
                    return 56;
                  case 12:
                    return 60;
                  case 13:
                    return 29;
                  case 14:
                    return 47;
                  case 15:
                    return this.popState(), 44;
                    break;
                  case 16:
                    return this.popState(), 44;
                    break;
                  case 17:
                    return 34;
                  case 18:
                    return 39;
                  case 19:
                    return 52;
                  case 20:
                    return 48;
                  case 21:
                    this.unput(O.yytext), this.popState(), this.begin("com");
                    break;
                  case 22:
                    return this.popState(), 14;
                    break;
                  case 23:
                    return 48;
                  case 24:
                    return 72;
                  case 25:
                    return 71;
                  case 26:
                    return 71;
                  case 27:
                    return 86;
                  case 28:
                    break;
                  case 29:
                    return this.popState(), 55;
                    break;
                  case 30:
                    return this.popState(), 33;
                    break;
                  case 31:
                    return O.yytext = A(1, 2).replace(/\\"/g, '"'), 79;
                    break;
                  case 32:
                    return O.yytext = A(1, 2).replace(/\\'/g, "'"), 79;
                    break;
                  case 33:
                    return 84;
                  case 34:
                    return 81;
                  case 35:
                    return 81;
                  case 36:
                    return 82;
                  case 37:
                    return 83;
                  case 38:
                    return 80;
                  case 39:
                    return 74;
                  case 40:
                    return 76;
                  case 41:
                    return 71;
                  case 42:
                    return O.yytext = O.yytext.replace(/\\([\\\]])/g, "$1"), 71;
                    break;
                  case 43:
                    return "INVALID";
                  case 44:
                    return 5;
                }
              }, rules: [/^(?:[^\x00]*?(?=(\{\{)))/, /^(?:[^\x00]+)/, /^(?:[^\x00]{2,}?(?=(\{\{|\\\{\{|\\\\\{\{|$)))/, /^(?:\{\{\{\{(?=[^/]))/, /^(?:\{\{\{\{\/[^\s!"#%-,\.\/;->@\[-\^`\{-~]+(?=[=}\s\/.])\}\}\}\})/, /^(?:[^\x00]+?(?=(\{\{\{\{)))/, /^(?:[\s\S]*?--(~)?\}\})/, /^(?:\()/, /^(?:\))/, /^(?:\{\{\{\{)/, /^(?:\}\}\}\})/, /^(?:\{\{(~)?>)/, /^(?:\{\{(~)?#>)/, /^(?:\{\{(~)?#\*?)/, /^(?:\{\{(~)?\/)/, /^(?:\{\{(~)?\^\s*(~)?\}\})/, /^(?:\{\{(~)?\s*else\s*(~)?\}\})/, /^(?:\{\{(~)?\^)/, /^(?:\{\{(~)?\s*else\b)/, /^(?:\{\{(~)?\{)/, /^(?:\{\{(~)?&)/, /^(?:\{\{(~)?!--)/, /^(?:\{\{(~)?![\s\S]*?\}\})/, /^(?:\{\{(~)?\*?)/, /^(?:=)/, /^(?:\.\.)/, /^(?:\.(?=([=~}\s\/.)|])))/, /^(?:[\/.])/, /^(?:\s+)/, /^(?:\}(~)?\}\})/, /^(?:(~)?\}\})/, /^(?:"(\\["]|[^"])*")/, /^(?:'(\\[']|[^'])*')/, /^(?:@)/, /^(?:true(?=([~}\s)])))/, /^(?:false(?=([~}\s)])))/, /^(?:undefined(?=([~}\s)])))/, /^(?:null(?=([~}\s)])))/, /^(?:-?[0-9]+(?:\.[0-9]+)?(?=([~}\s)])))/, /^(?:as\s+\|)/, /^(?:\|)/, /^(?:([^\s!"#%-,\.\/;->@\[-\^`\{-~]+(?=([=~}\s\/.)|]))))/, /^(?:\[(\\\]|[^\]])*\])/, /^(?:.)/, /^(?:$)/], conditions: { mu: { rules: [7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44], inclusive: false }, emu: { rules: [2], inclusive: false }, com: { rules: [6], inclusive: false }, raw: { rules: [3, 4, 5], inclusive: false }, INITIAL: { rules: [0, 1, 44], inclusive: true } } };
              return N;
            }();
            Z.lexer = W;
            function T() {
              this.yy = {};
            }
            return T.prototype = Z, Z.Parser = T, new T();
          }();
          t3.default = f;
        } }), Nt = I({ "node_modules/@handlebars/parser/dist/cjs/printer.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__importDefault || function(o) {
            return o && o.__esModule ? o : { default: o };
          };
          Object.defineProperty(t3, "__esModule", { value: true }), t3.PrintVisitor = t3.print = void 0;
          var h = f(Oe());
          function d(o) {
            return new c().accept(o);
          }
          t3.print = d;
          function c() {
            this.padding = 0;
          }
          t3.PrintVisitor = c, c.prototype = new h.default(), c.prototype.pad = function(o) {
            for (var e = "", r = 0, a = this.padding; r < a; r++)
              e += "  ";
            return e += o + `
`, e;
          }, c.prototype.Program = function(o) {
            var e = "", r = o.body, a, p;
            if (o.blockParams) {
              var n = "BLOCK PARAMS: [";
              for (a = 0, p = o.blockParams.length; a < p; a++)
                n += " " + o.blockParams[a];
              n += " ]", e += this.pad(n);
            }
            for (a = 0, p = r.length; a < p; a++)
              e += this.accept(r[a]);
            return this.padding--, e;
          }, c.prototype.MustacheStatement = function(o) {
            return this.pad("{{ " + this.SubExpression(o) + " }}");
          }, c.prototype.Decorator = function(o) {
            return this.pad("{{ DIRECTIVE " + this.SubExpression(o) + " }}");
          }, c.prototype.BlockStatement = c.prototype.DecoratorBlock = function(o) {
            var e = "";
            return e += this.pad((o.type === "DecoratorBlock" ? "DIRECTIVE " : "") + "BLOCK:"), this.padding++, e += this.pad(this.SubExpression(o)), o.program && (e += this.pad("PROGRAM:"), this.padding++, e += this.accept(o.program), this.padding--), o.inverse && (o.program && this.padding++, e += this.pad("{{^}}"), this.padding++, e += this.accept(o.inverse), this.padding--, o.program && this.padding--), this.padding--, e;
          }, c.prototype.PartialStatement = function(o) {
            var e = "PARTIAL:" + o.name.original;
            return o.params[0] && (e += " " + this.accept(o.params[0])), o.hash && (e += " " + this.accept(o.hash)), this.pad("{{> " + e + " }}");
          }, c.prototype.PartialBlockStatement = function(o) {
            var e = "PARTIAL BLOCK:" + o.name.original;
            return o.params[0] && (e += " " + this.accept(o.params[0])), o.hash && (e += " " + this.accept(o.hash)), e += " " + this.pad("PROGRAM:"), this.padding++, e += this.accept(o.program), this.padding--, this.pad("{{> " + e + " }}");
          }, c.prototype.ContentStatement = function(o) {
            return this.pad("CONTENT[ '" + o.value + "' ]");
          }, c.prototype.CommentStatement = function(o) {
            return this.pad("{{! '" + o.value + "' }}");
          }, c.prototype.SubExpression = function(o) {
            for (var e = o.params, r = [], a, p = 0, n = e.length; p < n; p++)
              r.push(this.accept(e[p]));
            return e = "[" + r.join(", ") + "]", a = o.hash ? " " + this.accept(o.hash) : "", this.accept(o.path) + " " + e + a;
          }, c.prototype.PathExpression = function(o) {
            var e = o.parts.join("/");
            return (o.data ? "@" : "") + "PATH:" + e;
          }, c.prototype.StringLiteral = function(o) {
            return '"' + o.value + '"';
          }, c.prototype.NumberLiteral = function(o) {
            return "NUMBER{" + o.value + "}";
          }, c.prototype.BooleanLiteral = function(o) {
            return "BOOLEAN{" + o.value + "}";
          }, c.prototype.UndefinedLiteral = function() {
            return "UNDEFINED";
          }, c.prototype.NullLiteral = function() {
            return "NULL";
          }, c.prototype.Hash = function(o) {
            for (var e = o.pairs, r = [], a = 0, p = e.length; a < p; a++)
              r.push(this.accept(e[a]));
            return "HASH{" + r.join(", ") + "}";
          }, c.prototype.HashPair = function(o) {
            return o.key + "=" + this.accept(o.value);
          };
        } }), Lt = I({ "node_modules/@handlebars/parser/dist/cjs/helpers.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__importDefault || function(l) {
            return l && l.__esModule ? l : { default: l };
          };
          Object.defineProperty(t3, "__esModule", { value: true }), t3.preparePartialBlock = t3.prepareProgram = t3.prepareBlock = t3.prepareRawBlock = t3.prepareMustache = t3.preparePath = t3.stripComment = t3.stripFlags = t3.id = t3.SourceLocation = void 0;
          var h = f(Be());
          function d(l, b) {
            if (b = b.path ? b.path.original : b, l.path.original !== b) {
              var P = { loc: l.path.loc };
              throw new h.default(l.path.original + " doesn't match " + b, P);
            }
          }
          function c(l, b) {
            this.source = l, this.start = { line: b.first_line, column: b.first_column }, this.end = { line: b.last_line, column: b.last_column };
          }
          t3.SourceLocation = c;
          function o(l) {
            return /^\[.*\]$/.test(l) ? l.substring(1, l.length - 1) : l;
          }
          t3.id = o;
          function e(l, b) {
            return { open: l.charAt(2) === "~", close: b.charAt(b.length - 3) === "~" };
          }
          t3.stripFlags = e;
          function r(l) {
            return l.replace(/^\{\{~?!-?-?/, "").replace(/-?-?~?\}\}$/, "");
          }
          t3.stripComment = r;
          function a(l, b, P) {
            P = this.locInfo(P);
            for (var E = l ? "@" : "", v = [], _ = 0, y = 0, g = b.length; y < g; y++) {
              var L = b[y].part, j = b[y].original !== L;
              if (E += (b[y].separator || "") + L, !j && (L === ".." || L === "." || L === "this")) {
                if (v.length > 0)
                  throw new h.default("Invalid path: " + E, { loc: P });
                L === ".." && _++;
              } else
                v.push(L);
            }
            return { type: "PathExpression", data: l, depth: _, parts: v, original: E, loc: P };
          }
          t3.preparePath = a;
          function p(l, b, P, E, v, _) {
            var y = E.charAt(3) || E.charAt(2), g = y !== "{" && y !== "&", L = /\*/.test(E);
            return { type: L ? "Decorator" : "MustacheStatement", path: l, params: b, hash: P, escaped: g, strip: v, loc: this.locInfo(_) };
          }
          t3.prepareMustache = p;
          function n(l, b, P, E) {
            d(l, P), E = this.locInfo(E);
            var v = { type: "Program", body: b, strip: {}, loc: E };
            return { type: "BlockStatement", path: l.path, params: l.params, hash: l.hash, program: v, openStrip: {}, inverseStrip: {}, closeStrip: {}, loc: E };
          }
          t3.prepareRawBlock = n;
          function s(l, b, P, E, v, _) {
            E && E.path && d(l, E);
            var y = /\*/.test(l.open);
            b.blockParams = l.blockParams;
            var g, L;
            if (P) {
              if (y)
                throw new h.default("Unexpected inverse block on decorator", P);
              P.chain && (P.program.body[0].closeStrip = E.strip), L = P.strip, g = P.program;
            }
            return v && (v = g, g = b, b = v), { type: y ? "DecoratorBlock" : "BlockStatement", path: l.path, params: l.params, hash: l.hash, program: b, inverse: g, openStrip: l.strip, inverseStrip: L, closeStrip: E && E.strip, loc: this.locInfo(_) };
          }
          t3.prepareBlock = s;
          function u(l, b) {
            if (!b && l.length) {
              var P = l[0].loc, E = l[l.length - 1].loc;
              P && E && (b = { source: P.source, start: { line: P.start.line, column: P.start.column }, end: { line: E.end.line, column: E.end.column } });
            }
            return { type: "Program", body: l, strip: {}, loc: b };
          }
          t3.prepareProgram = u;
          function i(l, b, P, E) {
            return d(l, P), { type: "PartialBlockStatement", name: l.path, params: l.params, hash: l.hash, program: b, openStrip: l.strip, closeStrip: P && P.strip, loc: this.locInfo(E) };
          }
          t3.preparePartialBlock = i;
        } }), Ft = I({ "node_modules/@handlebars/parser/dist/cjs/parse.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__createBinding || (Object.create ? function(u, i, l, b) {
            b === void 0 && (b = l), Object.defineProperty(u, b, { enumerable: true, get: function() {
              return i[l];
            } });
          } : function(u, i, l, b) {
            b === void 0 && (b = l), u[b] = i[l];
          }), h = t3 && t3.__setModuleDefault || (Object.create ? function(u, i) {
            Object.defineProperty(u, "default", { enumerable: true, value: i });
          } : function(u, i) {
            u.default = i;
          }), d = t3 && t3.__importStar || function(u) {
            if (u && u.__esModule)
              return u;
            var i = {};
            if (u != null)
              for (var l in u)
                l !== "default" && Object.prototype.hasOwnProperty.call(u, l) && f(i, u, l);
            return h(i, u), i;
          }, c = t3 && t3.__importDefault || function(u) {
            return u && u.__esModule ? u : { default: u };
          };
          Object.defineProperty(t3, "__esModule", { value: true }), t3.parse = t3.parseWithoutProcessing = void 0;
          var o = c(Ge()), e = c(ze()), r = d(Lt()), a = {};
          for (p in r)
            Object.prototype.hasOwnProperty.call(r, p) && (a[p] = r[p]);
          var p;
          function n(u, i) {
            if (u.type === "Program")
              return u;
            o.default.yy = a, o.default.yy.locInfo = function(b) {
              return new r.SourceLocation(i && i.srcName, b);
            };
            var l = o.default.parse(u);
            return l;
          }
          t3.parseWithoutProcessing = n;
          function s(u, i) {
            var l = n(u, i), b = new e.default(i);
            return b.accept(l);
          }
          t3.parse = s;
        } }), It = I({ "node_modules/@handlebars/parser/dist/cjs/index.js"(t3) {
          "use strict";
          F();
          var f = t3 && t3.__importDefault || function(a) {
            return a && a.__esModule ? a : { default: a };
          };
          Object.defineProperty(t3, "__esModule", { value: true }), t3.parseWithoutProcessing = t3.parse = t3.PrintVisitor = t3.print = t3.Exception = t3.parser = t3.WhitespaceControl = t3.Visitor = void 0;
          var h = Oe();
          Object.defineProperty(t3, "Visitor", { enumerable: true, get: function() {
            return f(h).default;
          } });
          var d = ze();
          Object.defineProperty(t3, "WhitespaceControl", { enumerable: true, get: function() {
            return f(d).default;
          } });
          var c = Ge();
          Object.defineProperty(t3, "parser", { enumerable: true, get: function() {
            return f(c).default;
          } });
          var o = Be();
          Object.defineProperty(t3, "Exception", { enumerable: true, get: function() {
            return f(o).default;
          } });
          var e = Nt();
          Object.defineProperty(t3, "print", { enumerable: true, get: function() {
            return e.print;
          } }), Object.defineProperty(t3, "PrintVisitor", { enumerable: true, get: function() {
            return e.PrintVisitor;
          } });
          var r = Ft();
          Object.defineProperty(t3, "parse", { enumerable: true, get: function() {
            return r.parse;
          } }), Object.defineProperty(t3, "parseWithoutProcessing", { enumerable: true, get: function() {
            return r.parseWithoutProcessing;
          } });
        } }), Ke = I({ "node_modules/simple-html-tokenizer/dist/simple-html-tokenizer.js"(t3, f) {
          F(), function(h, d) {
            typeof t3 == "object" && typeof f < "u" ? d(t3) : typeof define == "function" && define.amd ? define(["exports"], d) : d(h.HTML5Tokenizer = {});
          }(t3, function(h) {
            "use strict";
            var d = { Aacute: "\xC1", aacute: "\xE1", Abreve: "\u0102", abreve: "\u0103", ac: "\u223E", acd: "\u223F", acE: "\u223E\u0333", Acirc: "\xC2", acirc: "\xE2", acute: "\xB4", Acy: "\u0410", acy: "\u0430", AElig: "\xC6", aelig: "\xE6", af: "\u2061", Afr: "\u{1D504}", afr: "\u{1D51E}", Agrave: "\xC0", agrave: "\xE0", alefsym: "\u2135", aleph: "\u2135", Alpha: "\u0391", alpha: "\u03B1", Amacr: "\u0100", amacr: "\u0101", amalg: "\u2A3F", amp: "&", AMP: "&", andand: "\u2A55", And: "\u2A53", and: "\u2227", andd: "\u2A5C", andslope: "\u2A58", andv: "\u2A5A", ang: "\u2220", ange: "\u29A4", angle: "\u2220", angmsdaa: "\u29A8", angmsdab: "\u29A9", angmsdac: "\u29AA", angmsdad: "\u29AB", angmsdae: "\u29AC", angmsdaf: "\u29AD", angmsdag: "\u29AE", angmsdah: "\u29AF", angmsd: "\u2221", angrt: "\u221F", angrtvb: "\u22BE", angrtvbd: "\u299D", angsph: "\u2222", angst: "\xC5", angzarr: "\u237C", Aogon: "\u0104", aogon: "\u0105", Aopf: "\u{1D538}", aopf: "\u{1D552}", apacir: "\u2A6F", ap: "\u2248", apE: "\u2A70", ape: "\u224A", apid: "\u224B", apos: "'", ApplyFunction: "\u2061", approx: "\u2248", approxeq: "\u224A", Aring: "\xC5", aring: "\xE5", Ascr: "\u{1D49C}", ascr: "\u{1D4B6}", Assign: "\u2254", ast: "*", asymp: "\u2248", asympeq: "\u224D", Atilde: "\xC3", atilde: "\xE3", Auml: "\xC4", auml: "\xE4", awconint: "\u2233", awint: "\u2A11", backcong: "\u224C", backepsilon: "\u03F6", backprime: "\u2035", backsim: "\u223D", backsimeq: "\u22CD", Backslash: "\u2216", Barv: "\u2AE7", barvee: "\u22BD", barwed: "\u2305", Barwed: "\u2306", barwedge: "\u2305", bbrk: "\u23B5", bbrktbrk: "\u23B6", bcong: "\u224C", Bcy: "\u0411", bcy: "\u0431", bdquo: "\u201E", becaus: "\u2235", because: "\u2235", Because: "\u2235", bemptyv: "\u29B0", bepsi: "\u03F6", bernou: "\u212C", Bernoullis: "\u212C", Beta: "\u0392", beta: "\u03B2", beth: "\u2136", between: "\u226C", Bfr: "\u{1D505}", bfr: "\u{1D51F}", bigcap: "\u22C2", bigcirc: "\u25EF", bigcup: "\u22C3", bigodot: "\u2A00", bigoplus: "\u2A01", bigotimes: "\u2A02", bigsqcup: "\u2A06", bigstar: "\u2605", bigtriangledown: "\u25BD", bigtriangleup: "\u25B3", biguplus: "\u2A04", bigvee: "\u22C1", bigwedge: "\u22C0", bkarow: "\u290D", blacklozenge: "\u29EB", blacksquare: "\u25AA", blacktriangle: "\u25B4", blacktriangledown: "\u25BE", blacktriangleleft: "\u25C2", blacktriangleright: "\u25B8", blank: "\u2423", blk12: "\u2592", blk14: "\u2591", blk34: "\u2593", block: "\u2588", bne: "=\u20E5", bnequiv: "\u2261\u20E5", bNot: "\u2AED", bnot: "\u2310", Bopf: "\u{1D539}", bopf: "\u{1D553}", bot: "\u22A5", bottom: "\u22A5", bowtie: "\u22C8", boxbox: "\u29C9", boxdl: "\u2510", boxdL: "\u2555", boxDl: "\u2556", boxDL: "\u2557", boxdr: "\u250C", boxdR: "\u2552", boxDr: "\u2553", boxDR: "\u2554", boxh: "\u2500", boxH: "\u2550", boxhd: "\u252C", boxHd: "\u2564", boxhD: "\u2565", boxHD: "\u2566", boxhu: "\u2534", boxHu: "\u2567", boxhU: "\u2568", boxHU: "\u2569", boxminus: "\u229F", boxplus: "\u229E", boxtimes: "\u22A0", boxul: "\u2518", boxuL: "\u255B", boxUl: "\u255C", boxUL: "\u255D", boxur: "\u2514", boxuR: "\u2558", boxUr: "\u2559", boxUR: "\u255A", boxv: "\u2502", boxV: "\u2551", boxvh: "\u253C", boxvH: "\u256A", boxVh: "\u256B", boxVH: "\u256C", boxvl: "\u2524", boxvL: "\u2561", boxVl: "\u2562", boxVL: "\u2563", boxvr: "\u251C", boxvR: "\u255E", boxVr: "\u255F", boxVR: "\u2560", bprime: "\u2035", breve: "\u02D8", Breve: "\u02D8", brvbar: "\xA6", bscr: "\u{1D4B7}", Bscr: "\u212C", bsemi: "\u204F", bsim: "\u223D", bsime: "\u22CD", bsolb: "\u29C5", bsol: "\\", bsolhsub: "\u27C8", bull: "\u2022", bullet: "\u2022", bump: "\u224E", bumpE: "\u2AAE", bumpe: "\u224F", Bumpeq: "\u224E", bumpeq: "\u224F", Cacute: "\u0106", cacute: "\u0107", capand: "\u2A44", capbrcup: "\u2A49", capcap: "\u2A4B", cap: "\u2229", Cap: "\u22D2", capcup: "\u2A47", capdot: "\u2A40", CapitalDifferentialD: "\u2145", caps: "\u2229\uFE00", caret: "\u2041", caron: "\u02C7", Cayleys: "\u212D", ccaps: "\u2A4D", Ccaron: "\u010C", ccaron: "\u010D", Ccedil: "\xC7", ccedil: "\xE7", Ccirc: "\u0108", ccirc: "\u0109", Cconint: "\u2230", ccups: "\u2A4C", ccupssm: "\u2A50", Cdot: "\u010A", cdot: "\u010B", cedil: "\xB8", Cedilla: "\xB8", cemptyv: "\u29B2", cent: "\xA2", centerdot: "\xB7", CenterDot: "\xB7", cfr: "\u{1D520}", Cfr: "\u212D", CHcy: "\u0427", chcy: "\u0447", check: "\u2713", checkmark: "\u2713", Chi: "\u03A7", chi: "\u03C7", circ: "\u02C6", circeq: "\u2257", circlearrowleft: "\u21BA", circlearrowright: "\u21BB", circledast: "\u229B", circledcirc: "\u229A", circleddash: "\u229D", CircleDot: "\u2299", circledR: "\xAE", circledS: "\u24C8", CircleMinus: "\u2296", CirclePlus: "\u2295", CircleTimes: "\u2297", cir: "\u25CB", cirE: "\u29C3", cire: "\u2257", cirfnint: "\u2A10", cirmid: "\u2AEF", cirscir: "\u29C2", ClockwiseContourIntegral: "\u2232", CloseCurlyDoubleQuote: "\u201D", CloseCurlyQuote: "\u2019", clubs: "\u2663", clubsuit: "\u2663", colon: ":", Colon: "\u2237", Colone: "\u2A74", colone: "\u2254", coloneq: "\u2254", comma: ",", commat: "@", comp: "\u2201", compfn: "\u2218", complement: "\u2201", complexes: "\u2102", cong: "\u2245", congdot: "\u2A6D", Congruent: "\u2261", conint: "\u222E", Conint: "\u222F", ContourIntegral: "\u222E", copf: "\u{1D554}", Copf: "\u2102", coprod: "\u2210", Coproduct: "\u2210", copy: "\xA9", COPY: "\xA9", copysr: "\u2117", CounterClockwiseContourIntegral: "\u2233", crarr: "\u21B5", cross: "\u2717", Cross: "\u2A2F", Cscr: "\u{1D49E}", cscr: "\u{1D4B8}", csub: "\u2ACF", csube: "\u2AD1", csup: "\u2AD0", csupe: "\u2AD2", ctdot: "\u22EF", cudarrl: "\u2938", cudarrr: "\u2935", cuepr: "\u22DE", cuesc: "\u22DF", cularr: "\u21B6", cularrp: "\u293D", cupbrcap: "\u2A48", cupcap: "\u2A46", CupCap: "\u224D", cup: "\u222A", Cup: "\u22D3", cupcup: "\u2A4A", cupdot: "\u228D", cupor: "\u2A45", cups: "\u222A\uFE00", curarr: "\u21B7", curarrm: "\u293C", curlyeqprec: "\u22DE", curlyeqsucc: "\u22DF", curlyvee: "\u22CE", curlywedge: "\u22CF", curren: "\xA4", curvearrowleft: "\u21B6", curvearrowright: "\u21B7", cuvee: "\u22CE", cuwed: "\u22CF", cwconint: "\u2232", cwint: "\u2231", cylcty: "\u232D", dagger: "\u2020", Dagger: "\u2021", daleth: "\u2138", darr: "\u2193", Darr: "\u21A1", dArr: "\u21D3", dash: "\u2010", Dashv: "\u2AE4", dashv: "\u22A3", dbkarow: "\u290F", dblac: "\u02DD", Dcaron: "\u010E", dcaron: "\u010F", Dcy: "\u0414", dcy: "\u0434", ddagger: "\u2021", ddarr: "\u21CA", DD: "\u2145", dd: "\u2146", DDotrahd: "\u2911", ddotseq: "\u2A77", deg: "\xB0", Del: "\u2207", Delta: "\u0394", delta: "\u03B4", demptyv: "\u29B1", dfisht: "\u297F", Dfr: "\u{1D507}", dfr: "\u{1D521}", dHar: "\u2965", dharl: "\u21C3", dharr: "\u21C2", DiacriticalAcute: "\xB4", DiacriticalDot: "\u02D9", DiacriticalDoubleAcute: "\u02DD", DiacriticalGrave: "`", DiacriticalTilde: "\u02DC", diam: "\u22C4", diamond: "\u22C4", Diamond: "\u22C4", diamondsuit: "\u2666", diams: "\u2666", die: "\xA8", DifferentialD: "\u2146", digamma: "\u03DD", disin: "\u22F2", div: "\xF7", divide: "\xF7", divideontimes: "\u22C7", divonx: "\u22C7", DJcy: "\u0402", djcy: "\u0452", dlcorn: "\u231E", dlcrop: "\u230D", dollar: "$", Dopf: "\u{1D53B}", dopf: "\u{1D555}", Dot: "\xA8", dot: "\u02D9", DotDot: "\u20DC", doteq: "\u2250", doteqdot: "\u2251", DotEqual: "\u2250", dotminus: "\u2238", dotplus: "\u2214", dotsquare: "\u22A1", doublebarwedge: "\u2306", DoubleContourIntegral: "\u222F", DoubleDot: "\xA8", DoubleDownArrow: "\u21D3", DoubleLeftArrow: "\u21D0", DoubleLeftRightArrow: "\u21D4", DoubleLeftTee: "\u2AE4", DoubleLongLeftArrow: "\u27F8", DoubleLongLeftRightArrow: "\u27FA", DoubleLongRightArrow: "\u27F9", DoubleRightArrow: "\u21D2", DoubleRightTee: "\u22A8", DoubleUpArrow: "\u21D1", DoubleUpDownArrow: "\u21D5", DoubleVerticalBar: "\u2225", DownArrowBar: "\u2913", downarrow: "\u2193", DownArrow: "\u2193", Downarrow: "\u21D3", DownArrowUpArrow: "\u21F5", DownBreve: "\u0311", downdownarrows: "\u21CA", downharpoonleft: "\u21C3", downharpoonright: "\u21C2", DownLeftRightVector: "\u2950", DownLeftTeeVector: "\u295E", DownLeftVectorBar: "\u2956", DownLeftVector: "\u21BD", DownRightTeeVector: "\u295F", DownRightVectorBar: "\u2957", DownRightVector: "\u21C1", DownTeeArrow: "\u21A7", DownTee: "\u22A4", drbkarow: "\u2910", drcorn: "\u231F", drcrop: "\u230C", Dscr: "\u{1D49F}", dscr: "\u{1D4B9}", DScy: "\u0405", dscy: "\u0455", dsol: "\u29F6", Dstrok: "\u0110", dstrok: "\u0111", dtdot: "\u22F1", dtri: "\u25BF", dtrif: "\u25BE", duarr: "\u21F5", duhar: "\u296F", dwangle: "\u29A6", DZcy: "\u040F", dzcy: "\u045F", dzigrarr: "\u27FF", Eacute: "\xC9", eacute: "\xE9", easter: "\u2A6E", Ecaron: "\u011A", ecaron: "\u011B", Ecirc: "\xCA", ecirc: "\xEA", ecir: "\u2256", ecolon: "\u2255", Ecy: "\u042D", ecy: "\u044D", eDDot: "\u2A77", Edot: "\u0116", edot: "\u0117", eDot: "\u2251", ee: "\u2147", efDot: "\u2252", Efr: "\u{1D508}", efr: "\u{1D522}", eg: "\u2A9A", Egrave: "\xC8", egrave: "\xE8", egs: "\u2A96", egsdot: "\u2A98", el: "\u2A99", Element: "\u2208", elinters: "\u23E7", ell: "\u2113", els: "\u2A95", elsdot: "\u2A97", Emacr: "\u0112", emacr: "\u0113", empty: "\u2205", emptyset: "\u2205", EmptySmallSquare: "\u25FB", emptyv: "\u2205", EmptyVerySmallSquare: "\u25AB", emsp13: "\u2004", emsp14: "\u2005", emsp: "\u2003", ENG: "\u014A", eng: "\u014B", ensp: "\u2002", Eogon: "\u0118", eogon: "\u0119", Eopf: "\u{1D53C}", eopf: "\u{1D556}", epar: "\u22D5", eparsl: "\u29E3", eplus: "\u2A71", epsi: "\u03B5", Epsilon: "\u0395", epsilon: "\u03B5", epsiv: "\u03F5", eqcirc: "\u2256", eqcolon: "\u2255", eqsim: "\u2242", eqslantgtr: "\u2A96", eqslantless: "\u2A95", Equal: "\u2A75", equals: "=", EqualTilde: "\u2242", equest: "\u225F", Equilibrium: "\u21CC", equiv: "\u2261", equivDD: "\u2A78", eqvparsl: "\u29E5", erarr: "\u2971", erDot: "\u2253", escr: "\u212F", Escr: "\u2130", esdot: "\u2250", Esim: "\u2A73", esim: "\u2242", Eta: "\u0397", eta: "\u03B7", ETH: "\xD0", eth: "\xF0", Euml: "\xCB", euml: "\xEB", euro: "\u20AC", excl: "!", exist: "\u2203", Exists: "\u2203", expectation: "\u2130", exponentiale: "\u2147", ExponentialE: "\u2147", fallingdotseq: "\u2252", Fcy: "\u0424", fcy: "\u0444", female: "\u2640", ffilig: "\uFB03", fflig: "\uFB00", ffllig: "\uFB04", Ffr: "\u{1D509}", ffr: "\u{1D523}", filig: "\uFB01", FilledSmallSquare: "\u25FC", FilledVerySmallSquare: "\u25AA", fjlig: "fj", flat: "\u266D", fllig: "\uFB02", fltns: "\u25B1", fnof: "\u0192", Fopf: "\u{1D53D}", fopf: "\u{1D557}", forall: "\u2200", ForAll: "\u2200", fork: "\u22D4", forkv: "\u2AD9", Fouriertrf: "\u2131", fpartint: "\u2A0D", frac12: "\xBD", frac13: "\u2153", frac14: "\xBC", frac15: "\u2155", frac16: "\u2159", frac18: "\u215B", frac23: "\u2154", frac25: "\u2156", frac34: "\xBE", frac35: "\u2157", frac38: "\u215C", frac45: "\u2158", frac56: "\u215A", frac58: "\u215D", frac78: "\u215E", frasl: "\u2044", frown: "\u2322", fscr: "\u{1D4BB}", Fscr: "\u2131", gacute: "\u01F5", Gamma: "\u0393", gamma: "\u03B3", Gammad: "\u03DC", gammad: "\u03DD", gap: "\u2A86", Gbreve: "\u011E", gbreve: "\u011F", Gcedil: "\u0122", Gcirc: "\u011C", gcirc: "\u011D", Gcy: "\u0413", gcy: "\u0433", Gdot: "\u0120", gdot: "\u0121", ge: "\u2265", gE: "\u2267", gEl: "\u2A8C", gel: "\u22DB", geq: "\u2265", geqq: "\u2267", geqslant: "\u2A7E", gescc: "\u2AA9", ges: "\u2A7E", gesdot: "\u2A80", gesdoto: "\u2A82", gesdotol: "\u2A84", gesl: "\u22DB\uFE00", gesles: "\u2A94", Gfr: "\u{1D50A}", gfr: "\u{1D524}", gg: "\u226B", Gg: "\u22D9", ggg: "\u22D9", gimel: "\u2137", GJcy: "\u0403", gjcy: "\u0453", gla: "\u2AA5", gl: "\u2277", glE: "\u2A92", glj: "\u2AA4", gnap: "\u2A8A", gnapprox: "\u2A8A", gne: "\u2A88", gnE: "\u2269", gneq: "\u2A88", gneqq: "\u2269", gnsim: "\u22E7", Gopf: "\u{1D53E}", gopf: "\u{1D558}", grave: "`", GreaterEqual: "\u2265", GreaterEqualLess: "\u22DB", GreaterFullEqual: "\u2267", GreaterGreater: "\u2AA2", GreaterLess: "\u2277", GreaterSlantEqual: "\u2A7E", GreaterTilde: "\u2273", Gscr: "\u{1D4A2}", gscr: "\u210A", gsim: "\u2273", gsime: "\u2A8E", gsiml: "\u2A90", gtcc: "\u2AA7", gtcir: "\u2A7A", gt: ">", GT: ">", Gt: "\u226B", gtdot: "\u22D7", gtlPar: "\u2995", gtquest: "\u2A7C", gtrapprox: "\u2A86", gtrarr: "\u2978", gtrdot: "\u22D7", gtreqless: "\u22DB", gtreqqless: "\u2A8C", gtrless: "\u2277", gtrsim: "\u2273", gvertneqq: "\u2269\uFE00", gvnE: "\u2269\uFE00", Hacek: "\u02C7", hairsp: "\u200A", half: "\xBD", hamilt: "\u210B", HARDcy: "\u042A", hardcy: "\u044A", harrcir: "\u2948", harr: "\u2194", hArr: "\u21D4", harrw: "\u21AD", Hat: "^", hbar: "\u210F", Hcirc: "\u0124", hcirc: "\u0125", hearts: "\u2665", heartsuit: "\u2665", hellip: "\u2026", hercon: "\u22B9", hfr: "\u{1D525}", Hfr: "\u210C", HilbertSpace: "\u210B", hksearow: "\u2925", hkswarow: "\u2926", hoarr: "\u21FF", homtht: "\u223B", hookleftarrow: "\u21A9", hookrightarrow: "\u21AA", hopf: "\u{1D559}", Hopf: "\u210D", horbar: "\u2015", HorizontalLine: "\u2500", hscr: "\u{1D4BD}", Hscr: "\u210B", hslash: "\u210F", Hstrok: "\u0126", hstrok: "\u0127", HumpDownHump: "\u224E", HumpEqual: "\u224F", hybull: "\u2043", hyphen: "\u2010", Iacute: "\xCD", iacute: "\xED", ic: "\u2063", Icirc: "\xCE", icirc: "\xEE", Icy: "\u0418", icy: "\u0438", Idot: "\u0130", IEcy: "\u0415", iecy: "\u0435", iexcl: "\xA1", iff: "\u21D4", ifr: "\u{1D526}", Ifr: "\u2111", Igrave: "\xCC", igrave: "\xEC", ii: "\u2148", iiiint: "\u2A0C", iiint: "\u222D", iinfin: "\u29DC", iiota: "\u2129", IJlig: "\u0132", ijlig: "\u0133", Imacr: "\u012A", imacr: "\u012B", image: "\u2111", ImaginaryI: "\u2148", imagline: "\u2110", imagpart: "\u2111", imath: "\u0131", Im: "\u2111", imof: "\u22B7", imped: "\u01B5", Implies: "\u21D2", incare: "\u2105", in: "\u2208", infin: "\u221E", infintie: "\u29DD", inodot: "\u0131", intcal: "\u22BA", int: "\u222B", Int: "\u222C", integers: "\u2124", Integral: "\u222B", intercal: "\u22BA", Intersection: "\u22C2", intlarhk: "\u2A17", intprod: "\u2A3C", InvisibleComma: "\u2063", InvisibleTimes: "\u2062", IOcy: "\u0401", iocy: "\u0451", Iogon: "\u012E", iogon: "\u012F", Iopf: "\u{1D540}", iopf: "\u{1D55A}", Iota: "\u0399", iota: "\u03B9", iprod: "\u2A3C", iquest: "\xBF", iscr: "\u{1D4BE}", Iscr: "\u2110", isin: "\u2208", isindot: "\u22F5", isinE: "\u22F9", isins: "\u22F4", isinsv: "\u22F3", isinv: "\u2208", it: "\u2062", Itilde: "\u0128", itilde: "\u0129", Iukcy: "\u0406", iukcy: "\u0456", Iuml: "\xCF", iuml: "\xEF", Jcirc: "\u0134", jcirc: "\u0135", Jcy: "\u0419", jcy: "\u0439", Jfr: "\u{1D50D}", jfr: "\u{1D527}", jmath: "\u0237", Jopf: "\u{1D541}", jopf: "\u{1D55B}", Jscr: "\u{1D4A5}", jscr: "\u{1D4BF}", Jsercy: "\u0408", jsercy: "\u0458", Jukcy: "\u0404", jukcy: "\u0454", Kappa: "\u039A", kappa: "\u03BA", kappav: "\u03F0", Kcedil: "\u0136", kcedil: "\u0137", Kcy: "\u041A", kcy: "\u043A", Kfr: "\u{1D50E}", kfr: "\u{1D528}", kgreen: "\u0138", KHcy: "\u0425", khcy: "\u0445", KJcy: "\u040C", kjcy: "\u045C", Kopf: "\u{1D542}", kopf: "\u{1D55C}", Kscr: "\u{1D4A6}", kscr: "\u{1D4C0}", lAarr: "\u21DA", Lacute: "\u0139", lacute: "\u013A", laemptyv: "\u29B4", lagran: "\u2112", Lambda: "\u039B", lambda: "\u03BB", lang: "\u27E8", Lang: "\u27EA", langd: "\u2991", langle: "\u27E8", lap: "\u2A85", Laplacetrf: "\u2112", laquo: "\xAB", larrb: "\u21E4", larrbfs: "\u291F", larr: "\u2190", Larr: "\u219E", lArr: "\u21D0", larrfs: "\u291D", larrhk: "\u21A9", larrlp: "\u21AB", larrpl: "\u2939", larrsim: "\u2973", larrtl: "\u21A2", latail: "\u2919", lAtail: "\u291B", lat: "\u2AAB", late: "\u2AAD", lates: "\u2AAD\uFE00", lbarr: "\u290C", lBarr: "\u290E", lbbrk: "\u2772", lbrace: "{", lbrack: "[", lbrke: "\u298B", lbrksld: "\u298F", lbrkslu: "\u298D", Lcaron: "\u013D", lcaron: "\u013E", Lcedil: "\u013B", lcedil: "\u013C", lceil: "\u2308", lcub: "{", Lcy: "\u041B", lcy: "\u043B", ldca: "\u2936", ldquo: "\u201C", ldquor: "\u201E", ldrdhar: "\u2967", ldrushar: "\u294B", ldsh: "\u21B2", le: "\u2264", lE: "\u2266", LeftAngleBracket: "\u27E8", LeftArrowBar: "\u21E4", leftarrow: "\u2190", LeftArrow: "\u2190", Leftarrow: "\u21D0", LeftArrowRightArrow: "\u21C6", leftarrowtail: "\u21A2", LeftCeiling: "\u2308", LeftDoubleBracket: "\u27E6", LeftDownTeeVector: "\u2961", LeftDownVectorBar: "\u2959", LeftDownVector: "\u21C3", LeftFloor: "\u230A", leftharpoondown: "\u21BD", leftharpoonup: "\u21BC", leftleftarrows: "\u21C7", leftrightarrow: "\u2194", LeftRightArrow: "\u2194", Leftrightarrow: "\u21D4", leftrightarrows: "\u21C6", leftrightharpoons: "\u21CB", leftrightsquigarrow: "\u21AD", LeftRightVector: "\u294E", LeftTeeArrow: "\u21A4", LeftTee: "\u22A3", LeftTeeVector: "\u295A", leftthreetimes: "\u22CB", LeftTriangleBar: "\u29CF", LeftTriangle: "\u22B2", LeftTriangleEqual: "\u22B4", LeftUpDownVector: "\u2951", LeftUpTeeVector: "\u2960", LeftUpVectorBar: "\u2958", LeftUpVector: "\u21BF", LeftVectorBar: "\u2952", LeftVector: "\u21BC", lEg: "\u2A8B", leg: "\u22DA", leq: "\u2264", leqq: "\u2266", leqslant: "\u2A7D", lescc: "\u2AA8", les: "\u2A7D", lesdot: "\u2A7F", lesdoto: "\u2A81", lesdotor: "\u2A83", lesg: "\u22DA\uFE00", lesges: "\u2A93", lessapprox: "\u2A85", lessdot: "\u22D6", lesseqgtr: "\u22DA", lesseqqgtr: "\u2A8B", LessEqualGreater: "\u22DA", LessFullEqual: "\u2266", LessGreater: "\u2276", lessgtr: "\u2276", LessLess: "\u2AA1", lesssim: "\u2272", LessSlantEqual: "\u2A7D", LessTilde: "\u2272", lfisht: "\u297C", lfloor: "\u230A", Lfr: "\u{1D50F}", lfr: "\u{1D529}", lg: "\u2276", lgE: "\u2A91", lHar: "\u2962", lhard: "\u21BD", lharu: "\u21BC", lharul: "\u296A", lhblk: "\u2584", LJcy: "\u0409", ljcy: "\u0459", llarr: "\u21C7", ll: "\u226A", Ll: "\u22D8", llcorner: "\u231E", Lleftarrow: "\u21DA", llhard: "\u296B", lltri: "\u25FA", Lmidot: "\u013F", lmidot: "\u0140", lmoustache: "\u23B0", lmoust: "\u23B0", lnap: "\u2A89", lnapprox: "\u2A89", lne: "\u2A87", lnE: "\u2268", lneq: "\u2A87", lneqq: "\u2268", lnsim: "\u22E6", loang: "\u27EC", loarr: "\u21FD", lobrk: "\u27E6", longleftarrow: "\u27F5", LongLeftArrow: "\u27F5", Longleftarrow: "\u27F8", longleftrightarrow: "\u27F7", LongLeftRightArrow: "\u27F7", Longleftrightarrow: "\u27FA", longmapsto: "\u27FC", longrightarrow: "\u27F6", LongRightArrow: "\u27F6", Longrightarrow: "\u27F9", looparrowleft: "\u21AB", looparrowright: "\u21AC", lopar: "\u2985", Lopf: "\u{1D543}", lopf: "\u{1D55D}", loplus: "\u2A2D", lotimes: "\u2A34", lowast: "\u2217", lowbar: "_", LowerLeftArrow: "\u2199", LowerRightArrow: "\u2198", loz: "\u25CA", lozenge: "\u25CA", lozf: "\u29EB", lpar: "(", lparlt: "\u2993", lrarr: "\u21C6", lrcorner: "\u231F", lrhar: "\u21CB", lrhard: "\u296D", lrm: "\u200E", lrtri: "\u22BF", lsaquo: "\u2039", lscr: "\u{1D4C1}", Lscr: "\u2112", lsh: "\u21B0", Lsh: "\u21B0", lsim: "\u2272", lsime: "\u2A8D", lsimg: "\u2A8F", lsqb: "[", lsquo: "\u2018", lsquor: "\u201A", Lstrok: "\u0141", lstrok: "\u0142", ltcc: "\u2AA6", ltcir: "\u2A79", lt: "<", LT: "<", Lt: "\u226A", ltdot: "\u22D6", lthree: "\u22CB", ltimes: "\u22C9", ltlarr: "\u2976", ltquest: "\u2A7B", ltri: "\u25C3", ltrie: "\u22B4", ltrif: "\u25C2", ltrPar: "\u2996", lurdshar: "\u294A", luruhar: "\u2966", lvertneqq: "\u2268\uFE00", lvnE: "\u2268\uFE00", macr: "\xAF", male: "\u2642", malt: "\u2720", maltese: "\u2720", Map: "\u2905", map: "\u21A6", mapsto: "\u21A6", mapstodown: "\u21A7", mapstoleft: "\u21A4", mapstoup: "\u21A5", marker: "\u25AE", mcomma: "\u2A29", Mcy: "\u041C", mcy: "\u043C", mdash: "\u2014", mDDot: "\u223A", measuredangle: "\u2221", MediumSpace: "\u205F", Mellintrf: "\u2133", Mfr: "\u{1D510}", mfr: "\u{1D52A}", mho: "\u2127", micro: "\xB5", midast: "*", midcir: "\u2AF0", mid: "\u2223", middot: "\xB7", minusb: "\u229F", minus: "\u2212", minusd: "\u2238", minusdu: "\u2A2A", MinusPlus: "\u2213", mlcp: "\u2ADB", mldr: "\u2026", mnplus: "\u2213", models: "\u22A7", Mopf: "\u{1D544}", mopf: "\u{1D55E}", mp: "\u2213", mscr: "\u{1D4C2}", Mscr: "\u2133", mstpos: "\u223E", Mu: "\u039C", mu: "\u03BC", multimap: "\u22B8", mumap: "\u22B8", nabla: "\u2207", Nacute: "\u0143", nacute: "\u0144", nang: "\u2220\u20D2", nap: "\u2249", napE: "\u2A70\u0338", napid: "\u224B\u0338", napos: "\u0149", napprox: "\u2249", natural: "\u266E", naturals: "\u2115", natur: "\u266E", nbsp: "\xA0", nbump: "\u224E\u0338", nbumpe: "\u224F\u0338", ncap: "\u2A43", Ncaron: "\u0147", ncaron: "\u0148", Ncedil: "\u0145", ncedil: "\u0146", ncong: "\u2247", ncongdot: "\u2A6D\u0338", ncup: "\u2A42", Ncy: "\u041D", ncy: "\u043D", ndash: "\u2013", nearhk: "\u2924", nearr: "\u2197", neArr: "\u21D7", nearrow: "\u2197", ne: "\u2260", nedot: "\u2250\u0338", NegativeMediumSpace: "\u200B", NegativeThickSpace: "\u200B", NegativeThinSpace: "\u200B", NegativeVeryThinSpace: "\u200B", nequiv: "\u2262", nesear: "\u2928", nesim: "\u2242\u0338", NestedGreaterGreater: "\u226B", NestedLessLess: "\u226A", NewLine: `
`, nexist: "\u2204", nexists: "\u2204", Nfr: "\u{1D511}", nfr: "\u{1D52B}", ngE: "\u2267\u0338", nge: "\u2271", ngeq: "\u2271", ngeqq: "\u2267\u0338", ngeqslant: "\u2A7E\u0338", nges: "\u2A7E\u0338", nGg: "\u22D9\u0338", ngsim: "\u2275", nGt: "\u226B\u20D2", ngt: "\u226F", ngtr: "\u226F", nGtv: "\u226B\u0338", nharr: "\u21AE", nhArr: "\u21CE", nhpar: "\u2AF2", ni: "\u220B", nis: "\u22FC", nisd: "\u22FA", niv: "\u220B", NJcy: "\u040A", njcy: "\u045A", nlarr: "\u219A", nlArr: "\u21CD", nldr: "\u2025", nlE: "\u2266\u0338", nle: "\u2270", nleftarrow: "\u219A", nLeftarrow: "\u21CD", nleftrightarrow: "\u21AE", nLeftrightarrow: "\u21CE", nleq: "\u2270", nleqq: "\u2266\u0338", nleqslant: "\u2A7D\u0338", nles: "\u2A7D\u0338", nless: "\u226E", nLl: "\u22D8\u0338", nlsim: "\u2274", nLt: "\u226A\u20D2", nlt: "\u226E", nltri: "\u22EA", nltrie: "\u22EC", nLtv: "\u226A\u0338", nmid: "\u2224", NoBreak: "\u2060", NonBreakingSpace: "\xA0", nopf: "\u{1D55F}", Nopf: "\u2115", Not: "\u2AEC", not: "\xAC", NotCongruent: "\u2262", NotCupCap: "\u226D", NotDoubleVerticalBar: "\u2226", NotElement: "\u2209", NotEqual: "\u2260", NotEqualTilde: "\u2242\u0338", NotExists: "\u2204", NotGreater: "\u226F", NotGreaterEqual: "\u2271", NotGreaterFullEqual: "\u2267\u0338", NotGreaterGreater: "\u226B\u0338", NotGreaterLess: "\u2279", NotGreaterSlantEqual: "\u2A7E\u0338", NotGreaterTilde: "\u2275", NotHumpDownHump: "\u224E\u0338", NotHumpEqual: "\u224F\u0338", notin: "\u2209", notindot: "\u22F5\u0338", notinE: "\u22F9\u0338", notinva: "\u2209", notinvb: "\u22F7", notinvc: "\u22F6", NotLeftTriangleBar: "\u29CF\u0338", NotLeftTriangle: "\u22EA", NotLeftTriangleEqual: "\u22EC", NotLess: "\u226E", NotLessEqual: "\u2270", NotLessGreater: "\u2278", NotLessLess: "\u226A\u0338", NotLessSlantEqual: "\u2A7D\u0338", NotLessTilde: "\u2274", NotNestedGreaterGreater: "\u2AA2\u0338", NotNestedLessLess: "\u2AA1\u0338", notni: "\u220C", notniva: "\u220C", notnivb: "\u22FE", notnivc: "\u22FD", NotPrecedes: "\u2280", NotPrecedesEqual: "\u2AAF\u0338", NotPrecedesSlantEqual: "\u22E0", NotReverseElement: "\u220C", NotRightTriangleBar: "\u29D0\u0338", NotRightTriangle: "\u22EB", NotRightTriangleEqual: "\u22ED", NotSquareSubset: "\u228F\u0338", NotSquareSubsetEqual: "\u22E2", NotSquareSuperset: "\u2290\u0338", NotSquareSupersetEqual: "\u22E3", NotSubset: "\u2282\u20D2", NotSubsetEqual: "\u2288", NotSucceeds: "\u2281", NotSucceedsEqual: "\u2AB0\u0338", NotSucceedsSlantEqual: "\u22E1", NotSucceedsTilde: "\u227F\u0338", NotSuperset: "\u2283\u20D2", NotSupersetEqual: "\u2289", NotTilde: "\u2241", NotTildeEqual: "\u2244", NotTildeFullEqual: "\u2247", NotTildeTilde: "\u2249", NotVerticalBar: "\u2224", nparallel: "\u2226", npar: "\u2226", nparsl: "\u2AFD\u20E5", npart: "\u2202\u0338", npolint: "\u2A14", npr: "\u2280", nprcue: "\u22E0", nprec: "\u2280", npreceq: "\u2AAF\u0338", npre: "\u2AAF\u0338", nrarrc: "\u2933\u0338", nrarr: "\u219B", nrArr: "\u21CF", nrarrw: "\u219D\u0338", nrightarrow: "\u219B", nRightarrow: "\u21CF", nrtri: "\u22EB", nrtrie: "\u22ED", nsc: "\u2281", nsccue: "\u22E1", nsce: "\u2AB0\u0338", Nscr: "\u{1D4A9}", nscr: "\u{1D4C3}", nshortmid: "\u2224", nshortparallel: "\u2226", nsim: "\u2241", nsime: "\u2244", nsimeq: "\u2244", nsmid: "\u2224", nspar: "\u2226", nsqsube: "\u22E2", nsqsupe: "\u22E3", nsub: "\u2284", nsubE: "\u2AC5\u0338", nsube: "\u2288", nsubset: "\u2282\u20D2", nsubseteq: "\u2288", nsubseteqq: "\u2AC5\u0338", nsucc: "\u2281", nsucceq: "\u2AB0\u0338", nsup: "\u2285", nsupE: "\u2AC6\u0338", nsupe: "\u2289", nsupset: "\u2283\u20D2", nsupseteq: "\u2289", nsupseteqq: "\u2AC6\u0338", ntgl: "\u2279", Ntilde: "\xD1", ntilde: "\xF1", ntlg: "\u2278", ntriangleleft: "\u22EA", ntrianglelefteq: "\u22EC", ntriangleright: "\u22EB", ntrianglerighteq: "\u22ED", Nu: "\u039D", nu: "\u03BD", num: "#", numero: "\u2116", numsp: "\u2007", nvap: "\u224D\u20D2", nvdash: "\u22AC", nvDash: "\u22AD", nVdash: "\u22AE", nVDash: "\u22AF", nvge: "\u2265\u20D2", nvgt: ">\u20D2", nvHarr: "\u2904", nvinfin: "\u29DE", nvlArr: "\u2902", nvle: "\u2264\u20D2", nvlt: "<\u20D2", nvltrie: "\u22B4\u20D2", nvrArr: "\u2903", nvrtrie: "\u22B5\u20D2", nvsim: "\u223C\u20D2", nwarhk: "\u2923", nwarr: "\u2196", nwArr: "\u21D6", nwarrow: "\u2196", nwnear: "\u2927", Oacute: "\xD3", oacute: "\xF3", oast: "\u229B", Ocirc: "\xD4", ocirc: "\xF4", ocir: "\u229A", Ocy: "\u041E", ocy: "\u043E", odash: "\u229D", Odblac: "\u0150", odblac: "\u0151", odiv: "\u2A38", odot: "\u2299", odsold: "\u29BC", OElig: "\u0152", oelig: "\u0153", ofcir: "\u29BF", Ofr: "\u{1D512}", ofr: "\u{1D52C}", ogon: "\u02DB", Ograve: "\xD2", ograve: "\xF2", ogt: "\u29C1", ohbar: "\u29B5", ohm: "\u03A9", oint: "\u222E", olarr: "\u21BA", olcir: "\u29BE", olcross: "\u29BB", oline: "\u203E", olt: "\u29C0", Omacr: "\u014C", omacr: "\u014D", Omega: "\u03A9", omega: "\u03C9", Omicron: "\u039F", omicron: "\u03BF", omid: "\u29B6", ominus: "\u2296", Oopf: "\u{1D546}", oopf: "\u{1D560}", opar: "\u29B7", OpenCurlyDoubleQuote: "\u201C", OpenCurlyQuote: "\u2018", operp: "\u29B9", oplus: "\u2295", orarr: "\u21BB", Or: "\u2A54", or: "\u2228", ord: "\u2A5D", order: "\u2134", orderof: "\u2134", ordf: "\xAA", ordm: "\xBA", origof: "\u22B6", oror: "\u2A56", orslope: "\u2A57", orv: "\u2A5B", oS: "\u24C8", Oscr: "\u{1D4AA}", oscr: "\u2134", Oslash: "\xD8", oslash: "\xF8", osol: "\u2298", Otilde: "\xD5", otilde: "\xF5", otimesas: "\u2A36", Otimes: "\u2A37", otimes: "\u2297", Ouml: "\xD6", ouml: "\xF6", ovbar: "\u233D", OverBar: "\u203E", OverBrace: "\u23DE", OverBracket: "\u23B4", OverParenthesis: "\u23DC", para: "\xB6", parallel: "\u2225", par: "\u2225", parsim: "\u2AF3", parsl: "\u2AFD", part: "\u2202", PartialD: "\u2202", Pcy: "\u041F", pcy: "\u043F", percnt: "%", period: ".", permil: "\u2030", perp: "\u22A5", pertenk: "\u2031", Pfr: "\u{1D513}", pfr: "\u{1D52D}", Phi: "\u03A6", phi: "\u03C6", phiv: "\u03D5", phmmat: "\u2133", phone: "\u260E", Pi: "\u03A0", pi: "\u03C0", pitchfork: "\u22D4", piv: "\u03D6", planck: "\u210F", planckh: "\u210E", plankv: "\u210F", plusacir: "\u2A23", plusb: "\u229E", pluscir: "\u2A22", plus: "+", plusdo: "\u2214", plusdu: "\u2A25", pluse: "\u2A72", PlusMinus: "\xB1", plusmn: "\xB1", plussim: "\u2A26", plustwo: "\u2A27", pm: "\xB1", Poincareplane: "\u210C", pointint: "\u2A15", popf: "\u{1D561}", Popf: "\u2119", pound: "\xA3", prap: "\u2AB7", Pr: "\u2ABB", pr: "\u227A", prcue: "\u227C", precapprox: "\u2AB7", prec: "\u227A", preccurlyeq: "\u227C", Precedes: "\u227A", PrecedesEqual: "\u2AAF", PrecedesSlantEqual: "\u227C", PrecedesTilde: "\u227E", preceq: "\u2AAF", precnapprox: "\u2AB9", precneqq: "\u2AB5", precnsim: "\u22E8", pre: "\u2AAF", prE: "\u2AB3", precsim: "\u227E", prime: "\u2032", Prime: "\u2033", primes: "\u2119", prnap: "\u2AB9", prnE: "\u2AB5", prnsim: "\u22E8", prod: "\u220F", Product: "\u220F", profalar: "\u232E", profline: "\u2312", profsurf: "\u2313", prop: "\u221D", Proportional: "\u221D", Proportion: "\u2237", propto: "\u221D", prsim: "\u227E", prurel: "\u22B0", Pscr: "\u{1D4AB}", pscr: "\u{1D4C5}", Psi: "\u03A8", psi: "\u03C8", puncsp: "\u2008", Qfr: "\u{1D514}", qfr: "\u{1D52E}", qint: "\u2A0C", qopf: "\u{1D562}", Qopf: "\u211A", qprime: "\u2057", Qscr: "\u{1D4AC}", qscr: "\u{1D4C6}", quaternions: "\u210D", quatint: "\u2A16", quest: "?", questeq: "\u225F", quot: '"', QUOT: '"', rAarr: "\u21DB", race: "\u223D\u0331", Racute: "\u0154", racute: "\u0155", radic: "\u221A", raemptyv: "\u29B3", rang: "\u27E9", Rang: "\u27EB", rangd: "\u2992", range: "\u29A5", rangle: "\u27E9", raquo: "\xBB", rarrap: "\u2975", rarrb: "\u21E5", rarrbfs: "\u2920", rarrc: "\u2933", rarr: "\u2192", Rarr: "\u21A0", rArr: "\u21D2", rarrfs: "\u291E", rarrhk: "\u21AA", rarrlp: "\u21AC", rarrpl: "\u2945", rarrsim: "\u2974", Rarrtl: "\u2916", rarrtl: "\u21A3", rarrw: "\u219D", ratail: "\u291A", rAtail: "\u291C", ratio: "\u2236", rationals: "\u211A", rbarr: "\u290D", rBarr: "\u290F", RBarr: "\u2910", rbbrk: "\u2773", rbrace: "}", rbrack: "]", rbrke: "\u298C", rbrksld: "\u298E", rbrkslu: "\u2990", Rcaron: "\u0158", rcaron: "\u0159", Rcedil: "\u0156", rcedil: "\u0157", rceil: "\u2309", rcub: "}", Rcy: "\u0420", rcy: "\u0440", rdca: "\u2937", rdldhar: "\u2969", rdquo: "\u201D", rdquor: "\u201D", rdsh: "\u21B3", real: "\u211C", realine: "\u211B", realpart: "\u211C", reals: "\u211D", Re: "\u211C", rect: "\u25AD", reg: "\xAE", REG: "\xAE", ReverseElement: "\u220B", ReverseEquilibrium: "\u21CB", ReverseUpEquilibrium: "\u296F", rfisht: "\u297D", rfloor: "\u230B", rfr: "\u{1D52F}", Rfr: "\u211C", rHar: "\u2964", rhard: "\u21C1", rharu: "\u21C0", rharul: "\u296C", Rho: "\u03A1", rho: "\u03C1", rhov: "\u03F1", RightAngleBracket: "\u27E9", RightArrowBar: "\u21E5", rightarrow: "\u2192", RightArrow: "\u2192", Rightarrow: "\u21D2", RightArrowLeftArrow: "\u21C4", rightarrowtail: "\u21A3", RightCeiling: "\u2309", RightDoubleBracket: "\u27E7", RightDownTeeVector: "\u295D", RightDownVectorBar: "\u2955", RightDownVector: "\u21C2", RightFloor: "\u230B", rightharpoondown: "\u21C1", rightharpoonup: "\u21C0", rightleftarrows: "\u21C4", rightleftharpoons: "\u21CC", rightrightarrows: "\u21C9", rightsquigarrow: "\u219D", RightTeeArrow: "\u21A6", RightTee: "\u22A2", RightTeeVector: "\u295B", rightthreetimes: "\u22CC", RightTriangleBar: "\u29D0", RightTriangle: "\u22B3", RightTriangleEqual: "\u22B5", RightUpDownVector: "\u294F", RightUpTeeVector: "\u295C", RightUpVectorBar: "\u2954", RightUpVector: "\u21BE", RightVectorBar: "\u2953", RightVector: "\u21C0", ring: "\u02DA", risingdotseq: "\u2253", rlarr: "\u21C4", rlhar: "\u21CC", rlm: "\u200F", rmoustache: "\u23B1", rmoust: "\u23B1", rnmid: "\u2AEE", roang: "\u27ED", roarr: "\u21FE", robrk: "\u27E7", ropar: "\u2986", ropf: "\u{1D563}", Ropf: "\u211D", roplus: "\u2A2E", rotimes: "\u2A35", RoundImplies: "\u2970", rpar: ")", rpargt: "\u2994", rppolint: "\u2A12", rrarr: "\u21C9", Rrightarrow: "\u21DB", rsaquo: "\u203A", rscr: "\u{1D4C7}", Rscr: "\u211B", rsh: "\u21B1", Rsh: "\u21B1", rsqb: "]", rsquo: "\u2019", rsquor: "\u2019", rthree: "\u22CC", rtimes: "\u22CA", rtri: "\u25B9", rtrie: "\u22B5", rtrif: "\u25B8", rtriltri: "\u29CE", RuleDelayed: "\u29F4", ruluhar: "\u2968", rx: "\u211E", Sacute: "\u015A", sacute: "\u015B", sbquo: "\u201A", scap: "\u2AB8", Scaron: "\u0160", scaron: "\u0161", Sc: "\u2ABC", sc: "\u227B", sccue: "\u227D", sce: "\u2AB0", scE: "\u2AB4", Scedil: "\u015E", scedil: "\u015F", Scirc: "\u015C", scirc: "\u015D", scnap: "\u2ABA", scnE: "\u2AB6", scnsim: "\u22E9", scpolint: "\u2A13", scsim: "\u227F", Scy: "\u0421", scy: "\u0441", sdotb: "\u22A1", sdot: "\u22C5", sdote: "\u2A66", searhk: "\u2925", searr: "\u2198", seArr: "\u21D8", searrow: "\u2198", sect: "\xA7", semi: ";", seswar: "\u2929", setminus: "\u2216", setmn: "\u2216", sext: "\u2736", Sfr: "\u{1D516}", sfr: "\u{1D530}", sfrown: "\u2322", sharp: "\u266F", SHCHcy: "\u0429", shchcy: "\u0449", SHcy: "\u0428", shcy: "\u0448", ShortDownArrow: "\u2193", ShortLeftArrow: "\u2190", shortmid: "\u2223", shortparallel: "\u2225", ShortRightArrow: "\u2192", ShortUpArrow: "\u2191", shy: "\xAD", Sigma: "\u03A3", sigma: "\u03C3", sigmaf: "\u03C2", sigmav: "\u03C2", sim: "\u223C", simdot: "\u2A6A", sime: "\u2243", simeq: "\u2243", simg: "\u2A9E", simgE: "\u2AA0", siml: "\u2A9D", simlE: "\u2A9F", simne: "\u2246", simplus: "\u2A24", simrarr: "\u2972", slarr: "\u2190", SmallCircle: "\u2218", smallsetminus: "\u2216", smashp: "\u2A33", smeparsl: "\u29E4", smid: "\u2223", smile: "\u2323", smt: "\u2AAA", smte: "\u2AAC", smtes: "\u2AAC\uFE00", SOFTcy: "\u042C", softcy: "\u044C", solbar: "\u233F", solb: "\u29C4", sol: "/", Sopf: "\u{1D54A}", sopf: "\u{1D564}", spades: "\u2660", spadesuit: "\u2660", spar: "\u2225", sqcap: "\u2293", sqcaps: "\u2293\uFE00", sqcup: "\u2294", sqcups: "\u2294\uFE00", Sqrt: "\u221A", sqsub: "\u228F", sqsube: "\u2291", sqsubset: "\u228F", sqsubseteq: "\u2291", sqsup: "\u2290", sqsupe: "\u2292", sqsupset: "\u2290", sqsupseteq: "\u2292", square: "\u25A1", Square: "\u25A1", SquareIntersection: "\u2293", SquareSubset: "\u228F", SquareSubsetEqual: "\u2291", SquareSuperset: "\u2290", SquareSupersetEqual: "\u2292", SquareUnion: "\u2294", squarf: "\u25AA", squ: "\u25A1", squf: "\u25AA", srarr: "\u2192", Sscr: "\u{1D4AE}", sscr: "\u{1D4C8}", ssetmn: "\u2216", ssmile: "\u2323", sstarf: "\u22C6", Star: "\u22C6", star: "\u2606", starf: "\u2605", straightepsilon: "\u03F5", straightphi: "\u03D5", strns: "\xAF", sub: "\u2282", Sub: "\u22D0", subdot: "\u2ABD", subE: "\u2AC5", sube: "\u2286", subedot: "\u2AC3", submult: "\u2AC1", subnE: "\u2ACB", subne: "\u228A", subplus: "\u2ABF", subrarr: "\u2979", subset: "\u2282", Subset: "\u22D0", subseteq: "\u2286", subseteqq: "\u2AC5", SubsetEqual: "\u2286", subsetneq: "\u228A", subsetneqq: "\u2ACB", subsim: "\u2AC7", subsub: "\u2AD5", subsup: "\u2AD3", succapprox: "\u2AB8", succ: "\u227B", succcurlyeq: "\u227D", Succeeds: "\u227B", SucceedsEqual: "\u2AB0", SucceedsSlantEqual: "\u227D", SucceedsTilde: "\u227F", succeq: "\u2AB0", succnapprox: "\u2ABA", succneqq: "\u2AB6", succnsim: "\u22E9", succsim: "\u227F", SuchThat: "\u220B", sum: "\u2211", Sum: "\u2211", sung: "\u266A", sup1: "\xB9", sup2: "\xB2", sup3: "\xB3", sup: "\u2283", Sup: "\u22D1", supdot: "\u2ABE", supdsub: "\u2AD8", supE: "\u2AC6", supe: "\u2287", supedot: "\u2AC4", Superset: "\u2283", SupersetEqual: "\u2287", suphsol: "\u27C9", suphsub: "\u2AD7", suplarr: "\u297B", supmult: "\u2AC2", supnE: "\u2ACC", supne: "\u228B", supplus: "\u2AC0", supset: "\u2283", Supset: "\u22D1", supseteq: "\u2287", supseteqq: "\u2AC6", supsetneq: "\u228B", supsetneqq: "\u2ACC", supsim: "\u2AC8", supsub: "\u2AD4", supsup: "\u2AD6", swarhk: "\u2926", swarr: "\u2199", swArr: "\u21D9", swarrow: "\u2199", swnwar: "\u292A", szlig: "\xDF", Tab: "	", target: "\u2316", Tau: "\u03A4", tau: "\u03C4", tbrk: "\u23B4", Tcaron: "\u0164", tcaron: "\u0165", Tcedil: "\u0162", tcedil: "\u0163", Tcy: "\u0422", tcy: "\u0442", tdot: "\u20DB", telrec: "\u2315", Tfr: "\u{1D517}", tfr: "\u{1D531}", there4: "\u2234", therefore: "\u2234", Therefore: "\u2234", Theta: "\u0398", theta: "\u03B8", thetasym: "\u03D1", thetav: "\u03D1", thickapprox: "\u2248", thicksim: "\u223C", ThickSpace: "\u205F\u200A", ThinSpace: "\u2009", thinsp: "\u2009", thkap: "\u2248", thksim: "\u223C", THORN: "\xDE", thorn: "\xFE", tilde: "\u02DC", Tilde: "\u223C", TildeEqual: "\u2243", TildeFullEqual: "\u2245", TildeTilde: "\u2248", timesbar: "\u2A31", timesb: "\u22A0", times: "\xD7", timesd: "\u2A30", tint: "\u222D", toea: "\u2928", topbot: "\u2336", topcir: "\u2AF1", top: "\u22A4", Topf: "\u{1D54B}", topf: "\u{1D565}", topfork: "\u2ADA", tosa: "\u2929", tprime: "\u2034", trade: "\u2122", TRADE: "\u2122", triangle: "\u25B5", triangledown: "\u25BF", triangleleft: "\u25C3", trianglelefteq: "\u22B4", triangleq: "\u225C", triangleright: "\u25B9", trianglerighteq: "\u22B5", tridot: "\u25EC", trie: "\u225C", triminus: "\u2A3A", TripleDot: "\u20DB", triplus: "\u2A39", trisb: "\u29CD", tritime: "\u2A3B", trpezium: "\u23E2", Tscr: "\u{1D4AF}", tscr: "\u{1D4C9}", TScy: "\u0426", tscy: "\u0446", TSHcy: "\u040B", tshcy: "\u045B", Tstrok: "\u0166", tstrok: "\u0167", twixt: "\u226C", twoheadleftarrow: "\u219E", twoheadrightarrow: "\u21A0", Uacute: "\xDA", uacute: "\xFA", uarr: "\u2191", Uarr: "\u219F", uArr: "\u21D1", Uarrocir: "\u2949", Ubrcy: "\u040E", ubrcy: "\u045E", Ubreve: "\u016C", ubreve: "\u016D", Ucirc: "\xDB", ucirc: "\xFB", Ucy: "\u0423", ucy: "\u0443", udarr: "\u21C5", Udblac: "\u0170", udblac: "\u0171", udhar: "\u296E", ufisht: "\u297E", Ufr: "\u{1D518}", ufr: "\u{1D532}", Ugrave: "\xD9", ugrave: "\xF9", uHar: "\u2963", uharl: "\u21BF", uharr: "\u21BE", uhblk: "\u2580", ulcorn: "\u231C", ulcorner: "\u231C", ulcrop: "\u230F", ultri: "\u25F8", Umacr: "\u016A", umacr: "\u016B", uml: "\xA8", UnderBar: "_", UnderBrace: "\u23DF", UnderBracket: "\u23B5", UnderParenthesis: "\u23DD", Union: "\u22C3", UnionPlus: "\u228E", Uogon: "\u0172", uogon: "\u0173", Uopf: "\u{1D54C}", uopf: "\u{1D566}", UpArrowBar: "\u2912", uparrow: "\u2191", UpArrow: "\u2191", Uparrow: "\u21D1", UpArrowDownArrow: "\u21C5", updownarrow: "\u2195", UpDownArrow: "\u2195", Updownarrow: "\u21D5", UpEquilibrium: "\u296E", upharpoonleft: "\u21BF", upharpoonright: "\u21BE", uplus: "\u228E", UpperLeftArrow: "\u2196", UpperRightArrow: "\u2197", upsi: "\u03C5", Upsi: "\u03D2", upsih: "\u03D2", Upsilon: "\u03A5", upsilon: "\u03C5", UpTeeArrow: "\u21A5", UpTee: "\u22A5", upuparrows: "\u21C8", urcorn: "\u231D", urcorner: "\u231D", urcrop: "\u230E", Uring: "\u016E", uring: "\u016F", urtri: "\u25F9", Uscr: "\u{1D4B0}", uscr: "\u{1D4CA}", utdot: "\u22F0", Utilde: "\u0168", utilde: "\u0169", utri: "\u25B5", utrif: "\u25B4", uuarr: "\u21C8", Uuml: "\xDC", uuml: "\xFC", uwangle: "\u29A7", vangrt: "\u299C", varepsilon: "\u03F5", varkappa: "\u03F0", varnothing: "\u2205", varphi: "\u03D5", varpi: "\u03D6", varpropto: "\u221D", varr: "\u2195", vArr: "\u21D5", varrho: "\u03F1", varsigma: "\u03C2", varsubsetneq: "\u228A\uFE00", varsubsetneqq: "\u2ACB\uFE00", varsupsetneq: "\u228B\uFE00", varsupsetneqq: "\u2ACC\uFE00", vartheta: "\u03D1", vartriangleleft: "\u22B2", vartriangleright: "\u22B3", vBar: "\u2AE8", Vbar: "\u2AEB", vBarv: "\u2AE9", Vcy: "\u0412", vcy: "\u0432", vdash: "\u22A2", vDash: "\u22A8", Vdash: "\u22A9", VDash: "\u22AB", Vdashl: "\u2AE6", veebar: "\u22BB", vee: "\u2228", Vee: "\u22C1", veeeq: "\u225A", vellip: "\u22EE", verbar: "|", Verbar: "\u2016", vert: "|", Vert: "\u2016", VerticalBar: "\u2223", VerticalLine: "|", VerticalSeparator: "\u2758", VerticalTilde: "\u2240", VeryThinSpace: "\u200A", Vfr: "\u{1D519}", vfr: "\u{1D533}", vltri: "\u22B2", vnsub: "\u2282\u20D2", vnsup: "\u2283\u20D2", Vopf: "\u{1D54D}", vopf: "\u{1D567}", vprop: "\u221D", vrtri: "\u22B3", Vscr: "\u{1D4B1}", vscr: "\u{1D4CB}", vsubnE: "\u2ACB\uFE00", vsubne: "\u228A\uFE00", vsupnE: "\u2ACC\uFE00", vsupne: "\u228B\uFE00", Vvdash: "\u22AA", vzigzag: "\u299A", Wcirc: "\u0174", wcirc: "\u0175", wedbar: "\u2A5F", wedge: "\u2227", Wedge: "\u22C0", wedgeq: "\u2259", weierp: "\u2118", Wfr: "\u{1D51A}", wfr: "\u{1D534}", Wopf: "\u{1D54E}", wopf: "\u{1D568}", wp: "\u2118", wr: "\u2240", wreath: "\u2240", Wscr: "\u{1D4B2}", wscr: "\u{1D4CC}", xcap: "\u22C2", xcirc: "\u25EF", xcup: "\u22C3", xdtri: "\u25BD", Xfr: "\u{1D51B}", xfr: "\u{1D535}", xharr: "\u27F7", xhArr: "\u27FA", Xi: "\u039E", xi: "\u03BE", xlarr: "\u27F5", xlArr: "\u27F8", xmap: "\u27FC", xnis: "\u22FB", xodot: "\u2A00", Xopf: "\u{1D54F}", xopf: "\u{1D569}", xoplus: "\u2A01", xotime: "\u2A02", xrarr: "\u27F6", xrArr: "\u27F9", Xscr: "\u{1D4B3}", xscr: "\u{1D4CD}", xsqcup: "\u2A06", xuplus: "\u2A04", xutri: "\u25B3", xvee: "\u22C1", xwedge: "\u22C0", Yacute: "\xDD", yacute: "\xFD", YAcy: "\u042F", yacy: "\u044F", Ycirc: "\u0176", ycirc: "\u0177", Ycy: "\u042B", ycy: "\u044B", yen: "\xA5", Yfr: "\u{1D51C}", yfr: "\u{1D536}", YIcy: "\u0407", yicy: "\u0457", Yopf: "\u{1D550}", yopf: "\u{1D56A}", Yscr: "\u{1D4B4}", yscr: "\u{1D4CE}", YUcy: "\u042E", yucy: "\u044E", yuml: "\xFF", Yuml: "\u0178", Zacute: "\u0179", zacute: "\u017A", Zcaron: "\u017D", zcaron: "\u017E", Zcy: "\u0417", zcy: "\u0437", Zdot: "\u017B", zdot: "\u017C", zeetrf: "\u2128", ZeroWidthSpace: "\u200B", Zeta: "\u0396", zeta: "\u03B6", zfr: "\u{1D537}", Zfr: "\u2128", ZHcy: "\u0416", zhcy: "\u0436", zigrarr: "\u21DD", zopf: "\u{1D56B}", Zopf: "\u2124", Zscr: "\u{1D4B5}", zscr: "\u{1D4CF}", zwj: "\u200D", zwnj: "\u200C" }, c = /^#[xX]([A-Fa-f0-9]+)$/, o = /^#([0-9]+)$/, e = /^([A-Za-z0-9]+)$/, r = function() {
              function E(v) {
                this.named = v;
              }
              return E.prototype.parse = function(v) {
                if (v) {
                  var _ = v.match(c);
                  if (_)
                    return String.fromCharCode(parseInt(_[1], 16));
                  if (_ = v.match(o), _)
                    return String.fromCharCode(parseInt(_[1], 10));
                  if (_ = v.match(e), _)
                    return this.named[_[1]];
                }
              }, E;
            }(), a = /[\t\n\f ]/, p = /[A-Za-z]/, n = /\r\n?/g;
            function s(E) {
              return a.test(E);
            }
            function u(E) {
              return p.test(E);
            }
            function i(E) {
              return E.replace(n, `
`);
            }
            var l = function() {
              function E(v, _, y) {
                y === void 0 && (y = "precompile"), this.delegate = v, this.entityParser = _, this.mode = y, this.state = "beforeData", this.line = -1, this.column = -1, this.input = "", this.index = -1, this.tagNameBuffer = "", this.states = { beforeData: function() {
                  var g = this.peek();
                  if (g === "<" && !this.isIgnoredEndTag())
                    this.transitionTo("tagOpen"), this.markTagStart(), this.consume();
                  else {
                    if (this.mode === "precompile" && g === `
`) {
                      var L = this.tagNameBuffer.toLowerCase();
                      (L === "pre" || L === "textarea") && this.consume();
                    }
                    this.transitionTo("data"), this.delegate.beginData();
                  }
                }, data: function() {
                  var g = this.peek(), L = this.tagNameBuffer;
                  g === "<" && !this.isIgnoredEndTag() ? (this.delegate.finishData(), this.transitionTo("tagOpen"), this.markTagStart(), this.consume()) : g === "&" && L !== "script" && L !== "style" ? (this.consume(), this.delegate.appendToData(this.consumeCharRef() || "&")) : (this.consume(), this.delegate.appendToData(g));
                }, tagOpen: function() {
                  var g = this.consume();
                  g === "!" ? this.transitionTo("markupDeclarationOpen") : g === "/" ? this.transitionTo("endTagOpen") : (g === "@" || g === ":" || u(g)) && (this.transitionTo("tagName"), this.tagNameBuffer = "", this.delegate.beginStartTag(), this.appendToTagName(g));
                }, markupDeclarationOpen: function() {
                  var g = this.consume();
                  if (g === "-" && this.peek() === "-")
                    this.consume(), this.transitionTo("commentStart"), this.delegate.beginComment();
                  else {
                    var L = g.toUpperCase() + this.input.substring(this.index, this.index + 6).toUpperCase();
                    L === "DOCTYPE" && (this.consume(), this.consume(), this.consume(), this.consume(), this.consume(), this.consume(), this.transitionTo("doctype"), this.delegate.beginDoctype && this.delegate.beginDoctype());
                  }
                }, doctype: function() {
                  var g = this.consume();
                  s(g) && this.transitionTo("beforeDoctypeName");
                }, beforeDoctypeName: function() {
                  var g = this.consume();
                  s(g) || (this.transitionTo("doctypeName"), this.delegate.appendToDoctypeName && this.delegate.appendToDoctypeName(g.toLowerCase()));
                }, doctypeName: function() {
                  var g = this.consume();
                  s(g) ? this.transitionTo("afterDoctypeName") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : this.delegate.appendToDoctypeName && this.delegate.appendToDoctypeName(g.toLowerCase());
                }, afterDoctypeName: function() {
                  var g = this.consume();
                  if (!s(g))
                    if (g === ">")
                      this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData");
                    else {
                      var L = g.toUpperCase() + this.input.substring(this.index, this.index + 5).toUpperCase(), j = L.toUpperCase() === "PUBLIC", x = L.toUpperCase() === "SYSTEM";
                      (j || x) && (this.consume(), this.consume(), this.consume(), this.consume(), this.consume(), this.consume()), j ? this.transitionTo("afterDoctypePublicKeyword") : x && this.transitionTo("afterDoctypeSystemKeyword");
                    }
                }, afterDoctypePublicKeyword: function() {
                  var g = this.peek();
                  s(g) ? (this.transitionTo("beforeDoctypePublicIdentifier"), this.consume()) : g === '"' ? (this.transitionTo("doctypePublicIdentifierDoubleQuoted"), this.consume()) : g === "'" ? (this.transitionTo("doctypePublicIdentifierSingleQuoted"), this.consume()) : g === ">" && (this.consume(), this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData"));
                }, doctypePublicIdentifierDoubleQuoted: function() {
                  var g = this.consume();
                  g === '"' ? this.transitionTo("afterDoctypePublicIdentifier") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : this.delegate.appendToDoctypePublicIdentifier && this.delegate.appendToDoctypePublicIdentifier(g);
                }, doctypePublicIdentifierSingleQuoted: function() {
                  var g = this.consume();
                  g === "'" ? this.transitionTo("afterDoctypePublicIdentifier") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : this.delegate.appendToDoctypePublicIdentifier && this.delegate.appendToDoctypePublicIdentifier(g);
                }, afterDoctypePublicIdentifier: function() {
                  var g = this.consume();
                  s(g) ? this.transitionTo("betweenDoctypePublicAndSystemIdentifiers") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : g === '"' ? this.transitionTo("doctypeSystemIdentifierDoubleQuoted") : g === "'" && this.transitionTo("doctypeSystemIdentifierSingleQuoted");
                }, betweenDoctypePublicAndSystemIdentifiers: function() {
                  var g = this.consume();
                  s(g) || (g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : g === '"' ? this.transitionTo("doctypeSystemIdentifierDoubleQuoted") : g === "'" && this.transitionTo("doctypeSystemIdentifierSingleQuoted"));
                }, doctypeSystemIdentifierDoubleQuoted: function() {
                  var g = this.consume();
                  g === '"' ? this.transitionTo("afterDoctypeSystemIdentifier") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : this.delegate.appendToDoctypeSystemIdentifier && this.delegate.appendToDoctypeSystemIdentifier(g);
                }, doctypeSystemIdentifierSingleQuoted: function() {
                  var g = this.consume();
                  g === "'" ? this.transitionTo("afterDoctypeSystemIdentifier") : g === ">" ? (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData")) : this.delegate.appendToDoctypeSystemIdentifier && this.delegate.appendToDoctypeSystemIdentifier(g);
                }, afterDoctypeSystemIdentifier: function() {
                  var g = this.consume();
                  s(g) || g === ">" && (this.delegate.endDoctype && this.delegate.endDoctype(), this.transitionTo("beforeData"));
                }, commentStart: function() {
                  var g = this.consume();
                  g === "-" ? this.transitionTo("commentStartDash") : g === ">" ? (this.delegate.finishComment(), this.transitionTo("beforeData")) : (this.delegate.appendToCommentData(g), this.transitionTo("comment"));
                }, commentStartDash: function() {
                  var g = this.consume();
                  g === "-" ? this.transitionTo("commentEnd") : g === ">" ? (this.delegate.finishComment(), this.transitionTo("beforeData")) : (this.delegate.appendToCommentData("-"), this.transitionTo("comment"));
                }, comment: function() {
                  var g = this.consume();
                  g === "-" ? this.transitionTo("commentEndDash") : this.delegate.appendToCommentData(g);
                }, commentEndDash: function() {
                  var g = this.consume();
                  g === "-" ? this.transitionTo("commentEnd") : (this.delegate.appendToCommentData("-" + g), this.transitionTo("comment"));
                }, commentEnd: function() {
                  var g = this.consume();
                  g === ">" ? (this.delegate.finishComment(), this.transitionTo("beforeData")) : (this.delegate.appendToCommentData("--" + g), this.transitionTo("comment"));
                }, tagName: function() {
                  var g = this.consume();
                  s(g) ? this.transitionTo("beforeAttributeName") : g === "/" ? this.transitionTo("selfClosingStartTag") : g === ">" ? (this.delegate.finishTag(), this.transitionTo("beforeData")) : this.appendToTagName(g);
                }, endTagName: function() {
                  var g = this.consume();
                  s(g) ? (this.transitionTo("beforeAttributeName"), this.tagNameBuffer = "") : g === "/" ? (this.transitionTo("selfClosingStartTag"), this.tagNameBuffer = "") : g === ">" ? (this.delegate.finishTag(), this.transitionTo("beforeData"), this.tagNameBuffer = "") : this.appendToTagName(g);
                }, beforeAttributeName: function() {
                  var g = this.peek();
                  if (s(g)) {
                    this.consume();
                    return;
                  } else
                    g === "/" ? (this.transitionTo("selfClosingStartTag"), this.consume()) : g === ">" ? (this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : g === "=" ? (this.delegate.reportSyntaxError("attribute name cannot start with equals sign"), this.transitionTo("attributeName"), this.delegate.beginAttribute(), this.consume(), this.delegate.appendToAttributeName(g)) : (this.transitionTo("attributeName"), this.delegate.beginAttribute());
                }, attributeName: function() {
                  var g = this.peek();
                  s(g) ? (this.transitionTo("afterAttributeName"), this.consume()) : g === "/" ? (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.consume(), this.transitionTo("selfClosingStartTag")) : g === "=" ? (this.transitionTo("beforeAttributeValue"), this.consume()) : g === ">" ? (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : g === '"' || g === "'" || g === "<" ? (this.delegate.reportSyntaxError(g + " is not a valid character within attribute names"), this.consume(), this.delegate.appendToAttributeName(g)) : (this.consume(), this.delegate.appendToAttributeName(g));
                }, afterAttributeName: function() {
                  var g = this.peek();
                  if (s(g)) {
                    this.consume();
                    return;
                  } else
                    g === "/" ? (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.consume(), this.transitionTo("selfClosingStartTag")) : g === "=" ? (this.consume(), this.transitionTo("beforeAttributeValue")) : g === ">" ? (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.transitionTo("attributeName"), this.delegate.beginAttribute(), this.consume(), this.delegate.appendToAttributeName(g));
                }, beforeAttributeValue: function() {
                  var g = this.peek();
                  s(g) ? this.consume() : g === '"' ? (this.transitionTo("attributeValueDoubleQuoted"), this.delegate.beginAttributeValue(true), this.consume()) : g === "'" ? (this.transitionTo("attributeValueSingleQuoted"), this.delegate.beginAttributeValue(true), this.consume()) : g === ">" ? (this.delegate.beginAttributeValue(false), this.delegate.finishAttributeValue(), this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : (this.transitionTo("attributeValueUnquoted"), this.delegate.beginAttributeValue(false), this.consume(), this.delegate.appendToAttributeValue(g));
                }, attributeValueDoubleQuoted: function() {
                  var g = this.consume();
                  g === '"' ? (this.delegate.finishAttributeValue(), this.transitionTo("afterAttributeValueQuoted")) : g === "&" ? this.delegate.appendToAttributeValue(this.consumeCharRef() || "&") : this.delegate.appendToAttributeValue(g);
                }, attributeValueSingleQuoted: function() {
                  var g = this.consume();
                  g === "'" ? (this.delegate.finishAttributeValue(), this.transitionTo("afterAttributeValueQuoted")) : g === "&" ? this.delegate.appendToAttributeValue(this.consumeCharRef() || "&") : this.delegate.appendToAttributeValue(g);
                }, attributeValueUnquoted: function() {
                  var g = this.peek();
                  s(g) ? (this.delegate.finishAttributeValue(), this.consume(), this.transitionTo("beforeAttributeName")) : g === "/" ? (this.delegate.finishAttributeValue(), this.consume(), this.transitionTo("selfClosingStartTag")) : g === "&" ? (this.consume(), this.delegate.appendToAttributeValue(this.consumeCharRef() || "&")) : g === ">" ? (this.delegate.finishAttributeValue(), this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : (this.consume(), this.delegate.appendToAttributeValue(g));
                }, afterAttributeValueQuoted: function() {
                  var g = this.peek();
                  s(g) ? (this.consume(), this.transitionTo("beforeAttributeName")) : g === "/" ? (this.consume(), this.transitionTo("selfClosingStartTag")) : g === ">" ? (this.consume(), this.delegate.finishTag(), this.transitionTo("beforeData")) : this.transitionTo("beforeAttributeName");
                }, selfClosingStartTag: function() {
                  var g = this.peek();
                  g === ">" ? (this.consume(), this.delegate.markTagAsSelfClosing(), this.delegate.finishTag(), this.transitionTo("beforeData")) : this.transitionTo("beforeAttributeName");
                }, endTagOpen: function() {
                  var g = this.consume();
                  (g === "@" || g === ":" || u(g)) && (this.transitionTo("endTagName"), this.tagNameBuffer = "", this.delegate.beginEndTag(), this.appendToTagName(g));
                } }, this.reset();
              }
              return E.prototype.reset = function() {
                this.transitionTo("beforeData"), this.input = "", this.tagNameBuffer = "", this.index = 0, this.line = 1, this.column = 0, this.delegate.reset();
              }, E.prototype.transitionTo = function(v) {
                this.state = v;
              }, E.prototype.tokenize = function(v) {
                this.reset(), this.tokenizePart(v), this.tokenizeEOF();
              }, E.prototype.tokenizePart = function(v) {
                for (this.input += i(v); this.index < this.input.length; ) {
                  var _ = this.states[this.state];
                  if (_ !== void 0)
                    _.call(this);
                  else
                    throw new Error("unhandled state " + this.state);
                }
              }, E.prototype.tokenizeEOF = function() {
                this.flushData();
              }, E.prototype.flushData = function() {
                this.state === "data" && (this.delegate.finishData(), this.transitionTo("beforeData"));
              }, E.prototype.peek = function() {
                return this.input.charAt(this.index);
              }, E.prototype.consume = function() {
                var v = this.peek();
                return this.index++, v === `
` ? (this.line++, this.column = 0) : this.column++, v;
              }, E.prototype.consumeCharRef = function() {
                var v = this.input.indexOf(";", this.index);
                if (v !== -1) {
                  var _ = this.input.slice(this.index, v), y = this.entityParser.parse(_);
                  if (y) {
                    for (var g = _.length; g; )
                      this.consume(), g--;
                    return this.consume(), y;
                  }
                }
              }, E.prototype.markTagStart = function() {
                this.delegate.tagOpen();
              }, E.prototype.appendToTagName = function(v) {
                this.tagNameBuffer += v, this.delegate.appendToTagName(v);
              }, E.prototype.isIgnoredEndTag = function() {
                var v = this.tagNameBuffer;
                return v === "title" && this.input.substring(this.index, this.index + 8) !== "</title>" || v === "style" && this.input.substring(this.index, this.index + 8) !== "</style>" || v === "script" && this.input.substring(this.index, this.index + 9) !== "</script>";
              }, E;
            }(), b = function() {
              function E(v, _) {
                _ === void 0 && (_ = {}), this.options = _, this.token = null, this.startLine = 1, this.startColumn = 0, this.tokens = [], this.tokenizer = new l(this, v, _.mode), this._currentAttribute = void 0;
              }
              return E.prototype.tokenize = function(v) {
                return this.tokens = [], this.tokenizer.tokenize(v), this.tokens;
              }, E.prototype.tokenizePart = function(v) {
                return this.tokens = [], this.tokenizer.tokenizePart(v), this.tokens;
              }, E.prototype.tokenizeEOF = function() {
                return this.tokens = [], this.tokenizer.tokenizeEOF(), this.tokens[0];
              }, E.prototype.reset = function() {
                this.token = null, this.startLine = 1, this.startColumn = 0;
              }, E.prototype.current = function() {
                var v = this.token;
                if (v === null)
                  throw new Error("token was unexpectedly null");
                if (arguments.length === 0)
                  return v;
                for (var _ = 0; _ < arguments.length; _++)
                  if (v.type === arguments[_])
                    return v;
                throw new Error("token type was unexpectedly " + v.type);
              }, E.prototype.push = function(v) {
                this.token = v, this.tokens.push(v);
              }, E.prototype.currentAttribute = function() {
                return this._currentAttribute;
              }, E.prototype.addLocInfo = function() {
                this.options.loc && (this.current().loc = { start: { line: this.startLine, column: this.startColumn }, end: { line: this.tokenizer.line, column: this.tokenizer.column } }), this.startLine = this.tokenizer.line, this.startColumn = this.tokenizer.column;
              }, E.prototype.beginDoctype = function() {
                this.push({ type: "Doctype", name: "" });
              }, E.prototype.appendToDoctypeName = function(v) {
                this.current("Doctype").name += v;
              }, E.prototype.appendToDoctypePublicIdentifier = function(v) {
                var _ = this.current("Doctype");
                _.publicIdentifier === void 0 ? _.publicIdentifier = v : _.publicIdentifier += v;
              }, E.prototype.appendToDoctypeSystemIdentifier = function(v) {
                var _ = this.current("Doctype");
                _.systemIdentifier === void 0 ? _.systemIdentifier = v : _.systemIdentifier += v;
              }, E.prototype.endDoctype = function() {
                this.addLocInfo();
              }, E.prototype.beginData = function() {
                this.push({ type: "Chars", chars: "" });
              }, E.prototype.appendToData = function(v) {
                this.current("Chars").chars += v;
              }, E.prototype.finishData = function() {
                this.addLocInfo();
              }, E.prototype.beginComment = function() {
                this.push({ type: "Comment", chars: "" });
              }, E.prototype.appendToCommentData = function(v) {
                this.current("Comment").chars += v;
              }, E.prototype.finishComment = function() {
                this.addLocInfo();
              }, E.prototype.tagOpen = function() {
              }, E.prototype.beginStartTag = function() {
                this.push({ type: "StartTag", tagName: "", attributes: [], selfClosing: false });
              }, E.prototype.beginEndTag = function() {
                this.push({ type: "EndTag", tagName: "" });
              }, E.prototype.finishTag = function() {
                this.addLocInfo();
              }, E.prototype.markTagAsSelfClosing = function() {
                this.current("StartTag").selfClosing = true;
              }, E.prototype.appendToTagName = function(v) {
                this.current("StartTag", "EndTag").tagName += v;
              }, E.prototype.beginAttribute = function() {
                this._currentAttribute = ["", "", false];
              }, E.prototype.appendToAttributeName = function(v) {
                this.currentAttribute()[0] += v;
              }, E.prototype.beginAttributeValue = function(v) {
                this.currentAttribute()[2] = v;
              }, E.prototype.appendToAttributeValue = function(v) {
                this.currentAttribute()[1] += v;
              }, E.prototype.finishAttributeValue = function() {
                this.current("StartTag").attributes.push(this._currentAttribute);
              }, E.prototype.reportSyntaxError = function(v) {
                this.current().syntaxError = v;
              }, E;
            }();
            function P(E, v) {
              var _ = new b(new r(d), v);
              return _.tokenize(E);
            }
            h.HTML5NamedCharRefs = d, h.EntityParser = r, h.EventedTokenizer = l, h.Tokenizer = b, h.tokenize = P, Object.defineProperty(h, "__esModule", { value: true });
          });
        } }), We = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/generation/print.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = d;
          var f = h(Te());
          function h(c) {
            return c && c.__esModule ? c : { default: c };
          }
          function d(c) {
            let o = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : { entityEncoding: "transformed" };
            return c ? new f.default(o).print(c) : "";
          }
        } }), he = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/syntax-error.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.generateSyntaxError = f;
          function f(h, d) {
            let { module: c, loc: o } = d, { line: e, column: r } = o.start, a = d.asString(), p = a ? `

|
|  ${a.split(`
`).join(`
|  `)}
|

` : "", n = new Error(`${h}: ${p}(error occurred in '${c}' @ line ${e} : column ${r})`);
            return n.name = "SyntaxError", n.location = d, n.code = a, n;
          }
        } }), Rt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/visitor-keys.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = X(), h = { Program: (0, f.tuple)("body"), Template: (0, f.tuple)("body"), Block: (0, f.tuple)("body"), MustacheStatement: (0, f.tuple)("path", "params", "hash"), BlockStatement: (0, f.tuple)("path", "params", "hash", "program", "inverse"), ElementModifierStatement: (0, f.tuple)("path", "params", "hash"), PartialStatement: (0, f.tuple)("name", "params", "hash"), CommentStatement: (0, f.tuple)(), MustacheCommentStatement: (0, f.tuple)(), ElementNode: (0, f.tuple)("attributes", "modifiers", "children", "comments"), AttrNode: (0, f.tuple)("value"), TextNode: (0, f.tuple)(), ConcatStatement: (0, f.tuple)("parts"), SubExpression: (0, f.tuple)("path", "params", "hash"), PathExpression: (0, f.tuple)(), PathHead: (0, f.tuple)(), StringLiteral: (0, f.tuple)(), BooleanLiteral: (0, f.tuple)(), NumberLiteral: (0, f.tuple)(), NullLiteral: (0, f.tuple)(), UndefinedLiteral: (0, f.tuple)(), Hash: (0, f.tuple)("pairs"), HashPair: (0, f.tuple)("value"), NamedBlock: (0, f.tuple)("attributes", "modifiers", "children", "comments"), SimpleElement: (0, f.tuple)("attributes", "modifiers", "children", "comments"), Component: (0, f.tuple)("head", "attributes", "modifiers", "children", "comments") }, d = h;
          t3.default = d;
        } }), Ye = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/traversal/errors.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.cannotRemoveNode = d, t3.cannotReplaceNode = c, t3.cannotReplaceOrRemoveInKeyHandlerYet = o, t3.default = void 0;
          var f = function() {
            e.prototype = Object.create(Error.prototype), e.prototype.constructor = e;
            function e(r, a, p, n) {
              let s = Error.call(this, r);
              this.key = n, this.message = r, this.node = a, this.parent = p, this.stack = s.stack;
            }
            return e;
          }(), h = f;
          t3.default = h;
          function d(e, r, a) {
            return new f("Cannot remove a node unless it is part of an array", e, r, a);
          }
          function c(e, r, a) {
            return new f("Cannot replace a node with multiple nodes unless it is part of an array", e, r, a);
          }
          function o(e, r) {
            return new f("Replacing and removing in key handlers is not yet supported.", e, null, r);
          }
        } }), Qe = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/traversal/path.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = class {
            constructor(d) {
              let c = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null, o = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
              this.node = d, this.parent = c, this.parentKey = o;
            }
            get parentNode() {
              return this.parent ? this.parent.node : null;
            }
            parents() {
              return { [Symbol.iterator]: () => new h(this) };
            }
          };
          t3.default = f;
          var h = class {
            constructor(d) {
              this.path = d;
            }
            next() {
              return this.path.parent ? (this.path = this.path.parent, { done: false, value: this.path }) : { done: true, value: null };
            }
          };
        } }), Ne = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/traversal/traverse.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = E;
          var f = X(), h = o(Rt()), d = Ye(), c = o(Qe());
          function o(v) {
            return v && v.__esModule ? v : { default: v };
          }
          function e(v) {
            return typeof v == "function" ? v : v.enter;
          }
          function r(v) {
            if (typeof v != "function")
              return v.exit;
          }
          function a(v, _) {
            let y = typeof v != "function" ? v.keys : void 0;
            if (y === void 0)
              return;
            let g = y[_];
            return g !== void 0 ? g : y.All;
          }
          function p(v, _) {
            if ((_ === "Template" || _ === "Block") && v.Program)
              return v.Program;
            let y = v[_];
            return y !== void 0 ? y : v.All;
          }
          function n(v, _) {
            let { node: y, parent: g, parentKey: L } = _, j = p(v, y.type), x, w;
            j !== void 0 && (x = e(j), w = r(j));
            let H;
            if (x !== void 0 && (H = x(y, _)), H != null)
              if (JSON.stringify(y) === JSON.stringify(H))
                H = void 0;
              else {
                if (Array.isArray(H))
                  return l(v, H, g, L), H;
                {
                  let m = new c.default(H, g, L);
                  return n(v, m) || H;
                }
              }
            if (H === void 0) {
              let m = h.default[y.type];
              for (let C = 0; C < m.length; C++) {
                let S = m[C];
                i(v, j, _, S);
              }
              w !== void 0 && (H = w(y, _));
            }
            return H;
          }
          function s(v, _) {
            return v[_];
          }
          function u(v, _, y) {
            v[_] = y;
          }
          function i(v, _, y, g) {
            let { node: L } = y, j = s(L, g);
            if (!j)
              return;
            let x, w;
            if (_ !== void 0) {
              let H = a(_, g);
              H !== void 0 && (x = e(H), w = r(H));
            }
            if (x !== void 0 && x(L, g) !== void 0)
              throw (0, d.cannotReplaceOrRemoveInKeyHandlerYet)(L, g);
            if (Array.isArray(j))
              l(v, j, y, g);
            else {
              let H = new c.default(j, y, g), m = n(v, H);
              m !== void 0 && b(L, g, j, m);
            }
            if (w !== void 0 && w(L, g) !== void 0)
              throw (0, d.cannotReplaceOrRemoveInKeyHandlerYet)(L, g);
          }
          function l(v, _, y, g) {
            for (let L = 0; L < _.length; L++) {
              let j = _[L], x = new c.default(j, y, g), w = n(v, x);
              w !== void 0 && (L += P(_, L, w) - 1);
            }
          }
          function b(v, _, y, g) {
            if (g === null)
              throw (0, d.cannotRemoveNode)(y, v, _);
            if (Array.isArray(g))
              if (g.length === 1)
                u(v, _, g[0]);
              else
                throw g.length === 0 ? (0, d.cannotRemoveNode)(y, v, _) : (0, d.cannotReplaceNode)(y, v, _);
            else
              u(v, _, g);
          }
          function P(v, _, y) {
            return y === null ? (v.splice(_, 1), 0) : Array.isArray(y) ? (v.splice(_, 1, ...y), y.length) : (v.splice(_, 1, y), 1);
          }
          function E(v, _) {
            let y = new c.default(v);
            n(_, y);
          }
        } }), Je = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/traversal/walker.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = class {
            constructor(d) {
              this.order = d, this.stack = [];
            }
            visit(d, c) {
              d && (this.stack.push(d), this.order === "post" ? (this.children(d, c), c(d, this)) : (c(d, this), this.children(d, c)), this.stack.pop());
            }
            children(d, c) {
              switch (d.type) {
                case "Block":
                case "Template":
                  return h.Program(this, d, c);
                case "ElementNode":
                  return h.ElementNode(this, d, c);
                case "BlockStatement":
                  return h.BlockStatement(this, d, c);
                default:
                  return;
              }
            }
          };
          t3.default = f;
          var h = { Program(d, c, o) {
            for (let e = 0; e < c.body.length; e++)
              d.visit(c.body[e], o);
          }, Template(d, c, o) {
            for (let e = 0; e < c.body.length; e++)
              d.visit(c.body[e], o);
          }, Block(d, c, o) {
            for (let e = 0; e < c.body.length; e++)
              d.visit(c.body[e], o);
          }, ElementNode(d, c, o) {
            for (let e = 0; e < c.children.length; e++)
              d.visit(c.children[e], o);
          }, BlockStatement(d, c, o) {
            d.visit(c.program, o), d.visit(c.inverse || null, o);
          } };
        } }), ye = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/utils.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.parseElementBlockParams = d, t3.childrenFor = o, t3.appendChild = e, t3.isHBSLiteral = r, t3.printLiteral = a, t3.isUpperCase = p, t3.isLowerCase = n;
          var f = he(), h = /[!"#%-,\.\/;->@\[-\^`\{-~]/;
          function d(s) {
            let u = c(s);
            u && (s.blockParams = u);
          }
          function c(s) {
            let u = s.attributes.length, i = [];
            for (let b = 0; b < u; b++)
              i.push(s.attributes[b].name);
            let l = i.indexOf("as");
            if (l === -1 && i.length > 0 && i[i.length - 1].charAt(0) === "|")
              throw (0, f.generateSyntaxError)("Block parameters must be preceded by the `as` keyword, detected block parameters without `as`", s.loc);
            if (l !== -1 && u > l && i[l + 1].charAt(0) === "|") {
              let b = i.slice(l).join(" ");
              if (b.charAt(b.length - 1) !== "|" || b.match(/\|/g).length !== 2)
                throw (0, f.generateSyntaxError)("Invalid block parameters syntax, '" + b + "'", s.loc);
              let P = [];
              for (let E = l + 1; E < u; E++) {
                let v = i[E].replace(/\|/g, "");
                if (v !== "") {
                  if (h.test(v))
                    throw (0, f.generateSyntaxError)("Invalid identifier for block parameters, '" + v + "'", s.loc);
                  P.push(v);
                }
              }
              if (P.length === 0)
                throw (0, f.generateSyntaxError)("Cannot use zero block parameters", s.loc);
              return s.attributes = s.attributes.slice(0, l), P;
            }
            return null;
          }
          function o(s) {
            switch (s.type) {
              case "Block":
              case "Template":
                return s.body;
              case "ElementNode":
                return s.children;
            }
          }
          function e(s, u) {
            o(s).push(u);
          }
          function r(s) {
            return s.type === "StringLiteral" || s.type === "BooleanLiteral" || s.type === "NumberLiteral" || s.type === "NullLiteral" || s.type === "UndefinedLiteral";
          }
          function a(s) {
            return s.type === "UndefinedLiteral" ? "undefined" : JSON.stringify(s.value);
          }
          function p(s) {
            return s[0] === s[0].toUpperCase() && s[0] !== s[0].toLowerCase();
          }
          function n(s) {
            return s[0] === s[0].toLowerCase() && s[0] !== s[0].toUpperCase();
          }
        } }), Le = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v1/parser-builders.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.default = void 0;
          var f = X(), h = we(), d = { close: false, open: false }, c = class {
            pos(r, a) {
              return { line: r, column: a };
            }
            blockItself(r) {
              let { body: a, blockParams: p, chained: n = false, loc: s } = r;
              return { type: "Block", body: a || [], blockParams: p || [], chained: n, loc: s };
            }
            template(r) {
              let { body: a, blockParams: p, loc: n } = r;
              return { type: "Template", body: a || [], blockParams: p || [], loc: n };
            }
            mustache(r) {
              let { path: a, params: p, hash: n, trusting: s, loc: u, strip: i = d } = r;
              return { type: "MustacheStatement", path: a, params: p, hash: n, escaped: !s, trusting: s, loc: u, strip: i || { open: false, close: false } };
            }
            block(r) {
              let { path: a, params: p, hash: n, defaultBlock: s, elseBlock: u = null, loc: i, openStrip: l = d, inverseStrip: b = d, closeStrip: P = d } = r;
              return { type: "BlockStatement", path: a, params: p, hash: n, program: s, inverse: u, loc: i, openStrip: l, inverseStrip: b, closeStrip: P };
            }
            comment(r, a) {
              return { type: "CommentStatement", value: r, loc: a };
            }
            mustacheComment(r, a) {
              return { type: "MustacheCommentStatement", value: r, loc: a };
            }
            concat(r, a) {
              return { type: "ConcatStatement", parts: r, loc: a };
            }
            element(r) {
              let { tag: a, selfClosing: p, attrs: n, blockParams: s, modifiers: u, comments: i, children: l, loc: b } = r;
              return { type: "ElementNode", tag: a, selfClosing: p, attributes: n || [], blockParams: s || [], modifiers: u || [], comments: i || [], children: l || [], loc: b };
            }
            elementModifier(r) {
              let { path: a, params: p, hash: n, loc: s } = r;
              return { type: "ElementModifierStatement", path: a, params: p, hash: n, loc: s };
            }
            attr(r) {
              let { name: a, value: p, loc: n } = r;
              return { type: "AttrNode", name: a, value: p, loc: n };
            }
            text(r) {
              let { chars: a, loc: p } = r;
              return { type: "TextNode", chars: a, loc: p };
            }
            sexpr(r) {
              let { path: a, params: p, hash: n, loc: s } = r;
              return { type: "SubExpression", path: a, params: p, hash: n, loc: s };
            }
            path(r) {
              let { head: a, tail: p, loc: n } = r, { original: s } = o(a), u = [...s, ...p].join(".");
              return new h.PathExpressionImplV1(u, a, p, n);
            }
            head(r, a) {
              return r[0] === "@" ? this.atName(r, a) : r === "this" ? this.this(a) : this.var(r, a);
            }
            this(r) {
              return { type: "ThisHead", loc: r };
            }
            atName(r, a) {
              return { type: "AtHead", name: r, loc: a };
            }
            var(r, a) {
              return { type: "VarHead", name: r, loc: a };
            }
            hash(r, a) {
              return { type: "Hash", pairs: r || [], loc: a };
            }
            pair(r) {
              let { key: a, value: p, loc: n } = r;
              return { type: "HashPair", key: a, value: p, loc: n };
            }
            literal(r) {
              let { type: a, value: p, loc: n } = r;
              return { type: a, value: p, original: p, loc: n };
            }
            undefined() {
              return this.literal({ type: "UndefinedLiteral", value: void 0 });
            }
            null() {
              return this.literal({ type: "NullLiteral", value: null });
            }
            string(r, a) {
              return this.literal({ type: "StringLiteral", value: r, loc: a });
            }
            boolean(r, a) {
              return this.literal({ type: "BooleanLiteral", value: r, loc: a });
            }
            number(r, a) {
              return this.literal({ type: "NumberLiteral", value: r, loc: a });
            }
          };
          function o(r) {
            switch (r.type) {
              case "AtHead":
                return { original: r.name, parts: [r.name] };
              case "ThisHead":
                return { original: "this", parts: [] };
              case "VarHead":
                return { original: r.name, parts: [r.name] };
            }
          }
          var e = new c();
          t3.default = e;
        } }), qt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/parser.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.Parser = void 0;
          var f = X(), h = Ke(), d = class {
            constructor(c) {
              let o = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : new h.EntityParser(h.HTML5NamedCharRefs), e = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "precompile";
              this.elementStack = [], this.currentAttribute = null, this.currentNode = null, this.source = c, this.lines = c.source.split(/(?:\r\n?|\n)/g), this.tokenizer = new h.EventedTokenizer(this, o, e);
            }
            offset() {
              let { line: c, column: o } = this.tokenizer;
              return this.source.offsetFor(c, o);
            }
            pos(c) {
              let { line: o, column: e } = c;
              return this.source.offsetFor(o, e);
            }
            finish(c) {
              return (0, f.assign)({}, c, { loc: c.loc.until(this.offset()) });
            }
            get currentAttr() {
              return this.currentAttribute;
            }
            get currentTag() {
              return this.currentNode;
            }
            get currentStartTag() {
              return this.currentNode;
            }
            get currentEndTag() {
              return this.currentNode;
            }
            get currentComment() {
              return this.currentNode;
            }
            get currentData() {
              return this.currentNode;
            }
            acceptTemplate(c) {
              return this[c.type](c);
            }
            acceptNode(c) {
              return this[c.type](c);
            }
            currentElement() {
              return this.elementStack[this.elementStack.length - 1];
            }
            sourceForNode(c, o) {
              let e = c.loc.start.line - 1, r = e - 1, a = c.loc.start.column, p = [], n, s, u;
              for (o ? (s = o.loc.end.line - 1, u = o.loc.end.column) : (s = c.loc.end.line - 1, u = c.loc.end.column); r < s; )
                r++, n = this.lines[r], r === e ? e === s ? p.push(n.slice(a, u)) : p.push(n.slice(a)) : r === s ? p.push(n.slice(0, u)) : p.push(n);
              return p.join(`
`);
            }
          };
          t3.Parser = d;
        } }), xt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/parser/handlebars-node-visitors.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.HandlebarsNodeVisitors = void 0;
          var f = qt(), h = ge(), d = he(), c = ye(), o = we(), e = r(Le());
          function r(i) {
            return i && i.__esModule ? i : { default: i };
          }
          var a = class extends f.Parser {
            get isTopLevel() {
              return this.elementStack.length === 0;
            }
            Program(i) {
              let l = [], b;
              this.isTopLevel ? b = e.default.template({ body: l, blockParams: i.blockParams, loc: this.source.spanFor(i.loc) }) : b = e.default.blockItself({ body: l, blockParams: i.blockParams, chained: i.chained, loc: this.source.spanFor(i.loc) });
              let P, E = i.body.length;
              if (this.elementStack.push(b), E === 0)
                return this.elementStack.pop();
              for (P = 0; P < E; P++)
                this.acceptNode(i.body[P]);
              let v = this.elementStack.pop();
              if (v !== b) {
                let _ = v;
                throw (0, d.generateSyntaxError)(`Unclosed element \`${_.tag}\``, _.loc);
              }
              return b;
            }
            BlockStatement(i) {
              if (this.tokenizer.state === "comment") {
                this.appendToCommentData(this.sourceForNode(i));
                return;
              }
              if (this.tokenizer.state !== "data" && this.tokenizer.state !== "beforeData")
                throw (0, d.generateSyntaxError)("A block may only be used inside an HTML element or another block.", this.source.spanFor(i.loc));
              let { path: l, params: b, hash: P } = s(this, i);
              i.program.loc || (i.program.loc = h.NON_EXISTENT_LOCATION), i.inverse && !i.inverse.loc && (i.inverse.loc = h.NON_EXISTENT_LOCATION);
              let E = this.Program(i.program), v = i.inverse ? this.Program(i.inverse) : null, _ = e.default.block({ path: l, params: b, hash: P, defaultBlock: E, elseBlock: v, loc: this.source.spanFor(i.loc), openStrip: i.openStrip, inverseStrip: i.inverseStrip, closeStrip: i.closeStrip }), y = this.currentElement();
              (0, c.appendChild)(y, _);
            }
            MustacheStatement(i) {
              let { tokenizer: l } = this;
              if (l.state === "comment") {
                this.appendToCommentData(this.sourceForNode(i));
                return;
              }
              let b, { escaped: P, loc: E, strip: v } = i;
              if ((0, c.isHBSLiteral)(i.path))
                b = e.default.mustache({ path: this.acceptNode(i.path), params: [], hash: e.default.hash([], this.source.spanFor(i.path.loc).collapse("end")), trusting: !P, loc: this.source.spanFor(E), strip: v });
              else {
                let { path: _, params: y, hash: g } = s(this, i);
                b = e.default.mustache({ path: _, params: y, hash: g, trusting: !P, loc: this.source.spanFor(E), strip: v });
              }
              switch (l.state) {
                case "tagOpen":
                case "tagName":
                  throw (0, d.generateSyntaxError)("Cannot use mustaches in an elements tagname", b.loc);
                case "beforeAttributeName":
                  u(this.currentStartTag, b);
                  break;
                case "attributeName":
                case "afterAttributeName":
                  this.beginAttributeValue(false), this.finishAttributeValue(), u(this.currentStartTag, b), l.transitionTo("beforeAttributeName");
                  break;
                case "afterAttributeValueQuoted":
                  u(this.currentStartTag, b), l.transitionTo("beforeAttributeName");
                  break;
                case "beforeAttributeValue":
                  this.beginAttributeValue(false), this.appendDynamicAttributeValuePart(b), l.transitionTo("attributeValueUnquoted");
                  break;
                case "attributeValueDoubleQuoted":
                case "attributeValueSingleQuoted":
                case "attributeValueUnquoted":
                  this.appendDynamicAttributeValuePart(b);
                  break;
                default:
                  (0, c.appendChild)(this.currentElement(), b);
              }
              return b;
            }
            appendDynamicAttributeValuePart(i) {
              this.finalizeTextPart();
              let l = this.currentAttr;
              l.isDynamic = true, l.parts.push(i);
            }
            finalizeTextPart() {
              let l = this.currentAttr.currentPart;
              l !== null && (this.currentAttr.parts.push(l), this.startTextPart());
            }
            startTextPart() {
              this.currentAttr.currentPart = null;
            }
            ContentStatement(i) {
              n(this.tokenizer, i), this.tokenizer.tokenizePart(i.value), this.tokenizer.flushData();
            }
            CommentStatement(i) {
              let { tokenizer: l } = this;
              if (l.state === "comment")
                return this.appendToCommentData(this.sourceForNode(i)), null;
              let { value: b, loc: P } = i, E = e.default.mustacheComment(b, this.source.spanFor(P));
              switch (l.state) {
                case "beforeAttributeName":
                case "afterAttributeName":
                  this.currentStartTag.comments.push(E);
                  break;
                case "beforeData":
                case "data":
                  (0, c.appendChild)(this.currentElement(), E);
                  break;
                default:
                  throw (0, d.generateSyntaxError)(`Using a Handlebars comment when in the \`${l.state}\` state is not supported`, this.source.spanFor(i.loc));
              }
              return E;
            }
            PartialStatement(i) {
              throw (0, d.generateSyntaxError)("Handlebars partials are not supported", this.source.spanFor(i.loc));
            }
            PartialBlockStatement(i) {
              throw (0, d.generateSyntaxError)("Handlebars partial blocks are not supported", this.source.spanFor(i.loc));
            }
            Decorator(i) {
              throw (0, d.generateSyntaxError)("Handlebars decorators are not supported", this.source.spanFor(i.loc));
            }
            DecoratorBlock(i) {
              throw (0, d.generateSyntaxError)("Handlebars decorator blocks are not supported", this.source.spanFor(i.loc));
            }
            SubExpression(i) {
              let { path: l, params: b, hash: P } = s(this, i);
              return e.default.sexpr({ path: l, params: b, hash: P, loc: this.source.spanFor(i.loc) });
            }
            PathExpression(i) {
              let { original: l } = i, b;
              if (l.indexOf("/") !== -1) {
                if (l.slice(0, 2) === "./")
                  throw (0, d.generateSyntaxError)('Using "./" is not supported in Glimmer and unnecessary', this.source.spanFor(i.loc));
                if (l.slice(0, 3) === "../")
                  throw (0, d.generateSyntaxError)('Changing context using "../" is not supported in Glimmer', this.source.spanFor(i.loc));
                if (l.indexOf(".") !== -1)
                  throw (0, d.generateSyntaxError)("Mixing '.' and '/' in paths is not supported in Glimmer; use only '.' to separate property paths", this.source.spanFor(i.loc));
                b = [i.parts.join("/")];
              } else {
                if (l === ".")
                  throw (0, d.generateSyntaxError)("'.' is not a supported path in Glimmer; check for a path with a trailing '.'", this.source.spanFor(i.loc));
                b = i.parts;
              }
              let P = false;
              l.match(/^this(\..+)?$/) && (P = true);
              let E;
              if (P)
                E = { type: "ThisHead", loc: { start: i.loc.start, end: { line: i.loc.start.line, column: i.loc.start.column + 4 } } };
              else if (i.data) {
                let v = b.shift();
                if (v === void 0)
                  throw (0, d.generateSyntaxError)("Attempted to parse a path expression, but it was not valid. Paths beginning with @ must start with a-z.", this.source.spanFor(i.loc));
                E = { type: "AtHead", name: `@${v}`, loc: { start: i.loc.start, end: { line: i.loc.start.line, column: i.loc.start.column + v.length + 1 } } };
              } else {
                let v = b.shift();
                if (v === void 0)
                  throw (0, d.generateSyntaxError)("Attempted to parse a path expression, but it was not valid. Paths must start with a-z or A-Z.", this.source.spanFor(i.loc));
                E = { type: "VarHead", name: v, loc: { start: i.loc.start, end: { line: i.loc.start.line, column: i.loc.start.column + v.length } } };
              }
              return new o.PathExpressionImplV1(i.original, E, b, this.source.spanFor(i.loc));
            }
            Hash(i) {
              let l = [];
              for (let b = 0; b < i.pairs.length; b++) {
                let P = i.pairs[b];
                l.push(e.default.pair({ key: P.key, value: this.acceptNode(P.value), loc: this.source.spanFor(P.loc) }));
              }
              return e.default.hash(l, this.source.spanFor(i.loc));
            }
            StringLiteral(i) {
              return e.default.literal({ type: "StringLiteral", value: i.value, loc: i.loc });
            }
            BooleanLiteral(i) {
              return e.default.literal({ type: "BooleanLiteral", value: i.value, loc: i.loc });
            }
            NumberLiteral(i) {
              return e.default.literal({ type: "NumberLiteral", value: i.value, loc: i.loc });
            }
            UndefinedLiteral(i) {
              return e.default.literal({ type: "UndefinedLiteral", value: void 0, loc: i.loc });
            }
            NullLiteral(i) {
              return e.default.literal({ type: "NullLiteral", value: null, loc: i.loc });
            }
          };
          t3.HandlebarsNodeVisitors = a;
          function p(i, l) {
            if (l === "")
              return { lines: i.split(`
`).length - 1, columns: 0 };
            let P = i.split(l)[0].split(/\n/), E = P.length - 1;
            return { lines: E, columns: P[E].length };
          }
          function n(i, l) {
            let b = l.loc.start.line, P = l.loc.start.column, E = p(l.original, l.value);
            b = b + E.lines, E.lines ? P = E.columns : P = P + E.columns, i.line = b, i.column = P;
          }
          function s(i, l) {
            if (l.path.type.endsWith("Literal")) {
              let _ = l.path, y = "";
              throw _.type === "BooleanLiteral" ? y = _.original.toString() : _.type === "StringLiteral" ? y = `"${_.original}"` : _.type === "NullLiteral" ? y = "null" : _.type === "NumberLiteral" ? y = _.value.toString() : y = "undefined", (0, d.generateSyntaxError)(`${_.type} "${_.type === "StringLiteral" ? _.original : y}" cannot be called as a sub-expression, replace (${y}) with ${y}`, i.source.spanFor(_.loc));
            }
            let b = l.path.type === "PathExpression" ? i.PathExpression(l.path) : i.SubExpression(l.path), P = l.params ? l.params.map((_) => i.acceptNode(_)) : [], E = P.length > 0 ? P[P.length - 1].loc : b.loc, v = l.hash ? i.Hash(l.hash) : { type: "Hash", pairs: [], loc: i.source.spanFor(E).collapse("end") };
            return { path: b, params: P, hash: v };
          }
          function u(i, l) {
            let { path: b, params: P, hash: E, loc: v } = l;
            if ((0, c.isHBSLiteral)(b)) {
              let y = `{{${(0, c.printLiteral)(b)}}}`, g = `<${i.name} ... ${y} ...`;
              throw (0, d.generateSyntaxError)(`In ${g}, ${y} is not a valid modifier`, l.loc);
            }
            let _ = e.default.elementModifier({ path: b, params: P, hash: E, loc: v });
            i.modifiers.push(_);
          }
        } }), Fe = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/parser/tokenizer-event-handlers.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.preprocess = _, t3.TokenizerEventHandlers = void 0;
          var f = X(), h = It(), d = Ke(), c = b(We()), o = Te(), e = De(), r = ue(), a = he(), p = b(Ne()), n = b(Je()), s = ye(), u = b(Le()), i = b(ke()), l = xt();
          function b(y) {
            return y && y.__esModule ? y : { default: y };
          }
          var P = class extends l.HandlebarsNodeVisitors {
            constructor() {
              super(...arguments), this.tagOpenLine = 0, this.tagOpenColumn = 0;
            }
            reset() {
              this.currentNode = null;
            }
            beginComment() {
              this.currentNode = u.default.comment("", this.source.offsetFor(this.tagOpenLine, this.tagOpenColumn));
            }
            appendToCommentData(y) {
              this.currentComment.value += y;
            }
            finishComment() {
              (0, s.appendChild)(this.currentElement(), this.finish(this.currentComment));
            }
            beginData() {
              this.currentNode = u.default.text({ chars: "", loc: this.offset().collapsed() });
            }
            appendToData(y) {
              this.currentData.chars += y;
            }
            finishData() {
              this.currentData.loc = this.currentData.loc.withEnd(this.offset()), (0, s.appendChild)(this.currentElement(), this.currentData);
            }
            tagOpen() {
              this.tagOpenLine = this.tokenizer.line, this.tagOpenColumn = this.tokenizer.column;
            }
            beginStartTag() {
              this.currentNode = { type: "StartTag", name: "", attributes: [], modifiers: [], comments: [], selfClosing: false, loc: this.source.offsetFor(this.tagOpenLine, this.tagOpenColumn) };
            }
            beginEndTag() {
              this.currentNode = { type: "EndTag", name: "", attributes: [], modifiers: [], comments: [], selfClosing: false, loc: this.source.offsetFor(this.tagOpenLine, this.tagOpenColumn) };
            }
            finishTag() {
              let y = this.finish(this.currentTag);
              if (y.type === "StartTag") {
                if (this.finishStartTag(), y.name === ":")
                  throw (0, a.generateSyntaxError)("Invalid named block named detected, you may have created a named block without a name, or you may have began your name with a number. Named blocks must have names that are at least one character long, and begin with a lower case letter", this.source.spanFor({ start: this.currentTag.loc.toJSON(), end: this.offset().toJSON() }));
                (o.voidMap[y.name] || y.selfClosing) && this.finishEndTag(true);
              } else
                y.type === "EndTag" && this.finishEndTag(false);
            }
            finishStartTag() {
              let { name: y, attributes: g, modifiers: L, comments: j, selfClosing: x, loc: w } = this.finish(this.currentStartTag), H = u.default.element({ tag: y, selfClosing: x, attrs: g, modifiers: L, comments: j, children: [], blockParams: [], loc: w });
              this.elementStack.push(H);
            }
            finishEndTag(y) {
              let g = this.finish(this.currentTag), L = this.elementStack.pop(), j = this.currentElement();
              this.validateEndTag(g, L, y), L.loc = L.loc.withEnd(this.offset()), (0, s.parseElementBlockParams)(L), (0, s.appendChild)(j, L);
            }
            markTagAsSelfClosing() {
              this.currentTag.selfClosing = true;
            }
            appendToTagName(y) {
              this.currentTag.name += y;
            }
            beginAttribute() {
              let y = this.offset();
              this.currentAttribute = { name: "", parts: [], currentPart: null, isQuoted: false, isDynamic: false, start: y, valueSpan: y.collapsed() };
            }
            appendToAttributeName(y) {
              this.currentAttr.name += y;
            }
            beginAttributeValue(y) {
              this.currentAttr.isQuoted = y, this.startTextPart(), this.currentAttr.valueSpan = this.offset().collapsed();
            }
            appendToAttributeValue(y) {
              let g = this.currentAttr.parts, L = g[g.length - 1], j = this.currentAttr.currentPart;
              if (j)
                j.chars += y, j.loc = j.loc.withEnd(this.offset());
              else {
                let x = this.offset();
                y === `
` ? x = L ? L.loc.getEnd() : this.currentAttr.valueSpan.getStart() : x = x.move(-1), this.currentAttr.currentPart = u.default.text({ chars: y, loc: x.collapsed() });
              }
            }
            finishAttributeValue() {
              this.finalizeTextPart();
              let y = this.currentTag, g = this.offset();
              if (y.type === "EndTag")
                throw (0, a.generateSyntaxError)("Invalid end tag: closing tag must not have attributes", this.source.spanFor({ start: y.loc.toJSON(), end: g.toJSON() }));
              let { name: L, parts: j, start: x, isQuoted: w, isDynamic: H, valueSpan: m } = this.currentAttr, C = this.assembleAttributeValue(j, w, H, x.until(g));
              C.loc = m.withEnd(g);
              let S = u.default.attr({ name: L, value: C, loc: x.until(g) });
              this.currentStartTag.attributes.push(S);
            }
            reportSyntaxError(y) {
              throw (0, a.generateSyntaxError)(y, this.offset().collapsed());
            }
            assembleConcatenatedValue(y) {
              for (let j = 0; j < y.length; j++) {
                let x = y[j];
                if (x.type !== "MustacheStatement" && x.type !== "TextNode")
                  throw (0, a.generateSyntaxError)("Unsupported node in quoted attribute value: " + x.type, x.loc);
              }
              (0, f.assertPresent)(y, "the concatenation parts of an element should not be empty");
              let g = y[0], L = y[y.length - 1];
              return u.default.concat(y, this.source.spanFor(g.loc).extend(this.source.spanFor(L.loc)));
            }
            validateEndTag(y, g, L) {
              let j;
              if (o.voidMap[y.name] && !L ? j = `<${y.name}> elements do not need end tags. You should remove it` : g.tag === void 0 ? j = `Closing tag </${y.name}> without an open tag` : g.tag !== y.name && (j = `Closing tag </${y.name}> did not match last open tag <${g.tag}> (on line ${g.loc.startPosition.line})`), j)
                throw (0, a.generateSyntaxError)(j, y.loc);
            }
            assembleAttributeValue(y, g, L, j) {
              if (L) {
                if (g)
                  return this.assembleConcatenatedValue(y);
                if (y.length === 1 || y.length === 2 && y[1].type === "TextNode" && y[1].chars === "/")
                  return y[0];
                throw (0, a.generateSyntaxError)("An unquoted attribute value must be a string or a mustache, preceded by whitespace or a '=' character, and followed by whitespace, a '>' character, or '/>'", j);
              } else
                return y.length > 0 ? y[0] : u.default.text({ chars: "", loc: j });
            }
          };
          t3.TokenizerEventHandlers = P;
          var E = { parse: _, builders: i.default, print: c.default, traverse: p.default, Walker: n.default }, v = class extends d.EntityParser {
            constructor() {
              super({});
            }
            parse() {
            }
          };
          function _(y) {
            let g = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            var L, j, x;
            let w = g.mode || "precompile", H, m;
            typeof y == "string" ? (H = new e.Source(y, (L = g.meta) === null || L === void 0 ? void 0 : L.moduleName), w === "codemod" ? m = (0, h.parseWithoutProcessing)(y, g.parseOptions) : m = (0, h.parse)(y, g.parseOptions)) : y instanceof e.Source ? (H = y, w === "codemod" ? m = (0, h.parseWithoutProcessing)(y.source, g.parseOptions) : m = (0, h.parse)(y.source, g.parseOptions)) : (H = new e.Source("", (j = g.meta) === null || j === void 0 ? void 0 : j.moduleName), m = y);
            let C;
            w === "codemod" && (C = new v());
            let S = r.SourceSpan.forCharPositions(H, 0, H.source.length);
            m.loc = { source: "(program)", start: S.startPosition, end: S.endPosition };
            let R = new P(H, C, w).acceptTemplate(m);
            if (g.strictMode && (R.blockParams = (x = g.locals) !== null && x !== void 0 ? x : []), g && g.plugins && g.plugins.ast)
              for (let M = 0, V = g.plugins.ast.length; M < V; M++) {
                let G = g.plugins.ast[M], K = (0, f.assign)({}, g, { syntax: E }, { plugins: void 0 }), U = G(K);
                (0, p.default)(R, U.visitor);
              }
            return R;
          }
        } }), Xe = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/symbol-table.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.BlockSymbolTable = t3.ProgramSymbolTable = t3.SymbolTable = void 0;
          var f = X(), h = ye(), d = class {
            static top(e, r) {
              return new c(e, r);
            }
            child(e) {
              let r = e.map((a) => this.allocate(a));
              return new o(this, e, r);
            }
          };
          t3.SymbolTable = d;
          var c = class extends d {
            constructor(e, r) {
              super(), this.templateLocals = e, this.customizeComponentName = r, this.symbols = [], this.upvars = [], this.size = 1, this.named = (0, f.dict)(), this.blocks = (0, f.dict)(), this.usedTemplateLocals = [], this._hasEval = false;
            }
            getUsedTemplateLocals() {
              return this.usedTemplateLocals;
            }
            setHasEval() {
              this._hasEval = true;
            }
            get hasEval() {
              return this._hasEval;
            }
            has(e) {
              return this.templateLocals.indexOf(e) !== -1;
            }
            get(e) {
              let r = this.usedTemplateLocals.indexOf(e);
              return r !== -1 ? [r, true] : (r = this.usedTemplateLocals.length, this.usedTemplateLocals.push(e), [r, true]);
            }
            getLocalsMap() {
              return (0, f.dict)();
            }
            getEvalInfo() {
              let e = this.getLocalsMap();
              return Object.keys(e).map((r) => e[r]);
            }
            allocateFree(e, r) {
              r.resolution() === 39 && r.isAngleBracket && (0, h.isUpperCase)(e) && (e = this.customizeComponentName(e));
              let a = this.upvars.indexOf(e);
              return a !== -1 || (a = this.upvars.length, this.upvars.push(e)), a;
            }
            allocateNamed(e) {
              let r = this.named[e];
              return r || (r = this.named[e] = this.allocate(e)), r;
            }
            allocateBlock(e) {
              e === "inverse" && (e = "else");
              let r = this.blocks[e];
              return r || (r = this.blocks[e] = this.allocate(`&${e}`)), r;
            }
            allocate(e) {
              return this.symbols.push(e), this.size++;
            }
          };
          t3.ProgramSymbolTable = c;
          var o = class extends d {
            constructor(e, r, a) {
              super(), this.parent = e, this.symbols = r, this.slots = a;
            }
            get locals() {
              return this.symbols;
            }
            has(e) {
              return this.symbols.indexOf(e) !== -1 || this.parent.has(e);
            }
            get(e) {
              let r = this.symbols.indexOf(e);
              return r === -1 ? this.parent.get(e) : [this.slots[r], false];
            }
            getLocalsMap() {
              let e = this.parent.getLocalsMap();
              return this.symbols.forEach((r) => e[r] = this.get(r)[0]), e;
            }
            getEvalInfo() {
              let e = this.getLocalsMap();
              return Object.keys(e).map((r) => e[r]);
            }
            setHasEval() {
              this.parent.setHasEval();
            }
            allocateFree(e, r) {
              return this.parent.allocateFree(e, r);
            }
            allocateNamed(e) {
              return this.parent.allocateNamed(e);
            }
            allocateBlock(e) {
              return this.parent.allocateBlock(e);
            }
            allocate(e) {
              return this.parent.allocate(e);
            }
          };
          t3.BlockSymbolTable = o;
        } }), jt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/builders.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.BuildElement = t3.Builder = void 0;
          var f = X(), h = le(), d = ce(), c = e(ve());
          function o() {
            if (typeof WeakMap != "function")
              return null;
            var n = /* @__PURE__ */ new WeakMap();
            return o = function() {
              return n;
            }, n;
          }
          function e(n) {
            if (n && n.__esModule)
              return n;
            if (n === null || typeof n != "object" && typeof n != "function")
              return { default: n };
            var s = o();
            if (s && s.has(n))
              return s.get(n);
            var u = {}, i = Object.defineProperty && Object.getOwnPropertyDescriptor;
            for (var l in n)
              if (Object.prototype.hasOwnProperty.call(n, l)) {
                var b = i ? Object.getOwnPropertyDescriptor(n, l) : null;
                b && (b.get || b.set) ? Object.defineProperty(u, l, b) : u[l] = n[l];
              }
            return u.default = n, s && s.set(n, u), u;
          }
          var r = function(n, s) {
            var u = {};
            for (var i in n)
              Object.prototype.hasOwnProperty.call(n, i) && s.indexOf(i) < 0 && (u[i] = n[i]);
            if (n != null && typeof Object.getOwnPropertySymbols == "function")
              for (var l = 0, i = Object.getOwnPropertySymbols(n); l < i.length; l++)
                s.indexOf(i[l]) < 0 && Object.prototype.propertyIsEnumerable.call(n, i[l]) && (u[i[l]] = n[i[l]]);
            return u;
          }, a = class {
            template(n, s, u) {
              return new c.Template({ table: n, body: s, loc: u });
            }
            block(n, s, u) {
              return new c.Block({ scope: n, body: s, loc: u });
            }
            namedBlock(n, s, u) {
              return new c.NamedBlock({ name: n, block: s, attrs: [], componentArgs: [], modifiers: [], loc: u });
            }
            simpleNamedBlock(n, s, u) {
              return new p({ selfClosing: false, attrs: [], componentArgs: [], modifiers: [], comments: [] }).named(n, s, u);
            }
            slice(n, s) {
              return new h.SourceSlice({ loc: s, chars: n });
            }
            args(n, s, u) {
              return new c.Args({ loc: u, positional: n, named: s });
            }
            positional(n, s) {
              return new c.PositionalArguments({ loc: s, exprs: n });
            }
            namedArgument(n, s) {
              return new c.NamedArgument({ name: n, value: s });
            }
            named(n, s) {
              return new c.NamedArguments({ loc: s, entries: n });
            }
            attr(n, s) {
              let { name: u, value: i, trusting: l } = n;
              return new c.HtmlAttr({ loc: s, name: u, value: i, trusting: l });
            }
            splatAttr(n, s) {
              return new c.SplatAttr({ symbol: n, loc: s });
            }
            arg(n, s) {
              let { name: u, value: i, trusting: l } = n;
              return new c.ComponentArg({ name: u, value: i, trusting: l, loc: s });
            }
            path(n, s, u) {
              return new c.PathExpression({ loc: u, ref: n, tail: s });
            }
            self(n) {
              return new c.ThisReference({ loc: n });
            }
            at(n, s, u) {
              return new c.ArgReference({ loc: u, name: new h.SourceSlice({ loc: u, chars: n }), symbol: s });
            }
            freeVar(n) {
              let { name: s, context: u, symbol: i, loc: l } = n;
              return new c.FreeVarReference({ name: s, resolution: u, symbol: i, loc: l });
            }
            localVar(n, s, u, i) {
              return new c.LocalVarReference({ loc: i, name: n, isTemplateLocal: u, symbol: s });
            }
            sexp(n, s) {
              return new c.CallExpression({ loc: s, callee: n.callee, args: n.args });
            }
            deprecatedCall(n, s, u) {
              return new c.DeprecatedCallExpression({ loc: u, arg: n, callee: s });
            }
            interpolate(n, s) {
              return (0, f.assertPresent)(n), new c.InterpolateExpression({ loc: s, parts: n });
            }
            literal(n, s) {
              return new c.LiteralExpression({ loc: s, value: n });
            }
            append(n, s) {
              let { table: u, trusting: i, value: l } = n;
              return new c.AppendContent({ table: u, trusting: i, value: l, loc: s });
            }
            modifier(n, s) {
              let { callee: u, args: i } = n;
              return new c.ElementModifier({ loc: s, callee: u, args: i });
            }
            namedBlocks(n, s) {
              return new c.NamedBlocks({ loc: s, blocks: n });
            }
            blockStatement(n, s) {
              var { symbols: u, program: i, inverse: l = null } = n, b = r(n, ["symbols", "program", "inverse"]);
              let P = i.loc, E = [this.namedBlock(h.SourceSlice.synthetic("default"), i, i.loc)];
              return l && (P = P.extend(l.loc), E.push(this.namedBlock(h.SourceSlice.synthetic("else"), l, l.loc))), new c.InvokeBlock({ loc: s, blocks: this.namedBlocks(E, P), callee: b.callee, args: b.args });
            }
            element(n) {
              return new p(n);
            }
          };
          t3.Builder = a;
          var p = class {
            constructor(n) {
              this.base = n, this.builder = new a();
            }
            simple(n, s, u) {
              return new c.SimpleElement((0, f.assign)({ tag: n, body: s, componentArgs: [], loc: u }, this.base));
            }
            named(n, s, u) {
              return new c.NamedBlock((0, f.assign)({ name: n, block: s, componentArgs: [], loc: u }, this.base));
            }
            selfClosingComponent(n, s) {
              return new c.InvokeComponent((0, f.assign)({ loc: s, callee: n, blocks: new c.NamedBlocks({ blocks: [], loc: s.sliceEndChars({ skipEnd: 1, chars: 1 }) }) }, this.base));
            }
            componentWithDefaultBlock(n, s, u, i) {
              let l = this.builder.block(u, s, i), b = this.builder.namedBlock(h.SourceSlice.synthetic("default"), l, i);
              return new c.InvokeComponent((0, f.assign)({ loc: i, callee: n, blocks: this.builder.namedBlocks([b], b.loc) }, this.base));
            }
            componentWithNamedBlocks(n, s, u) {
              return new c.InvokeComponent((0, f.assign)({ loc: u, callee: n, blocks: this.builder.namedBlocks(s, d.SpanList.range(s)) }, this.base));
            }
          };
          t3.BuildElement = p;
        } }), Mt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/loose-resolution.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.SexpSyntaxContext = c, t3.ModifierSyntaxContext = o, t3.BlockSyntaxContext = e, t3.ComponentSyntaxContext = r, t3.AttrValueSyntaxContext = a, t3.AppendSyntaxContext = p;
          var f = d(ve());
          function h() {
            if (typeof WeakMap != "function")
              return null;
            var i = /* @__PURE__ */ new WeakMap();
            return h = function() {
              return i;
            }, i;
          }
          function d(i) {
            if (i && i.__esModule)
              return i;
            if (i === null || typeof i != "object" && typeof i != "function")
              return { default: i };
            var l = h();
            if (l && l.has(i))
              return l.get(i);
            var b = {}, P = Object.defineProperty && Object.getOwnPropertyDescriptor;
            for (var E in i)
              if (Object.prototype.hasOwnProperty.call(i, E)) {
                var v = P ? Object.getOwnPropertyDescriptor(i, E) : null;
                v && (v.get || v.set) ? Object.defineProperty(b, E, v) : b[E] = i[E];
              }
            return b.default = i, l && l.set(i, b), b;
          }
          function c(i) {
            return n(i) ? f.LooseModeResolution.namespaced("Helper") : null;
          }
          function o(i) {
            return n(i) ? f.LooseModeResolution.namespaced("Modifier") : null;
          }
          function e(i) {
            return n(i) ? f.LooseModeResolution.namespaced("Component") : f.LooseModeResolution.fallback();
          }
          function r(i) {
            return s(i) ? f.LooseModeResolution.namespaced("Component", true) : null;
          }
          function a(i) {
            let l = n(i), b = u(i);
            return l ? b ? f.LooseModeResolution.namespaced("Helper") : f.LooseModeResolution.attr() : b ? f.STRICT_RESOLUTION : f.LooseModeResolution.fallback();
          }
          function p(i) {
            let l = n(i), b = u(i), P = i.trusting;
            return l ? P ? f.LooseModeResolution.trustingAppend({ invoke: b }) : f.LooseModeResolution.append({ invoke: b }) : f.LooseModeResolution.fallback();
          }
          function n(i) {
            let l = i.path;
            return s(l);
          }
          function s(i) {
            return i.type === "PathExpression" && i.head.type === "VarHead" ? i.tail.length === 0 : false;
          }
          function u(i) {
            return i.params.length > 0 || i.hash.pairs.length > 0;
          }
        } }), Ht = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/v2-a/normalize.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.normalize = P, t3.BlockContext = void 0;
          var f = X(), h = b(Te()), d = Fe(), c = le(), o = ce(), e = Xe(), r = he(), a = ye(), p = b(Le()), n = l(ve()), s = jt(), u = Mt();
          function i() {
            if (typeof WeakMap != "function")
              return null;
            var m = /* @__PURE__ */ new WeakMap();
            return i = function() {
              return m;
            }, m;
          }
          function l(m) {
            if (m && m.__esModule)
              return m;
            if (m === null || typeof m != "object" && typeof m != "function")
              return { default: m };
            var C = i();
            if (C && C.has(m))
              return C.get(m);
            var S = {}, R = Object.defineProperty && Object.getOwnPropertyDescriptor;
            for (var M in m)
              if (Object.prototype.hasOwnProperty.call(m, M)) {
                var V = R ? Object.getOwnPropertyDescriptor(m, M) : null;
                V && (V.get || V.set) ? Object.defineProperty(S, M, V) : S[M] = m[M];
              }
            return S.default = m, C && C.set(m, S), S;
          }
          function b(m) {
            return m && m.__esModule ? m : { default: m };
          }
          function P(m) {
            let C = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
            var S;
            let R = (0, d.preprocess)(m, C), M = (0, f.assign)({ strictMode: false, locals: [] }, C), V = e.SymbolTable.top(M.locals, (S = C.customizeComponentName) !== null && S !== void 0 ? S : (W) => W), G = new E(m, M, V), K = new _(G), U = new L(G.loc(R.loc), R.body.map((W) => K.normalize(W)), G).assertTemplate(V), Z = V.getUsedTemplateLocals();
            return [U, Z];
          }
          var E = class {
            constructor(m, C, S) {
              this.source = m, this.options = C, this.table = S, this.builder = new s.Builder();
            }
            get strict() {
              return this.options.strictMode || false;
            }
            loc(m) {
              return this.source.spanFor(m);
            }
            resolutionFor(m, C) {
              if (this.strict)
                return { resolution: n.STRICT_RESOLUTION };
              if (this.isFreeVar(m)) {
                let S = C(m);
                return S === null ? { resolution: "error", path: w(m), head: H(m) } : { resolution: S };
              } else
                return { resolution: n.STRICT_RESOLUTION };
            }
            isFreeVar(m) {
              return m.type === "PathExpression" ? m.head.type !== "VarHead" ? false : !this.table.has(m.head.name) : m.path.type === "PathExpression" ? this.isFreeVar(m.path) : false;
            }
            hasBinding(m) {
              return this.table.has(m);
            }
            child(m) {
              return new E(this.source, this.options, this.table.child(m));
            }
            customizeComponentName(m) {
              return this.options.customizeComponentName ? this.options.customizeComponentName(m) : m;
            }
          };
          t3.BlockContext = E;
          var v = class {
            constructor(m) {
              this.block = m;
            }
            normalize(m, C) {
              switch (m.type) {
                case "NullLiteral":
                case "BooleanLiteral":
                case "NumberLiteral":
                case "StringLiteral":
                case "UndefinedLiteral":
                  return this.block.builder.literal(m.value, this.block.loc(m.loc));
                case "PathExpression":
                  return this.path(m, C);
                case "SubExpression": {
                  let S = this.block.resolutionFor(m, u.SexpSyntaxContext);
                  if (S.resolution === "error")
                    throw (0, r.generateSyntaxError)(`You attempted to invoke a path (\`${S.path}\`) but ${S.head} was not in scope`, m.loc);
                  return this.block.builder.sexp(this.callParts(m, S.resolution), this.block.loc(m.loc));
                }
              }
            }
            path(m, C) {
              let S = this.block.loc(m.head.loc), R = [], M = S;
              for (let V of m.tail)
                M = M.sliceStartChars({ chars: V.length, skipStart: 1 }), R.push(new c.SourceSlice({ loc: M, chars: V }));
              return this.block.builder.path(this.ref(m.head, C), R, this.block.loc(m.loc));
            }
            callParts(m, C) {
              let { path: S, params: R, hash: M } = m, V = this.normalize(S, C), G = R.map((N) => this.normalize(N, n.ARGUMENT_RESOLUTION)), K = o.SpanList.range(G, V.loc.collapse("end")), U = this.block.loc(M.loc), Z = o.SpanList.range([K, U]), W = this.block.builder.positional(R.map((N) => this.normalize(N, n.ARGUMENT_RESOLUTION)), K), T = this.block.builder.named(M.pairs.map((N) => this.namedArgument(N)), this.block.loc(M.loc));
              return { callee: V, args: this.block.builder.args(W, T, Z) };
            }
            namedArgument(m) {
              let S = this.block.loc(m.loc).sliceStartChars({ chars: m.key.length });
              return this.block.builder.namedArgument(new c.SourceSlice({ chars: m.key, loc: S }), this.normalize(m.value, n.ARGUMENT_RESOLUTION));
            }
            ref(m, C) {
              let { block: S } = this, { builder: R, table: M } = S, V = S.loc(m.loc);
              switch (m.type) {
                case "ThisHead":
                  return R.self(V);
                case "AtHead": {
                  let G = M.allocateNamed(m.name);
                  return R.at(m.name, G, V);
                }
                case "VarHead":
                  if (S.hasBinding(m.name)) {
                    let [G, K] = M.get(m.name);
                    return S.builder.localVar(m.name, G, K, V);
                  } else {
                    let G = S.strict ? n.STRICT_RESOLUTION : C, K = S.table.allocateFree(m.name, G);
                    return S.builder.freeVar({ name: m.name, context: G, symbol: K, loc: V });
                  }
              }
            }
          }, _ = class {
            constructor(m) {
              this.block = m;
            }
            normalize(m) {
              switch (m.type) {
                case "PartialStatement":
                  throw new Error("Handlebars partial syntax ({{> ...}}) is not allowed in Glimmer");
                case "BlockStatement":
                  return this.BlockStatement(m);
                case "ElementNode":
                  return new y(this.block).ElementNode(m);
                case "MustacheStatement":
                  return this.MustacheStatement(m);
                case "MustacheCommentStatement":
                  return this.MustacheCommentStatement(m);
                case "CommentStatement": {
                  let C = this.block.loc(m.loc);
                  return new n.HtmlComment({ loc: C, text: C.slice({ skipStart: 4, skipEnd: 3 }).toSlice(m.value) });
                }
                case "TextNode":
                  return new n.HtmlText({ loc: this.block.loc(m.loc), chars: m.chars });
              }
            }
            MustacheCommentStatement(m) {
              let C = this.block.loc(m.loc), S;
              return C.asString().slice(0, 5) === "{{!--" ? S = C.slice({ skipStart: 5, skipEnd: 4 }) : S = C.slice({ skipStart: 3, skipEnd: 2 }), new n.GlimmerComment({ loc: C, text: S.toSlice(m.value) });
            }
            MustacheStatement(m) {
              let { escaped: C } = m, S = this.block.loc(m.loc), R = this.expr.callParts({ path: m.path, params: m.params, hash: m.hash }, (0, u.AppendSyntaxContext)(m)), M = R.args.isEmpty() ? R.callee : this.block.builder.sexp(R, S);
              return this.block.builder.append({ table: this.block.table, trusting: !C, value: M }, S);
            }
            BlockStatement(m) {
              let { program: C, inverse: S } = m, R = this.block.loc(m.loc), M = this.block.resolutionFor(m, u.BlockSyntaxContext);
              if (M.resolution === "error")
                throw (0, r.generateSyntaxError)(`You attempted to invoke a path (\`{{#${M.path}}}\`) but ${M.head} was not in scope`, R);
              let V = this.expr.callParts(m, M.resolution);
              return this.block.builder.blockStatement((0, f.assign)({ symbols: this.block.table, program: this.Block(C), inverse: S ? this.Block(S) : null }, V), R);
            }
            Block(m) {
              let { body: C, loc: S, blockParams: R } = m, M = this.block.child(R), V = new _(M);
              return new j(this.block.loc(S), C.map((G) => V.normalize(G)), this.block).assertBlock(M.table);
            }
            get expr() {
              return new v(this.block);
            }
          }, y = class {
            constructor(m) {
              this.ctx = m;
            }
            ElementNode(m) {
              let { tag: C, selfClosing: S, comments: R } = m, M = this.ctx.loc(m.loc), [V, ...G] = C.split("."), K = this.classifyTag(V, G, m.loc), U = m.attributes.filter((A) => A.name[0] !== "@").map((A) => this.attr(A)), Z = m.attributes.filter((A) => A.name[0] === "@").map((A) => this.arg(A)), W = m.modifiers.map((A) => this.modifier(A)), T = this.ctx.child(m.blockParams), N = new _(T), k = m.children.map((A) => N.normalize(A)), B = this.ctx.builder.element({ selfClosing: S, attrs: U, componentArgs: Z, modifiers: W, comments: R.map((A) => new _(this.ctx).MustacheCommentStatement(A)) }), O = new x(B, M, k, this.ctx), z = this.ctx.loc(m.loc).sliceStartChars({ chars: C.length, skipStart: 1 });
              if (K === "ElementHead")
                return C[0] === ":" ? O.assertNamedBlock(z.slice({ skipStart: 1 }).toSlice(C.slice(1)), T.table) : O.assertElement(z.toSlice(C), m.blockParams.length > 0);
              if (m.selfClosing)
                return B.selfClosingComponent(K, M);
              {
                let A = O.assertComponent(C, T.table, m.blockParams.length > 0);
                return B.componentWithNamedBlocks(K, A, M);
              }
            }
            modifier(m) {
              let C = this.ctx.resolutionFor(m, u.ModifierSyntaxContext);
              if (C.resolution === "error")
                throw (0, r.generateSyntaxError)(`You attempted to invoke a path (\`{{#${C.path}}}\`) as a modifier, but ${C.head} was not in scope. Try adding \`this\` to the beginning of the path`, m.loc);
              let S = this.expr.callParts(m, C.resolution);
              return this.ctx.builder.modifier(S, this.ctx.loc(m.loc));
            }
            mustacheAttr(m) {
              let C = this.ctx.builder.sexp(this.expr.callParts(m, (0, u.AttrValueSyntaxContext)(m)), this.ctx.loc(m.loc));
              return C.args.isEmpty() ? C.callee : C;
            }
            attrPart(m) {
              switch (m.type) {
                case "MustacheStatement":
                  return { expr: this.mustacheAttr(m), trusting: !m.escaped };
                case "TextNode":
                  return { expr: this.ctx.builder.literal(m.chars, this.ctx.loc(m.loc)), trusting: true };
              }
            }
            attrValue(m) {
              switch (m.type) {
                case "ConcatStatement": {
                  let C = m.parts.map((S) => this.attrPart(S).expr);
                  return { expr: this.ctx.builder.interpolate(C, this.ctx.loc(m.loc)), trusting: false };
                }
                default:
                  return this.attrPart(m);
              }
            }
            attr(m) {
              if (m.name === "...attributes")
                return this.ctx.builder.splatAttr(this.ctx.table.allocateBlock("attrs"), this.ctx.loc(m.loc));
              let C = this.ctx.loc(m.loc), S = C.sliceStartChars({ chars: m.name.length }).toSlice(m.name), R = this.attrValue(m.value);
              return this.ctx.builder.attr({ name: S, value: R.expr, trusting: R.trusting }, C);
            }
            maybeDeprecatedCall(m, C) {
              if (this.ctx.strict || C.type !== "MustacheStatement")
                return null;
              let { path: S } = C;
              if (S.type !== "PathExpression" || S.head.type !== "VarHead")
                return null;
              let { name: R } = S.head;
              if (R === "has-block" || R === "has-block-params" || this.ctx.hasBinding(R) || S.tail.length !== 0 || C.params.length !== 0 || C.hash.pairs.length !== 0)
                return null;
              let M = n.LooseModeResolution.attr(), V = this.ctx.builder.freeVar({ name: R, context: M, symbol: this.ctx.table.allocateFree(R, M), loc: S.loc });
              return { expr: this.ctx.builder.deprecatedCall(m, V, C.loc), trusting: false };
            }
            arg(m) {
              let C = this.ctx.loc(m.loc), S = C.sliceStartChars({ chars: m.name.length }).toSlice(m.name), R = this.maybeDeprecatedCall(S, m.value) || this.attrValue(m.value);
              return this.ctx.builder.arg({ name: S, value: R.expr, trusting: R.trusting }, C);
            }
            classifyTag(m, C, S) {
              let R = (0, a.isUpperCase)(m), M = m[0] === "@" || m === "this" || this.ctx.hasBinding(m);
              if (this.ctx.strict && !M) {
                if (R)
                  throw (0, r.generateSyntaxError)(`Attempted to invoke a component that was not in scope in a strict mode template, \`<${m}>\`. If you wanted to create an element with that name, convert it to lowercase - \`<${m.toLowerCase()}>\``, S);
                return "ElementHead";
              }
              let V = M || R, G = S.sliceStartChars({ skipStart: 1, chars: m.length }), K = C.reduce((W, T) => W + 1 + T.length, 0), U = G.getEnd().move(K), Z = G.withEnd(U);
              if (V) {
                let W = p.default.path({ head: p.default.head(m, G), tail: C, loc: Z }), T = this.ctx.resolutionFor(W, u.ComponentSyntaxContext);
                if (T.resolution === "error")
                  throw (0, r.generateSyntaxError)(`You attempted to invoke a path (\`<${T.path}>\`) but ${T.head} was not in scope`, S);
                return new v(this.ctx).normalize(W, T.resolution);
              }
              if (C.length > 0)
                throw (0, r.generateSyntaxError)(`You used ${m}.${C.join(".")} as a tag name, but ${m} is not in scope`, S);
              return "ElementHead";
            }
            get expr() {
              return new v(this.ctx);
            }
          }, g = class {
            constructor(m, C, S) {
              this.loc = m, this.children = C, this.block = S, this.namedBlocks = C.filter((R) => R instanceof n.NamedBlock), this.hasSemanticContent = Boolean(C.filter((R) => {
                if (R instanceof n.NamedBlock)
                  return false;
                switch (R.type) {
                  case "GlimmerComment":
                  case "HtmlComment":
                    return false;
                  case "HtmlText":
                    return !/^\s*$/.exec(R.chars);
                  default:
                    return true;
                }
              }).length), this.nonBlockChildren = C.filter((R) => !(R instanceof n.NamedBlock));
            }
          }, L = class extends g {
            assertTemplate(m) {
              if ((0, f.isPresent)(this.namedBlocks))
                throw (0, r.generateSyntaxError)("Unexpected named block at the top-level of a template", this.loc);
              return this.block.builder.template(m, this.nonBlockChildren, this.block.loc(this.loc));
            }
          }, j = class extends g {
            assertBlock(m) {
              if ((0, f.isPresent)(this.namedBlocks))
                throw (0, r.generateSyntaxError)("Unexpected named block nested in a normal block", this.loc);
              return this.block.builder.block(m, this.nonBlockChildren, this.loc);
            }
          }, x = class extends g {
            constructor(m, C, S, R) {
              super(C, S, R), this.el = m;
            }
            assertNamedBlock(m, C) {
              if (this.el.base.selfClosing)
                throw (0, r.generateSyntaxError)(`<:${m.chars}/> is not a valid named block: named blocks cannot be self-closing`, this.loc);
              if ((0, f.isPresent)(this.namedBlocks))
                throw (0, r.generateSyntaxError)(`Unexpected named block inside <:${m.chars}> named block: named blocks cannot contain nested named blocks`, this.loc);
              if (!(0, a.isLowerCase)(m.chars))
                throw (0, r.generateSyntaxError)(`<:${m.chars}> is not a valid named block, and named blocks must begin with a lowercase letter`, this.loc);
              if (this.el.base.attrs.length > 0 || this.el.base.componentArgs.length > 0 || this.el.base.modifiers.length > 0)
                throw (0, r.generateSyntaxError)(`named block <:${m.chars}> cannot have attributes, arguments, or modifiers`, this.loc);
              let S = o.SpanList.range(this.nonBlockChildren, this.loc);
              return this.block.builder.namedBlock(m, this.block.builder.block(C, this.nonBlockChildren, S), this.loc);
            }
            assertElement(m, C) {
              if (C)
                throw (0, r.generateSyntaxError)(`Unexpected block params in <${m}>: simple elements cannot have block params`, this.loc);
              if ((0, f.isPresent)(this.namedBlocks)) {
                let S = this.namedBlocks.map((R) => R.name);
                if (S.length === 1)
                  throw (0, r.generateSyntaxError)(`Unexpected named block <:foo> inside <${m.chars}> HTML element`, this.loc);
                {
                  let R = S.map((M) => `<:${M.chars}>`).join(", ");
                  throw (0, r.generateSyntaxError)(`Unexpected named blocks inside <${m.chars}> HTML element (${R})`, this.loc);
                }
              }
              return this.el.simple(m, this.nonBlockChildren, this.loc);
            }
            assertComponent(m, C, S) {
              if ((0, f.isPresent)(this.namedBlocks) && this.hasSemanticContent)
                throw (0, r.generateSyntaxError)(`Unexpected content inside <${m}> component invocation: when using named blocks, the tag cannot contain other content`, this.loc);
              if ((0, f.isPresent)(this.namedBlocks)) {
                if (S)
                  throw (0, r.generateSyntaxError)(`Unexpected block params list on <${m}> component invocation: when passing named blocks, the invocation tag cannot take block params`, this.loc);
                let R = /* @__PURE__ */ new Set();
                for (let M of this.namedBlocks) {
                  let V = M.name.chars;
                  if (R.has(V))
                    throw (0, r.generateSyntaxError)(`Component had two named blocks with the same name, \`<:${V}>\`. Only one block with a given name may be passed`, this.loc);
                  if (V === "inverse" && R.has("else") || V === "else" && R.has("inverse"))
                    throw (0, r.generateSyntaxError)("Component has both <:else> and <:inverse> block. <:inverse> is an alias for <:else>", this.loc);
                  R.add(V);
                }
                return this.namedBlocks;
              } else
                return [this.block.builder.namedBlock(c.SourceSlice.synthetic("default"), this.block.builder.block(C, this.nonBlockChildren, this.loc), this.loc)];
            }
          };
          function w(m) {
            return m.type !== "PathExpression" && m.path.type === "PathExpression" ? w(m.path) : new h.default({ entityEncoding: "raw" }).print(m);
          }
          function H(m) {
            if (m.type === "PathExpression")
              switch (m.head.type) {
                case "AtHead":
                case "VarHead":
                  return m.head.name;
                case "ThisHead":
                  return "this";
              }
            else
              return m.path.type === "PathExpression" ? H(m.path) : new h.default({ entityEncoding: "raw" }).print(m);
          }
        } }), Ze = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/keywords.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.isKeyword = f, t3.KEYWORDS_TYPES = void 0;
          function f(d) {
            return d in h;
          }
          var h = { component: ["Call", "Append", "Block"], debugger: ["Append"], "each-in": ["Block"], each: ["Block"], "has-block-params": ["Call", "Append"], "has-block": ["Call", "Append"], helper: ["Call", "Append"], if: ["Call", "Append", "Block"], "in-element": ["Block"], let: ["Block"], "link-to": ["Append", "Block"], log: ["Call", "Append"], modifier: ["Call"], mount: ["Append"], mut: ["Call", "Append"], outlet: ["Append"], "query-params": ["Call"], readonly: ["Call", "Append"], unbound: ["Call", "Append"], unless: ["Call", "Append", "Block"], with: ["Block"], yield: ["Append"] };
          t3.KEYWORDS_TYPES = h;
        } }), Vt = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/lib/get-template-locals.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), t3.getTemplateLocals = r;
          var f = Ze(), h = Fe(), d = c(Ne());
          function c(a) {
            return a && a.__esModule ? a : { default: a };
          }
          function o(a, p, n) {
            if (a.type === "PathExpression") {
              if (a.head.type === "AtHead" || a.head.type === "ThisHead")
                return;
              let s = a.head.name;
              if (p.indexOf(s) === -1)
                return s;
            } else if (a.type === "ElementNode") {
              let { tag: s } = a, u = s.charAt(0);
              return u === ":" || u === "@" || !n.includeHtmlElements && s.indexOf(".") === -1 && s.toLowerCase() === s || s.substr(0, 5) === "this." || p.indexOf(s) !== -1 ? void 0 : s;
            }
          }
          function e(a, p, n, s) {
            let u = o(p, n, s);
            (Array.isArray(u) ? u : [u]).forEach((i) => {
              i !== void 0 && i[0] !== "@" && a.add(i.split(".")[0]);
            });
          }
          function r(a) {
            let p = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : { includeHtmlElements: false, includeKeywords: false }, n = (0, h.preprocess)(a), s = /* @__PURE__ */ new Set(), u = [];
            (0, d.default)(n, { Block: { enter(l) {
              let { blockParams: b } = l;
              b.forEach((P) => {
                u.push(P);
              });
            }, exit(l) {
              let { blockParams: b } = l;
              b.forEach(() => {
                u.pop();
              });
            } }, ElementNode: { enter(l) {
              l.blockParams.forEach((b) => {
                u.push(b);
              }), e(s, l, u, p);
            }, exit(l) {
              let { blockParams: b } = l;
              b.forEach(() => {
                u.pop();
              });
            } }, PathExpression(l) {
              e(s, l, u, p);
            } });
            let i = [];
            return s.forEach((l) => i.push(l)), p != null && p.includeKeywords || (i = i.filter((l) => !(0, f.isKeyword)(l))), i;
          }
        } }), Ut = I({ "node_modules/@glimmer/syntax/dist/commonjs/es2017/index.js"(t3) {
          "use strict";
          F(), Object.defineProperty(t3, "__esModule", { value: true }), Object.defineProperty(t3, "Source", { enumerable: true, get: function() {
            return f.Source;
          } }), Object.defineProperty(t3, "builders", { enumerable: true, get: function() {
            return h.default;
          } }), Object.defineProperty(t3, "normalize", { enumerable: true, get: function() {
            return o.normalize;
          } }), Object.defineProperty(t3, "SymbolTable", { enumerable: true, get: function() {
            return e.SymbolTable;
          } }), Object.defineProperty(t3, "BlockSymbolTable", { enumerable: true, get: function() {
            return e.BlockSymbolTable;
          } }), Object.defineProperty(t3, "ProgramSymbolTable", { enumerable: true, get: function() {
            return e.ProgramSymbolTable;
          } }), Object.defineProperty(t3, "generateSyntaxError", { enumerable: true, get: function() {
            return r.generateSyntaxError;
          } }), Object.defineProperty(t3, "preprocess", { enumerable: true, get: function() {
            return a.preprocess;
          } }), Object.defineProperty(t3, "print", { enumerable: true, get: function() {
            return p.default;
          } }), Object.defineProperty(t3, "sortByLoc", { enumerable: true, get: function() {
            return n.sortByLoc;
          } }), Object.defineProperty(t3, "Walker", { enumerable: true, get: function() {
            return s.default;
          } }), Object.defineProperty(t3, "Path", { enumerable: true, get: function() {
            return s.default;
          } }), Object.defineProperty(t3, "traverse", { enumerable: true, get: function() {
            return u.default;
          } }), Object.defineProperty(t3, "cannotRemoveNode", { enumerable: true, get: function() {
            return i.cannotRemoveNode;
          } }), Object.defineProperty(t3, "cannotReplaceNode", { enumerable: true, get: function() {
            return i.cannotReplaceNode;
          } }), Object.defineProperty(t3, "WalkerPath", { enumerable: true, get: function() {
            return l.default;
          } }), Object.defineProperty(t3, "isKeyword", { enumerable: true, get: function() {
            return b.isKeyword;
          } }), Object.defineProperty(t3, "KEYWORDS_TYPES", { enumerable: true, get: function() {
            return b.KEYWORDS_TYPES;
          } }), Object.defineProperty(t3, "getTemplateLocals", { enumerable: true, get: function() {
            return P.getTemplateLocals;
          } }), Object.defineProperty(t3, "SourceSlice", { enumerable: true, get: function() {
            return E.SourceSlice;
          } }), Object.defineProperty(t3, "SourceSpan", { enumerable: true, get: function() {
            return v.SourceSpan;
          } }), Object.defineProperty(t3, "SpanList", { enumerable: true, get: function() {
            return _.SpanList;
          } }), Object.defineProperty(t3, "maybeLoc", { enumerable: true, get: function() {
            return _.maybeLoc;
          } }), Object.defineProperty(t3, "loc", { enumerable: true, get: function() {
            return _.loc;
          } }), Object.defineProperty(t3, "hasSpan", { enumerable: true, get: function() {
            return _.hasSpan;
          } }), Object.defineProperty(t3, "node", { enumerable: true, get: function() {
            return y.node;
          } }), t3.ASTv2 = t3.AST = t3.ASTv1 = void 0;
          var f = De(), h = j(ke()), d = L(Ct());
          t3.ASTv1 = d, t3.AST = d;
          var c = L(ve());
          t3.ASTv2 = c;
          var o = Ht(), e = Xe(), r = he(), a = Fe(), p = j(We()), n = Ue(), s = j(Je()), u = j(Ne()), i = Ye(), l = j(Qe()), b = Ze(), P = Vt(), E = le(), v = ue(), _ = ce(), y = ne();
          function g() {
            if (typeof WeakMap != "function")
              return null;
            var x = /* @__PURE__ */ new WeakMap();
            return g = function() {
              return x;
            }, x;
          }
          function L(x) {
            if (x && x.__esModule)
              return x;
            if (x === null || typeof x != "object" && typeof x != "function")
              return { default: x };
            var w = g();
            if (w && w.has(x))
              return w.get(x);
            var H = {}, m = Object.defineProperty && Object.getOwnPropertyDescriptor;
            for (var C in x)
              if (Object.prototype.hasOwnProperty.call(x, C)) {
                var S = m ? Object.getOwnPropertyDescriptor(x, C) : null;
                S && (S.get || S.set) ? Object.defineProperty(H, C, S) : H[C] = x[C];
              }
            return H.default = x, w && w.set(x, H), H;
          }
          function j(x) {
            return x && x.__esModule ? x : { default: x };
          }
        } });
        F();
        var { LinesAndColumns: zt } = at(), Gt = ut(), { locStart: Kt, locEnd: Wt } = ot();
        function Yt() {
          return { name: "addBackslash", visitor: { All(t3) {
            var f;
            let h = (f = t3.children) !== null && f !== void 0 ? f : t3.body;
            if (h)
              for (let d = 0; d < h.length - 1; d++)
                h[d].type === "TextNode" && h[d + 1].type === "MustacheStatement" && (h[d].chars = h[d].chars.replace(/\\$/, "\\\\"));
          } } };
        }
        function Qt(t3) {
          let f = new zt(t3), h = (d) => {
            let { line: c, column: o } = d;
            return f.indexForLocation({ line: c - 1, column: o });
          };
          return () => ({ name: "addOffset", visitor: { All(d) {
            let { start: c, end: o } = d.loc;
            c.offset = h(c), o.offset = h(o);
          } } });
        }
        function Jt(t3) {
          let { preprocess: f } = Ut(), h;
          try {
            h = f(t3, { mode: "codemod", plugins: { ast: [Yt, Qt(t3)] } });
          } catch (d) {
            let c = Xt(d);
            throw c ? Gt(d.message, c) : d;
          }
          return h;
        }
        function Xt(t3) {
          let { location: f, hash: h } = t3;
          if (f) {
            let { start: d, end: c } = f;
            return typeof c.line != "number" ? { start: d } : f;
          }
          if (h) {
            let { loc: { last_line: d, last_column: c } } = h;
            return { start: { line: d, column: c + 1 } };
          }
        }
        $e.exports = { parsers: { glimmer: { parse: Jt, astFormat: "glimmer", locStart: Kt, locEnd: Wt } } };
      });
      return Zt();
    });
  }
});

// node_modules/prettier/parser-graphql.js
var require_parser_graphql = __commonJS({
  "node_modules/prettier/parser-graphql.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.graphql = e();
      }
    })(function() {
      "use strict";
      var oe = (a, d) => () => (d || a((d = { exports: {} }).exports, d), d.exports);
      var be = oe((Ce, ae) => {
        var H = Object.getOwnPropertyNames, se = (a, d) => function() {
          return a && (d = (0, a[H(a)[0]])(a = 0)), d;
        }, L = (a, d) => function() {
          return d || (0, a[H(a)[0]])((d = { exports: {} }).exports, d), d.exports;
        }, K = se({ "<define:process>"() {
        } }), ce = L({ "src/common/parser-create-error.js"(a, d) {
          "use strict";
          K();
          function i(c, r) {
            let _ = new SyntaxError(c + " (" + r.start.line + ":" + r.start.column + ")");
            return _.loc = r, _;
          }
          d.exports = i;
        } }), ue = L({ "src/utils/try-combinations.js"(a, d) {
          "use strict";
          K();
          function i() {
            let c;
            for (var r = arguments.length, _ = new Array(r), E = 0; E < r; E++)
              _[E] = arguments[E];
            for (let [k, O] of _.entries())
              try {
                return { result: O() };
              } catch (A) {
                k === 0 && (c = A);
              }
            return { error: c };
          }
          d.exports = i;
        } }), le = L({ "src/language-graphql/pragma.js"(a, d) {
          "use strict";
          K();
          function i(r) {
            return /^\s*#[^\S\n]*@(?:format|prettier)\s*(?:\n|$)/.test(r);
          }
          function c(r) {
            return `# @format

` + r;
          }
          d.exports = { hasPragma: i, insertPragma: c };
        } }), pe = L({ "src/language-graphql/loc.js"(a, d) {
          "use strict";
          K();
          function i(r) {
            return typeof r.start == "number" ? r.start : r.loc && r.loc.start;
          }
          function c(r) {
            return typeof r.end == "number" ? r.end : r.loc && r.loc.end;
          }
          d.exports = { locStart: i, locEnd: c };
        } }), fe = L({ "node_modules/graphql/jsutils/isObjectLike.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = i;
          function d(c) {
            return typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? d = function(_) {
              return typeof _;
            } : d = function(_) {
              return _ && typeof Symbol == "function" && _.constructor === Symbol && _ !== Symbol.prototype ? "symbol" : typeof _;
            }, d(c);
          }
          function i(c) {
            return d(c) == "object" && c !== null;
          }
        } }), z = L({ "node_modules/graphql/polyfills/symbols.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.SYMBOL_TO_STRING_TAG = a.SYMBOL_ASYNC_ITERATOR = a.SYMBOL_ITERATOR = void 0;
          var d = typeof Symbol == "function" && Symbol.iterator != null ? Symbol.iterator : "@@iterator";
          a.SYMBOL_ITERATOR = d;
          var i = typeof Symbol == "function" && Symbol.asyncIterator != null ? Symbol.asyncIterator : "@@asyncIterator";
          a.SYMBOL_ASYNC_ITERATOR = i;
          var c = typeof Symbol == "function" && Symbol.toStringTag != null ? Symbol.toStringTag : "@@toStringTag";
          a.SYMBOL_TO_STRING_TAG = c;
        } }), $2 = L({ "node_modules/graphql/language/location.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.getLocation = d;
          function d(i, c) {
            for (var r = /\r\n|[\n\r]/g, _ = 1, E = c + 1, k; (k = r.exec(i.body)) && k.index < c; )
              _ += 1, E = c + 1 - (k.index + k[0].length);
            return { line: _, column: E };
          }
        } }), de = L({ "node_modules/graphql/language/printLocation.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.printLocation = i, a.printSourceLocation = c;
          var d = $2();
          function i(k) {
            return c(k.source, (0, d.getLocation)(k.source, k.start));
          }
          function c(k, O) {
            var A = k.locationOffset.column - 1, N = _(A) + k.body, g = O.line - 1, D = k.locationOffset.line - 1, v = O.line + D, I = O.line === 1 ? A : 0, s = O.column + I, p = "".concat(k.name, ":").concat(v, ":").concat(s, `
`), e = N.split(/\r\n|[\n\r]/g), n = e[g];
            if (n.length > 120) {
              for (var t3 = Math.floor(s / 80), u = s % 80, y = [], f = 0; f < n.length; f += 80)
                y.push(n.slice(f, f + 80));
              return p + r([["".concat(v), y[0]]].concat(y.slice(1, t3 + 1).map(function(m) {
                return ["", m];
              }), [[" ", _(u - 1) + "^"], ["", y[t3 + 1]]]));
            }
            return p + r([["".concat(v - 1), e[g - 1]], ["".concat(v), n], ["", _(s - 1) + "^"], ["".concat(v + 1), e[g + 1]]]);
          }
          function r(k) {
            var O = k.filter(function(N) {
              var g = N[0], D = N[1];
              return D !== void 0;
            }), A = Math.max.apply(Math, O.map(function(N) {
              var g = N[0];
              return g.length;
            }));
            return O.map(function(N) {
              var g = N[0], D = N[1];
              return E(A, g) + (D ? " | " + D : " |");
            }).join(`
`);
          }
          function _(k) {
            return Array(k + 1).join(" ");
          }
          function E(k, O) {
            return _(k - O.length) + O;
          }
        } }), W = L({ "node_modules/graphql/error/GraphQLError.js"(a) {
          "use strict";
          K();
          function d(f) {
            return typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? d = function(o) {
              return typeof o;
            } : d = function(o) {
              return o && typeof Symbol == "function" && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o;
            }, d(f);
          }
          Object.defineProperty(a, "__esModule", { value: true }), a.printError = y, a.GraphQLError = void 0;
          var i = E(fe()), c = z(), r = $2(), _ = de();
          function E(f) {
            return f && f.__esModule ? f : { default: f };
          }
          function k(f, m) {
            if (!(f instanceof m))
              throw new TypeError("Cannot call a class as a function");
          }
          function O(f, m) {
            for (var o = 0; o < m.length; o++) {
              var h = m[o];
              h.enumerable = h.enumerable || false, h.configurable = true, "value" in h && (h.writable = true), Object.defineProperty(f, h.key, h);
            }
          }
          function A(f, m, o) {
            return m && O(f.prototype, m), o && O(f, o), f;
          }
          function N(f, m) {
            if (typeof m != "function" && m !== null)
              throw new TypeError("Super expression must either be null or a function");
            f.prototype = Object.create(m && m.prototype, { constructor: { value: f, writable: true, configurable: true } }), m && n(f, m);
          }
          function g(f) {
            var m = p();
            return function() {
              var h = t3(f), l;
              if (m) {
                var T = t3(this).constructor;
                l = Reflect.construct(h, arguments, T);
              } else
                l = h.apply(this, arguments);
              return D(this, l);
            };
          }
          function D(f, m) {
            return m && (d(m) === "object" || typeof m == "function") ? m : v(f);
          }
          function v(f) {
            if (f === void 0)
              throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
            return f;
          }
          function I(f) {
            var m = typeof Map == "function" ? /* @__PURE__ */ new Map() : void 0;
            return I = function(h) {
              if (h === null || !e(h))
                return h;
              if (typeof h != "function")
                throw new TypeError("Super expression must either be null or a function");
              if (typeof m < "u") {
                if (m.has(h))
                  return m.get(h);
                m.set(h, l);
              }
              function l() {
                return s(h, arguments, t3(this).constructor);
              }
              return l.prototype = Object.create(h.prototype, { constructor: { value: l, enumerable: false, writable: true, configurable: true } }), n(l, h);
            }, I(f);
          }
          function s(f, m, o) {
            return p() ? s = Reflect.construct : s = function(l, T, S) {
              var x = [null];
              x.push.apply(x, T);
              var b = Function.bind.apply(l, x), M = new b();
              return S && n(M, S.prototype), M;
            }, s.apply(null, arguments);
          }
          function p() {
            if (typeof Reflect > "u" || !Reflect.construct || Reflect.construct.sham)
              return false;
            if (typeof Proxy == "function")
              return true;
            try {
              return Date.prototype.toString.call(Reflect.construct(Date, [], function() {
              })), true;
            } catch {
              return false;
            }
          }
          function e(f) {
            return Function.toString.call(f).indexOf("[native code]") !== -1;
          }
          function n(f, m) {
            return n = Object.setPrototypeOf || function(h, l) {
              return h.__proto__ = l, h;
            }, n(f, m);
          }
          function t3(f) {
            return t3 = Object.setPrototypeOf ? Object.getPrototypeOf : function(o) {
              return o.__proto__ || Object.getPrototypeOf(o);
            }, t3(f);
          }
          var u = function(f) {
            N(o, f);
            var m = g(o);
            function o(h, l, T, S, x, b, M) {
              var U, V, q, G, C;
              k(this, o), C = m.call(this, h);
              var R = Array.isArray(l) ? l.length !== 0 ? l : void 0 : l ? [l] : void 0, Y = T;
              if (!Y && R) {
                var J;
                Y = (J = R[0].loc) === null || J === void 0 ? void 0 : J.source;
              }
              var F = S;
              !F && R && (F = R.reduce(function(w, P) {
                return P.loc && w.push(P.loc.start), w;
              }, [])), F && F.length === 0 && (F = void 0);
              var B;
              S && T ? B = S.map(function(w) {
                return (0, r.getLocation)(T, w);
              }) : R && (B = R.reduce(function(w, P) {
                return P.loc && w.push((0, r.getLocation)(P.loc.source, P.loc.start)), w;
              }, []));
              var j = M;
              if (j == null && b != null) {
                var Q = b.extensions;
                (0, i.default)(Q) && (j = Q);
              }
              return Object.defineProperties(v(C), { name: { value: "GraphQLError" }, message: { value: h, enumerable: true, writable: true }, locations: { value: (U = B) !== null && U !== void 0 ? U : void 0, enumerable: B != null }, path: { value: x != null ? x : void 0, enumerable: x != null }, nodes: { value: R != null ? R : void 0 }, source: { value: (V = Y) !== null && V !== void 0 ? V : void 0 }, positions: { value: (q = F) !== null && q !== void 0 ? q : void 0 }, originalError: { value: b }, extensions: { value: (G = j) !== null && G !== void 0 ? G : void 0, enumerable: j != null } }), b != null && b.stack ? (Object.defineProperty(v(C), "stack", { value: b.stack, writable: true, configurable: true }), D(C)) : (Error.captureStackTrace ? Error.captureStackTrace(v(C), o) : Object.defineProperty(v(C), "stack", { value: Error().stack, writable: true, configurable: true }), C);
            }
            return A(o, [{ key: "toString", value: function() {
              return y(this);
            } }, { key: c.SYMBOL_TO_STRING_TAG, get: function() {
              return "Object";
            } }]), o;
          }(I(Error));
          a.GraphQLError = u;
          function y(f) {
            var m = f.message;
            if (f.nodes)
              for (var o = 0, h = f.nodes; o < h.length; o++) {
                var l = h[o];
                l.loc && (m += `

` + (0, _.printLocation)(l.loc));
              }
            else if (f.source && f.locations)
              for (var T = 0, S = f.locations; T < S.length; T++) {
                var x = S[T];
                m += `

` + (0, _.printSourceLocation)(f.source, x);
              }
            return m;
          }
        } }), Z = L({ "node_modules/graphql/error/syntaxError.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.syntaxError = i;
          var d = W();
          function i(c, r, _) {
            return new d.GraphQLError("Syntax Error: ".concat(_), void 0, c, [r]);
          }
        } }), he = L({ "node_modules/graphql/language/kinds.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.Kind = void 0;
          var d = Object.freeze({ NAME: "Name", DOCUMENT: "Document", OPERATION_DEFINITION: "OperationDefinition", VARIABLE_DEFINITION: "VariableDefinition", SELECTION_SET: "SelectionSet", FIELD: "Field", ARGUMENT: "Argument", FRAGMENT_SPREAD: "FragmentSpread", INLINE_FRAGMENT: "InlineFragment", FRAGMENT_DEFINITION: "FragmentDefinition", VARIABLE: "Variable", INT: "IntValue", FLOAT: "FloatValue", STRING: "StringValue", BOOLEAN: "BooleanValue", NULL: "NullValue", ENUM: "EnumValue", LIST: "ListValue", OBJECT: "ObjectValue", OBJECT_FIELD: "ObjectField", DIRECTIVE: "Directive", NAMED_TYPE: "NamedType", LIST_TYPE: "ListType", NON_NULL_TYPE: "NonNullType", SCHEMA_DEFINITION: "SchemaDefinition", OPERATION_TYPE_DEFINITION: "OperationTypeDefinition", SCALAR_TYPE_DEFINITION: "ScalarTypeDefinition", OBJECT_TYPE_DEFINITION: "ObjectTypeDefinition", FIELD_DEFINITION: "FieldDefinition", INPUT_VALUE_DEFINITION: "InputValueDefinition", INTERFACE_TYPE_DEFINITION: "InterfaceTypeDefinition", UNION_TYPE_DEFINITION: "UnionTypeDefinition", ENUM_TYPE_DEFINITION: "EnumTypeDefinition", ENUM_VALUE_DEFINITION: "EnumValueDefinition", INPUT_OBJECT_TYPE_DEFINITION: "InputObjectTypeDefinition", DIRECTIVE_DEFINITION: "DirectiveDefinition", SCHEMA_EXTENSION: "SchemaExtension", SCALAR_TYPE_EXTENSION: "ScalarTypeExtension", OBJECT_TYPE_EXTENSION: "ObjectTypeExtension", INTERFACE_TYPE_EXTENSION: "InterfaceTypeExtension", UNION_TYPE_EXTENSION: "UnionTypeExtension", ENUM_TYPE_EXTENSION: "EnumTypeExtension", INPUT_OBJECT_TYPE_EXTENSION: "InputObjectTypeExtension" });
          a.Kind = d;
        } }), ve = L({ "node_modules/graphql/jsutils/invariant.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = d;
          function d(i, c) {
            var r = Boolean(i);
            if (!r)
              throw new Error(c != null ? c : "Unexpected invariant triggered.");
          }
        } }), ee = L({ "node_modules/graphql/jsutils/nodejsCustomInspectSymbol.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = void 0;
          var d = typeof Symbol == "function" && typeof Symbol.for == "function" ? Symbol.for("nodejs.util.inspect.custom") : void 0, i = d;
          a.default = i;
        } }), Te = L({ "node_modules/graphql/jsutils/defineInspect.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = r;
          var d = c(ve()), i = c(ee());
          function c(_) {
            return _ && _.__esModule ? _ : { default: _ };
          }
          function r(_) {
            var E = _.prototype.toJSON;
            typeof E == "function" || (0, d.default)(0), _.prototype.inspect = E, i.default && (_.prototype[i.default] = E);
          }
        } }), te = L({ "node_modules/graphql/language/ast.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.isNode = _, a.Token = a.Location = void 0;
          var d = i(Te());
          function i(E) {
            return E && E.__esModule ? E : { default: E };
          }
          var c = function() {
            function E(O, A, N) {
              this.start = O.start, this.end = A.end, this.startToken = O, this.endToken = A, this.source = N;
            }
            var k = E.prototype;
            return k.toJSON = function() {
              return { start: this.start, end: this.end };
            }, E;
          }();
          a.Location = c, (0, d.default)(c);
          var r = function() {
            function E(O, A, N, g, D, v, I) {
              this.kind = O, this.start = A, this.end = N, this.line = g, this.column = D, this.value = I, this.prev = v, this.next = null;
            }
            var k = E.prototype;
            return k.toJSON = function() {
              return { kind: this.kind, value: this.value, line: this.line, column: this.column };
            }, E;
          }();
          a.Token = r, (0, d.default)(r);
          function _(E) {
            return E != null && typeof E.kind == "string";
          }
        } }), ne = L({ "node_modules/graphql/language/tokenKind.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.TokenKind = void 0;
          var d = Object.freeze({ SOF: "<SOF>", EOF: "<EOF>", BANG: "!", DOLLAR: "$", AMP: "&", PAREN_L: "(", PAREN_R: ")", SPREAD: "...", COLON: ":", EQUALS: "=", AT: "@", BRACKET_L: "[", BRACKET_R: "]", BRACE_L: "{", PIPE: "|", BRACE_R: "}", NAME: "Name", INT: "Int", FLOAT: "Float", STRING: "String", BLOCK_STRING: "BlockString", COMMENT: "Comment" });
          a.TokenKind = d;
        } }), re = L({ "node_modules/graphql/jsutils/inspect.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = E;
          var d = i(ee());
          function i(v) {
            return v && v.__esModule ? v : { default: v };
          }
          function c(v) {
            return typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? c = function(s) {
              return typeof s;
            } : c = function(s) {
              return s && typeof Symbol == "function" && s.constructor === Symbol && s !== Symbol.prototype ? "symbol" : typeof s;
            }, c(v);
          }
          var r = 10, _ = 2;
          function E(v) {
            return k(v, []);
          }
          function k(v, I) {
            switch (c(v)) {
              case "string":
                return JSON.stringify(v);
              case "function":
                return v.name ? "[function ".concat(v.name, "]") : "[function]";
              case "object":
                return v === null ? "null" : O(v, I);
              default:
                return String(v);
            }
          }
          function O(v, I) {
            if (I.indexOf(v) !== -1)
              return "[Circular]";
            var s = [].concat(I, [v]), p = g(v);
            if (p !== void 0) {
              var e = p.call(v);
              if (e !== v)
                return typeof e == "string" ? e : k(e, s);
            } else if (Array.isArray(v))
              return N(v, s);
            return A(v, s);
          }
          function A(v, I) {
            var s = Object.keys(v);
            if (s.length === 0)
              return "{}";
            if (I.length > _)
              return "[" + D(v) + "]";
            var p = s.map(function(e) {
              var n = k(v[e], I);
              return e + ": " + n;
            });
            return "{ " + p.join(", ") + " }";
          }
          function N(v, I) {
            if (v.length === 0)
              return "[]";
            if (I.length > _)
              return "[Array]";
            for (var s = Math.min(r, v.length), p = v.length - s, e = [], n = 0; n < s; ++n)
              e.push(k(v[n], I));
            return p === 1 ? e.push("... 1 more item") : p > 1 && e.push("... ".concat(p, " more items")), "[" + e.join(", ") + "]";
          }
          function g(v) {
            var I = v[String(d.default)];
            if (typeof I == "function")
              return I;
            if (typeof v.inspect == "function")
              return v.inspect;
          }
          function D(v) {
            var I = Object.prototype.toString.call(v).replace(/^\[object /, "").replace(/]$/, "");
            if (I === "Object" && typeof v.constructor == "function") {
              var s = v.constructor.name;
              if (typeof s == "string" && s !== "")
                return s;
            }
            return I;
          }
        } }), _e = L({ "node_modules/graphql/jsutils/devAssert.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = d;
          function d(i, c) {
            var r = Boolean(i);
            if (!r)
              throw new Error(c);
          }
        } }), Ee = L({ "node_modules/graphql/jsutils/instanceOf.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.default = void 0;
          var d = i(re());
          function i(r) {
            return r && r.__esModule ? r : { default: r };
          }
          var c = function(_, E) {
            return _ instanceof E;
          };
          a.default = c;
        } }), me = L({ "node_modules/graphql/language/source.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.isSource = A, a.Source = void 0;
          var d = z(), i = _(re()), c = _(_e()), r = _(Ee());
          function _(N) {
            return N && N.__esModule ? N : { default: N };
          }
          function E(N, g) {
            for (var D = 0; D < g.length; D++) {
              var v = g[D];
              v.enumerable = v.enumerable || false, v.configurable = true, "value" in v && (v.writable = true), Object.defineProperty(N, v.key, v);
            }
          }
          function k(N, g, D) {
            return g && E(N.prototype, g), D && E(N, D), N;
          }
          var O = function() {
            function N(g) {
              var D = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "GraphQL request", v = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : { line: 1, column: 1 };
              typeof g == "string" || (0, c.default)(0, "Body must be a string. Received: ".concat((0, i.default)(g), ".")), this.body = g, this.name = D, this.locationOffset = v, this.locationOffset.line > 0 || (0, c.default)(0, "line in locationOffset is 1-indexed and must be positive."), this.locationOffset.column > 0 || (0, c.default)(0, "column in locationOffset is 1-indexed and must be positive.");
            }
            return k(N, [{ key: d.SYMBOL_TO_STRING_TAG, get: function() {
              return "Source";
            } }]), N;
          }();
          a.Source = O;
          function A(N) {
            return (0, r.default)(N, O);
          }
        } }), ye = L({ "node_modules/graphql/language/directiveLocation.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.DirectiveLocation = void 0;
          var d = Object.freeze({ QUERY: "QUERY", MUTATION: "MUTATION", SUBSCRIPTION: "SUBSCRIPTION", FIELD: "FIELD", FRAGMENT_DEFINITION: "FRAGMENT_DEFINITION", FRAGMENT_SPREAD: "FRAGMENT_SPREAD", INLINE_FRAGMENT: "INLINE_FRAGMENT", VARIABLE_DEFINITION: "VARIABLE_DEFINITION", SCHEMA: "SCHEMA", SCALAR: "SCALAR", OBJECT: "OBJECT", FIELD_DEFINITION: "FIELD_DEFINITION", ARGUMENT_DEFINITION: "ARGUMENT_DEFINITION", INTERFACE: "INTERFACE", UNION: "UNION", ENUM: "ENUM", ENUM_VALUE: "ENUM_VALUE", INPUT_OBJECT: "INPUT_OBJECT", INPUT_FIELD_DEFINITION: "INPUT_FIELD_DEFINITION" });
          a.DirectiveLocation = d;
        } }), ke = L({ "node_modules/graphql/language/blockString.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.dedentBlockStringValue = d, a.getBlockStringIndentation = c, a.printBlockString = r;
          function d(_) {
            var E = _.split(/\r\n|[\n\r]/g), k = c(_);
            if (k !== 0)
              for (var O = 1; O < E.length; O++)
                E[O] = E[O].slice(k);
            for (var A = 0; A < E.length && i(E[A]); )
              ++A;
            for (var N = E.length; N > A && i(E[N - 1]); )
              --N;
            return E.slice(A, N).join(`
`);
          }
          function i(_) {
            for (var E = 0; E < _.length; ++E)
              if (_[E] !== " " && _[E] !== "	")
                return false;
            return true;
          }
          function c(_) {
            for (var E, k = true, O = true, A = 0, N = null, g = 0; g < _.length; ++g)
              switch (_.charCodeAt(g)) {
                case 13:
                  _.charCodeAt(g + 1) === 10 && ++g;
                case 10:
                  k = false, O = true, A = 0;
                  break;
                case 9:
                case 32:
                  ++A;
                  break;
                default:
                  O && !k && (N === null || A < N) && (N = A), O = false;
              }
            return (E = N) !== null && E !== void 0 ? E : 0;
          }
          function r(_) {
            var E = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", k = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false, O = _.indexOf(`
`) === -1, A = _[0] === " " || _[0] === "	", N = _[_.length - 1] === '"', g = _[_.length - 1] === "\\", D = !O || N || g || k, v = "";
            return D && !(O && A) && (v += `
` + E), v += E ? _.replace(/\n/g, `
` + E) : _, D && (v += `
`), '"""' + v.replace(/"""/g, '\\"""') + '"""';
          }
        } }), Ne = L({ "node_modules/graphql/language/lexer.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.isPunctuatorTokenKind = E, a.Lexer = void 0;
          var d = Z(), i = te(), c = ne(), r = ke(), _ = function() {
            function t3(y) {
              var f = new i.Token(c.TokenKind.SOF, 0, 0, 0, 0, null);
              this.source = y, this.lastToken = f, this.token = f, this.line = 1, this.lineStart = 0;
            }
            var u = t3.prototype;
            return u.advance = function() {
              this.lastToken = this.token;
              var f = this.token = this.lookahead();
              return f;
            }, u.lookahead = function() {
              var f = this.token;
              if (f.kind !== c.TokenKind.EOF)
                do {
                  var m;
                  f = (m = f.next) !== null && m !== void 0 ? m : f.next = O(this, f);
                } while (f.kind === c.TokenKind.COMMENT);
              return f;
            }, t3;
          }();
          a.Lexer = _;
          function E(t3) {
            return t3 === c.TokenKind.BANG || t3 === c.TokenKind.DOLLAR || t3 === c.TokenKind.AMP || t3 === c.TokenKind.PAREN_L || t3 === c.TokenKind.PAREN_R || t3 === c.TokenKind.SPREAD || t3 === c.TokenKind.COLON || t3 === c.TokenKind.EQUALS || t3 === c.TokenKind.AT || t3 === c.TokenKind.BRACKET_L || t3 === c.TokenKind.BRACKET_R || t3 === c.TokenKind.BRACE_L || t3 === c.TokenKind.PIPE || t3 === c.TokenKind.BRACE_R;
          }
          function k(t3) {
            return isNaN(t3) ? c.TokenKind.EOF : t3 < 127 ? JSON.stringify(String.fromCharCode(t3)) : '"\\u'.concat(("00" + t3.toString(16).toUpperCase()).slice(-4), '"');
          }
          function O(t3, u) {
            for (var y = t3.source, f = y.body, m = f.length, o = u.end; o < m; ) {
              var h = f.charCodeAt(o), l = t3.line, T = 1 + o - t3.lineStart;
              switch (h) {
                case 65279:
                case 9:
                case 32:
                case 44:
                  ++o;
                  continue;
                case 10:
                  ++o, ++t3.line, t3.lineStart = o;
                  continue;
                case 13:
                  f.charCodeAt(o + 1) === 10 ? o += 2 : ++o, ++t3.line, t3.lineStart = o;
                  continue;
                case 33:
                  return new i.Token(c.TokenKind.BANG, o, o + 1, l, T, u);
                case 35:
                  return N(y, o, l, T, u);
                case 36:
                  return new i.Token(c.TokenKind.DOLLAR, o, o + 1, l, T, u);
                case 38:
                  return new i.Token(c.TokenKind.AMP, o, o + 1, l, T, u);
                case 40:
                  return new i.Token(c.TokenKind.PAREN_L, o, o + 1, l, T, u);
                case 41:
                  return new i.Token(c.TokenKind.PAREN_R, o, o + 1, l, T, u);
                case 46:
                  if (f.charCodeAt(o + 1) === 46 && f.charCodeAt(o + 2) === 46)
                    return new i.Token(c.TokenKind.SPREAD, o, o + 3, l, T, u);
                  break;
                case 58:
                  return new i.Token(c.TokenKind.COLON, o, o + 1, l, T, u);
                case 61:
                  return new i.Token(c.TokenKind.EQUALS, o, o + 1, l, T, u);
                case 64:
                  return new i.Token(c.TokenKind.AT, o, o + 1, l, T, u);
                case 91:
                  return new i.Token(c.TokenKind.BRACKET_L, o, o + 1, l, T, u);
                case 93:
                  return new i.Token(c.TokenKind.BRACKET_R, o, o + 1, l, T, u);
                case 123:
                  return new i.Token(c.TokenKind.BRACE_L, o, o + 1, l, T, u);
                case 124:
                  return new i.Token(c.TokenKind.PIPE, o, o + 1, l, T, u);
                case 125:
                  return new i.Token(c.TokenKind.BRACE_R, o, o + 1, l, T, u);
                case 34:
                  return f.charCodeAt(o + 1) === 34 && f.charCodeAt(o + 2) === 34 ? I(y, o, l, T, u, t3) : v(y, o, l, T, u);
                case 45:
                case 48:
                case 49:
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 55:
                case 56:
                case 57:
                  return g(y, o, h, l, T, u);
                case 65:
                case 66:
                case 67:
                case 68:
                case 69:
                case 70:
                case 71:
                case 72:
                case 73:
                case 74:
                case 75:
                case 76:
                case 77:
                case 78:
                case 79:
                case 80:
                case 81:
                case 82:
                case 83:
                case 84:
                case 85:
                case 86:
                case 87:
                case 88:
                case 89:
                case 90:
                case 95:
                case 97:
                case 98:
                case 99:
                case 100:
                case 101:
                case 102:
                case 103:
                case 104:
                case 105:
                case 106:
                case 107:
                case 108:
                case 109:
                case 110:
                case 111:
                case 112:
                case 113:
                case 114:
                case 115:
                case 116:
                case 117:
                case 118:
                case 119:
                case 120:
                case 121:
                case 122:
                  return e(y, o, l, T, u);
              }
              throw (0, d.syntaxError)(y, o, A(h));
            }
            var S = t3.line, x = 1 + o - t3.lineStart;
            return new i.Token(c.TokenKind.EOF, m, m, S, x, u);
          }
          function A(t3) {
            return t3 < 32 && t3 !== 9 && t3 !== 10 && t3 !== 13 ? "Cannot contain the invalid character ".concat(k(t3), ".") : t3 === 39 ? `Unexpected single quote character ('), did you mean to use a double quote (")?` : "Cannot parse the unexpected character ".concat(k(t3), ".");
          }
          function N(t3, u, y, f, m) {
            var o = t3.body, h, l = u;
            do
              h = o.charCodeAt(++l);
            while (!isNaN(h) && (h > 31 || h === 9));
            return new i.Token(c.TokenKind.COMMENT, u, l, y, f, m, o.slice(u + 1, l));
          }
          function g(t3, u, y, f, m, o) {
            var h = t3.body, l = y, T = u, S = false;
            if (l === 45 && (l = h.charCodeAt(++T)), l === 48) {
              if (l = h.charCodeAt(++T), l >= 48 && l <= 57)
                throw (0, d.syntaxError)(t3, T, "Invalid number, unexpected digit after 0: ".concat(k(l), "."));
            } else
              T = D(t3, T, l), l = h.charCodeAt(T);
            if (l === 46 && (S = true, l = h.charCodeAt(++T), T = D(t3, T, l), l = h.charCodeAt(T)), (l === 69 || l === 101) && (S = true, l = h.charCodeAt(++T), (l === 43 || l === 45) && (l = h.charCodeAt(++T)), T = D(t3, T, l), l = h.charCodeAt(T)), l === 46 || n(l))
              throw (0, d.syntaxError)(t3, T, "Invalid number, expected digit but got: ".concat(k(l), "."));
            return new i.Token(S ? c.TokenKind.FLOAT : c.TokenKind.INT, u, T, f, m, o, h.slice(u, T));
          }
          function D(t3, u, y) {
            var f = t3.body, m = u, o = y;
            if (o >= 48 && o <= 57) {
              do
                o = f.charCodeAt(++m);
              while (o >= 48 && o <= 57);
              return m;
            }
            throw (0, d.syntaxError)(t3, m, "Invalid number, expected digit but got: ".concat(k(o), "."));
          }
          function v(t3, u, y, f, m) {
            for (var o = t3.body, h = u + 1, l = h, T = 0, S = ""; h < o.length && !isNaN(T = o.charCodeAt(h)) && T !== 10 && T !== 13; ) {
              if (T === 34)
                return S += o.slice(l, h), new i.Token(c.TokenKind.STRING, u, h + 1, y, f, m, S);
              if (T < 32 && T !== 9)
                throw (0, d.syntaxError)(t3, h, "Invalid character within String: ".concat(k(T), "."));
              if (++h, T === 92) {
                switch (S += o.slice(l, h - 1), T = o.charCodeAt(h), T) {
                  case 34:
                    S += '"';
                    break;
                  case 47:
                    S += "/";
                    break;
                  case 92:
                    S += "\\";
                    break;
                  case 98:
                    S += "\b";
                    break;
                  case 102:
                    S += "\f";
                    break;
                  case 110:
                    S += `
`;
                    break;
                  case 114:
                    S += "\r";
                    break;
                  case 116:
                    S += "	";
                    break;
                  case 117: {
                    var x = s(o.charCodeAt(h + 1), o.charCodeAt(h + 2), o.charCodeAt(h + 3), o.charCodeAt(h + 4));
                    if (x < 0) {
                      var b = o.slice(h + 1, h + 5);
                      throw (0, d.syntaxError)(t3, h, "Invalid character escape sequence: \\u".concat(b, "."));
                    }
                    S += String.fromCharCode(x), h += 4;
                    break;
                  }
                  default:
                    throw (0, d.syntaxError)(t3, h, "Invalid character escape sequence: \\".concat(String.fromCharCode(T), "."));
                }
                ++h, l = h;
              }
            }
            throw (0, d.syntaxError)(t3, h, "Unterminated string.");
          }
          function I(t3, u, y, f, m, o) {
            for (var h = t3.body, l = u + 3, T = l, S = 0, x = ""; l < h.length && !isNaN(S = h.charCodeAt(l)); ) {
              if (S === 34 && h.charCodeAt(l + 1) === 34 && h.charCodeAt(l + 2) === 34)
                return x += h.slice(T, l), new i.Token(c.TokenKind.BLOCK_STRING, u, l + 3, y, f, m, (0, r.dedentBlockStringValue)(x));
              if (S < 32 && S !== 9 && S !== 10 && S !== 13)
                throw (0, d.syntaxError)(t3, l, "Invalid character within String: ".concat(k(S), "."));
              S === 10 ? (++l, ++o.line, o.lineStart = l) : S === 13 ? (h.charCodeAt(l + 1) === 10 ? l += 2 : ++l, ++o.line, o.lineStart = l) : S === 92 && h.charCodeAt(l + 1) === 34 && h.charCodeAt(l + 2) === 34 && h.charCodeAt(l + 3) === 34 ? (x += h.slice(T, l) + '"""', l += 4, T = l) : ++l;
            }
            throw (0, d.syntaxError)(t3, l, "Unterminated string.");
          }
          function s(t3, u, y, f) {
            return p(t3) << 12 | p(u) << 8 | p(y) << 4 | p(f);
          }
          function p(t3) {
            return t3 >= 48 && t3 <= 57 ? t3 - 48 : t3 >= 65 && t3 <= 70 ? t3 - 55 : t3 >= 97 && t3 <= 102 ? t3 - 87 : -1;
          }
          function e(t3, u, y, f, m) {
            for (var o = t3.body, h = o.length, l = u + 1, T = 0; l !== h && !isNaN(T = o.charCodeAt(l)) && (T === 95 || T >= 48 && T <= 57 || T >= 65 && T <= 90 || T >= 97 && T <= 122); )
              ++l;
            return new i.Token(c.TokenKind.NAME, u, l, y, f, m, o.slice(u, l));
          }
          function n(t3) {
            return t3 === 95 || t3 >= 65 && t3 <= 90 || t3 >= 97 && t3 <= 122;
          }
        } }), Oe = L({ "node_modules/graphql/language/parser.js"(a) {
          "use strict";
          K(), Object.defineProperty(a, "__esModule", { value: true }), a.parse = O, a.parseValue = A, a.parseType = N, a.Parser = void 0;
          var d = Z(), i = he(), c = te(), r = ne(), _ = me(), E = ye(), k = Ne();
          function O(I, s) {
            var p = new g(I, s);
            return p.parseDocument();
          }
          function A(I, s) {
            var p = new g(I, s);
            p.expectToken(r.TokenKind.SOF);
            var e = p.parseValueLiteral(false);
            return p.expectToken(r.TokenKind.EOF), e;
          }
          function N(I, s) {
            var p = new g(I, s);
            p.expectToken(r.TokenKind.SOF);
            var e = p.parseTypeReference();
            return p.expectToken(r.TokenKind.EOF), e;
          }
          var g = function() {
            function I(p, e) {
              var n = (0, _.isSource)(p) ? p : new _.Source(p);
              this._lexer = new k.Lexer(n), this._options = e;
            }
            var s = I.prototype;
            return s.parseName = function() {
              var e = this.expectToken(r.TokenKind.NAME);
              return { kind: i.Kind.NAME, value: e.value, loc: this.loc(e) };
            }, s.parseDocument = function() {
              var e = this._lexer.token;
              return { kind: i.Kind.DOCUMENT, definitions: this.many(r.TokenKind.SOF, this.parseDefinition, r.TokenKind.EOF), loc: this.loc(e) };
            }, s.parseDefinition = function() {
              if (this.peek(r.TokenKind.NAME))
                switch (this._lexer.token.value) {
                  case "query":
                  case "mutation":
                  case "subscription":
                    return this.parseOperationDefinition();
                  case "fragment":
                    return this.parseFragmentDefinition();
                  case "schema":
                  case "scalar":
                  case "type":
                  case "interface":
                  case "union":
                  case "enum":
                  case "input":
                  case "directive":
                    return this.parseTypeSystemDefinition();
                  case "extend":
                    return this.parseTypeSystemExtension();
                }
              else {
                if (this.peek(r.TokenKind.BRACE_L))
                  return this.parseOperationDefinition();
                if (this.peekDescription())
                  return this.parseTypeSystemDefinition();
              }
              throw this.unexpected();
            }, s.parseOperationDefinition = function() {
              var e = this._lexer.token;
              if (this.peek(r.TokenKind.BRACE_L))
                return { kind: i.Kind.OPERATION_DEFINITION, operation: "query", name: void 0, variableDefinitions: [], directives: [], selectionSet: this.parseSelectionSet(), loc: this.loc(e) };
              var n = this.parseOperationType(), t3;
              return this.peek(r.TokenKind.NAME) && (t3 = this.parseName()), { kind: i.Kind.OPERATION_DEFINITION, operation: n, name: t3, variableDefinitions: this.parseVariableDefinitions(), directives: this.parseDirectives(false), selectionSet: this.parseSelectionSet(), loc: this.loc(e) };
            }, s.parseOperationType = function() {
              var e = this.expectToken(r.TokenKind.NAME);
              switch (e.value) {
                case "query":
                  return "query";
                case "mutation":
                  return "mutation";
                case "subscription":
                  return "subscription";
              }
              throw this.unexpected(e);
            }, s.parseVariableDefinitions = function() {
              return this.optionalMany(r.TokenKind.PAREN_L, this.parseVariableDefinition, r.TokenKind.PAREN_R);
            }, s.parseVariableDefinition = function() {
              var e = this._lexer.token;
              return { kind: i.Kind.VARIABLE_DEFINITION, variable: this.parseVariable(), type: (this.expectToken(r.TokenKind.COLON), this.parseTypeReference()), defaultValue: this.expectOptionalToken(r.TokenKind.EQUALS) ? this.parseValueLiteral(true) : void 0, directives: this.parseDirectives(true), loc: this.loc(e) };
            }, s.parseVariable = function() {
              var e = this._lexer.token;
              return this.expectToken(r.TokenKind.DOLLAR), { kind: i.Kind.VARIABLE, name: this.parseName(), loc: this.loc(e) };
            }, s.parseSelectionSet = function() {
              var e = this._lexer.token;
              return { kind: i.Kind.SELECTION_SET, selections: this.many(r.TokenKind.BRACE_L, this.parseSelection, r.TokenKind.BRACE_R), loc: this.loc(e) };
            }, s.parseSelection = function() {
              return this.peek(r.TokenKind.SPREAD) ? this.parseFragment() : this.parseField();
            }, s.parseField = function() {
              var e = this._lexer.token, n = this.parseName(), t3, u;
              return this.expectOptionalToken(r.TokenKind.COLON) ? (t3 = n, u = this.parseName()) : u = n, { kind: i.Kind.FIELD, alias: t3, name: u, arguments: this.parseArguments(false), directives: this.parseDirectives(false), selectionSet: this.peek(r.TokenKind.BRACE_L) ? this.parseSelectionSet() : void 0, loc: this.loc(e) };
            }, s.parseArguments = function(e) {
              var n = e ? this.parseConstArgument : this.parseArgument;
              return this.optionalMany(r.TokenKind.PAREN_L, n, r.TokenKind.PAREN_R);
            }, s.parseArgument = function() {
              var e = this._lexer.token, n = this.parseName();
              return this.expectToken(r.TokenKind.COLON), { kind: i.Kind.ARGUMENT, name: n, value: this.parseValueLiteral(false), loc: this.loc(e) };
            }, s.parseConstArgument = function() {
              var e = this._lexer.token;
              return { kind: i.Kind.ARGUMENT, name: this.parseName(), value: (this.expectToken(r.TokenKind.COLON), this.parseValueLiteral(true)), loc: this.loc(e) };
            }, s.parseFragment = function() {
              var e = this._lexer.token;
              this.expectToken(r.TokenKind.SPREAD);
              var n = this.expectOptionalKeyword("on");
              return !n && this.peek(r.TokenKind.NAME) ? { kind: i.Kind.FRAGMENT_SPREAD, name: this.parseFragmentName(), directives: this.parseDirectives(false), loc: this.loc(e) } : { kind: i.Kind.INLINE_FRAGMENT, typeCondition: n ? this.parseNamedType() : void 0, directives: this.parseDirectives(false), selectionSet: this.parseSelectionSet(), loc: this.loc(e) };
            }, s.parseFragmentDefinition = function() {
              var e, n = this._lexer.token;
              return this.expectKeyword("fragment"), ((e = this._options) === null || e === void 0 ? void 0 : e.experimentalFragmentVariables) === true ? { kind: i.Kind.FRAGMENT_DEFINITION, name: this.parseFragmentName(), variableDefinitions: this.parseVariableDefinitions(), typeCondition: (this.expectKeyword("on"), this.parseNamedType()), directives: this.parseDirectives(false), selectionSet: this.parseSelectionSet(), loc: this.loc(n) } : { kind: i.Kind.FRAGMENT_DEFINITION, name: this.parseFragmentName(), typeCondition: (this.expectKeyword("on"), this.parseNamedType()), directives: this.parseDirectives(false), selectionSet: this.parseSelectionSet(), loc: this.loc(n) };
            }, s.parseFragmentName = function() {
              if (this._lexer.token.value === "on")
                throw this.unexpected();
              return this.parseName();
            }, s.parseValueLiteral = function(e) {
              var n = this._lexer.token;
              switch (n.kind) {
                case r.TokenKind.BRACKET_L:
                  return this.parseList(e);
                case r.TokenKind.BRACE_L:
                  return this.parseObject(e);
                case r.TokenKind.INT:
                  return this._lexer.advance(), { kind: i.Kind.INT, value: n.value, loc: this.loc(n) };
                case r.TokenKind.FLOAT:
                  return this._lexer.advance(), { kind: i.Kind.FLOAT, value: n.value, loc: this.loc(n) };
                case r.TokenKind.STRING:
                case r.TokenKind.BLOCK_STRING:
                  return this.parseStringLiteral();
                case r.TokenKind.NAME:
                  switch (this._lexer.advance(), n.value) {
                    case "true":
                      return { kind: i.Kind.BOOLEAN, value: true, loc: this.loc(n) };
                    case "false":
                      return { kind: i.Kind.BOOLEAN, value: false, loc: this.loc(n) };
                    case "null":
                      return { kind: i.Kind.NULL, loc: this.loc(n) };
                    default:
                      return { kind: i.Kind.ENUM, value: n.value, loc: this.loc(n) };
                  }
                case r.TokenKind.DOLLAR:
                  if (!e)
                    return this.parseVariable();
                  break;
              }
              throw this.unexpected();
            }, s.parseStringLiteral = function() {
              var e = this._lexer.token;
              return this._lexer.advance(), { kind: i.Kind.STRING, value: e.value, block: e.kind === r.TokenKind.BLOCK_STRING, loc: this.loc(e) };
            }, s.parseList = function(e) {
              var n = this, t3 = this._lexer.token, u = function() {
                return n.parseValueLiteral(e);
              };
              return { kind: i.Kind.LIST, values: this.any(r.TokenKind.BRACKET_L, u, r.TokenKind.BRACKET_R), loc: this.loc(t3) };
            }, s.parseObject = function(e) {
              var n = this, t3 = this._lexer.token, u = function() {
                return n.parseObjectField(e);
              };
              return { kind: i.Kind.OBJECT, fields: this.any(r.TokenKind.BRACE_L, u, r.TokenKind.BRACE_R), loc: this.loc(t3) };
            }, s.parseObjectField = function(e) {
              var n = this._lexer.token, t3 = this.parseName();
              return this.expectToken(r.TokenKind.COLON), { kind: i.Kind.OBJECT_FIELD, name: t3, value: this.parseValueLiteral(e), loc: this.loc(n) };
            }, s.parseDirectives = function(e) {
              for (var n = []; this.peek(r.TokenKind.AT); )
                n.push(this.parseDirective(e));
              return n;
            }, s.parseDirective = function(e) {
              var n = this._lexer.token;
              return this.expectToken(r.TokenKind.AT), { kind: i.Kind.DIRECTIVE, name: this.parseName(), arguments: this.parseArguments(e), loc: this.loc(n) };
            }, s.parseTypeReference = function() {
              var e = this._lexer.token, n;
              return this.expectOptionalToken(r.TokenKind.BRACKET_L) ? (n = this.parseTypeReference(), this.expectToken(r.TokenKind.BRACKET_R), n = { kind: i.Kind.LIST_TYPE, type: n, loc: this.loc(e) }) : n = this.parseNamedType(), this.expectOptionalToken(r.TokenKind.BANG) ? { kind: i.Kind.NON_NULL_TYPE, type: n, loc: this.loc(e) } : n;
            }, s.parseNamedType = function() {
              var e = this._lexer.token;
              return { kind: i.Kind.NAMED_TYPE, name: this.parseName(), loc: this.loc(e) };
            }, s.parseTypeSystemDefinition = function() {
              var e = this.peekDescription() ? this._lexer.lookahead() : this._lexer.token;
              if (e.kind === r.TokenKind.NAME)
                switch (e.value) {
                  case "schema":
                    return this.parseSchemaDefinition();
                  case "scalar":
                    return this.parseScalarTypeDefinition();
                  case "type":
                    return this.parseObjectTypeDefinition();
                  case "interface":
                    return this.parseInterfaceTypeDefinition();
                  case "union":
                    return this.parseUnionTypeDefinition();
                  case "enum":
                    return this.parseEnumTypeDefinition();
                  case "input":
                    return this.parseInputObjectTypeDefinition();
                  case "directive":
                    return this.parseDirectiveDefinition();
                }
              throw this.unexpected(e);
            }, s.peekDescription = function() {
              return this.peek(r.TokenKind.STRING) || this.peek(r.TokenKind.BLOCK_STRING);
            }, s.parseDescription = function() {
              if (this.peekDescription())
                return this.parseStringLiteral();
            }, s.parseSchemaDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("schema");
              var t3 = this.parseDirectives(true), u = this.many(r.TokenKind.BRACE_L, this.parseOperationTypeDefinition, r.TokenKind.BRACE_R);
              return { kind: i.Kind.SCHEMA_DEFINITION, description: n, directives: t3, operationTypes: u, loc: this.loc(e) };
            }, s.parseOperationTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseOperationType();
              this.expectToken(r.TokenKind.COLON);
              var t3 = this.parseNamedType();
              return { kind: i.Kind.OPERATION_TYPE_DEFINITION, operation: n, type: t3, loc: this.loc(e) };
            }, s.parseScalarTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("scalar");
              var t3 = this.parseName(), u = this.parseDirectives(true);
              return { kind: i.Kind.SCALAR_TYPE_DEFINITION, description: n, name: t3, directives: u, loc: this.loc(e) };
            }, s.parseObjectTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("type");
              var t3 = this.parseName(), u = this.parseImplementsInterfaces(), y = this.parseDirectives(true), f = this.parseFieldsDefinition();
              return { kind: i.Kind.OBJECT_TYPE_DEFINITION, description: n, name: t3, interfaces: u, directives: y, fields: f, loc: this.loc(e) };
            }, s.parseImplementsInterfaces = function() {
              var e;
              if (!this.expectOptionalKeyword("implements"))
                return [];
              if (((e = this._options) === null || e === void 0 ? void 0 : e.allowLegacySDLImplementsInterfaces) === true) {
                var n = [];
                this.expectOptionalToken(r.TokenKind.AMP);
                do
                  n.push(this.parseNamedType());
                while (this.expectOptionalToken(r.TokenKind.AMP) || this.peek(r.TokenKind.NAME));
                return n;
              }
              return this.delimitedMany(r.TokenKind.AMP, this.parseNamedType);
            }, s.parseFieldsDefinition = function() {
              var e;
              return ((e = this._options) === null || e === void 0 ? void 0 : e.allowLegacySDLEmptyFields) === true && this.peek(r.TokenKind.BRACE_L) && this._lexer.lookahead().kind === r.TokenKind.BRACE_R ? (this._lexer.advance(), this._lexer.advance(), []) : this.optionalMany(r.TokenKind.BRACE_L, this.parseFieldDefinition, r.TokenKind.BRACE_R);
            }, s.parseFieldDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription(), t3 = this.parseName(), u = this.parseArgumentDefs();
              this.expectToken(r.TokenKind.COLON);
              var y = this.parseTypeReference(), f = this.parseDirectives(true);
              return { kind: i.Kind.FIELD_DEFINITION, description: n, name: t3, arguments: u, type: y, directives: f, loc: this.loc(e) };
            }, s.parseArgumentDefs = function() {
              return this.optionalMany(r.TokenKind.PAREN_L, this.parseInputValueDef, r.TokenKind.PAREN_R);
            }, s.parseInputValueDef = function() {
              var e = this._lexer.token, n = this.parseDescription(), t3 = this.parseName();
              this.expectToken(r.TokenKind.COLON);
              var u = this.parseTypeReference(), y;
              this.expectOptionalToken(r.TokenKind.EQUALS) && (y = this.parseValueLiteral(true));
              var f = this.parseDirectives(true);
              return { kind: i.Kind.INPUT_VALUE_DEFINITION, description: n, name: t3, type: u, defaultValue: y, directives: f, loc: this.loc(e) };
            }, s.parseInterfaceTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("interface");
              var t3 = this.parseName(), u = this.parseImplementsInterfaces(), y = this.parseDirectives(true), f = this.parseFieldsDefinition();
              return { kind: i.Kind.INTERFACE_TYPE_DEFINITION, description: n, name: t3, interfaces: u, directives: y, fields: f, loc: this.loc(e) };
            }, s.parseUnionTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("union");
              var t3 = this.parseName(), u = this.parseDirectives(true), y = this.parseUnionMemberTypes();
              return { kind: i.Kind.UNION_TYPE_DEFINITION, description: n, name: t3, directives: u, types: y, loc: this.loc(e) };
            }, s.parseUnionMemberTypes = function() {
              return this.expectOptionalToken(r.TokenKind.EQUALS) ? this.delimitedMany(r.TokenKind.PIPE, this.parseNamedType) : [];
            }, s.parseEnumTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("enum");
              var t3 = this.parseName(), u = this.parseDirectives(true), y = this.parseEnumValuesDefinition();
              return { kind: i.Kind.ENUM_TYPE_DEFINITION, description: n, name: t3, directives: u, values: y, loc: this.loc(e) };
            }, s.parseEnumValuesDefinition = function() {
              return this.optionalMany(r.TokenKind.BRACE_L, this.parseEnumValueDefinition, r.TokenKind.BRACE_R);
            }, s.parseEnumValueDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription(), t3 = this.parseName(), u = this.parseDirectives(true);
              return { kind: i.Kind.ENUM_VALUE_DEFINITION, description: n, name: t3, directives: u, loc: this.loc(e) };
            }, s.parseInputObjectTypeDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("input");
              var t3 = this.parseName(), u = this.parseDirectives(true), y = this.parseInputFieldsDefinition();
              return { kind: i.Kind.INPUT_OBJECT_TYPE_DEFINITION, description: n, name: t3, directives: u, fields: y, loc: this.loc(e) };
            }, s.parseInputFieldsDefinition = function() {
              return this.optionalMany(r.TokenKind.BRACE_L, this.parseInputValueDef, r.TokenKind.BRACE_R);
            }, s.parseTypeSystemExtension = function() {
              var e = this._lexer.lookahead();
              if (e.kind === r.TokenKind.NAME)
                switch (e.value) {
                  case "schema":
                    return this.parseSchemaExtension();
                  case "scalar":
                    return this.parseScalarTypeExtension();
                  case "type":
                    return this.parseObjectTypeExtension();
                  case "interface":
                    return this.parseInterfaceTypeExtension();
                  case "union":
                    return this.parseUnionTypeExtension();
                  case "enum":
                    return this.parseEnumTypeExtension();
                  case "input":
                    return this.parseInputObjectTypeExtension();
                }
              throw this.unexpected(e);
            }, s.parseSchemaExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("schema");
              var n = this.parseDirectives(true), t3 = this.optionalMany(r.TokenKind.BRACE_L, this.parseOperationTypeDefinition, r.TokenKind.BRACE_R);
              if (n.length === 0 && t3.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.SCHEMA_EXTENSION, directives: n, operationTypes: t3, loc: this.loc(e) };
            }, s.parseScalarTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("scalar");
              var n = this.parseName(), t3 = this.parseDirectives(true);
              if (t3.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.SCALAR_TYPE_EXTENSION, name: n, directives: t3, loc: this.loc(e) };
            }, s.parseObjectTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("type");
              var n = this.parseName(), t3 = this.parseImplementsInterfaces(), u = this.parseDirectives(true), y = this.parseFieldsDefinition();
              if (t3.length === 0 && u.length === 0 && y.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.OBJECT_TYPE_EXTENSION, name: n, interfaces: t3, directives: u, fields: y, loc: this.loc(e) };
            }, s.parseInterfaceTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("interface");
              var n = this.parseName(), t3 = this.parseImplementsInterfaces(), u = this.parseDirectives(true), y = this.parseFieldsDefinition();
              if (t3.length === 0 && u.length === 0 && y.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.INTERFACE_TYPE_EXTENSION, name: n, interfaces: t3, directives: u, fields: y, loc: this.loc(e) };
            }, s.parseUnionTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("union");
              var n = this.parseName(), t3 = this.parseDirectives(true), u = this.parseUnionMemberTypes();
              if (t3.length === 0 && u.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.UNION_TYPE_EXTENSION, name: n, directives: t3, types: u, loc: this.loc(e) };
            }, s.parseEnumTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("enum");
              var n = this.parseName(), t3 = this.parseDirectives(true), u = this.parseEnumValuesDefinition();
              if (t3.length === 0 && u.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.ENUM_TYPE_EXTENSION, name: n, directives: t3, values: u, loc: this.loc(e) };
            }, s.parseInputObjectTypeExtension = function() {
              var e = this._lexer.token;
              this.expectKeyword("extend"), this.expectKeyword("input");
              var n = this.parseName(), t3 = this.parseDirectives(true), u = this.parseInputFieldsDefinition();
              if (t3.length === 0 && u.length === 0)
                throw this.unexpected();
              return { kind: i.Kind.INPUT_OBJECT_TYPE_EXTENSION, name: n, directives: t3, fields: u, loc: this.loc(e) };
            }, s.parseDirectiveDefinition = function() {
              var e = this._lexer.token, n = this.parseDescription();
              this.expectKeyword("directive"), this.expectToken(r.TokenKind.AT);
              var t3 = this.parseName(), u = this.parseArgumentDefs(), y = this.expectOptionalKeyword("repeatable");
              this.expectKeyword("on");
              var f = this.parseDirectiveLocations();
              return { kind: i.Kind.DIRECTIVE_DEFINITION, description: n, name: t3, arguments: u, repeatable: y, locations: f, loc: this.loc(e) };
            }, s.parseDirectiveLocations = function() {
              return this.delimitedMany(r.TokenKind.PIPE, this.parseDirectiveLocation);
            }, s.parseDirectiveLocation = function() {
              var e = this._lexer.token, n = this.parseName();
              if (E.DirectiveLocation[n.value] !== void 0)
                return n;
              throw this.unexpected(e);
            }, s.loc = function(e) {
              var n;
              if (((n = this._options) === null || n === void 0 ? void 0 : n.noLocation) !== true)
                return new c.Location(e, this._lexer.lastToken, this._lexer.source);
            }, s.peek = function(e) {
              return this._lexer.token.kind === e;
            }, s.expectToken = function(e) {
              var n = this._lexer.token;
              if (n.kind === e)
                return this._lexer.advance(), n;
              throw (0, d.syntaxError)(this._lexer.source, n.start, "Expected ".concat(v(e), ", found ").concat(D(n), "."));
            }, s.expectOptionalToken = function(e) {
              var n = this._lexer.token;
              if (n.kind === e)
                return this._lexer.advance(), n;
            }, s.expectKeyword = function(e) {
              var n = this._lexer.token;
              if (n.kind === r.TokenKind.NAME && n.value === e)
                this._lexer.advance();
              else
                throw (0, d.syntaxError)(this._lexer.source, n.start, 'Expected "'.concat(e, '", found ').concat(D(n), "."));
            }, s.expectOptionalKeyword = function(e) {
              var n = this._lexer.token;
              return n.kind === r.TokenKind.NAME && n.value === e ? (this._lexer.advance(), true) : false;
            }, s.unexpected = function(e) {
              var n = e != null ? e : this._lexer.token;
              return (0, d.syntaxError)(this._lexer.source, n.start, "Unexpected ".concat(D(n), "."));
            }, s.any = function(e, n, t3) {
              this.expectToken(e);
              for (var u = []; !this.expectOptionalToken(t3); )
                u.push(n.call(this));
              return u;
            }, s.optionalMany = function(e, n, t3) {
              if (this.expectOptionalToken(e)) {
                var u = [];
                do
                  u.push(n.call(this));
                while (!this.expectOptionalToken(t3));
                return u;
              }
              return [];
            }, s.many = function(e, n, t3) {
              this.expectToken(e);
              var u = [];
              do
                u.push(n.call(this));
              while (!this.expectOptionalToken(t3));
              return u;
            }, s.delimitedMany = function(e, n) {
              this.expectOptionalToken(e);
              var t3 = [];
              do
                t3.push(n.call(this));
              while (this.expectOptionalToken(e));
              return t3;
            }, I;
          }();
          a.Parser = g;
          function D(I) {
            var s = I.value;
            return v(I.kind) + (s != null ? ' "'.concat(s, '"') : "");
          }
          function v(I) {
            return (0, k.isPunctuatorTokenKind)(I) ? '"'.concat(I, '"') : I;
          }
        } });
        K();
        var Ie = ce(), ge = ue(), { hasPragma: Se } = le(), { locStart: Ae, locEnd: De } = pe();
        function Ke(a) {
          let d = [], { startToken: i } = a.loc, { next: c } = i;
          for (; c.kind !== "<EOF>"; )
            c.kind === "Comment" && (Object.assign(c, { column: c.column - 1 }), d.push(c)), c = c.next;
          return d;
        }
        function ie(a) {
          if (a && typeof a == "object") {
            delete a.startToken, delete a.endToken, delete a.prev, delete a.next;
            for (let d in a)
              ie(a[d]);
          }
          return a;
        }
        var X = { allowLegacySDLImplementsInterfaces: false, experimentalFragmentVariables: true };
        function Le(a) {
          let { GraphQLError: d } = W();
          if (a instanceof d) {
            let { message: i, locations: [c] } = a;
            return Ie(i, { start: c });
          }
          return a;
        }
        function xe(a) {
          let { parse: d } = Oe(), { result: i, error: c } = ge(() => d(a, Object.assign({}, X)), () => d(a, Object.assign(Object.assign({}, X), {}, { allowLegacySDLImplementsInterfaces: true })));
          if (!i)
            throw Le(c);
          return i.comments = Ke(i), ie(i), i;
        }
        ae.exports = { parsers: { graphql: { parse: xe, astFormat: "graphql", hasPragma: Se, locStart: Ae, locEnd: De } } };
      });
      return be();
    });
  }
});

// node_modules/prettier/parser-markdown.js
var require_parser_markdown = __commonJS({
  "node_modules/prettier/parser-markdown.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.markdown = e();
      }
    })(function() {
      "use strict";
      var $2 = (e, r) => () => (r || e((r = { exports: {} }).exports, r), r.exports);
      var Fe = $2((nf, yu) => {
        var tr = function(e) {
          return e && e.Math == Math && e;
        };
        yu.exports = tr(typeof globalThis == "object" && globalThis) || tr(typeof window == "object" && window) || tr(typeof self == "object" && self) || tr(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var Ae = $2((af, wu) => {
        wu.exports = function(e) {
          try {
            return !!e();
          } catch {
            return true;
          }
        };
      });
      var Be = $2((of, Bu) => {
        var fa = Ae();
        Bu.exports = !fa(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var nr = $2((sf, ku) => {
        var pa = Ae();
        ku.exports = !pa(function() {
          var e = function() {
          }.bind();
          return typeof e != "function" || e.hasOwnProperty("prototype");
        });
      });
      var Oe = $2((cf, qu) => {
        var da = nr(), ir = Function.prototype.call;
        qu.exports = da ? ir.bind(ir) : function() {
          return ir.apply(ir, arguments);
        };
      });
      var Su = $2((Iu) => {
        "use strict";
        var _u = {}.propertyIsEnumerable, Ou = Object.getOwnPropertyDescriptor, ha = Ou && !_u.call({ 1: 2 }, 1);
        Iu.f = ha ? function(r) {
          var u = Ou(this, r);
          return !!u && u.enumerable;
        } : _u;
      });
      var ar = $2((Df, Tu) => {
        Tu.exports = function(e, r) {
          return { enumerable: !(e & 1), configurable: !(e & 2), writable: !(e & 4), value: r };
        };
      });
      var ve = $2((ff, Ru) => {
        var Nu = nr(), Lu = Function.prototype, wr = Lu.call, va = Nu && Lu.bind.bind(wr, wr);
        Ru.exports = Nu ? va : function(e) {
          return function() {
            return wr.apply(e, arguments);
          };
        };
      });
      var Ve = $2((pf, Pu) => {
        var ju = ve(), ma = ju({}.toString), Ea = ju("".slice);
        Pu.exports = function(e) {
          return Ea(ma(e), 8, -1);
        };
      });
      var zu = $2((df, Mu) => {
        var Ca = ve(), ga = Ae(), Fa = Ve(), Br = Object, Aa = Ca("".split);
        Mu.exports = ga(function() {
          return !Br("z").propertyIsEnumerable(0);
        }) ? function(e) {
          return Fa(e) == "String" ? Aa(e, "") : Br(e);
        } : Br;
      });
      var or = $2((hf, $u) => {
        $u.exports = function(e) {
          return e == null;
        };
      });
      var kr = $2((vf, Uu) => {
        var xa = or(), ba = TypeError;
        Uu.exports = function(e) {
          if (xa(e))
            throw ba("Can't call method on " + e);
          return e;
        };
      });
      var sr = $2((mf, Gu) => {
        var ya = zu(), wa = kr();
        Gu.exports = function(e) {
          return ya(wa(e));
        };
      });
      var _r = $2((Ef, Vu) => {
        var qr = typeof document == "object" && document.all, Ba = typeof qr > "u" && qr !== void 0;
        Vu.exports = { all: qr, IS_HTMLDDA: Ba };
      });
      var de = $2((Cf, Xu) => {
        var Hu = _r(), ka = Hu.all;
        Xu.exports = Hu.IS_HTMLDDA ? function(e) {
          return typeof e == "function" || e === ka;
        } : function(e) {
          return typeof e == "function";
        };
      });
      var Ie = $2((gf, Yu) => {
        var Wu = de(), Ku = _r(), qa = Ku.all;
        Yu.exports = Ku.IS_HTMLDDA ? function(e) {
          return typeof e == "object" ? e !== null : Wu(e) || e === qa;
        } : function(e) {
          return typeof e == "object" ? e !== null : Wu(e);
        };
      });
      var He = $2((Ff, Ju) => {
        var Or = Fe(), _a = de(), Oa = function(e) {
          return _a(e) ? e : void 0;
        };
        Ju.exports = function(e, r) {
          return arguments.length < 2 ? Oa(Or[e]) : Or[e] && Or[e][r];
        };
      });
      var Ir = $2((Af, Zu) => {
        var Ia = ve();
        Zu.exports = Ia({}.isPrototypeOf);
      });
      var et = $2((xf, Qu) => {
        var Sa = He();
        Qu.exports = Sa("navigator", "userAgent") || "";
      });
      var ot = $2((bf, at) => {
        var it2 = Fe(), Sr = et(), rt = it2.process, ut = it2.Deno, tt = rt && rt.versions || ut && ut.version, nt = tt && tt.v8, me, cr;
        nt && (me = nt.split("."), cr = me[0] > 0 && me[0] < 4 ? 1 : +(me[0] + me[1]));
        !cr && Sr && (me = Sr.match(/Edge\/(\d+)/), (!me || me[1] >= 74) && (me = Sr.match(/Chrome\/(\d+)/), me && (cr = +me[1])));
        at.exports = cr;
      });
      var Tr = $2((yf, ct) => {
        var st = ot(), Ta = Ae();
        ct.exports = !!Object.getOwnPropertySymbols && !Ta(function() {
          var e = Symbol();
          return !String(e) || !(Object(e) instanceof Symbol) || !Symbol.sham && st && st < 41;
        });
      });
      var Nr = $2((wf, lt) => {
        var Na = Tr();
        lt.exports = Na && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var Lr = $2((Bf, Dt) => {
        var La = He(), Ra = de(), ja = Ir(), Pa = Nr(), Ma = Object;
        Dt.exports = Pa ? function(e) {
          return typeof e == "symbol";
        } : function(e) {
          var r = La("Symbol");
          return Ra(r) && ja(r.prototype, Ma(e));
        };
      });
      var lr = $2((kf, ft) => {
        var za = String;
        ft.exports = function(e) {
          try {
            return za(e);
          } catch {
            return "Object";
          }
        };
      });
      var Xe = $2((qf, pt) => {
        var $a = de(), Ua = lr(), Ga = TypeError;
        pt.exports = function(e) {
          if ($a(e))
            return e;
          throw Ga(Ua(e) + " is not a function");
        };
      });
      var Dr = $2((_f, dt) => {
        var Va = Xe(), Ha = or();
        dt.exports = function(e, r) {
          var u = e[r];
          return Ha(u) ? void 0 : Va(u);
        };
      });
      var vt = $2((Of, ht) => {
        var Rr = Oe(), jr = de(), Pr = Ie(), Xa = TypeError;
        ht.exports = function(e, r) {
          var u, t3;
          if (r === "string" && jr(u = e.toString) && !Pr(t3 = Rr(u, e)) || jr(u = e.valueOf) && !Pr(t3 = Rr(u, e)) || r !== "string" && jr(u = e.toString) && !Pr(t3 = Rr(u, e)))
            return t3;
          throw Xa("Can't convert object to primitive value");
        };
      });
      var Et = $2((If, mt) => {
        mt.exports = false;
      });
      var fr = $2((Sf, gt) => {
        var Ct = Fe(), Wa = Object.defineProperty;
        gt.exports = function(e, r) {
          try {
            Wa(Ct, e, { value: r, configurable: true, writable: true });
          } catch {
            Ct[e] = r;
          }
          return r;
        };
      });
      var pr = $2((Tf, At) => {
        var Ka = Fe(), Ya = fr(), Ft = "__core-js_shared__", Ja = Ka[Ft] || Ya(Ft, {});
        At.exports = Ja;
      });
      var Mr = $2((Nf, bt) => {
        var Za = Et(), xt = pr();
        (bt.exports = function(e, r) {
          return xt[e] || (xt[e] = r !== void 0 ? r : {});
        })("versions", []).push({ version: "3.26.1", mode: Za ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var zr = $2((Lf, yt) => {
        var Qa = kr(), eo = Object;
        yt.exports = function(e) {
          return eo(Qa(e));
        };
      });
      var ke = $2((Rf, wt) => {
        var ro = ve(), uo = zr(), to = ro({}.hasOwnProperty);
        wt.exports = Object.hasOwn || function(r, u) {
          return to(uo(r), u);
        };
      });
      var $r = $2((jf, Bt) => {
        var no = ve(), io = 0, ao = Math.random(), oo = no(1 .toString);
        Bt.exports = function(e) {
          return "Symbol(" + (e === void 0 ? "" : e) + ")_" + oo(++io + ao, 36);
        };
      });
      var Te = $2((Pf, It) => {
        var so = Fe(), co = Mr(), kt = ke(), lo = $r(), qt = Tr(), Ot = Nr(), Le = co("wks"), Se = so.Symbol, _t = Se && Se.for, Do = Ot ? Se : Se && Se.withoutSetter || lo;
        It.exports = function(e) {
          if (!kt(Le, e) || !(qt || typeof Le[e] == "string")) {
            var r = "Symbol." + e;
            qt && kt(Se, e) ? Le[e] = Se[e] : Ot && _t ? Le[e] = _t(r) : Le[e] = Do(r);
          }
          return Le[e];
        };
      });
      var Lt = $2((Mf, Nt) => {
        var fo = Oe(), St = Ie(), Tt = Lr(), po = Dr(), ho = vt(), vo = Te(), mo = TypeError, Eo = vo("toPrimitive");
        Nt.exports = function(e, r) {
          if (!St(e) || Tt(e))
            return e;
          var u = po(e, Eo), t3;
          if (u) {
            if (r === void 0 && (r = "default"), t3 = fo(u, e, r), !St(t3) || Tt(t3))
              return t3;
            throw mo("Can't convert object to primitive value");
          }
          return r === void 0 && (r = "number"), ho(e, r);
        };
      });
      var dr = $2((zf, Rt) => {
        var Co = Lt(), go = Lr();
        Rt.exports = function(e) {
          var r = Co(e, "string");
          return go(r) ? r : r + "";
        };
      });
      var Mt = $2(($f, Pt) => {
        var Fo = Fe(), jt = Ie(), Ur = Fo.document, Ao = jt(Ur) && jt(Ur.createElement);
        Pt.exports = function(e) {
          return Ao ? Ur.createElement(e) : {};
        };
      });
      var Gr = $2((Uf, zt) => {
        var xo = Be(), bo = Ae(), yo = Mt();
        zt.exports = !xo && !bo(function() {
          return Object.defineProperty(yo("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var Vr = $2((Ut) => {
        var wo = Be(), Bo = Oe(), ko = Su(), qo = ar(), _o = sr(), Oo = dr(), Io = ke(), So = Gr(), $t = Object.getOwnPropertyDescriptor;
        Ut.f = wo ? $t : function(r, u) {
          if (r = _o(r), u = Oo(u), So)
            try {
              return $t(r, u);
            } catch {
            }
          if (Io(r, u))
            return qo(!Bo(ko.f, r, u), r[u]);
        };
      });
      var Vt = $2((Vf, Gt) => {
        var To = Be(), No = Ae();
        Gt.exports = To && No(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var Re = $2((Hf, Ht) => {
        var Lo = Ie(), Ro = String, jo = TypeError;
        Ht.exports = function(e) {
          if (Lo(e))
            return e;
          throw jo(Ro(e) + " is not an object");
        };
      });
      var We = $2((Wt) => {
        var Po = Be(), Mo = Gr(), zo = Vt(), hr = Re(), Xt = dr(), $o = TypeError, Hr = Object.defineProperty, Uo = Object.getOwnPropertyDescriptor, Xr = "enumerable", Wr = "configurable", Kr = "writable";
        Wt.f = Po ? zo ? function(r, u, t3) {
          if (hr(r), u = Xt(u), hr(t3), typeof r == "function" && u === "prototype" && "value" in t3 && Kr in t3 && !t3[Kr]) {
            var a = Uo(r, u);
            a && a[Kr] && (r[u] = t3.value, t3 = { configurable: Wr in t3 ? t3[Wr] : a[Wr], enumerable: Xr in t3 ? t3[Xr] : a[Xr], writable: false });
          }
          return Hr(r, u, t3);
        } : Hr : function(r, u, t3) {
          if (hr(r), u = Xt(u), hr(t3), Mo)
            try {
              return Hr(r, u, t3);
            } catch {
            }
          if ("get" in t3 || "set" in t3)
            throw $o("Accessors not supported");
          return "value" in t3 && (r[u] = t3.value), r;
        };
      });
      var Yr = $2((Wf, Kt) => {
        var Go = Be(), Vo = We(), Ho = ar();
        Kt.exports = Go ? function(e, r, u) {
          return Vo.f(e, r, Ho(1, u));
        } : function(e, r, u) {
          return e[r] = u, e;
        };
      });
      var Zt = $2((Kf, Jt) => {
        var Jr = Be(), Xo = ke(), Yt = Function.prototype, Wo = Jr && Object.getOwnPropertyDescriptor, Zr = Xo(Yt, "name"), Ko = Zr && function() {
        }.name === "something", Yo = Zr && (!Jr || Jr && Wo(Yt, "name").configurable);
        Jt.exports = { EXISTS: Zr, PROPER: Ko, CONFIGURABLE: Yo };
      });
      var eu = $2((Yf, Qt) => {
        var Jo = ve(), Zo = de(), Qr = pr(), Qo = Jo(Function.toString);
        Zo(Qr.inspectSource) || (Qr.inspectSource = function(e) {
          return Qo(e);
        });
        Qt.exports = Qr.inspectSource;
      });
      var un = $2((Jf, rn) => {
        var es = Fe(), rs = de(), en = es.WeakMap;
        rn.exports = rs(en) && /native code/.test(String(en));
      });
      var an = $2((Zf, nn) => {
        var us = Mr(), ts = $r(), tn = us("keys");
        nn.exports = function(e) {
          return tn[e] || (tn[e] = ts(e));
        };
      });
      var ru = $2((Qf, on) => {
        on.exports = {};
      });
      var Dn = $2((ep, ln) => {
        var ns = un(), cn = Fe(), is = Ie(), as = Yr(), uu = ke(), tu = pr(), os = an(), ss = ru(), sn = "Object already initialized", nu = cn.TypeError, cs = cn.WeakMap, vr, Ke, mr, ls = function(e) {
          return mr(e) ? Ke(e) : vr(e, {});
        }, Ds = function(e) {
          return function(r) {
            var u;
            if (!is(r) || (u = Ke(r)).type !== e)
              throw nu("Incompatible receiver, " + e + " required");
            return u;
          };
        };
        ns || tu.state ? (Ee = tu.state || (tu.state = new cs()), Ee.get = Ee.get, Ee.has = Ee.has, Ee.set = Ee.set, vr = function(e, r) {
          if (Ee.has(e))
            throw nu(sn);
          return r.facade = e, Ee.set(e, r), r;
        }, Ke = function(e) {
          return Ee.get(e) || {};
        }, mr = function(e) {
          return Ee.has(e);
        }) : (Ne = os("state"), ss[Ne] = true, vr = function(e, r) {
          if (uu(e, Ne))
            throw nu(sn);
          return r.facade = e, as(e, Ne, r), r;
        }, Ke = function(e) {
          return uu(e, Ne) ? e[Ne] : {};
        }, mr = function(e) {
          return uu(e, Ne);
        });
        var Ee, Ne;
        ln.exports = { set: vr, get: Ke, has: mr, enforce: ls, getterFor: Ds };
      });
      var dn = $2((rp, pn) => {
        var fs2 = Ae(), ps = de(), Er = ke(), iu = Be(), ds = Zt().CONFIGURABLE, hs = eu(), fn = Dn(), vs = fn.enforce, ms = fn.get, Cr = Object.defineProperty, Es = iu && !fs2(function() {
          return Cr(function() {
          }, "length", { value: 8 }).length !== 8;
        }), Cs = String(String).split("String"), gs = pn.exports = function(e, r, u) {
          String(r).slice(0, 7) === "Symbol(" && (r = "[" + String(r).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), u && u.getter && (r = "get " + r), u && u.setter && (r = "set " + r), (!Er(e, "name") || ds && e.name !== r) && (iu ? Cr(e, "name", { value: r, configurable: true }) : e.name = r), Es && u && Er(u, "arity") && e.length !== u.arity && Cr(e, "length", { value: u.arity });
          try {
            u && Er(u, "constructor") && u.constructor ? iu && Cr(e, "prototype", { writable: false }) : e.prototype && (e.prototype = void 0);
          } catch {
          }
          var t3 = vs(e);
          return Er(t3, "source") || (t3.source = Cs.join(typeof r == "string" ? r : "")), e;
        };
        Function.prototype.toString = gs(function() {
          return ps(this) && ms(this).source || hs(this);
        }, "toString");
      });
      var vn = $2((up, hn) => {
        var Fs = de(), As = We(), xs = dn(), bs = fr();
        hn.exports = function(e, r, u, t3) {
          t3 || (t3 = {});
          var a = t3.enumerable, n = t3.name !== void 0 ? t3.name : r;
          if (Fs(u) && xs(u, n, t3), t3.global)
            a ? e[r] = u : bs(r, u);
          else {
            try {
              t3.unsafe ? e[r] && (a = true) : delete e[r];
            } catch {
            }
            a ? e[r] = u : As.f(e, r, { value: u, enumerable: false, configurable: !t3.nonConfigurable, writable: !t3.nonWritable });
          }
          return e;
        };
      });
      var En = $2((tp, mn) => {
        var ys = Math.ceil, ws = Math.floor;
        mn.exports = Math.trunc || function(r) {
          var u = +r;
          return (u > 0 ? ws : ys)(u);
        };
      });
      var au = $2((np, Cn) => {
        var Bs = En();
        Cn.exports = function(e) {
          var r = +e;
          return r !== r || r === 0 ? 0 : Bs(r);
        };
      });
      var Fn = $2((ip, gn) => {
        var ks = au(), qs = Math.max, _s = Math.min;
        gn.exports = function(e, r) {
          var u = ks(e);
          return u < 0 ? qs(u + r, 0) : _s(u, r);
        };
      });
      var xn = $2((ap, An) => {
        var Os = au(), Is = Math.min;
        An.exports = function(e) {
          return e > 0 ? Is(Os(e), 9007199254740991) : 0;
        };
      });
      var Ye = $2((op, bn) => {
        var Ss = xn();
        bn.exports = function(e) {
          return Ss(e.length);
        };
      });
      var Bn = $2((sp, wn) => {
        var Ts = sr(), Ns = Fn(), Ls = Ye(), yn = function(e) {
          return function(r, u, t3) {
            var a = Ts(r), n = Ls(a), s = Ns(t3, n), c;
            if (e && u != u) {
              for (; n > s; )
                if (c = a[s++], c != c)
                  return true;
            } else
              for (; n > s; s++)
                if ((e || s in a) && a[s] === u)
                  return e || s || 0;
            return !e && -1;
          };
        };
        wn.exports = { includes: yn(true), indexOf: yn(false) };
      });
      var _n = $2((cp, qn) => {
        var Rs = ve(), ou = ke(), js = sr(), Ps = Bn().indexOf, Ms = ru(), kn = Rs([].push);
        qn.exports = function(e, r) {
          var u = js(e), t3 = 0, a = [], n;
          for (n in u)
            !ou(Ms, n) && ou(u, n) && kn(a, n);
          for (; r.length > t3; )
            ou(u, n = r[t3++]) && (~Ps(a, n) || kn(a, n));
          return a;
        };
      });
      var In = $2((lp, On) => {
        On.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var Tn = $2((Sn) => {
        var zs = _n(), $s = In(), Us = $s.concat("length", "prototype");
        Sn.f = Object.getOwnPropertyNames || function(r) {
          return zs(r, Us);
        };
      });
      var Ln = $2((Nn) => {
        Nn.f = Object.getOwnPropertySymbols;
      });
      var jn = $2((pp, Rn) => {
        var Gs = He(), Vs = ve(), Hs = Tn(), Xs = Ln(), Ws = Re(), Ks = Vs([].concat);
        Rn.exports = Gs("Reflect", "ownKeys") || function(r) {
          var u = Hs.f(Ws(r)), t3 = Xs.f;
          return t3 ? Ks(u, t3(r)) : u;
        };
      });
      var zn = $2((dp, Mn) => {
        var Pn = ke(), Ys = jn(), Js = Vr(), Zs = We();
        Mn.exports = function(e, r, u) {
          for (var t3 = Ys(r), a = Zs.f, n = Js.f, s = 0; s < t3.length; s++) {
            var c = t3[s];
            !Pn(e, c) && !(u && Pn(u, c)) && a(e, c, n(r, c));
          }
        };
      });
      var Un = $2((hp, $n) => {
        var Qs = Ae(), ec = de(), rc = /#|\.prototype\./, Je = function(e, r) {
          var u = tc[uc(e)];
          return u == ic ? true : u == nc ? false : ec(r) ? Qs(r) : !!r;
        }, uc = Je.normalize = function(e) {
          return String(e).replace(rc, ".").toLowerCase();
        }, tc = Je.data = {}, nc = Je.NATIVE = "N", ic = Je.POLYFILL = "P";
        $n.exports = Je;
      });
      var cu = $2((vp, Gn) => {
        var su = Fe(), ac = Vr().f, oc = Yr(), sc = vn(), cc = fr(), lc = zn(), Dc = Un();
        Gn.exports = function(e, r) {
          var u = e.target, t3 = e.global, a = e.stat, n, s, c, i, D, o;
          if (t3 ? s = su : a ? s = su[u] || cc(u, {}) : s = (su[u] || {}).prototype, s)
            for (c in r) {
              if (D = r[c], e.dontCallGetSet ? (o = ac(s, c), i = o && o.value) : i = s[c], n = Dc(t3 ? c : u + (a ? "." : "#") + c, e.forced), !n && i !== void 0) {
                if (typeof D == typeof i)
                  continue;
                lc(D, i);
              }
              (e.sham || i && i.sham) && oc(D, "sham", true), sc(s, c, D, e);
            }
        };
      });
      var lu = $2((mp, Vn) => {
        var fc = Ve();
        Vn.exports = Array.isArray || function(r) {
          return fc(r) == "Array";
        };
      });
      var Xn = $2((Ep, Hn) => {
        var pc = TypeError, dc = 9007199254740991;
        Hn.exports = function(e) {
          if (e > dc)
            throw pc("Maximum allowed index exceeded");
          return e;
        };
      });
      var Kn = $2((Cp, Wn) => {
        var hc = Ve(), vc = ve();
        Wn.exports = function(e) {
          if (hc(e) === "Function")
            return vc(e);
        };
      });
      var Du = $2((gp, Jn) => {
        var Yn = Kn(), mc = Xe(), Ec = nr(), Cc = Yn(Yn.bind);
        Jn.exports = function(e, r) {
          return mc(e), r === void 0 ? e : Ec ? Cc(e, r) : function() {
            return e.apply(r, arguments);
          };
        };
      });
      var ei = $2((Fp, Qn) => {
        "use strict";
        var gc = lu(), Fc = Ye(), Ac = Xn(), xc = Du(), Zn = function(e, r, u, t3, a, n, s, c) {
          for (var i = a, D = 0, o = s ? xc(s, c) : false, l, d; D < t3; )
            D in u && (l = o ? o(u[D], D, r) : u[D], n > 0 && gc(l) ? (d = Fc(l), i = Zn(e, r, l, d, i, n - 1) - 1) : (Ac(i + 1), e[i] = l), i++), D++;
          return i;
        };
        Qn.exports = Zn;
      });
      var ti = $2((Ap, ui) => {
        var bc = Te(), yc = bc("toStringTag"), ri = {};
        ri[yc] = "z";
        ui.exports = String(ri) === "[object z]";
      });
      var fu = $2((xp, ni) => {
        var wc = ti(), Bc = de(), gr = Ve(), kc = Te(), qc = kc("toStringTag"), _c = Object, Oc = gr(function() {
          return arguments;
        }()) == "Arguments", Ic = function(e, r) {
          try {
            return e[r];
          } catch {
          }
        };
        ni.exports = wc ? gr : function(e) {
          var r, u, t3;
          return e === void 0 ? "Undefined" : e === null ? "Null" : typeof (u = Ic(r = _c(e), qc)) == "string" ? u : Oc ? gr(r) : (t3 = gr(r)) == "Object" && Bc(r.callee) ? "Arguments" : t3;
        };
      });
      var li = $2((bp, ci) => {
        var Sc = ve(), Tc = Ae(), ii = de(), Nc = fu(), Lc = He(), Rc = eu(), ai = function() {
        }, jc = [], oi = Lc("Reflect", "construct"), pu = /^\s*(?:class|function)\b/, Pc = Sc(pu.exec), Mc = !pu.exec(ai), Ze = function(r) {
          if (!ii(r))
            return false;
          try {
            return oi(ai, jc, r), true;
          } catch {
            return false;
          }
        }, si = function(r) {
          if (!ii(r))
            return false;
          switch (Nc(r)) {
            case "AsyncFunction":
            case "GeneratorFunction":
            case "AsyncGeneratorFunction":
              return false;
          }
          try {
            return Mc || !!Pc(pu, Rc(r));
          } catch {
            return true;
          }
        };
        si.sham = true;
        ci.exports = !oi || Tc(function() {
          var e;
          return Ze(Ze.call) || !Ze(Object) || !Ze(function() {
            e = true;
          }) || e;
        }) ? si : Ze;
      });
      var di = $2((yp, pi) => {
        var Di = lu(), zc = li(), $c = Ie(), Uc = Te(), Gc = Uc("species"), fi = Array;
        pi.exports = function(e) {
          var r;
          return Di(e) && (r = e.constructor, zc(r) && (r === fi || Di(r.prototype)) ? r = void 0 : $c(r) && (r = r[Gc], r === null && (r = void 0))), r === void 0 ? fi : r;
        };
      });
      var vi = $2((wp, hi) => {
        var Vc = di();
        hi.exports = function(e, r) {
          return new (Vc(e))(r === 0 ? 0 : r);
        };
      });
      var mi = $2(() => {
        "use strict";
        var Hc = cu(), Xc = ei(), Wc = Xe(), Kc = zr(), Yc = Ye(), Jc = vi();
        Hc({ target: "Array", proto: true }, { flatMap: function(r) {
          var u = Kc(this), t3 = Yc(u), a;
          return Wc(r), a = Jc(u, 0), a.length = Xc(a, u, u, t3, 0, 1, r, arguments.length > 1 ? arguments[1] : void 0), a;
        } });
      });
      var du = $2((qp, Ei) => {
        Ei.exports = {};
      });
      var gi = $2((_p, Ci) => {
        var Zc = Te(), Qc = du(), el = Zc("iterator"), rl = Array.prototype;
        Ci.exports = function(e) {
          return e !== void 0 && (Qc.Array === e || rl[el] === e);
        };
      });
      var hu = $2((Op, Ai) => {
        var ul = fu(), Fi = Dr(), tl = or(), nl = du(), il = Te(), al = il("iterator");
        Ai.exports = function(e) {
          if (!tl(e))
            return Fi(e, al) || Fi(e, "@@iterator") || nl[ul(e)];
        };
      });
      var bi = $2((Ip, xi) => {
        var ol = Oe(), sl = Xe(), cl = Re(), ll = lr(), Dl = hu(), fl = TypeError;
        xi.exports = function(e, r) {
          var u = arguments.length < 2 ? Dl(e) : r;
          if (sl(u))
            return cl(ol(u, e));
          throw fl(ll(e) + " is not iterable");
        };
      });
      var Bi = $2((Sp, wi) => {
        var pl = Oe(), yi = Re(), dl = Dr();
        wi.exports = function(e, r, u) {
          var t3, a;
          yi(e);
          try {
            if (t3 = dl(e, "return"), !t3) {
              if (r === "throw")
                throw u;
              return u;
            }
            t3 = pl(t3, e);
          } catch (n) {
            a = true, t3 = n;
          }
          if (r === "throw")
            throw u;
          if (a)
            throw t3;
          return yi(t3), u;
        };
      });
      var Ii = $2((Tp, Oi) => {
        var hl = Du(), vl = Oe(), ml = Re(), El = lr(), Cl = gi(), gl = Ye(), ki = Ir(), Fl = bi(), Al = hu(), qi = Bi(), xl = TypeError, Fr = function(e, r) {
          this.stopped = e, this.result = r;
        }, _i = Fr.prototype;
        Oi.exports = function(e, r, u) {
          var t3 = u && u.that, a = !!(u && u.AS_ENTRIES), n = !!(u && u.IS_RECORD), s = !!(u && u.IS_ITERATOR), c = !!(u && u.INTERRUPTED), i = hl(r, t3), D, o, l, d, p, g, F, E = function(f) {
            return D && qi(D, "normal", f), new Fr(true, f);
          }, b = function(f) {
            return a ? (ml(f), c ? i(f[0], f[1], E) : i(f[0], f[1])) : c ? i(f, E) : i(f);
          };
          if (n)
            D = e.iterator;
          else if (s)
            D = e;
          else {
            if (o = Al(e), !o)
              throw xl(El(e) + " is not iterable");
            if (Cl(o)) {
              for (l = 0, d = gl(e); d > l; l++)
                if (p = b(e[l]), p && ki(_i, p))
                  return p;
              return new Fr(false);
            }
            D = Fl(e, o);
          }
          for (g = n ? e.next : D.next; !(F = vl(g, D)).done; ) {
            try {
              p = b(F.value);
            } catch (f) {
              qi(D, "throw", f);
            }
            if (typeof p == "object" && p && ki(_i, p))
              return p;
          }
          return new Fr(false);
        };
      });
      var Ti = $2((Np, Si) => {
        "use strict";
        var bl = dr(), yl = We(), wl = ar();
        Si.exports = function(e, r, u) {
          var t3 = bl(r);
          t3 in e ? yl.f(e, t3, wl(0, u)) : e[t3] = u;
        };
      });
      var Ni = $2(() => {
        var Bl = cu(), kl = Ii(), ql = Ti();
        Bl({ target: "Object", stat: true }, { fromEntries: function(r) {
          var u = {};
          return kl(r, function(t3, a) {
            ql(u, t3, a);
          }, { AS_ENTRIES: true }), u;
        } });
      });
      var uf = $2((jp, la) => {
        var _l = ["cliName", "cliCategory", "cliDescription"];
        function Ol(e, r) {
          if (e == null)
            return {};
          var u = Il(e, r), t3, a;
          if (Object.getOwnPropertySymbols) {
            var n = Object.getOwnPropertySymbols(e);
            for (a = 0; a < n.length; a++)
              t3 = n[a], !(r.indexOf(t3) >= 0) && Object.prototype.propertyIsEnumerable.call(e, t3) && (u[t3] = e[t3]);
          }
          return u;
        }
        function Il(e, r) {
          if (e == null)
            return {};
          var u = {}, t3 = Object.keys(e), a, n;
          for (n = 0; n < t3.length; n++)
            a = t3[n], !(r.indexOf(a) >= 0) && (u[a] = e[a]);
          return u;
        }
        mi();
        Ni();
        var Sl = Object.create, Ar = Object.defineProperty, Tl = Object.getOwnPropertyDescriptor, vu = Object.getOwnPropertyNames, Nl = Object.getPrototypeOf, Ll = Object.prototype.hasOwnProperty, je = (e, r) => function() {
          return e && (r = (0, e[vu(e)[0]])(e = 0)), r;
        }, S = (e, r) => function() {
          return r || (0, e[vu(e)[0]])((r = { exports: {} }).exports, r), r.exports;
        }, Pi = (e, r) => {
          for (var u in r)
            Ar(e, u, { get: r[u], enumerable: true });
        }, Mi = (e, r, u, t3) => {
          if (r && typeof r == "object" || typeof r == "function")
            for (let a of vu(r))
              !Ll.call(e, a) && a !== u && Ar(e, a, { get: () => r[a], enumerable: !(t3 = Tl(r, a)) || t3.enumerable });
          return e;
        }, Rl = (e, r, u) => (u = e != null ? Sl(Nl(e)) : {}, Mi(r || !e || !e.__esModule ? Ar(u, "default", { value: e, enumerable: true }) : u, e)), zi = (e) => Mi(Ar({}, "__esModule", { value: true }), e), Qe, I = je({ "<define:process>"() {
          Qe = { env: {}, argv: [] };
        } }), Pe = S({ "node_modules/xtend/immutable.js"(e, r) {
          I(), r.exports = t3;
          var u = Object.prototype.hasOwnProperty;
          function t3() {
            for (var a = {}, n = 0; n < arguments.length; n++) {
              var s = arguments[n];
              for (var c in s)
                u.call(s, c) && (a[c] = s[c]);
            }
            return a;
          }
        } }), jl = S({ "node_modules/inherits/inherits_browser.js"(e, r) {
          I(), typeof Object.create == "function" ? r.exports = function(t3, a) {
            a && (t3.super_ = a, t3.prototype = Object.create(a.prototype, { constructor: { value: t3, enumerable: false, writable: true, configurable: true } }));
          } : r.exports = function(t3, a) {
            if (a) {
              t3.super_ = a;
              var n = function() {
              };
              n.prototype = a.prototype, t3.prototype = new n(), t3.prototype.constructor = t3;
            }
          };
        } }), Pl = S({ "node_modules/unherit/index.js"(e, r) {
          "use strict";
          I();
          var u = Pe(), t3 = jl();
          r.exports = a;
          function a(n) {
            var s, c, i;
            t3(o, n), t3(D, o), s = o.prototype;
            for (c in s)
              i = s[c], i && typeof i == "object" && (s[c] = "concat" in i ? i.concat() : u(i));
            return o;
            function D(l) {
              return n.apply(this, l);
            }
            function o() {
              return this instanceof o ? n.apply(this, arguments) : new D(arguments);
            }
          }
        } }), Ml = S({ "node_modules/state-toggle/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a, n) {
            return s;
            function s() {
              var c = n || this, i = c[t3];
              return c[t3] = !a, D;
              function D() {
                c[t3] = i;
              }
            }
          }
        } }), zl = S({ "node_modules/vfile-location/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            for (var a = String(t3), n = [], s = /\r?\n|\r/g; s.exec(a); )
              n.push(s.lastIndex);
            return n.push(a.length + 1), { toPoint: c, toPosition: c, toOffset: i };
            function c(D) {
              var o = -1;
              if (D > -1 && D < n[n.length - 1]) {
                for (; ++o < n.length; )
                  if (n[o] > D)
                    return { line: o + 1, column: D - (n[o - 1] || 0) + 1, offset: D };
              }
              return {};
            }
            function i(D) {
              var o = D && D.line, l = D && D.column, d;
              return !isNaN(o) && !isNaN(l) && o - 1 in n && (d = (n[o - 2] || 0) + l - 1 || 0), d > -1 && d < n[n.length - 1] ? d : -1;
            }
          }
        } }), $l = S({ "node_modules/remark-parse/lib/unescape.js"(e, r) {
          "use strict";
          I(), r.exports = t3;
          var u = "\\";
          function t3(a, n) {
            return s;
            function s(c) {
              for (var i = 0, D = c.indexOf(u), o = a[n], l = [], d; D !== -1; )
                l.push(c.slice(i, D)), i = D + 1, d = c.charAt(i), (!d || o.indexOf(d) === -1) && l.push(u), D = c.indexOf(u, i + 1);
              return l.push(c.slice(i)), l.join("");
            }
          }
        } }), Ul = S({ "node_modules/character-entities-legacy/index.json"(e, r) {
          r.exports = { AElig: "\xC6", AMP: "&", Aacute: "\xC1", Acirc: "\xC2", Agrave: "\xC0", Aring: "\xC5", Atilde: "\xC3", Auml: "\xC4", COPY: "\xA9", Ccedil: "\xC7", ETH: "\xD0", Eacute: "\xC9", Ecirc: "\xCA", Egrave: "\xC8", Euml: "\xCB", GT: ">", Iacute: "\xCD", Icirc: "\xCE", Igrave: "\xCC", Iuml: "\xCF", LT: "<", Ntilde: "\xD1", Oacute: "\xD3", Ocirc: "\xD4", Ograve: "\xD2", Oslash: "\xD8", Otilde: "\xD5", Ouml: "\xD6", QUOT: '"', REG: "\xAE", THORN: "\xDE", Uacute: "\xDA", Ucirc: "\xDB", Ugrave: "\xD9", Uuml: "\xDC", Yacute: "\xDD", aacute: "\xE1", acirc: "\xE2", acute: "\xB4", aelig: "\xE6", agrave: "\xE0", amp: "&", aring: "\xE5", atilde: "\xE3", auml: "\xE4", brvbar: "\xA6", ccedil: "\xE7", cedil: "\xB8", cent: "\xA2", copy: "\xA9", curren: "\xA4", deg: "\xB0", divide: "\xF7", eacute: "\xE9", ecirc: "\xEA", egrave: "\xE8", eth: "\xF0", euml: "\xEB", frac12: "\xBD", frac14: "\xBC", frac34: "\xBE", gt: ">", iacute: "\xED", icirc: "\xEE", iexcl: "\xA1", igrave: "\xEC", iquest: "\xBF", iuml: "\xEF", laquo: "\xAB", lt: "<", macr: "\xAF", micro: "\xB5", middot: "\xB7", nbsp: "\xA0", not: "\xAC", ntilde: "\xF1", oacute: "\xF3", ocirc: "\xF4", ograve: "\xF2", ordf: "\xAA", ordm: "\xBA", oslash: "\xF8", otilde: "\xF5", ouml: "\xF6", para: "\xB6", plusmn: "\xB1", pound: "\xA3", quot: '"', raquo: "\xBB", reg: "\xAE", sect: "\xA7", shy: "\xAD", sup1: "\xB9", sup2: "\xB2", sup3: "\xB3", szlig: "\xDF", thorn: "\xFE", times: "\xD7", uacute: "\xFA", ucirc: "\xFB", ugrave: "\xF9", uml: "\xA8", uuml: "\xFC", yacute: "\xFD", yen: "\xA5", yuml: "\xFF" };
        } }), Gl = S({ "node_modules/character-reference-invalid/index.json"(e, r) {
          r.exports = { 0: "\uFFFD", 128: "\u20AC", 130: "\u201A", 131: "\u0192", 132: "\u201E", 133: "\u2026", 134: "\u2020", 135: "\u2021", 136: "\u02C6", 137: "\u2030", 138: "\u0160", 139: "\u2039", 140: "\u0152", 142: "\u017D", 145: "\u2018", 146: "\u2019", 147: "\u201C", 148: "\u201D", 149: "\u2022", 150: "\u2013", 151: "\u2014", 152: "\u02DC", 153: "\u2122", 154: "\u0161", 155: "\u203A", 156: "\u0153", 158: "\u017E", 159: "\u0178" };
        } }), Me = S({ "node_modules/is-decimal/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            var a = typeof t3 == "string" ? t3.charCodeAt(0) : t3;
            return a >= 48 && a <= 57;
          }
        } }), Vl = S({ "node_modules/is-hexadecimal/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            var a = typeof t3 == "string" ? t3.charCodeAt(0) : t3;
            return a >= 97 && a <= 102 || a >= 65 && a <= 70 || a >= 48 && a <= 57;
          }
        } }), er = S({ "node_modules/is-alphabetical/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            var a = typeof t3 == "string" ? t3.charCodeAt(0) : t3;
            return a >= 97 && a <= 122 || a >= 65 && a <= 90;
          }
        } }), Hl = S({ "node_modules/is-alphanumerical/index.js"(e, r) {
          "use strict";
          I();
          var u = er(), t3 = Me();
          r.exports = a;
          function a(n) {
            return u(n) || t3(n);
          }
        } }), Xl = S({ "node_modules/character-entities/index.json"(e, r) {
          r.exports = { AEli: "\xC6", AElig: "\xC6", AM: "&", AMP: "&", Aacut: "\xC1", Aacute: "\xC1", Abreve: "\u0102", Acir: "\xC2", Acirc: "\xC2", Acy: "\u0410", Afr: "\u{1D504}", Agrav: "\xC0", Agrave: "\xC0", Alpha: "\u0391", Amacr: "\u0100", And: "\u2A53", Aogon: "\u0104", Aopf: "\u{1D538}", ApplyFunction: "\u2061", Arin: "\xC5", Aring: "\xC5", Ascr: "\u{1D49C}", Assign: "\u2254", Atild: "\xC3", Atilde: "\xC3", Aum: "\xC4", Auml: "\xC4", Backslash: "\u2216", Barv: "\u2AE7", Barwed: "\u2306", Bcy: "\u0411", Because: "\u2235", Bernoullis: "\u212C", Beta: "\u0392", Bfr: "\u{1D505}", Bopf: "\u{1D539}", Breve: "\u02D8", Bscr: "\u212C", Bumpeq: "\u224E", CHcy: "\u0427", COP: "\xA9", COPY: "\xA9", Cacute: "\u0106", Cap: "\u22D2", CapitalDifferentialD: "\u2145", Cayleys: "\u212D", Ccaron: "\u010C", Ccedi: "\xC7", Ccedil: "\xC7", Ccirc: "\u0108", Cconint: "\u2230", Cdot: "\u010A", Cedilla: "\xB8", CenterDot: "\xB7", Cfr: "\u212D", Chi: "\u03A7", CircleDot: "\u2299", CircleMinus: "\u2296", CirclePlus: "\u2295", CircleTimes: "\u2297", ClockwiseContourIntegral: "\u2232", CloseCurlyDoubleQuote: "\u201D", CloseCurlyQuote: "\u2019", Colon: "\u2237", Colone: "\u2A74", Congruent: "\u2261", Conint: "\u222F", ContourIntegral: "\u222E", Copf: "\u2102", Coproduct: "\u2210", CounterClockwiseContourIntegral: "\u2233", Cross: "\u2A2F", Cscr: "\u{1D49E}", Cup: "\u22D3", CupCap: "\u224D", DD: "\u2145", DDotrahd: "\u2911", DJcy: "\u0402", DScy: "\u0405", DZcy: "\u040F", Dagger: "\u2021", Darr: "\u21A1", Dashv: "\u2AE4", Dcaron: "\u010E", Dcy: "\u0414", Del: "\u2207", Delta: "\u0394", Dfr: "\u{1D507}", DiacriticalAcute: "\xB4", DiacriticalDot: "\u02D9", DiacriticalDoubleAcute: "\u02DD", DiacriticalGrave: "`", DiacriticalTilde: "\u02DC", Diamond: "\u22C4", DifferentialD: "\u2146", Dopf: "\u{1D53B}", Dot: "\xA8", DotDot: "\u20DC", DotEqual: "\u2250", DoubleContourIntegral: "\u222F", DoubleDot: "\xA8", DoubleDownArrow: "\u21D3", DoubleLeftArrow: "\u21D0", DoubleLeftRightArrow: "\u21D4", DoubleLeftTee: "\u2AE4", DoubleLongLeftArrow: "\u27F8", DoubleLongLeftRightArrow: "\u27FA", DoubleLongRightArrow: "\u27F9", DoubleRightArrow: "\u21D2", DoubleRightTee: "\u22A8", DoubleUpArrow: "\u21D1", DoubleUpDownArrow: "\u21D5", DoubleVerticalBar: "\u2225", DownArrow: "\u2193", DownArrowBar: "\u2913", DownArrowUpArrow: "\u21F5", DownBreve: "\u0311", DownLeftRightVector: "\u2950", DownLeftTeeVector: "\u295E", DownLeftVector: "\u21BD", DownLeftVectorBar: "\u2956", DownRightTeeVector: "\u295F", DownRightVector: "\u21C1", DownRightVectorBar: "\u2957", DownTee: "\u22A4", DownTeeArrow: "\u21A7", Downarrow: "\u21D3", Dscr: "\u{1D49F}", Dstrok: "\u0110", ENG: "\u014A", ET: "\xD0", ETH: "\xD0", Eacut: "\xC9", Eacute: "\xC9", Ecaron: "\u011A", Ecir: "\xCA", Ecirc: "\xCA", Ecy: "\u042D", Edot: "\u0116", Efr: "\u{1D508}", Egrav: "\xC8", Egrave: "\xC8", Element: "\u2208", Emacr: "\u0112", EmptySmallSquare: "\u25FB", EmptyVerySmallSquare: "\u25AB", Eogon: "\u0118", Eopf: "\u{1D53C}", Epsilon: "\u0395", Equal: "\u2A75", EqualTilde: "\u2242", Equilibrium: "\u21CC", Escr: "\u2130", Esim: "\u2A73", Eta: "\u0397", Eum: "\xCB", Euml: "\xCB", Exists: "\u2203", ExponentialE: "\u2147", Fcy: "\u0424", Ffr: "\u{1D509}", FilledSmallSquare: "\u25FC", FilledVerySmallSquare: "\u25AA", Fopf: "\u{1D53D}", ForAll: "\u2200", Fouriertrf: "\u2131", Fscr: "\u2131", GJcy: "\u0403", G: ">", GT: ">", Gamma: "\u0393", Gammad: "\u03DC", Gbreve: "\u011E", Gcedil: "\u0122", Gcirc: "\u011C", Gcy: "\u0413", Gdot: "\u0120", Gfr: "\u{1D50A}", Gg: "\u22D9", Gopf: "\u{1D53E}", GreaterEqual: "\u2265", GreaterEqualLess: "\u22DB", GreaterFullEqual: "\u2267", GreaterGreater: "\u2AA2", GreaterLess: "\u2277", GreaterSlantEqual: "\u2A7E", GreaterTilde: "\u2273", Gscr: "\u{1D4A2}", Gt: "\u226B", HARDcy: "\u042A", Hacek: "\u02C7", Hat: "^", Hcirc: "\u0124", Hfr: "\u210C", HilbertSpace: "\u210B", Hopf: "\u210D", HorizontalLine: "\u2500", Hscr: "\u210B", Hstrok: "\u0126", HumpDownHump: "\u224E", HumpEqual: "\u224F", IEcy: "\u0415", IJlig: "\u0132", IOcy: "\u0401", Iacut: "\xCD", Iacute: "\xCD", Icir: "\xCE", Icirc: "\xCE", Icy: "\u0418", Idot: "\u0130", Ifr: "\u2111", Igrav: "\xCC", Igrave: "\xCC", Im: "\u2111", Imacr: "\u012A", ImaginaryI: "\u2148", Implies: "\u21D2", Int: "\u222C", Integral: "\u222B", Intersection: "\u22C2", InvisibleComma: "\u2063", InvisibleTimes: "\u2062", Iogon: "\u012E", Iopf: "\u{1D540}", Iota: "\u0399", Iscr: "\u2110", Itilde: "\u0128", Iukcy: "\u0406", Ium: "\xCF", Iuml: "\xCF", Jcirc: "\u0134", Jcy: "\u0419", Jfr: "\u{1D50D}", Jopf: "\u{1D541}", Jscr: "\u{1D4A5}", Jsercy: "\u0408", Jukcy: "\u0404", KHcy: "\u0425", KJcy: "\u040C", Kappa: "\u039A", Kcedil: "\u0136", Kcy: "\u041A", Kfr: "\u{1D50E}", Kopf: "\u{1D542}", Kscr: "\u{1D4A6}", LJcy: "\u0409", L: "<", LT: "<", Lacute: "\u0139", Lambda: "\u039B", Lang: "\u27EA", Laplacetrf: "\u2112", Larr: "\u219E", Lcaron: "\u013D", Lcedil: "\u013B", Lcy: "\u041B", LeftAngleBracket: "\u27E8", LeftArrow: "\u2190", LeftArrowBar: "\u21E4", LeftArrowRightArrow: "\u21C6", LeftCeiling: "\u2308", LeftDoubleBracket: "\u27E6", LeftDownTeeVector: "\u2961", LeftDownVector: "\u21C3", LeftDownVectorBar: "\u2959", LeftFloor: "\u230A", LeftRightArrow: "\u2194", LeftRightVector: "\u294E", LeftTee: "\u22A3", LeftTeeArrow: "\u21A4", LeftTeeVector: "\u295A", LeftTriangle: "\u22B2", LeftTriangleBar: "\u29CF", LeftTriangleEqual: "\u22B4", LeftUpDownVector: "\u2951", LeftUpTeeVector: "\u2960", LeftUpVector: "\u21BF", LeftUpVectorBar: "\u2958", LeftVector: "\u21BC", LeftVectorBar: "\u2952", Leftarrow: "\u21D0", Leftrightarrow: "\u21D4", LessEqualGreater: "\u22DA", LessFullEqual: "\u2266", LessGreater: "\u2276", LessLess: "\u2AA1", LessSlantEqual: "\u2A7D", LessTilde: "\u2272", Lfr: "\u{1D50F}", Ll: "\u22D8", Lleftarrow: "\u21DA", Lmidot: "\u013F", LongLeftArrow: "\u27F5", LongLeftRightArrow: "\u27F7", LongRightArrow: "\u27F6", Longleftarrow: "\u27F8", Longleftrightarrow: "\u27FA", Longrightarrow: "\u27F9", Lopf: "\u{1D543}", LowerLeftArrow: "\u2199", LowerRightArrow: "\u2198", Lscr: "\u2112", Lsh: "\u21B0", Lstrok: "\u0141", Lt: "\u226A", Map: "\u2905", Mcy: "\u041C", MediumSpace: "\u205F", Mellintrf: "\u2133", Mfr: "\u{1D510}", MinusPlus: "\u2213", Mopf: "\u{1D544}", Mscr: "\u2133", Mu: "\u039C", NJcy: "\u040A", Nacute: "\u0143", Ncaron: "\u0147", Ncedil: "\u0145", Ncy: "\u041D", NegativeMediumSpace: "\u200B", NegativeThickSpace: "\u200B", NegativeThinSpace: "\u200B", NegativeVeryThinSpace: "\u200B", NestedGreaterGreater: "\u226B", NestedLessLess: "\u226A", NewLine: `
`, Nfr: "\u{1D511}", NoBreak: "\u2060", NonBreakingSpace: "\xA0", Nopf: "\u2115", Not: "\u2AEC", NotCongruent: "\u2262", NotCupCap: "\u226D", NotDoubleVerticalBar: "\u2226", NotElement: "\u2209", NotEqual: "\u2260", NotEqualTilde: "\u2242\u0338", NotExists: "\u2204", NotGreater: "\u226F", NotGreaterEqual: "\u2271", NotGreaterFullEqual: "\u2267\u0338", NotGreaterGreater: "\u226B\u0338", NotGreaterLess: "\u2279", NotGreaterSlantEqual: "\u2A7E\u0338", NotGreaterTilde: "\u2275", NotHumpDownHump: "\u224E\u0338", NotHumpEqual: "\u224F\u0338", NotLeftTriangle: "\u22EA", NotLeftTriangleBar: "\u29CF\u0338", NotLeftTriangleEqual: "\u22EC", NotLess: "\u226E", NotLessEqual: "\u2270", NotLessGreater: "\u2278", NotLessLess: "\u226A\u0338", NotLessSlantEqual: "\u2A7D\u0338", NotLessTilde: "\u2274", NotNestedGreaterGreater: "\u2AA2\u0338", NotNestedLessLess: "\u2AA1\u0338", NotPrecedes: "\u2280", NotPrecedesEqual: "\u2AAF\u0338", NotPrecedesSlantEqual: "\u22E0", NotReverseElement: "\u220C", NotRightTriangle: "\u22EB", NotRightTriangleBar: "\u29D0\u0338", NotRightTriangleEqual: "\u22ED", NotSquareSubset: "\u228F\u0338", NotSquareSubsetEqual: "\u22E2", NotSquareSuperset: "\u2290\u0338", NotSquareSupersetEqual: "\u22E3", NotSubset: "\u2282\u20D2", NotSubsetEqual: "\u2288", NotSucceeds: "\u2281", NotSucceedsEqual: "\u2AB0\u0338", NotSucceedsSlantEqual: "\u22E1", NotSucceedsTilde: "\u227F\u0338", NotSuperset: "\u2283\u20D2", NotSupersetEqual: "\u2289", NotTilde: "\u2241", NotTildeEqual: "\u2244", NotTildeFullEqual: "\u2247", NotTildeTilde: "\u2249", NotVerticalBar: "\u2224", Nscr: "\u{1D4A9}", Ntild: "\xD1", Ntilde: "\xD1", Nu: "\u039D", OElig: "\u0152", Oacut: "\xD3", Oacute: "\xD3", Ocir: "\xD4", Ocirc: "\xD4", Ocy: "\u041E", Odblac: "\u0150", Ofr: "\u{1D512}", Ograv: "\xD2", Ograve: "\xD2", Omacr: "\u014C", Omega: "\u03A9", Omicron: "\u039F", Oopf: "\u{1D546}", OpenCurlyDoubleQuote: "\u201C", OpenCurlyQuote: "\u2018", Or: "\u2A54", Oscr: "\u{1D4AA}", Oslas: "\xD8", Oslash: "\xD8", Otild: "\xD5", Otilde: "\xD5", Otimes: "\u2A37", Oum: "\xD6", Ouml: "\xD6", OverBar: "\u203E", OverBrace: "\u23DE", OverBracket: "\u23B4", OverParenthesis: "\u23DC", PartialD: "\u2202", Pcy: "\u041F", Pfr: "\u{1D513}", Phi: "\u03A6", Pi: "\u03A0", PlusMinus: "\xB1", Poincareplane: "\u210C", Popf: "\u2119", Pr: "\u2ABB", Precedes: "\u227A", PrecedesEqual: "\u2AAF", PrecedesSlantEqual: "\u227C", PrecedesTilde: "\u227E", Prime: "\u2033", Product: "\u220F", Proportion: "\u2237", Proportional: "\u221D", Pscr: "\u{1D4AB}", Psi: "\u03A8", QUO: '"', QUOT: '"', Qfr: "\u{1D514}", Qopf: "\u211A", Qscr: "\u{1D4AC}", RBarr: "\u2910", RE: "\xAE", REG: "\xAE", Racute: "\u0154", Rang: "\u27EB", Rarr: "\u21A0", Rarrtl: "\u2916", Rcaron: "\u0158", Rcedil: "\u0156", Rcy: "\u0420", Re: "\u211C", ReverseElement: "\u220B", ReverseEquilibrium: "\u21CB", ReverseUpEquilibrium: "\u296F", Rfr: "\u211C", Rho: "\u03A1", RightAngleBracket: "\u27E9", RightArrow: "\u2192", RightArrowBar: "\u21E5", RightArrowLeftArrow: "\u21C4", RightCeiling: "\u2309", RightDoubleBracket: "\u27E7", RightDownTeeVector: "\u295D", RightDownVector: "\u21C2", RightDownVectorBar: "\u2955", RightFloor: "\u230B", RightTee: "\u22A2", RightTeeArrow: "\u21A6", RightTeeVector: "\u295B", RightTriangle: "\u22B3", RightTriangleBar: "\u29D0", RightTriangleEqual: "\u22B5", RightUpDownVector: "\u294F", RightUpTeeVector: "\u295C", RightUpVector: "\u21BE", RightUpVectorBar: "\u2954", RightVector: "\u21C0", RightVectorBar: "\u2953", Rightarrow: "\u21D2", Ropf: "\u211D", RoundImplies: "\u2970", Rrightarrow: "\u21DB", Rscr: "\u211B", Rsh: "\u21B1", RuleDelayed: "\u29F4", SHCHcy: "\u0429", SHcy: "\u0428", SOFTcy: "\u042C", Sacute: "\u015A", Sc: "\u2ABC", Scaron: "\u0160", Scedil: "\u015E", Scirc: "\u015C", Scy: "\u0421", Sfr: "\u{1D516}", ShortDownArrow: "\u2193", ShortLeftArrow: "\u2190", ShortRightArrow: "\u2192", ShortUpArrow: "\u2191", Sigma: "\u03A3", SmallCircle: "\u2218", Sopf: "\u{1D54A}", Sqrt: "\u221A", Square: "\u25A1", SquareIntersection: "\u2293", SquareSubset: "\u228F", SquareSubsetEqual: "\u2291", SquareSuperset: "\u2290", SquareSupersetEqual: "\u2292", SquareUnion: "\u2294", Sscr: "\u{1D4AE}", Star: "\u22C6", Sub: "\u22D0", Subset: "\u22D0", SubsetEqual: "\u2286", Succeeds: "\u227B", SucceedsEqual: "\u2AB0", SucceedsSlantEqual: "\u227D", SucceedsTilde: "\u227F", SuchThat: "\u220B", Sum: "\u2211", Sup: "\u22D1", Superset: "\u2283", SupersetEqual: "\u2287", Supset: "\u22D1", THOR: "\xDE", THORN: "\xDE", TRADE: "\u2122", TSHcy: "\u040B", TScy: "\u0426", Tab: "	", Tau: "\u03A4", Tcaron: "\u0164", Tcedil: "\u0162", Tcy: "\u0422", Tfr: "\u{1D517}", Therefore: "\u2234", Theta: "\u0398", ThickSpace: "\u205F\u200A", ThinSpace: "\u2009", Tilde: "\u223C", TildeEqual: "\u2243", TildeFullEqual: "\u2245", TildeTilde: "\u2248", Topf: "\u{1D54B}", TripleDot: "\u20DB", Tscr: "\u{1D4AF}", Tstrok: "\u0166", Uacut: "\xDA", Uacute: "\xDA", Uarr: "\u219F", Uarrocir: "\u2949", Ubrcy: "\u040E", Ubreve: "\u016C", Ucir: "\xDB", Ucirc: "\xDB", Ucy: "\u0423", Udblac: "\u0170", Ufr: "\u{1D518}", Ugrav: "\xD9", Ugrave: "\xD9", Umacr: "\u016A", UnderBar: "_", UnderBrace: "\u23DF", UnderBracket: "\u23B5", UnderParenthesis: "\u23DD", Union: "\u22C3", UnionPlus: "\u228E", Uogon: "\u0172", Uopf: "\u{1D54C}", UpArrow: "\u2191", UpArrowBar: "\u2912", UpArrowDownArrow: "\u21C5", UpDownArrow: "\u2195", UpEquilibrium: "\u296E", UpTee: "\u22A5", UpTeeArrow: "\u21A5", Uparrow: "\u21D1", Updownarrow: "\u21D5", UpperLeftArrow: "\u2196", UpperRightArrow: "\u2197", Upsi: "\u03D2", Upsilon: "\u03A5", Uring: "\u016E", Uscr: "\u{1D4B0}", Utilde: "\u0168", Uum: "\xDC", Uuml: "\xDC", VDash: "\u22AB", Vbar: "\u2AEB", Vcy: "\u0412", Vdash: "\u22A9", Vdashl: "\u2AE6", Vee: "\u22C1", Verbar: "\u2016", Vert: "\u2016", VerticalBar: "\u2223", VerticalLine: "|", VerticalSeparator: "\u2758", VerticalTilde: "\u2240", VeryThinSpace: "\u200A", Vfr: "\u{1D519}", Vopf: "\u{1D54D}", Vscr: "\u{1D4B1}", Vvdash: "\u22AA", Wcirc: "\u0174", Wedge: "\u22C0", Wfr: "\u{1D51A}", Wopf: "\u{1D54E}", Wscr: "\u{1D4B2}", Xfr: "\u{1D51B}", Xi: "\u039E", Xopf: "\u{1D54F}", Xscr: "\u{1D4B3}", YAcy: "\u042F", YIcy: "\u0407", YUcy: "\u042E", Yacut: "\xDD", Yacute: "\xDD", Ycirc: "\u0176", Ycy: "\u042B", Yfr: "\u{1D51C}", Yopf: "\u{1D550}", Yscr: "\u{1D4B4}", Yuml: "\u0178", ZHcy: "\u0416", Zacute: "\u0179", Zcaron: "\u017D", Zcy: "\u0417", Zdot: "\u017B", ZeroWidthSpace: "\u200B", Zeta: "\u0396", Zfr: "\u2128", Zopf: "\u2124", Zscr: "\u{1D4B5}", aacut: "\xE1", aacute: "\xE1", abreve: "\u0103", ac: "\u223E", acE: "\u223E\u0333", acd: "\u223F", acir: "\xE2", acirc: "\xE2", acut: "\xB4", acute: "\xB4", acy: "\u0430", aeli: "\xE6", aelig: "\xE6", af: "\u2061", afr: "\u{1D51E}", agrav: "\xE0", agrave: "\xE0", alefsym: "\u2135", aleph: "\u2135", alpha: "\u03B1", amacr: "\u0101", amalg: "\u2A3F", am: "&", amp: "&", and: "\u2227", andand: "\u2A55", andd: "\u2A5C", andslope: "\u2A58", andv: "\u2A5A", ang: "\u2220", ange: "\u29A4", angle: "\u2220", angmsd: "\u2221", angmsdaa: "\u29A8", angmsdab: "\u29A9", angmsdac: "\u29AA", angmsdad: "\u29AB", angmsdae: "\u29AC", angmsdaf: "\u29AD", angmsdag: "\u29AE", angmsdah: "\u29AF", angrt: "\u221F", angrtvb: "\u22BE", angrtvbd: "\u299D", angsph: "\u2222", angst: "\xC5", angzarr: "\u237C", aogon: "\u0105", aopf: "\u{1D552}", ap: "\u2248", apE: "\u2A70", apacir: "\u2A6F", ape: "\u224A", apid: "\u224B", apos: "'", approx: "\u2248", approxeq: "\u224A", arin: "\xE5", aring: "\xE5", ascr: "\u{1D4B6}", ast: "*", asymp: "\u2248", asympeq: "\u224D", atild: "\xE3", atilde: "\xE3", aum: "\xE4", auml: "\xE4", awconint: "\u2233", awint: "\u2A11", bNot: "\u2AED", backcong: "\u224C", backepsilon: "\u03F6", backprime: "\u2035", backsim: "\u223D", backsimeq: "\u22CD", barvee: "\u22BD", barwed: "\u2305", barwedge: "\u2305", bbrk: "\u23B5", bbrktbrk: "\u23B6", bcong: "\u224C", bcy: "\u0431", bdquo: "\u201E", becaus: "\u2235", because: "\u2235", bemptyv: "\u29B0", bepsi: "\u03F6", bernou: "\u212C", beta: "\u03B2", beth: "\u2136", between: "\u226C", bfr: "\u{1D51F}", bigcap: "\u22C2", bigcirc: "\u25EF", bigcup: "\u22C3", bigodot: "\u2A00", bigoplus: "\u2A01", bigotimes: "\u2A02", bigsqcup: "\u2A06", bigstar: "\u2605", bigtriangledown: "\u25BD", bigtriangleup: "\u25B3", biguplus: "\u2A04", bigvee: "\u22C1", bigwedge: "\u22C0", bkarow: "\u290D", blacklozenge: "\u29EB", blacksquare: "\u25AA", blacktriangle: "\u25B4", blacktriangledown: "\u25BE", blacktriangleleft: "\u25C2", blacktriangleright: "\u25B8", blank: "\u2423", blk12: "\u2592", blk14: "\u2591", blk34: "\u2593", block: "\u2588", bne: "=\u20E5", bnequiv: "\u2261\u20E5", bnot: "\u2310", bopf: "\u{1D553}", bot: "\u22A5", bottom: "\u22A5", bowtie: "\u22C8", boxDL: "\u2557", boxDR: "\u2554", boxDl: "\u2556", boxDr: "\u2553", boxH: "\u2550", boxHD: "\u2566", boxHU: "\u2569", boxHd: "\u2564", boxHu: "\u2567", boxUL: "\u255D", boxUR: "\u255A", boxUl: "\u255C", boxUr: "\u2559", boxV: "\u2551", boxVH: "\u256C", boxVL: "\u2563", boxVR: "\u2560", boxVh: "\u256B", boxVl: "\u2562", boxVr: "\u255F", boxbox: "\u29C9", boxdL: "\u2555", boxdR: "\u2552", boxdl: "\u2510", boxdr: "\u250C", boxh: "\u2500", boxhD: "\u2565", boxhU: "\u2568", boxhd: "\u252C", boxhu: "\u2534", boxminus: "\u229F", boxplus: "\u229E", boxtimes: "\u22A0", boxuL: "\u255B", boxuR: "\u2558", boxul: "\u2518", boxur: "\u2514", boxv: "\u2502", boxvH: "\u256A", boxvL: "\u2561", boxvR: "\u255E", boxvh: "\u253C", boxvl: "\u2524", boxvr: "\u251C", bprime: "\u2035", breve: "\u02D8", brvba: "\xA6", brvbar: "\xA6", bscr: "\u{1D4B7}", bsemi: "\u204F", bsim: "\u223D", bsime: "\u22CD", bsol: "\\", bsolb: "\u29C5", bsolhsub: "\u27C8", bull: "\u2022", bullet: "\u2022", bump: "\u224E", bumpE: "\u2AAE", bumpe: "\u224F", bumpeq: "\u224F", cacute: "\u0107", cap: "\u2229", capand: "\u2A44", capbrcup: "\u2A49", capcap: "\u2A4B", capcup: "\u2A47", capdot: "\u2A40", caps: "\u2229\uFE00", caret: "\u2041", caron: "\u02C7", ccaps: "\u2A4D", ccaron: "\u010D", ccedi: "\xE7", ccedil: "\xE7", ccirc: "\u0109", ccups: "\u2A4C", ccupssm: "\u2A50", cdot: "\u010B", cedi: "\xB8", cedil: "\xB8", cemptyv: "\u29B2", cen: "\xA2", cent: "\xA2", centerdot: "\xB7", cfr: "\u{1D520}", chcy: "\u0447", check: "\u2713", checkmark: "\u2713", chi: "\u03C7", cir: "\u25CB", cirE: "\u29C3", circ: "\u02C6", circeq: "\u2257", circlearrowleft: "\u21BA", circlearrowright: "\u21BB", circledR: "\xAE", circledS: "\u24C8", circledast: "\u229B", circledcirc: "\u229A", circleddash: "\u229D", cire: "\u2257", cirfnint: "\u2A10", cirmid: "\u2AEF", cirscir: "\u29C2", clubs: "\u2663", clubsuit: "\u2663", colon: ":", colone: "\u2254", coloneq: "\u2254", comma: ",", commat: "@", comp: "\u2201", compfn: "\u2218", complement: "\u2201", complexes: "\u2102", cong: "\u2245", congdot: "\u2A6D", conint: "\u222E", copf: "\u{1D554}", coprod: "\u2210", cop: "\xA9", copy: "\xA9", copysr: "\u2117", crarr: "\u21B5", cross: "\u2717", cscr: "\u{1D4B8}", csub: "\u2ACF", csube: "\u2AD1", csup: "\u2AD0", csupe: "\u2AD2", ctdot: "\u22EF", cudarrl: "\u2938", cudarrr: "\u2935", cuepr: "\u22DE", cuesc: "\u22DF", cularr: "\u21B6", cularrp: "\u293D", cup: "\u222A", cupbrcap: "\u2A48", cupcap: "\u2A46", cupcup: "\u2A4A", cupdot: "\u228D", cupor: "\u2A45", cups: "\u222A\uFE00", curarr: "\u21B7", curarrm: "\u293C", curlyeqprec: "\u22DE", curlyeqsucc: "\u22DF", curlyvee: "\u22CE", curlywedge: "\u22CF", curre: "\xA4", curren: "\xA4", curvearrowleft: "\u21B6", curvearrowright: "\u21B7", cuvee: "\u22CE", cuwed: "\u22CF", cwconint: "\u2232", cwint: "\u2231", cylcty: "\u232D", dArr: "\u21D3", dHar: "\u2965", dagger: "\u2020", daleth: "\u2138", darr: "\u2193", dash: "\u2010", dashv: "\u22A3", dbkarow: "\u290F", dblac: "\u02DD", dcaron: "\u010F", dcy: "\u0434", dd: "\u2146", ddagger: "\u2021", ddarr: "\u21CA", ddotseq: "\u2A77", de: "\xB0", deg: "\xB0", delta: "\u03B4", demptyv: "\u29B1", dfisht: "\u297F", dfr: "\u{1D521}", dharl: "\u21C3", dharr: "\u21C2", diam: "\u22C4", diamond: "\u22C4", diamondsuit: "\u2666", diams: "\u2666", die: "\xA8", digamma: "\u03DD", disin: "\u22F2", div: "\xF7", divid: "\xF7", divide: "\xF7", divideontimes: "\u22C7", divonx: "\u22C7", djcy: "\u0452", dlcorn: "\u231E", dlcrop: "\u230D", dollar: "$", dopf: "\u{1D555}", dot: "\u02D9", doteq: "\u2250", doteqdot: "\u2251", dotminus: "\u2238", dotplus: "\u2214", dotsquare: "\u22A1", doublebarwedge: "\u2306", downarrow: "\u2193", downdownarrows: "\u21CA", downharpoonleft: "\u21C3", downharpoonright: "\u21C2", drbkarow: "\u2910", drcorn: "\u231F", drcrop: "\u230C", dscr: "\u{1D4B9}", dscy: "\u0455", dsol: "\u29F6", dstrok: "\u0111", dtdot: "\u22F1", dtri: "\u25BF", dtrif: "\u25BE", duarr: "\u21F5", duhar: "\u296F", dwangle: "\u29A6", dzcy: "\u045F", dzigrarr: "\u27FF", eDDot: "\u2A77", eDot: "\u2251", eacut: "\xE9", eacute: "\xE9", easter: "\u2A6E", ecaron: "\u011B", ecir: "\xEA", ecirc: "\xEA", ecolon: "\u2255", ecy: "\u044D", edot: "\u0117", ee: "\u2147", efDot: "\u2252", efr: "\u{1D522}", eg: "\u2A9A", egrav: "\xE8", egrave: "\xE8", egs: "\u2A96", egsdot: "\u2A98", el: "\u2A99", elinters: "\u23E7", ell: "\u2113", els: "\u2A95", elsdot: "\u2A97", emacr: "\u0113", empty: "\u2205", emptyset: "\u2205", emptyv: "\u2205", emsp13: "\u2004", emsp14: "\u2005", emsp: "\u2003", eng: "\u014B", ensp: "\u2002", eogon: "\u0119", eopf: "\u{1D556}", epar: "\u22D5", eparsl: "\u29E3", eplus: "\u2A71", epsi: "\u03B5", epsilon: "\u03B5", epsiv: "\u03F5", eqcirc: "\u2256", eqcolon: "\u2255", eqsim: "\u2242", eqslantgtr: "\u2A96", eqslantless: "\u2A95", equals: "=", equest: "\u225F", equiv: "\u2261", equivDD: "\u2A78", eqvparsl: "\u29E5", erDot: "\u2253", erarr: "\u2971", escr: "\u212F", esdot: "\u2250", esim: "\u2242", eta: "\u03B7", et: "\xF0", eth: "\xF0", eum: "\xEB", euml: "\xEB", euro: "\u20AC", excl: "!", exist: "\u2203", expectation: "\u2130", exponentiale: "\u2147", fallingdotseq: "\u2252", fcy: "\u0444", female: "\u2640", ffilig: "\uFB03", fflig: "\uFB00", ffllig: "\uFB04", ffr: "\u{1D523}", filig: "\uFB01", fjlig: "fj", flat: "\u266D", fllig: "\uFB02", fltns: "\u25B1", fnof: "\u0192", fopf: "\u{1D557}", forall: "\u2200", fork: "\u22D4", forkv: "\u2AD9", fpartint: "\u2A0D", frac1: "\xBC", frac12: "\xBD", frac13: "\u2153", frac14: "\xBC", frac15: "\u2155", frac16: "\u2159", frac18: "\u215B", frac23: "\u2154", frac25: "\u2156", frac3: "\xBE", frac34: "\xBE", frac35: "\u2157", frac38: "\u215C", frac45: "\u2158", frac56: "\u215A", frac58: "\u215D", frac78: "\u215E", frasl: "\u2044", frown: "\u2322", fscr: "\u{1D4BB}", gE: "\u2267", gEl: "\u2A8C", gacute: "\u01F5", gamma: "\u03B3", gammad: "\u03DD", gap: "\u2A86", gbreve: "\u011F", gcirc: "\u011D", gcy: "\u0433", gdot: "\u0121", ge: "\u2265", gel: "\u22DB", geq: "\u2265", geqq: "\u2267", geqslant: "\u2A7E", ges: "\u2A7E", gescc: "\u2AA9", gesdot: "\u2A80", gesdoto: "\u2A82", gesdotol: "\u2A84", gesl: "\u22DB\uFE00", gesles: "\u2A94", gfr: "\u{1D524}", gg: "\u226B", ggg: "\u22D9", gimel: "\u2137", gjcy: "\u0453", gl: "\u2277", glE: "\u2A92", gla: "\u2AA5", glj: "\u2AA4", gnE: "\u2269", gnap: "\u2A8A", gnapprox: "\u2A8A", gne: "\u2A88", gneq: "\u2A88", gneqq: "\u2269", gnsim: "\u22E7", gopf: "\u{1D558}", grave: "`", gscr: "\u210A", gsim: "\u2273", gsime: "\u2A8E", gsiml: "\u2A90", g: ">", gt: ">", gtcc: "\u2AA7", gtcir: "\u2A7A", gtdot: "\u22D7", gtlPar: "\u2995", gtquest: "\u2A7C", gtrapprox: "\u2A86", gtrarr: "\u2978", gtrdot: "\u22D7", gtreqless: "\u22DB", gtreqqless: "\u2A8C", gtrless: "\u2277", gtrsim: "\u2273", gvertneqq: "\u2269\uFE00", gvnE: "\u2269\uFE00", hArr: "\u21D4", hairsp: "\u200A", half: "\xBD", hamilt: "\u210B", hardcy: "\u044A", harr: "\u2194", harrcir: "\u2948", harrw: "\u21AD", hbar: "\u210F", hcirc: "\u0125", hearts: "\u2665", heartsuit: "\u2665", hellip: "\u2026", hercon: "\u22B9", hfr: "\u{1D525}", hksearow: "\u2925", hkswarow: "\u2926", hoarr: "\u21FF", homtht: "\u223B", hookleftarrow: "\u21A9", hookrightarrow: "\u21AA", hopf: "\u{1D559}", horbar: "\u2015", hscr: "\u{1D4BD}", hslash: "\u210F", hstrok: "\u0127", hybull: "\u2043", hyphen: "\u2010", iacut: "\xED", iacute: "\xED", ic: "\u2063", icir: "\xEE", icirc: "\xEE", icy: "\u0438", iecy: "\u0435", iexc: "\xA1", iexcl: "\xA1", iff: "\u21D4", ifr: "\u{1D526}", igrav: "\xEC", igrave: "\xEC", ii: "\u2148", iiiint: "\u2A0C", iiint: "\u222D", iinfin: "\u29DC", iiota: "\u2129", ijlig: "\u0133", imacr: "\u012B", image: "\u2111", imagline: "\u2110", imagpart: "\u2111", imath: "\u0131", imof: "\u22B7", imped: "\u01B5", in: "\u2208", incare: "\u2105", infin: "\u221E", infintie: "\u29DD", inodot: "\u0131", int: "\u222B", intcal: "\u22BA", integers: "\u2124", intercal: "\u22BA", intlarhk: "\u2A17", intprod: "\u2A3C", iocy: "\u0451", iogon: "\u012F", iopf: "\u{1D55A}", iota: "\u03B9", iprod: "\u2A3C", iques: "\xBF", iquest: "\xBF", iscr: "\u{1D4BE}", isin: "\u2208", isinE: "\u22F9", isindot: "\u22F5", isins: "\u22F4", isinsv: "\u22F3", isinv: "\u2208", it: "\u2062", itilde: "\u0129", iukcy: "\u0456", ium: "\xEF", iuml: "\xEF", jcirc: "\u0135", jcy: "\u0439", jfr: "\u{1D527}", jmath: "\u0237", jopf: "\u{1D55B}", jscr: "\u{1D4BF}", jsercy: "\u0458", jukcy: "\u0454", kappa: "\u03BA", kappav: "\u03F0", kcedil: "\u0137", kcy: "\u043A", kfr: "\u{1D528}", kgreen: "\u0138", khcy: "\u0445", kjcy: "\u045C", kopf: "\u{1D55C}", kscr: "\u{1D4C0}", lAarr: "\u21DA", lArr: "\u21D0", lAtail: "\u291B", lBarr: "\u290E", lE: "\u2266", lEg: "\u2A8B", lHar: "\u2962", lacute: "\u013A", laemptyv: "\u29B4", lagran: "\u2112", lambda: "\u03BB", lang: "\u27E8", langd: "\u2991", langle: "\u27E8", lap: "\u2A85", laqu: "\xAB", laquo: "\xAB", larr: "\u2190", larrb: "\u21E4", larrbfs: "\u291F", larrfs: "\u291D", larrhk: "\u21A9", larrlp: "\u21AB", larrpl: "\u2939", larrsim: "\u2973", larrtl: "\u21A2", lat: "\u2AAB", latail: "\u2919", late: "\u2AAD", lates: "\u2AAD\uFE00", lbarr: "\u290C", lbbrk: "\u2772", lbrace: "{", lbrack: "[", lbrke: "\u298B", lbrksld: "\u298F", lbrkslu: "\u298D", lcaron: "\u013E", lcedil: "\u013C", lceil: "\u2308", lcub: "{", lcy: "\u043B", ldca: "\u2936", ldquo: "\u201C", ldquor: "\u201E", ldrdhar: "\u2967", ldrushar: "\u294B", ldsh: "\u21B2", le: "\u2264", leftarrow: "\u2190", leftarrowtail: "\u21A2", leftharpoondown: "\u21BD", leftharpoonup: "\u21BC", leftleftarrows: "\u21C7", leftrightarrow: "\u2194", leftrightarrows: "\u21C6", leftrightharpoons: "\u21CB", leftrightsquigarrow: "\u21AD", leftthreetimes: "\u22CB", leg: "\u22DA", leq: "\u2264", leqq: "\u2266", leqslant: "\u2A7D", les: "\u2A7D", lescc: "\u2AA8", lesdot: "\u2A7F", lesdoto: "\u2A81", lesdotor: "\u2A83", lesg: "\u22DA\uFE00", lesges: "\u2A93", lessapprox: "\u2A85", lessdot: "\u22D6", lesseqgtr: "\u22DA", lesseqqgtr: "\u2A8B", lessgtr: "\u2276", lesssim: "\u2272", lfisht: "\u297C", lfloor: "\u230A", lfr: "\u{1D529}", lg: "\u2276", lgE: "\u2A91", lhard: "\u21BD", lharu: "\u21BC", lharul: "\u296A", lhblk: "\u2584", ljcy: "\u0459", ll: "\u226A", llarr: "\u21C7", llcorner: "\u231E", llhard: "\u296B", lltri: "\u25FA", lmidot: "\u0140", lmoust: "\u23B0", lmoustache: "\u23B0", lnE: "\u2268", lnap: "\u2A89", lnapprox: "\u2A89", lne: "\u2A87", lneq: "\u2A87", lneqq: "\u2268", lnsim: "\u22E6", loang: "\u27EC", loarr: "\u21FD", lobrk: "\u27E6", longleftarrow: "\u27F5", longleftrightarrow: "\u27F7", longmapsto: "\u27FC", longrightarrow: "\u27F6", looparrowleft: "\u21AB", looparrowright: "\u21AC", lopar: "\u2985", lopf: "\u{1D55D}", loplus: "\u2A2D", lotimes: "\u2A34", lowast: "\u2217", lowbar: "_", loz: "\u25CA", lozenge: "\u25CA", lozf: "\u29EB", lpar: "(", lparlt: "\u2993", lrarr: "\u21C6", lrcorner: "\u231F", lrhar: "\u21CB", lrhard: "\u296D", lrm: "\u200E", lrtri: "\u22BF", lsaquo: "\u2039", lscr: "\u{1D4C1}", lsh: "\u21B0", lsim: "\u2272", lsime: "\u2A8D", lsimg: "\u2A8F", lsqb: "[", lsquo: "\u2018", lsquor: "\u201A", lstrok: "\u0142", l: "<", lt: "<", ltcc: "\u2AA6", ltcir: "\u2A79", ltdot: "\u22D6", lthree: "\u22CB", ltimes: "\u22C9", ltlarr: "\u2976", ltquest: "\u2A7B", ltrPar: "\u2996", ltri: "\u25C3", ltrie: "\u22B4", ltrif: "\u25C2", lurdshar: "\u294A", luruhar: "\u2966", lvertneqq: "\u2268\uFE00", lvnE: "\u2268\uFE00", mDDot: "\u223A", mac: "\xAF", macr: "\xAF", male: "\u2642", malt: "\u2720", maltese: "\u2720", map: "\u21A6", mapsto: "\u21A6", mapstodown: "\u21A7", mapstoleft: "\u21A4", mapstoup: "\u21A5", marker: "\u25AE", mcomma: "\u2A29", mcy: "\u043C", mdash: "\u2014", measuredangle: "\u2221", mfr: "\u{1D52A}", mho: "\u2127", micr: "\xB5", micro: "\xB5", mid: "\u2223", midast: "*", midcir: "\u2AF0", middo: "\xB7", middot: "\xB7", minus: "\u2212", minusb: "\u229F", minusd: "\u2238", minusdu: "\u2A2A", mlcp: "\u2ADB", mldr: "\u2026", mnplus: "\u2213", models: "\u22A7", mopf: "\u{1D55E}", mp: "\u2213", mscr: "\u{1D4C2}", mstpos: "\u223E", mu: "\u03BC", multimap: "\u22B8", mumap: "\u22B8", nGg: "\u22D9\u0338", nGt: "\u226B\u20D2", nGtv: "\u226B\u0338", nLeftarrow: "\u21CD", nLeftrightarrow: "\u21CE", nLl: "\u22D8\u0338", nLt: "\u226A\u20D2", nLtv: "\u226A\u0338", nRightarrow: "\u21CF", nVDash: "\u22AF", nVdash: "\u22AE", nabla: "\u2207", nacute: "\u0144", nang: "\u2220\u20D2", nap: "\u2249", napE: "\u2A70\u0338", napid: "\u224B\u0338", napos: "\u0149", napprox: "\u2249", natur: "\u266E", natural: "\u266E", naturals: "\u2115", nbs: "\xA0", nbsp: "\xA0", nbump: "\u224E\u0338", nbumpe: "\u224F\u0338", ncap: "\u2A43", ncaron: "\u0148", ncedil: "\u0146", ncong: "\u2247", ncongdot: "\u2A6D\u0338", ncup: "\u2A42", ncy: "\u043D", ndash: "\u2013", ne: "\u2260", neArr: "\u21D7", nearhk: "\u2924", nearr: "\u2197", nearrow: "\u2197", nedot: "\u2250\u0338", nequiv: "\u2262", nesear: "\u2928", nesim: "\u2242\u0338", nexist: "\u2204", nexists: "\u2204", nfr: "\u{1D52B}", ngE: "\u2267\u0338", nge: "\u2271", ngeq: "\u2271", ngeqq: "\u2267\u0338", ngeqslant: "\u2A7E\u0338", nges: "\u2A7E\u0338", ngsim: "\u2275", ngt: "\u226F", ngtr: "\u226F", nhArr: "\u21CE", nharr: "\u21AE", nhpar: "\u2AF2", ni: "\u220B", nis: "\u22FC", nisd: "\u22FA", niv: "\u220B", njcy: "\u045A", nlArr: "\u21CD", nlE: "\u2266\u0338", nlarr: "\u219A", nldr: "\u2025", nle: "\u2270", nleftarrow: "\u219A", nleftrightarrow: "\u21AE", nleq: "\u2270", nleqq: "\u2266\u0338", nleqslant: "\u2A7D\u0338", nles: "\u2A7D\u0338", nless: "\u226E", nlsim: "\u2274", nlt: "\u226E", nltri: "\u22EA", nltrie: "\u22EC", nmid: "\u2224", nopf: "\u{1D55F}", no: "\xAC", not: "\xAC", notin: "\u2209", notinE: "\u22F9\u0338", notindot: "\u22F5\u0338", notinva: "\u2209", notinvb: "\u22F7", notinvc: "\u22F6", notni: "\u220C", notniva: "\u220C", notnivb: "\u22FE", notnivc: "\u22FD", npar: "\u2226", nparallel: "\u2226", nparsl: "\u2AFD\u20E5", npart: "\u2202\u0338", npolint: "\u2A14", npr: "\u2280", nprcue: "\u22E0", npre: "\u2AAF\u0338", nprec: "\u2280", npreceq: "\u2AAF\u0338", nrArr: "\u21CF", nrarr: "\u219B", nrarrc: "\u2933\u0338", nrarrw: "\u219D\u0338", nrightarrow: "\u219B", nrtri: "\u22EB", nrtrie: "\u22ED", nsc: "\u2281", nsccue: "\u22E1", nsce: "\u2AB0\u0338", nscr: "\u{1D4C3}", nshortmid: "\u2224", nshortparallel: "\u2226", nsim: "\u2241", nsime: "\u2244", nsimeq: "\u2244", nsmid: "\u2224", nspar: "\u2226", nsqsube: "\u22E2", nsqsupe: "\u22E3", nsub: "\u2284", nsubE: "\u2AC5\u0338", nsube: "\u2288", nsubset: "\u2282\u20D2", nsubseteq: "\u2288", nsubseteqq: "\u2AC5\u0338", nsucc: "\u2281", nsucceq: "\u2AB0\u0338", nsup: "\u2285", nsupE: "\u2AC6\u0338", nsupe: "\u2289", nsupset: "\u2283\u20D2", nsupseteq: "\u2289", nsupseteqq: "\u2AC6\u0338", ntgl: "\u2279", ntild: "\xF1", ntilde: "\xF1", ntlg: "\u2278", ntriangleleft: "\u22EA", ntrianglelefteq: "\u22EC", ntriangleright: "\u22EB", ntrianglerighteq: "\u22ED", nu: "\u03BD", num: "#", numero: "\u2116", numsp: "\u2007", nvDash: "\u22AD", nvHarr: "\u2904", nvap: "\u224D\u20D2", nvdash: "\u22AC", nvge: "\u2265\u20D2", nvgt: ">\u20D2", nvinfin: "\u29DE", nvlArr: "\u2902", nvle: "\u2264\u20D2", nvlt: "<\u20D2", nvltrie: "\u22B4\u20D2", nvrArr: "\u2903", nvrtrie: "\u22B5\u20D2", nvsim: "\u223C\u20D2", nwArr: "\u21D6", nwarhk: "\u2923", nwarr: "\u2196", nwarrow: "\u2196", nwnear: "\u2927", oS: "\u24C8", oacut: "\xF3", oacute: "\xF3", oast: "\u229B", ocir: "\xF4", ocirc: "\xF4", ocy: "\u043E", odash: "\u229D", odblac: "\u0151", odiv: "\u2A38", odot: "\u2299", odsold: "\u29BC", oelig: "\u0153", ofcir: "\u29BF", ofr: "\u{1D52C}", ogon: "\u02DB", ograv: "\xF2", ograve: "\xF2", ogt: "\u29C1", ohbar: "\u29B5", ohm: "\u03A9", oint: "\u222E", olarr: "\u21BA", olcir: "\u29BE", olcross: "\u29BB", oline: "\u203E", olt: "\u29C0", omacr: "\u014D", omega: "\u03C9", omicron: "\u03BF", omid: "\u29B6", ominus: "\u2296", oopf: "\u{1D560}", opar: "\u29B7", operp: "\u29B9", oplus: "\u2295", or: "\u2228", orarr: "\u21BB", ord: "\xBA", order: "\u2134", orderof: "\u2134", ordf: "\xAA", ordm: "\xBA", origof: "\u22B6", oror: "\u2A56", orslope: "\u2A57", orv: "\u2A5B", oscr: "\u2134", oslas: "\xF8", oslash: "\xF8", osol: "\u2298", otild: "\xF5", otilde: "\xF5", otimes: "\u2297", otimesas: "\u2A36", oum: "\xF6", ouml: "\xF6", ovbar: "\u233D", par: "\xB6", para: "\xB6", parallel: "\u2225", parsim: "\u2AF3", parsl: "\u2AFD", part: "\u2202", pcy: "\u043F", percnt: "%", period: ".", permil: "\u2030", perp: "\u22A5", pertenk: "\u2031", pfr: "\u{1D52D}", phi: "\u03C6", phiv: "\u03D5", phmmat: "\u2133", phone: "\u260E", pi: "\u03C0", pitchfork: "\u22D4", piv: "\u03D6", planck: "\u210F", planckh: "\u210E", plankv: "\u210F", plus: "+", plusacir: "\u2A23", plusb: "\u229E", pluscir: "\u2A22", plusdo: "\u2214", plusdu: "\u2A25", pluse: "\u2A72", plusm: "\xB1", plusmn: "\xB1", plussim: "\u2A26", plustwo: "\u2A27", pm: "\xB1", pointint: "\u2A15", popf: "\u{1D561}", poun: "\xA3", pound: "\xA3", pr: "\u227A", prE: "\u2AB3", prap: "\u2AB7", prcue: "\u227C", pre: "\u2AAF", prec: "\u227A", precapprox: "\u2AB7", preccurlyeq: "\u227C", preceq: "\u2AAF", precnapprox: "\u2AB9", precneqq: "\u2AB5", precnsim: "\u22E8", precsim: "\u227E", prime: "\u2032", primes: "\u2119", prnE: "\u2AB5", prnap: "\u2AB9", prnsim: "\u22E8", prod: "\u220F", profalar: "\u232E", profline: "\u2312", profsurf: "\u2313", prop: "\u221D", propto: "\u221D", prsim: "\u227E", prurel: "\u22B0", pscr: "\u{1D4C5}", psi: "\u03C8", puncsp: "\u2008", qfr: "\u{1D52E}", qint: "\u2A0C", qopf: "\u{1D562}", qprime: "\u2057", qscr: "\u{1D4C6}", quaternions: "\u210D", quatint: "\u2A16", quest: "?", questeq: "\u225F", quo: '"', quot: '"', rAarr: "\u21DB", rArr: "\u21D2", rAtail: "\u291C", rBarr: "\u290F", rHar: "\u2964", race: "\u223D\u0331", racute: "\u0155", radic: "\u221A", raemptyv: "\u29B3", rang: "\u27E9", rangd: "\u2992", range: "\u29A5", rangle: "\u27E9", raqu: "\xBB", raquo: "\xBB", rarr: "\u2192", rarrap: "\u2975", rarrb: "\u21E5", rarrbfs: "\u2920", rarrc: "\u2933", rarrfs: "\u291E", rarrhk: "\u21AA", rarrlp: "\u21AC", rarrpl: "\u2945", rarrsim: "\u2974", rarrtl: "\u21A3", rarrw: "\u219D", ratail: "\u291A", ratio: "\u2236", rationals: "\u211A", rbarr: "\u290D", rbbrk: "\u2773", rbrace: "}", rbrack: "]", rbrke: "\u298C", rbrksld: "\u298E", rbrkslu: "\u2990", rcaron: "\u0159", rcedil: "\u0157", rceil: "\u2309", rcub: "}", rcy: "\u0440", rdca: "\u2937", rdldhar: "\u2969", rdquo: "\u201D", rdquor: "\u201D", rdsh: "\u21B3", real: "\u211C", realine: "\u211B", realpart: "\u211C", reals: "\u211D", rect: "\u25AD", re: "\xAE", reg: "\xAE", rfisht: "\u297D", rfloor: "\u230B", rfr: "\u{1D52F}", rhard: "\u21C1", rharu: "\u21C0", rharul: "\u296C", rho: "\u03C1", rhov: "\u03F1", rightarrow: "\u2192", rightarrowtail: "\u21A3", rightharpoondown: "\u21C1", rightharpoonup: "\u21C0", rightleftarrows: "\u21C4", rightleftharpoons: "\u21CC", rightrightarrows: "\u21C9", rightsquigarrow: "\u219D", rightthreetimes: "\u22CC", ring: "\u02DA", risingdotseq: "\u2253", rlarr: "\u21C4", rlhar: "\u21CC", rlm: "\u200F", rmoust: "\u23B1", rmoustache: "\u23B1", rnmid: "\u2AEE", roang: "\u27ED", roarr: "\u21FE", robrk: "\u27E7", ropar: "\u2986", ropf: "\u{1D563}", roplus: "\u2A2E", rotimes: "\u2A35", rpar: ")", rpargt: "\u2994", rppolint: "\u2A12", rrarr: "\u21C9", rsaquo: "\u203A", rscr: "\u{1D4C7}", rsh: "\u21B1", rsqb: "]", rsquo: "\u2019", rsquor: "\u2019", rthree: "\u22CC", rtimes: "\u22CA", rtri: "\u25B9", rtrie: "\u22B5", rtrif: "\u25B8", rtriltri: "\u29CE", ruluhar: "\u2968", rx: "\u211E", sacute: "\u015B", sbquo: "\u201A", sc: "\u227B", scE: "\u2AB4", scap: "\u2AB8", scaron: "\u0161", sccue: "\u227D", sce: "\u2AB0", scedil: "\u015F", scirc: "\u015D", scnE: "\u2AB6", scnap: "\u2ABA", scnsim: "\u22E9", scpolint: "\u2A13", scsim: "\u227F", scy: "\u0441", sdot: "\u22C5", sdotb: "\u22A1", sdote: "\u2A66", seArr: "\u21D8", searhk: "\u2925", searr: "\u2198", searrow: "\u2198", sec: "\xA7", sect: "\xA7", semi: ";", seswar: "\u2929", setminus: "\u2216", setmn: "\u2216", sext: "\u2736", sfr: "\u{1D530}", sfrown: "\u2322", sharp: "\u266F", shchcy: "\u0449", shcy: "\u0448", shortmid: "\u2223", shortparallel: "\u2225", sh: "\xAD", shy: "\xAD", sigma: "\u03C3", sigmaf: "\u03C2", sigmav: "\u03C2", sim: "\u223C", simdot: "\u2A6A", sime: "\u2243", simeq: "\u2243", simg: "\u2A9E", simgE: "\u2AA0", siml: "\u2A9D", simlE: "\u2A9F", simne: "\u2246", simplus: "\u2A24", simrarr: "\u2972", slarr: "\u2190", smallsetminus: "\u2216", smashp: "\u2A33", smeparsl: "\u29E4", smid: "\u2223", smile: "\u2323", smt: "\u2AAA", smte: "\u2AAC", smtes: "\u2AAC\uFE00", softcy: "\u044C", sol: "/", solb: "\u29C4", solbar: "\u233F", sopf: "\u{1D564}", spades: "\u2660", spadesuit: "\u2660", spar: "\u2225", sqcap: "\u2293", sqcaps: "\u2293\uFE00", sqcup: "\u2294", sqcups: "\u2294\uFE00", sqsub: "\u228F", sqsube: "\u2291", sqsubset: "\u228F", sqsubseteq: "\u2291", sqsup: "\u2290", sqsupe: "\u2292", sqsupset: "\u2290", sqsupseteq: "\u2292", squ: "\u25A1", square: "\u25A1", squarf: "\u25AA", squf: "\u25AA", srarr: "\u2192", sscr: "\u{1D4C8}", ssetmn: "\u2216", ssmile: "\u2323", sstarf: "\u22C6", star: "\u2606", starf: "\u2605", straightepsilon: "\u03F5", straightphi: "\u03D5", strns: "\xAF", sub: "\u2282", subE: "\u2AC5", subdot: "\u2ABD", sube: "\u2286", subedot: "\u2AC3", submult: "\u2AC1", subnE: "\u2ACB", subne: "\u228A", subplus: "\u2ABF", subrarr: "\u2979", subset: "\u2282", subseteq: "\u2286", subseteqq: "\u2AC5", subsetneq: "\u228A", subsetneqq: "\u2ACB", subsim: "\u2AC7", subsub: "\u2AD5", subsup: "\u2AD3", succ: "\u227B", succapprox: "\u2AB8", succcurlyeq: "\u227D", succeq: "\u2AB0", succnapprox: "\u2ABA", succneqq: "\u2AB6", succnsim: "\u22E9", succsim: "\u227F", sum: "\u2211", sung: "\u266A", sup: "\u2283", sup1: "\xB9", sup2: "\xB2", sup3: "\xB3", supE: "\u2AC6", supdot: "\u2ABE", supdsub: "\u2AD8", supe: "\u2287", supedot: "\u2AC4", suphsol: "\u27C9", suphsub: "\u2AD7", suplarr: "\u297B", supmult: "\u2AC2", supnE: "\u2ACC", supne: "\u228B", supplus: "\u2AC0", supset: "\u2283", supseteq: "\u2287", supseteqq: "\u2AC6", supsetneq: "\u228B", supsetneqq: "\u2ACC", supsim: "\u2AC8", supsub: "\u2AD4", supsup: "\u2AD6", swArr: "\u21D9", swarhk: "\u2926", swarr: "\u2199", swarrow: "\u2199", swnwar: "\u292A", szli: "\xDF", szlig: "\xDF", target: "\u2316", tau: "\u03C4", tbrk: "\u23B4", tcaron: "\u0165", tcedil: "\u0163", tcy: "\u0442", tdot: "\u20DB", telrec: "\u2315", tfr: "\u{1D531}", there4: "\u2234", therefore: "\u2234", theta: "\u03B8", thetasym: "\u03D1", thetav: "\u03D1", thickapprox: "\u2248", thicksim: "\u223C", thinsp: "\u2009", thkap: "\u2248", thksim: "\u223C", thor: "\xFE", thorn: "\xFE", tilde: "\u02DC", time: "\xD7", times: "\xD7", timesb: "\u22A0", timesbar: "\u2A31", timesd: "\u2A30", tint: "\u222D", toea: "\u2928", top: "\u22A4", topbot: "\u2336", topcir: "\u2AF1", topf: "\u{1D565}", topfork: "\u2ADA", tosa: "\u2929", tprime: "\u2034", trade: "\u2122", triangle: "\u25B5", triangledown: "\u25BF", triangleleft: "\u25C3", trianglelefteq: "\u22B4", triangleq: "\u225C", triangleright: "\u25B9", trianglerighteq: "\u22B5", tridot: "\u25EC", trie: "\u225C", triminus: "\u2A3A", triplus: "\u2A39", trisb: "\u29CD", tritime: "\u2A3B", trpezium: "\u23E2", tscr: "\u{1D4C9}", tscy: "\u0446", tshcy: "\u045B", tstrok: "\u0167", twixt: "\u226C", twoheadleftarrow: "\u219E", twoheadrightarrow: "\u21A0", uArr: "\u21D1", uHar: "\u2963", uacut: "\xFA", uacute: "\xFA", uarr: "\u2191", ubrcy: "\u045E", ubreve: "\u016D", ucir: "\xFB", ucirc: "\xFB", ucy: "\u0443", udarr: "\u21C5", udblac: "\u0171", udhar: "\u296E", ufisht: "\u297E", ufr: "\u{1D532}", ugrav: "\xF9", ugrave: "\xF9", uharl: "\u21BF", uharr: "\u21BE", uhblk: "\u2580", ulcorn: "\u231C", ulcorner: "\u231C", ulcrop: "\u230F", ultri: "\u25F8", umacr: "\u016B", um: "\xA8", uml: "\xA8", uogon: "\u0173", uopf: "\u{1D566}", uparrow: "\u2191", updownarrow: "\u2195", upharpoonleft: "\u21BF", upharpoonright: "\u21BE", uplus: "\u228E", upsi: "\u03C5", upsih: "\u03D2", upsilon: "\u03C5", upuparrows: "\u21C8", urcorn: "\u231D", urcorner: "\u231D", urcrop: "\u230E", uring: "\u016F", urtri: "\u25F9", uscr: "\u{1D4CA}", utdot: "\u22F0", utilde: "\u0169", utri: "\u25B5", utrif: "\u25B4", uuarr: "\u21C8", uum: "\xFC", uuml: "\xFC", uwangle: "\u29A7", vArr: "\u21D5", vBar: "\u2AE8", vBarv: "\u2AE9", vDash: "\u22A8", vangrt: "\u299C", varepsilon: "\u03F5", varkappa: "\u03F0", varnothing: "\u2205", varphi: "\u03D5", varpi: "\u03D6", varpropto: "\u221D", varr: "\u2195", varrho: "\u03F1", varsigma: "\u03C2", varsubsetneq: "\u228A\uFE00", varsubsetneqq: "\u2ACB\uFE00", varsupsetneq: "\u228B\uFE00", varsupsetneqq: "\u2ACC\uFE00", vartheta: "\u03D1", vartriangleleft: "\u22B2", vartriangleright: "\u22B3", vcy: "\u0432", vdash: "\u22A2", vee: "\u2228", veebar: "\u22BB", veeeq: "\u225A", vellip: "\u22EE", verbar: "|", vert: "|", vfr: "\u{1D533}", vltri: "\u22B2", vnsub: "\u2282\u20D2", vnsup: "\u2283\u20D2", vopf: "\u{1D567}", vprop: "\u221D", vrtri: "\u22B3", vscr: "\u{1D4CB}", vsubnE: "\u2ACB\uFE00", vsubne: "\u228A\uFE00", vsupnE: "\u2ACC\uFE00", vsupne: "\u228B\uFE00", vzigzag: "\u299A", wcirc: "\u0175", wedbar: "\u2A5F", wedge: "\u2227", wedgeq: "\u2259", weierp: "\u2118", wfr: "\u{1D534}", wopf: "\u{1D568}", wp: "\u2118", wr: "\u2240", wreath: "\u2240", wscr: "\u{1D4CC}", xcap: "\u22C2", xcirc: "\u25EF", xcup: "\u22C3", xdtri: "\u25BD", xfr: "\u{1D535}", xhArr: "\u27FA", xharr: "\u27F7", xi: "\u03BE", xlArr: "\u27F8", xlarr: "\u27F5", xmap: "\u27FC", xnis: "\u22FB", xodot: "\u2A00", xopf: "\u{1D569}", xoplus: "\u2A01", xotime: "\u2A02", xrArr: "\u27F9", xrarr: "\u27F6", xscr: "\u{1D4CD}", xsqcup: "\u2A06", xuplus: "\u2A04", xutri: "\u25B3", xvee: "\u22C1", xwedge: "\u22C0", yacut: "\xFD", yacute: "\xFD", yacy: "\u044F", ycirc: "\u0177", ycy: "\u044B", ye: "\xA5", yen: "\xA5", yfr: "\u{1D536}", yicy: "\u0457", yopf: "\u{1D56A}", yscr: "\u{1D4CE}", yucy: "\u044E", yum: "\xFF", yuml: "\xFF", zacute: "\u017A", zcaron: "\u017E", zcy: "\u0437", zdot: "\u017C", zeetrf: "\u2128", zeta: "\u03B6", zfr: "\u{1D537}", zhcy: "\u0436", zigrarr: "\u21DD", zopf: "\u{1D56B}", zscr: "\u{1D4CF}", zwj: "\u200D", zwnj: "\u200C" };
        } }), Wl = S({ "node_modules/parse-entities/decode-entity.js"(e, r) {
          "use strict";
          I();
          var u = Xl();
          r.exports = a;
          var t3 = {}.hasOwnProperty;
          function a(n) {
            return t3.call(u, n) ? u[n] : false;
          }
        } }), xr = S({ "node_modules/parse-entities/index.js"(e, r) {
          "use strict";
          I();
          var u = Ul(), t3 = Gl(), a = Me(), n = Vl(), s = Hl(), c = Wl();
          r.exports = J;
          var i = {}.hasOwnProperty, D = String.fromCharCode, o = Function.prototype, l = { warning: null, reference: null, text: null, warningContext: null, referenceContext: null, textContext: null, position: {}, additional: null, attribute: false, nonTerminated: true }, d = 9, p = 10, g = 12, F = 32, E = 38, b = 59, f = 60, x = 61, v = 35, h = 88, m = 120, C = 65533, w = "named", q = "hexadecimal", L = "decimal", B = {};
          B[q] = 16, B[L] = 10;
          var O = {};
          O[w] = s, O[L] = a, O[q] = n;
          var T = 1, P = 2, A = 3, j = 4, H = 5, G = 6, X = 7, R = {};
          R[T] = "Named character references must be terminated by a semicolon", R[P] = "Numeric character references must be terminated by a semicolon", R[A] = "Named character references cannot be empty", R[j] = "Numeric character references cannot be empty", R[H] = "Named character references must be known", R[G] = "Numeric character references cannot be disallowed", R[X] = "Numeric character references cannot be outside the permissible Unicode range";
          function J(k, y) {
            var _ = {}, N, V;
            y || (y = {});
            for (V in l)
              N = y[V], _[V] = N == null ? l[V] : N;
            return (_.position.indent || _.position.start) && (_.indent = _.position.indent || [], _.position = _.position.start), z(k, _);
          }
          function z(k, y) {
            var _ = y.additional, N = y.nonTerminated, V = y.text, W = y.reference, K = y.warning, ee = y.textContext, Y = y.referenceContext, ue = y.warningContext, le = y.position, ce = y.indent || [], te = k.length, Z = 0, Q = -1, De = le.column || 1, ye = le.line || 1, fe = "", he = [], ae, pe, ne, re, we, oe, ie, Ce, rr, br, qe, $e, _e, xe, Fu, Ue, ur, ge, se;
            for (typeof _ == "string" && (_ = _.charCodeAt(0)), Ue = Ge(), Ce = K ? Da : o, Z--, te++; ++Z < te; )
              if (we === p && (De = ce[Q] || 1), we = k.charCodeAt(Z), we === E) {
                if (ie = k.charCodeAt(Z + 1), ie === d || ie === p || ie === g || ie === F || ie === E || ie === f || ie !== ie || _ && ie === _) {
                  fe += D(we), De++;
                  continue;
                }
                for (_e = Z + 1, $e = _e, se = _e, ie === v ? (se = ++$e, ie = k.charCodeAt(se), ie === h || ie === m ? (xe = q, se = ++$e) : xe = L) : xe = w, ae = "", qe = "", re = "", Fu = O[xe], se--; ++se < te && (ie = k.charCodeAt(se), !!Fu(ie)); )
                  re += D(ie), xe === w && i.call(u, re) && (ae = re, qe = u[re]);
                ne = k.charCodeAt(se) === b, ne && (se++, pe = xe === w ? c(re) : false, pe && (ae = re, qe = pe)), ge = 1 + se - _e, !ne && !N || (re ? xe === w ? (ne && !qe ? Ce(H, 1) : (ae !== re && (se = $e + ae.length, ge = 1 + se - $e, ne = false), ne || (rr = ae ? T : A, y.attribute ? (ie = k.charCodeAt(se), ie === x ? (Ce(rr, ge), qe = null) : s(ie) ? qe = null : Ce(rr, ge)) : Ce(rr, ge))), oe = qe) : (ne || Ce(P, ge), oe = parseInt(re, B[xe]), M(oe) ? (Ce(X, ge), oe = D(C)) : oe in t3 ? (Ce(G, ge), oe = t3[oe]) : (br = "", U(oe) && Ce(G, ge), oe > 65535 && (oe -= 65536, br += D(oe >>> 10 | 55296), oe = 56320 | oe & 1023), oe = br + D(oe))) : xe !== w && Ce(j, ge)), oe ? (Au(), Ue = Ge(), Z = se - 1, De += se - _e + 1, he.push(oe), ur = Ge(), ur.offset++, W && W.call(Y, oe, { start: Ue, end: ur }, k.slice(_e - 1, se)), Ue = ur) : (re = k.slice(_e - 1, se), fe += re, De += re.length, Z = se - 1);
              } else
                we === 10 && (ye++, Q++, De = 0), we === we ? (fe += D(we), De++) : Au();
            return he.join("");
            function Ge() {
              return { line: ye, column: De, offset: Z + (le.offset || 0) };
            }
            function Da(xu, bu) {
              var yr = Ge();
              yr.column += bu, yr.offset += bu, K.call(ue, R[xu], yr, xu);
            }
            function Au() {
              fe && (he.push(fe), V && V.call(ee, fe, { start: Ue, end: Ge() }), fe = "");
            }
          }
          function M(k) {
            return k >= 55296 && k <= 57343 || k > 1114111;
          }
          function U(k) {
            return k >= 1 && k <= 8 || k === 11 || k >= 13 && k <= 31 || k >= 127 && k <= 159 || k >= 64976 && k <= 65007 || (k & 65535) === 65535 || (k & 65535) === 65534;
          }
        } }), Kl = S({ "node_modules/remark-parse/lib/decode.js"(e, r) {
          "use strict";
          I();
          var u = Pe(), t3 = xr();
          r.exports = a;
          function a(n) {
            return c.raw = i, c;
            function s(o) {
              for (var l = n.offset, d = o.line, p = []; ++d && d in l; )
                p.push((l[d] || 0) + 1);
              return { start: o, indent: p };
            }
            function c(o, l, d) {
              t3(o, { position: s(l), warning: D, text: d, reference: d, textContext: n, referenceContext: n });
            }
            function i(o, l, d) {
              return t3(o, u(d, { position: s(l), warning: D }));
            }
            function D(o, l, d) {
              d !== 3 && n.file.message(o, l);
            }
          }
        } }), Yl = S({ "node_modules/remark-parse/lib/tokenizer.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(s) {
            return c;
            function c(i, D) {
              var o = this, l = o.offset, d = [], p = o[s + "Methods"], g = o[s + "Tokenizers"], F = D.line, E = D.column, b, f, x, v, h, m;
              if (!i)
                return d;
              for (P.now = q, P.file = o.file, C(""); i; ) {
                for (b = -1, f = p.length, h = false; ++b < f && (v = p[b], x = g[v], !(x && (!x.onlyAtStart || o.atStart) && (!x.notInList || !o.inList) && (!x.notInBlock || !o.inBlock) && (!x.notInLink || !o.inLink) && (m = i.length, x.apply(o, [P, i]), h = m !== i.length, h))); )
                  ;
                h || o.file.fail(new Error("Infinite loop"), P.now());
              }
              return o.eof = q(), d;
              function C(A) {
                for (var j = -1, H = A.indexOf(`
`); H !== -1; )
                  F++, j = H, H = A.indexOf(`
`, H + 1);
                j === -1 ? E += A.length : E = A.length - j, F in l && (j !== -1 ? E += l[F] : E <= l[F] && (E = l[F] + 1));
              }
              function w() {
                var A = [], j = F + 1;
                return function() {
                  for (var H = F + 1; j < H; )
                    A.push((l[j] || 0) + 1), j++;
                  return A;
                };
              }
              function q() {
                var A = { line: F, column: E };
                return A.offset = o.toOffset(A), A;
              }
              function L(A) {
                this.start = A, this.end = q();
              }
              function B(A) {
                i.slice(0, A.length) !== A && o.file.fail(new Error("Incorrectly eaten value: please report this warning on https://git.io/vg5Ft"), q());
              }
              function O() {
                var A = q();
                return j;
                function j(H, G) {
                  var X = H.position, R = X ? X.start : A, J = [], z = X && X.end.line, M = A.line;
                  if (H.position = new L(R), X && G && X.indent) {
                    if (J = X.indent, z < M) {
                      for (; ++z < M; )
                        J.push((l[z] || 0) + 1);
                      J.push(A.column);
                    }
                    G = J.concat(G);
                  }
                  return H.position.indent = G || [], H;
                }
              }
              function T(A, j) {
                var H = j ? j.children : d, G = H[H.length - 1], X;
                return G && A.type === G.type && (A.type === "text" || A.type === "blockquote") && t3(G) && t3(A) && (X = A.type === "text" ? a : n, A = X.call(o, G, A)), A !== G && H.push(A), o.atStart && d.length !== 0 && o.exitStart(), A;
              }
              function P(A) {
                var j = w(), H = O(), G = q();
                return B(A), X.reset = R, R.test = J, X.test = J, i = i.slice(A.length), C(A), j = j(), X;
                function X(z, M) {
                  return H(T(H(z), M), j);
                }
                function R() {
                  var z = X.apply(null, arguments);
                  return F = G.line, E = G.column, i = A + i, z;
                }
                function J() {
                  var z = H({});
                  return F = G.line, E = G.column, i = A + i, z.position;
                }
              }
            }
          }
          function t3(s) {
            var c, i;
            return s.type !== "text" || !s.position ? true : (c = s.position.start, i = s.position.end, c.line !== i.line || i.column - c.column === s.value.length);
          }
          function a(s, c) {
            return s.value += c.value, s;
          }
          function n(s, c) {
            return this.options.commonmark || this.options.gfm ? c : (s.children = s.children.concat(c.children), s);
          }
        } }), Jl = S({ "node_modules/markdown-escapes/index.js"(e, r) {
          "use strict";
          I(), r.exports = n;
          var u = ["\\", "`", "*", "{", "}", "[", "]", "(", ")", "#", "+", "-", ".", "!", "_", ">"], t3 = u.concat(["~", "|"]), a = t3.concat([`
`, '"', "$", "%", "&", "'", ",", "/", ":", ";", "<", "=", "?", "@", "^"]);
          n.default = u, n.gfm = t3, n.commonmark = a;
          function n(s) {
            var c = s || {};
            return c.commonmark ? a : c.gfm ? t3 : u;
          }
        } }), Zl = S({ "node_modules/remark-parse/lib/block-elements.js"(e, r) {
          "use strict";
          I(), r.exports = ["address", "article", "aside", "base", "basefont", "blockquote", "body", "caption", "center", "col", "colgroup", "dd", "details", "dialog", "dir", "div", "dl", "dt", "fieldset", "figcaption", "figure", "footer", "form", "frame", "frameset", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "iframe", "legend", "li", "link", "main", "menu", "menuitem", "meta", "nav", "noframes", "ol", "optgroup", "option", "p", "param", "pre", "section", "source", "title", "summary", "table", "tbody", "td", "tfoot", "th", "thead", "title", "tr", "track", "ul"];
        } }), $i = S({ "node_modules/remark-parse/lib/defaults.js"(e, r) {
          "use strict";
          I(), r.exports = { position: true, gfm: true, commonmark: false, pedantic: false, blocks: Zl() };
        } }), Ql = S({ "node_modules/remark-parse/lib/set-options.js"(e, r) {
          "use strict";
          I();
          var u = Pe(), t3 = Jl(), a = $i();
          r.exports = n;
          function n(s) {
            var c = this, i = c.options, D, o;
            if (s == null)
              s = {};
            else if (typeof s == "object")
              s = u(s);
            else
              throw new Error("Invalid value `" + s + "` for setting `options`");
            for (D in a) {
              if (o = s[D], o == null && (o = i[D]), D !== "blocks" && typeof o != "boolean" || D === "blocks" && typeof o != "object")
                throw new Error("Invalid value `" + o + "` for setting `options." + D + "`");
              s[D] = o;
            }
            return c.options = s, c.escape = t3(s), c;
          }
        } }), eD = S({ "node_modules/unist-util-is/convert.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(c) {
            if (c == null)
              return s;
            if (typeof c == "string")
              return n(c);
            if (typeof c == "object")
              return "length" in c ? a(c) : t3(c);
            if (typeof c == "function")
              return c;
            throw new Error("Expected function, string, or object as test");
          }
          function t3(c) {
            return i;
            function i(D) {
              var o;
              for (o in c)
                if (D[o] !== c[o])
                  return false;
              return true;
            }
          }
          function a(c) {
            for (var i = [], D = -1; ++D < c.length; )
              i[D] = u(c[D]);
            return o;
            function o() {
              for (var l = -1; ++l < i.length; )
                if (i[l].apply(this, arguments))
                  return true;
              return false;
            }
          }
          function n(c) {
            return i;
            function i(D) {
              return Boolean(D && D.type === c);
            }
          }
          function s() {
            return true;
          }
        } }), rD = S({ "node_modules/unist-util-visit-parents/color.browser.js"(e, r) {
          I(), r.exports = u;
          function u(t3) {
            return t3;
          }
        } }), uD = S({ "node_modules/unist-util-visit-parents/index.js"(e, r) {
          "use strict";
          I(), r.exports = c;
          var u = eD(), t3 = rD(), a = true, n = "skip", s = false;
          c.CONTINUE = a, c.SKIP = n, c.EXIT = s;
          function c(D, o, l, d) {
            var p, g;
            typeof o == "function" && typeof l != "function" && (d = l, l = o, o = null), g = u(o), p = d ? -1 : 1, F(D, null, [])();
            function F(E, b, f) {
              var x = typeof E == "object" && E !== null ? E : {}, v;
              return typeof x.type == "string" && (v = typeof x.tagName == "string" ? x.tagName : typeof x.name == "string" ? x.name : void 0, h.displayName = "node (" + t3(x.type + (v ? "<" + v + ">" : "")) + ")"), h;
              function h() {
                var m = f.concat(E), C = [], w, q;
                if ((!o || g(E, b, f[f.length - 1] || null)) && (C = i(l(E, f)), C[0] === s))
                  return C;
                if (E.children && C[0] !== n)
                  for (q = (d ? E.children.length : -1) + p; q > -1 && q < E.children.length; ) {
                    if (w = F(E.children[q], q, m)(), w[0] === s)
                      return w;
                    q = typeof w[1] == "number" ? w[1] : q + p;
                  }
                return C;
              }
            }
          }
          function i(D) {
            return D !== null && typeof D == "object" && "length" in D ? D : typeof D == "number" ? [a, D] : [D];
          }
        } }), tD = S({ "node_modules/unist-util-visit/index.js"(e, r) {
          "use strict";
          I(), r.exports = s;
          var u = uD(), t3 = u.CONTINUE, a = u.SKIP, n = u.EXIT;
          s.CONTINUE = t3, s.SKIP = a, s.EXIT = n;
          function s(c, i, D, o) {
            typeof i == "function" && typeof D != "function" && (o = D, D = i, i = null), u(c, i, l, o);
            function l(d, p) {
              var g = p[p.length - 1], F = g ? g.children.indexOf(d) : null;
              return D(d, F, g);
            }
          }
        } }), nD = S({ "node_modules/unist-util-remove-position/index.js"(e, r) {
          "use strict";
          I();
          var u = tD();
          r.exports = t3;
          function t3(s, c) {
            return u(s, c ? a : n), s;
          }
          function a(s) {
            delete s.position;
          }
          function n(s) {
            s.position = void 0;
          }
        } }), iD = S({ "node_modules/remark-parse/lib/parse.js"(e, r) {
          "use strict";
          I();
          var u = Pe(), t3 = nD();
          r.exports = s;
          var a = `
`, n = /\r\n|\r/g;
          function s() {
            var c = this, i = String(c.file), D = { line: 1, column: 1, offset: 0 }, o = u(D), l;
            return i = i.replace(n, a), i.charCodeAt(0) === 65279 && (i = i.slice(1), o.column++, o.offset++), l = { type: "root", children: c.tokenizeBlock(i, o), position: { start: D, end: c.eof || u(D) } }, c.options.position || t3(l, true), l;
          }
        } }), aD = S({ "node_modules/remark-parse/lib/tokenize/blank-line.js"(e, r) {
          "use strict";
          I();
          var u = /^[ \t]*(\n|$)/;
          r.exports = t3;
          function t3(a, n, s) {
            for (var c, i = "", D = 0, o = n.length; D < o && (c = u.exec(n.slice(D)), c != null); )
              D += c[0].length, i += c[0];
            if (i !== "") {
              if (s)
                return true;
              a(i);
            }
          }
        } }), mu = S({ "node_modules/repeat-string/index.js"(e, r) {
          "use strict";
          I();
          var u = "", t3;
          r.exports = a;
          function a(n, s) {
            if (typeof n != "string")
              throw new TypeError("expected a string");
            if (s === 1)
              return n;
            if (s === 2)
              return n + n;
            var c = n.length * s;
            if (t3 !== n || typeof t3 > "u")
              t3 = n, u = "";
            else if (u.length >= c)
              return u.substr(0, c);
            for (; c > u.length && s > 1; )
              s & 1 && (u += n), s >>= 1, n += n;
            return u += n, u = u.substr(0, c), u;
          }
        } }), Ui = S({ "node_modules/trim-trailing-lines/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            return String(t3).replace(/\n+$/, "");
          }
        } }), oD = S({ "node_modules/remark-parse/lib/tokenize/code-indented.js"(e, r) {
          "use strict";
          I();
          var u = mu(), t3 = Ui();
          r.exports = D;
          var a = `
`, n = "	", s = " ", c = 4, i = u(s, c);
          function D(o, l, d) {
            for (var p = -1, g = l.length, F = "", E = "", b = "", f = "", x, v, h; ++p < g; )
              if (x = l.charAt(p), h)
                if (h = false, F += b, E += f, b = "", f = "", x === a)
                  b = x, f = x;
                else
                  for (F += x, E += x; ++p < g; ) {
                    if (x = l.charAt(p), !x || x === a) {
                      f = x, b = x;
                      break;
                    }
                    F += x, E += x;
                  }
              else if (x === s && l.charAt(p + 1) === x && l.charAt(p + 2) === x && l.charAt(p + 3) === x)
                b += i, p += 3, h = true;
              else if (x === n)
                b += x, h = true;
              else {
                for (v = ""; x === n || x === s; )
                  v += x, x = l.charAt(++p);
                if (x !== a)
                  break;
                b += v + x, f += x;
              }
            if (E)
              return d ? true : o(F)({ type: "code", lang: null, meta: null, value: t3(E) });
          }
        } }), sD = S({ "node_modules/remark-parse/lib/tokenize/code-fenced.js"(e, r) {
          "use strict";
          I(), r.exports = D;
          var u = `
`, t3 = "	", a = " ", n = "~", s = "`", c = 3, i = 4;
          function D(o, l, d) {
            var p = this, g = p.options.gfm, F = l.length + 1, E = 0, b = "", f, x, v, h, m, C, w, q, L, B, O, T, P;
            if (g) {
              for (; E < F && (v = l.charAt(E), !(v !== a && v !== t3)); )
                b += v, E++;
              if (T = E, v = l.charAt(E), !(v !== n && v !== s)) {
                for (E++, x = v, f = 1, b += v; E < F && (v = l.charAt(E), v === x); )
                  b += v, f++, E++;
                if (!(f < c)) {
                  for (; E < F && (v = l.charAt(E), !(v !== a && v !== t3)); )
                    b += v, E++;
                  for (h = "", w = ""; E < F && (v = l.charAt(E), !(v === u || x === s && v === x)); )
                    v === a || v === t3 ? w += v : (h += w + v, w = ""), E++;
                  if (v = l.charAt(E), !(v && v !== u)) {
                    if (d)
                      return true;
                    P = o.now(), P.column += b.length, P.offset += b.length, b += h, h = p.decode.raw(p.unescape(h), P), w && (b += w), w = "", B = "", O = "", q = "", L = "";
                    for (var A = true; E < F; ) {
                      if (v = l.charAt(E), q += B, L += O, B = "", O = "", v !== u) {
                        q += v, O += v, E++;
                        continue;
                      }
                      for (A ? (b += v, A = false) : (B += v, O += v), w = "", E++; E < F && (v = l.charAt(E), v === a); )
                        w += v, E++;
                      if (B += w, O += w.slice(T), !(w.length >= i)) {
                        for (w = ""; E < F && (v = l.charAt(E), v === x); )
                          w += v, E++;
                        if (B += w, O += w, !(w.length < f)) {
                          for (w = ""; E < F && (v = l.charAt(E), !(v !== a && v !== t3)); )
                            B += v, O += v, E++;
                          if (!v || v === u)
                            break;
                        }
                      }
                    }
                    for (b += q + B, E = -1, F = h.length; ++E < F; )
                      if (v = h.charAt(E), v === a || v === t3)
                        m || (m = h.slice(0, E));
                      else if (m) {
                        C = h.slice(E);
                        break;
                      }
                    return o(b)({ type: "code", lang: m || h || null, meta: C || null, value: L });
                  }
                }
              }
            }
          }
        } }), ze = S({ "node_modules/trim/index.js"(e, r) {
          I(), e = r.exports = u;
          function u(t3) {
            return t3.replace(/^\s*|\s*$/g, "");
          }
          e.left = function(t3) {
            return t3.replace(/^\s*/, "");
          }, e.right = function(t3) {
            return t3.replace(/\s*$/, "");
          };
        } }), Eu = S({ "node_modules/remark-parse/lib/util/interrupt.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a, n, s) {
            for (var c = t3.length, i = -1, D, o; ++i < c; )
              if (D = t3[i], o = D[1] || {}, !(o.pedantic !== void 0 && o.pedantic !== n.options.pedantic) && !(o.commonmark !== void 0 && o.commonmark !== n.options.commonmark) && a[D[0]].apply(n, s))
                return true;
            return false;
          }
        } }), cD = S({ "node_modules/remark-parse/lib/tokenize/blockquote.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = Eu();
          r.exports = i;
          var a = `
`, n = "	", s = " ", c = ">";
          function i(D, o, l) {
            for (var d = this, p = d.offset, g = d.blockTokenizers, F = d.interruptBlockquote, E = D.now(), b = E.line, f = o.length, x = [], v = [], h = [], m, C = 0, w, q, L, B, O, T, P, A; C < f && (w = o.charAt(C), !(w !== s && w !== n)); )
              C++;
            if (o.charAt(C) === c) {
              if (l)
                return true;
              for (C = 0; C < f; ) {
                for (L = o.indexOf(a, C), T = C, P = false, L === -1 && (L = f); C < f && (w = o.charAt(C), !(w !== s && w !== n)); )
                  C++;
                if (o.charAt(C) === c ? (C++, P = true, o.charAt(C) === s && C++) : C = T, B = o.slice(C, L), !P && !u(B)) {
                  C = T;
                  break;
                }
                if (!P && (q = o.slice(C), t3(F, g, d, [D, q, true])))
                  break;
                O = T === C ? B : o.slice(T, L), h.push(C - T), x.push(O), v.push(B), C = L + 1;
              }
              for (C = -1, f = h.length, m = D(x.join(a)); ++C < f; )
                p[b] = (p[b] || 0) + h[C], b++;
              return A = d.enterBlock(), v = d.tokenizeBlock(v.join(a), E), A(), m({ type: "blockquote", children: v });
            }
          }
        } }), lD = S({ "node_modules/remark-parse/lib/tokenize/heading-atx.js"(e, r) {
          "use strict";
          I(), r.exports = c;
          var u = `
`, t3 = "	", a = " ", n = "#", s = 6;
          function c(i, D, o) {
            for (var l = this, d = l.options.pedantic, p = D.length + 1, g = -1, F = i.now(), E = "", b = "", f, x, v; ++g < p; ) {
              if (f = D.charAt(g), f !== a && f !== t3) {
                g--;
                break;
              }
              E += f;
            }
            for (v = 0; ++g <= p; ) {
              if (f = D.charAt(g), f !== n) {
                g--;
                break;
              }
              E += f, v++;
            }
            if (!(v > s) && !(!v || !d && D.charAt(g + 1) === n)) {
              for (p = D.length + 1, x = ""; ++g < p; ) {
                if (f = D.charAt(g), f !== a && f !== t3) {
                  g--;
                  break;
                }
                x += f;
              }
              if (!(!d && x.length === 0 && f && f !== u)) {
                if (o)
                  return true;
                for (E += x, x = "", b = ""; ++g < p && (f = D.charAt(g), !(!f || f === u)); ) {
                  if (f !== a && f !== t3 && f !== n) {
                    b += x + f, x = "";
                    continue;
                  }
                  for (; f === a || f === t3; )
                    x += f, f = D.charAt(++g);
                  if (!d && b && !x && f === n) {
                    b += f;
                    continue;
                  }
                  for (; f === n; )
                    x += f, f = D.charAt(++g);
                  for (; f === a || f === t3; )
                    x += f, f = D.charAt(++g);
                  g--;
                }
                return F.column += E.length, F.offset += E.length, E += b + x, i(E)({ type: "heading", depth: v, children: l.tokenizeInline(b, F) });
              }
            }
          }
        } }), DD = S({ "node_modules/remark-parse/lib/tokenize/thematic-break.js"(e, r) {
          "use strict";
          I(), r.exports = D;
          var u = "	", t3 = `
`, a = " ", n = "*", s = "-", c = "_", i = 3;
          function D(o, l, d) {
            for (var p = -1, g = l.length + 1, F = "", E, b, f, x; ++p < g && (E = l.charAt(p), !(E !== u && E !== a)); )
              F += E;
            if (!(E !== n && E !== s && E !== c))
              for (b = E, F += E, f = 1, x = ""; ++p < g; )
                if (E = l.charAt(p), E === b)
                  f++, F += x + b, x = "";
                else if (E === a)
                  x += E;
                else
                  return f >= i && (!E || E === t3) ? (F += x, d ? true : o(F)({ type: "thematicBreak" })) : void 0;
          }
        } }), Gi = S({ "node_modules/remark-parse/lib/util/get-indentation.js"(e, r) {
          "use strict";
          I(), r.exports = s;
          var u = "	", t3 = " ", a = 1, n = 4;
          function s(c) {
            for (var i = 0, D = 0, o = c.charAt(i), l = {}, d, p = 0; o === u || o === t3; ) {
              for (d = o === u ? n : a, D += d, d > 1 && (D = Math.floor(D / d) * d); p < D; )
                l[++p] = i;
              o = c.charAt(++i);
            }
            return { indent: D, stops: l };
          }
        } }), fD = S({ "node_modules/remark-parse/lib/util/remove-indentation.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = mu(), a = Gi();
          r.exports = i;
          var n = `
`, s = " ", c = "!";
          function i(D, o) {
            var l = D.split(n), d = l.length + 1, p = 1 / 0, g = [], F, E, b;
            for (l.unshift(t3(s, o) + c); d--; )
              if (E = a(l[d]), g[d] = E.stops, u(l[d]).length !== 0)
                if (E.indent)
                  E.indent > 0 && E.indent < p && (p = E.indent);
                else {
                  p = 1 / 0;
                  break;
                }
            if (p !== 1 / 0)
              for (d = l.length; d--; ) {
                for (b = g[d], F = p; F && !(F in b); )
                  F--;
                l[d] = l[d].slice(b[F] + 1);
              }
            return l.shift(), l.join(n);
          }
        } }), pD = S({ "node_modules/remark-parse/lib/tokenize/list.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = mu(), a = Me(), n = Gi(), s = fD(), c = Eu();
          r.exports = w;
          var i = "*", D = "_", o = "+", l = "-", d = ".", p = " ", g = `
`, F = "	", E = ")", b = "x", f = 4, x = /\n\n(?!\s*$)/, v = /^\[([ X\tx])][ \t]/, h = /^([ \t]*)([*+-]|\d+[.)])( {1,4}(?! )| |\t|$|(?=\n))([^\n]*)/, m = /^([ \t]*)([*+-]|\d+[.)])([ \t]+)/, C = /^( {1,4}|\t)?/gm;
          function w(O, T, P) {
            for (var A = this, j = A.options.commonmark, H = A.options.pedantic, G = A.blockTokenizers, X = A.interruptList, R = 0, J = T.length, z = null, M, U, k, y, _, N, V, W, K, ee, Y, ue, le, ce, te, Z, Q, De, ye, fe = false, he, ae, pe, ne; R < J && (y = T.charAt(R), !(y !== F && y !== p)); )
              R++;
            if (y = T.charAt(R), y === i || y === o || y === l)
              _ = y, k = false;
            else {
              for (k = true, U = ""; R < J && (y = T.charAt(R), !!a(y)); )
                U += y, R++;
              if (y = T.charAt(R), !U || !(y === d || j && y === E) || P && U !== "1")
                return;
              z = parseInt(U, 10), _ = y;
            }
            if (y = T.charAt(++R), !(y !== p && y !== F && (H || y !== g && y !== ""))) {
              if (P)
                return true;
              for (R = 0, ce = [], te = [], Z = []; R < J; ) {
                for (N = T.indexOf(g, R), V = R, W = false, ne = false, N === -1 && (N = J), M = 0; R < J; ) {
                  if (y = T.charAt(R), y === F)
                    M += f - M % f;
                  else if (y === p)
                    M++;
                  else
                    break;
                  R++;
                }
                if (Q && M >= Q.indent && (ne = true), y = T.charAt(R), K = null, !ne) {
                  if (y === i || y === o || y === l)
                    K = y, R++, M++;
                  else {
                    for (U = ""; R < J && (y = T.charAt(R), !!a(y)); )
                      U += y, R++;
                    y = T.charAt(R), R++, U && (y === d || j && y === E) && (K = y, M += U.length + 1);
                  }
                  if (K)
                    if (y = T.charAt(R), y === F)
                      M += f - M % f, R++;
                    else if (y === p) {
                      for (pe = R + f; R < pe && T.charAt(R) === p; )
                        R++, M++;
                      R === pe && T.charAt(R) === p && (R -= f - 1, M -= f - 1);
                    } else
                      y !== g && y !== "" && (K = null);
                }
                if (K) {
                  if (!H && _ !== K)
                    break;
                  W = true;
                } else
                  !j && !ne && T.charAt(V) === p ? ne = true : j && Q && (ne = M >= Q.indent || M > f), W = false, R = V;
                if (Y = T.slice(V, N), ee = V === R ? Y : T.slice(R, N), (K === i || K === D || K === l) && G.thematicBreak.call(A, O, Y, true))
                  break;
                if (ue = le, le = !W && !u(ee).length, ne && Q)
                  Q.value = Q.value.concat(Z, Y), te = te.concat(Z, Y), Z = [];
                else if (W)
                  Z.length !== 0 && (fe = true, Q.value.push(""), Q.trail = Z.concat()), Q = { value: [Y], indent: M, trail: [] }, ce.push(Q), te = te.concat(Z, Y), Z = [];
                else if (le) {
                  if (ue && !j)
                    break;
                  Z.push(Y);
                } else {
                  if (ue || c(X, G, A, [O, Y, true]))
                    break;
                  Q.value = Q.value.concat(Z, Y), te = te.concat(Z, Y), Z = [];
                }
                R = N + 1;
              }
              for (he = O(te.join(g)).reset({ type: "list", ordered: k, start: z, spread: fe, children: [] }), De = A.enterList(), ye = A.enterBlock(), R = -1, J = ce.length; ++R < J; )
                Q = ce[R].value.join(g), ae = O.now(), O(Q)(q(A, Q, ae), he), Q = ce[R].trail.join(g), R !== J - 1 && (Q += g), O(Q);
              return De(), ye(), he;
            }
          }
          function q(O, T, P) {
            var A = O.offset, j = O.options.pedantic ? L : B, H = null, G, X;
            return T = j.apply(null, arguments), O.options.gfm && (G = T.match(v), G && (X = G[0].length, H = G[1].toLowerCase() === b, A[P.line] += X, T = T.slice(X))), { type: "listItem", spread: x.test(T), checked: H, children: O.tokenizeBlock(T, P) };
          }
          function L(O, T, P) {
            var A = O.offset, j = P.line;
            return T = T.replace(m, H), j = P.line, T.replace(C, H);
            function H(G) {
              return A[j] = (A[j] || 0) + G.length, j++, "";
            }
          }
          function B(O, T, P) {
            var A = O.offset, j = P.line, H, G, X, R, J, z, M;
            for (T = T.replace(h, U), R = T.split(g), J = s(T, n(H).indent).split(g), J[0] = X, A[j] = (A[j] || 0) + G.length, j++, z = 0, M = R.length; ++z < M; )
              A[j] = (A[j] || 0) + R[z].length - J[z].length, j++;
            return J.join(g);
            function U(k, y, _, N, V) {
              return G = y + _ + N, X = V, Number(_) < 10 && G.length % 2 === 1 && (_ = p + _), H = y + t3(p, _.length) + N, H + X;
            }
          }
        } }), dD = S({ "node_modules/remark-parse/lib/tokenize/heading-setext.js"(e, r) {
          "use strict";
          I(), r.exports = o;
          var u = `
`, t3 = "	", a = " ", n = "=", s = "-", c = 3, i = 1, D = 2;
          function o(l, d, p) {
            for (var g = this, F = l.now(), E = d.length, b = -1, f = "", x, v, h, m, C; ++b < E; ) {
              if (h = d.charAt(b), h !== a || b >= c) {
                b--;
                break;
              }
              f += h;
            }
            for (x = "", v = ""; ++b < E; ) {
              if (h = d.charAt(b), h === u) {
                b--;
                break;
              }
              h === a || h === t3 ? v += h : (x += v + h, v = "");
            }
            if (F.column += f.length, F.offset += f.length, f += x + v, h = d.charAt(++b), m = d.charAt(++b), !(h !== u || m !== n && m !== s)) {
              for (f += h, v = m, C = m === n ? i : D; ++b < E; ) {
                if (h = d.charAt(b), h !== m) {
                  if (h !== u)
                    return;
                  b--;
                  break;
                }
                v += h;
              }
              return p ? true : l(f + v)({ type: "heading", depth: C, children: g.tokenizeInline(x, F) });
            }
          }
        } }), Vi = S({ "node_modules/remark-parse/lib/util/html.js"(e) {
          "use strict";
          I();
          var r = "[a-zA-Z_:][a-zA-Z0-9:._-]*", u = "[^\"'=<>`\\u0000-\\u0020]+", t3 = "'[^']*'", a = '"[^"]*"', n = "(?:" + u + "|" + t3 + "|" + a + ")", s = "(?:\\s+" + r + "(?:\\s*=\\s*" + n + ")?)", c = "<[A-Za-z][A-Za-z0-9\\-]*" + s + "*\\s*\\/?>", i = "<\\/[A-Za-z][A-Za-z0-9\\-]*\\s*>", D = "<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->", o = "<[?].*?[?]>", l = "<![A-Za-z]+\\s+[^>]*>", d = "<!\\[CDATA\\[[\\s\\S]*?\\]\\]>";
          e.openCloseTag = new RegExp("^(?:" + c + "|" + i + ")"), e.tag = new RegExp("^(?:" + c + "|" + i + "|" + D + "|" + o + "|" + l + "|" + d + ")");
        } }), hD = S({ "node_modules/remark-parse/lib/tokenize/html-block.js"(e, r) {
          "use strict";
          I();
          var u = Vi().openCloseTag;
          r.exports = x;
          var t3 = "	", a = " ", n = `
`, s = "<", c = /^<(script|pre|style)(?=(\s|>|$))/i, i = /<\/(script|pre|style)>/i, D = /^<!--/, o = /-->/, l = /^<\?/, d = /\?>/, p = /^<![A-Za-z]/, g = />/, F = /^<!\[CDATA\[/, E = /]]>/, b = /^$/, f = new RegExp(u.source + "\\s*$");
          function x(v, h, m) {
            for (var C = this, w = C.options.blocks.join("|"), q = new RegExp("^</?(" + w + ")(?=(\\s|/?>|$))", "i"), L = h.length, B = 0, O, T, P, A, j, H, G, X = [[c, i, true], [D, o, true], [l, d, true], [p, g, true], [F, E, true], [q, b, true], [f, b, false]]; B < L && (A = h.charAt(B), !(A !== t3 && A !== a)); )
              B++;
            if (h.charAt(B) === s) {
              for (O = h.indexOf(n, B + 1), O = O === -1 ? L : O, T = h.slice(B, O), P = -1, j = X.length; ++P < j; )
                if (X[P][0].test(T)) {
                  H = X[P];
                  break;
                }
              if (H) {
                if (m)
                  return H[2];
                if (B = O, !H[1].test(T))
                  for (; B < L; ) {
                    if (O = h.indexOf(n, B + 1), O = O === -1 ? L : O, T = h.slice(B + 1, O), H[1].test(T)) {
                      T && (B = O);
                      break;
                    }
                    B = O;
                  }
                return G = h.slice(0, B), v(G)({ type: "html", value: G });
              }
            }
          }
        } }), be = S({ "node_modules/is-whitespace-character/index.js"(e, r) {
          "use strict";
          I(), r.exports = a;
          var u = String.fromCharCode, t3 = /\s/;
          function a(n) {
            return t3.test(typeof n == "number" ? u(n) : n.charAt(0));
          }
        } }), vD = S({ "node_modules/collapse-white-space/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            return String(t3).replace(/\s+/g, " ");
          }
        } }), Hi = S({ "node_modules/remark-parse/lib/util/normalize.js"(e, r) {
          "use strict";
          I();
          var u = vD();
          r.exports = t3;
          function t3(a) {
            return u(a).toLowerCase();
          }
        } }), mD = S({ "node_modules/remark-parse/lib/tokenize/definition.js"(e, r) {
          "use strict";
          I();
          var u = be(), t3 = Hi();
          r.exports = b;
          var a = '"', n = "'", s = "\\", c = `
`, i = "	", D = " ", o = "[", l = "]", d = "(", p = ")", g = ":", F = "<", E = ">";
          function b(v, h, m) {
            for (var C = this, w = C.options.commonmark, q = 0, L = h.length, B = "", O, T, P, A, j, H, G, X; q < L && (A = h.charAt(q), !(A !== D && A !== i)); )
              B += A, q++;
            if (A = h.charAt(q), A === o) {
              for (q++, B += A, P = ""; q < L && (A = h.charAt(q), A !== l); )
                A === s && (P += A, q++, A = h.charAt(q)), P += A, q++;
              if (!(!P || h.charAt(q) !== l || h.charAt(q + 1) !== g)) {
                for (H = P, B += P + l + g, q = B.length, P = ""; q < L && (A = h.charAt(q), !(A !== i && A !== D && A !== c)); )
                  B += A, q++;
                if (A = h.charAt(q), P = "", O = B, A === F) {
                  for (q++; q < L && (A = h.charAt(q), !!f(A)); )
                    P += A, q++;
                  if (A = h.charAt(q), A === f.delimiter)
                    B += F + P + A, q++;
                  else {
                    if (w)
                      return;
                    q -= P.length + 1, P = "";
                  }
                }
                if (!P) {
                  for (; q < L && (A = h.charAt(q), !!x(A)); )
                    P += A, q++;
                  B += P;
                }
                if (P) {
                  for (G = P, P = ""; q < L && (A = h.charAt(q), !(A !== i && A !== D && A !== c)); )
                    P += A, q++;
                  if (A = h.charAt(q), j = null, A === a ? j = a : A === n ? j = n : A === d && (j = p), !j)
                    P = "", q = B.length;
                  else if (P) {
                    for (B += P + A, q = B.length, P = ""; q < L && (A = h.charAt(q), A !== j); ) {
                      if (A === c) {
                        if (q++, A = h.charAt(q), A === c || A === j)
                          return;
                        P += c;
                      }
                      P += A, q++;
                    }
                    if (A = h.charAt(q), A !== j)
                      return;
                    T = B, B += P + A, q++, X = P, P = "";
                  } else
                    return;
                  for (; q < L && (A = h.charAt(q), !(A !== i && A !== D)); )
                    B += A, q++;
                  if (A = h.charAt(q), !A || A === c)
                    return m ? true : (O = v(O).test().end, G = C.decode.raw(C.unescape(G), O, { nonTerminated: false }), X && (T = v(T).test().end, X = C.decode.raw(C.unescape(X), T)), v(B)({ type: "definition", identifier: t3(H), label: H, title: X || null, url: G }));
                }
              }
            }
          }
          function f(v) {
            return v !== E && v !== o && v !== l;
          }
          f.delimiter = E;
          function x(v) {
            return v !== o && v !== l && !u(v);
          }
        } }), ED = S({ "node_modules/remark-parse/lib/tokenize/table.js"(e, r) {
          "use strict";
          I();
          var u = be();
          r.exports = F;
          var t3 = "	", a = `
`, n = " ", s = "-", c = ":", i = "\\", D = "|", o = 1, l = 2, d = "left", p = "center", g = "right";
          function F(E, b, f) {
            var x = this, v, h, m, C, w, q, L, B, O, T, P, A, j, H, G, X, R, J, z, M, U, k;
            if (x.options.gfm) {
              for (v = 0, X = 0, q = b.length + 1, L = []; v < q; ) {
                if (M = b.indexOf(a, v), U = b.indexOf(D, v + 1), M === -1 && (M = b.length), U === -1 || U > M) {
                  if (X < l)
                    return;
                  break;
                }
                L.push(b.slice(v, M)), X++, v = M + 1;
              }
              for (C = L.join(a), h = L.splice(1, 1)[0] || [], v = 0, q = h.length, X--, m = false, P = []; v < q; ) {
                if (O = h.charAt(v), O === D) {
                  if (T = null, m === false) {
                    if (k === false)
                      return;
                  } else
                    P.push(m), m = false;
                  k = false;
                } else if (O === s)
                  T = true, m = m || null;
                else if (O === c)
                  m === d ? m = p : T && m === null ? m = g : m = d;
                else if (!u(O))
                  return;
                v++;
              }
              if (m !== false && P.push(m), !(P.length < o)) {
                if (f)
                  return true;
                for (G = -1, J = [], z = E(C).reset({ type: "table", align: P, children: J }); ++G < X; ) {
                  for (R = L[G], w = { type: "tableRow", children: [] }, G && E(a), E(R).reset(w, z), q = R.length + 1, v = 0, B = "", A = "", j = true; v < q; ) {
                    if (O = R.charAt(v), O === t3 || O === n) {
                      A ? B += O : E(O), v++;
                      continue;
                    }
                    O === "" || O === D ? j ? E(O) : ((A || O) && !j && (C = A, B.length > 1 && (O ? (C += B.slice(0, -1), B = B.charAt(B.length - 1)) : (C += B, B = "")), H = E.now(), E(C)({ type: "tableCell", children: x.tokenizeInline(A, H) }, w)), E(B + O), B = "", A = "") : (B && (A += B, B = ""), A += O, O === i && v !== q - 2 && (A += R.charAt(v + 1), v++)), j = false, v++;
                  }
                  G || E(a + h);
                }
                return z;
              }
            }
          }
        } }), CD = S({ "node_modules/remark-parse/lib/tokenize/paragraph.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = Ui(), a = Eu();
          r.exports = D;
          var n = "	", s = `
`, c = " ", i = 4;
          function D(o, l, d) {
            for (var p = this, g = p.options, F = g.commonmark, E = p.blockTokenizers, b = p.interruptParagraph, f = l.indexOf(s), x = l.length, v, h, m, C, w; f < x; ) {
              if (f === -1) {
                f = x;
                break;
              }
              if (l.charAt(f + 1) === s)
                break;
              if (F) {
                for (C = 0, v = f + 1; v < x; ) {
                  if (m = l.charAt(v), m === n) {
                    C = i;
                    break;
                  } else if (m === c)
                    C++;
                  else
                    break;
                  v++;
                }
                if (C >= i && m !== s) {
                  f = l.indexOf(s, f + 1);
                  continue;
                }
              }
              if (h = l.slice(f + 1), a(b, E, p, [o, h, true]))
                break;
              if (v = f, f = l.indexOf(s, f + 1), f !== -1 && u(l.slice(v, f)) === "") {
                f = v;
                break;
              }
            }
            return h = l.slice(0, f), d ? true : (w = o.now(), h = t3(h), o(h)({ type: "paragraph", children: p.tokenizeInline(h, w) }));
          }
        } }), gD = S({ "node_modules/remark-parse/lib/locate/escape.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            return t3.indexOf("\\", a);
          }
        } }), FD = S({ "node_modules/remark-parse/lib/tokenize/escape.js"(e, r) {
          "use strict";
          I();
          var u = gD();
          r.exports = n, n.locator = u;
          var t3 = `
`, a = "\\";
          function n(s, c, i) {
            var D = this, o, l;
            if (c.charAt(0) === a && (o = c.charAt(1), D.escape.indexOf(o) !== -1))
              return i ? true : (o === t3 ? l = { type: "break" } : l = { type: "text", value: o }, s(a + o)(l));
          }
        } }), Xi = S({ "node_modules/remark-parse/lib/locate/tag.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            return t3.indexOf("<", a);
          }
        } }), AD = S({ "node_modules/remark-parse/lib/tokenize/auto-link.js"(e, r) {
          "use strict";
          I();
          var u = be(), t3 = xr(), a = Xi();
          r.exports = l, l.locator = a, l.notInLink = true;
          var n = "<", s = ">", c = "@", i = "/", D = "mailto:", o = D.length;
          function l(d, p, g) {
            var F = this, E = "", b = p.length, f = 0, x = "", v = false, h = "", m, C, w, q, L;
            if (p.charAt(0) === n) {
              for (f++, E = n; f < b && (m = p.charAt(f), !(u(m) || m === s || m === c || m === ":" && p.charAt(f + 1) === i)); )
                x += m, f++;
              if (x) {
                if (h += x, x = "", m = p.charAt(f), h += m, f++, m === c)
                  v = true;
                else {
                  if (m !== ":" || p.charAt(f + 1) !== i)
                    return;
                  h += i, f++;
                }
                for (; f < b && (m = p.charAt(f), !(u(m) || m === s)); )
                  x += m, f++;
                if (m = p.charAt(f), !(!x || m !== s))
                  return g ? true : (h += x, w = h, E += h + m, C = d.now(), C.column++, C.offset++, v && (h.slice(0, o).toLowerCase() === D ? (w = w.slice(o), C.column += o, C.offset += o) : h = D + h), q = F.inlineTokenizers, F.inlineTokenizers = { text: q.text }, L = F.enterLink(), w = F.tokenizeInline(w, C), F.inlineTokenizers = q, L(), d(E)({ type: "link", title: null, url: t3(h, { nonTerminated: false }), children: w }));
              }
            }
          }
        } }), xD = S({ "node_modules/ccount/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            var n = String(t3), s = 0, c;
            if (typeof a != "string")
              throw new Error("Expected character");
            for (c = n.indexOf(a); c !== -1; )
              s++, c = n.indexOf(a, c + a.length);
            return s;
          }
        } }), bD = S({ "node_modules/remark-parse/lib/locate/url.js"(e, r) {
          "use strict";
          I(), r.exports = t3;
          var u = ["www.", "http://", "https://"];
          function t3(a, n) {
            var s = -1, c, i, D;
            if (!this.options.gfm)
              return s;
            for (i = u.length, c = -1; ++c < i; )
              D = a.indexOf(u[c], n), D !== -1 && (s === -1 || D < s) && (s = D);
            return s;
          }
        } }), yD = S({ "node_modules/remark-parse/lib/tokenize/url.js"(e, r) {
          "use strict";
          I();
          var u = xD(), t3 = xr(), a = Me(), n = er(), s = be(), c = bD();
          r.exports = C, C.locator = c, C.notInLink = true;
          var i = 33, D = 38, o = 41, l = 42, d = 44, p = 45, g = 46, F = 58, E = 59, b = 63, f = 60, x = 95, v = 126, h = "(", m = ")";
          function C(w, q, L) {
            var B = this, O = B.options.gfm, T = B.inlineTokenizers, P = q.length, A = -1, j = false, H, G, X, R, J, z, M, U, k, y, _, N, V, W;
            if (O) {
              if (q.slice(0, 4) === "www.")
                j = true, R = 4;
              else if (q.slice(0, 7).toLowerCase() === "http://")
                R = 7;
              else if (q.slice(0, 8).toLowerCase() === "https://")
                R = 8;
              else
                return;
              for (A = R - 1, X = R, H = []; R < P; ) {
                if (M = q.charCodeAt(R), M === g) {
                  if (A === R - 1)
                    break;
                  H.push(R), A = R, R++;
                  continue;
                }
                if (a(M) || n(M) || M === p || M === x) {
                  R++;
                  continue;
                }
                break;
              }
              if (M === g && (H.pop(), R--), H[0] !== void 0 && (G = H.length < 2 ? X : H[H.length - 2] + 1, q.slice(G, R).indexOf("_") === -1)) {
                if (L)
                  return true;
                for (U = R, J = R; R < P && (M = q.charCodeAt(R), !(s(M) || M === f)); )
                  R++, M === i || M === l || M === d || M === g || M === F || M === b || M === x || M === v || (U = R);
                if (R = U, q.charCodeAt(R - 1) === o)
                  for (z = q.slice(J, R), k = u(z, h), y = u(z, m); y > k; )
                    R = J + z.lastIndexOf(m), z = q.slice(J, R), y--;
                if (q.charCodeAt(R - 1) === E && (R--, n(q.charCodeAt(R - 1)))) {
                  for (U = R - 2; n(q.charCodeAt(U)); )
                    U--;
                  q.charCodeAt(U) === D && (R = U);
                }
                return _ = q.slice(0, R), V = t3(_, { nonTerminated: false }), j && (V = "http://" + V), W = B.enterLink(), B.inlineTokenizers = { text: T.text }, N = B.tokenizeInline(_, w.now()), B.inlineTokenizers = T, W(), w(_)({ type: "link", title: null, url: V, children: N });
              }
            }
          }
        } }), wD = S({ "node_modules/remark-parse/lib/locate/email.js"(e, r) {
          "use strict";
          I();
          var u = Me(), t3 = er(), a = 43, n = 45, s = 46, c = 95;
          r.exports = i;
          function i(o, l) {
            var d = this, p, g;
            if (!this.options.gfm || (p = o.indexOf("@", l), p === -1))
              return -1;
            if (g = p, g === l || !D(o.charCodeAt(g - 1)))
              return i.call(d, o, p + 1);
            for (; g > l && D(o.charCodeAt(g - 1)); )
              g--;
            return g;
          }
          function D(o) {
            return u(o) || t3(o) || o === a || o === n || o === s || o === c;
          }
        } }), BD = S({ "node_modules/remark-parse/lib/tokenize/email.js"(e, r) {
          "use strict";
          I();
          var u = xr(), t3 = Me(), a = er(), n = wD();
          r.exports = l, l.locator = n, l.notInLink = true;
          var s = 43, c = 45, i = 46, D = 64, o = 95;
          function l(d, p, g) {
            var F = this, E = F.options.gfm, b = F.inlineTokenizers, f = 0, x = p.length, v = -1, h, m, C, w;
            if (E) {
              for (h = p.charCodeAt(f); t3(h) || a(h) || h === s || h === c || h === i || h === o; )
                h = p.charCodeAt(++f);
              if (f !== 0 && h === D) {
                for (f++; f < x; ) {
                  if (h = p.charCodeAt(f), t3(h) || a(h) || h === c || h === i || h === o) {
                    f++, v === -1 && h === i && (v = f);
                    continue;
                  }
                  break;
                }
                if (!(v === -1 || v === f || h === c || h === o))
                  return h === i && f--, m = p.slice(0, f), g ? true : (w = F.enterLink(), F.inlineTokenizers = { text: b.text }, C = F.tokenizeInline(m, d.now()), F.inlineTokenizers = b, w(), d(m)({ type: "link", title: null, url: "mailto:" + u(m, { nonTerminated: false }), children: C }));
              }
            }
          }
        } }), kD = S({ "node_modules/remark-parse/lib/tokenize/html-inline.js"(e, r) {
          "use strict";
          I();
          var u = er(), t3 = Xi(), a = Vi().tag;
          r.exports = l, l.locator = t3;
          var n = "<", s = "?", c = "!", i = "/", D = /^<a /i, o = /^<\/a>/i;
          function l(d, p, g) {
            var F = this, E = p.length, b, f;
            if (!(p.charAt(0) !== n || E < 3) && (b = p.charAt(1), !(!u(b) && b !== s && b !== c && b !== i) && (f = p.match(a), !!f)))
              return g ? true : (f = f[0], !F.inLink && D.test(f) ? F.inLink = true : F.inLink && o.test(f) && (F.inLink = false), d(f)({ type: "html", value: f }));
          }
        } }), Wi = S({ "node_modules/remark-parse/lib/locate/link.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            var n = t3.indexOf("[", a), s = t3.indexOf("![", a);
            return s === -1 || n < s ? n : s;
          }
        } }), qD = S({ "node_modules/remark-parse/lib/tokenize/link.js"(e, r) {
          "use strict";
          I();
          var u = be(), t3 = Wi();
          r.exports = E, E.locator = t3;
          var a = `
`, n = "!", s = '"', c = "'", i = "(", D = ")", o = "<", l = ">", d = "[", p = "\\", g = "]", F = "`";
          function E(b, f, x) {
            var v = this, h = "", m = 0, C = f.charAt(0), w = v.options.pedantic, q = v.options.commonmark, L = v.options.gfm, B, O, T, P, A, j, H, G, X, R, J, z, M, U, k, y, _, N;
            if (C === n && (G = true, h = C, C = f.charAt(++m)), C === d && !(!G && v.inLink)) {
              for (h += C, U = "", m++, J = f.length, y = b.now(), M = 0, y.column += m, y.offset += m; m < J; ) {
                if (C = f.charAt(m), j = C, C === F) {
                  for (O = 1; f.charAt(m + 1) === F; )
                    j += C, m++, O++;
                  T ? O >= T && (T = 0) : T = O;
                } else if (C === p)
                  m++, j += f.charAt(m);
                else if ((!T || L) && C === d)
                  M++;
                else if ((!T || L) && C === g)
                  if (M)
                    M--;
                  else {
                    if (f.charAt(m + 1) !== i)
                      return;
                    j += i, B = true, m++;
                    break;
                  }
                U += j, j = "", m++;
              }
              if (B) {
                for (X = U, h += U + j, m++; m < J && (C = f.charAt(m), !!u(C)); )
                  h += C, m++;
                if (C = f.charAt(m), U = "", P = h, C === o) {
                  for (m++, P += o; m < J && (C = f.charAt(m), C !== l); ) {
                    if (q && C === a)
                      return;
                    U += C, m++;
                  }
                  if (f.charAt(m) !== l)
                    return;
                  h += o + U + l, k = U, m++;
                } else {
                  for (C = null, j = ""; m < J && (C = f.charAt(m), !(j && (C === s || C === c || q && C === i))); ) {
                    if (u(C)) {
                      if (!w)
                        break;
                      j += C;
                    } else {
                      if (C === i)
                        M++;
                      else if (C === D) {
                        if (M === 0)
                          break;
                        M--;
                      }
                      U += j, j = "", C === p && (U += p, C = f.charAt(++m)), U += C;
                    }
                    m++;
                  }
                  h += U, k = U, m = h.length;
                }
                for (U = ""; m < J && (C = f.charAt(m), !!u(C)); )
                  U += C, m++;
                if (C = f.charAt(m), h += U, U && (C === s || C === c || q && C === i))
                  if (m++, h += C, U = "", R = C === i ? D : C, A = h, q) {
                    for (; m < J && (C = f.charAt(m), C !== R); )
                      C === p && (U += p, C = f.charAt(++m)), m++, U += C;
                    if (C = f.charAt(m), C !== R)
                      return;
                    for (z = U, h += U + C, m++; m < J && (C = f.charAt(m), !!u(C)); )
                      h += C, m++;
                  } else
                    for (j = ""; m < J; ) {
                      if (C = f.charAt(m), C === R)
                        H && (U += R + j, j = ""), H = true;
                      else if (!H)
                        U += C;
                      else if (C === D) {
                        h += U + R + j, z = U;
                        break;
                      } else
                        u(C) ? j += C : (U += R + j + C, j = "", H = false);
                      m++;
                    }
                if (f.charAt(m) === D)
                  return x ? true : (h += D, k = v.decode.raw(v.unescape(k), b(P).test().end, { nonTerminated: false }), z && (A = b(A).test().end, z = v.decode.raw(v.unescape(z), A)), N = { type: G ? "image" : "link", title: z || null, url: k }, G ? N.alt = v.decode.raw(v.unescape(X), y) || null : (_ = v.enterLink(), N.children = v.tokenizeInline(X, y), _()), b(h)(N));
              }
            }
          }
        } }), _D = S({ "node_modules/remark-parse/lib/tokenize/reference.js"(e, r) {
          "use strict";
          I();
          var u = be(), t3 = Wi(), a = Hi();
          r.exports = g, g.locator = t3;
          var n = "link", s = "image", c = "shortcut", i = "collapsed", D = "full", o = "!", l = "[", d = "\\", p = "]";
          function g(F, E, b) {
            var f = this, x = f.options.commonmark, v = E.charAt(0), h = 0, m = E.length, C = "", w = "", q = n, L = c, B, O, T, P, A, j, H, G;
            if (v === o && (q = s, w = v, v = E.charAt(++h)), v === l) {
              for (h++, w += v, j = "", G = 0; h < m; ) {
                if (v = E.charAt(h), v === l)
                  H = true, G++;
                else if (v === p) {
                  if (!G)
                    break;
                  G--;
                }
                v === d && (j += d, v = E.charAt(++h)), j += v, h++;
              }
              if (C = j, B = j, v = E.charAt(h), v === p) {
                if (h++, C += v, j = "", !x)
                  for (; h < m && (v = E.charAt(h), !!u(v)); )
                    j += v, h++;
                if (v = E.charAt(h), v === l) {
                  for (O = "", j += v, h++; h < m && (v = E.charAt(h), !(v === l || v === p)); )
                    v === d && (O += d, v = E.charAt(++h)), O += v, h++;
                  v = E.charAt(h), v === p ? (L = O ? D : i, j += O + v, h++) : O = "", C += j, j = "";
                } else {
                  if (!B)
                    return;
                  O = B;
                }
                if (!(L !== D && H))
                  return C = w + C, q === n && f.inLink ? null : b ? true : (T = F.now(), T.column += w.length, T.offset += w.length, O = L === D ? O : B, P = { type: q + "Reference", identifier: a(O), label: O, referenceType: L }, q === n ? (A = f.enterLink(), P.children = f.tokenizeInline(B, T), A()) : P.alt = f.decode.raw(f.unescape(B), T) || null, F(C)(P));
              }
            }
          }
        } }), OD = S({ "node_modules/remark-parse/lib/locate/strong.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            var n = t3.indexOf("**", a), s = t3.indexOf("__", a);
            return s === -1 ? n : n === -1 || s < n ? s : n;
          }
        } }), ID = S({ "node_modules/remark-parse/lib/tokenize/strong.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = be(), a = OD();
          r.exports = i, i.locator = a;
          var n = "\\", s = "*", c = "_";
          function i(D, o, l) {
            var d = this, p = 0, g = o.charAt(p), F, E, b, f, x, v, h;
            if (!(g !== s && g !== c || o.charAt(++p) !== g) && (E = d.options.pedantic, b = g, x = b + b, v = o.length, p++, f = "", g = "", !(E && t3(o.charAt(p)))))
              for (; p < v; ) {
                if (h = g, g = o.charAt(p), g === b && o.charAt(p + 1) === b && (!E || !t3(h)) && (g = o.charAt(p + 2), g !== b))
                  return u(f) ? l ? true : (F = D.now(), F.column += 2, F.offset += 2, D(x + f + x)({ type: "strong", children: d.tokenizeInline(f, F) })) : void 0;
                !E && g === n && (f += g, g = o.charAt(++p)), f += g, p++;
              }
          }
        } }), SD = S({ "node_modules/is-word-character/index.js"(e, r) {
          "use strict";
          I(), r.exports = a;
          var u = String.fromCharCode, t3 = /\w/;
          function a(n) {
            return t3.test(typeof n == "number" ? u(n) : n.charAt(0));
          }
        } }), TD = S({ "node_modules/remark-parse/lib/locate/emphasis.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            var n = t3.indexOf("*", a), s = t3.indexOf("_", a);
            return s === -1 ? n : n === -1 || s < n ? s : n;
          }
        } }), ND = S({ "node_modules/remark-parse/lib/tokenize/emphasis.js"(e, r) {
          "use strict";
          I();
          var u = ze(), t3 = SD(), a = be(), n = TD();
          r.exports = D, D.locator = n;
          var s = "*", c = "_", i = "\\";
          function D(o, l, d) {
            var p = this, g = 0, F = l.charAt(g), E, b, f, x, v, h, m;
            if (!(F !== s && F !== c) && (b = p.options.pedantic, v = F, f = F, h = l.length, g++, x = "", F = "", !(b && a(l.charAt(g)))))
              for (; g < h; ) {
                if (m = F, F = l.charAt(g), F === f && (!b || !a(m))) {
                  if (F = l.charAt(++g), F !== f) {
                    if (!u(x) || m === f)
                      return;
                    if (!b && f === c && t3(F)) {
                      x += f;
                      continue;
                    }
                    return d ? true : (E = o.now(), E.column++, E.offset++, o(v + x + f)({ type: "emphasis", children: p.tokenizeInline(x, E) }));
                  }
                  x += f;
                }
                !b && F === i && (x += F, F = l.charAt(++g)), x += F, g++;
              }
          }
        } }), LD = S({ "node_modules/remark-parse/lib/locate/delete.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            return t3.indexOf("~~", a);
          }
        } }), RD = S({ "node_modules/remark-parse/lib/tokenize/delete.js"(e, r) {
          "use strict";
          I();
          var u = be(), t3 = LD();
          r.exports = s, s.locator = t3;
          var a = "~", n = "~~";
          function s(c, i, D) {
            var o = this, l = "", d = "", p = "", g = "", F, E, b;
            if (!(!o.options.gfm || i.charAt(0) !== a || i.charAt(1) !== a || u(i.charAt(2))))
              for (F = 1, E = i.length, b = c.now(), b.column += 2, b.offset += 2; ++F < E; ) {
                if (l = i.charAt(F), l === a && d === a && (!p || !u(p)))
                  return D ? true : c(n + g + n)({ type: "delete", children: o.tokenizeInline(g, b) });
                g += d, p = d, d = l;
              }
          }
        } }), jD = S({ "node_modules/remark-parse/lib/locate/code-inline.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            return t3.indexOf("`", a);
          }
        } }), PD = S({ "node_modules/remark-parse/lib/tokenize/code-inline.js"(e, r) {
          "use strict";
          I();
          var u = jD();
          r.exports = s, s.locator = u;
          var t3 = 10, a = 32, n = 96;
          function s(c, i, D) {
            for (var o = i.length, l = 0, d, p, g, F, E, b; l < o && i.charCodeAt(l) === n; )
              l++;
            if (!(l === 0 || l === o)) {
              for (d = l, E = i.charCodeAt(l); l < o; ) {
                if (F = E, E = i.charCodeAt(l + 1), F === n) {
                  if (p === void 0 && (p = l), g = l + 1, E !== n && g - p === d) {
                    b = true;
                    break;
                  }
                } else
                  p !== void 0 && (p = void 0, g = void 0);
                l++;
              }
              if (b) {
                if (D)
                  return true;
                if (l = d, o = p, F = i.charCodeAt(l), E = i.charCodeAt(o - 1), b = false, o - l > 2 && (F === a || F === t3) && (E === a || E === t3)) {
                  for (l++, o--; l < o; ) {
                    if (F = i.charCodeAt(l), F !== a && F !== t3) {
                      b = true;
                      break;
                    }
                    l++;
                  }
                  b === true && (d++, p--);
                }
                return c(i.slice(0, g))({ type: "inlineCode", value: i.slice(d, p) });
              }
            }
          }
        } }), MD = S({ "node_modules/remark-parse/lib/locate/break.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a) {
            for (var n = t3.indexOf(`
`, a); n > a && t3.charAt(n - 1) === " "; )
              n--;
            return n;
          }
        } }), zD = S({ "node_modules/remark-parse/lib/tokenize/break.js"(e, r) {
          "use strict";
          I();
          var u = MD();
          r.exports = s, s.locator = u;
          var t3 = " ", a = `
`, n = 2;
          function s(c, i, D) {
            for (var o = i.length, l = -1, d = "", p; ++l < o; ) {
              if (p = i.charAt(l), p === a)
                return l < n ? void 0 : D ? true : (d += p, c(d)({ type: "break" }));
              if (p !== t3)
                return;
              d += p;
            }
          }
        } }), $D = S({ "node_modules/remark-parse/lib/tokenize/text.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3, a, n) {
            var s = this, c, i, D, o, l, d, p, g, F, E;
            if (n)
              return true;
            for (c = s.inlineMethods, o = c.length, i = s.inlineTokenizers, D = -1, F = a.length; ++D < o; )
              g = c[D], !(g === "text" || !i[g]) && (p = i[g].locator, p || t3.file.fail("Missing locator: `" + g + "`"), d = p.call(s, a, 1), d !== -1 && d < F && (F = d));
            l = a.slice(0, F), E = t3.now(), s.decode(l, E, b);
            function b(f, x, v) {
              t3(v || f)({ type: "text", value: f });
            }
          }
        } }), UD = S({ "node_modules/remark-parse/lib/parser.js"(e, r) {
          "use strict";
          I();
          var u = Pe(), t3 = Ml(), a = zl(), n = $l(), s = Kl(), c = Yl();
          r.exports = i;
          function i(l, d) {
            this.file = d, this.offset = {}, this.options = u(this.options), this.setOptions({}), this.inList = false, this.inBlock = false, this.inLink = false, this.atStart = true, this.toOffset = a(d).toOffset, this.unescape = n(this, "escape"), this.decode = s(this);
          }
          var D = i.prototype;
          D.setOptions = Ql(), D.parse = iD(), D.options = $i(), D.exitStart = t3("atStart", true), D.enterList = t3("inList", false), D.enterLink = t3("inLink", false), D.enterBlock = t3("inBlock", false), D.interruptParagraph = [["thematicBreak"], ["list"], ["atxHeading"], ["fencedCode"], ["blockquote"], ["html"], ["setextHeading", { commonmark: false }], ["definition", { commonmark: false }]], D.interruptList = [["atxHeading", { pedantic: false }], ["fencedCode", { pedantic: false }], ["thematicBreak", { pedantic: false }], ["definition", { commonmark: false }]], D.interruptBlockquote = [["indentedCode", { commonmark: true }], ["fencedCode", { commonmark: true }], ["atxHeading", { commonmark: true }], ["setextHeading", { commonmark: true }], ["thematicBreak", { commonmark: true }], ["html", { commonmark: true }], ["list", { commonmark: true }], ["definition", { commonmark: false }]], D.blockTokenizers = { blankLine: aD(), indentedCode: oD(), fencedCode: sD(), blockquote: cD(), atxHeading: lD(), thematicBreak: DD(), list: pD(), setextHeading: dD(), html: hD(), definition: mD(), table: ED(), paragraph: CD() }, D.inlineTokenizers = { escape: FD(), autoLink: AD(), url: yD(), email: BD(), html: kD(), link: qD(), reference: _D(), strong: ID(), emphasis: ND(), deletion: RD(), code: PD(), break: zD(), text: $D() }, D.blockMethods = o(D.blockTokenizers), D.inlineMethods = o(D.inlineTokenizers), D.tokenizeBlock = c("block"), D.tokenizeInline = c("inline"), D.tokenizeFactory = c;
          function o(l) {
            var d = [], p;
            for (p in l)
              d.push(p);
            return d;
          }
        } }), GD = S({ "node_modules/remark-parse/index.js"(e, r) {
          "use strict";
          I();
          var u = Pl(), t3 = Pe(), a = UD();
          r.exports = n, n.Parser = a;
          function n(s) {
            var c = this.data("settings"), i = u(a);
            i.prototype.options = t3(i.prototype.options, c, s), this.Parser = i;
          }
        } }), VD = S({ "node_modules/bail/index.js"(e, r) {
          "use strict";
          I(), r.exports = u;
          function u(t3) {
            if (t3)
              throw t3;
          }
        } }), Ki = S({ "node_modules/is-buffer/index.js"(e, r) {
          I(), r.exports = function(t3) {
            return t3 != null && t3.constructor != null && typeof t3.constructor.isBuffer == "function" && t3.constructor.isBuffer(t3);
          };
        } }), HD = S({ "node_modules/extend/index.js"(e, r) {
          "use strict";
          I();
          var u = Object.prototype.hasOwnProperty, t3 = Object.prototype.toString, a = Object.defineProperty, n = Object.getOwnPropertyDescriptor, s = function(l) {
            return typeof Array.isArray == "function" ? Array.isArray(l) : t3.call(l) === "[object Array]";
          }, c = function(l) {
            if (!l || t3.call(l) !== "[object Object]")
              return false;
            var d = u.call(l, "constructor"), p = l.constructor && l.constructor.prototype && u.call(l.constructor.prototype, "isPrototypeOf");
            if (l.constructor && !d && !p)
              return false;
            var g;
            for (g in l)
              ;
            return typeof g > "u" || u.call(l, g);
          }, i = function(l, d) {
            a && d.name === "__proto__" ? a(l, d.name, { enumerable: true, configurable: true, value: d.newValue, writable: true }) : l[d.name] = d.newValue;
          }, D = function(l, d) {
            if (d === "__proto__")
              if (u.call(l, d)) {
                if (n)
                  return n(l, d).value;
              } else
                return;
            return l[d];
          };
          r.exports = function o() {
            var l, d, p, g, F, E, b = arguments[0], f = 1, x = arguments.length, v = false;
            for (typeof b == "boolean" && (v = b, b = arguments[1] || {}, f = 2), (b == null || typeof b != "object" && typeof b != "function") && (b = {}); f < x; ++f)
              if (l = arguments[f], l != null)
                for (d in l)
                  p = D(b, d), g = D(l, d), b !== g && (v && g && (c(g) || (F = s(g))) ? (F ? (F = false, E = p && s(p) ? p : []) : E = p && c(p) ? p : {}, i(b, { name: d, newValue: o(v, E, g) })) : typeof g < "u" && i(b, { name: d, newValue: g }));
            return b;
          };
        } }), XD = S({ "node_modules/is-plain-obj/index.js"(e, r) {
          "use strict";
          I(), r.exports = (u) => {
            if (Object.prototype.toString.call(u) !== "[object Object]")
              return false;
            let t3 = Object.getPrototypeOf(u);
            return t3 === null || t3 === Object.prototype;
          };
        } }), WD = S({ "node_modules/trough/wrap.js"(e, r) {
          "use strict";
          I();
          var u = [].slice;
          r.exports = t3;
          function t3(a, n) {
            var s;
            return c;
            function c() {
              var o = u.call(arguments, 0), l = a.length > o.length, d;
              l && o.push(i);
              try {
                d = a.apply(null, o);
              } catch (p) {
                if (l && s)
                  throw p;
                return i(p);
              }
              l || (d && typeof d.then == "function" ? d.then(D, i) : d instanceof Error ? i(d) : D(d));
            }
            function i() {
              s || (s = true, n.apply(null, arguments));
            }
            function D(o) {
              i(null, o);
            }
          }
        } }), KD = S({ "node_modules/trough/index.js"(e, r) {
          "use strict";
          I();
          var u = WD();
          r.exports = a, a.wrap = u;
          var t3 = [].slice;
          function a() {
            var n = [], s = {};
            return s.run = c, s.use = i, s;
            function c() {
              var D = -1, o = t3.call(arguments, 0, -1), l = arguments[arguments.length - 1];
              if (typeof l != "function")
                throw new Error("Expected function as last argument, not " + l);
              d.apply(null, [null].concat(o));
              function d(p) {
                var g = n[++D], F = t3.call(arguments, 0), E = F.slice(1), b = o.length, f = -1;
                if (p) {
                  l(p);
                  return;
                }
                for (; ++f < b; )
                  (E[f] === null || E[f] === void 0) && (E[f] = o[f]);
                o = E, g ? u(g, d).apply(null, o) : l.apply(null, [null].concat(o));
              }
            }
            function i(D) {
              if (typeof D != "function")
                throw new Error("Expected `fn` to be a function, not " + D);
              return n.push(D), s;
            }
          }
        } }), YD = S({ "node_modules/unist-util-stringify-position/index.js"(e, r) {
          "use strict";
          I();
          var u = {}.hasOwnProperty;
          r.exports = t3;
          function t3(c) {
            return !c || typeof c != "object" ? "" : u.call(c, "position") || u.call(c, "type") ? n(c.position) : u.call(c, "start") || u.call(c, "end") ? n(c) : u.call(c, "line") || u.call(c, "column") ? a(c) : "";
          }
          function a(c) {
            return (!c || typeof c != "object") && (c = {}), s(c.line) + ":" + s(c.column);
          }
          function n(c) {
            return (!c || typeof c != "object") && (c = {}), a(c.start) + "-" + a(c.end);
          }
          function s(c) {
            return c && typeof c == "number" ? c : 1;
          }
        } }), JD = S({ "node_modules/vfile-message/index.js"(e, r) {
          "use strict";
          I();
          var u = YD();
          r.exports = n;
          function t3() {
          }
          t3.prototype = Error.prototype, n.prototype = new t3();
          var a = n.prototype;
          a.file = "", a.name = "", a.reason = "", a.message = "", a.stack = "", a.fatal = null, a.column = null, a.line = null;
          function n(c, i, D) {
            var o, l, d;
            typeof i == "string" && (D = i, i = null), o = s(D), l = u(i) || "1:1", d = { start: { line: null, column: null }, end: { line: null, column: null } }, i && i.position && (i = i.position), i && (i.start ? (d = i, i = i.start) : d.start = i), c.stack && (this.stack = c.stack, c = c.message), this.message = c, this.name = l, this.reason = c, this.line = i ? i.line : null, this.column = i ? i.column : null, this.location = d, this.source = o[0], this.ruleId = o[1];
          }
          function s(c) {
            var i = [null, null], D;
            return typeof c == "string" && (D = c.indexOf(":"), D === -1 ? i[1] = c : (i[0] = c.slice(0, D), i[1] = c.slice(D + 1))), i;
          }
        } }), ZD = S({ "node_modules/vfile/lib/minpath.browser.js"(e) {
          "use strict";
          I(), e.basename = r, e.dirname = u, e.extname = t3, e.join = a, e.sep = "/";
          function r(i, D) {
            var o = 0, l = -1, d, p, g, F;
            if (D !== void 0 && typeof D != "string")
              throw new TypeError('"ext" argument must be a string');
            if (c(i), d = i.length, D === void 0 || !D.length || D.length > i.length) {
              for (; d--; )
                if (i.charCodeAt(d) === 47) {
                  if (g) {
                    o = d + 1;
                    break;
                  }
                } else
                  l < 0 && (g = true, l = d + 1);
              return l < 0 ? "" : i.slice(o, l);
            }
            if (D === i)
              return "";
            for (p = -1, F = D.length - 1; d--; )
              if (i.charCodeAt(d) === 47) {
                if (g) {
                  o = d + 1;
                  break;
                }
              } else
                p < 0 && (g = true, p = d + 1), F > -1 && (i.charCodeAt(d) === D.charCodeAt(F--) ? F < 0 && (l = d) : (F = -1, l = p));
            return o === l ? l = p : l < 0 && (l = i.length), i.slice(o, l);
          }
          function u(i) {
            var D, o, l;
            if (c(i), !i.length)
              return ".";
            for (D = -1, l = i.length; --l; )
              if (i.charCodeAt(l) === 47) {
                if (o) {
                  D = l;
                  break;
                }
              } else
                o || (o = true);
            return D < 0 ? i.charCodeAt(0) === 47 ? "/" : "." : D === 1 && i.charCodeAt(0) === 47 ? "//" : i.slice(0, D);
          }
          function t3(i) {
            var D = -1, o = 0, l = -1, d = 0, p, g, F;
            for (c(i), F = i.length; F--; ) {
              if (g = i.charCodeAt(F), g === 47) {
                if (p) {
                  o = F + 1;
                  break;
                }
                continue;
              }
              l < 0 && (p = true, l = F + 1), g === 46 ? D < 0 ? D = F : d !== 1 && (d = 1) : D > -1 && (d = -1);
            }
            return D < 0 || l < 0 || d === 0 || d === 1 && D === l - 1 && D === o + 1 ? "" : i.slice(D, l);
          }
          function a() {
            for (var i = -1, D; ++i < arguments.length; )
              c(arguments[i]), arguments[i] && (D = D === void 0 ? arguments[i] : D + "/" + arguments[i]);
            return D === void 0 ? "." : n(D);
          }
          function n(i) {
            var D, o;
            return c(i), D = i.charCodeAt(0) === 47, o = s(i, !D), !o.length && !D && (o = "."), o.length && i.charCodeAt(i.length - 1) === 47 && (o += "/"), D ? "/" + o : o;
          }
          function s(i, D) {
            for (var o = "", l = 0, d = -1, p = 0, g = -1, F, E; ++g <= i.length; ) {
              if (g < i.length)
                F = i.charCodeAt(g);
              else {
                if (F === 47)
                  break;
                F = 47;
              }
              if (F === 47) {
                if (!(d === g - 1 || p === 1))
                  if (d !== g - 1 && p === 2) {
                    if (o.length < 2 || l !== 2 || o.charCodeAt(o.length - 1) !== 46 || o.charCodeAt(o.length - 2) !== 46) {
                      if (o.length > 2) {
                        if (E = o.lastIndexOf("/"), E !== o.length - 1) {
                          E < 0 ? (o = "", l = 0) : (o = o.slice(0, E), l = o.length - 1 - o.lastIndexOf("/")), d = g, p = 0;
                          continue;
                        }
                      } else if (o.length) {
                        o = "", l = 0, d = g, p = 0;
                        continue;
                      }
                    }
                    D && (o = o.length ? o + "/.." : "..", l = 2);
                  } else
                    o.length ? o += "/" + i.slice(d + 1, g) : o = i.slice(d + 1, g), l = g - d - 1;
                d = g, p = 0;
              } else
                F === 46 && p > -1 ? p++ : p = -1;
            }
            return o;
          }
          function c(i) {
            if (typeof i != "string")
              throw new TypeError("Path must be a string. Received " + JSON.stringify(i));
          }
        } }), QD = S({ "node_modules/vfile/lib/minproc.browser.js"(e) {
          "use strict";
          I(), e.cwd = r;
          function r() {
            return "/";
          }
        } }), e2 = S({ "node_modules/vfile/lib/core.js"(e, r) {
          "use strict";
          I();
          var u = ZD(), t3 = QD(), a = Ki();
          r.exports = c;
          var n = {}.hasOwnProperty, s = ["history", "path", "basename", "stem", "extname", "dirname"];
          c.prototype.toString = f, Object.defineProperty(c.prototype, "path", { get: i, set: D }), Object.defineProperty(c.prototype, "dirname", { get: o, set: l }), Object.defineProperty(c.prototype, "basename", { get: d, set: p }), Object.defineProperty(c.prototype, "extname", { get: g, set: F }), Object.defineProperty(c.prototype, "stem", { get: E, set: b });
          function c(m) {
            var C, w;
            if (!m)
              m = {};
            else if (typeof m == "string" || a(m))
              m = { contents: m };
            else if ("message" in m && "messages" in m)
              return m;
            if (!(this instanceof c))
              return new c(m);
            for (this.data = {}, this.messages = [], this.history = [], this.cwd = t3.cwd(), w = -1; ++w < s.length; )
              C = s[w], n.call(m, C) && (this[C] = m[C]);
            for (C in m)
              s.indexOf(C) < 0 && (this[C] = m[C]);
          }
          function i() {
            return this.history[this.history.length - 1];
          }
          function D(m) {
            v(m, "path"), this.path !== m && this.history.push(m);
          }
          function o() {
            return typeof this.path == "string" ? u.dirname(this.path) : void 0;
          }
          function l(m) {
            h(this.path, "dirname"), this.path = u.join(m || "", this.basename);
          }
          function d() {
            return typeof this.path == "string" ? u.basename(this.path) : void 0;
          }
          function p(m) {
            v(m, "basename"), x(m, "basename"), this.path = u.join(this.dirname || "", m);
          }
          function g() {
            return typeof this.path == "string" ? u.extname(this.path) : void 0;
          }
          function F(m) {
            if (x(m, "extname"), h(this.path, "extname"), m) {
              if (m.charCodeAt(0) !== 46)
                throw new Error("`extname` must start with `.`");
              if (m.indexOf(".", 1) > -1)
                throw new Error("`extname` cannot contain multiple dots");
            }
            this.path = u.join(this.dirname, this.stem + (m || ""));
          }
          function E() {
            return typeof this.path == "string" ? u.basename(this.path, this.extname) : void 0;
          }
          function b(m) {
            v(m, "stem"), x(m, "stem"), this.path = u.join(this.dirname || "", m + (this.extname || ""));
          }
          function f(m) {
            return (this.contents || "").toString(m);
          }
          function x(m, C) {
            if (m && m.indexOf(u.sep) > -1)
              throw new Error("`" + C + "` cannot be a path: did not expect `" + u.sep + "`");
          }
          function v(m, C) {
            if (!m)
              throw new Error("`" + C + "` cannot be empty");
          }
          function h(m, C) {
            if (!m)
              throw new Error("Setting `" + C + "` requires `path` to be set too");
          }
        } }), r2 = S({ "node_modules/vfile/lib/index.js"(e, r) {
          "use strict";
          I();
          var u = JD(), t3 = e2();
          r.exports = t3, t3.prototype.message = a, t3.prototype.info = s, t3.prototype.fail = n;
          function a(c, i, D) {
            var o = new u(c, i, D);
            return this.path && (o.name = this.path + ":" + o.name, o.file = this.path), o.fatal = false, this.messages.push(o), o;
          }
          function n() {
            var c = this.message.apply(this, arguments);
            throw c.fatal = true, c;
          }
          function s() {
            var c = this.message.apply(this, arguments);
            return c.fatal = null, c;
          }
        } }), u2 = S({ "node_modules/vfile/index.js"(e, r) {
          "use strict";
          I(), r.exports = r2();
        } }), t22 = S({ "node_modules/unified/index.js"(e, r) {
          "use strict";
          I();
          var u = VD(), t3 = Ki(), a = HD(), n = XD(), s = KD(), c = u2();
          r.exports = g().freeze();
          var i = [].slice, D = {}.hasOwnProperty, o = s().use(l).use(d).use(p);
          function l(m, C) {
            C.tree = m.parse(C.file);
          }
          function d(m, C, w) {
            m.run(C.tree, C.file, q);
            function q(L, B, O) {
              L ? w(L) : (C.tree = B, C.file = O, w());
            }
          }
          function p(m, C) {
            var w = m.stringify(C.tree, C.file);
            w == null || (typeof w == "string" || t3(w) ? C.file.contents = w : C.file.result = w);
          }
          function g() {
            var m = [], C = s(), w = {}, q = -1, L;
            return B.data = T, B.freeze = O, B.attachers = m, B.use = P, B.parse = j, B.stringify = X, B.run = H, B.runSync = G, B.process = R, B.processSync = J, B;
            function B() {
              for (var z = g(), M = -1; ++M < m.length; )
                z.use.apply(null, m[M]);
              return z.data(a(true, {}, w)), z;
            }
            function O() {
              var z, M;
              if (L)
                return B;
              for (; ++q < m.length; )
                z = m[q], z[1] !== false && (z[1] === true && (z[1] = void 0), M = z[0].apply(B, z.slice(1)), typeof M == "function" && C.use(M));
              return L = true, q = 1 / 0, B;
            }
            function T(z, M) {
              return typeof z == "string" ? arguments.length === 2 ? (x("data", L), w[z] = M, B) : D.call(w, z) && w[z] || null : z ? (x("data", L), w = z, B) : w;
            }
            function P(z) {
              var M;
              if (x("use", L), z != null)
                if (typeof z == "function")
                  _.apply(null, arguments);
                else if (typeof z == "object")
                  "length" in z ? y(z) : U(z);
                else
                  throw new Error("Expected usable value, not `" + z + "`");
              return M && (w.settings = a(w.settings || {}, M)), B;
              function U(N) {
                y(N.plugins), N.settings && (M = a(M || {}, N.settings));
              }
              function k(N) {
                if (typeof N == "function")
                  _(N);
                else if (typeof N == "object")
                  "length" in N ? _.apply(null, N) : U(N);
                else
                  throw new Error("Expected usable value, not `" + N + "`");
              }
              function y(N) {
                var V = -1;
                if (N != null)
                  if (typeof N == "object" && "length" in N)
                    for (; ++V < N.length; )
                      k(N[V]);
                  else
                    throw new Error("Expected a list of plugins, not `" + N + "`");
              }
              function _(N, V) {
                var W = A(N);
                W ? (n(W[1]) && n(V) && (V = a(true, W[1], V)), W[1] = V) : m.push(i.call(arguments));
              }
            }
            function A(z) {
              for (var M = -1; ++M < m.length; )
                if (m[M][0] === z)
                  return m[M];
            }
            function j(z) {
              var M = c(z), U;
              return O(), U = B.Parser, b("parse", U), F(U, "parse") ? new U(String(M), M).parse() : U(String(M), M);
            }
            function H(z, M, U) {
              if (v(z), O(), !U && typeof M == "function" && (U = M, M = null), !U)
                return new Promise(k);
              k(null, U);
              function k(y, _) {
                C.run(z, c(M), N);
                function N(V, W, K) {
                  W = W || z, V ? _(V) : y ? y(W) : U(null, W, K);
                }
              }
            }
            function G(z, M) {
              var U, k;
              return H(z, M, y), h("runSync", "run", k), U;
              function y(_, N) {
                k = true, U = N, u(_);
              }
            }
            function X(z, M) {
              var U = c(M), k;
              return O(), k = B.Compiler, f("stringify", k), v(z), F(k, "compile") ? new k(z, U).compile() : k(z, U);
            }
            function R(z, M) {
              if (O(), b("process", B.Parser), f("process", B.Compiler), !M)
                return new Promise(U);
              U(null, M);
              function U(k, y) {
                var _ = c(z);
                o.run(B, { file: _ }, N);
                function N(V) {
                  V ? y(V) : k ? k(_) : M(null, _);
                }
              }
            }
            function J(z) {
              var M, U;
              return O(), b("processSync", B.Parser), f("processSync", B.Compiler), M = c(z), R(M, k), h("processSync", "process", U), M;
              function k(y) {
                U = true, u(y);
              }
            }
          }
          function F(m, C) {
            return typeof m == "function" && m.prototype && (E(m.prototype) || C in m.prototype);
          }
          function E(m) {
            var C;
            for (C in m)
              return true;
            return false;
          }
          function b(m, C) {
            if (typeof C != "function")
              throw new Error("Cannot `" + m + "` without `Parser`");
          }
          function f(m, C) {
            if (typeof C != "function")
              throw new Error("Cannot `" + m + "` without `Compiler`");
          }
          function x(m, C) {
            if (C)
              throw new Error("Cannot invoke `" + m + "` on a frozen processor.\nCreate a new processor first, by invoking it: use `processor()` instead of `processor`.");
          }
          function v(m) {
            if (!m || typeof m.type != "string")
              throw new Error("Expected node, got `" + m + "`");
          }
          function h(m, C, w) {
            if (!w)
              throw new Error("`" + m + "` finished async. Use `" + C + "` instead");
          }
        } }), Yi = S({ "node_modules/remark-math/util.js"(e) {
          I(), e.isRemarkParser = r, e.isRemarkCompiler = u;
          function r(t3) {
            return Boolean(t3 && t3.prototype && t3.prototype.blockTokenizers);
          }
          function u(t3) {
            return Boolean(t3 && t3.prototype && t3.prototype.visitors);
          }
        } }), n2 = S({ "node_modules/remark-math/inline.js"(e, r) {
          I();
          var u = Yi();
          r.exports = l;
          var t3 = 9, a = 32, n = 36, s = 48, c = 57, i = 92, D = ["math", "math-inline"], o = "math-display";
          function l(g) {
            let F = this.Parser, E = this.Compiler;
            u.isRemarkParser(F) && d(F, g), u.isRemarkCompiler(E) && p(E, g);
          }
          function d(g, F) {
            let E = g.prototype, b = E.inlineMethods;
            x.locator = f, E.inlineTokenizers.math = x, b.splice(b.indexOf("text"), 0, "math");
            function f(v, h) {
              return v.indexOf("$", h);
            }
            function x(v, h, m) {
              let C = h.length, w = false, q = false, L = 0, B, O, T, P, A, j, H;
              if (h.charCodeAt(L) === i && (q = true, L++), h.charCodeAt(L) === n) {
                if (L++, q)
                  return m ? true : v(h.slice(0, L))({ type: "text", value: "$" });
                if (h.charCodeAt(L) === n && (w = true, L++), T = h.charCodeAt(L), !(T === a || T === t3)) {
                  for (P = L; L < C; ) {
                    if (O = T, T = h.charCodeAt(L + 1), O === n) {
                      if (B = h.charCodeAt(L - 1), B !== a && B !== t3 && (T !== T || T < s || T > c) && (!w || T === n)) {
                        A = L - 1, L++, w && L++, j = L;
                        break;
                      }
                    } else
                      O === i && (L++, T = h.charCodeAt(L + 1));
                    L++;
                  }
                  if (j !== void 0)
                    return m ? true : (H = h.slice(P, A + 1), v(h.slice(0, j))({ type: "inlineMath", value: H, data: { hName: "span", hProperties: { className: D.concat(w && F.inlineMathDouble ? [o] : []) }, hChildren: [{ type: "text", value: H }] } }));
                }
              }
            }
          }
          function p(g) {
            let F = g.prototype;
            F.visitors.inlineMath = E;
            function E(b) {
              let f = "$";
              return (b.data && b.data.hProperties && b.data.hProperties.className || []).includes(o) && (f = "$$"), f + b.value + f;
            }
          }
        } }), i2 = S({ "node_modules/remark-math/block.js"(e, r) {
          I();
          var u = Yi();
          r.exports = o;
          var t3 = 10, a = 32, n = 36, s = `
`, c = "$", i = 2, D = ["math", "math-display"];
          function o() {
            let p = this.Parser, g = this.Compiler;
            u.isRemarkParser(p) && l(p), u.isRemarkCompiler(g) && d(g);
          }
          function l(p) {
            let g = p.prototype, F = g.blockMethods, E = g.interruptParagraph, b = g.interruptList, f = g.interruptBlockquote;
            g.blockTokenizers.math = x, F.splice(F.indexOf("fencedCode") + 1, 0, "math"), E.splice(E.indexOf("fencedCode") + 1, 0, ["math"]), b.splice(b.indexOf("fencedCode") + 1, 0, ["math"]), f.splice(f.indexOf("fencedCode") + 1, 0, ["math"]);
            function x(v, h, m) {
              var C = h.length, w = 0;
              let q, L, B, O, T, P, A, j, H, G, X;
              for (; w < C && h.charCodeAt(w) === a; )
                w++;
              for (T = w; w < C && h.charCodeAt(w) === n; )
                w++;
              if (P = w - T, !(P < i)) {
                for (; w < C && h.charCodeAt(w) === a; )
                  w++;
                for (A = w; w < C; ) {
                  if (q = h.charCodeAt(w), q === n)
                    return;
                  if (q === t3)
                    break;
                  w++;
                }
                if (h.charCodeAt(w) === t3) {
                  if (m)
                    return true;
                  for (L = [], A !== w && L.push(h.slice(A, w)), w++, B = h.indexOf(s, w + 1), B = B === -1 ? C : B; w < C; ) {
                    for (j = false, G = w, X = B, O = B, H = 0; O > G && h.charCodeAt(O - 1) === a; )
                      O--;
                    for (; O > G && h.charCodeAt(O - 1) === n; )
                      H++, O--;
                    for (P <= H && h.indexOf(c, G) === O && (j = true, X = O); G <= X && G - w < T && h.charCodeAt(G) === a; )
                      G++;
                    if (j)
                      for (; X > G && h.charCodeAt(X - 1) === a; )
                        X--;
                    if ((!j || G !== X) && L.push(h.slice(G, X)), j)
                      break;
                    w = B + 1, B = h.indexOf(s, w + 1), B = B === -1 ? C : B;
                  }
                  return L = L.join(`
`), v(h.slice(0, B))({ type: "math", value: L, data: { hName: "div", hProperties: { className: D.concat() }, hChildren: [{ type: "text", value: L }] } });
                }
              }
            }
          }
          function d(p) {
            let g = p.prototype;
            g.visitors.math = F;
            function F(E) {
              return `$$
` + E.value + `
$$`;
            }
          }
        } }), a2 = S({ "node_modules/remark-math/index.js"(e, r) {
          I();
          var u = n2(), t3 = i2();
          r.exports = a;
          function a(n) {
            var s = n || {};
            t3.call(this, s), u.call(this, s);
          }
        } }), o2 = S({ "node_modules/remark-footnotes/index.js"(e, r) {
          "use strict";
          I(), r.exports = g;
          var u = 9, t3 = 10, a = 32, n = 33, s = 58, c = 91, i = 92, D = 93, o = 94, l = 96, d = 4, p = 1024;
          function g(h) {
            var m = this.Parser, C = this.Compiler;
            F(m) && b(m, h), E(C) && f(C);
          }
          function F(h) {
            return Boolean(h && h.prototype && h.prototype.blockTokenizers);
          }
          function E(h) {
            return Boolean(h && h.prototype && h.prototype.visitors);
          }
          function b(h, m) {
            for (var C = m || {}, w = h.prototype, q = w.blockTokenizers, L = w.inlineTokenizers, B = w.blockMethods, O = w.inlineMethods, T = q.definition, P = L.reference, A = [], j = -1, H = B.length, G; ++j < H; )
              G = B[j], !(G === "newline" || G === "indentedCode" || G === "paragraph" || G === "footnoteDefinition") && A.push([G]);
            A.push(["footnoteDefinition"]), C.inlineNotes && (x(O, "reference", "inlineNote"), L.inlineNote = J), x(B, "definition", "footnoteDefinition"), x(O, "reference", "footnoteCall"), q.definition = M, q.footnoteDefinition = X, L.footnoteCall = R, L.reference = z, w.interruptFootnoteDefinition = A, z.locator = P.locator, R.locator = U, J.locator = k;
            function X(y, _, N) {
              for (var V = this, W = V.interruptFootnoteDefinition, K = V.offset, ee = _.length + 1, Y = 0, ue = [], le, ce, te, Z, Q, De, ye, fe, he, ae, pe, ne, re; Y < ee && (Z = _.charCodeAt(Y), !(Z !== u && Z !== a)); )
                Y++;
              if (_.charCodeAt(Y++) === c && _.charCodeAt(Y++) === o) {
                for (ce = Y; Y < ee; ) {
                  if (Z = _.charCodeAt(Y), Z !== Z || Z === t3 || Z === u || Z === a)
                    return;
                  if (Z === D) {
                    te = Y, Y++;
                    break;
                  }
                  Y++;
                }
                if (!(te === void 0 || ce === te || _.charCodeAt(Y++) !== s)) {
                  if (N)
                    return true;
                  for (le = _.slice(ce, te), Q = y.now(), he = 0, ae = 0, pe = Y, ne = []; Y < ee; ) {
                    if (Z = _.charCodeAt(Y), Z !== Z || Z === t3)
                      re = { start: he, contentStart: pe || Y, contentEnd: Y, end: Y }, ne.push(re), Z === t3 && (he = Y + 1, ae = 0, pe = void 0, re.end = he);
                    else if (ae !== void 0)
                      if (Z === a || Z === u)
                        ae += Z === a ? 1 : d - ae % d, ae > d && (ae = void 0, pe = Y);
                      else {
                        if (ae < d && re && (re.contentStart === re.contentEnd || v(W, q, V, [y, _.slice(Y, p), true])))
                          break;
                        ae = void 0, pe = Y;
                      }
                    Y++;
                  }
                  for (Y = -1, ee = ne.length; ee > 0 && (re = ne[ee - 1], re.contentStart === re.contentEnd); )
                    ee--;
                  for (De = y(_.slice(0, re.contentEnd)); ++Y < ee; )
                    re = ne[Y], K[Q.line + Y] = (K[Q.line + Y] || 0) + (re.contentStart - re.start), ue.push(_.slice(re.contentStart, re.end));
                  return ye = V.enterBlock(), fe = V.tokenizeBlock(ue.join(""), Q), ye(), De({ type: "footnoteDefinition", identifier: le.toLowerCase(), label: le, children: fe });
                }
              }
            }
            function R(y, _, N) {
              var V = _.length + 1, W = 0, K, ee, Y, ue;
              if (_.charCodeAt(W++) === c && _.charCodeAt(W++) === o) {
                for (ee = W; W < V; ) {
                  if (ue = _.charCodeAt(W), ue !== ue || ue === t3 || ue === u || ue === a)
                    return;
                  if (ue === D) {
                    Y = W, W++;
                    break;
                  }
                  W++;
                }
                if (!(Y === void 0 || ee === Y))
                  return N ? true : (K = _.slice(ee, Y), y(_.slice(0, W))({ type: "footnoteReference", identifier: K.toLowerCase(), label: K }));
              }
            }
            function J(y, _, N) {
              var V = this, W = _.length + 1, K = 0, ee = 0, Y, ue, le, ce, te, Z, Q;
              if (_.charCodeAt(K++) === o && _.charCodeAt(K++) === c) {
                for (le = K; K < W; ) {
                  if (ue = _.charCodeAt(K), ue !== ue)
                    return;
                  if (Z === void 0)
                    if (ue === i)
                      K += 2;
                    else if (ue === c)
                      ee++, K++;
                    else if (ue === D)
                      if (ee === 0) {
                        ce = K, K++;
                        break;
                      } else
                        ee--, K++;
                    else if (ue === l) {
                      for (te = K, Z = 1; _.charCodeAt(te + Z) === l; )
                        Z++;
                      K += Z;
                    } else
                      K++;
                  else if (ue === l) {
                    for (te = K, Q = 1; _.charCodeAt(te + Q) === l; )
                      Q++;
                    K += Q, Z === Q && (Z = void 0), Q = void 0;
                  } else
                    K++;
                }
                if (ce !== void 0)
                  return N ? true : (Y = y.now(), Y.column += 2, Y.offset += 2, y(_.slice(0, K))({ type: "footnote", children: V.tokenizeInline(_.slice(le, ce), Y) }));
              }
            }
            function z(y, _, N) {
              var V = 0;
              if (_.charCodeAt(V) === n && V++, _.charCodeAt(V) === c && _.charCodeAt(V + 1) !== o)
                return P.call(this, y, _, N);
            }
            function M(y, _, N) {
              for (var V = 0, W = _.charCodeAt(V); W === a || W === u; )
                W = _.charCodeAt(++V);
              if (W === c && _.charCodeAt(V + 1) !== o)
                return T.call(this, y, _, N);
            }
            function U(y, _) {
              return y.indexOf("[", _);
            }
            function k(y, _) {
              return y.indexOf("^[", _);
            }
          }
          function f(h) {
            var m = h.prototype.visitors, C = "    ";
            m.footnote = w, m.footnoteReference = q, m.footnoteDefinition = L;
            function w(B) {
              return "^[" + this.all(B).join("") + "]";
            }
            function q(B) {
              return "[^" + (B.label || B.identifier) + "]";
            }
            function L(B) {
              for (var O = this.all(B).join(`

`).split(`
`), T = 0, P = O.length, A; ++T < P; )
                A = O[T], A !== "" && (O[T] = C + A);
              return "[^" + (B.label || B.identifier) + "]: " + O.join(`
`);
            }
          }
          function x(h, m, C) {
            h.splice(h.indexOf(m), 0, C);
          }
          function v(h, m, C, w) {
            for (var q = h.length, L = -1; ++L < q; )
              if (m[h[L][0]].apply(C, w))
                return true;
            return false;
          }
        } }), Ji = S({ "src/utils/front-matter/parse.js"(e, r) {
          "use strict";
          I();
          var u = new RegExp("^(?<startDelimiter>-{3}|\\+{3})(?<language>[^\\n]*)\\n(?:|(?<value>.*?)\\n)(?<endDelimiter>\\k<startDelimiter>|\\.{3})[^\\S\\n]*(?:\\n|$)", "s");
          function t3(a) {
            let n = a.match(u);
            if (!n)
              return { content: a };
            let { startDelimiter: s, language: c, value: i = "", endDelimiter: D } = n.groups, o = c.trim() || "yaml";
            if (s === "+++" && (o = "toml"), o !== "yaml" && s !== D)
              return { content: a };
            let [l] = n;
            return { frontMatter: { type: "front-matter", lang: o, value: i, startDelimiter: s, endDelimiter: D, raw: l.replace(/\n$/, "") }, content: l.replace(/[^\n]/g, " ") + a.slice(l.length) };
          }
          r.exports = t3;
        } }), s2 = S({ "src/language-markdown/pragma.js"(e, r) {
          "use strict";
          I();
          var u = Ji(), t3 = ["format", "prettier"];
          function a(n) {
            let s = `@(${t3.join("|")})`, c = new RegExp([`<!--\\s*${s}\\s*-->`, `{\\s*\\/\\*\\s*${s}\\s*\\*\\/\\s*}`, `<!--.*\r?
[\\s\\S]*(^|
)[^\\S
]*${s}[^\\S
]*($|
)[\\s\\S]*
.*-->`].join("|"), "m"), i = n.match(c);
            return (i == null ? void 0 : i.index) === 0;
          }
          r.exports = { startWithPragma: a, hasPragma: (n) => a(u(n).content.trimStart()), insertPragma: (n) => {
            let s = u(n), c = `<!-- @${t3[0]} -->`;
            return s.frontMatter ? `${s.frontMatter.raw}

${c}

${s.content}` : `${c}

${s.content}`;
          } };
        } }), Zi = S({ "src/language-markdown/loc.js"(e, r) {
          "use strict";
          I();
          function u(a) {
            return a.position.start.offset;
          }
          function t3(a) {
            return a.position.end.offset;
          }
          r.exports = { locStart: u, locEnd: t3 };
        } }), Qi = S({ "src/language-markdown/mdx.js"(e, r) {
          "use strict";
          I();
          var u = /^import\s/, t3 = /^export\s/, a = "[a-z][a-z0-9]*(\\.[a-z][a-z0-9]*)*|", n = /<!---->|<!---?[^>-](?:-?[^-])*-->/, s = /^{\s*\/\*(.*)\*\/\s*}/, c = `

`, i = (p) => u.test(p), D = (p) => t3.test(p), o = (p, g) => {
            let F = g.indexOf(c), E = g.slice(0, F);
            if (D(E) || i(E))
              return p(E)({ type: D(E) ? "export" : "import", value: E });
          }, l = (p, g) => {
            let F = s.exec(g);
            if (F)
              return p(F[0])({ type: "esComment", value: F[1].trim() });
          };
          o.locator = (p) => D(p) || i(p) ? -1 : 1, l.locator = (p, g) => p.indexOf("{", g);
          function d() {
            let { Parser: p } = this, { blockTokenizers: g, blockMethods: F, inlineTokenizers: E, inlineMethods: b } = p.prototype;
            g.esSyntax = o, E.esComment = l, F.splice(F.indexOf("paragraph"), 0, "esSyntax"), b.splice(b.indexOf("text"), 0, "esComment");
          }
          r.exports = { esSyntax: d, BLOCKS_REGEX: a, COMMENT_REGEX: n };
        } }), ea = {};
        Pi(ea, { default: () => c2 });
        function c2(e) {
          if (typeof e != "string")
            throw new TypeError("Expected a string");
          return e.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
        }
        var l2 = je({ "node_modules/escape-string-regexp/index.js"() {
          I();
        } }), D2 = S({ "src/utils/get-last.js"(e, r) {
          "use strict";
          I();
          var u = (t3) => t3[t3.length - 1];
          r.exports = u;
        } }), ra = S({ "node_modules/semver/internal/debug.js"(e, r) {
          I();
          var u = typeof Qe == "object" && Qe.env && Qe.env.NODE_DEBUG && /\bsemver\b/i.test(Qe.env.NODE_DEBUG) ? function() {
            for (var t3 = arguments.length, a = new Array(t3), n = 0; n < t3; n++)
              a[n] = arguments[n];
            return console.error("SEMVER", ...a);
          } : () => {
          };
          r.exports = u;
        } }), ua = S({ "node_modules/semver/internal/constants.js"(e, r) {
          I();
          var u = "2.0.0", t3 = 256, a = Number.MAX_SAFE_INTEGER || 9007199254740991, n = 16;
          r.exports = { SEMVER_SPEC_VERSION: u, MAX_LENGTH: t3, MAX_SAFE_INTEGER: a, MAX_SAFE_COMPONENT_LENGTH: n };
        } }), f2 = S({ "node_modules/semver/internal/re.js"(e, r) {
          I();
          var { MAX_SAFE_COMPONENT_LENGTH: u } = ua(), t3 = ra();
          e = r.exports = {};
          var a = e.re = [], n = e.src = [], s = e.t = {}, c = 0, i = (D, o, l) => {
            let d = c++;
            t3(D, d, o), s[D] = d, n[d] = o, a[d] = new RegExp(o, l ? "g" : void 0);
          };
          i("NUMERICIDENTIFIER", "0|[1-9]\\d*"), i("NUMERICIDENTIFIERLOOSE", "[0-9]+"), i("NONNUMERICIDENTIFIER", "\\d*[a-zA-Z-][a-zA-Z0-9-]*"), i("MAINVERSION", `(${n[s.NUMERICIDENTIFIER]})\\.(${n[s.NUMERICIDENTIFIER]})\\.(${n[s.NUMERICIDENTIFIER]})`), i("MAINVERSIONLOOSE", `(${n[s.NUMERICIDENTIFIERLOOSE]})\\.(${n[s.NUMERICIDENTIFIERLOOSE]})\\.(${n[s.NUMERICIDENTIFIERLOOSE]})`), i("PRERELEASEIDENTIFIER", `(?:${n[s.NUMERICIDENTIFIER]}|${n[s.NONNUMERICIDENTIFIER]})`), i("PRERELEASEIDENTIFIERLOOSE", `(?:${n[s.NUMERICIDENTIFIERLOOSE]}|${n[s.NONNUMERICIDENTIFIER]})`), i("PRERELEASE", `(?:-(${n[s.PRERELEASEIDENTIFIER]}(?:\\.${n[s.PRERELEASEIDENTIFIER]})*))`), i("PRERELEASELOOSE", `(?:-?(${n[s.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${n[s.PRERELEASEIDENTIFIERLOOSE]})*))`), i("BUILDIDENTIFIER", "[0-9A-Za-z-]+"), i("BUILD", `(?:\\+(${n[s.BUILDIDENTIFIER]}(?:\\.${n[s.BUILDIDENTIFIER]})*))`), i("FULLPLAIN", `v?${n[s.MAINVERSION]}${n[s.PRERELEASE]}?${n[s.BUILD]}?`), i("FULL", `^${n[s.FULLPLAIN]}$`), i("LOOSEPLAIN", `[v=\\s]*${n[s.MAINVERSIONLOOSE]}${n[s.PRERELEASELOOSE]}?${n[s.BUILD]}?`), i("LOOSE", `^${n[s.LOOSEPLAIN]}$`), i("GTLT", "((?:<|>)?=?)"), i("XRANGEIDENTIFIERLOOSE", `${n[s.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`), i("XRANGEIDENTIFIER", `${n[s.NUMERICIDENTIFIER]}|x|X|\\*`), i("XRANGEPLAIN", `[v=\\s]*(${n[s.XRANGEIDENTIFIER]})(?:\\.(${n[s.XRANGEIDENTIFIER]})(?:\\.(${n[s.XRANGEIDENTIFIER]})(?:${n[s.PRERELEASE]})?${n[s.BUILD]}?)?)?`), i("XRANGEPLAINLOOSE", `[v=\\s]*(${n[s.XRANGEIDENTIFIERLOOSE]})(?:\\.(${n[s.XRANGEIDENTIFIERLOOSE]})(?:\\.(${n[s.XRANGEIDENTIFIERLOOSE]})(?:${n[s.PRERELEASELOOSE]})?${n[s.BUILD]}?)?)?`), i("XRANGE", `^${n[s.GTLT]}\\s*${n[s.XRANGEPLAIN]}$`), i("XRANGELOOSE", `^${n[s.GTLT]}\\s*${n[s.XRANGEPLAINLOOSE]}$`), i("COERCE", `(^|[^\\d])(\\d{1,${u}})(?:\\.(\\d{1,${u}}))?(?:\\.(\\d{1,${u}}))?(?:$|[^\\d])`), i("COERCERTL", n[s.COERCE], true), i("LONETILDE", "(?:~>?)"), i("TILDETRIM", `(\\s*)${n[s.LONETILDE]}\\s+`, true), e.tildeTrimReplace = "$1~", i("TILDE", `^${n[s.LONETILDE]}${n[s.XRANGEPLAIN]}$`), i("TILDELOOSE", `^${n[s.LONETILDE]}${n[s.XRANGEPLAINLOOSE]}$`), i("LONECARET", "(?:\\^)"), i("CARETTRIM", `(\\s*)${n[s.LONECARET]}\\s+`, true), e.caretTrimReplace = "$1^", i("CARET", `^${n[s.LONECARET]}${n[s.XRANGEPLAIN]}$`), i("CARETLOOSE", `^${n[s.LONECARET]}${n[s.XRANGEPLAINLOOSE]}$`), i("COMPARATORLOOSE", `^${n[s.GTLT]}\\s*(${n[s.LOOSEPLAIN]})$|^$`), i("COMPARATOR", `^${n[s.GTLT]}\\s*(${n[s.FULLPLAIN]})$|^$`), i("COMPARATORTRIM", `(\\s*)${n[s.GTLT]}\\s*(${n[s.LOOSEPLAIN]}|${n[s.XRANGEPLAIN]})`, true), e.comparatorTrimReplace = "$1$2$3", i("HYPHENRANGE", `^\\s*(${n[s.XRANGEPLAIN]})\\s+-\\s+(${n[s.XRANGEPLAIN]})\\s*$`), i("HYPHENRANGELOOSE", `^\\s*(${n[s.XRANGEPLAINLOOSE]})\\s+-\\s+(${n[s.XRANGEPLAINLOOSE]})\\s*$`), i("STAR", "(<|>)?=?\\s*\\*"), i("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$"), i("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
        } }), p2 = S({ "node_modules/semver/internal/parse-options.js"(e, r) {
          I();
          var u = ["includePrerelease", "loose", "rtl"], t3 = (a) => a ? typeof a != "object" ? { loose: true } : u.filter((n) => a[n]).reduce((n, s) => (n[s] = true, n), {}) : {};
          r.exports = t3;
        } }), d2 = S({ "node_modules/semver/internal/identifiers.js"(e, r) {
          I();
          var u = /^[0-9]+$/, t3 = (n, s) => {
            let c = u.test(n), i = u.test(s);
            return c && i && (n = +n, s = +s), n === s ? 0 : c && !i ? -1 : i && !c ? 1 : n < s ? -1 : 1;
          }, a = (n, s) => t3(s, n);
          r.exports = { compareIdentifiers: t3, rcompareIdentifiers: a };
        } }), h2 = S({ "node_modules/semver/classes/semver.js"(e, r) {
          I();
          var u = ra(), { MAX_LENGTH: t3, MAX_SAFE_INTEGER: a } = ua(), { re: n, t: s } = f2(), c = p2(), { compareIdentifiers: i } = d2(), D = class {
            constructor(o, l) {
              if (l = c(l), o instanceof D) {
                if (o.loose === !!l.loose && o.includePrerelease === !!l.includePrerelease)
                  return o;
                o = o.version;
              } else if (typeof o != "string")
                throw new TypeError(`Invalid Version: ${o}`);
              if (o.length > t3)
                throw new TypeError(`version is longer than ${t3} characters`);
              u("SemVer", o, l), this.options = l, this.loose = !!l.loose, this.includePrerelease = !!l.includePrerelease;
              let d = o.trim().match(l.loose ? n[s.LOOSE] : n[s.FULL]);
              if (!d)
                throw new TypeError(`Invalid Version: ${o}`);
              if (this.raw = o, this.major = +d[1], this.minor = +d[2], this.patch = +d[3], this.major > a || this.major < 0)
                throw new TypeError("Invalid major version");
              if (this.minor > a || this.minor < 0)
                throw new TypeError("Invalid minor version");
              if (this.patch > a || this.patch < 0)
                throw new TypeError("Invalid patch version");
              d[4] ? this.prerelease = d[4].split(".").map((p) => {
                if (/^[0-9]+$/.test(p)) {
                  let g = +p;
                  if (g >= 0 && g < a)
                    return g;
                }
                return p;
              }) : this.prerelease = [], this.build = d[5] ? d[5].split(".") : [], this.format();
            }
            format() {
              return this.version = `${this.major}.${this.minor}.${this.patch}`, this.prerelease.length && (this.version += `-${this.prerelease.join(".")}`), this.version;
            }
            toString() {
              return this.version;
            }
            compare(o) {
              if (u("SemVer.compare", this.version, this.options, o), !(o instanceof D)) {
                if (typeof o == "string" && o === this.version)
                  return 0;
                o = new D(o, this.options);
              }
              return o.version === this.version ? 0 : this.compareMain(o) || this.comparePre(o);
            }
            compareMain(o) {
              return o instanceof D || (o = new D(o, this.options)), i(this.major, o.major) || i(this.minor, o.minor) || i(this.patch, o.patch);
            }
            comparePre(o) {
              if (o instanceof D || (o = new D(o, this.options)), this.prerelease.length && !o.prerelease.length)
                return -1;
              if (!this.prerelease.length && o.prerelease.length)
                return 1;
              if (!this.prerelease.length && !o.prerelease.length)
                return 0;
              let l = 0;
              do {
                let d = this.prerelease[l], p = o.prerelease[l];
                if (u("prerelease compare", l, d, p), d === void 0 && p === void 0)
                  return 0;
                if (p === void 0)
                  return 1;
                if (d === void 0)
                  return -1;
                if (d === p)
                  continue;
                return i(d, p);
              } while (++l);
            }
            compareBuild(o) {
              o instanceof D || (o = new D(o, this.options));
              let l = 0;
              do {
                let d = this.build[l], p = o.build[l];
                if (u("prerelease compare", l, d, p), d === void 0 && p === void 0)
                  return 0;
                if (p === void 0)
                  return 1;
                if (d === void 0)
                  return -1;
                if (d === p)
                  continue;
                return i(d, p);
              } while (++l);
            }
            inc(o, l) {
              switch (o) {
                case "premajor":
                  this.prerelease.length = 0, this.patch = 0, this.minor = 0, this.major++, this.inc("pre", l);
                  break;
                case "preminor":
                  this.prerelease.length = 0, this.patch = 0, this.minor++, this.inc("pre", l);
                  break;
                case "prepatch":
                  this.prerelease.length = 0, this.inc("patch", l), this.inc("pre", l);
                  break;
                case "prerelease":
                  this.prerelease.length === 0 && this.inc("patch", l), this.inc("pre", l);
                  break;
                case "major":
                  (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) && this.major++, this.minor = 0, this.patch = 0, this.prerelease = [];
                  break;
                case "minor":
                  (this.patch !== 0 || this.prerelease.length === 0) && this.minor++, this.patch = 0, this.prerelease = [];
                  break;
                case "patch":
                  this.prerelease.length === 0 && this.patch++, this.prerelease = [];
                  break;
                case "pre":
                  if (this.prerelease.length === 0)
                    this.prerelease = [0];
                  else {
                    let d = this.prerelease.length;
                    for (; --d >= 0; )
                      typeof this.prerelease[d] == "number" && (this.prerelease[d]++, d = -2);
                    d === -1 && this.prerelease.push(0);
                  }
                  l && (i(this.prerelease[0], l) === 0 ? isNaN(this.prerelease[1]) && (this.prerelease = [l, 0]) : this.prerelease = [l, 0]);
                  break;
                default:
                  throw new Error(`invalid increment argument: ${o}`);
              }
              return this.format(), this.raw = this.version, this;
            }
          };
          r.exports = D;
        } }), Cu = S({ "node_modules/semver/functions/compare.js"(e, r) {
          I();
          var u = h2(), t3 = (a, n, s) => new u(a, s).compare(new u(n, s));
          r.exports = t3;
        } }), v2 = S({ "node_modules/semver/functions/lt.js"(e, r) {
          I();
          var u = Cu(), t3 = (a, n, s) => u(a, n, s) < 0;
          r.exports = t3;
        } }), m2 = S({ "node_modules/semver/functions/gte.js"(e, r) {
          I();
          var u = Cu(), t3 = (a, n, s) => u(a, n, s) >= 0;
          r.exports = t3;
        } }), E2 = S({ "src/utils/arrayify.js"(e, r) {
          "use strict";
          I(), r.exports = (u, t3) => Object.entries(u).map((a) => {
            let [n, s] = a;
            return Object.assign({ [t3]: n }, s);
          });
        } }), C2 = S({ "package.json"(e, r) {
          r.exports = { version: "2.8.2" };
        } }), g2 = S({ "node_modules/outdent/lib/index.js"(e, r) {
          "use strict";
          I(), Object.defineProperty(e, "__esModule", { value: true }), e.outdent = void 0;
          function u() {
            for (var f = [], x = 0; x < arguments.length; x++)
              f[x] = arguments[x];
          }
          function t3() {
            return typeof WeakMap < "u" ? /* @__PURE__ */ new WeakMap() : a();
          }
          function a() {
            return { add: u, delete: u, get: u, set: u, has: function(f) {
              return false;
            } };
          }
          var n = Object.prototype.hasOwnProperty, s = function(f, x) {
            return n.call(f, x);
          };
          function c(f, x) {
            for (var v in x)
              s(x, v) && (f[v] = x[v]);
            return f;
          }
          var i = /^[ \t]*(?:\r\n|\r|\n)/, D = /(?:\r\n|\r|\n)[ \t]*$/, o = /^(?:[\r\n]|$)/, l = /(?:\r\n|\r|\n)([ \t]*)(?:[^ \t\r\n]|$)/, d = /^[ \t]*[\r\n][ \t\r\n]*$/;
          function p(f, x, v) {
            var h = 0, m = f[0].match(l);
            m && (h = m[1].length);
            var C = "(\\r\\n|\\r|\\n).{0," + h + "}", w = new RegExp(C, "g");
            x && (f = f.slice(1));
            var q = v.newline, L = v.trimLeadingNewline, B = v.trimTrailingNewline, O = typeof q == "string", T = f.length, P = f.map(function(A, j) {
              return A = A.replace(w, "$1"), j === 0 && L && (A = A.replace(i, "")), j === T - 1 && B && (A = A.replace(D, "")), O && (A = A.replace(/\r\n|\n|\r/g, function(H) {
                return q;
              })), A;
            });
            return P;
          }
          function g(f, x) {
            for (var v = "", h = 0, m = f.length; h < m; h++)
              v += f[h], h < m - 1 && (v += x[h]);
            return v;
          }
          function F(f) {
            return s(f, "raw") && s(f, "length");
          }
          function E(f) {
            var x = t3(), v = t3();
            function h(C) {
              for (var w = [], q = 1; q < arguments.length; q++)
                w[q - 1] = arguments[q];
              if (F(C)) {
                var L = C, B = (w[0] === h || w[0] === b) && d.test(L[0]) && o.test(L[1]), O = B ? v : x, T = O.get(L);
                if (T || (T = p(L, B, f), O.set(L, T)), w.length === 0)
                  return T[0];
                var P = g(T, B ? w.slice(1) : w);
                return P;
              } else
                return E(c(c({}, f), C || {}));
            }
            var m = c(h, { string: function(C) {
              return p([C], false, f)[0];
            } });
            return m;
          }
          var b = E({ trimLeadingNewline: true, trimTrailingNewline: true });
          if (e.outdent = b, e.default = b, typeof r < "u")
            try {
              r.exports = b, Object.defineProperty(b, "__esModule", { value: true }), b.default = b, b.outdent = b;
            } catch {
            }
        } }), F2 = S({ "src/main/core-options.js"(e, r) {
          "use strict";
          I();
          var { outdent: u } = g2(), t3 = "Config", a = "Editor", n = "Format", s = "Other", c = "Output", i = "Global", D = "Special", o = { cursorOffset: { since: "1.4.0", category: D, type: "int", default: -1, range: { start: -1, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Print (to stderr) where a cursor at the given position would move to after formatting.
      This option cannot be used with --range-start and --range-end.
    `, cliCategory: a }, endOfLine: { since: "1.15.0", category: i, type: "choice", default: [{ since: "1.15.0", value: "auto" }, { since: "2.0.0", value: "lf" }], description: "Which end of line characters to apply.", choices: [{ value: "lf", description: "Line Feed only (\\n), common on Linux and macOS as well as inside git repos" }, { value: "crlf", description: "Carriage Return + Line Feed characters (\\r\\n), common on Windows" }, { value: "cr", description: "Carriage Return character only (\\r), used very rarely" }, { value: "auto", description: u`
          Maintain existing
          (mixed values within one file are normalised by looking at what's used after the first line)
        ` }] }, filepath: { since: "1.4.0", category: D, type: "path", description: "Specify the input filepath. This will be used to do parser inference.", cliName: "stdin-filepath", cliCategory: s, cliDescription: "Path to the file to pretend that stdin comes from." }, insertPragma: { since: "1.8.0", category: D, type: "boolean", default: false, description: "Insert @format pragma into file's first docblock comment.", cliCategory: s }, parser: { since: "0.0.10", category: i, type: "choice", default: [{ since: "0.0.10", value: "babylon" }, { since: "1.13.0", value: void 0 }], description: "Which parser to use.", exception: (l) => typeof l == "string" || typeof l == "function", choices: [{ value: "flow", description: "Flow" }, { value: "babel", since: "1.16.0", description: "JavaScript" }, { value: "babel-flow", since: "1.16.0", description: "Flow" }, { value: "babel-ts", since: "2.0.0", description: "TypeScript" }, { value: "typescript", since: "1.4.0", description: "TypeScript" }, { value: "acorn", since: "2.6.0", description: "JavaScript" }, { value: "espree", since: "2.2.0", description: "JavaScript" }, { value: "meriyah", since: "2.2.0", description: "JavaScript" }, { value: "css", since: "1.7.1", description: "CSS" }, { value: "less", since: "1.7.1", description: "Less" }, { value: "scss", since: "1.7.1", description: "SCSS" }, { value: "json", since: "1.5.0", description: "JSON" }, { value: "json5", since: "1.13.0", description: "JSON5" }, { value: "json-stringify", since: "1.13.0", description: "JSON.stringify" }, { value: "graphql", since: "1.5.0", description: "GraphQL" }, { value: "markdown", since: "1.8.0", description: "Markdown" }, { value: "mdx", since: "1.15.0", description: "MDX" }, { value: "vue", since: "1.10.0", description: "Vue" }, { value: "yaml", since: "1.14.0", description: "YAML" }, { value: "glimmer", since: "2.3.0", description: "Ember / Handlebars" }, { value: "html", since: "1.15.0", description: "HTML" }, { value: "angular", since: "1.15.0", description: "Angular" }, { value: "lwc", since: "1.17.0", description: "Lightning Web Components" }] }, plugins: { since: "1.10.0", type: "path", array: true, default: [{ value: [] }], category: i, description: "Add a plugin. Multiple plugins can be passed as separate `--plugin`s.", exception: (l) => typeof l == "string" || typeof l == "object", cliName: "plugin", cliCategory: t3 }, pluginSearchDirs: { since: "1.13.0", type: "path", array: true, default: [{ value: [] }], category: i, description: u`
      Custom directory that contains prettier plugins in node_modules subdirectory.
      Overrides default behavior when plugins are searched relatively to the location of Prettier.
      Multiple values are accepted.
    `, exception: (l) => typeof l == "string" || typeof l == "object", cliName: "plugin-search-dir", cliCategory: t3 }, printWidth: { since: "0.0.0", category: i, type: "int", default: 80, description: "The line length where Prettier will try wrap.", range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 } }, rangeEnd: { since: "1.4.0", category: D, type: "int", default: Number.POSITIVE_INFINITY, range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Format code ending at a given character offset (exclusive).
      The range will extend forwards to the end of the selected statement.
      This option cannot be used with --cursor-offset.
    `, cliCategory: a }, rangeStart: { since: "1.4.0", category: D, type: "int", default: 0, range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Format code starting at a given character offset.
      The range will extend backwards to the start of the first line containing the selected statement.
      This option cannot be used with --cursor-offset.
    `, cliCategory: a }, requirePragma: { since: "1.7.0", category: D, type: "boolean", default: false, description: u`
      Require either '@prettier' or '@format' to be present in the file's first docblock comment
      in order for it to be formatted.
    `, cliCategory: s }, tabWidth: { type: "int", category: i, default: 2, description: "Number of spaces per indentation level.", range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 } }, useTabs: { since: "1.0.0", category: i, type: "boolean", default: false, description: "Indent with tabs instead of spaces." }, embeddedLanguageFormatting: { since: "2.1.0", category: i, type: "choice", default: [{ since: "2.1.0", value: "auto" }], description: "Control how Prettier formats quoted code embedded in the file.", choices: [{ value: "auto", description: "Format embedded code if Prettier can automatically identify it." }, { value: "off", description: "Never automatically format embedded code." }] } };
          r.exports = { CATEGORY_CONFIG: t3, CATEGORY_EDITOR: a, CATEGORY_FORMAT: n, CATEGORY_OTHER: s, CATEGORY_OUTPUT: c, CATEGORY_GLOBAL: i, CATEGORY_SPECIAL: D, options: o };
        } }), A2 = S({ "src/main/support.js"(e, r) {
          "use strict";
          I();
          var u = { compare: Cu(), lt: v2(), gte: m2() }, t3 = E2(), a = C2().version, n = F2().options;
          function s() {
            let { plugins: i = [], showUnreleased: D = false, showDeprecated: o = false, showInternal: l = false } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, d = a.split("-", 1)[0], p = i.flatMap((f) => f.languages || []).filter(F), g = t3(Object.assign({}, ...i.map((f) => {
              let { options: x } = f;
              return x;
            }), n), "name").filter((f) => F(f) && E(f)).sort((f, x) => f.name === x.name ? 0 : f.name < x.name ? -1 : 1).map(b).map((f) => {
              f = Object.assign({}, f), Array.isArray(f.default) && (f.default = f.default.length === 1 ? f.default[0].value : f.default.filter(F).sort((v, h) => u.compare(h.since, v.since))[0].value), Array.isArray(f.choices) && (f.choices = f.choices.filter((v) => F(v) && E(v)), f.name === "parser" && c(f, p, i));
              let x = Object.fromEntries(i.filter((v) => v.defaultOptions && v.defaultOptions[f.name] !== void 0).map((v) => [v.name, v.defaultOptions[f.name]]));
              return Object.assign(Object.assign({}, f), {}, { pluginDefaults: x });
            });
            return { languages: p, options: g };
            function F(f) {
              return D || !("since" in f) || f.since && u.gte(d, f.since);
            }
            function E(f) {
              return o || !("deprecated" in f) || f.deprecated && u.lt(d, f.deprecated);
            }
            function b(f) {
              if (l)
                return f;
              let { cliName: x, cliCategory: v, cliDescription: h } = f;
              return Ol(f, _l);
            }
          }
          function c(i, D, o) {
            let l = new Set(i.choices.map((d) => d.value));
            for (let d of D)
              if (d.parsers) {
                for (let p of d.parsers)
                  if (!l.has(p)) {
                    l.add(p);
                    let g = o.find((E) => E.parsers && E.parsers[p]), F = d.name;
                    g && g.name && (F += ` (plugin: ${g.name})`), i.choices.push({ value: p, description: F });
                  }
              }
          }
          r.exports = { getSupportInfo: s };
        } }), x2 = S({ "src/utils/is-non-empty-array.js"(e, r) {
          "use strict";
          I();
          function u(t3) {
            return Array.isArray(t3) && t3.length > 0;
          }
          r.exports = u;
        } });
        function b2() {
          let { onlyFirst: e = false } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, r = ["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)", "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"].join("|");
          return new RegExp(r, e ? void 0 : "g");
        }
        var y2 = je({ "node_modules/strip-ansi/node_modules/ansi-regex/index.js"() {
          I();
        } });
        function w2(e) {
          if (typeof e != "string")
            throw new TypeError(`Expected a \`string\`, got \`${typeof e}\``);
          return e.replace(b2(), "");
        }
        var B2 = je({ "node_modules/strip-ansi/index.js"() {
          I(), y2();
        } });
        function k2(e) {
          return Number.isInteger(e) ? e >= 4352 && (e <= 4447 || e === 9001 || e === 9002 || 11904 <= e && e <= 12871 && e !== 12351 || 12880 <= e && e <= 19903 || 19968 <= e && e <= 42182 || 43360 <= e && e <= 43388 || 44032 <= e && e <= 55203 || 63744 <= e && e <= 64255 || 65040 <= e && e <= 65049 || 65072 <= e && e <= 65131 || 65281 <= e && e <= 65376 || 65504 <= e && e <= 65510 || 110592 <= e && e <= 110593 || 127488 <= e && e <= 127569 || 131072 <= e && e <= 262141) : false;
        }
        var q2 = je({ "node_modules/is-fullwidth-code-point/index.js"() {
          I();
        } }), _2 = S({ "node_modules/emoji-regex/index.js"(e, r) {
          "use strict";
          I(), r.exports = function() {
            return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67)\uDB40\uDC7F|(?:\uD83E\uDDD1\uD83C\uDFFF\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFC-\uDFFF])|\uD83D\uDC68(?:\uD83C\uDFFB(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|[\u2695\u2696\u2708]\uFE0F|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))?|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])\uFE0F|\u200D(?:(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D[\uDC66\uDC67])|\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC)?|(?:\uD83D\uDC69(?:\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69]))|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC69(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83E\uDDD1(?:\u200D(?:\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDE36\u200D\uD83C\uDF2B|\uD83C\uDFF3\uFE0F\u200D\u26A7|\uD83D\uDC3B\u200D\u2744|(?:(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\uD83C\uDFF4\u200D\u2620|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])\u200D[\u2640\u2642]|[\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u2328\u23CF\u23ED-\u23EF\u23F1\u23F2\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB\u25FC\u2600-\u2604\u260E\u2611\u2618\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u2692\u2694-\u2697\u2699\u269B\u269C\u26A0\u26A7\u26B0\u26B1\u26C8\u26CF\u26D1\u26D3\u26E9\u26F0\u26F1\u26F4\u26F7\u26F8\u2702\u2708\u2709\u270F\u2712\u2714\u2716\u271D\u2721\u2733\u2734\u2744\u2747\u2763\u27A1\u2934\u2935\u2B05-\u2B07\u3030\u303D\u3297\u3299]|\uD83C[\uDD70\uDD71\uDD7E\uDD7F\uDE02\uDE37\uDF21\uDF24-\uDF2C\uDF36\uDF7D\uDF96\uDF97\uDF99-\uDF9B\uDF9E\uDF9F\uDFCD\uDFCE\uDFD4-\uDFDF\uDFF5\uDFF7]|\uD83D[\uDC3F\uDCFD\uDD49\uDD4A\uDD6F\uDD70\uDD73\uDD76-\uDD79\uDD87\uDD8A-\uDD8D\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA\uDECB\uDECD-\uDECF\uDEE0-\uDEE5\uDEE9\uDEF0\uDEF3])\uFE0F|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDE35\u200D\uD83D\uDCAB|\uD83D\uDE2E\u200D\uD83D\uDCA8|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83E\uDDD1(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83D\uDC69(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF6\uD83C\uDDE6|\uD83C\uDDF4\uD83C\uDDF2|\uD83D\uDC08\u200D\u2B1B|\u2764\uFE0F\u200D(?:\uD83D\uDD25|\uD83E\uDE79)|\uD83D\uDC41\uFE0F|\uD83C\uDFF3\uFE0F|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|[#\*0-9]\uFE0F\u20E3|\u2764\uFE0F|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|\uD83C\uDFF4|(?:[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270C\u270D]|\uD83D[\uDD74\uDD90])(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC08\uDC15\uDC3B\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE2E\uDE35\uDE36\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5]|\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD]|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF]|[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF84\uDF86-\uDF93\uDFA0-\uDFC1\uDFC5\uDFC6\uDFC8\uDFC9\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC07\uDC09-\uDC14\uDC16-\uDC3A\uDC3C-\uDC3E\uDC40\uDC44\uDC45\uDC51-\uDC65\uDC6A\uDC79-\uDC7B\uDC7D-\uDC80\uDC84\uDC88-\uDC8E\uDC90\uDC92-\uDCA9\uDCAB-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDDA4\uDDFB-\uDE2D\uDE2F-\uDE34\uDE37-\uDE44\uDE48-\uDE4A\uDE80-\uDEA2\uDEA4-\uDEB3\uDEB7-\uDEBF\uDEC1-\uDEC5\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0D\uDD0E\uDD10-\uDD17\uDD1D\uDD20-\uDD25\uDD27-\uDD2F\uDD3A\uDD3F-\uDD45\uDD47-\uDD76\uDD78\uDD7A-\uDDB4\uDDB7\uDDBA\uDDBC-\uDDCB\uDDD0\uDDE0-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6]|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26A7\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5-\uDED7\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDD77\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
          };
        } }), ta = {};
        Pi(ta, { default: () => O2 });
        function O2(e) {
          if (typeof e != "string" || e.length === 0 || (e = w2(e), e.length === 0))
            return 0;
          e = e.replace((0, na.default)(), "  ");
          let r = 0;
          for (let u = 0; u < e.length; u++) {
            let t3 = e.codePointAt(u);
            t3 <= 31 || t3 >= 127 && t3 <= 159 || t3 >= 768 && t3 <= 879 || (t3 > 65535 && u++, r += k2(t3) ? 2 : 1);
          }
          return r;
        }
        var na, I2 = je({ "node_modules/string-width/index.js"() {
          I(), B2(), q2(), na = Rl(_2());
        } }), S2 = S({ "src/utils/get-string-width.js"(e, r) {
          "use strict";
          I();
          var u = (I2(), zi(ta)).default, t3 = /[^\x20-\x7F]/;
          function a(n) {
            return n ? t3.test(n) ? u(n) : n.length : 0;
          }
          r.exports = a;
        } }), gu = S({ "src/utils/text/skip.js"(e, r) {
          "use strict";
          I();
          function u(c) {
            return (i, D, o) => {
              let l = o && o.backwards;
              if (D === false)
                return false;
              let { length: d } = i, p = D;
              for (; p >= 0 && p < d; ) {
                let g = i.charAt(p);
                if (c instanceof RegExp) {
                  if (!c.test(g))
                    return p;
                } else if (!c.includes(g))
                  return p;
                l ? p-- : p++;
              }
              return p === -1 || p === d ? p : false;
            };
          }
          var t3 = u(/\s/), a = u(" 	"), n = u(",; 	"), s = u(/[^\n\r]/);
          r.exports = { skipWhitespace: t3, skipSpaces: a, skipToLineEnd: n, skipEverythingButNewLine: s };
        } }), ia = S({ "src/utils/text/skip-inline-comment.js"(e, r) {
          "use strict";
          I();
          function u(t3, a) {
            if (a === false)
              return false;
            if (t3.charAt(a) === "/" && t3.charAt(a + 1) === "*") {
              for (let n = a + 2; n < t3.length; ++n)
                if (t3.charAt(n) === "*" && t3.charAt(n + 1) === "/")
                  return n + 2;
            }
            return a;
          }
          r.exports = u;
        } }), aa = S({ "src/utils/text/skip-trailing-comment.js"(e, r) {
          "use strict";
          I();
          var { skipEverythingButNewLine: u } = gu();
          function t3(a, n) {
            return n === false ? false : a.charAt(n) === "/" && a.charAt(n + 1) === "/" ? u(a, n) : n;
          }
          r.exports = t3;
        } }), oa = S({ "src/utils/text/skip-newline.js"(e, r) {
          "use strict";
          I();
          function u(t3, a, n) {
            let s = n && n.backwards;
            if (a === false)
              return false;
            let c = t3.charAt(a);
            if (s) {
              if (t3.charAt(a - 1) === "\r" && c === `
`)
                return a - 2;
              if (c === `
` || c === "\r" || c === "\u2028" || c === "\u2029")
                return a - 1;
            } else {
              if (c === "\r" && t3.charAt(a + 1) === `
`)
                return a + 2;
              if (c === `
` || c === "\r" || c === "\u2028" || c === "\u2029")
                return a + 1;
            }
            return a;
          }
          r.exports = u;
        } }), T2 = S({ "src/utils/text/get-next-non-space-non-comment-character-index-with-start-index.js"(e, r) {
          "use strict";
          I();
          var u = ia(), t3 = oa(), a = aa(), { skipSpaces: n } = gu();
          function s(c, i) {
            let D = null, o = i;
            for (; o !== D; )
              D = o, o = n(c, o), o = u(c, o), o = a(c, o), o = t3(c, o);
            return o;
          }
          r.exports = s;
        } }), N2 = S({ "src/common/util.js"(e, r) {
          "use strict";
          I();
          var { default: u } = (l2(), zi(ea)), t3 = D2(), { getSupportInfo: a } = A2(), n = x2(), s = S2(), { skipWhitespace: c, skipSpaces: i, skipToLineEnd: D, skipEverythingButNewLine: o } = gu(), l = ia(), d = aa(), p = oa(), g = T2(), F = (k) => k[k.length - 2];
          function E(k) {
            return (y, _, N) => {
              let V = N && N.backwards;
              if (_ === false)
                return false;
              let { length: W } = y, K = _;
              for (; K >= 0 && K < W; ) {
                let ee = y.charAt(K);
                if (k instanceof RegExp) {
                  if (!k.test(ee))
                    return K;
                } else if (!k.includes(ee))
                  return K;
                V ? K-- : K++;
              }
              return K === -1 || K === W ? K : false;
            };
          }
          function b(k, y) {
            let _ = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, N = i(k, _.backwards ? y - 1 : y, _), V = p(k, N, _);
            return N !== V;
          }
          function f(k, y, _) {
            for (let N = y; N < _; ++N)
              if (k.charAt(N) === `
`)
                return true;
            return false;
          }
          function x(k, y, _) {
            let N = _(y) - 1;
            N = i(k, N, { backwards: true }), N = p(k, N, { backwards: true }), N = i(k, N, { backwards: true });
            let V = p(k, N, { backwards: true });
            return N !== V;
          }
          function v(k, y) {
            let _ = null, N = y;
            for (; N !== _; )
              _ = N, N = D(k, N), N = l(k, N), N = i(k, N);
            return N = d(k, N), N = p(k, N), N !== false && b(k, N);
          }
          function h(k, y, _) {
            return v(k, _(y));
          }
          function m(k, y, _) {
            return g(k, _(y));
          }
          function C(k, y, _) {
            return k.charAt(m(k, y, _));
          }
          function w(k, y) {
            let _ = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
            return i(k, _.backwards ? y - 1 : y, _) !== y;
          }
          function q(k, y) {
            let _ = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : 0, N = 0;
            for (let V = _; V < k.length; ++V)
              k[V] === "	" ? N = N + y - N % y : N++;
            return N;
          }
          function L(k, y) {
            let _ = k.lastIndexOf(`
`);
            return _ === -1 ? 0 : q(k.slice(_ + 1).match(/^[\t ]*/)[0], y);
          }
          function B(k, y) {
            let _ = { quote: '"', regex: /"/g, escaped: "&quot;" }, N = { quote: "'", regex: /'/g, escaped: "&apos;" }, V = y === "'" ? N : _, W = V === N ? _ : N, K = V;
            if (k.includes(V.quote) || k.includes(W.quote)) {
              let ee = (k.match(V.regex) || []).length, Y = (k.match(W.regex) || []).length;
              K = ee > Y ? W : V;
            }
            return K;
          }
          function O(k, y) {
            let _ = k.slice(1, -1), N = y.parser === "json" || y.parser === "json5" && y.quoteProps === "preserve" && !y.singleQuote ? '"' : y.__isInHtmlAttribute ? "'" : B(_, y.singleQuote ? "'" : '"').quote;
            return T(_, N, !(y.parser === "css" || y.parser === "less" || y.parser === "scss" || y.__embeddedInHtml));
          }
          function T(k, y, _) {
            let N = y === '"' ? "'" : '"', V = /\\(.)|(["'])/gs, W = k.replace(V, (K, ee, Y) => ee === N ? ee : Y === y ? "\\" + Y : Y || (_ && /^[^\n\r"'0-7\\bfnrt-vx\u2028\u2029]$/.test(ee) ? ee : "\\" + ee));
            return y + W + y;
          }
          function P(k) {
            return k.toLowerCase().replace(/^([+-]?[\d.]+e)(?:\+|(-))?0*(\d)/, "$1$2$3").replace(/^([+-]?[\d.]+)e[+-]?0+$/, "$1").replace(/^([+-])?\./, "$10.").replace(/(\.\d+?)0+(?=e|$)/, "$1").replace(/\.(?=e|$)/, "");
          }
          function A(k, y) {
            let _ = k.match(new RegExp(`(${u(y)})+`, "g"));
            return _ === null ? 0 : _.reduce((N, V) => Math.max(N, V.length / y.length), 0);
          }
          function j(k, y) {
            let _ = k.match(new RegExp(`(${u(y)})+`, "g"));
            if (_ === null)
              return 0;
            let N = /* @__PURE__ */ new Map(), V = 0;
            for (let W of _) {
              let K = W.length / y.length;
              N.set(K, true), K > V && (V = K);
            }
            for (let W = 1; W < V; W++)
              if (!N.get(W))
                return W;
            return V + 1;
          }
          function H(k, y) {
            (k.comments || (k.comments = [])).push(y), y.printed = false, y.nodeDescription = U(k);
          }
          function G(k, y) {
            y.leading = true, y.trailing = false, H(k, y);
          }
          function X(k, y, _) {
            y.leading = false, y.trailing = false, _ && (y.marker = _), H(k, y);
          }
          function R(k, y) {
            y.leading = false, y.trailing = true, H(k, y);
          }
          function J(k, y) {
            let { languages: _ } = a({ plugins: y.plugins }), N = _.find((V) => {
              let { name: W } = V;
              return W.toLowerCase() === k;
            }) || _.find((V) => {
              let { aliases: W } = V;
              return Array.isArray(W) && W.includes(k);
            }) || _.find((V) => {
              let { extensions: W } = V;
              return Array.isArray(W) && W.includes(`.${k}`);
            });
            return N && N.parsers[0];
          }
          function z(k) {
            return k && k.type === "front-matter";
          }
          function M(k) {
            let y = /* @__PURE__ */ new WeakMap();
            return function(_) {
              return y.has(_) || y.set(_, Symbol(k)), y.get(_);
            };
          }
          function U(k) {
            let y = k.type || k.kind || "(unknown type)", _ = String(k.name || k.id && (typeof k.id == "object" ? k.id.name : k.id) || k.key && (typeof k.key == "object" ? k.key.name : k.key) || k.value && (typeof k.value == "object" ? "" : String(k.value)) || k.operator || "");
            return _.length > 20 && (_ = _.slice(0, 19) + "\u2026"), y + (_ ? " " + _ : "");
          }
          r.exports = { inferParserByLanguage: J, getStringWidth: s, getMaxContinuousCount: A, getMinNotPresentContinuousCount: j, getPenultimate: F, getLast: t3, getNextNonSpaceNonCommentCharacterIndexWithStartIndex: g, getNextNonSpaceNonCommentCharacterIndex: m, getNextNonSpaceNonCommentCharacter: C, skip: E, skipWhitespace: c, skipSpaces: i, skipToLineEnd: D, skipEverythingButNewLine: o, skipInlineComment: l, skipTrailingComment: d, skipNewline: p, isNextLineEmptyAfterIndex: v, isNextLineEmpty: h, isPreviousLineEmpty: x, hasNewline: b, hasNewlineInRange: f, hasSpaces: w, getAlignmentSize: q, getIndentSize: L, getPreferredQuote: B, printString: O, printNumber: P, makeString: T, addLeadingComment: G, addDanglingComment: X, addTrailingComment: R, isFrontMatterNode: z, isNonEmptyArray: n, createGroupIdMapper: M };
        } }), L2 = S({ "src/language-markdown/constants.evaluate.js"(e, r) {
          r.exports = { cjkPattern: "(?:[\\u02ea-\\u02eb\\u1100-\\u11ff\\u2e80-\\u2e99\\u2e9b-\\u2ef3\\u2f00-\\u2fd5\\u2ff0-\\u303f\\u3041-\\u3096\\u3099-\\u309f\\u30a1-\\u30fa\\u30fc-\\u30ff\\u3105-\\u312f\\u3131-\\u318e\\u3190-\\u3191\\u3196-\\u31ba\\u31c0-\\u31e3\\u31f0-\\u321e\\u322a-\\u3247\\u3260-\\u327e\\u328a-\\u32b0\\u32c0-\\u32cb\\u32d0-\\u3370\\u337b-\\u337f\\u33e0-\\u33fe\\u3400-\\u4db5\\u4e00-\\u9fef\\ua960-\\ua97c\\uac00-\\ud7a3\\ud7b0-\\ud7c6\\ud7cb-\\ud7fb\\uf900-\\ufa6d\\ufa70-\\ufad9\\ufe10-\\ufe1f\\ufe30-\\ufe6f\\uff00-\\uffef]|[\\ud840-\\ud868\\ud86a-\\ud86c\\ud86f-\\ud872\\ud874-\\ud879][\\udc00-\\udfff]|\\ud82c[\\udc00-\\udd1e\\udd50-\\udd52\\udd64-\\udd67]|\\ud83c[\\ude00\\ude50-\\ude51]|\\ud869[\\udc00-\\uded6\\udf00-\\udfff]|\\ud86d[\\udc00-\\udf34\\udf40-\\udfff]|\\ud86e[\\udc00-\\udc1d\\udc20-\\udfff]|\\ud873[\\udc00-\\udea1\\udeb0-\\udfff]|\\ud87a[\\udc00-\\udfe0]|\\ud87e[\\udc00-\\ude1d])(?:[\\ufe00-\\ufe0f]|\\udb40[\\udd00-\\uddef])?", kPattern: "[\\u1100-\\u11ff\\u3001-\\u3003\\u3008-\\u3011\\u3013-\\u301f\\u302e-\\u3030\\u3037\\u30fb\\u3131-\\u318e\\u3200-\\u321e\\u3260-\\u327e\\ua960-\\ua97c\\uac00-\\ud7a3\\ud7b0-\\ud7c6\\ud7cb-\\ud7fb\\ufe45-\\ufe46\\uff61-\\uff65\\uffa0-\\uffbe\\uffc2-\\uffc7\\uffca-\\uffcf\\uffd2-\\uffd7\\uffda-\\uffdc]", punctuationPattern: "[\\u0021-\\u002f\\u003a-\\u0040\\u005b-\\u0060\\u007b-\\u007e\\u00a1\\u00a7\\u00ab\\u00b6-\\u00b7\\u00bb\\u00bf\\u037e\\u0387\\u055a-\\u055f\\u0589-\\u058a\\u05be\\u05c0\\u05c3\\u05c6\\u05f3-\\u05f4\\u0609-\\u060a\\u060c-\\u060d\\u061b\\u061e-\\u061f\\u066a-\\u066d\\u06d4\\u0700-\\u070d\\u07f7-\\u07f9\\u0830-\\u083e\\u085e\\u0964-\\u0965\\u0970\\u09fd\\u0a76\\u0af0\\u0c77\\u0c84\\u0df4\\u0e4f\\u0e5a-\\u0e5b\\u0f04-\\u0f12\\u0f14\\u0f3a-\\u0f3d\\u0f85\\u0fd0-\\u0fd4\\u0fd9-\\u0fda\\u104a-\\u104f\\u10fb\\u1360-\\u1368\\u1400\\u166e\\u169b-\\u169c\\u16eb-\\u16ed\\u1735-\\u1736\\u17d4-\\u17d6\\u17d8-\\u17da\\u1800-\\u180a\\u1944-\\u1945\\u1a1e-\\u1a1f\\u1aa0-\\u1aa6\\u1aa8-\\u1aad\\u1b5a-\\u1b60\\u1bfc-\\u1bff\\u1c3b-\\u1c3f\\u1c7e-\\u1c7f\\u1cc0-\\u1cc7\\u1cd3\\u2010-\\u2027\\u2030-\\u2043\\u2045-\\u2051\\u2053-\\u205e\\u207d-\\u207e\\u208d-\\u208e\\u2308-\\u230b\\u2329-\\u232a\\u2768-\\u2775\\u27c5-\\u27c6\\u27e6-\\u27ef\\u2983-\\u2998\\u29d8-\\u29db\\u29fc-\\u29fd\\u2cf9-\\u2cfc\\u2cfe-\\u2cff\\u2d70\\u2e00-\\u2e2e\\u2e30-\\u2e4f\\u3001-\\u3003\\u3008-\\u3011\\u3014-\\u301f\\u3030\\u303d\\u30a0\\u30fb\\ua4fe-\\ua4ff\\ua60d-\\ua60f\\ua673\\ua67e\\ua6f2-\\ua6f7\\ua874-\\ua877\\ua8ce-\\ua8cf\\ua8f8-\\ua8fa\\ua8fc\\ua92e-\\ua92f\\ua95f\\ua9c1-\\ua9cd\\ua9de-\\ua9df\\uaa5c-\\uaa5f\\uaade-\\uaadf\\uaaf0-\\uaaf1\\uabeb\\ufd3e-\\ufd3f\\ufe10-\\ufe19\\ufe30-\\ufe52\\ufe54-\\ufe61\\ufe63\\ufe68\\ufe6a-\\ufe6b\\uff01-\\uff03\\uff05-\\uff0a\\uff0c-\\uff0f\\uff1a-\\uff1b\\uff1f-\\uff20\\uff3b-\\uff3d\\uff3f\\uff5b\\uff5d\\uff5f-\\uff65]|\\ud800[\\udd00-\\udd02\\udf9f\\udfd0]|\\ud801[\\udd6f]|\\ud802[\\udc57\\udd1f\\udd3f\\ude50-\\ude58\\ude7f\\udef0-\\udef6\\udf39-\\udf3f\\udf99-\\udf9c]|\\ud803[\\udf55-\\udf59]|\\ud804[\\udc47-\\udc4d\\udcbb-\\udcbc\\udcbe-\\udcc1\\udd40-\\udd43\\udd74-\\udd75\\uddc5-\\uddc8\\uddcd\\udddb\\udddd-\\udddf\\ude38-\\ude3d\\udea9]|\\ud805[\\udc4b-\\udc4f\\udc5b\\udc5d\\udcc6\\uddc1-\\uddd7\\ude41-\\ude43\\ude60-\\ude6c\\udf3c-\\udf3e]|\\ud806[\\udc3b\\udde2\\ude3f-\\ude46\\ude9a-\\ude9c\\ude9e-\\udea2]|\\ud807[\\udc41-\\udc45\\udc70-\\udc71\\udef7-\\udef8\\udfff]|\\ud809[\\udc70-\\udc74]|\\ud81a[\\ude6e-\\ude6f\\udef5\\udf37-\\udf3b\\udf44]|\\ud81b[\\ude97-\\ude9a\\udfe2]|\\ud82f[\\udc9f]|\\ud836[\\ude87-\\ude8b]|\\ud83a[\\udd5e-\\udd5f]" };
        } }), R2 = S({ "src/language-markdown/utils.js"(e, r) {
          "use strict";
          I();
          var { getLast: u } = N2(), { locStart: t3, locEnd: a } = Zi(), { cjkPattern: n, kPattern: s, punctuationPattern: c } = L2(), i = ["liquidNode", "inlineCode", "emphasis", "esComment", "strong", "delete", "wikiLink", "link", "linkReference", "image", "imageReference", "footnote", "footnoteReference", "sentence", "whitespace", "word", "break", "inlineMath"], D = [...i, "tableCell", "paragraph", "heading"], o = new RegExp(s), l = new RegExp(c);
          function d(f, x) {
            let v = "non-cjk", h = "cj-letter", m = "k-letter", C = "cjk-punctuation", w = [], q = (x.proseWrap === "preserve" ? f : f.replace(new RegExp(`(${n})
(${n})`, "g"), "$1$2")).split(/([\t\n ]+)/);
            for (let [B, O] of q.entries()) {
              if (B % 2 === 1) {
                w.push({ type: "whitespace", value: /\n/.test(O) ? `
` : " " });
                continue;
              }
              if ((B === 0 || B === q.length - 1) && O === "")
                continue;
              let T = O.split(new RegExp(`(${n})`));
              for (let [P, A] of T.entries())
                if (!((P === 0 || P === T.length - 1) && A === "")) {
                  if (P % 2 === 0) {
                    A !== "" && L({ type: "word", value: A, kind: v, hasLeadingPunctuation: l.test(A[0]), hasTrailingPunctuation: l.test(u(A)) });
                    continue;
                  }
                  L(l.test(A) ? { type: "word", value: A, kind: C, hasLeadingPunctuation: true, hasTrailingPunctuation: true } : { type: "word", value: A, kind: o.test(A) ? m : h, hasLeadingPunctuation: false, hasTrailingPunctuation: false });
                }
            }
            return w;
            function L(B) {
              let O = u(w);
              O && O.type === "word" && (O.kind === v && B.kind === h && !O.hasTrailingPunctuation || O.kind === h && B.kind === v && !B.hasLeadingPunctuation ? w.push({ type: "whitespace", value: " " }) : !T(v, C) && ![O.value, B.value].some((P) => /\u3000/.test(P)) && w.push({ type: "whitespace", value: "" })), w.push(B);
              function T(P, A) {
                return O.kind === P && B.kind === A || O.kind === A && B.kind === P;
              }
            }
          }
          function p(f, x) {
            let [, v, h, m] = x.slice(f.position.start.offset, f.position.end.offset).match(/^\s*(\d+)(\.|\))(\s*)/);
            return { numberText: v, marker: h, leadingSpaces: m };
          }
          function g(f, x) {
            if (!f.ordered || f.children.length < 2)
              return false;
            let v = Number(p(f.children[0], x.originalText).numberText), h = Number(p(f.children[1], x.originalText).numberText);
            if (v === 0 && f.children.length > 2) {
              let m = Number(p(f.children[2], x.originalText).numberText);
              return h === 1 && m === 1;
            }
            return h === 1;
          }
          function F(f, x) {
            let { value: v } = f;
            return f.position.end.offset === x.length && v.endsWith(`
`) && x.endsWith(`
`) ? v.slice(0, -1) : v;
          }
          function E(f, x) {
            return function v(h, m, C) {
              let w = Object.assign({}, x(h, m, C));
              return w.children && (w.children = w.children.map((q, L) => v(q, L, [w, ...C]))), w;
            }(f, null, []);
          }
          function b(f) {
            if ((f == null ? void 0 : f.type) !== "link" || f.children.length !== 1)
              return false;
            let [x] = f.children;
            return t3(f) === t3(x) && a(f) === a(x);
          }
          r.exports = { mapAst: E, splitText: d, punctuationPattern: c, getFencedCodeBlockValue: F, getOrderedListItemInfo: p, hasGitDiffFriendlyOrderedList: g, INLINE_NODE_TYPES: i, INLINE_NODE_WRAPPER_TYPES: D, isAutolink: b };
        } }), j2 = S({ "src/language-markdown/unified-plugins/html-to-jsx.js"(e, r) {
          "use strict";
          I();
          var u = Qi(), { mapAst: t3, INLINE_NODE_WRAPPER_TYPES: a } = R2();
          function n() {
            return (s) => t3(s, (c, i, D) => {
              let [o] = D;
              return c.type !== "html" || u.COMMENT_REGEX.test(c.value) || a.includes(o.type) ? c : Object.assign(Object.assign({}, c), {}, { type: "jsx" });
            });
          }
          r.exports = n;
        } }), P2 = S({ "src/language-markdown/unified-plugins/front-matter.js"(e, r) {
          "use strict";
          I();
          var u = Ji();
          function t3() {
            let a = this.Parser.prototype;
            a.blockMethods = ["frontMatter", ...a.blockMethods], a.blockTokenizers.frontMatter = n;
            function n(s, c) {
              let i = u(c);
              if (i.frontMatter)
                return s(i.frontMatter.raw)(i.frontMatter);
            }
            n.onlyAtStart = true;
          }
          r.exports = t3;
        } }), M2 = S({ "src/language-markdown/unified-plugins/liquid.js"(e, r) {
          "use strict";
          I();
          function u() {
            let t3 = this.Parser.prototype, a = t3.inlineMethods;
            a.splice(a.indexOf("text"), 0, "liquid"), t3.inlineTokenizers.liquid = n;
            function n(s, c) {
              let i = c.match(/^({%.*?%}|{{.*?}})/s);
              if (i)
                return s(i[0])({ type: "liquidNode", value: i[0] });
            }
            n.locator = function(s, c) {
              return s.indexOf("{", c);
            };
          }
          r.exports = u;
        } }), z2 = S({ "src/language-markdown/unified-plugins/wiki-link.js"(e, r) {
          "use strict";
          I();
          function u() {
            let t3 = "wikiLink", a = /^\[\[(?<linkContents>.+?)]]/s, n = this.Parser.prototype, s = n.inlineMethods;
            s.splice(s.indexOf("link"), 0, t3), n.inlineTokenizers.wikiLink = c;
            function c(i, D) {
              let o = a.exec(D);
              if (o) {
                let l = o.groups.linkContents.trim();
                return i(o[0])({ type: t3, value: l });
              }
            }
            c.locator = function(i, D) {
              return i.indexOf("[", D);
            };
          }
          r.exports = u;
        } }), $22 = S({ "src/language-markdown/unified-plugins/loose-items.js"(e, r) {
          "use strict";
          I();
          function u() {
            let t3 = this.Parser.prototype, a = t3.blockTokenizers.list;
            function n(s, c, i) {
              return c.type === "listItem" && (c.loose = c.spread || s.charAt(s.length - 1) === `
`, c.loose && (i.loose = true)), c;
            }
            t3.blockTokenizers.list = function(c, i, D) {
              function o(l) {
                let d = c(l);
                function p(g, F) {
                  return d(n(l, g, F), F);
                }
                return p.reset = function(g, F) {
                  return d.reset(n(l, g, F), F);
                }, p;
              }
              return o.now = c.now, a.call(this, o, i, D);
            };
          }
          r.exports = u;
        } });
        I();
        var U2 = GD(), G2 = t22(), V2 = a2(), H2 = o2(), X2 = s2(), { locStart: W2, locEnd: K2 } = Zi(), Li = Qi(), Y2 = j2(), J2 = P2(), Z2 = M2(), Q2 = z2(), ef = $22();
        function sa(e) {
          let { isMDX: r } = e;
          return (u) => {
            let t3 = G2().use(U2, Object.assign({ commonmark: true }, r && { blocks: [Li.BLOCKS_REGEX] })).use(H2).use(J2).use(V2).use(r ? Li.esSyntax : Ri).use(Z2).use(r ? Y2 : Ri).use(Q2).use(ef);
            return t3.runSync(t3.parse(u));
          };
        }
        function Ri(e) {
          return e;
        }
        var ca = { astFormat: "mdast", hasPragma: X2.hasPragma, locStart: W2, locEnd: K2 }, ji = Object.assign(Object.assign({}, ca), {}, { parse: sa({ isMDX: false }) }), rf = Object.assign(Object.assign({}, ca), {}, { parse: sa({ isMDX: true }) });
        la.exports = { parsers: { remark: ji, markdown: ji, mdx: rf } };
      });
      return uf();
    });
  }
});

// node_modules/prettier/parser-html.js
var require_parser_html = __commonJS({
  "node_modules/prettier/parser-html.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.html = e();
      }
    })(function() {
      "use strict";
      var S = (e, r) => () => (r || e((r = { exports: {} }).exports, r), r.exports);
      var ee = S((cc, Kr) => {
        var Ne = function(e) {
          return e && e.Math == Math && e;
        };
        Kr.exports = Ne(typeof globalThis == "object" && globalThis) || Ne(typeof window == "object" && window) || Ne(typeof self == "object" && self) || Ne(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      });
      var se = S((hc, Jr) => {
        Jr.exports = function(e) {
          try {
            return !!e();
          } catch {
            return true;
          }
        };
      });
      var ae = S((pc, Zr) => {
        var qs = se();
        Zr.exports = !qs(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      });
      var Oe = S((fc, eu) => {
        var Is = se();
        eu.exports = !Is(function() {
          var e = function() {
          }.bind();
          return typeof e != "function" || e.hasOwnProperty("prototype");
        });
      });
      var De = S((dc, ru) => {
        var Rs = Oe(), qe = Function.prototype.call;
        ru.exports = Rs ? qe.bind(qe) : function() {
          return qe.apply(qe, arguments);
        };
      });
      var su = S((nu) => {
        "use strict";
        var uu = {}.propertyIsEnumerable, tu = Object.getOwnPropertyDescriptor, xs = tu && !uu.call({ 1: 2 }, 1);
        nu.f = xs ? function(r) {
          var u = tu(this, r);
          return !!u && u.enumerable;
        } : uu;
      });
      var Ie = S((Cc, iu) => {
        iu.exports = function(e, r) {
          return { enumerable: !(e & 1), configurable: !(e & 2), writable: !(e & 4), value: r };
        };
      });
      var re = S((mc, Du) => {
        var au = Oe(), ou = Function.prototype, er = ou.call, Ps = au && ou.bind.bind(er, er);
        Du.exports = au ? Ps : function(e) {
          return function() {
            return er.apply(e, arguments);
          };
        };
      });
      var me = S((gc, cu) => {
        var lu = re(), ks = lu({}.toString), Ls = lu("".slice);
        cu.exports = function(e) {
          return Ls(ks(e), 8, -1);
        };
      });
      var pu = S((Fc, hu) => {
        var $s = re(), Ms = se(), js = me(), rr = Object, Us = $s("".split);
        hu.exports = Ms(function() {
          return !rr("z").propertyIsEnumerable(0);
        }) ? function(e) {
          return js(e) == "String" ? Us(e, "") : rr(e);
        } : rr;
      });
      var Re = S((Ac, fu) => {
        fu.exports = function(e) {
          return e == null;
        };
      });
      var ur = S((vc, du) => {
        var Gs = Re(), Vs = TypeError;
        du.exports = function(e) {
          if (Gs(e))
            throw Vs("Can't call method on " + e);
          return e;
        };
      });
      var xe = S((_c, Eu) => {
        var Xs = pu(), Hs = ur();
        Eu.exports = function(e) {
          return Xs(Hs(e));
        };
      });
      var nr = S((Sc, Cu) => {
        var tr = typeof document == "object" && document.all, zs = typeof tr > "u" && tr !== void 0;
        Cu.exports = { all: tr, IS_HTMLDDA: zs };
      });
      var Y = S((yc, gu) => {
        var mu = nr(), Ws = mu.all;
        gu.exports = mu.IS_HTMLDDA ? function(e) {
          return typeof e == "function" || e === Ws;
        } : function(e) {
          return typeof e == "function";
        };
      });
      var le = S((Tc, vu) => {
        var Fu = Y(), Au = nr(), Ys = Au.all;
        vu.exports = Au.IS_HTMLDDA ? function(e) {
          return typeof e == "object" ? e !== null : Fu(e) || e === Ys;
        } : function(e) {
          return typeof e == "object" ? e !== null : Fu(e);
        };
      });
      var ge = S((Bc, _u) => {
        var sr = ee(), Qs = Y(), Ks = function(e) {
          return Qs(e) ? e : void 0;
        };
        _u.exports = function(e, r) {
          return arguments.length < 2 ? Ks(sr[e]) : sr[e] && sr[e][r];
        };
      });
      var ir = S((bc, Su) => {
        var Js = re();
        Su.exports = Js({}.isPrototypeOf);
      });
      var Tu = S((wc, yu) => {
        var Zs = ge();
        yu.exports = Zs("navigator", "userAgent") || "";
      });
      var Iu = S((Nc, qu) => {
        var Ou = ee(), ar = Tu(), Bu = Ou.process, bu = Ou.Deno, wu = Bu && Bu.versions || bu && bu.version, Nu = wu && wu.v8, ue, Pe;
        Nu && (ue = Nu.split("."), Pe = ue[0] > 0 && ue[0] < 4 ? 1 : +(ue[0] + ue[1]));
        !Pe && ar && (ue = ar.match(/Edge\/(\d+)/), (!ue || ue[1] >= 74) && (ue = ar.match(/Chrome\/(\d+)/), ue && (Pe = +ue[1])));
        qu.exports = Pe;
      });
      var or = S((Oc, xu) => {
        var Ru = Iu(), ei = se();
        xu.exports = !!Object.getOwnPropertySymbols && !ei(function() {
          var e = Symbol();
          return !String(e) || !(Object(e) instanceof Symbol) || !Symbol.sham && Ru && Ru < 41;
        });
      });
      var Dr = S((qc, Pu) => {
        var ri = or();
        Pu.exports = ri && !Symbol.sham && typeof Symbol.iterator == "symbol";
      });
      var lr = S((Ic, ku) => {
        var ui = ge(), ti = Y(), ni = ir(), si = Dr(), ii = Object;
        ku.exports = si ? function(e) {
          return typeof e == "symbol";
        } : function(e) {
          var r = ui("Symbol");
          return ti(r) && ni(r.prototype, ii(e));
        };
      });
      var ke = S((Rc, Lu) => {
        var ai = String;
        Lu.exports = function(e) {
          try {
            return ai(e);
          } catch {
            return "Object";
          }
        };
      });
      var Fe = S((xc, $u) => {
        var oi = Y(), Di = ke(), li = TypeError;
        $u.exports = function(e) {
          if (oi(e))
            return e;
          throw li(Di(e) + " is not a function");
        };
      });
      var Le = S((Pc, Mu) => {
        var ci = Fe(), hi = Re();
        Mu.exports = function(e, r) {
          var u = e[r];
          return hi(u) ? void 0 : ci(u);
        };
      });
      var Uu = S((kc, ju) => {
        var cr = De(), hr = Y(), pr = le(), pi = TypeError;
        ju.exports = function(e, r) {
          var u, n;
          if (r === "string" && hr(u = e.toString) && !pr(n = cr(u, e)) || hr(u = e.valueOf) && !pr(n = cr(u, e)) || r !== "string" && hr(u = e.toString) && !pr(n = cr(u, e)))
            return n;
          throw pi("Can't convert object to primitive value");
        };
      });
      var Vu = S((Lc, Gu) => {
        Gu.exports = false;
      });
      var $e = S(($c, Hu) => {
        var Xu = ee(), fi = Object.defineProperty;
        Hu.exports = function(e, r) {
          try {
            fi(Xu, e, { value: r, configurable: true, writable: true });
          } catch {
            Xu[e] = r;
          }
          return r;
        };
      });
      var Me = S((Mc, Wu) => {
        var di = ee(), Ei = $e(), zu = "__core-js_shared__", Ci = di[zu] || Ei(zu, {});
        Wu.exports = Ci;
      });
      var fr = S((jc, Qu) => {
        var mi = Vu(), Yu = Me();
        (Qu.exports = function(e, r) {
          return Yu[e] || (Yu[e] = r !== void 0 ? r : {});
        })("versions", []).push({ version: "3.26.1", mode: mi ? "pure" : "global", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE", source: "https://github.com/zloirock/core-js" });
      });
      var dr = S((Uc, Ku) => {
        var gi = ur(), Fi = Object;
        Ku.exports = function(e) {
          return Fi(gi(e));
        };
      });
      var oe = S((Gc, Ju) => {
        var Ai = re(), vi = dr(), _i = Ai({}.hasOwnProperty);
        Ju.exports = Object.hasOwn || function(r, u) {
          return _i(vi(r), u);
        };
      });
      var Er = S((Vc, Zu) => {
        var Si = re(), yi = 0, Ti = Math.random(), Bi = Si(1 .toString);
        Zu.exports = function(e) {
          return "Symbol(" + (e === void 0 ? "" : e) + ")_" + Bi(++yi + Ti, 36);
        };
      });
      var he = S((Xc, nt) => {
        var bi = ee(), wi = fr(), et = oe(), Ni = Er(), rt = or(), tt = Dr(), fe = wi("wks"), ce = bi.Symbol, ut = ce && ce.for, Oi = tt ? ce : ce && ce.withoutSetter || Ni;
        nt.exports = function(e) {
          if (!et(fe, e) || !(rt || typeof fe[e] == "string")) {
            var r = "Symbol." + e;
            rt && et(ce, e) ? fe[e] = ce[e] : tt && ut ? fe[e] = ut(r) : fe[e] = Oi(r);
          }
          return fe[e];
        };
      });
      var ot = S((Hc, at) => {
        var qi = De(), st = le(), it2 = lr(), Ii = Le(), Ri = Uu(), xi = he(), Pi = TypeError, ki = xi("toPrimitive");
        at.exports = function(e, r) {
          if (!st(e) || it2(e))
            return e;
          var u = Ii(e, ki), n;
          if (u) {
            if (r === void 0 && (r = "default"), n = qi(u, e, r), !st(n) || it2(n))
              return n;
            throw Pi("Can't convert object to primitive value");
          }
          return r === void 0 && (r = "number"), Ri(e, r);
        };
      });
      var je = S((zc, Dt) => {
        var Li = ot(), $i = lr();
        Dt.exports = function(e) {
          var r = Li(e, "string");
          return $i(r) ? r : r + "";
        };
      });
      var ht = S((Wc, ct) => {
        var Mi = ee(), lt = le(), Cr = Mi.document, ji = lt(Cr) && lt(Cr.createElement);
        ct.exports = function(e) {
          return ji ? Cr.createElement(e) : {};
        };
      });
      var mr = S((Yc, pt) => {
        var Ui = ae(), Gi = se(), Vi = ht();
        pt.exports = !Ui && !Gi(function() {
          return Object.defineProperty(Vi("div"), "a", { get: function() {
            return 7;
          } }).a != 7;
        });
      });
      var gr = S((dt) => {
        var Xi = ae(), Hi = De(), zi = su(), Wi = Ie(), Yi = xe(), Qi = je(), Ki = oe(), Ji = mr(), ft = Object.getOwnPropertyDescriptor;
        dt.f = Xi ? ft : function(r, u) {
          if (r = Yi(r), u = Qi(u), Ji)
            try {
              return ft(r, u);
            } catch {
            }
          if (Ki(r, u))
            return Wi(!Hi(zi.f, r, u), r[u]);
        };
      });
      var Ct = S((Kc, Et) => {
        var Zi = ae(), ea = se();
        Et.exports = Zi && ea(function() {
          return Object.defineProperty(function() {
          }, "prototype", { value: 42, writable: false }).prototype != 42;
        });
      });
      var de = S((Jc, mt) => {
        var ra = le(), ua = String, ta = TypeError;
        mt.exports = function(e) {
          if (ra(e))
            return e;
          throw ta(ua(e) + " is not an object");
        };
      });
      var Ae = S((Ft) => {
        var na = ae(), sa = mr(), ia = Ct(), Ue = de(), gt = je(), aa = TypeError, Fr = Object.defineProperty, oa = Object.getOwnPropertyDescriptor, Ar = "enumerable", vr = "configurable", _r = "writable";
        Ft.f = na ? ia ? function(r, u, n) {
          if (Ue(r), u = gt(u), Ue(n), typeof r == "function" && u === "prototype" && "value" in n && _r in n && !n[_r]) {
            var D = oa(r, u);
            D && D[_r] && (r[u] = n.value, n = { configurable: vr in n ? n[vr] : D[vr], enumerable: Ar in n ? n[Ar] : D[Ar], writable: false });
          }
          return Fr(r, u, n);
        } : Fr : function(r, u, n) {
          if (Ue(r), u = gt(u), Ue(n), sa)
            try {
              return Fr(r, u, n);
            } catch {
            }
          if ("get" in n || "set" in n)
            throw aa("Accessors not supported");
          return "value" in n && (r[u] = n.value), r;
        };
      });
      var Sr = S((e2, At) => {
        var Da = ae(), la = Ae(), ca = Ie();
        At.exports = Da ? function(e, r, u) {
          return la.f(e, r, ca(1, u));
        } : function(e, r, u) {
          return e[r] = u, e;
        };
      });
      var St = S((r2, _t) => {
        var yr = ae(), ha = oe(), vt = Function.prototype, pa = yr && Object.getOwnPropertyDescriptor, Tr = ha(vt, "name"), fa = Tr && function() {
        }.name === "something", da = Tr && (!yr || yr && pa(vt, "name").configurable);
        _t.exports = { EXISTS: Tr, PROPER: fa, CONFIGURABLE: da };
      });
      var br = S((u2, yt) => {
        var Ea = re(), Ca = Y(), Br = Me(), ma = Ea(Function.toString);
        Ca(Br.inspectSource) || (Br.inspectSource = function(e) {
          return ma(e);
        });
        yt.exports = Br.inspectSource;
      });
      var bt = S((t22, Bt) => {
        var ga = ee(), Fa = Y(), Tt = ga.WeakMap;
        Bt.exports = Fa(Tt) && /native code/.test(String(Tt));
      });
      var Ot = S((n2, Nt) => {
        var Aa = fr(), va = Er(), wt = Aa("keys");
        Nt.exports = function(e) {
          return wt[e] || (wt[e] = va(e));
        };
      });
      var wr = S((s2, qt) => {
        qt.exports = {};
      });
      var Pt = S((i2, xt) => {
        var _a = bt(), Rt = ee(), Sa = le(), ya = Sr(), Nr = oe(), Or = Me(), Ta = Ot(), Ba = wr(), It = "Object already initialized", qr = Rt.TypeError, ba = Rt.WeakMap, Ge, ve, Ve, wa = function(e) {
          return Ve(e) ? ve(e) : Ge(e, {});
        }, Na = function(e) {
          return function(r) {
            var u;
            if (!Sa(r) || (u = ve(r)).type !== e)
              throw qr("Incompatible receiver, " + e + " required");
            return u;
          };
        };
        _a || Or.state ? (te = Or.state || (Or.state = new ba()), te.get = te.get, te.has = te.has, te.set = te.set, Ge = function(e, r) {
          if (te.has(e))
            throw qr(It);
          return r.facade = e, te.set(e, r), r;
        }, ve = function(e) {
          return te.get(e) || {};
        }, Ve = function(e) {
          return te.has(e);
        }) : (pe = Ta("state"), Ba[pe] = true, Ge = function(e, r) {
          if (Nr(e, pe))
            throw qr(It);
          return r.facade = e, ya(e, pe, r), r;
        }, ve = function(e) {
          return Nr(e, pe) ? e[pe] : {};
        }, Ve = function(e) {
          return Nr(e, pe);
        });
        var te, pe;
        xt.exports = { set: Ge, get: ve, has: Ve, enforce: wa, getterFor: Na };
      });
      var $t = S((a2, Lt) => {
        var Oa = se(), qa = Y(), Xe = oe(), Ir = ae(), Ia = St().CONFIGURABLE, Ra = br(), kt = Pt(), xa = kt.enforce, Pa = kt.get, He = Object.defineProperty, ka = Ir && !Oa(function() {
          return He(function() {
          }, "length", { value: 8 }).length !== 8;
        }), La = String(String).split("String"), $a = Lt.exports = function(e, r, u) {
          String(r).slice(0, 7) === "Symbol(" && (r = "[" + String(r).replace(/^Symbol\(([^)]*)\)/, "$1") + "]"), u && u.getter && (r = "get " + r), u && u.setter && (r = "set " + r), (!Xe(e, "name") || Ia && e.name !== r) && (Ir ? He(e, "name", { value: r, configurable: true }) : e.name = r), ka && u && Xe(u, "arity") && e.length !== u.arity && He(e, "length", { value: u.arity });
          try {
            u && Xe(u, "constructor") && u.constructor ? Ir && He(e, "prototype", { writable: false }) : e.prototype && (e.prototype = void 0);
          } catch {
          }
          var n = xa(e);
          return Xe(n, "source") || (n.source = La.join(typeof r == "string" ? r : "")), e;
        };
        Function.prototype.toString = $a(function() {
          return qa(this) && Pa(this).source || Ra(this);
        }, "toString");
      });
      var jt = S((o2, Mt) => {
        var Ma = Y(), ja = Ae(), Ua = $t(), Ga = $e();
        Mt.exports = function(e, r, u, n) {
          n || (n = {});
          var D = n.enumerable, s = n.name !== void 0 ? n.name : r;
          if (Ma(u) && Ua(u, s, n), n.global)
            D ? e[r] = u : Ga(r, u);
          else {
            try {
              n.unsafe ? e[r] && (D = true) : delete e[r];
            } catch {
            }
            D ? e[r] = u : ja.f(e, r, { value: u, enumerable: false, configurable: !n.nonConfigurable, writable: !n.nonWritable });
          }
          return e;
        };
      });
      var Gt = S((D2, Ut) => {
        var Va = Math.ceil, Xa = Math.floor;
        Ut.exports = Math.trunc || function(r) {
          var u = +r;
          return (u > 0 ? Xa : Va)(u);
        };
      });
      var Rr = S((l2, Vt) => {
        var Ha = Gt();
        Vt.exports = function(e) {
          var r = +e;
          return r !== r || r === 0 ? 0 : Ha(r);
        };
      });
      var Ht = S((c2, Xt) => {
        var za = Rr(), Wa = Math.max, Ya = Math.min;
        Xt.exports = function(e, r) {
          var u = za(e);
          return u < 0 ? Wa(u + r, 0) : Ya(u, r);
        };
      });
      var Wt = S((h2, zt) => {
        var Qa = Rr(), Ka = Math.min;
        zt.exports = function(e) {
          return e > 0 ? Ka(Qa(e), 9007199254740991) : 0;
        };
      });
      var _e = S((p2, Yt) => {
        var Ja = Wt();
        Yt.exports = function(e) {
          return Ja(e.length);
        };
      });
      var Jt = S((f2, Kt) => {
        var Za = xe(), eo = Ht(), ro = _e(), Qt = function(e) {
          return function(r, u, n) {
            var D = Za(r), s = ro(D), i = eo(n, s), f;
            if (e && u != u) {
              for (; s > i; )
                if (f = D[i++], f != f)
                  return true;
            } else
              for (; s > i; i++)
                if ((e || i in D) && D[i] === u)
                  return e || i || 0;
            return !e && -1;
          };
        };
        Kt.exports = { includes: Qt(true), indexOf: Qt(false) };
      });
      var rn = S((d2, en) => {
        var uo = re(), xr = oe(), to = xe(), no = Jt().indexOf, so = wr(), Zt = uo([].push);
        en.exports = function(e, r) {
          var u = to(e), n = 0, D = [], s;
          for (s in u)
            !xr(so, s) && xr(u, s) && Zt(D, s);
          for (; r.length > n; )
            xr(u, s = r[n++]) && (~no(D, s) || Zt(D, s));
          return D;
        };
      });
      var tn = S((E2, un) => {
        un.exports = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"];
      });
      var sn = S((nn) => {
        var io = rn(), ao = tn(), oo = ao.concat("length", "prototype");
        nn.f = Object.getOwnPropertyNames || function(r) {
          return io(r, oo);
        };
      });
      var on = S((an) => {
        an.f = Object.getOwnPropertySymbols;
      });
      var ln = S((g2, Dn) => {
        var Do = ge(), lo = re(), co = sn(), ho = on(), po = de(), fo = lo([].concat);
        Dn.exports = Do("Reflect", "ownKeys") || function(r) {
          var u = co.f(po(r)), n = ho.f;
          return n ? fo(u, n(r)) : u;
        };
      });
      var pn = S((F2, hn) => {
        var cn = oe(), Eo = ln(), Co = gr(), mo = Ae();
        hn.exports = function(e, r, u) {
          for (var n = Eo(r), D = mo.f, s = Co.f, i = 0; i < n.length; i++) {
            var f = n[i];
            !cn(e, f) && !(u && cn(u, f)) && D(e, f, s(r, f));
          }
        };
      });
      var dn = S((A2, fn) => {
        var go = se(), Fo = Y(), Ao = /#|\.prototype\./, Se = function(e, r) {
          var u = _o[vo(e)];
          return u == yo ? true : u == So ? false : Fo(r) ? go(r) : !!r;
        }, vo = Se.normalize = function(e) {
          return String(e).replace(Ao, ".").toLowerCase();
        }, _o = Se.data = {}, So = Se.NATIVE = "N", yo = Se.POLYFILL = "P";
        fn.exports = Se;
      });
      var ze = S((v2, En) => {
        var Pr = ee(), To = gr().f, Bo = Sr(), bo = jt(), wo = $e(), No = pn(), Oo = dn();
        En.exports = function(e, r) {
          var u = e.target, n = e.global, D = e.stat, s, i, f, c, F, a;
          if (n ? i = Pr : D ? i = Pr[u] || wo(u, {}) : i = (Pr[u] || {}).prototype, i)
            for (f in r) {
              if (F = r[f], e.dontCallGetSet ? (a = To(i, f), c = a && a.value) : c = i[f], s = Oo(n ? f : u + (D ? "." : "#") + f, e.forced), !s && c !== void 0) {
                if (typeof F == typeof c)
                  continue;
                No(F, c);
              }
              (e.sham || c && c.sham) && Bo(F, "sham", true), bo(i, f, F, e);
            }
        };
      });
      var Cn = S(() => {
        var qo = ze(), kr = ee();
        qo({ global: true, forced: kr.globalThis !== kr }, { globalThis: kr });
      });
      var mn = S(() => {
        Cn();
      });
      var Lr = S((B2, gn) => {
        var Io = me();
        gn.exports = Array.isArray || function(r) {
          return Io(r) == "Array";
        };
      });
      var An = S((b2, Fn) => {
        var Ro = TypeError, xo = 9007199254740991;
        Fn.exports = function(e) {
          if (e > xo)
            throw Ro("Maximum allowed index exceeded");
          return e;
        };
      });
      var _n = S((w2, vn) => {
        var Po = me(), ko = re();
        vn.exports = function(e) {
          if (Po(e) === "Function")
            return ko(e);
        };
      });
      var $r = S((N2, yn) => {
        var Sn = _n(), Lo = Fe(), $o = Oe(), Mo = Sn(Sn.bind);
        yn.exports = function(e, r) {
          return Lo(e), r === void 0 ? e : $o ? Mo(e, r) : function() {
            return e.apply(r, arguments);
          };
        };
      });
      var bn = S((O2, Bn) => {
        "use strict";
        var jo = Lr(), Uo = _e(), Go = An(), Vo = $r(), Tn = function(e, r, u, n, D, s, i, f) {
          for (var c = D, F = 0, a = i ? Vo(i, f) : false, l, h; F < n; )
            F in u && (l = a ? a(u[F], F, r) : u[F], s > 0 && jo(l) ? (h = Uo(l), c = Tn(e, r, l, h, c, s - 1) - 1) : (Go(c + 1), e[c] = l), c++), F++;
          return c;
        };
        Bn.exports = Tn;
      });
      var On = S((q2, Nn) => {
        var Xo = he(), Ho = Xo("toStringTag"), wn = {};
        wn[Ho] = "z";
        Nn.exports = String(wn) === "[object z]";
      });
      var Mr = S((I2, qn) => {
        var zo = On(), Wo = Y(), We = me(), Yo = he(), Qo = Yo("toStringTag"), Ko = Object, Jo = We(function() {
          return arguments;
        }()) == "Arguments", Zo = function(e, r) {
          try {
            return e[r];
          } catch {
          }
        };
        qn.exports = zo ? We : function(e) {
          var r, u, n;
          return e === void 0 ? "Undefined" : e === null ? "Null" : typeof (u = Zo(r = Ko(e), Qo)) == "string" ? u : Jo ? We(r) : (n = We(r)) == "Object" && Wo(r.callee) ? "Arguments" : n;
        };
      });
      var Ln = S((R2, kn) => {
        var eD = re(), rD = se(), In = Y(), uD = Mr(), tD = ge(), nD = br(), Rn = function() {
        }, sD = [], xn = tD("Reflect", "construct"), jr = /^\s*(?:class|function)\b/, iD = eD(jr.exec), aD = !jr.exec(Rn), ye = function(r) {
          if (!In(r))
            return false;
          try {
            return xn(Rn, sD, r), true;
          } catch {
            return false;
          }
        }, Pn = function(r) {
          if (!In(r))
            return false;
          switch (uD(r)) {
            case "AsyncFunction":
            case "GeneratorFunction":
            case "AsyncGeneratorFunction":
              return false;
          }
          try {
            return aD || !!iD(jr, nD(r));
          } catch {
            return true;
          }
        };
        Pn.sham = true;
        kn.exports = !xn || rD(function() {
          var e;
          return ye(ye.call) || !ye(Object) || !ye(function() {
            e = true;
          }) || e;
        }) ? Pn : ye;
      });
      var Un = S((x2, jn) => {
        var $n = Lr(), oD = Ln(), DD = le(), lD = he(), cD = lD("species"), Mn = Array;
        jn.exports = function(e) {
          var r;
          return $n(e) && (r = e.constructor, oD(r) && (r === Mn || $n(r.prototype)) ? r = void 0 : DD(r) && (r = r[cD], r === null && (r = void 0))), r === void 0 ? Mn : r;
        };
      });
      var Vn = S((P2, Gn) => {
        var hD = Un();
        Gn.exports = function(e, r) {
          return new (hD(e))(r === 0 ? 0 : r);
        };
      });
      var Xn = S(() => {
        "use strict";
        var pD = ze(), fD = bn(), dD = Fe(), ED = dr(), CD = _e(), mD = Vn();
        pD({ target: "Array", proto: true }, { flatMap: function(r) {
          var u = ED(this), n = CD(u), D;
          return dD(r), D = mD(u, 0), D.length = fD(D, u, u, n, 0, 1, r, arguments.length > 1 ? arguments[1] : void 0), D;
        } });
      });
      var Ur = S(($2, Hn) => {
        Hn.exports = {};
      });
      var Wn = S((M2, zn) => {
        var gD = he(), FD = Ur(), AD = gD("iterator"), vD = Array.prototype;
        zn.exports = function(e) {
          return e !== void 0 && (FD.Array === e || vD[AD] === e);
        };
      });
      var Gr = S((j2, Qn) => {
        var _D = Mr(), Yn = Le(), SD = Re(), yD = Ur(), TD = he(), BD = TD("iterator");
        Qn.exports = function(e) {
          if (!SD(e))
            return Yn(e, BD) || Yn(e, "@@iterator") || yD[_D(e)];
        };
      });
      var Jn = S((U2, Kn) => {
        var bD = De(), wD = Fe(), ND = de(), OD = ke(), qD = Gr(), ID = TypeError;
        Kn.exports = function(e, r) {
          var u = arguments.length < 2 ? qD(e) : r;
          if (wD(u))
            return ND(bD(u, e));
          throw ID(OD(e) + " is not iterable");
        };
      });
      var rs = S((G2, es) => {
        var RD = De(), Zn = de(), xD = Le();
        es.exports = function(e, r, u) {
          var n, D;
          Zn(e);
          try {
            if (n = xD(e, "return"), !n) {
              if (r === "throw")
                throw u;
              return u;
            }
            n = RD(n, e);
          } catch (s) {
            D = true, n = s;
          }
          if (r === "throw")
            throw u;
          if (D)
            throw n;
          return Zn(n), u;
        };
      });
      var is = S((V2, ss) => {
        var PD = $r(), kD = De(), LD = de(), $D = ke(), MD = Wn(), jD = _e(), us = ir(), UD = Jn(), GD = Gr(), ts = rs(), VD = TypeError, Ye = function(e, r) {
          this.stopped = e, this.result = r;
        }, ns = Ye.prototype;
        ss.exports = function(e, r, u) {
          var n = u && u.that, D = !!(u && u.AS_ENTRIES), s = !!(u && u.IS_RECORD), i = !!(u && u.IS_ITERATOR), f = !!(u && u.INTERRUPTED), c = PD(r, n), F, a, l, h, C, d, m, T = function(g) {
            return F && ts(F, "normal", g), new Ye(true, g);
          }, w = function(g) {
            return D ? (LD(g), f ? c(g[0], g[1], T) : c(g[0], g[1])) : f ? c(g, T) : c(g);
          };
          if (s)
            F = e.iterator;
          else if (i)
            F = e;
          else {
            if (a = GD(e), !a)
              throw VD($D(e) + " is not iterable");
            if (MD(a)) {
              for (l = 0, h = jD(e); h > l; l++)
                if (C = w(e[l]), C && us(ns, C))
                  return C;
              return new Ye(false);
            }
            F = UD(e, a);
          }
          for (d = s ? e.next : F.next; !(m = kD(d, F)).done; ) {
            try {
              C = w(m.value);
            } catch (g) {
              ts(F, "throw", g);
            }
            if (typeof C == "object" && C && us(ns, C))
              return C;
          }
          return new Ye(false);
        };
      });
      var os = S((X2, as) => {
        "use strict";
        var XD = je(), HD = Ae(), zD = Ie();
        as.exports = function(e, r, u) {
          var n = XD(r);
          n in e ? HD.f(e, n, zD(0, u)) : e[n] = u;
        };
      });
      var Ds = S(() => {
        var WD = ze(), YD = is(), QD = os();
        WD({ target: "Object", stat: true }, { fromEntries: function(r) {
          var u = {};
          return YD(r, function(n, D) {
            QD(u, n, D);
          }, { AS_ENTRIES: true }), u;
        } });
      });
      var Dc = S((W2, Os) => {
        var KD = ["cliName", "cliCategory", "cliDescription"];
        function JD(e, r) {
          if (e == null)
            return {};
          var u = ZD(e, r), n, D;
          if (Object.getOwnPropertySymbols) {
            var s = Object.getOwnPropertySymbols(e);
            for (D = 0; D < s.length; D++)
              n = s[D], !(r.indexOf(n) >= 0) && Object.prototype.propertyIsEnumerable.call(e, n) && (u[n] = e[n]);
          }
          return u;
        }
        function ZD(e, r) {
          if (e == null)
            return {};
          var u = {}, n = Object.keys(e), D, s;
          for (s = 0; s < n.length; s++)
            D = n[s], !(r.indexOf(D) >= 0) && (u[D] = e[D]);
          return u;
        }
        mn();
        Xn();
        Ds();
        var el = Object.create, Je = Object.defineProperty, rl = Object.getOwnPropertyDescriptor, Xr = Object.getOwnPropertyNames, ul = Object.getPrototypeOf, tl = Object.prototype.hasOwnProperty, Ee = (e, r) => function() {
          return e && (r = (0, e[Xr(e)[0]])(e = 0)), r;
        }, I = (e, r) => function() {
          return r || (0, e[Xr(e)[0]])((r = { exports: {} }).exports, r), r.exports;
        }, ps = (e, r) => {
          for (var u in r)
            Je(e, u, { get: r[u], enumerable: true });
        }, fs2 = (e, r, u, n) => {
          if (r && typeof r == "object" || typeof r == "function")
            for (let D of Xr(r))
              !tl.call(e, D) && D !== u && Je(e, D, { get: () => r[D], enumerable: !(n = rl(r, D)) || n.enumerable });
          return e;
        }, nl = (e, r, u) => (u = e != null ? el(ul(e)) : {}, fs2(r || !e || !e.__esModule ? Je(u, "default", { value: e, enumerable: true }) : u, e)), ds = (e) => fs2(Je({}, "__esModule", { value: true }), e), Te, q = Ee({ "<define:process>"() {
          Te = { env: {}, argv: [] };
        } }), Es = I({ "node_modules/angular-html-parser/lib/compiler/src/chars.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true }), e.$EOF = 0, e.$BSPACE = 8, e.$TAB = 9, e.$LF = 10, e.$VTAB = 11, e.$FF = 12, e.$CR = 13, e.$SPACE = 32, e.$BANG = 33, e.$DQ = 34, e.$HASH = 35, e.$$ = 36, e.$PERCENT = 37, e.$AMPERSAND = 38, e.$SQ = 39, e.$LPAREN = 40, e.$RPAREN = 41, e.$STAR = 42, e.$PLUS = 43, e.$COMMA = 44, e.$MINUS = 45, e.$PERIOD = 46, e.$SLASH = 47, e.$COLON = 58, e.$SEMICOLON = 59, e.$LT = 60, e.$EQ = 61, e.$GT = 62, e.$QUESTION = 63, e.$0 = 48, e.$7 = 55, e.$9 = 57, e.$A = 65, e.$E = 69, e.$F = 70, e.$X = 88, e.$Z = 90, e.$LBRACKET = 91, e.$BACKSLASH = 92, e.$RBRACKET = 93, e.$CARET = 94, e.$_ = 95, e.$a = 97, e.$b = 98, e.$e = 101, e.$f = 102, e.$n = 110, e.$r = 114, e.$t = 116, e.$u = 117, e.$v = 118, e.$x = 120, e.$z = 122, e.$LBRACE = 123, e.$BAR = 124, e.$RBRACE = 125, e.$NBSP = 160, e.$PIPE = 124, e.$TILDA = 126, e.$AT = 64, e.$BT = 96;
          function r(f) {
            return f >= e.$TAB && f <= e.$SPACE || f == e.$NBSP;
          }
          e.isWhitespace = r;
          function u(f) {
            return e.$0 <= f && f <= e.$9;
          }
          e.isDigit = u;
          function n(f) {
            return f >= e.$a && f <= e.$z || f >= e.$A && f <= e.$Z;
          }
          e.isAsciiLetter = n;
          function D(f) {
            return f >= e.$a && f <= e.$f || f >= e.$A && f <= e.$F || u(f);
          }
          e.isAsciiHexDigit = D;
          function s(f) {
            return f === e.$LF || f === e.$CR;
          }
          e.isNewLine = s;
          function i(f) {
            return e.$0 <= f && f <= e.$7;
          }
          e.isOctalDigit = i;
        } }), sl = I({ "node_modules/angular-html-parser/lib/compiler/src/aot/static_symbol.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = class {
            constructor(n, D, s) {
              this.filePath = n, this.name = D, this.members = s;
            }
            assertNoMembers() {
              if (this.members.length)
                throw new Error(`Illegal state: symbol without members expected, but got ${JSON.stringify(this)}.`);
            }
          };
          e.StaticSymbol = r;
          var u = class {
            constructor() {
              this.cache = /* @__PURE__ */ new Map();
            }
            get(n, D, s) {
              s = s || [];
              let i = s.length ? `.${s.join(".")}` : "", f = `"${n}".${D}${i}`, c = this.cache.get(f);
              return c || (c = new r(n, D, s), this.cache.set(f, c)), c;
            }
          };
          e.StaticSymbolCache = u;
        } }), il = I({ "node_modules/angular-html-parser/lib/compiler/src/util.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = /-+([a-z0-9])/g;
          function u(o) {
            return o.replace(r, function() {
              for (var E = arguments.length, p = new Array(E), A = 0; A < E; A++)
                p[A] = arguments[A];
              return p[1].toUpperCase();
            });
          }
          e.dashCaseToCamelCase = u;
          function n(o, E) {
            return s(o, ":", E);
          }
          e.splitAtColon = n;
          function D(o, E) {
            return s(o, ".", E);
          }
          e.splitAtPeriod = D;
          function s(o, E, p) {
            let A = o.indexOf(E);
            return A == -1 ? p : [o.slice(0, A).trim(), o.slice(A + 1).trim()];
          }
          function i(o, E, p) {
            return Array.isArray(o) ? E.visitArray(o, p) : g(o) ? E.visitStringMap(o, p) : o == null || typeof o == "string" || typeof o == "number" || typeof o == "boolean" ? E.visitPrimitive(o, p) : E.visitOther(o, p);
          }
          e.visitValue = i;
          function f(o) {
            return o != null;
          }
          e.isDefined = f;
          function c(o) {
            return o === void 0 ? null : o;
          }
          e.noUndefined = c;
          var F = class {
            visitArray(o, E) {
              return o.map((p) => i(p, this, E));
            }
            visitStringMap(o, E) {
              let p = {};
              return Object.keys(o).forEach((A) => {
                p[A] = i(o[A], this, E);
              }), p;
            }
            visitPrimitive(o, E) {
              return o;
            }
            visitOther(o, E) {
              return o;
            }
          };
          e.ValueTransformer = F, e.SyncAsync = { assertSync: (o) => {
            if (_(o))
              throw new Error("Illegal state: value cannot be a promise");
            return o;
          }, then: (o, E) => _(o) ? o.then(E) : E(o), all: (o) => o.some(_) ? Promise.all(o) : o };
          function a(o) {
            throw new Error(`Internal Error: ${o}`);
          }
          e.error = a;
          function l(o, E) {
            let p = Error(o);
            return p[h] = true, E && (p[C] = E), p;
          }
          e.syntaxError = l;
          var h = "ngSyntaxError", C = "ngParseErrors";
          function d(o) {
            return o[h];
          }
          e.isSyntaxError = d;
          function m(o) {
            return o[C] || [];
          }
          e.getParseErrors = m;
          function T(o) {
            return o.replace(/([.*+?^=!:${}()|[\]\/\\])/g, "\\$1");
          }
          e.escapeRegExp = T;
          var w = Object.getPrototypeOf({});
          function g(o) {
            return typeof o == "object" && o !== null && Object.getPrototypeOf(o) === w;
          }
          function N(o) {
            let E = "";
            for (let p = 0; p < o.length; p++) {
              let A = o.charCodeAt(p);
              if (A >= 55296 && A <= 56319 && o.length > p + 1) {
                let P = o.charCodeAt(p + 1);
                P >= 56320 && P <= 57343 && (p++, A = (A - 55296 << 10) + P - 56320 + 65536);
              }
              A <= 127 ? E += String.fromCharCode(A) : A <= 2047 ? E += String.fromCharCode(A >> 6 & 31 | 192, A & 63 | 128) : A <= 65535 ? E += String.fromCharCode(A >> 12 | 224, A >> 6 & 63 | 128, A & 63 | 128) : A <= 2097151 && (E += String.fromCharCode(A >> 18 & 7 | 240, A >> 12 & 63 | 128, A >> 6 & 63 | 128, A & 63 | 128));
            }
            return E;
          }
          e.utf8Encode = N;
          function R(o) {
            if (typeof o == "string")
              return o;
            if (o instanceof Array)
              return "[" + o.map(R).join(", ") + "]";
            if (o == null)
              return "" + o;
            if (o.overriddenName)
              return `${o.overriddenName}`;
            if (o.name)
              return `${o.name}`;
            if (!o.toString)
              return "object";
            let E = o.toString();
            if (E == null)
              return "" + E;
            let p = E.indexOf(`
`);
            return p === -1 ? E : E.substring(0, p);
          }
          e.stringify = R;
          function j(o) {
            return typeof o == "function" && o.hasOwnProperty("__forward_ref__") ? o() : o;
          }
          e.resolveForwardRef = j;
          function _(o) {
            return !!o && typeof o.then == "function";
          }
          e.isPromise = _;
          var O = class {
            constructor(o) {
              this.full = o;
              let E = o.split(".");
              this.major = E[0], this.minor = E[1], this.patch = E.slice(2).join(".");
            }
          };
          e.Version = O;
          var x = typeof window < "u" && window, k = typeof self < "u" && typeof WorkerGlobalScope < "u" && self instanceof WorkerGlobalScope && self, $2 = typeof globalThis < "u" && globalThis, t3 = $2 || x || k;
          e.global = t3;
        } }), al = I({ "node_modules/angular-html-parser/lib/compiler/src/compile_metadata.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = sl(), u = il(), n = /^(?:(?:\[([^\]]+)\])|(?:\(([^\)]+)\)))|(\@[-\w]+)$/;
          function D(p) {
            return p.replace(/\W/g, "_");
          }
          e.sanitizeIdentifier = D;
          var s = 0;
          function i(p) {
            if (!p || !p.reference)
              return null;
            let A = p.reference;
            if (A instanceof r.StaticSymbol)
              return A.name;
            if (A.__anonymousType)
              return A.__anonymousType;
            let P = u.stringify(A);
            return P.indexOf("(") >= 0 ? (P = `anonymous_${s++}`, A.__anonymousType = P) : P = D(P), P;
          }
          e.identifierName = i;
          function f(p) {
            let A = p.reference;
            return A instanceof r.StaticSymbol ? A.filePath : `./${u.stringify(A)}`;
          }
          e.identifierModuleUrl = f;
          function c(p, A) {
            return `View_${i({ reference: p })}_${A}`;
          }
          e.viewClassName = c;
          function F(p) {
            return `RenderType_${i({ reference: p })}`;
          }
          e.rendererTypeName = F;
          function a(p) {
            return `HostView_${i({ reference: p })}`;
          }
          e.hostViewClassName = a;
          function l(p) {
            return `${i({ reference: p })}NgFactory`;
          }
          e.componentFactoryName = l;
          var h;
          (function(p) {
            p[p.Pipe = 0] = "Pipe", p[p.Directive = 1] = "Directive", p[p.NgModule = 2] = "NgModule", p[p.Injectable = 3] = "Injectable";
          })(h = e.CompileSummaryKind || (e.CompileSummaryKind = {}));
          function C(p) {
            return p.value != null ? D(p.value) : i(p.identifier);
          }
          e.tokenName = C;
          function d(p) {
            return p.identifier != null ? p.identifier.reference : p.value;
          }
          e.tokenReference = d;
          var m = class {
            constructor() {
              let { moduleUrl: p, styles: A, styleUrls: P } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
              this.moduleUrl = p || null, this.styles = _(A), this.styleUrls = _(P);
            }
          };
          e.CompileStylesheetMetadata = m;
          var T = class {
            constructor(p) {
              let { encapsulation: A, template: P, templateUrl: M, htmlAst: z, styles: V, styleUrls: X, externalStylesheets: H, animations: Q, ngContentSelectors: K, interpolation: J, isInline: v, preserveWhitespaces: y } = p;
              if (this.encapsulation = A, this.template = P, this.templateUrl = M, this.htmlAst = z, this.styles = _(V), this.styleUrls = _(X), this.externalStylesheets = _(H), this.animations = Q ? x(Q) : [], this.ngContentSelectors = K || [], J && J.length != 2)
                throw new Error("'interpolation' should have a start and an end symbol.");
              this.interpolation = J, this.isInline = v, this.preserveWhitespaces = y;
            }
            toSummary() {
              return { ngContentSelectors: this.ngContentSelectors, encapsulation: this.encapsulation, styles: this.styles, animations: this.animations };
            }
          };
          e.CompileTemplateMetadata = T;
          var w = class {
            static create(p) {
              let { isHost: A, type: P, isComponent: M, selector: z, exportAs: V, changeDetection: X, inputs: H, outputs: Q, host: K, providers: J, viewProviders: v, queries: y, guards: B, viewQueries: b, entryComponents: L, template: U, componentViewType: G, rendererType: W, componentFactory: ne } = p, be = {}, we = {}, Wr = {};
              K != null && Object.keys(K).forEach((Z) => {
                let ie = K[Z], Ce = Z.match(n);
                Ce === null ? Wr[Z] = ie : Ce[1] != null ? we[Ce[1]] = ie : Ce[2] != null && (be[Ce[2]] = ie);
              });
              let Yr = {};
              H != null && H.forEach((Z) => {
                let ie = u.splitAtColon(Z, [Z, Z]);
                Yr[ie[0]] = ie[1];
              });
              let Qr = {};
              return Q != null && Q.forEach((Z) => {
                let ie = u.splitAtColon(Z, [Z, Z]);
                Qr[ie[0]] = ie[1];
              }), new w({ isHost: A, type: P, isComponent: !!M, selector: z, exportAs: V, changeDetection: X, inputs: Yr, outputs: Qr, hostListeners: be, hostProperties: we, hostAttributes: Wr, providers: J, viewProviders: v, queries: y, guards: B, viewQueries: b, entryComponents: L, template: U, componentViewType: G, rendererType: W, componentFactory: ne });
            }
            constructor(p) {
              let { isHost: A, type: P, isComponent: M, selector: z, exportAs: V, changeDetection: X, inputs: H, outputs: Q, hostListeners: K, hostProperties: J, hostAttributes: v, providers: y, viewProviders: B, queries: b, guards: L, viewQueries: U, entryComponents: G, template: W, componentViewType: ne, rendererType: be, componentFactory: we } = p;
              this.isHost = !!A, this.type = P, this.isComponent = M, this.selector = z, this.exportAs = V, this.changeDetection = X, this.inputs = H, this.outputs = Q, this.hostListeners = K, this.hostProperties = J, this.hostAttributes = v, this.providers = _(y), this.viewProviders = _(B), this.queries = _(b), this.guards = L, this.viewQueries = _(U), this.entryComponents = _(G), this.template = W, this.componentViewType = ne, this.rendererType = be, this.componentFactory = we;
            }
            toSummary() {
              return { summaryKind: h.Directive, type: this.type, isComponent: this.isComponent, selector: this.selector, exportAs: this.exportAs, inputs: this.inputs, outputs: this.outputs, hostListeners: this.hostListeners, hostProperties: this.hostProperties, hostAttributes: this.hostAttributes, providers: this.providers, viewProviders: this.viewProviders, queries: this.queries, guards: this.guards, viewQueries: this.viewQueries, entryComponents: this.entryComponents, changeDetection: this.changeDetection, template: this.template && this.template.toSummary(), componentViewType: this.componentViewType, rendererType: this.rendererType, componentFactory: this.componentFactory };
            }
          };
          e.CompileDirectiveMetadata = w;
          var g = class {
            constructor(p) {
              let { type: A, name: P, pure: M } = p;
              this.type = A, this.name = P, this.pure = !!M;
            }
            toSummary() {
              return { summaryKind: h.Pipe, type: this.type, name: this.name, pure: this.pure };
            }
          };
          e.CompilePipeMetadata = g;
          var N = class {
          };
          e.CompileShallowModuleMetadata = N;
          var R = class {
            constructor(p) {
              let { type: A, providers: P, declaredDirectives: M, exportedDirectives: z, declaredPipes: V, exportedPipes: X, entryComponents: H, bootstrapComponents: Q, importedModules: K, exportedModules: J, schemas: v, transitiveModule: y, id: B } = p;
              this.type = A || null, this.declaredDirectives = _(M), this.exportedDirectives = _(z), this.declaredPipes = _(V), this.exportedPipes = _(X), this.providers = _(P), this.entryComponents = _(H), this.bootstrapComponents = _(Q), this.importedModules = _(K), this.exportedModules = _(J), this.schemas = _(v), this.id = B || null, this.transitiveModule = y || null;
            }
            toSummary() {
              let p = this.transitiveModule;
              return { summaryKind: h.NgModule, type: this.type, entryComponents: p.entryComponents, providers: p.providers, modules: p.modules, exportedDirectives: p.exportedDirectives, exportedPipes: p.exportedPipes };
            }
          };
          e.CompileNgModuleMetadata = R;
          var j = class {
            constructor() {
              this.directivesSet = /* @__PURE__ */ new Set(), this.directives = [], this.exportedDirectivesSet = /* @__PURE__ */ new Set(), this.exportedDirectives = [], this.pipesSet = /* @__PURE__ */ new Set(), this.pipes = [], this.exportedPipesSet = /* @__PURE__ */ new Set(), this.exportedPipes = [], this.modulesSet = /* @__PURE__ */ new Set(), this.modules = [], this.entryComponentsSet = /* @__PURE__ */ new Set(), this.entryComponents = [], this.providers = [];
            }
            addProvider(p, A) {
              this.providers.push({ provider: p, module: A });
            }
            addDirective(p) {
              this.directivesSet.has(p.reference) || (this.directivesSet.add(p.reference), this.directives.push(p));
            }
            addExportedDirective(p) {
              this.exportedDirectivesSet.has(p.reference) || (this.exportedDirectivesSet.add(p.reference), this.exportedDirectives.push(p));
            }
            addPipe(p) {
              this.pipesSet.has(p.reference) || (this.pipesSet.add(p.reference), this.pipes.push(p));
            }
            addExportedPipe(p) {
              this.exportedPipesSet.has(p.reference) || (this.exportedPipesSet.add(p.reference), this.exportedPipes.push(p));
            }
            addModule(p) {
              this.modulesSet.has(p.reference) || (this.modulesSet.add(p.reference), this.modules.push(p));
            }
            addEntryComponent(p) {
              this.entryComponentsSet.has(p.componentType) || (this.entryComponentsSet.add(p.componentType), this.entryComponents.push(p));
            }
          };
          e.TransitiveCompileNgModuleMetadata = j;
          function _(p) {
            return p || [];
          }
          var O = class {
            constructor(p, A) {
              let { useClass: P, useValue: M, useExisting: z, useFactory: V, deps: X, multi: H } = A;
              this.token = p, this.useClass = P || null, this.useValue = M, this.useExisting = z, this.useFactory = V || null, this.dependencies = X || null, this.multi = !!H;
            }
          };
          e.ProviderMeta = O;
          function x(p) {
            return p.reduce((A, P) => {
              let M = Array.isArray(P) ? x(P) : P;
              return A.concat(M);
            }, []);
          }
          e.flatten = x;
          function k(p) {
            return p.replace(/(\w+:\/\/[\w:-]+)?(\/+)?/, "ng:///");
          }
          function $2(p, A, P) {
            let M;
            return P.isInline ? A.type.reference instanceof r.StaticSymbol ? M = `${A.type.reference.filePath}.${A.type.reference.name}.html` : M = `${i(p)}/${i(A.type)}.html` : M = P.templateUrl, A.type.reference instanceof r.StaticSymbol ? M : k(M);
          }
          e.templateSourceUrl = $2;
          function t3(p, A) {
            let P = p.moduleUrl.split(/\/\\/g), M = P[P.length - 1];
            return k(`css/${A}${M}.ngstyle.js`);
          }
          e.sharedStylesheetJitUrl = t3;
          function o(p) {
            return k(`${i(p.type)}/module.ngfactory.js`);
          }
          e.ngModuleJitUrl = o;
          function E(p, A) {
            return k(`${i(p)}/${i(A.type)}.ngfactory.js`);
          }
          e.templateJitUrl = E;
        } }), Be = I({ "node_modules/angular-html-parser/lib/compiler/src/parse_util.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Es(), u = al(), n = class {
            constructor(a, l, h, C) {
              this.file = a, this.offset = l, this.line = h, this.col = C;
            }
            toString() {
              return this.offset != null ? `${this.file.url}@${this.line}:${this.col}` : this.file.url;
            }
            moveBy(a) {
              let l = this.file.content, h = l.length, C = this.offset, d = this.line, m = this.col;
              for (; C > 0 && a < 0; )
                if (C--, a++, l.charCodeAt(C) == r.$LF) {
                  d--;
                  let w = l.substr(0, C - 1).lastIndexOf(String.fromCharCode(r.$LF));
                  m = w > 0 ? C - w : C;
                } else
                  m--;
              for (; C < h && a > 0; ) {
                let T = l.charCodeAt(C);
                C++, a--, T == r.$LF ? (d++, m = 0) : m++;
              }
              return new n(this.file, C, d, m);
            }
            getContext(a, l) {
              let h = this.file.content, C = this.offset;
              if (C != null) {
                C > h.length - 1 && (C = h.length - 1);
                let d = C, m = 0, T = 0;
                for (; m < a && C > 0 && (C--, m++, !(h[C] == `
` && ++T == l)); )
                  ;
                for (m = 0, T = 0; m < a && d < h.length - 1 && (d++, m++, !(h[d] == `
` && ++T == l)); )
                  ;
                return { before: h.substring(C, this.offset), after: h.substring(this.offset, d + 1) };
              }
              return null;
            }
          };
          e.ParseLocation = n;
          var D = class {
            constructor(a, l) {
              this.content = a, this.url = l;
            }
          };
          e.ParseSourceFile = D;
          var s = class {
            constructor(a, l) {
              let h = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
              this.start = a, this.end = l, this.details = h;
            }
            toString() {
              return this.start.file.content.substring(this.start.offset, this.end.offset);
            }
          };
          e.ParseSourceSpan = s, e.EMPTY_PARSE_LOCATION = new n(new D("", ""), 0, 0, 0), e.EMPTY_SOURCE_SPAN = new s(e.EMPTY_PARSE_LOCATION, e.EMPTY_PARSE_LOCATION);
          var i;
          (function(a) {
            a[a.WARNING = 0] = "WARNING", a[a.ERROR = 1] = "ERROR";
          })(i = e.ParseErrorLevel || (e.ParseErrorLevel = {}));
          var f = class {
            constructor(a, l) {
              let h = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : i.ERROR;
              this.span = a, this.msg = l, this.level = h;
            }
            contextualMessage() {
              let a = this.span.start.getContext(100, 3);
              return a ? `${this.msg} ("${a.before}[${i[this.level]} ->]${a.after}")` : this.msg;
            }
            toString() {
              let a = this.span.details ? `, ${this.span.details}` : "";
              return `${this.contextualMessage()}: ${this.span.start}${a}`;
            }
          };
          e.ParseError = f;
          function c(a, l) {
            let h = u.identifierModuleUrl(l), C = h != null ? `in ${a} ${u.identifierName(l)} in ${h}` : `in ${a} ${u.identifierName(l)}`, d = new D("", C);
            return new s(new n(d, -1, -1, -1), new n(d, -1, -1, -1));
          }
          e.typeSourceSpan = c;
          function F(a, l, h) {
            let C = `in ${a} ${l} in ${h}`, d = new D("", C);
            return new s(new n(d, -1, -1, -1), new n(d, -1, -1, -1));
          }
          e.r3JitTypeSourceSpan = F;
        } }), ol = I({ "src/utils/front-matter/parse.js"(e, r) {
          "use strict";
          q();
          var u = new RegExp("^(?<startDelimiter>-{3}|\\+{3})(?<language>[^\\n]*)\\n(?:|(?<value>.*?)\\n)(?<endDelimiter>\\k<startDelimiter>|\\.{3})[^\\S\\n]*(?:\\n|$)", "s");
          function n(D) {
            let s = D.match(u);
            if (!s)
              return { content: D };
            let { startDelimiter: i, language: f, value: c = "", endDelimiter: F } = s.groups, a = f.trim() || "yaml";
            if (i === "+++" && (a = "toml"), a !== "yaml" && i !== F)
              return { content: D };
            let [l] = s;
            return { frontMatter: { type: "front-matter", lang: a, value: c, startDelimiter: i, endDelimiter: F, raw: l.replace(/\n$/, "") }, content: l.replace(/[^\n]/g, " ") + D.slice(l.length) };
          }
          r.exports = n;
        } }), Cs = I({ "src/utils/get-last.js"(e, r) {
          "use strict";
          q();
          var u = (n) => n[n.length - 1];
          r.exports = u;
        } }), Dl = I({ "src/common/parser-create-error.js"(e, r) {
          "use strict";
          q();
          function u(n, D) {
            let s = new SyntaxError(n + " (" + D.start.line + ":" + D.start.column + ")");
            return s.loc = D, s;
          }
          r.exports = u;
        } }), ms = {};
        ps(ms, { default: () => ll });
        function ll(e) {
          if (typeof e != "string")
            throw new TypeError("Expected a string");
          return e.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
        }
        var cl = Ee({ "node_modules/escape-string-regexp/index.js"() {
          q();
        } }), gs = I({ "node_modules/semver/internal/debug.js"(e, r) {
          q();
          var u = typeof Te == "object" && Te.env && Te.env.NODE_DEBUG && /\bsemver\b/i.test(Te.env.NODE_DEBUG) ? function() {
            for (var n = arguments.length, D = new Array(n), s = 0; s < n; s++)
              D[s] = arguments[s];
            return console.error("SEMVER", ...D);
          } : () => {
          };
          r.exports = u;
        } }), Fs = I({ "node_modules/semver/internal/constants.js"(e, r) {
          q();
          var u = "2.0.0", n = 256, D = Number.MAX_SAFE_INTEGER || 9007199254740991, s = 16;
          r.exports = { SEMVER_SPEC_VERSION: u, MAX_LENGTH: n, MAX_SAFE_INTEGER: D, MAX_SAFE_COMPONENT_LENGTH: s };
        } }), hl = I({ "node_modules/semver/internal/re.js"(e, r) {
          q();
          var { MAX_SAFE_COMPONENT_LENGTH: u } = Fs(), n = gs();
          e = r.exports = {};
          var D = e.re = [], s = e.src = [], i = e.t = {}, f = 0, c = (F, a, l) => {
            let h = f++;
            n(F, h, a), i[F] = h, s[h] = a, D[h] = new RegExp(a, l ? "g" : void 0);
          };
          c("NUMERICIDENTIFIER", "0|[1-9]\\d*"), c("NUMERICIDENTIFIERLOOSE", "[0-9]+"), c("NONNUMERICIDENTIFIER", "\\d*[a-zA-Z-][a-zA-Z0-9-]*"), c("MAINVERSION", `(${s[i.NUMERICIDENTIFIER]})\\.(${s[i.NUMERICIDENTIFIER]})\\.(${s[i.NUMERICIDENTIFIER]})`), c("MAINVERSIONLOOSE", `(${s[i.NUMERICIDENTIFIERLOOSE]})\\.(${s[i.NUMERICIDENTIFIERLOOSE]})\\.(${s[i.NUMERICIDENTIFIERLOOSE]})`), c("PRERELEASEIDENTIFIER", `(?:${s[i.NUMERICIDENTIFIER]}|${s[i.NONNUMERICIDENTIFIER]})`), c("PRERELEASEIDENTIFIERLOOSE", `(?:${s[i.NUMERICIDENTIFIERLOOSE]}|${s[i.NONNUMERICIDENTIFIER]})`), c("PRERELEASE", `(?:-(${s[i.PRERELEASEIDENTIFIER]}(?:\\.${s[i.PRERELEASEIDENTIFIER]})*))`), c("PRERELEASELOOSE", `(?:-?(${s[i.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${s[i.PRERELEASEIDENTIFIERLOOSE]})*))`), c("BUILDIDENTIFIER", "[0-9A-Za-z-]+"), c("BUILD", `(?:\\+(${s[i.BUILDIDENTIFIER]}(?:\\.${s[i.BUILDIDENTIFIER]})*))`), c("FULLPLAIN", `v?${s[i.MAINVERSION]}${s[i.PRERELEASE]}?${s[i.BUILD]}?`), c("FULL", `^${s[i.FULLPLAIN]}$`), c("LOOSEPLAIN", `[v=\\s]*${s[i.MAINVERSIONLOOSE]}${s[i.PRERELEASELOOSE]}?${s[i.BUILD]}?`), c("LOOSE", `^${s[i.LOOSEPLAIN]}$`), c("GTLT", "((?:<|>)?=?)"), c("XRANGEIDENTIFIERLOOSE", `${s[i.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`), c("XRANGEIDENTIFIER", `${s[i.NUMERICIDENTIFIER]}|x|X|\\*`), c("XRANGEPLAIN", `[v=\\s]*(${s[i.XRANGEIDENTIFIER]})(?:\\.(${s[i.XRANGEIDENTIFIER]})(?:\\.(${s[i.XRANGEIDENTIFIER]})(?:${s[i.PRERELEASE]})?${s[i.BUILD]}?)?)?`), c("XRANGEPLAINLOOSE", `[v=\\s]*(${s[i.XRANGEIDENTIFIERLOOSE]})(?:\\.(${s[i.XRANGEIDENTIFIERLOOSE]})(?:\\.(${s[i.XRANGEIDENTIFIERLOOSE]})(?:${s[i.PRERELEASELOOSE]})?${s[i.BUILD]}?)?)?`), c("XRANGE", `^${s[i.GTLT]}\\s*${s[i.XRANGEPLAIN]}$`), c("XRANGELOOSE", `^${s[i.GTLT]}\\s*${s[i.XRANGEPLAINLOOSE]}$`), c("COERCE", `(^|[^\\d])(\\d{1,${u}})(?:\\.(\\d{1,${u}}))?(?:\\.(\\d{1,${u}}))?(?:$|[^\\d])`), c("COERCERTL", s[i.COERCE], true), c("LONETILDE", "(?:~>?)"), c("TILDETRIM", `(\\s*)${s[i.LONETILDE]}\\s+`, true), e.tildeTrimReplace = "$1~", c("TILDE", `^${s[i.LONETILDE]}${s[i.XRANGEPLAIN]}$`), c("TILDELOOSE", `^${s[i.LONETILDE]}${s[i.XRANGEPLAINLOOSE]}$`), c("LONECARET", "(?:\\^)"), c("CARETTRIM", `(\\s*)${s[i.LONECARET]}\\s+`, true), e.caretTrimReplace = "$1^", c("CARET", `^${s[i.LONECARET]}${s[i.XRANGEPLAIN]}$`), c("CARETLOOSE", `^${s[i.LONECARET]}${s[i.XRANGEPLAINLOOSE]}$`), c("COMPARATORLOOSE", `^${s[i.GTLT]}\\s*(${s[i.LOOSEPLAIN]})$|^$`), c("COMPARATOR", `^${s[i.GTLT]}\\s*(${s[i.FULLPLAIN]})$|^$`), c("COMPARATORTRIM", `(\\s*)${s[i.GTLT]}\\s*(${s[i.LOOSEPLAIN]}|${s[i.XRANGEPLAIN]})`, true), e.comparatorTrimReplace = "$1$2$3", c("HYPHENRANGE", `^\\s*(${s[i.XRANGEPLAIN]})\\s+-\\s+(${s[i.XRANGEPLAIN]})\\s*$`), c("HYPHENRANGELOOSE", `^\\s*(${s[i.XRANGEPLAINLOOSE]})\\s+-\\s+(${s[i.XRANGEPLAINLOOSE]})\\s*$`), c("STAR", "(<|>)?=?\\s*\\*"), c("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$"), c("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
        } }), pl = I({ "node_modules/semver/internal/parse-options.js"(e, r) {
          q();
          var u = ["includePrerelease", "loose", "rtl"], n = (D) => D ? typeof D != "object" ? { loose: true } : u.filter((s) => D[s]).reduce((s, i) => (s[i] = true, s), {}) : {};
          r.exports = n;
        } }), fl = I({ "node_modules/semver/internal/identifiers.js"(e, r) {
          q();
          var u = /^[0-9]+$/, n = (s, i) => {
            let f = u.test(s), c = u.test(i);
            return f && c && (s = +s, i = +i), s === i ? 0 : f && !c ? -1 : c && !f ? 1 : s < i ? -1 : 1;
          }, D = (s, i) => n(i, s);
          r.exports = { compareIdentifiers: n, rcompareIdentifiers: D };
        } }), dl = I({ "node_modules/semver/classes/semver.js"(e, r) {
          q();
          var u = gs(), { MAX_LENGTH: n, MAX_SAFE_INTEGER: D } = Fs(), { re: s, t: i } = hl(), f = pl(), { compareIdentifiers: c } = fl(), F = class {
            constructor(a, l) {
              if (l = f(l), a instanceof F) {
                if (a.loose === !!l.loose && a.includePrerelease === !!l.includePrerelease)
                  return a;
                a = a.version;
              } else if (typeof a != "string")
                throw new TypeError(`Invalid Version: ${a}`);
              if (a.length > n)
                throw new TypeError(`version is longer than ${n} characters`);
              u("SemVer", a, l), this.options = l, this.loose = !!l.loose, this.includePrerelease = !!l.includePrerelease;
              let h = a.trim().match(l.loose ? s[i.LOOSE] : s[i.FULL]);
              if (!h)
                throw new TypeError(`Invalid Version: ${a}`);
              if (this.raw = a, this.major = +h[1], this.minor = +h[2], this.patch = +h[3], this.major > D || this.major < 0)
                throw new TypeError("Invalid major version");
              if (this.minor > D || this.minor < 0)
                throw new TypeError("Invalid minor version");
              if (this.patch > D || this.patch < 0)
                throw new TypeError("Invalid patch version");
              h[4] ? this.prerelease = h[4].split(".").map((C) => {
                if (/^[0-9]+$/.test(C)) {
                  let d = +C;
                  if (d >= 0 && d < D)
                    return d;
                }
                return C;
              }) : this.prerelease = [], this.build = h[5] ? h[5].split(".") : [], this.format();
            }
            format() {
              return this.version = `${this.major}.${this.minor}.${this.patch}`, this.prerelease.length && (this.version += `-${this.prerelease.join(".")}`), this.version;
            }
            toString() {
              return this.version;
            }
            compare(a) {
              if (u("SemVer.compare", this.version, this.options, a), !(a instanceof F)) {
                if (typeof a == "string" && a === this.version)
                  return 0;
                a = new F(a, this.options);
              }
              return a.version === this.version ? 0 : this.compareMain(a) || this.comparePre(a);
            }
            compareMain(a) {
              return a instanceof F || (a = new F(a, this.options)), c(this.major, a.major) || c(this.minor, a.minor) || c(this.patch, a.patch);
            }
            comparePre(a) {
              if (a instanceof F || (a = new F(a, this.options)), this.prerelease.length && !a.prerelease.length)
                return -1;
              if (!this.prerelease.length && a.prerelease.length)
                return 1;
              if (!this.prerelease.length && !a.prerelease.length)
                return 0;
              let l = 0;
              do {
                let h = this.prerelease[l], C = a.prerelease[l];
                if (u("prerelease compare", l, h, C), h === void 0 && C === void 0)
                  return 0;
                if (C === void 0)
                  return 1;
                if (h === void 0)
                  return -1;
                if (h === C)
                  continue;
                return c(h, C);
              } while (++l);
            }
            compareBuild(a) {
              a instanceof F || (a = new F(a, this.options));
              let l = 0;
              do {
                let h = this.build[l], C = a.build[l];
                if (u("prerelease compare", l, h, C), h === void 0 && C === void 0)
                  return 0;
                if (C === void 0)
                  return 1;
                if (h === void 0)
                  return -1;
                if (h === C)
                  continue;
                return c(h, C);
              } while (++l);
            }
            inc(a, l) {
              switch (a) {
                case "premajor":
                  this.prerelease.length = 0, this.patch = 0, this.minor = 0, this.major++, this.inc("pre", l);
                  break;
                case "preminor":
                  this.prerelease.length = 0, this.patch = 0, this.minor++, this.inc("pre", l);
                  break;
                case "prepatch":
                  this.prerelease.length = 0, this.inc("patch", l), this.inc("pre", l);
                  break;
                case "prerelease":
                  this.prerelease.length === 0 && this.inc("patch", l), this.inc("pre", l);
                  break;
                case "major":
                  (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) && this.major++, this.minor = 0, this.patch = 0, this.prerelease = [];
                  break;
                case "minor":
                  (this.patch !== 0 || this.prerelease.length === 0) && this.minor++, this.patch = 0, this.prerelease = [];
                  break;
                case "patch":
                  this.prerelease.length === 0 && this.patch++, this.prerelease = [];
                  break;
                case "pre":
                  if (this.prerelease.length === 0)
                    this.prerelease = [0];
                  else {
                    let h = this.prerelease.length;
                    for (; --h >= 0; )
                      typeof this.prerelease[h] == "number" && (this.prerelease[h]++, h = -2);
                    h === -1 && this.prerelease.push(0);
                  }
                  l && (c(this.prerelease[0], l) === 0 ? isNaN(this.prerelease[1]) && (this.prerelease = [l, 0]) : this.prerelease = [l, 0]);
                  break;
                default:
                  throw new Error(`invalid increment argument: ${a}`);
              }
              return this.format(), this.raw = this.version, this;
            }
          };
          r.exports = F;
        } }), Hr = I({ "node_modules/semver/functions/compare.js"(e, r) {
          q();
          var u = dl(), n = (D, s, i) => new u(D, i).compare(new u(s, i));
          r.exports = n;
        } }), El = I({ "node_modules/semver/functions/lt.js"(e, r) {
          q();
          var u = Hr(), n = (D, s, i) => u(D, s, i) < 0;
          r.exports = n;
        } }), Cl = I({ "node_modules/semver/functions/gte.js"(e, r) {
          q();
          var u = Hr(), n = (D, s, i) => u(D, s, i) >= 0;
          r.exports = n;
        } }), ml = I({ "src/utils/arrayify.js"(e, r) {
          "use strict";
          q(), r.exports = (u, n) => Object.entries(u).map((D) => {
            let [s, i] = D;
            return Object.assign({ [n]: s }, i);
          });
        } }), gl = I({ "package.json"(e, r) {
          r.exports = { version: "2.8.2" };
        } }), Fl = I({ "node_modules/outdent/lib/index.js"(e, r) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true }), e.outdent = void 0;
          function u() {
            for (var g = [], N = 0; N < arguments.length; N++)
              g[N] = arguments[N];
          }
          function n() {
            return typeof WeakMap < "u" ? /* @__PURE__ */ new WeakMap() : D();
          }
          function D() {
            return { add: u, delete: u, get: u, set: u, has: function(g) {
              return false;
            } };
          }
          var s = Object.prototype.hasOwnProperty, i = function(g, N) {
            return s.call(g, N);
          };
          function f(g, N) {
            for (var R in N)
              i(N, R) && (g[R] = N[R]);
            return g;
          }
          var c = /^[ \t]*(?:\r\n|\r|\n)/, F = /(?:\r\n|\r|\n)[ \t]*$/, a = /^(?:[\r\n]|$)/, l = /(?:\r\n|\r|\n)([ \t]*)(?:[^ \t\r\n]|$)/, h = /^[ \t]*[\r\n][ \t\r\n]*$/;
          function C(g, N, R) {
            var j = 0, _ = g[0].match(l);
            _ && (j = _[1].length);
            var O = "(\\r\\n|\\r|\\n).{0," + j + "}", x = new RegExp(O, "g");
            N && (g = g.slice(1));
            var k = R.newline, $2 = R.trimLeadingNewline, t3 = R.trimTrailingNewline, o = typeof k == "string", E = g.length, p = g.map(function(A, P) {
              return A = A.replace(x, "$1"), P === 0 && $2 && (A = A.replace(c, "")), P === E - 1 && t3 && (A = A.replace(F, "")), o && (A = A.replace(/\r\n|\n|\r/g, function(M) {
                return k;
              })), A;
            });
            return p;
          }
          function d(g, N) {
            for (var R = "", j = 0, _ = g.length; j < _; j++)
              R += g[j], j < _ - 1 && (R += N[j]);
            return R;
          }
          function m(g) {
            return i(g, "raw") && i(g, "length");
          }
          function T(g) {
            var N = n(), R = n();
            function j(O) {
              for (var x = [], k = 1; k < arguments.length; k++)
                x[k - 1] = arguments[k];
              if (m(O)) {
                var $2 = O, t3 = (x[0] === j || x[0] === w) && h.test($2[0]) && a.test($2[1]), o = t3 ? R : N, E = o.get($2);
                if (E || (E = C($2, t3, g), o.set($2, E)), x.length === 0)
                  return E[0];
                var p = d(E, t3 ? x.slice(1) : x);
                return p;
              } else
                return T(f(f({}, g), O || {}));
            }
            var _ = f(j, { string: function(O) {
              return C([O], false, g)[0];
            } });
            return _;
          }
          var w = T({ trimLeadingNewline: true, trimTrailingNewline: true });
          if (e.outdent = w, e.default = w, typeof r < "u")
            try {
              r.exports = w, Object.defineProperty(w, "__esModule", { value: true }), w.default = w, w.outdent = w;
            } catch {
            }
        } }), Al = I({ "src/main/core-options.js"(e, r) {
          "use strict";
          q();
          var { outdent: u } = Fl(), n = "Config", D = "Editor", s = "Format", i = "Other", f = "Output", c = "Global", F = "Special", a = { cursorOffset: { since: "1.4.0", category: F, type: "int", default: -1, range: { start: -1, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Print (to stderr) where a cursor at the given position would move to after formatting.
      This option cannot be used with --range-start and --range-end.
    `, cliCategory: D }, endOfLine: { since: "1.15.0", category: c, type: "choice", default: [{ since: "1.15.0", value: "auto" }, { since: "2.0.0", value: "lf" }], description: "Which end of line characters to apply.", choices: [{ value: "lf", description: "Line Feed only (\\n), common on Linux and macOS as well as inside git repos" }, { value: "crlf", description: "Carriage Return + Line Feed characters (\\r\\n), common on Windows" }, { value: "cr", description: "Carriage Return character only (\\r), used very rarely" }, { value: "auto", description: u`
          Maintain existing
          (mixed values within one file are normalised by looking at what's used after the first line)
        ` }] }, filepath: { since: "1.4.0", category: F, type: "path", description: "Specify the input filepath. This will be used to do parser inference.", cliName: "stdin-filepath", cliCategory: i, cliDescription: "Path to the file to pretend that stdin comes from." }, insertPragma: { since: "1.8.0", category: F, type: "boolean", default: false, description: "Insert @format pragma into file's first docblock comment.", cliCategory: i }, parser: { since: "0.0.10", category: c, type: "choice", default: [{ since: "0.0.10", value: "babylon" }, { since: "1.13.0", value: void 0 }], description: "Which parser to use.", exception: (l) => typeof l == "string" || typeof l == "function", choices: [{ value: "flow", description: "Flow" }, { value: "babel", since: "1.16.0", description: "JavaScript" }, { value: "babel-flow", since: "1.16.0", description: "Flow" }, { value: "babel-ts", since: "2.0.0", description: "TypeScript" }, { value: "typescript", since: "1.4.0", description: "TypeScript" }, { value: "acorn", since: "2.6.0", description: "JavaScript" }, { value: "espree", since: "2.2.0", description: "JavaScript" }, { value: "meriyah", since: "2.2.0", description: "JavaScript" }, { value: "css", since: "1.7.1", description: "CSS" }, { value: "less", since: "1.7.1", description: "Less" }, { value: "scss", since: "1.7.1", description: "SCSS" }, { value: "json", since: "1.5.0", description: "JSON" }, { value: "json5", since: "1.13.0", description: "JSON5" }, { value: "json-stringify", since: "1.13.0", description: "JSON.stringify" }, { value: "graphql", since: "1.5.0", description: "GraphQL" }, { value: "markdown", since: "1.8.0", description: "Markdown" }, { value: "mdx", since: "1.15.0", description: "MDX" }, { value: "vue", since: "1.10.0", description: "Vue" }, { value: "yaml", since: "1.14.0", description: "YAML" }, { value: "glimmer", since: "2.3.0", description: "Ember / Handlebars" }, { value: "html", since: "1.15.0", description: "HTML" }, { value: "angular", since: "1.15.0", description: "Angular" }, { value: "lwc", since: "1.17.0", description: "Lightning Web Components" }] }, plugins: { since: "1.10.0", type: "path", array: true, default: [{ value: [] }], category: c, description: "Add a plugin. Multiple plugins can be passed as separate `--plugin`s.", exception: (l) => typeof l == "string" || typeof l == "object", cliName: "plugin", cliCategory: n }, pluginSearchDirs: { since: "1.13.0", type: "path", array: true, default: [{ value: [] }], category: c, description: u`
      Custom directory that contains prettier plugins in node_modules subdirectory.
      Overrides default behavior when plugins are searched relatively to the location of Prettier.
      Multiple values are accepted.
    `, exception: (l) => typeof l == "string" || typeof l == "object", cliName: "plugin-search-dir", cliCategory: n }, printWidth: { since: "0.0.0", category: c, type: "int", default: 80, description: "The line length where Prettier will try wrap.", range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 } }, rangeEnd: { since: "1.4.0", category: F, type: "int", default: Number.POSITIVE_INFINITY, range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Format code ending at a given character offset (exclusive).
      The range will extend forwards to the end of the selected statement.
      This option cannot be used with --cursor-offset.
    `, cliCategory: D }, rangeStart: { since: "1.4.0", category: F, type: "int", default: 0, range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 }, description: u`
      Format code starting at a given character offset.
      The range will extend backwards to the start of the first line containing the selected statement.
      This option cannot be used with --cursor-offset.
    `, cliCategory: D }, requirePragma: { since: "1.7.0", category: F, type: "boolean", default: false, description: u`
      Require either '@prettier' or '@format' to be present in the file's first docblock comment
      in order for it to be formatted.
    `, cliCategory: i }, tabWidth: { type: "int", category: c, default: 2, description: "Number of spaces per indentation level.", range: { start: 0, end: Number.POSITIVE_INFINITY, step: 1 } }, useTabs: { since: "1.0.0", category: c, type: "boolean", default: false, description: "Indent with tabs instead of spaces." }, embeddedLanguageFormatting: { since: "2.1.0", category: c, type: "choice", default: [{ since: "2.1.0", value: "auto" }], description: "Control how Prettier formats quoted code embedded in the file.", choices: [{ value: "auto", description: "Format embedded code if Prettier can automatically identify it." }, { value: "off", description: "Never automatically format embedded code." }] } };
          r.exports = { CATEGORY_CONFIG: n, CATEGORY_EDITOR: D, CATEGORY_FORMAT: s, CATEGORY_OTHER: i, CATEGORY_OUTPUT: f, CATEGORY_GLOBAL: c, CATEGORY_SPECIAL: F, options: a };
        } }), vl = I({ "src/main/support.js"(e, r) {
          "use strict";
          q();
          var u = { compare: Hr(), lt: El(), gte: Cl() }, n = ml(), D = gl().version, s = Al().options;
          function i() {
            let { plugins: c = [], showUnreleased: F = false, showDeprecated: a = false, showInternal: l = false } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, h = D.split("-", 1)[0], C = c.flatMap((g) => g.languages || []).filter(m), d = n(Object.assign({}, ...c.map((g) => {
              let { options: N } = g;
              return N;
            }), s), "name").filter((g) => m(g) && T(g)).sort((g, N) => g.name === N.name ? 0 : g.name < N.name ? -1 : 1).map(w).map((g) => {
              g = Object.assign({}, g), Array.isArray(g.default) && (g.default = g.default.length === 1 ? g.default[0].value : g.default.filter(m).sort((R, j) => u.compare(j.since, R.since))[0].value), Array.isArray(g.choices) && (g.choices = g.choices.filter((R) => m(R) && T(R)), g.name === "parser" && f(g, C, c));
              let N = Object.fromEntries(c.filter((R) => R.defaultOptions && R.defaultOptions[g.name] !== void 0).map((R) => [R.name, R.defaultOptions[g.name]]));
              return Object.assign(Object.assign({}, g), {}, { pluginDefaults: N });
            });
            return { languages: C, options: d };
            function m(g) {
              return F || !("since" in g) || g.since && u.gte(h, g.since);
            }
            function T(g) {
              return a || !("deprecated" in g) || g.deprecated && u.lt(h, g.deprecated);
            }
            function w(g) {
              if (l)
                return g;
              let { cliName: N, cliCategory: R, cliDescription: j } = g;
              return JD(g, KD);
            }
          }
          function f(c, F, a) {
            let l = new Set(c.choices.map((h) => h.value));
            for (let h of F)
              if (h.parsers) {
                for (let C of h.parsers)
                  if (!l.has(C)) {
                    l.add(C);
                    let d = a.find((T) => T.parsers && T.parsers[C]), m = h.name;
                    d && d.name && (m += ` (plugin: ${d.name})`), c.choices.push({ value: C, description: m });
                  }
              }
          }
          r.exports = { getSupportInfo: i };
        } }), _l = I({ "src/utils/is-non-empty-array.js"(e, r) {
          "use strict";
          q();
          function u(n) {
            return Array.isArray(n) && n.length > 0;
          }
          r.exports = u;
        } });
        function Sl() {
          let { onlyFirst: e = false } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, r = ["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)", "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"].join("|");
          return new RegExp(r, e ? void 0 : "g");
        }
        var yl = Ee({ "node_modules/strip-ansi/node_modules/ansi-regex/index.js"() {
          q();
        } });
        function Tl(e) {
          if (typeof e != "string")
            throw new TypeError(`Expected a \`string\`, got \`${typeof e}\``);
          return e.replace(Sl(), "");
        }
        var Bl = Ee({ "node_modules/strip-ansi/index.js"() {
          q(), yl();
        } });
        function bl(e) {
          return Number.isInteger(e) ? e >= 4352 && (e <= 4447 || e === 9001 || e === 9002 || 11904 <= e && e <= 12871 && e !== 12351 || 12880 <= e && e <= 19903 || 19968 <= e && e <= 42182 || 43360 <= e && e <= 43388 || 44032 <= e && e <= 55203 || 63744 <= e && e <= 64255 || 65040 <= e && e <= 65049 || 65072 <= e && e <= 65131 || 65281 <= e && e <= 65376 || 65504 <= e && e <= 65510 || 110592 <= e && e <= 110593 || 127488 <= e && e <= 127569 || 131072 <= e && e <= 262141) : false;
        }
        var wl = Ee({ "node_modules/is-fullwidth-code-point/index.js"() {
          q();
        } }), Nl = I({ "node_modules/emoji-regex/index.js"(e, r) {
          "use strict";
          q(), r.exports = function() {
            return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67)\uDB40\uDC7F|(?:\uD83E\uDDD1\uD83C\uDFFF\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFC-\uDFFF])|\uD83D\uDC68(?:\uD83C\uDFFB(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|[\u2695\u2696\u2708]\uFE0F|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))?|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])\uFE0F|\u200D(?:(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D[\uDC66\uDC67])|\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC)?|(?:\uD83D\uDC69(?:\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69]))|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC69(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83E\uDDD1(?:\u200D(?:\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDE36\u200D\uD83C\uDF2B|\uD83C\uDFF3\uFE0F\u200D\u26A7|\uD83D\uDC3B\u200D\u2744|(?:(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\uD83C\uDFF4\u200D\u2620|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])\u200D[\u2640\u2642]|[\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u2328\u23CF\u23ED-\u23EF\u23F1\u23F2\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB\u25FC\u2600-\u2604\u260E\u2611\u2618\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u2692\u2694-\u2697\u2699\u269B\u269C\u26A0\u26A7\u26B0\u26B1\u26C8\u26CF\u26D1\u26D3\u26E9\u26F0\u26F1\u26F4\u26F7\u26F8\u2702\u2708\u2709\u270F\u2712\u2714\u2716\u271D\u2721\u2733\u2734\u2744\u2747\u2763\u27A1\u2934\u2935\u2B05-\u2B07\u3030\u303D\u3297\u3299]|\uD83C[\uDD70\uDD71\uDD7E\uDD7F\uDE02\uDE37\uDF21\uDF24-\uDF2C\uDF36\uDF7D\uDF96\uDF97\uDF99-\uDF9B\uDF9E\uDF9F\uDFCD\uDFCE\uDFD4-\uDFDF\uDFF5\uDFF7]|\uD83D[\uDC3F\uDCFD\uDD49\uDD4A\uDD6F\uDD70\uDD73\uDD76-\uDD79\uDD87\uDD8A-\uDD8D\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA\uDECB\uDECD-\uDECF\uDEE0-\uDEE5\uDEE9\uDEF0\uDEF3])\uFE0F|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDE35\u200D\uD83D\uDCAB|\uD83D\uDE2E\u200D\uD83D\uDCA8|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83E\uDDD1(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83D\uDC69(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF6\uD83C\uDDE6|\uD83C\uDDF4\uD83C\uDDF2|\uD83D\uDC08\u200D\u2B1B|\u2764\uFE0F\u200D(?:\uD83D\uDD25|\uD83E\uDE79)|\uD83D\uDC41\uFE0F|\uD83C\uDFF3\uFE0F|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|[#\*0-9]\uFE0F\u20E3|\u2764\uFE0F|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|\uD83C\uDFF4|(?:[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270C\u270D]|\uD83D[\uDD74\uDD90])(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC08\uDC15\uDC3B\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE2E\uDE35\uDE36\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5]|\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD]|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF]|[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF84\uDF86-\uDF93\uDFA0-\uDFC1\uDFC5\uDFC6\uDFC8\uDFC9\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC07\uDC09-\uDC14\uDC16-\uDC3A\uDC3C-\uDC3E\uDC40\uDC44\uDC45\uDC51-\uDC65\uDC6A\uDC79-\uDC7B\uDC7D-\uDC80\uDC84\uDC88-\uDC8E\uDC90\uDC92-\uDCA9\uDCAB-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDDA4\uDDFB-\uDE2D\uDE2F-\uDE34\uDE37-\uDE44\uDE48-\uDE4A\uDE80-\uDEA2\uDEA4-\uDEB3\uDEB7-\uDEBF\uDEC1-\uDEC5\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0D\uDD0E\uDD10-\uDD17\uDD1D\uDD20-\uDD25\uDD27-\uDD2F\uDD3A\uDD3F-\uDD45\uDD47-\uDD76\uDD78\uDD7A-\uDDB4\uDDB7\uDDBA\uDDBC-\uDDCB\uDDD0\uDDE0-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6]|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26A7\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5-\uDED7\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDD77\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
          };
        } }), As = {};
        ps(As, { default: () => Ol });
        function Ol(e) {
          if (typeof e != "string" || e.length === 0 || (e = Tl(e), e.length === 0))
            return 0;
          e = e.replace((0, vs.default)(), "  ");
          let r = 0;
          for (let u = 0; u < e.length; u++) {
            let n = e.codePointAt(u);
            n <= 31 || n >= 127 && n <= 159 || n >= 768 && n <= 879 || (n > 65535 && u++, r += bl(n) ? 2 : 1);
          }
          return r;
        }
        var vs, ql = Ee({ "node_modules/string-width/index.js"() {
          q(), Bl(), wl(), vs = nl(Nl());
        } }), Il = I({ "src/utils/get-string-width.js"(e, r) {
          "use strict";
          q();
          var u = (ql(), ds(As)).default, n = /[^\x20-\x7F]/;
          function D(s) {
            return s ? n.test(s) ? u(s) : s.length : 0;
          }
          r.exports = D;
        } }), zr = I({ "src/utils/text/skip.js"(e, r) {
          "use strict";
          q();
          function u(f) {
            return (c, F, a) => {
              let l = a && a.backwards;
              if (F === false)
                return false;
              let { length: h } = c, C = F;
              for (; C >= 0 && C < h; ) {
                let d = c.charAt(C);
                if (f instanceof RegExp) {
                  if (!f.test(d))
                    return C;
                } else if (!f.includes(d))
                  return C;
                l ? C-- : C++;
              }
              return C === -1 || C === h ? C : false;
            };
          }
          var n = u(/\s/), D = u(" 	"), s = u(",; 	"), i = u(/[^\n\r]/);
          r.exports = { skipWhitespace: n, skipSpaces: D, skipToLineEnd: s, skipEverythingButNewLine: i };
        } }), _s = I({ "src/utils/text/skip-inline-comment.js"(e, r) {
          "use strict";
          q();
          function u(n, D) {
            if (D === false)
              return false;
            if (n.charAt(D) === "/" && n.charAt(D + 1) === "*") {
              for (let s = D + 2; s < n.length; ++s)
                if (n.charAt(s) === "*" && n.charAt(s + 1) === "/")
                  return s + 2;
            }
            return D;
          }
          r.exports = u;
        } }), Ss = I({ "src/utils/text/skip-trailing-comment.js"(e, r) {
          "use strict";
          q();
          var { skipEverythingButNewLine: u } = zr();
          function n(D, s) {
            return s === false ? false : D.charAt(s) === "/" && D.charAt(s + 1) === "/" ? u(D, s) : s;
          }
          r.exports = n;
        } }), ys = I({ "src/utils/text/skip-newline.js"(e, r) {
          "use strict";
          q();
          function u(n, D, s) {
            let i = s && s.backwards;
            if (D === false)
              return false;
            let f = n.charAt(D);
            if (i) {
              if (n.charAt(D - 1) === "\r" && f === `
`)
                return D - 2;
              if (f === `
` || f === "\r" || f === "\u2028" || f === "\u2029")
                return D - 1;
            } else {
              if (f === "\r" && n.charAt(D + 1) === `
`)
                return D + 2;
              if (f === `
` || f === "\r" || f === "\u2028" || f === "\u2029")
                return D + 1;
            }
            return D;
          }
          r.exports = u;
        } }), Rl = I({ "src/utils/text/get-next-non-space-non-comment-character-index-with-start-index.js"(e, r) {
          "use strict";
          q();
          var u = _s(), n = ys(), D = Ss(), { skipSpaces: s } = zr();
          function i(f, c) {
            let F = null, a = c;
            for (; a !== F; )
              F = a, a = s(f, a), a = u(f, a), a = D(f, a), a = n(f, a);
            return a;
          }
          r.exports = i;
        } }), xl = I({ "src/common/util.js"(e, r) {
          "use strict";
          q();
          var { default: u } = (cl(), ds(ms)), n = Cs(), { getSupportInfo: D } = vl(), s = _l(), i = Il(), { skipWhitespace: f, skipSpaces: c, skipToLineEnd: F, skipEverythingButNewLine: a } = zr(), l = _s(), h = Ss(), C = ys(), d = Rl(), m = (v) => v[v.length - 2];
          function T(v) {
            return (y, B, b) => {
              let L = b && b.backwards;
              if (B === false)
                return false;
              let { length: U } = y, G = B;
              for (; G >= 0 && G < U; ) {
                let W = y.charAt(G);
                if (v instanceof RegExp) {
                  if (!v.test(W))
                    return G;
                } else if (!v.includes(W))
                  return G;
                L ? G-- : G++;
              }
              return G === -1 || G === U ? G : false;
            };
          }
          function w(v, y) {
            let B = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, b = c(v, B.backwards ? y - 1 : y, B), L = C(v, b, B);
            return b !== L;
          }
          function g(v, y, B) {
            for (let b = y; b < B; ++b)
              if (v.charAt(b) === `
`)
                return true;
            return false;
          }
          function N(v, y, B) {
            let b = B(y) - 1;
            b = c(v, b, { backwards: true }), b = C(v, b, { backwards: true }), b = c(v, b, { backwards: true });
            let L = C(v, b, { backwards: true });
            return b !== L;
          }
          function R(v, y) {
            let B = null, b = y;
            for (; b !== B; )
              B = b, b = F(v, b), b = l(v, b), b = c(v, b);
            return b = h(v, b), b = C(v, b), b !== false && w(v, b);
          }
          function j(v, y, B) {
            return R(v, B(y));
          }
          function _(v, y, B) {
            return d(v, B(y));
          }
          function O(v, y, B) {
            return v.charAt(_(v, y, B));
          }
          function x(v, y) {
            let B = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
            return c(v, B.backwards ? y - 1 : y, B) !== y;
          }
          function k(v, y) {
            let B = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : 0, b = 0;
            for (let L = B; L < v.length; ++L)
              v[L] === "	" ? b = b + y - b % y : b++;
            return b;
          }
          function $2(v, y) {
            let B = v.lastIndexOf(`
`);
            return B === -1 ? 0 : k(v.slice(B + 1).match(/^[\t ]*/)[0], y);
          }
          function t3(v, y) {
            let B = { quote: '"', regex: /"/g, escaped: "&quot;" }, b = { quote: "'", regex: /'/g, escaped: "&apos;" }, L = y === "'" ? b : B, U = L === b ? B : b, G = L;
            if (v.includes(L.quote) || v.includes(U.quote)) {
              let W = (v.match(L.regex) || []).length, ne = (v.match(U.regex) || []).length;
              G = W > ne ? U : L;
            }
            return G;
          }
          function o(v, y) {
            let B = v.slice(1, -1), b = y.parser === "json" || y.parser === "json5" && y.quoteProps === "preserve" && !y.singleQuote ? '"' : y.__isInHtmlAttribute ? "'" : t3(B, y.singleQuote ? "'" : '"').quote;
            return E(B, b, !(y.parser === "css" || y.parser === "less" || y.parser === "scss" || y.__embeddedInHtml));
          }
          function E(v, y, B) {
            let b = y === '"' ? "'" : '"', L = /\\(.)|(["'])/gs, U = v.replace(L, (G, W, ne) => W === b ? W : ne === y ? "\\" + ne : ne || (B && /^[^\n\r"'0-7\\bfnrt-vx\u2028\u2029]$/.test(W) ? W : "\\" + W));
            return y + U + y;
          }
          function p(v) {
            return v.toLowerCase().replace(/^([+-]?[\d.]+e)(?:\+|(-))?0*(\d)/, "$1$2$3").replace(/^([+-]?[\d.]+)e[+-]?0+$/, "$1").replace(/^([+-])?\./, "$10.").replace(/(\.\d+?)0+(?=e|$)/, "$1").replace(/\.(?=e|$)/, "");
          }
          function A(v, y) {
            let B = v.match(new RegExp(`(${u(y)})+`, "g"));
            return B === null ? 0 : B.reduce((b, L) => Math.max(b, L.length / y.length), 0);
          }
          function P(v, y) {
            let B = v.match(new RegExp(`(${u(y)})+`, "g"));
            if (B === null)
              return 0;
            let b = /* @__PURE__ */ new Map(), L = 0;
            for (let U of B) {
              let G = U.length / y.length;
              b.set(G, true), G > L && (L = G);
            }
            for (let U = 1; U < L; U++)
              if (!b.get(U))
                return U;
            return L + 1;
          }
          function M(v, y) {
            (v.comments || (v.comments = [])).push(y), y.printed = false, y.nodeDescription = J(v);
          }
          function z(v, y) {
            y.leading = true, y.trailing = false, M(v, y);
          }
          function V(v, y, B) {
            y.leading = false, y.trailing = false, B && (y.marker = B), M(v, y);
          }
          function X(v, y) {
            y.leading = false, y.trailing = true, M(v, y);
          }
          function H(v, y) {
            let { languages: B } = D({ plugins: y.plugins }), b = B.find((L) => {
              let { name: U } = L;
              return U.toLowerCase() === v;
            }) || B.find((L) => {
              let { aliases: U } = L;
              return Array.isArray(U) && U.includes(v);
            }) || B.find((L) => {
              let { extensions: U } = L;
              return Array.isArray(U) && U.includes(`.${v}`);
            });
            return b && b.parsers[0];
          }
          function Q(v) {
            return v && v.type === "front-matter";
          }
          function K(v) {
            let y = /* @__PURE__ */ new WeakMap();
            return function(B) {
              return y.has(B) || y.set(B, Symbol(v)), y.get(B);
            };
          }
          function J(v) {
            let y = v.type || v.kind || "(unknown type)", B = String(v.name || v.id && (typeof v.id == "object" ? v.id.name : v.id) || v.key && (typeof v.key == "object" ? v.key.name : v.key) || v.value && (typeof v.value == "object" ? "" : String(v.value)) || v.operator || "");
            return B.length > 20 && (B = B.slice(0, 19) + "\u2026"), y + (B ? " " + B : "");
          }
          r.exports = { inferParserByLanguage: H, getStringWidth: i, getMaxContinuousCount: A, getMinNotPresentContinuousCount: P, getPenultimate: m, getLast: n, getNextNonSpaceNonCommentCharacterIndexWithStartIndex: d, getNextNonSpaceNonCommentCharacterIndex: _, getNextNonSpaceNonCommentCharacter: O, skip: T, skipWhitespace: f, skipSpaces: c, skipToLineEnd: F, skipEverythingButNewLine: a, skipInlineComment: l, skipTrailingComment: h, skipNewline: C, isNextLineEmptyAfterIndex: R, isNextLineEmpty: j, isPreviousLineEmpty: N, hasNewline: w, hasNewlineInRange: g, hasSpaces: x, getAlignmentSize: k, getIndentSize: $2, getPreferredQuote: t3, printString: o, printNumber: p, makeString: E, addLeadingComment: z, addDanglingComment: V, addTrailingComment: X, isFrontMatterNode: Q, isNonEmptyArray: s, createGroupIdMapper: K };
        } }), Pl = I({ "vendors/html-tag-names.json"(e, r) {
          r.exports = { htmlTagNames: ["a", "abbr", "acronym", "address", "applet", "area", "article", "aside", "audio", "b", "base", "basefont", "bdi", "bdo", "bgsound", "big", "blink", "blockquote", "body", "br", "button", "canvas", "caption", "center", "cite", "code", "col", "colgroup", "command", "content", "data", "datalist", "dd", "del", "details", "dfn", "dialog", "dir", "div", "dl", "dt", "element", "em", "embed", "fieldset", "figcaption", "figure", "font", "footer", "form", "frame", "frameset", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "i", "iframe", "image", "img", "input", "ins", "isindex", "kbd", "keygen", "label", "legend", "li", "link", "listing", "main", "map", "mark", "marquee", "math", "menu", "menuitem", "meta", "meter", "multicol", "nav", "nextid", "nobr", "noembed", "noframes", "noscript", "object", "ol", "optgroup", "option", "output", "p", "param", "picture", "plaintext", "pre", "progress", "q", "rb", "rbc", "rp", "rt", "rtc", "ruby", "s", "samp", "script", "section", "select", "shadow", "slot", "small", "source", "spacer", "span", "strike", "strong", "style", "sub", "summary", "sup", "svg", "table", "tbody", "td", "template", "textarea", "tfoot", "th", "thead", "time", "title", "tr", "track", "tt", "u", "ul", "var", "video", "wbr", "xmp"] };
        } }), Ts = I({ "src/language-html/utils/array-to-map.js"(e, r) {
          "use strict";
          q();
          function u(n) {
            let D = /* @__PURE__ */ Object.create(null);
            for (let s of n)
              D[s] = true;
            return D;
          }
          r.exports = u;
        } }), kl = I({ "src/language-html/utils/html-tag-names.js"(e, r) {
          "use strict";
          q();
          var { htmlTagNames: u } = Pl(), n = Ts(), D = n(u);
          r.exports = D;
        } }), Ll = I({ "vendors/html-element-attributes.json"(e, r) {
          r.exports = { htmlElementAttributes: { "*": ["accesskey", "autocapitalize", "autofocus", "class", "contenteditable", "dir", "draggable", "enterkeyhint", "hidden", "id", "inputmode", "is", "itemid", "itemprop", "itemref", "itemscope", "itemtype", "lang", "nonce", "slot", "spellcheck", "style", "tabindex", "title", "translate"], a: ["charset", "coords", "download", "href", "hreflang", "name", "ping", "referrerpolicy", "rel", "rev", "shape", "target", "type"], applet: ["align", "alt", "archive", "code", "codebase", "height", "hspace", "name", "object", "vspace", "width"], area: ["alt", "coords", "download", "href", "hreflang", "nohref", "ping", "referrerpolicy", "rel", "shape", "target", "type"], audio: ["autoplay", "controls", "crossorigin", "loop", "muted", "preload", "src"], base: ["href", "target"], basefont: ["color", "face", "size"], blockquote: ["cite"], body: ["alink", "background", "bgcolor", "link", "text", "vlink"], br: ["clear"], button: ["disabled", "form", "formaction", "formenctype", "formmethod", "formnovalidate", "formtarget", "name", "type", "value"], canvas: ["height", "width"], caption: ["align"], col: ["align", "char", "charoff", "span", "valign", "width"], colgroup: ["align", "char", "charoff", "span", "valign", "width"], data: ["value"], del: ["cite", "datetime"], details: ["open"], dialog: ["open"], dir: ["compact"], div: ["align"], dl: ["compact"], embed: ["height", "src", "type", "width"], fieldset: ["disabled", "form", "name"], font: ["color", "face", "size"], form: ["accept", "accept-charset", "action", "autocomplete", "enctype", "method", "name", "novalidate", "target"], frame: ["frameborder", "longdesc", "marginheight", "marginwidth", "name", "noresize", "scrolling", "src"], frameset: ["cols", "rows"], h1: ["align"], h2: ["align"], h3: ["align"], h4: ["align"], h5: ["align"], h6: ["align"], head: ["profile"], hr: ["align", "noshade", "size", "width"], html: ["manifest", "version"], iframe: ["align", "allow", "allowfullscreen", "allowpaymentrequest", "allowusermedia", "frameborder", "height", "loading", "longdesc", "marginheight", "marginwidth", "name", "referrerpolicy", "sandbox", "scrolling", "src", "srcdoc", "width"], img: ["align", "alt", "border", "crossorigin", "decoding", "height", "hspace", "ismap", "loading", "longdesc", "name", "referrerpolicy", "sizes", "src", "srcset", "usemap", "vspace", "width"], input: ["accept", "align", "alt", "autocomplete", "checked", "dirname", "disabled", "form", "formaction", "formenctype", "formmethod", "formnovalidate", "formtarget", "height", "ismap", "list", "max", "maxlength", "min", "minlength", "multiple", "name", "pattern", "placeholder", "readonly", "required", "size", "src", "step", "type", "usemap", "value", "width"], ins: ["cite", "datetime"], isindex: ["prompt"], label: ["for", "form"], legend: ["align"], li: ["type", "value"], link: ["as", "charset", "color", "crossorigin", "disabled", "href", "hreflang", "imagesizes", "imagesrcset", "integrity", "media", "referrerpolicy", "rel", "rev", "sizes", "target", "type"], map: ["name"], menu: ["compact"], meta: ["charset", "content", "http-equiv", "media", "name", "scheme"], meter: ["high", "low", "max", "min", "optimum", "value"], object: ["align", "archive", "border", "classid", "codebase", "codetype", "data", "declare", "form", "height", "hspace", "name", "standby", "type", "typemustmatch", "usemap", "vspace", "width"], ol: ["compact", "reversed", "start", "type"], optgroup: ["disabled", "label"], option: ["disabled", "label", "selected", "value"], output: ["for", "form", "name"], p: ["align"], param: ["name", "type", "value", "valuetype"], pre: ["width"], progress: ["max", "value"], q: ["cite"], script: ["async", "charset", "crossorigin", "defer", "integrity", "language", "nomodule", "referrerpolicy", "src", "type"], select: ["autocomplete", "disabled", "form", "multiple", "name", "required", "size"], slot: ["name"], source: ["height", "media", "sizes", "src", "srcset", "type", "width"], style: ["media", "type"], table: ["align", "bgcolor", "border", "cellpadding", "cellspacing", "frame", "rules", "summary", "width"], tbody: ["align", "char", "charoff", "valign"], td: ["abbr", "align", "axis", "bgcolor", "char", "charoff", "colspan", "headers", "height", "nowrap", "rowspan", "scope", "valign", "width"], textarea: ["autocomplete", "cols", "dirname", "disabled", "form", "maxlength", "minlength", "name", "placeholder", "readonly", "required", "rows", "wrap"], tfoot: ["align", "char", "charoff", "valign"], th: ["abbr", "align", "axis", "bgcolor", "char", "charoff", "colspan", "headers", "height", "nowrap", "rowspan", "scope", "valign", "width"], thead: ["align", "char", "charoff", "valign"], time: ["datetime"], tr: ["align", "bgcolor", "char", "charoff", "valign"], track: ["default", "kind", "label", "src", "srclang"], ul: ["compact", "type"], video: ["autoplay", "controls", "crossorigin", "height", "loop", "muted", "playsinline", "poster", "preload", "src", "width"] } };
        } }), $l = I({ "src/language-html/utils/map-object.js"(e, r) {
          "use strict";
          q();
          function u(n, D) {
            let s = /* @__PURE__ */ Object.create(null);
            for (let [i, f] of Object.entries(n))
              s[i] = D(f, i);
            return s;
          }
          r.exports = u;
        } }), Ml = I({ "src/language-html/utils/html-elements-attributes.js"(e, r) {
          "use strict";
          q();
          var { htmlElementAttributes: u } = Ll(), n = $l(), D = Ts(), s = n(u, D);
          r.exports = s;
        } }), jl = I({ "src/language-html/utils/is-unknown-namespace.js"(e, r) {
          "use strict";
          q();
          function u(n) {
            return n.type === "element" && !n.hasExplicitNamespace && !["html", "svg"].includes(n.namespace);
          }
          r.exports = u;
        } }), Ul = I({ "src/language-html/pragma.js"(e, r) {
          "use strict";
          q();
          function u(D) {
            return /^\s*<!--\s*@(?:format|prettier)\s*-->/.test(D);
          }
          function n(D) {
            return `<!-- @format -->

` + D.replace(/^\s*\n/, "");
          }
          r.exports = { hasPragma: u, insertPragma: n };
        } }), Gl = I({ "src/language-html/ast.js"(e, r) {
          "use strict";
          q();
          var u = { attrs: true, children: true }, n = /* @__PURE__ */ new Set(["parent"]), D = class {
            constructor() {
              let i = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
              for (let f of /* @__PURE__ */ new Set([...n, ...Object.keys(i)]))
                this.setProperty(f, i[f]);
            }
            setProperty(i, f) {
              if (this[i] !== f) {
                if (i in u && (f = f.map((c) => this.createChild(c))), !n.has(i)) {
                  this[i] = f;
                  return;
                }
                Object.defineProperty(this, i, { value: f, enumerable: false, configurable: true });
              }
            }
            map(i) {
              let f;
              for (let c in u) {
                let F = this[c];
                if (F) {
                  let a = s(F, (l) => l.map(i));
                  f !== F && (f || (f = new D({ parent: this.parent })), f.setProperty(c, a));
                }
              }
              if (f)
                for (let c in this)
                  c in u || (f[c] = this[c]);
              return i(f || this);
            }
            walk(i) {
              for (let f in u) {
                let c = this[f];
                if (c)
                  for (let F = 0; F < c.length; F++)
                    c[F].walk(i);
              }
              i(this);
            }
            createChild(i) {
              let f = i instanceof D ? i.clone() : new D(i);
              return f.setProperty("parent", this), f;
            }
            insertChildBefore(i, f) {
              this.children.splice(this.children.indexOf(i), 0, this.createChild(f));
            }
            removeChild(i) {
              this.children.splice(this.children.indexOf(i), 1);
            }
            replaceChild(i, f) {
              this.children[this.children.indexOf(i)] = this.createChild(f);
            }
            clone() {
              return new D(this);
            }
            get firstChild() {
              var i;
              return (i = this.children) === null || i === void 0 ? void 0 : i[0];
            }
            get lastChild() {
              var i;
              return (i = this.children) === null || i === void 0 ? void 0 : i[this.children.length - 1];
            }
            get prev() {
              var i;
              return (i = this.parent) === null || i === void 0 ? void 0 : i.children[this.parent.children.indexOf(this) - 1];
            }
            get next() {
              var i;
              return (i = this.parent) === null || i === void 0 ? void 0 : i.children[this.parent.children.indexOf(this) + 1];
            }
            get rawName() {
              return this.hasExplicitNamespace ? this.fullName : this.name;
            }
            get fullName() {
              return this.namespace ? this.namespace + ":" + this.name : this.name;
            }
            get attrMap() {
              return Object.fromEntries(this.attrs.map((i) => [i.fullName, i.value]));
            }
          };
          function s(i, f) {
            let c = i.map(f);
            return c.some((F, a) => F !== i[a]) ? c : i;
          }
          r.exports = { Node: D };
        } }), Vl = I({ "src/language-html/conditional-comment.js"(e, r) {
          "use strict";
          q();
          var { ParseSourceSpan: u } = Be(), n = [{ regex: /^(\[if([^\]]*)]>)(.*?)<!\s*\[endif]$/s, parse: s }, { regex: /^\[if([^\]]*)]><!$/, parse: i }, { regex: /^<!\s*\[endif]$/, parse: f }];
          function D(c, F) {
            if (c.value)
              for (let { regex: a, parse: l } of n) {
                let h = c.value.match(a);
                if (h)
                  return l(c, F, h);
              }
            return null;
          }
          function s(c, F, a) {
            let [, l, h, C] = a, d = 4 + l.length, m = c.sourceSpan.start.moveBy(d), T = m.moveBy(C.length), [w, g] = (() => {
              try {
                return [true, F(C, m).children];
              } catch {
                return [false, [{ type: "text", value: C, sourceSpan: new u(m, T) }]];
              }
            })();
            return { type: "ieConditionalComment", complete: w, children: g, condition: h.trim().replace(/\s+/g, " "), sourceSpan: c.sourceSpan, startSourceSpan: new u(c.sourceSpan.start, m), endSourceSpan: new u(T, c.sourceSpan.end) };
          }
          function i(c, F, a) {
            let [, l] = a;
            return { type: "ieConditionalStartComment", condition: l.trim().replace(/\s+/g, " "), sourceSpan: c.sourceSpan };
          }
          function f(c) {
            return { type: "ieConditionalEndComment", sourceSpan: c.sourceSpan };
          }
          r.exports = { parseIeConditionalComment: D };
        } }), Xl = I({ "src/language-html/loc.js"(e, r) {
          "use strict";
          q();
          function u(D) {
            return D.sourceSpan.start.offset;
          }
          function n(D) {
            return D.sourceSpan.end.offset;
          }
          r.exports = { locStart: u, locEnd: n };
        } }), Ze = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/tags.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r;
          (function(c) {
            c[c.RAW_TEXT = 0] = "RAW_TEXT", c[c.ESCAPABLE_RAW_TEXT = 1] = "ESCAPABLE_RAW_TEXT", c[c.PARSABLE_DATA = 2] = "PARSABLE_DATA";
          })(r = e.TagContentType || (e.TagContentType = {}));
          function u(c) {
            if (c[0] != ":")
              return [null, c];
            let F = c.indexOf(":", 1);
            if (F == -1)
              throw new Error(`Unsupported format "${c}" expecting ":namespace:name"`);
            return [c.slice(1, F), c.slice(F + 1)];
          }
          e.splitNsName = u;
          function n(c) {
            return u(c)[1] === "ng-container";
          }
          e.isNgContainer = n;
          function D(c) {
            return u(c)[1] === "ng-content";
          }
          e.isNgContent = D;
          function s(c) {
            return u(c)[1] === "ng-template";
          }
          e.isNgTemplate = s;
          function i(c) {
            return c === null ? null : u(c)[0];
          }
          e.getNsPrefix = i;
          function f(c, F) {
            return c ? `:${c}:${F}` : F;
          }
          e.mergeNsAndName = f, e.NAMED_ENTITIES = { Aacute: "\xC1", aacute: "\xE1", Abreve: "\u0102", abreve: "\u0103", ac: "\u223E", acd: "\u223F", acE: "\u223E\u0333", Acirc: "\xC2", acirc: "\xE2", acute: "\xB4", Acy: "\u0410", acy: "\u0430", AElig: "\xC6", aelig: "\xE6", af: "\u2061", Afr: "\u{1D504}", afr: "\u{1D51E}", Agrave: "\xC0", agrave: "\xE0", alefsym: "\u2135", aleph: "\u2135", Alpha: "\u0391", alpha: "\u03B1", Amacr: "\u0100", amacr: "\u0101", amalg: "\u2A3F", AMP: "&", amp: "&", And: "\u2A53", and: "\u2227", andand: "\u2A55", andd: "\u2A5C", andslope: "\u2A58", andv: "\u2A5A", ang: "\u2220", ange: "\u29A4", angle: "\u2220", angmsd: "\u2221", angmsdaa: "\u29A8", angmsdab: "\u29A9", angmsdac: "\u29AA", angmsdad: "\u29AB", angmsdae: "\u29AC", angmsdaf: "\u29AD", angmsdag: "\u29AE", angmsdah: "\u29AF", angrt: "\u221F", angrtvb: "\u22BE", angrtvbd: "\u299D", angsph: "\u2222", angst: "\xC5", angzarr: "\u237C", Aogon: "\u0104", aogon: "\u0105", Aopf: "\u{1D538}", aopf: "\u{1D552}", ap: "\u2248", apacir: "\u2A6F", apE: "\u2A70", ape: "\u224A", apid: "\u224B", apos: "'", ApplyFunction: "\u2061", approx: "\u2248", approxeq: "\u224A", Aring: "\xC5", aring: "\xE5", Ascr: "\u{1D49C}", ascr: "\u{1D4B6}", Assign: "\u2254", ast: "*", asymp: "\u2248", asympeq: "\u224D", Atilde: "\xC3", atilde: "\xE3", Auml: "\xC4", auml: "\xE4", awconint: "\u2233", awint: "\u2A11", backcong: "\u224C", backepsilon: "\u03F6", backprime: "\u2035", backsim: "\u223D", backsimeq: "\u22CD", Backslash: "\u2216", Barv: "\u2AE7", barvee: "\u22BD", Barwed: "\u2306", barwed: "\u2305", barwedge: "\u2305", bbrk: "\u23B5", bbrktbrk: "\u23B6", bcong: "\u224C", Bcy: "\u0411", bcy: "\u0431", bdquo: "\u201E", becaus: "\u2235", Because: "\u2235", because: "\u2235", bemptyv: "\u29B0", bepsi: "\u03F6", bernou: "\u212C", Bernoullis: "\u212C", Beta: "\u0392", beta: "\u03B2", beth: "\u2136", between: "\u226C", Bfr: "\u{1D505}", bfr: "\u{1D51F}", bigcap: "\u22C2", bigcirc: "\u25EF", bigcup: "\u22C3", bigodot: "\u2A00", bigoplus: "\u2A01", bigotimes: "\u2A02", bigsqcup: "\u2A06", bigstar: "\u2605", bigtriangledown: "\u25BD", bigtriangleup: "\u25B3", biguplus: "\u2A04", bigvee: "\u22C1", bigwedge: "\u22C0", bkarow: "\u290D", blacklozenge: "\u29EB", blacksquare: "\u25AA", blacktriangle: "\u25B4", blacktriangledown: "\u25BE", blacktriangleleft: "\u25C2", blacktriangleright: "\u25B8", blank: "\u2423", blk12: "\u2592", blk14: "\u2591", blk34: "\u2593", block: "\u2588", bne: "=\u20E5", bnequiv: "\u2261\u20E5", bNot: "\u2AED", bnot: "\u2310", Bopf: "\u{1D539}", bopf: "\u{1D553}", bot: "\u22A5", bottom: "\u22A5", bowtie: "\u22C8", boxbox: "\u29C9", boxDL: "\u2557", boxDl: "\u2556", boxdL: "\u2555", boxdl: "\u2510", boxDR: "\u2554", boxDr: "\u2553", boxdR: "\u2552", boxdr: "\u250C", boxH: "\u2550", boxh: "\u2500", boxHD: "\u2566", boxHd: "\u2564", boxhD: "\u2565", boxhd: "\u252C", boxHU: "\u2569", boxHu: "\u2567", boxhU: "\u2568", boxhu: "\u2534", boxminus: "\u229F", boxplus: "\u229E", boxtimes: "\u22A0", boxUL: "\u255D", boxUl: "\u255C", boxuL: "\u255B", boxul: "\u2518", boxUR: "\u255A", boxUr: "\u2559", boxuR: "\u2558", boxur: "\u2514", boxV: "\u2551", boxv: "\u2502", boxVH: "\u256C", boxVh: "\u256B", boxvH: "\u256A", boxvh: "\u253C", boxVL: "\u2563", boxVl: "\u2562", boxvL: "\u2561", boxvl: "\u2524", boxVR: "\u2560", boxVr: "\u255F", boxvR: "\u255E", boxvr: "\u251C", bprime: "\u2035", Breve: "\u02D8", breve: "\u02D8", brvbar: "\xA6", Bscr: "\u212C", bscr: "\u{1D4B7}", bsemi: "\u204F", bsim: "\u223D", bsime: "\u22CD", bsol: "\\", bsolb: "\u29C5", bsolhsub: "\u27C8", bull: "\u2022", bullet: "\u2022", bump: "\u224E", bumpE: "\u2AAE", bumpe: "\u224F", Bumpeq: "\u224E", bumpeq: "\u224F", Cacute: "\u0106", cacute: "\u0107", Cap: "\u22D2", cap: "\u2229", capand: "\u2A44", capbrcup: "\u2A49", capcap: "\u2A4B", capcup: "\u2A47", capdot: "\u2A40", CapitalDifferentialD: "\u2145", caps: "\u2229\uFE00", caret: "\u2041", caron: "\u02C7", Cayleys: "\u212D", ccaps: "\u2A4D", Ccaron: "\u010C", ccaron: "\u010D", Ccedil: "\xC7", ccedil: "\xE7", Ccirc: "\u0108", ccirc: "\u0109", Cconint: "\u2230", ccups: "\u2A4C", ccupssm: "\u2A50", Cdot: "\u010A", cdot: "\u010B", cedil: "\xB8", Cedilla: "\xB8", cemptyv: "\u29B2", cent: "\xA2", CenterDot: "\xB7", centerdot: "\xB7", Cfr: "\u212D", cfr: "\u{1D520}", CHcy: "\u0427", chcy: "\u0447", check: "\u2713", checkmark: "\u2713", Chi: "\u03A7", chi: "\u03C7", cir: "\u25CB", circ: "\u02C6", circeq: "\u2257", circlearrowleft: "\u21BA", circlearrowright: "\u21BB", circledast: "\u229B", circledcirc: "\u229A", circleddash: "\u229D", CircleDot: "\u2299", circledR: "\xAE", circledS: "\u24C8", CircleMinus: "\u2296", CirclePlus: "\u2295", CircleTimes: "\u2297", cirE: "\u29C3", cire: "\u2257", cirfnint: "\u2A10", cirmid: "\u2AEF", cirscir: "\u29C2", ClockwiseContourIntegral: "\u2232", CloseCurlyDoubleQuote: "\u201D", CloseCurlyQuote: "\u2019", clubs: "\u2663", clubsuit: "\u2663", Colon: "\u2237", colon: ":", Colone: "\u2A74", colone: "\u2254", coloneq: "\u2254", comma: ",", commat: "@", comp: "\u2201", compfn: "\u2218", complement: "\u2201", complexes: "\u2102", cong: "\u2245", congdot: "\u2A6D", Congruent: "\u2261", Conint: "\u222F", conint: "\u222E", ContourIntegral: "\u222E", Copf: "\u2102", copf: "\u{1D554}", coprod: "\u2210", Coproduct: "\u2210", COPY: "\xA9", copy: "\xA9", copysr: "\u2117", CounterClockwiseContourIntegral: "\u2233", crarr: "\u21B5", Cross: "\u2A2F", cross: "\u2717", Cscr: "\u{1D49E}", cscr: "\u{1D4B8}", csub: "\u2ACF", csube: "\u2AD1", csup: "\u2AD0", csupe: "\u2AD2", ctdot: "\u22EF", cudarrl: "\u2938", cudarrr: "\u2935", cuepr: "\u22DE", cuesc: "\u22DF", cularr: "\u21B6", cularrp: "\u293D", Cup: "\u22D3", cup: "\u222A", cupbrcap: "\u2A48", CupCap: "\u224D", cupcap: "\u2A46", cupcup: "\u2A4A", cupdot: "\u228D", cupor: "\u2A45", cups: "\u222A\uFE00", curarr: "\u21B7", curarrm: "\u293C", curlyeqprec: "\u22DE", curlyeqsucc: "\u22DF", curlyvee: "\u22CE", curlywedge: "\u22CF", curren: "\xA4", curvearrowleft: "\u21B6", curvearrowright: "\u21B7", cuvee: "\u22CE", cuwed: "\u22CF", cwconint: "\u2232", cwint: "\u2231", cylcty: "\u232D", Dagger: "\u2021", dagger: "\u2020", daleth: "\u2138", Darr: "\u21A1", dArr: "\u21D3", darr: "\u2193", dash: "\u2010", Dashv: "\u2AE4", dashv: "\u22A3", dbkarow: "\u290F", dblac: "\u02DD", Dcaron: "\u010E", dcaron: "\u010F", Dcy: "\u0414", dcy: "\u0434", DD: "\u2145", dd: "\u2146", ddagger: "\u2021", ddarr: "\u21CA", DDotrahd: "\u2911", ddotseq: "\u2A77", deg: "\xB0", Del: "\u2207", Delta: "\u0394", delta: "\u03B4", demptyv: "\u29B1", dfisht: "\u297F", Dfr: "\u{1D507}", dfr: "\u{1D521}", dHar: "\u2965", dharl: "\u21C3", dharr: "\u21C2", DiacriticalAcute: "\xB4", DiacriticalDot: "\u02D9", DiacriticalDoubleAcute: "\u02DD", DiacriticalGrave: "`", DiacriticalTilde: "\u02DC", diam: "\u22C4", Diamond: "\u22C4", diamond: "\u22C4", diamondsuit: "\u2666", diams: "\u2666", die: "\xA8", DifferentialD: "\u2146", digamma: "\u03DD", disin: "\u22F2", div: "\xF7", divide: "\xF7", divideontimes: "\u22C7", divonx: "\u22C7", DJcy: "\u0402", djcy: "\u0452", dlcorn: "\u231E", dlcrop: "\u230D", dollar: "$", Dopf: "\u{1D53B}", dopf: "\u{1D555}", Dot: "\xA8", dot: "\u02D9", DotDot: "\u20DC", doteq: "\u2250", doteqdot: "\u2251", DotEqual: "\u2250", dotminus: "\u2238", dotplus: "\u2214", dotsquare: "\u22A1", doublebarwedge: "\u2306", DoubleContourIntegral: "\u222F", DoubleDot: "\xA8", DoubleDownArrow: "\u21D3", DoubleLeftArrow: "\u21D0", DoubleLeftRightArrow: "\u21D4", DoubleLeftTee: "\u2AE4", DoubleLongLeftArrow: "\u27F8", DoubleLongLeftRightArrow: "\u27FA", DoubleLongRightArrow: "\u27F9", DoubleRightArrow: "\u21D2", DoubleRightTee: "\u22A8", DoubleUpArrow: "\u21D1", DoubleUpDownArrow: "\u21D5", DoubleVerticalBar: "\u2225", DownArrow: "\u2193", Downarrow: "\u21D3", downarrow: "\u2193", DownArrowBar: "\u2913", DownArrowUpArrow: "\u21F5", DownBreve: "\u0311", downdownarrows: "\u21CA", downharpoonleft: "\u21C3", downharpoonright: "\u21C2", DownLeftRightVector: "\u2950", DownLeftTeeVector: "\u295E", DownLeftVector: "\u21BD", DownLeftVectorBar: "\u2956", DownRightTeeVector: "\u295F", DownRightVector: "\u21C1", DownRightVectorBar: "\u2957", DownTee: "\u22A4", DownTeeArrow: "\u21A7", drbkarow: "\u2910", drcorn: "\u231F", drcrop: "\u230C", Dscr: "\u{1D49F}", dscr: "\u{1D4B9}", DScy: "\u0405", dscy: "\u0455", dsol: "\u29F6", Dstrok: "\u0110", dstrok: "\u0111", dtdot: "\u22F1", dtri: "\u25BF", dtrif: "\u25BE", duarr: "\u21F5", duhar: "\u296F", dwangle: "\u29A6", DZcy: "\u040F", dzcy: "\u045F", dzigrarr: "\u27FF", Eacute: "\xC9", eacute: "\xE9", easter: "\u2A6E", Ecaron: "\u011A", ecaron: "\u011B", ecir: "\u2256", Ecirc: "\xCA", ecirc: "\xEA", ecolon: "\u2255", Ecy: "\u042D", ecy: "\u044D", eDDot: "\u2A77", Edot: "\u0116", eDot: "\u2251", edot: "\u0117", ee: "\u2147", efDot: "\u2252", Efr: "\u{1D508}", efr: "\u{1D522}", eg: "\u2A9A", Egrave: "\xC8", egrave: "\xE8", egs: "\u2A96", egsdot: "\u2A98", el: "\u2A99", Element: "\u2208", elinters: "\u23E7", ell: "\u2113", els: "\u2A95", elsdot: "\u2A97", Emacr: "\u0112", emacr: "\u0113", empty: "\u2205", emptyset: "\u2205", EmptySmallSquare: "\u25FB", emptyv: "\u2205", EmptyVerySmallSquare: "\u25AB", emsp: "\u2003", emsp13: "\u2004", emsp14: "\u2005", ENG: "\u014A", eng: "\u014B", ensp: "\u2002", Eogon: "\u0118", eogon: "\u0119", Eopf: "\u{1D53C}", eopf: "\u{1D556}", epar: "\u22D5", eparsl: "\u29E3", eplus: "\u2A71", epsi: "\u03B5", Epsilon: "\u0395", epsilon: "\u03B5", epsiv: "\u03F5", eqcirc: "\u2256", eqcolon: "\u2255", eqsim: "\u2242", eqslantgtr: "\u2A96", eqslantless: "\u2A95", Equal: "\u2A75", equals: "=", EqualTilde: "\u2242", equest: "\u225F", Equilibrium: "\u21CC", equiv: "\u2261", equivDD: "\u2A78", eqvparsl: "\u29E5", erarr: "\u2971", erDot: "\u2253", Escr: "\u2130", escr: "\u212F", esdot: "\u2250", Esim: "\u2A73", esim: "\u2242", Eta: "\u0397", eta: "\u03B7", ETH: "\xD0", eth: "\xF0", Euml: "\xCB", euml: "\xEB", euro: "\u20AC", excl: "!", exist: "\u2203", Exists: "\u2203", expectation: "\u2130", ExponentialE: "\u2147", exponentiale: "\u2147", fallingdotseq: "\u2252", Fcy: "\u0424", fcy: "\u0444", female: "\u2640", ffilig: "\uFB03", fflig: "\uFB00", ffllig: "\uFB04", Ffr: "\u{1D509}", ffr: "\u{1D523}", filig: "\uFB01", FilledSmallSquare: "\u25FC", FilledVerySmallSquare: "\u25AA", fjlig: "fj", flat: "\u266D", fllig: "\uFB02", fltns: "\u25B1", fnof: "\u0192", Fopf: "\u{1D53D}", fopf: "\u{1D557}", ForAll: "\u2200", forall: "\u2200", fork: "\u22D4", forkv: "\u2AD9", Fouriertrf: "\u2131", fpartint: "\u2A0D", frac12: "\xBD", frac13: "\u2153", frac14: "\xBC", frac15: "\u2155", frac16: "\u2159", frac18: "\u215B", frac23: "\u2154", frac25: "\u2156", frac34: "\xBE", frac35: "\u2157", frac38: "\u215C", frac45: "\u2158", frac56: "\u215A", frac58: "\u215D", frac78: "\u215E", frasl: "\u2044", frown: "\u2322", Fscr: "\u2131", fscr: "\u{1D4BB}", gacute: "\u01F5", Gamma: "\u0393", gamma: "\u03B3", Gammad: "\u03DC", gammad: "\u03DD", gap: "\u2A86", Gbreve: "\u011E", gbreve: "\u011F", Gcedil: "\u0122", Gcirc: "\u011C", gcirc: "\u011D", Gcy: "\u0413", gcy: "\u0433", Gdot: "\u0120", gdot: "\u0121", gE: "\u2267", ge: "\u2265", gEl: "\u2A8C", gel: "\u22DB", geq: "\u2265", geqq: "\u2267", geqslant: "\u2A7E", ges: "\u2A7E", gescc: "\u2AA9", gesdot: "\u2A80", gesdoto: "\u2A82", gesdotol: "\u2A84", gesl: "\u22DB\uFE00", gesles: "\u2A94", Gfr: "\u{1D50A}", gfr: "\u{1D524}", Gg: "\u22D9", gg: "\u226B", ggg: "\u22D9", gimel: "\u2137", GJcy: "\u0403", gjcy: "\u0453", gl: "\u2277", gla: "\u2AA5", glE: "\u2A92", glj: "\u2AA4", gnap: "\u2A8A", gnapprox: "\u2A8A", gnE: "\u2269", gne: "\u2A88", gneq: "\u2A88", gneqq: "\u2269", gnsim: "\u22E7", Gopf: "\u{1D53E}", gopf: "\u{1D558}", grave: "`", GreaterEqual: "\u2265", GreaterEqualLess: "\u22DB", GreaterFullEqual: "\u2267", GreaterGreater: "\u2AA2", GreaterLess: "\u2277", GreaterSlantEqual: "\u2A7E", GreaterTilde: "\u2273", Gscr: "\u{1D4A2}", gscr: "\u210A", gsim: "\u2273", gsime: "\u2A8E", gsiml: "\u2A90", GT: ">", Gt: "\u226B", gt: ">", gtcc: "\u2AA7", gtcir: "\u2A7A", gtdot: "\u22D7", gtlPar: "\u2995", gtquest: "\u2A7C", gtrapprox: "\u2A86", gtrarr: "\u2978", gtrdot: "\u22D7", gtreqless: "\u22DB", gtreqqless: "\u2A8C", gtrless: "\u2277", gtrsim: "\u2273", gvertneqq: "\u2269\uFE00", gvnE: "\u2269\uFE00", Hacek: "\u02C7", hairsp: "\u200A", half: "\xBD", hamilt: "\u210B", HARDcy: "\u042A", hardcy: "\u044A", hArr: "\u21D4", harr: "\u2194", harrcir: "\u2948", harrw: "\u21AD", Hat: "^", hbar: "\u210F", Hcirc: "\u0124", hcirc: "\u0125", hearts: "\u2665", heartsuit: "\u2665", hellip: "\u2026", hercon: "\u22B9", Hfr: "\u210C", hfr: "\u{1D525}", HilbertSpace: "\u210B", hksearow: "\u2925", hkswarow: "\u2926", hoarr: "\u21FF", homtht: "\u223B", hookleftarrow: "\u21A9", hookrightarrow: "\u21AA", Hopf: "\u210D", hopf: "\u{1D559}", horbar: "\u2015", HorizontalLine: "\u2500", Hscr: "\u210B", hscr: "\u{1D4BD}", hslash: "\u210F", Hstrok: "\u0126", hstrok: "\u0127", HumpDownHump: "\u224E", HumpEqual: "\u224F", hybull: "\u2043", hyphen: "\u2010", Iacute: "\xCD", iacute: "\xED", ic: "\u2063", Icirc: "\xCE", icirc: "\xEE", Icy: "\u0418", icy: "\u0438", Idot: "\u0130", IEcy: "\u0415", iecy: "\u0435", iexcl: "\xA1", iff: "\u21D4", Ifr: "\u2111", ifr: "\u{1D526}", Igrave: "\xCC", igrave: "\xEC", ii: "\u2148", iiiint: "\u2A0C", iiint: "\u222D", iinfin: "\u29DC", iiota: "\u2129", IJlig: "\u0132", ijlig: "\u0133", Im: "\u2111", Imacr: "\u012A", imacr: "\u012B", image: "\u2111", ImaginaryI: "\u2148", imagline: "\u2110", imagpart: "\u2111", imath: "\u0131", imof: "\u22B7", imped: "\u01B5", Implies: "\u21D2", in: "\u2208", incare: "\u2105", infin: "\u221E", infintie: "\u29DD", inodot: "\u0131", Int: "\u222C", int: "\u222B", intcal: "\u22BA", integers: "\u2124", Integral: "\u222B", intercal: "\u22BA", Intersection: "\u22C2", intlarhk: "\u2A17", intprod: "\u2A3C", InvisibleComma: "\u2063", InvisibleTimes: "\u2062", IOcy: "\u0401", iocy: "\u0451", Iogon: "\u012E", iogon: "\u012F", Iopf: "\u{1D540}", iopf: "\u{1D55A}", Iota: "\u0399", iota: "\u03B9", iprod: "\u2A3C", iquest: "\xBF", Iscr: "\u2110", iscr: "\u{1D4BE}", isin: "\u2208", isindot: "\u22F5", isinE: "\u22F9", isins: "\u22F4", isinsv: "\u22F3", isinv: "\u2208", it: "\u2062", Itilde: "\u0128", itilde: "\u0129", Iukcy: "\u0406", iukcy: "\u0456", Iuml: "\xCF", iuml: "\xEF", Jcirc: "\u0134", jcirc: "\u0135", Jcy: "\u0419", jcy: "\u0439", Jfr: "\u{1D50D}", jfr: "\u{1D527}", jmath: "\u0237", Jopf: "\u{1D541}", jopf: "\u{1D55B}", Jscr: "\u{1D4A5}", jscr: "\u{1D4BF}", Jsercy: "\u0408", jsercy: "\u0458", Jukcy: "\u0404", jukcy: "\u0454", Kappa: "\u039A", kappa: "\u03BA", kappav: "\u03F0", Kcedil: "\u0136", kcedil: "\u0137", Kcy: "\u041A", kcy: "\u043A", Kfr: "\u{1D50E}", kfr: "\u{1D528}", kgreen: "\u0138", KHcy: "\u0425", khcy: "\u0445", KJcy: "\u040C", kjcy: "\u045C", Kopf: "\u{1D542}", kopf: "\u{1D55C}", Kscr: "\u{1D4A6}", kscr: "\u{1D4C0}", lAarr: "\u21DA", Lacute: "\u0139", lacute: "\u013A", laemptyv: "\u29B4", lagran: "\u2112", Lambda: "\u039B", lambda: "\u03BB", Lang: "\u27EA", lang: "\u27E8", langd: "\u2991", langle: "\u27E8", lap: "\u2A85", Laplacetrf: "\u2112", laquo: "\xAB", Larr: "\u219E", lArr: "\u21D0", larr: "\u2190", larrb: "\u21E4", larrbfs: "\u291F", larrfs: "\u291D", larrhk: "\u21A9", larrlp: "\u21AB", larrpl: "\u2939", larrsim: "\u2973", larrtl: "\u21A2", lat: "\u2AAB", lAtail: "\u291B", latail: "\u2919", late: "\u2AAD", lates: "\u2AAD\uFE00", lBarr: "\u290E", lbarr: "\u290C", lbbrk: "\u2772", lbrace: "{", lbrack: "[", lbrke: "\u298B", lbrksld: "\u298F", lbrkslu: "\u298D", Lcaron: "\u013D", lcaron: "\u013E", Lcedil: "\u013B", lcedil: "\u013C", lceil: "\u2308", lcub: "{", Lcy: "\u041B", lcy: "\u043B", ldca: "\u2936", ldquo: "\u201C", ldquor: "\u201E", ldrdhar: "\u2967", ldrushar: "\u294B", ldsh: "\u21B2", lE: "\u2266", le: "\u2264", LeftAngleBracket: "\u27E8", LeftArrow: "\u2190", Leftarrow: "\u21D0", leftarrow: "\u2190", LeftArrowBar: "\u21E4", LeftArrowRightArrow: "\u21C6", leftarrowtail: "\u21A2", LeftCeiling: "\u2308", LeftDoubleBracket: "\u27E6", LeftDownTeeVector: "\u2961", LeftDownVector: "\u21C3", LeftDownVectorBar: "\u2959", LeftFloor: "\u230A", leftharpoondown: "\u21BD", leftharpoonup: "\u21BC", leftleftarrows: "\u21C7", LeftRightArrow: "\u2194", Leftrightarrow: "\u21D4", leftrightarrow: "\u2194", leftrightarrows: "\u21C6", leftrightharpoons: "\u21CB", leftrightsquigarrow: "\u21AD", LeftRightVector: "\u294E", LeftTee: "\u22A3", LeftTeeArrow: "\u21A4", LeftTeeVector: "\u295A", leftthreetimes: "\u22CB", LeftTriangle: "\u22B2", LeftTriangleBar: "\u29CF", LeftTriangleEqual: "\u22B4", LeftUpDownVector: "\u2951", LeftUpTeeVector: "\u2960", LeftUpVector: "\u21BF", LeftUpVectorBar: "\u2958", LeftVector: "\u21BC", LeftVectorBar: "\u2952", lEg: "\u2A8B", leg: "\u22DA", leq: "\u2264", leqq: "\u2266", leqslant: "\u2A7D", les: "\u2A7D", lescc: "\u2AA8", lesdot: "\u2A7F", lesdoto: "\u2A81", lesdotor: "\u2A83", lesg: "\u22DA\uFE00", lesges: "\u2A93", lessapprox: "\u2A85", lessdot: "\u22D6", lesseqgtr: "\u22DA", lesseqqgtr: "\u2A8B", LessEqualGreater: "\u22DA", LessFullEqual: "\u2266", LessGreater: "\u2276", lessgtr: "\u2276", LessLess: "\u2AA1", lesssim: "\u2272", LessSlantEqual: "\u2A7D", LessTilde: "\u2272", lfisht: "\u297C", lfloor: "\u230A", Lfr: "\u{1D50F}", lfr: "\u{1D529}", lg: "\u2276", lgE: "\u2A91", lHar: "\u2962", lhard: "\u21BD", lharu: "\u21BC", lharul: "\u296A", lhblk: "\u2584", LJcy: "\u0409", ljcy: "\u0459", Ll: "\u22D8", ll: "\u226A", llarr: "\u21C7", llcorner: "\u231E", Lleftarrow: "\u21DA", llhard: "\u296B", lltri: "\u25FA", Lmidot: "\u013F", lmidot: "\u0140", lmoust: "\u23B0", lmoustache: "\u23B0", lnap: "\u2A89", lnapprox: "\u2A89", lnE: "\u2268", lne: "\u2A87", lneq: "\u2A87", lneqq: "\u2268", lnsim: "\u22E6", loang: "\u27EC", loarr: "\u21FD", lobrk: "\u27E6", LongLeftArrow: "\u27F5", Longleftarrow: "\u27F8", longleftarrow: "\u27F5", LongLeftRightArrow: "\u27F7", Longleftrightarrow: "\u27FA", longleftrightarrow: "\u27F7", longmapsto: "\u27FC", LongRightArrow: "\u27F6", Longrightarrow: "\u27F9", longrightarrow: "\u27F6", looparrowleft: "\u21AB", looparrowright: "\u21AC", lopar: "\u2985", Lopf: "\u{1D543}", lopf: "\u{1D55D}", loplus: "\u2A2D", lotimes: "\u2A34", lowast: "\u2217", lowbar: "_", LowerLeftArrow: "\u2199", LowerRightArrow: "\u2198", loz: "\u25CA", lozenge: "\u25CA", lozf: "\u29EB", lpar: "(", lparlt: "\u2993", lrarr: "\u21C6", lrcorner: "\u231F", lrhar: "\u21CB", lrhard: "\u296D", lrm: "\u200E", lrtri: "\u22BF", lsaquo: "\u2039", Lscr: "\u2112", lscr: "\u{1D4C1}", Lsh: "\u21B0", lsh: "\u21B0", lsim: "\u2272", lsime: "\u2A8D", lsimg: "\u2A8F", lsqb: "[", lsquo: "\u2018", lsquor: "\u201A", Lstrok: "\u0141", lstrok: "\u0142", LT: "<", Lt: "\u226A", lt: "<", ltcc: "\u2AA6", ltcir: "\u2A79", ltdot: "\u22D6", lthree: "\u22CB", ltimes: "\u22C9", ltlarr: "\u2976", ltquest: "\u2A7B", ltri: "\u25C3", ltrie: "\u22B4", ltrif: "\u25C2", ltrPar: "\u2996", lurdshar: "\u294A", luruhar: "\u2966", lvertneqq: "\u2268\uFE00", lvnE: "\u2268\uFE00", macr: "\xAF", male: "\u2642", malt: "\u2720", maltese: "\u2720", Map: "\u2905", map: "\u21A6", mapsto: "\u21A6", mapstodown: "\u21A7", mapstoleft: "\u21A4", mapstoup: "\u21A5", marker: "\u25AE", mcomma: "\u2A29", Mcy: "\u041C", mcy: "\u043C", mdash: "\u2014", mDDot: "\u223A", measuredangle: "\u2221", MediumSpace: "\u205F", Mellintrf: "\u2133", Mfr: "\u{1D510}", mfr: "\u{1D52A}", mho: "\u2127", micro: "\xB5", mid: "\u2223", midast: "*", midcir: "\u2AF0", middot: "\xB7", minus: "\u2212", minusb: "\u229F", minusd: "\u2238", minusdu: "\u2A2A", MinusPlus: "\u2213", mlcp: "\u2ADB", mldr: "\u2026", mnplus: "\u2213", models: "\u22A7", Mopf: "\u{1D544}", mopf: "\u{1D55E}", mp: "\u2213", Mscr: "\u2133", mscr: "\u{1D4C2}", mstpos: "\u223E", Mu: "\u039C", mu: "\u03BC", multimap: "\u22B8", mumap: "\u22B8", nabla: "\u2207", Nacute: "\u0143", nacute: "\u0144", nang: "\u2220\u20D2", nap: "\u2249", napE: "\u2A70\u0338", napid: "\u224B\u0338", napos: "\u0149", napprox: "\u2249", natur: "\u266E", natural: "\u266E", naturals: "\u2115", nbsp: "\xA0", nbump: "\u224E\u0338", nbumpe: "\u224F\u0338", ncap: "\u2A43", Ncaron: "\u0147", ncaron: "\u0148", Ncedil: "\u0145", ncedil: "\u0146", ncong: "\u2247", ncongdot: "\u2A6D\u0338", ncup: "\u2A42", Ncy: "\u041D", ncy: "\u043D", ndash: "\u2013", ne: "\u2260", nearhk: "\u2924", neArr: "\u21D7", nearr: "\u2197", nearrow: "\u2197", nedot: "\u2250\u0338", NegativeMediumSpace: "\u200B", NegativeThickSpace: "\u200B", NegativeThinSpace: "\u200B", NegativeVeryThinSpace: "\u200B", nequiv: "\u2262", nesear: "\u2928", nesim: "\u2242\u0338", NestedGreaterGreater: "\u226B", NestedLessLess: "\u226A", NewLine: `
`, nexist: "\u2204", nexists: "\u2204", Nfr: "\u{1D511}", nfr: "\u{1D52B}", ngE: "\u2267\u0338", nge: "\u2271", ngeq: "\u2271", ngeqq: "\u2267\u0338", ngeqslant: "\u2A7E\u0338", nges: "\u2A7E\u0338", nGg: "\u22D9\u0338", ngsim: "\u2275", nGt: "\u226B\u20D2", ngt: "\u226F", ngtr: "\u226F", nGtv: "\u226B\u0338", nhArr: "\u21CE", nharr: "\u21AE", nhpar: "\u2AF2", ni: "\u220B", nis: "\u22FC", nisd: "\u22FA", niv: "\u220B", NJcy: "\u040A", njcy: "\u045A", nlArr: "\u21CD", nlarr: "\u219A", nldr: "\u2025", nlE: "\u2266\u0338", nle: "\u2270", nLeftarrow: "\u21CD", nleftarrow: "\u219A", nLeftrightarrow: "\u21CE", nleftrightarrow: "\u21AE", nleq: "\u2270", nleqq: "\u2266\u0338", nleqslant: "\u2A7D\u0338", nles: "\u2A7D\u0338", nless: "\u226E", nLl: "\u22D8\u0338", nlsim: "\u2274", nLt: "\u226A\u20D2", nlt: "\u226E", nltri: "\u22EA", nltrie: "\u22EC", nLtv: "\u226A\u0338", nmid: "\u2224", NoBreak: "\u2060", NonBreakingSpace: "\xA0", Nopf: "\u2115", nopf: "\u{1D55F}", Not: "\u2AEC", not: "\xAC", NotCongruent: "\u2262", NotCupCap: "\u226D", NotDoubleVerticalBar: "\u2226", NotElement: "\u2209", NotEqual: "\u2260", NotEqualTilde: "\u2242\u0338", NotExists: "\u2204", NotGreater: "\u226F", NotGreaterEqual: "\u2271", NotGreaterFullEqual: "\u2267\u0338", NotGreaterGreater: "\u226B\u0338", NotGreaterLess: "\u2279", NotGreaterSlantEqual: "\u2A7E\u0338", NotGreaterTilde: "\u2275", NotHumpDownHump: "\u224E\u0338", NotHumpEqual: "\u224F\u0338", notin: "\u2209", notindot: "\u22F5\u0338", notinE: "\u22F9\u0338", notinva: "\u2209", notinvb: "\u22F7", notinvc: "\u22F6", NotLeftTriangle: "\u22EA", NotLeftTriangleBar: "\u29CF\u0338", NotLeftTriangleEqual: "\u22EC", NotLess: "\u226E", NotLessEqual: "\u2270", NotLessGreater: "\u2278", NotLessLess: "\u226A\u0338", NotLessSlantEqual: "\u2A7D\u0338", NotLessTilde: "\u2274", NotNestedGreaterGreater: "\u2AA2\u0338", NotNestedLessLess: "\u2AA1\u0338", notni: "\u220C", notniva: "\u220C", notnivb: "\u22FE", notnivc: "\u22FD", NotPrecedes: "\u2280", NotPrecedesEqual: "\u2AAF\u0338", NotPrecedesSlantEqual: "\u22E0", NotReverseElement: "\u220C", NotRightTriangle: "\u22EB", NotRightTriangleBar: "\u29D0\u0338", NotRightTriangleEqual: "\u22ED", NotSquareSubset: "\u228F\u0338", NotSquareSubsetEqual: "\u22E2", NotSquareSuperset: "\u2290\u0338", NotSquareSupersetEqual: "\u22E3", NotSubset: "\u2282\u20D2", NotSubsetEqual: "\u2288", NotSucceeds: "\u2281", NotSucceedsEqual: "\u2AB0\u0338", NotSucceedsSlantEqual: "\u22E1", NotSucceedsTilde: "\u227F\u0338", NotSuperset: "\u2283\u20D2", NotSupersetEqual: "\u2289", NotTilde: "\u2241", NotTildeEqual: "\u2244", NotTildeFullEqual: "\u2247", NotTildeTilde: "\u2249", NotVerticalBar: "\u2224", npar: "\u2226", nparallel: "\u2226", nparsl: "\u2AFD\u20E5", npart: "\u2202\u0338", npolint: "\u2A14", npr: "\u2280", nprcue: "\u22E0", npre: "\u2AAF\u0338", nprec: "\u2280", npreceq: "\u2AAF\u0338", nrArr: "\u21CF", nrarr: "\u219B", nrarrc: "\u2933\u0338", nrarrw: "\u219D\u0338", nRightarrow: "\u21CF", nrightarrow: "\u219B", nrtri: "\u22EB", nrtrie: "\u22ED", nsc: "\u2281", nsccue: "\u22E1", nsce: "\u2AB0\u0338", Nscr: "\u{1D4A9}", nscr: "\u{1D4C3}", nshortmid: "\u2224", nshortparallel: "\u2226", nsim: "\u2241", nsime: "\u2244", nsimeq: "\u2244", nsmid: "\u2224", nspar: "\u2226", nsqsube: "\u22E2", nsqsupe: "\u22E3", nsub: "\u2284", nsubE: "\u2AC5\u0338", nsube: "\u2288", nsubset: "\u2282\u20D2", nsubseteq: "\u2288", nsubseteqq: "\u2AC5\u0338", nsucc: "\u2281", nsucceq: "\u2AB0\u0338", nsup: "\u2285", nsupE: "\u2AC6\u0338", nsupe: "\u2289", nsupset: "\u2283\u20D2", nsupseteq: "\u2289", nsupseteqq: "\u2AC6\u0338", ntgl: "\u2279", Ntilde: "\xD1", ntilde: "\xF1", ntlg: "\u2278", ntriangleleft: "\u22EA", ntrianglelefteq: "\u22EC", ntriangleright: "\u22EB", ntrianglerighteq: "\u22ED", Nu: "\u039D", nu: "\u03BD", num: "#", numero: "\u2116", numsp: "\u2007", nvap: "\u224D\u20D2", nVDash: "\u22AF", nVdash: "\u22AE", nvDash: "\u22AD", nvdash: "\u22AC", nvge: "\u2265\u20D2", nvgt: ">\u20D2", nvHarr: "\u2904", nvinfin: "\u29DE", nvlArr: "\u2902", nvle: "\u2264\u20D2", nvlt: "<\u20D2", nvltrie: "\u22B4\u20D2", nvrArr: "\u2903", nvrtrie: "\u22B5\u20D2", nvsim: "\u223C\u20D2", nwarhk: "\u2923", nwArr: "\u21D6", nwarr: "\u2196", nwarrow: "\u2196", nwnear: "\u2927", Oacute: "\xD3", oacute: "\xF3", oast: "\u229B", ocir: "\u229A", Ocirc: "\xD4", ocirc: "\xF4", Ocy: "\u041E", ocy: "\u043E", odash: "\u229D", Odblac: "\u0150", odblac: "\u0151", odiv: "\u2A38", odot: "\u2299", odsold: "\u29BC", OElig: "\u0152", oelig: "\u0153", ofcir: "\u29BF", Ofr: "\u{1D512}", ofr: "\u{1D52C}", ogon: "\u02DB", Ograve: "\xD2", ograve: "\xF2", ogt: "\u29C1", ohbar: "\u29B5", ohm: "\u03A9", oint: "\u222E", olarr: "\u21BA", olcir: "\u29BE", olcross: "\u29BB", oline: "\u203E", olt: "\u29C0", Omacr: "\u014C", omacr: "\u014D", Omega: "\u03A9", omega: "\u03C9", Omicron: "\u039F", omicron: "\u03BF", omid: "\u29B6", ominus: "\u2296", Oopf: "\u{1D546}", oopf: "\u{1D560}", opar: "\u29B7", OpenCurlyDoubleQuote: "\u201C", OpenCurlyQuote: "\u2018", operp: "\u29B9", oplus: "\u2295", Or: "\u2A54", or: "\u2228", orarr: "\u21BB", ord: "\u2A5D", order: "\u2134", orderof: "\u2134", ordf: "\xAA", ordm: "\xBA", origof: "\u22B6", oror: "\u2A56", orslope: "\u2A57", orv: "\u2A5B", oS: "\u24C8", Oscr: "\u{1D4AA}", oscr: "\u2134", Oslash: "\xD8", oslash: "\xF8", osol: "\u2298", Otilde: "\xD5", otilde: "\xF5", Otimes: "\u2A37", otimes: "\u2297", otimesas: "\u2A36", Ouml: "\xD6", ouml: "\xF6", ovbar: "\u233D", OverBar: "\u203E", OverBrace: "\u23DE", OverBracket: "\u23B4", OverParenthesis: "\u23DC", par: "\u2225", para: "\xB6", parallel: "\u2225", parsim: "\u2AF3", parsl: "\u2AFD", part: "\u2202", PartialD: "\u2202", Pcy: "\u041F", pcy: "\u043F", percnt: "%", period: ".", permil: "\u2030", perp: "\u22A5", pertenk: "\u2031", Pfr: "\u{1D513}", pfr: "\u{1D52D}", Phi: "\u03A6", phi: "\u03C6", phiv: "\u03D5", phmmat: "\u2133", phone: "\u260E", Pi: "\u03A0", pi: "\u03C0", pitchfork: "\u22D4", piv: "\u03D6", planck: "\u210F", planckh: "\u210E", plankv: "\u210F", plus: "+", plusacir: "\u2A23", plusb: "\u229E", pluscir: "\u2A22", plusdo: "\u2214", plusdu: "\u2A25", pluse: "\u2A72", PlusMinus: "\xB1", plusmn: "\xB1", plussim: "\u2A26", plustwo: "\u2A27", pm: "\xB1", Poincareplane: "\u210C", pointint: "\u2A15", Popf: "\u2119", popf: "\u{1D561}", pound: "\xA3", Pr: "\u2ABB", pr: "\u227A", prap: "\u2AB7", prcue: "\u227C", prE: "\u2AB3", pre: "\u2AAF", prec: "\u227A", precapprox: "\u2AB7", preccurlyeq: "\u227C", Precedes: "\u227A", PrecedesEqual: "\u2AAF", PrecedesSlantEqual: "\u227C", PrecedesTilde: "\u227E", preceq: "\u2AAF", precnapprox: "\u2AB9", precneqq: "\u2AB5", precnsim: "\u22E8", precsim: "\u227E", Prime: "\u2033", prime: "\u2032", primes: "\u2119", prnap: "\u2AB9", prnE: "\u2AB5", prnsim: "\u22E8", prod: "\u220F", Product: "\u220F", profalar: "\u232E", profline: "\u2312", profsurf: "\u2313", prop: "\u221D", Proportion: "\u2237", Proportional: "\u221D", propto: "\u221D", prsim: "\u227E", prurel: "\u22B0", Pscr: "\u{1D4AB}", pscr: "\u{1D4C5}", Psi: "\u03A8", psi: "\u03C8", puncsp: "\u2008", Qfr: "\u{1D514}", qfr: "\u{1D52E}", qint: "\u2A0C", Qopf: "\u211A", qopf: "\u{1D562}", qprime: "\u2057", Qscr: "\u{1D4AC}", qscr: "\u{1D4C6}", quaternions: "\u210D", quatint: "\u2A16", quest: "?", questeq: "\u225F", QUOT: '"', quot: '"', rAarr: "\u21DB", race: "\u223D\u0331", Racute: "\u0154", racute: "\u0155", radic: "\u221A", raemptyv: "\u29B3", Rang: "\u27EB", rang: "\u27E9", rangd: "\u2992", range: "\u29A5", rangle: "\u27E9", raquo: "\xBB", Rarr: "\u21A0", rArr: "\u21D2", rarr: "\u2192", rarrap: "\u2975", rarrb: "\u21E5", rarrbfs: "\u2920", rarrc: "\u2933", rarrfs: "\u291E", rarrhk: "\u21AA", rarrlp: "\u21AC", rarrpl: "\u2945", rarrsim: "\u2974", Rarrtl: "\u2916", rarrtl: "\u21A3", rarrw: "\u219D", rAtail: "\u291C", ratail: "\u291A", ratio: "\u2236", rationals: "\u211A", RBarr: "\u2910", rBarr: "\u290F", rbarr: "\u290D", rbbrk: "\u2773", rbrace: "}", rbrack: "]", rbrke: "\u298C", rbrksld: "\u298E", rbrkslu: "\u2990", Rcaron: "\u0158", rcaron: "\u0159", Rcedil: "\u0156", rcedil: "\u0157", rceil: "\u2309", rcub: "}", Rcy: "\u0420", rcy: "\u0440", rdca: "\u2937", rdldhar: "\u2969", rdquo: "\u201D", rdquor: "\u201D", rdsh: "\u21B3", Re: "\u211C", real: "\u211C", realine: "\u211B", realpart: "\u211C", reals: "\u211D", rect: "\u25AD", REG: "\xAE", reg: "\xAE", ReverseElement: "\u220B", ReverseEquilibrium: "\u21CB", ReverseUpEquilibrium: "\u296F", rfisht: "\u297D", rfloor: "\u230B", Rfr: "\u211C", rfr: "\u{1D52F}", rHar: "\u2964", rhard: "\u21C1", rharu: "\u21C0", rharul: "\u296C", Rho: "\u03A1", rho: "\u03C1", rhov: "\u03F1", RightAngleBracket: "\u27E9", RightArrow: "\u2192", Rightarrow: "\u21D2", rightarrow: "\u2192", RightArrowBar: "\u21E5", RightArrowLeftArrow: "\u21C4", rightarrowtail: "\u21A3", RightCeiling: "\u2309", RightDoubleBracket: "\u27E7", RightDownTeeVector: "\u295D", RightDownVector: "\u21C2", RightDownVectorBar: "\u2955", RightFloor: "\u230B", rightharpoondown: "\u21C1", rightharpoonup: "\u21C0", rightleftarrows: "\u21C4", rightleftharpoons: "\u21CC", rightrightarrows: "\u21C9", rightsquigarrow: "\u219D", RightTee: "\u22A2", RightTeeArrow: "\u21A6", RightTeeVector: "\u295B", rightthreetimes: "\u22CC", RightTriangle: "\u22B3", RightTriangleBar: "\u29D0", RightTriangleEqual: "\u22B5", RightUpDownVector: "\u294F", RightUpTeeVector: "\u295C", RightUpVector: "\u21BE", RightUpVectorBar: "\u2954", RightVector: "\u21C0", RightVectorBar: "\u2953", ring: "\u02DA", risingdotseq: "\u2253", rlarr: "\u21C4", rlhar: "\u21CC", rlm: "\u200F", rmoust: "\u23B1", rmoustache: "\u23B1", rnmid: "\u2AEE", roang: "\u27ED", roarr: "\u21FE", robrk: "\u27E7", ropar: "\u2986", Ropf: "\u211D", ropf: "\u{1D563}", roplus: "\u2A2E", rotimes: "\u2A35", RoundImplies: "\u2970", rpar: ")", rpargt: "\u2994", rppolint: "\u2A12", rrarr: "\u21C9", Rrightarrow: "\u21DB", rsaquo: "\u203A", Rscr: "\u211B", rscr: "\u{1D4C7}", Rsh: "\u21B1", rsh: "\u21B1", rsqb: "]", rsquo: "\u2019", rsquor: "\u2019", rthree: "\u22CC", rtimes: "\u22CA", rtri: "\u25B9", rtrie: "\u22B5", rtrif: "\u25B8", rtriltri: "\u29CE", RuleDelayed: "\u29F4", ruluhar: "\u2968", rx: "\u211E", Sacute: "\u015A", sacute: "\u015B", sbquo: "\u201A", Sc: "\u2ABC", sc: "\u227B", scap: "\u2AB8", Scaron: "\u0160", scaron: "\u0161", sccue: "\u227D", scE: "\u2AB4", sce: "\u2AB0", Scedil: "\u015E", scedil: "\u015F", Scirc: "\u015C", scirc: "\u015D", scnap: "\u2ABA", scnE: "\u2AB6", scnsim: "\u22E9", scpolint: "\u2A13", scsim: "\u227F", Scy: "\u0421", scy: "\u0441", sdot: "\u22C5", sdotb: "\u22A1", sdote: "\u2A66", searhk: "\u2925", seArr: "\u21D8", searr: "\u2198", searrow: "\u2198", sect: "\xA7", semi: ";", seswar: "\u2929", setminus: "\u2216", setmn: "\u2216", sext: "\u2736", Sfr: "\u{1D516}", sfr: "\u{1D530}", sfrown: "\u2322", sharp: "\u266F", SHCHcy: "\u0429", shchcy: "\u0449", SHcy: "\u0428", shcy: "\u0448", ShortDownArrow: "\u2193", ShortLeftArrow: "\u2190", shortmid: "\u2223", shortparallel: "\u2225", ShortRightArrow: "\u2192", ShortUpArrow: "\u2191", shy: "\xAD", Sigma: "\u03A3", sigma: "\u03C3", sigmaf: "\u03C2", sigmav: "\u03C2", sim: "\u223C", simdot: "\u2A6A", sime: "\u2243", simeq: "\u2243", simg: "\u2A9E", simgE: "\u2AA0", siml: "\u2A9D", simlE: "\u2A9F", simne: "\u2246", simplus: "\u2A24", simrarr: "\u2972", slarr: "\u2190", SmallCircle: "\u2218", smallsetminus: "\u2216", smashp: "\u2A33", smeparsl: "\u29E4", smid: "\u2223", smile: "\u2323", smt: "\u2AAA", smte: "\u2AAC", smtes: "\u2AAC\uFE00", SOFTcy: "\u042C", softcy: "\u044C", sol: "/", solb: "\u29C4", solbar: "\u233F", Sopf: "\u{1D54A}", sopf: "\u{1D564}", spades: "\u2660", spadesuit: "\u2660", spar: "\u2225", sqcap: "\u2293", sqcaps: "\u2293\uFE00", sqcup: "\u2294", sqcups: "\u2294\uFE00", Sqrt: "\u221A", sqsub: "\u228F", sqsube: "\u2291", sqsubset: "\u228F", sqsubseteq: "\u2291", sqsup: "\u2290", sqsupe: "\u2292", sqsupset: "\u2290", sqsupseteq: "\u2292", squ: "\u25A1", Square: "\u25A1", square: "\u25A1", SquareIntersection: "\u2293", SquareSubset: "\u228F", SquareSubsetEqual: "\u2291", SquareSuperset: "\u2290", SquareSupersetEqual: "\u2292", SquareUnion: "\u2294", squarf: "\u25AA", squf: "\u25AA", srarr: "\u2192", Sscr: "\u{1D4AE}", sscr: "\u{1D4C8}", ssetmn: "\u2216", ssmile: "\u2323", sstarf: "\u22C6", Star: "\u22C6", star: "\u2606", starf: "\u2605", straightepsilon: "\u03F5", straightphi: "\u03D5", strns: "\xAF", Sub: "\u22D0", sub: "\u2282", subdot: "\u2ABD", subE: "\u2AC5", sube: "\u2286", subedot: "\u2AC3", submult: "\u2AC1", subnE: "\u2ACB", subne: "\u228A", subplus: "\u2ABF", subrarr: "\u2979", Subset: "\u22D0", subset: "\u2282", subseteq: "\u2286", subseteqq: "\u2AC5", SubsetEqual: "\u2286", subsetneq: "\u228A", subsetneqq: "\u2ACB", subsim: "\u2AC7", subsub: "\u2AD5", subsup: "\u2AD3", succ: "\u227B", succapprox: "\u2AB8", succcurlyeq: "\u227D", Succeeds: "\u227B", SucceedsEqual: "\u2AB0", SucceedsSlantEqual: "\u227D", SucceedsTilde: "\u227F", succeq: "\u2AB0", succnapprox: "\u2ABA", succneqq: "\u2AB6", succnsim: "\u22E9", succsim: "\u227F", SuchThat: "\u220B", Sum: "\u2211", sum: "\u2211", sung: "\u266A", Sup: "\u22D1", sup: "\u2283", sup1: "\xB9", sup2: "\xB2", sup3: "\xB3", supdot: "\u2ABE", supdsub: "\u2AD8", supE: "\u2AC6", supe: "\u2287", supedot: "\u2AC4", Superset: "\u2283", SupersetEqual: "\u2287", suphsol: "\u27C9", suphsub: "\u2AD7", suplarr: "\u297B", supmult: "\u2AC2", supnE: "\u2ACC", supne: "\u228B", supplus: "\u2AC0", Supset: "\u22D1", supset: "\u2283", supseteq: "\u2287", supseteqq: "\u2AC6", supsetneq: "\u228B", supsetneqq: "\u2ACC", supsim: "\u2AC8", supsub: "\u2AD4", supsup: "\u2AD6", swarhk: "\u2926", swArr: "\u21D9", swarr: "\u2199", swarrow: "\u2199", swnwar: "\u292A", szlig: "\xDF", Tab: "	", target: "\u2316", Tau: "\u03A4", tau: "\u03C4", tbrk: "\u23B4", Tcaron: "\u0164", tcaron: "\u0165", Tcedil: "\u0162", tcedil: "\u0163", Tcy: "\u0422", tcy: "\u0442", tdot: "\u20DB", telrec: "\u2315", Tfr: "\u{1D517}", tfr: "\u{1D531}", there4: "\u2234", Therefore: "\u2234", therefore: "\u2234", Theta: "\u0398", theta: "\u03B8", thetasym: "\u03D1", thetav: "\u03D1", thickapprox: "\u2248", thicksim: "\u223C", ThickSpace: "\u205F\u200A", thinsp: "\u2009", ThinSpace: "\u2009", thkap: "\u2248", thksim: "\u223C", THORN: "\xDE", thorn: "\xFE", Tilde: "\u223C", tilde: "\u02DC", TildeEqual: "\u2243", TildeFullEqual: "\u2245", TildeTilde: "\u2248", times: "\xD7", timesb: "\u22A0", timesbar: "\u2A31", timesd: "\u2A30", tint: "\u222D", toea: "\u2928", top: "\u22A4", topbot: "\u2336", topcir: "\u2AF1", Topf: "\u{1D54B}", topf: "\u{1D565}", topfork: "\u2ADA", tosa: "\u2929", tprime: "\u2034", TRADE: "\u2122", trade: "\u2122", triangle: "\u25B5", triangledown: "\u25BF", triangleleft: "\u25C3", trianglelefteq: "\u22B4", triangleq: "\u225C", triangleright: "\u25B9", trianglerighteq: "\u22B5", tridot: "\u25EC", trie: "\u225C", triminus: "\u2A3A", TripleDot: "\u20DB", triplus: "\u2A39", trisb: "\u29CD", tritime: "\u2A3B", trpezium: "\u23E2", Tscr: "\u{1D4AF}", tscr: "\u{1D4C9}", TScy: "\u0426", tscy: "\u0446", TSHcy: "\u040B", tshcy: "\u045B", Tstrok: "\u0166", tstrok: "\u0167", twixt: "\u226C", twoheadleftarrow: "\u219E", twoheadrightarrow: "\u21A0", Uacute: "\xDA", uacute: "\xFA", Uarr: "\u219F", uArr: "\u21D1", uarr: "\u2191", Uarrocir: "\u2949", Ubrcy: "\u040E", ubrcy: "\u045E", Ubreve: "\u016C", ubreve: "\u016D", Ucirc: "\xDB", ucirc: "\xFB", Ucy: "\u0423", ucy: "\u0443", udarr: "\u21C5", Udblac: "\u0170", udblac: "\u0171", udhar: "\u296E", ufisht: "\u297E", Ufr: "\u{1D518}", ufr: "\u{1D532}", Ugrave: "\xD9", ugrave: "\xF9", uHar: "\u2963", uharl: "\u21BF", uharr: "\u21BE", uhblk: "\u2580", ulcorn: "\u231C", ulcorner: "\u231C", ulcrop: "\u230F", ultri: "\u25F8", Umacr: "\u016A", umacr: "\u016B", uml: "\xA8", UnderBar: "_", UnderBrace: "\u23DF", UnderBracket: "\u23B5", UnderParenthesis: "\u23DD", Union: "\u22C3", UnionPlus: "\u228E", Uogon: "\u0172", uogon: "\u0173", Uopf: "\u{1D54C}", uopf: "\u{1D566}", UpArrow: "\u2191", Uparrow: "\u21D1", uparrow: "\u2191", UpArrowBar: "\u2912", UpArrowDownArrow: "\u21C5", UpDownArrow: "\u2195", Updownarrow: "\u21D5", updownarrow: "\u2195", UpEquilibrium: "\u296E", upharpoonleft: "\u21BF", upharpoonright: "\u21BE", uplus: "\u228E", UpperLeftArrow: "\u2196", UpperRightArrow: "\u2197", Upsi: "\u03D2", upsi: "\u03C5", upsih: "\u03D2", Upsilon: "\u03A5", upsilon: "\u03C5", UpTee: "\u22A5", UpTeeArrow: "\u21A5", upuparrows: "\u21C8", urcorn: "\u231D", urcorner: "\u231D", urcrop: "\u230E", Uring: "\u016E", uring: "\u016F", urtri: "\u25F9", Uscr: "\u{1D4B0}", uscr: "\u{1D4CA}", utdot: "\u22F0", Utilde: "\u0168", utilde: "\u0169", utri: "\u25B5", utrif: "\u25B4", uuarr: "\u21C8", Uuml: "\xDC", uuml: "\xFC", uwangle: "\u29A7", vangrt: "\u299C", varepsilon: "\u03F5", varkappa: "\u03F0", varnothing: "\u2205", varphi: "\u03D5", varpi: "\u03D6", varpropto: "\u221D", vArr: "\u21D5", varr: "\u2195", varrho: "\u03F1", varsigma: "\u03C2", varsubsetneq: "\u228A\uFE00", varsubsetneqq: "\u2ACB\uFE00", varsupsetneq: "\u228B\uFE00", varsupsetneqq: "\u2ACC\uFE00", vartheta: "\u03D1", vartriangleleft: "\u22B2", vartriangleright: "\u22B3", Vbar: "\u2AEB", vBar: "\u2AE8", vBarv: "\u2AE9", Vcy: "\u0412", vcy: "\u0432", VDash: "\u22AB", Vdash: "\u22A9", vDash: "\u22A8", vdash: "\u22A2", Vdashl: "\u2AE6", Vee: "\u22C1", vee: "\u2228", veebar: "\u22BB", veeeq: "\u225A", vellip: "\u22EE", Verbar: "\u2016", verbar: "|", Vert: "\u2016", vert: "|", VerticalBar: "\u2223", VerticalLine: "|", VerticalSeparator: "\u2758", VerticalTilde: "\u2240", VeryThinSpace: "\u200A", Vfr: "\u{1D519}", vfr: "\u{1D533}", vltri: "\u22B2", vnsub: "\u2282\u20D2", vnsup: "\u2283\u20D2", Vopf: "\u{1D54D}", vopf: "\u{1D567}", vprop: "\u221D", vrtri: "\u22B3", Vscr: "\u{1D4B1}", vscr: "\u{1D4CB}", vsubnE: "\u2ACB\uFE00", vsubne: "\u228A\uFE00", vsupnE: "\u2ACC\uFE00", vsupne: "\u228B\uFE00", Vvdash: "\u22AA", vzigzag: "\u299A", Wcirc: "\u0174", wcirc: "\u0175", wedbar: "\u2A5F", Wedge: "\u22C0", wedge: "\u2227", wedgeq: "\u2259", weierp: "\u2118", Wfr: "\u{1D51A}", wfr: "\u{1D534}", Wopf: "\u{1D54E}", wopf: "\u{1D568}", wp: "\u2118", wr: "\u2240", wreath: "\u2240", Wscr: "\u{1D4B2}", wscr: "\u{1D4CC}", xcap: "\u22C2", xcirc: "\u25EF", xcup: "\u22C3", xdtri: "\u25BD", Xfr: "\u{1D51B}", xfr: "\u{1D535}", xhArr: "\u27FA", xharr: "\u27F7", Xi: "\u039E", xi: "\u03BE", xlArr: "\u27F8", xlarr: "\u27F5", xmap: "\u27FC", xnis: "\u22FB", xodot: "\u2A00", Xopf: "\u{1D54F}", xopf: "\u{1D569}", xoplus: "\u2A01", xotime: "\u2A02", xrArr: "\u27F9", xrarr: "\u27F6", Xscr: "\u{1D4B3}", xscr: "\u{1D4CD}", xsqcup: "\u2A06", xuplus: "\u2A04", xutri: "\u25B3", xvee: "\u22C1", xwedge: "\u22C0", Yacute: "\xDD", yacute: "\xFD", YAcy: "\u042F", yacy: "\u044F", Ycirc: "\u0176", ycirc: "\u0177", Ycy: "\u042B", ycy: "\u044B", yen: "\xA5", Yfr: "\u{1D51C}", yfr: "\u{1D536}", YIcy: "\u0407", yicy: "\u0457", Yopf: "\u{1D550}", yopf: "\u{1D56A}", Yscr: "\u{1D4B4}", yscr: "\u{1D4CE}", YUcy: "\u042E", yucy: "\u044E", Yuml: "\u0178", yuml: "\xFF", Zacute: "\u0179", zacute: "\u017A", Zcaron: "\u017D", zcaron: "\u017E", Zcy: "\u0417", zcy: "\u0437", Zdot: "\u017B", zdot: "\u017C", zeetrf: "\u2128", ZeroWidthSpace: "\u200B", Zeta: "\u0396", zeta: "\u03B6", Zfr: "\u2128", zfr: "\u{1D537}", ZHcy: "\u0416", zhcy: "\u0436", zigrarr: "\u21DD", Zopf: "\u2124", zopf: "\u{1D56B}", Zscr: "\u{1D4B5}", zscr: "\u{1D4CF}", zwj: "\u200D", zwnj: "\u200C" }, e.NGSP_UNICODE = "\uE500", e.NAMED_ENTITIES.ngsp = e.NGSP_UNICODE;
        } }), Bs = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/html_tags.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Ze(), u = class {
            constructor() {
              let { closedByChildren: i, implicitNamespacePrefix: f, contentType: c = r.TagContentType.PARSABLE_DATA, closedByParent: F = false, isVoid: a = false, ignoreFirstLf: l = false } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
              this.closedByChildren = {}, this.closedByParent = false, this.canSelfClose = false, i && i.length > 0 && i.forEach((h) => this.closedByChildren[h] = true), this.isVoid = a, this.closedByParent = F || a, this.implicitNamespacePrefix = f || null, this.contentType = c, this.ignoreFirstLf = l;
            }
            isClosedByChild(i) {
              return this.isVoid || i.toLowerCase() in this.closedByChildren;
            }
          };
          e.HtmlTagDefinition = u;
          var n, D;
          function s(i) {
            return D || (n = new u(), D = { base: new u({ isVoid: true }), meta: new u({ isVoid: true }), area: new u({ isVoid: true }), embed: new u({ isVoid: true }), link: new u({ isVoid: true }), img: new u({ isVoid: true }), input: new u({ isVoid: true }), param: new u({ isVoid: true }), hr: new u({ isVoid: true }), br: new u({ isVoid: true }), source: new u({ isVoid: true }), track: new u({ isVoid: true }), wbr: new u({ isVoid: true }), p: new u({ closedByChildren: ["address", "article", "aside", "blockquote", "div", "dl", "fieldset", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "header", "hgroup", "hr", "main", "nav", "ol", "p", "pre", "section", "table", "ul"], closedByParent: true }), thead: new u({ closedByChildren: ["tbody", "tfoot"] }), tbody: new u({ closedByChildren: ["tbody", "tfoot"], closedByParent: true }), tfoot: new u({ closedByChildren: ["tbody"], closedByParent: true }), tr: new u({ closedByChildren: ["tr"], closedByParent: true }), td: new u({ closedByChildren: ["td", "th"], closedByParent: true }), th: new u({ closedByChildren: ["td", "th"], closedByParent: true }), col: new u({ isVoid: true }), svg: new u({ implicitNamespacePrefix: "svg" }), math: new u({ implicitNamespacePrefix: "math" }), li: new u({ closedByChildren: ["li"], closedByParent: true }), dt: new u({ closedByChildren: ["dt", "dd"] }), dd: new u({ closedByChildren: ["dt", "dd"], closedByParent: true }), rb: new u({ closedByChildren: ["rb", "rt", "rtc", "rp"], closedByParent: true }), rt: new u({ closedByChildren: ["rb", "rt", "rtc", "rp"], closedByParent: true }), rtc: new u({ closedByChildren: ["rb", "rtc", "rp"], closedByParent: true }), rp: new u({ closedByChildren: ["rb", "rt", "rtc", "rp"], closedByParent: true }), optgroup: new u({ closedByChildren: ["optgroup"], closedByParent: true }), option: new u({ closedByChildren: ["option", "optgroup"], closedByParent: true }), pre: new u({ ignoreFirstLf: true }), listing: new u({ ignoreFirstLf: true }), style: new u({ contentType: r.TagContentType.RAW_TEXT }), script: new u({ contentType: r.TagContentType.RAW_TEXT }), title: new u({ contentType: r.TagContentType.ESCAPABLE_RAW_TEXT }), textarea: new u({ contentType: r.TagContentType.ESCAPABLE_RAW_TEXT, ignoreFirstLf: true }) }), D[i] || n;
          }
          e.getHtmlTagDefinition = s;
        } }), Hl = I({ "node_modules/angular-html-parser/lib/compiler/src/ast_path.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = class {
            constructor(u) {
              let n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : -1;
              this.path = u, this.position = n;
            }
            get empty() {
              return !this.path || !this.path.length;
            }
            get head() {
              return this.path[0];
            }
            get tail() {
              return this.path[this.path.length - 1];
            }
            parentOf(u) {
              return u && this.path[this.path.indexOf(u) - 1];
            }
            childOf(u) {
              return this.path[this.path.indexOf(u) + 1];
            }
            first(u) {
              for (let n = this.path.length - 1; n >= 0; n--) {
                let D = this.path[n];
                if (D instanceof u)
                  return D;
              }
            }
            push(u) {
              this.path.push(u);
            }
            pop() {
              return this.path.pop();
            }
          };
          e.AstPath = r;
        } }), bs = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/ast.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Hl(), u = class {
            constructor(d, m, T) {
              this.value = d, this.sourceSpan = m, this.i18n = T, this.type = "text";
            }
            visit(d, m) {
              return d.visitText(this, m);
            }
          };
          e.Text = u;
          var n = class {
            constructor(d, m) {
              this.value = d, this.sourceSpan = m, this.type = "cdata";
            }
            visit(d, m) {
              return d.visitCdata(this, m);
            }
          };
          e.CDATA = n;
          var D = class {
            constructor(d, m, T, w, g, N) {
              this.switchValue = d, this.type = m, this.cases = T, this.sourceSpan = w, this.switchValueSourceSpan = g, this.i18n = N;
            }
            visit(d, m) {
              return d.visitExpansion(this, m);
            }
          };
          e.Expansion = D;
          var s = class {
            constructor(d, m, T, w, g) {
              this.value = d, this.expression = m, this.sourceSpan = T, this.valueSourceSpan = w, this.expSourceSpan = g;
            }
            visit(d, m) {
              return d.visitExpansionCase(this, m);
            }
          };
          e.ExpansionCase = s;
          var i = class {
            constructor(d, m, T) {
              let w = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : null, g = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : null, N = arguments.length > 5 && arguments[5] !== void 0 ? arguments[5] : null;
              this.name = d, this.value = m, this.sourceSpan = T, this.valueSpan = w, this.nameSpan = g, this.i18n = N, this.type = "attribute";
            }
            visit(d, m) {
              return d.visitAttribute(this, m);
            }
          };
          e.Attribute = i;
          var f = class {
            constructor(d, m, T, w) {
              let g = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : null, N = arguments.length > 5 && arguments[5] !== void 0 ? arguments[5] : null, R = arguments.length > 6 && arguments[6] !== void 0 ? arguments[6] : null, j = arguments.length > 7 && arguments[7] !== void 0 ? arguments[7] : null;
              this.name = d, this.attrs = m, this.children = T, this.sourceSpan = w, this.startSourceSpan = g, this.endSourceSpan = N, this.nameSpan = R, this.i18n = j, this.type = "element";
            }
            visit(d, m) {
              return d.visitElement(this, m);
            }
          };
          e.Element = f;
          var c = class {
            constructor(d, m) {
              this.value = d, this.sourceSpan = m, this.type = "comment";
            }
            visit(d, m) {
              return d.visitComment(this, m);
            }
          };
          e.Comment = c;
          var F = class {
            constructor(d, m) {
              this.value = d, this.sourceSpan = m, this.type = "docType";
            }
            visit(d, m) {
              return d.visitDocType(this, m);
            }
          };
          e.DocType = F;
          function a(d, m) {
            let T = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null, w = [], g = d.visit ? (N) => d.visit(N, T) || N.visit(d, T) : (N) => N.visit(d, T);
            return m.forEach((N) => {
              let R = g(N);
              R && w.push(R);
            }), w;
          }
          e.visitAll = a;
          var l = class {
            constructor() {
            }
            visitElement(d, m) {
              this.visitChildren(m, (T) => {
                T(d.attrs), T(d.children);
              });
            }
            visitAttribute(d, m) {
            }
            visitText(d, m) {
            }
            visitCdata(d, m) {
            }
            visitComment(d, m) {
            }
            visitDocType(d, m) {
            }
            visitExpansion(d, m) {
              return this.visitChildren(m, (T) => {
                T(d.cases);
              });
            }
            visitExpansionCase(d, m) {
            }
            visitChildren(d, m) {
              let T = [], w = this;
              function g(N) {
                N && T.push(a(w, N, d));
              }
              return m(g), Array.prototype.concat.apply([], T);
            }
          };
          e.RecursiveVisitor = l;
          function h(d) {
            let m = d.sourceSpan.start.offset, T = d.sourceSpan.end.offset;
            return d instanceof f && (d.endSourceSpan ? T = d.endSourceSpan.end.offset : d.children && d.children.length && (T = h(d.children[d.children.length - 1]).end)), { start: m, end: T };
          }
          function C(d, m) {
            let T = [], w = new class extends l {
              visit(g, N) {
                let R = h(g);
                if (R.start <= m && m < R.end)
                  T.push(g);
                else
                  return true;
              }
            }();
            return a(w, d), new r.AstPath(T, m);
          }
          e.findNode = C;
        } }), zl = I({ "node_modules/angular-html-parser/lib/compiler/src/assertions.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          function r(D, s) {
            if (s != null) {
              if (!Array.isArray(s))
                throw new Error(`Expected '${D}' to be an array of strings.`);
              for (let i = 0; i < s.length; i += 1)
                if (typeof s[i] != "string")
                  throw new Error(`Expected '${D}' to be an array of strings.`);
            }
          }
          e.assertArrayOfStrings = r;
          var u = [/^\s*$/, /[<>]/, /^[{}]$/, /&(#|[a-z])/i, /^\/\//];
          function n(D, s) {
            if (s != null && !(Array.isArray(s) && s.length == 2))
              throw new Error(`Expected '${D}' to be an array, [start, end].`);
            if (s != null) {
              let i = s[0], f = s[1];
              u.forEach((c) => {
                if (c.test(i) || c.test(f))
                  throw new Error(`['${i}', '${f}'] contains unusable interpolation symbol.`);
              });
            }
          }
          e.assertInterpolationSymbols = n;
        } }), Wl = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/interpolation_config.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = zl(), u = class {
            constructor(n, D) {
              this.start = n, this.end = D;
            }
            static fromArray(n) {
              return n ? (r.assertInterpolationSymbols("interpolation", n), new u(n[0], n[1])) : e.DEFAULT_INTERPOLATION_CONFIG;
            }
          };
          e.InterpolationConfig = u, e.DEFAULT_INTERPOLATION_CONFIG = new u("{{", "}}");
        } }), Yl = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/lexer.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Es(), u = Be(), n = Wl(), D = Ze(), s;
          (function(t3) {
            t3[t3.TAG_OPEN_START = 0] = "TAG_OPEN_START", t3[t3.TAG_OPEN_END = 1] = "TAG_OPEN_END", t3[t3.TAG_OPEN_END_VOID = 2] = "TAG_OPEN_END_VOID", t3[t3.TAG_CLOSE = 3] = "TAG_CLOSE", t3[t3.TEXT = 4] = "TEXT", t3[t3.ESCAPABLE_RAW_TEXT = 5] = "ESCAPABLE_RAW_TEXT", t3[t3.RAW_TEXT = 6] = "RAW_TEXT", t3[t3.COMMENT_START = 7] = "COMMENT_START", t3[t3.COMMENT_END = 8] = "COMMENT_END", t3[t3.CDATA_START = 9] = "CDATA_START", t3[t3.CDATA_END = 10] = "CDATA_END", t3[t3.ATTR_NAME = 11] = "ATTR_NAME", t3[t3.ATTR_QUOTE = 12] = "ATTR_QUOTE", t3[t3.ATTR_VALUE = 13] = "ATTR_VALUE", t3[t3.DOC_TYPE_START = 14] = "DOC_TYPE_START", t3[t3.DOC_TYPE_END = 15] = "DOC_TYPE_END", t3[t3.EXPANSION_FORM_START = 16] = "EXPANSION_FORM_START", t3[t3.EXPANSION_CASE_VALUE = 17] = "EXPANSION_CASE_VALUE", t3[t3.EXPANSION_CASE_EXP_START = 18] = "EXPANSION_CASE_EXP_START", t3[t3.EXPANSION_CASE_EXP_END = 19] = "EXPANSION_CASE_EXP_END", t3[t3.EXPANSION_FORM_END = 20] = "EXPANSION_FORM_END", t3[t3.EOF = 21] = "EOF";
          })(s = e.TokenType || (e.TokenType = {}));
          var i = class {
            constructor(t3, o, E) {
              this.type = t3, this.parts = o, this.sourceSpan = E;
            }
          };
          e.Token = i;
          var f = class extends u.ParseError {
            constructor(t3, o, E) {
              super(E, t3), this.tokenType = o;
            }
          };
          e.TokenError = f;
          var c = class {
            constructor(t3, o) {
              this.tokens = t3, this.errors = o;
            }
          };
          e.TokenizeResult = c;
          function F(t3, o, E) {
            let p = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
            return new d(new u.ParseSourceFile(t3, o), E, p).tokenize();
          }
          e.tokenize = F;
          var a = /\r\n?/g;
          function l(t3) {
            return `Unexpected character "${t3 === r.$EOF ? "EOF" : String.fromCharCode(t3)}"`;
          }
          function h(t3) {
            return `Unknown entity "${t3}" - use the "&#<decimal>;" or  "&#x<hex>;" syntax`;
          }
          var C = class {
            constructor(t3) {
              this.error = t3;
            }
          }, d = class {
            constructor(t3, o, E) {
              this._getTagContentType = o, this._currentTokenStart = null, this._currentTokenType = null, this._expansionCaseStack = [], this._inInterpolation = false, this._fullNameStack = [], this.tokens = [], this.errors = [], this._tokenizeIcu = E.tokenizeExpansionForms || false, this._interpolationConfig = E.interpolationConfig || n.DEFAULT_INTERPOLATION_CONFIG, this._leadingTriviaCodePoints = E.leadingTriviaChars && E.leadingTriviaChars.map((A) => A.codePointAt(0) || 0), this._canSelfClose = E.canSelfClose || false, this._allowHtmComponentClosingTags = E.allowHtmComponentClosingTags || false;
              let p = E.range || { endPos: t3.content.length, startPos: 0, startLine: 0, startCol: 0 };
              this._cursor = E.escapedString ? new k(t3, p) : new x(t3, p);
              try {
                this._cursor.init();
              } catch (A) {
                this.handleError(A);
              }
            }
            _processCarriageReturns(t3) {
              return t3.replace(a, `
`);
            }
            tokenize() {
              for (; this._cursor.peek() !== r.$EOF; ) {
                let t3 = this._cursor.clone();
                try {
                  if (this._attemptCharCode(r.$LT))
                    if (this._attemptCharCode(r.$BANG))
                      this._attemptStr("[CDATA[") ? this._consumeCdata(t3) : this._attemptStr("--") ? this._consumeComment(t3) : this._attemptStrCaseInsensitive("doctype") ? this._consumeDocType(t3) : this._consumeBogusComment(t3);
                    else if (this._attemptCharCode(r.$SLASH))
                      this._consumeTagClose(t3);
                    else {
                      let o = this._cursor.clone();
                      this._attemptCharCode(r.$QUESTION) ? (this._cursor = o, this._consumeBogusComment(t3)) : this._consumeTagOpen(t3);
                    }
                  else
                    this._tokenizeIcu && this._tokenizeExpansionForm() || this._consumeText();
                } catch (o) {
                  this.handleError(o);
                }
              }
              return this._beginToken(s.EOF), this._endToken([]), new c(O(this.tokens), this.errors);
            }
            _tokenizeExpansionForm() {
              if (this.isExpansionFormStart())
                return this._consumeExpansionFormStart(), true;
              if (R(this._cursor.peek()) && this._isInExpansionForm())
                return this._consumeExpansionCaseStart(), true;
              if (this._cursor.peek() === r.$RBRACE) {
                if (this._isInExpansionCase())
                  return this._consumeExpansionCaseEnd(), true;
                if (this._isInExpansionForm())
                  return this._consumeExpansionFormEnd(), true;
              }
              return false;
            }
            _beginToken(t3) {
              let o = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this._cursor.clone();
              this._currentTokenStart = o, this._currentTokenType = t3;
            }
            _endToken(t3) {
              let o = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : this._cursor.clone();
              if (this._currentTokenStart === null)
                throw new f("Programming error - attempted to end a token when there was no start to the token", this._currentTokenType, this._cursor.getSpan(o));
              if (this._currentTokenType === null)
                throw new f("Programming error - attempted to end a token which has no token type", null, this._cursor.getSpan(this._currentTokenStart));
              let E = new i(this._currentTokenType, t3, this._cursor.getSpan(this._currentTokenStart, this._leadingTriviaCodePoints));
              return this.tokens.push(E), this._currentTokenStart = null, this._currentTokenType = null, E;
            }
            _createError(t3, o) {
              this._isInExpansionForm() && (t3 += ` (Do you have an unescaped "{" in your template? Use "{{ '{' }}") to escape it.)`);
              let E = new f(t3, this._currentTokenType, o);
              return this._currentTokenStart = null, this._currentTokenType = null, new C(E);
            }
            handleError(t3) {
              if (t3 instanceof $2 && (t3 = this._createError(t3.msg, this._cursor.getSpan(t3.cursor))), t3 instanceof C)
                this.errors.push(t3.error);
              else
                throw t3;
            }
            _attemptCharCode(t3) {
              return this._cursor.peek() === t3 ? (this._cursor.advance(), true) : false;
            }
            _attemptCharCodeCaseInsensitive(t3) {
              return j(this._cursor.peek(), t3) ? (this._cursor.advance(), true) : false;
            }
            _requireCharCode(t3) {
              let o = this._cursor.clone();
              if (!this._attemptCharCode(t3))
                throw this._createError(l(this._cursor.peek()), this._cursor.getSpan(o));
            }
            _attemptStr(t3) {
              let o = t3.length;
              if (this._cursor.charsLeft() < o)
                return false;
              let E = this._cursor.clone();
              for (let p = 0; p < o; p++)
                if (!this._attemptCharCode(t3.charCodeAt(p)))
                  return this._cursor = E, false;
              return true;
            }
            _attemptStrCaseInsensitive(t3) {
              for (let o = 0; o < t3.length; o++)
                if (!this._attemptCharCodeCaseInsensitive(t3.charCodeAt(o)))
                  return false;
              return true;
            }
            _requireStr(t3) {
              let o = this._cursor.clone();
              if (!this._attemptStr(t3))
                throw this._createError(l(this._cursor.peek()), this._cursor.getSpan(o));
            }
            _requireStrCaseInsensitive(t3) {
              let o = this._cursor.clone();
              if (!this._attemptStrCaseInsensitive(t3))
                throw this._createError(l(this._cursor.peek()), this._cursor.getSpan(o));
            }
            _attemptCharCodeUntilFn(t3) {
              for (; !t3(this._cursor.peek()); )
                this._cursor.advance();
            }
            _requireCharCodeUntilFn(t3, o) {
              let E = this._cursor.clone();
              if (this._attemptCharCodeUntilFn(t3), this._cursor.clone().diff(E) < o)
                throw this._createError(l(this._cursor.peek()), this._cursor.getSpan(E));
            }
            _attemptUntilChar(t3) {
              for (; this._cursor.peek() !== t3; )
                this._cursor.advance();
            }
            _readChar(t3) {
              if (t3 && this._cursor.peek() === r.$AMPERSAND)
                return this._decodeEntity();
              {
                let o = String.fromCodePoint(this._cursor.peek());
                return this._cursor.advance(), o;
              }
            }
            _decodeEntity() {
              let t3 = this._cursor.clone();
              if (this._cursor.advance(), this._attemptCharCode(r.$HASH)) {
                let o = this._attemptCharCode(r.$x) || this._attemptCharCode(r.$X), E = this._cursor.clone();
                if (this._attemptCharCodeUntilFn(g), this._cursor.peek() != r.$SEMICOLON)
                  throw this._createError(l(this._cursor.peek()), this._cursor.getSpan());
                let p = this._cursor.getChars(E);
                this._cursor.advance();
                try {
                  let A = parseInt(p, o ? 16 : 10);
                  return String.fromCharCode(A);
                } catch {
                  throw this._createError(h(this._cursor.getChars(t3)), this._cursor.getSpan());
                }
              } else {
                let o = this._cursor.clone();
                if (this._attemptCharCodeUntilFn(N), this._cursor.peek() != r.$SEMICOLON)
                  return this._cursor = o, "&";
                let E = this._cursor.getChars(o);
                this._cursor.advance();
                let p = D.NAMED_ENTITIES[E];
                if (!p)
                  throw this._createError(h(E), this._cursor.getSpan(t3));
                return p;
              }
            }
            _consumeRawText(t3, o) {
              this._beginToken(t3 ? s.ESCAPABLE_RAW_TEXT : s.RAW_TEXT);
              let E = [];
              for (; ; ) {
                let p = this._cursor.clone(), A = o();
                if (this._cursor = p, A)
                  break;
                E.push(this._readChar(t3));
              }
              return this._endToken([this._processCarriageReturns(E.join(""))]);
            }
            _consumeComment(t3) {
              this._beginToken(s.COMMENT_START, t3), this._endToken([]), this._consumeRawText(false, () => this._attemptStr("-->")), this._beginToken(s.COMMENT_END), this._requireStr("-->"), this._endToken([]);
            }
            _consumeBogusComment(t3) {
              this._beginToken(s.COMMENT_START, t3), this._endToken([]), this._consumeRawText(false, () => this._cursor.peek() === r.$GT), this._beginToken(s.COMMENT_END), this._cursor.advance(), this._endToken([]);
            }
            _consumeCdata(t3) {
              this._beginToken(s.CDATA_START, t3), this._endToken([]), this._consumeRawText(false, () => this._attemptStr("]]>")), this._beginToken(s.CDATA_END), this._requireStr("]]>"), this._endToken([]);
            }
            _consumeDocType(t3) {
              this._beginToken(s.DOC_TYPE_START, t3), this._endToken([]), this._consumeRawText(false, () => this._cursor.peek() === r.$GT), this._beginToken(s.DOC_TYPE_END), this._cursor.advance(), this._endToken([]);
            }
            _consumePrefixAndName() {
              let t3 = this._cursor.clone(), o = "";
              for (; this._cursor.peek() !== r.$COLON && !w(this._cursor.peek()); )
                this._cursor.advance();
              let E;
              this._cursor.peek() === r.$COLON ? (o = this._cursor.getChars(t3), this._cursor.advance(), E = this._cursor.clone()) : E = t3, this._requireCharCodeUntilFn(T, o === "" ? 0 : 1);
              let p = this._cursor.getChars(E);
              return [o, p];
            }
            _consumeTagOpen(t3) {
              let o, E, p, A = this.tokens.length, P = this._cursor.clone(), M = [];
              try {
                if (!r.isAsciiLetter(this._cursor.peek()))
                  throw this._createError(l(this._cursor.peek()), this._cursor.getSpan(t3));
                for (p = this._consumeTagOpenStart(t3), E = p.parts[0], o = p.parts[1], this._attemptCharCodeUntilFn(m); this._cursor.peek() !== r.$SLASH && this._cursor.peek() !== r.$GT; ) {
                  let [V, X] = this._consumeAttributeName();
                  if (this._attemptCharCodeUntilFn(m), this._attemptCharCode(r.$EQ)) {
                    this._attemptCharCodeUntilFn(m);
                    let H = this._consumeAttributeValue();
                    M.push({ prefix: V, name: X, value: H });
                  } else
                    M.push({ prefix: V, name: X });
                  this._attemptCharCodeUntilFn(m);
                }
                this._consumeTagOpenEnd();
              } catch (V) {
                if (V instanceof C) {
                  this._cursor = P, p && (this.tokens.length = A), this._beginToken(s.TEXT, t3), this._endToken(["<"]);
                  return;
                }
                throw V;
              }
              if (this._canSelfClose && this.tokens[this.tokens.length - 1].type === s.TAG_OPEN_END_VOID)
                return;
              let z = this._getTagContentType(o, E, this._fullNameStack.length > 0, M);
              this._handleFullNameStackForTagOpen(E, o), z === D.TagContentType.RAW_TEXT ? this._consumeRawTextWithTagClose(E, o, false) : z === D.TagContentType.ESCAPABLE_RAW_TEXT && this._consumeRawTextWithTagClose(E, o, true);
            }
            _consumeRawTextWithTagClose(t3, o, E) {
              let p = this._consumeRawText(E, () => !this._attemptCharCode(r.$LT) || !this._attemptCharCode(r.$SLASH) || (this._attemptCharCodeUntilFn(m), !this._attemptStrCaseInsensitive(t3 ? `${t3}:${o}` : o)) ? false : (this._attemptCharCodeUntilFn(m), this._attemptCharCode(r.$GT)));
              this._beginToken(s.TAG_CLOSE), this._requireCharCodeUntilFn((A) => A === r.$GT, 3), this._cursor.advance(), this._endToken([t3, o]), this._handleFullNameStackForTagClose(t3, o);
            }
            _consumeTagOpenStart(t3) {
              this._beginToken(s.TAG_OPEN_START, t3);
              let o = this._consumePrefixAndName();
              return this._endToken(o);
            }
            _consumeAttributeName() {
              let t3 = this._cursor.peek();
              if (t3 === r.$SQ || t3 === r.$DQ)
                throw this._createError(l(t3), this._cursor.getSpan());
              this._beginToken(s.ATTR_NAME);
              let o = this._consumePrefixAndName();
              return this._endToken(o), o;
            }
            _consumeAttributeValue() {
              let t3;
              if (this._cursor.peek() === r.$SQ || this._cursor.peek() === r.$DQ) {
                this._beginToken(s.ATTR_QUOTE);
                let o = this._cursor.peek();
                this._cursor.advance(), this._endToken([String.fromCodePoint(o)]), this._beginToken(s.ATTR_VALUE);
                let E = [];
                for (; this._cursor.peek() !== o; )
                  E.push(this._readChar(true));
                t3 = this._processCarriageReturns(E.join("")), this._endToken([t3]), this._beginToken(s.ATTR_QUOTE), this._cursor.advance(), this._endToken([String.fromCodePoint(o)]);
              } else {
                this._beginToken(s.ATTR_VALUE);
                let o = this._cursor.clone();
                this._requireCharCodeUntilFn(T, 1), t3 = this._processCarriageReturns(this._cursor.getChars(o)), this._endToken([t3]);
              }
              return t3;
            }
            _consumeTagOpenEnd() {
              let t3 = this._attemptCharCode(r.$SLASH) ? s.TAG_OPEN_END_VOID : s.TAG_OPEN_END;
              this._beginToken(t3), this._requireCharCode(r.$GT), this._endToken([]);
            }
            _consumeTagClose(t3) {
              if (this._beginToken(s.TAG_CLOSE, t3), this._attemptCharCodeUntilFn(m), this._allowHtmComponentClosingTags && this._attemptCharCode(r.$SLASH))
                this._attemptCharCodeUntilFn(m), this._requireCharCode(r.$GT), this._endToken([]);
              else {
                let [o, E] = this._consumePrefixAndName();
                this._attemptCharCodeUntilFn(m), this._requireCharCode(r.$GT), this._endToken([o, E]), this._handleFullNameStackForTagClose(o, E);
              }
            }
            _consumeExpansionFormStart() {
              this._beginToken(s.EXPANSION_FORM_START), this._requireCharCode(r.$LBRACE), this._endToken([]), this._expansionCaseStack.push(s.EXPANSION_FORM_START), this._beginToken(s.RAW_TEXT);
              let t3 = this._readUntil(r.$COMMA);
              this._endToken([t3]), this._requireCharCode(r.$COMMA), this._attemptCharCodeUntilFn(m), this._beginToken(s.RAW_TEXT);
              let o = this._readUntil(r.$COMMA);
              this._endToken([o]), this._requireCharCode(r.$COMMA), this._attemptCharCodeUntilFn(m);
            }
            _consumeExpansionCaseStart() {
              this._beginToken(s.EXPANSION_CASE_VALUE);
              let t3 = this._readUntil(r.$LBRACE).trim();
              this._endToken([t3]), this._attemptCharCodeUntilFn(m), this._beginToken(s.EXPANSION_CASE_EXP_START), this._requireCharCode(r.$LBRACE), this._endToken([]), this._attemptCharCodeUntilFn(m), this._expansionCaseStack.push(s.EXPANSION_CASE_EXP_START);
            }
            _consumeExpansionCaseEnd() {
              this._beginToken(s.EXPANSION_CASE_EXP_END), this._requireCharCode(r.$RBRACE), this._endToken([]), this._attemptCharCodeUntilFn(m), this._expansionCaseStack.pop();
            }
            _consumeExpansionFormEnd() {
              this._beginToken(s.EXPANSION_FORM_END), this._requireCharCode(r.$RBRACE), this._endToken([]), this._expansionCaseStack.pop();
            }
            _consumeText() {
              let t3 = this._cursor.clone();
              this._beginToken(s.TEXT, t3);
              let o = [];
              do
                this._interpolationConfig && this._attemptStr(this._interpolationConfig.start) ? (o.push(this._interpolationConfig.start), this._inInterpolation = true) : this._interpolationConfig && this._inInterpolation && this._attemptStr(this._interpolationConfig.end) ? (o.push(this._interpolationConfig.end), this._inInterpolation = false) : o.push(this._readChar(true));
              while (!this._isTextEnd());
              this._endToken([this._processCarriageReturns(o.join(""))]);
            }
            _isTextEnd() {
              return !!(this._cursor.peek() === r.$LT || this._cursor.peek() === r.$EOF || this._tokenizeIcu && !this._inInterpolation && (this.isExpansionFormStart() || this._cursor.peek() === r.$RBRACE && this._isInExpansionCase()));
            }
            _readUntil(t3) {
              let o = this._cursor.clone();
              return this._attemptUntilChar(t3), this._cursor.getChars(o);
            }
            _isInExpansionCase() {
              return this._expansionCaseStack.length > 0 && this._expansionCaseStack[this._expansionCaseStack.length - 1] === s.EXPANSION_CASE_EXP_START;
            }
            _isInExpansionForm() {
              return this._expansionCaseStack.length > 0 && this._expansionCaseStack[this._expansionCaseStack.length - 1] === s.EXPANSION_FORM_START;
            }
            isExpansionFormStart() {
              if (this._cursor.peek() !== r.$LBRACE)
                return false;
              if (this._interpolationConfig) {
                let t3 = this._cursor.clone(), o = this._attemptStr(this._interpolationConfig.start);
                return this._cursor = t3, !o;
              }
              return true;
            }
            _handleFullNameStackForTagOpen(t3, o) {
              let E = D.mergeNsAndName(t3, o);
              (this._fullNameStack.length === 0 || this._fullNameStack[this._fullNameStack.length - 1] === E) && this._fullNameStack.push(E);
            }
            _handleFullNameStackForTagClose(t3, o) {
              let E = D.mergeNsAndName(t3, o);
              this._fullNameStack.length !== 0 && this._fullNameStack[this._fullNameStack.length - 1] === E && this._fullNameStack.pop();
            }
          };
          function m(t3) {
            return !r.isWhitespace(t3) || t3 === r.$EOF;
          }
          function T(t3) {
            return r.isWhitespace(t3) || t3 === r.$GT || t3 === r.$SLASH || t3 === r.$SQ || t3 === r.$DQ || t3 === r.$EQ;
          }
          function w(t3) {
            return (t3 < r.$a || r.$z < t3) && (t3 < r.$A || r.$Z < t3) && (t3 < r.$0 || t3 > r.$9);
          }
          function g(t3) {
            return t3 == r.$SEMICOLON || t3 == r.$EOF || !r.isAsciiHexDigit(t3);
          }
          function N(t3) {
            return t3 == r.$SEMICOLON || t3 == r.$EOF || !r.isAsciiLetter(t3);
          }
          function R(t3) {
            return t3 === r.$EQ || r.isAsciiLetter(t3) || r.isDigit(t3);
          }
          function j(t3, o) {
            return _(t3) == _(o);
          }
          function _(t3) {
            return t3 >= r.$a && t3 <= r.$z ? t3 - r.$a + r.$A : t3;
          }
          function O(t3) {
            let o = [], E;
            for (let p = 0; p < t3.length; p++) {
              let A = t3[p];
              E && E.type == s.TEXT && A.type == s.TEXT ? (E.parts[0] += A.parts[0], E.sourceSpan.end = A.sourceSpan.end) : (E = A, o.push(E));
            }
            return o;
          }
          var x = class {
            constructor(t3, o) {
              if (t3 instanceof x)
                this.file = t3.file, this.input = t3.input, this.end = t3.end, this.state = Object.assign({}, t3.state);
              else {
                if (!o)
                  throw new Error("Programming error: the range argument must be provided with a file argument.");
                this.file = t3, this.input = t3.content, this.end = o.endPos, this.state = { peek: -1, offset: o.startPos, line: o.startLine, column: o.startCol };
              }
            }
            clone() {
              return new x(this);
            }
            peek() {
              return this.state.peek;
            }
            charsLeft() {
              return this.end - this.state.offset;
            }
            diff(t3) {
              return this.state.offset - t3.state.offset;
            }
            advance() {
              this.advanceState(this.state);
            }
            init() {
              this.updatePeek(this.state);
            }
            getSpan(t3, o) {
              if (t3 = t3 || this, o)
                for (t3 = t3.clone(); this.diff(t3) > 0 && o.indexOf(t3.peek()) !== -1; )
                  t3.advance();
              return new u.ParseSourceSpan(new u.ParseLocation(t3.file, t3.state.offset, t3.state.line, t3.state.column), new u.ParseLocation(this.file, this.state.offset, this.state.line, this.state.column));
            }
            getChars(t3) {
              return this.input.substring(t3.state.offset, this.state.offset);
            }
            charAt(t3) {
              return this.input.charCodeAt(t3);
            }
            advanceState(t3) {
              if (t3.offset >= this.end)
                throw this.state = t3, new $2('Unexpected character "EOF"', this);
              let o = this.charAt(t3.offset);
              o === r.$LF ? (t3.line++, t3.column = 0) : r.isNewLine(o) || t3.column++, t3.offset++, this.updatePeek(t3);
            }
            updatePeek(t3) {
              t3.peek = t3.offset >= this.end ? r.$EOF : this.charAt(t3.offset);
            }
          }, k = class extends x {
            constructor(t3, o) {
              t3 instanceof k ? (super(t3), this.internalState = Object.assign({}, t3.internalState)) : (super(t3, o), this.internalState = this.state);
            }
            advance() {
              this.state = this.internalState, super.advance(), this.processEscapeSequence();
            }
            init() {
              super.init(), this.processEscapeSequence();
            }
            clone() {
              return new k(this);
            }
            getChars(t3) {
              let o = t3.clone(), E = "";
              for (; o.internalState.offset < this.internalState.offset; )
                E += String.fromCodePoint(o.peek()), o.advance();
              return E;
            }
            processEscapeSequence() {
              let t3 = () => this.internalState.peek;
              if (t3() === r.$BACKSLASH)
                if (this.internalState = Object.assign({}, this.state), this.advanceState(this.internalState), t3() === r.$n)
                  this.state.peek = r.$LF;
                else if (t3() === r.$r)
                  this.state.peek = r.$CR;
                else if (t3() === r.$v)
                  this.state.peek = r.$VTAB;
                else if (t3() === r.$t)
                  this.state.peek = r.$TAB;
                else if (t3() === r.$b)
                  this.state.peek = r.$BSPACE;
                else if (t3() === r.$f)
                  this.state.peek = r.$FF;
                else if (t3() === r.$u)
                  if (this.advanceState(this.internalState), t3() === r.$LBRACE) {
                    this.advanceState(this.internalState);
                    let o = this.clone(), E = 0;
                    for (; t3() !== r.$RBRACE; )
                      this.advanceState(this.internalState), E++;
                    this.state.peek = this.decodeHexDigits(o, E);
                  } else {
                    let o = this.clone();
                    this.advanceState(this.internalState), this.advanceState(this.internalState), this.advanceState(this.internalState), this.state.peek = this.decodeHexDigits(o, 4);
                  }
                else if (t3() === r.$x) {
                  this.advanceState(this.internalState);
                  let o = this.clone();
                  this.advanceState(this.internalState), this.state.peek = this.decodeHexDigits(o, 2);
                } else if (r.isOctalDigit(t3())) {
                  let o = "", E = 0, p = this.clone();
                  for (; r.isOctalDigit(t3()) && E < 3; )
                    p = this.clone(), o += String.fromCodePoint(t3()), this.advanceState(this.internalState), E++;
                  this.state.peek = parseInt(o, 8), this.internalState = p.internalState;
                } else
                  r.isNewLine(this.internalState.peek) ? (this.advanceState(this.internalState), this.state = this.internalState) : this.state.peek = this.internalState.peek;
            }
            decodeHexDigits(t3, o) {
              let E = this.input.substr(t3.internalState.offset, o), p = parseInt(E, 16);
              if (isNaN(p))
                throw t3.state = t3.internalState, new $2("Invalid hexadecimal escape sequence", t3);
              return p;
            }
          }, $2 = class {
            constructor(t3, o) {
              this.msg = t3, this.cursor = o;
            }
          };
          e.CursorError = $2;
        } }), ls = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/parser.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Be(), u = bs(), n = Yl(), D = Ze(), s = class extends r.ParseError {
            constructor(a, l, h) {
              super(l, h), this.elementName = a;
            }
            static create(a, l, h) {
              return new s(a, l, h);
            }
          };
          e.TreeError = s;
          var i = class {
            constructor(a, l) {
              this.rootNodes = a, this.errors = l;
            }
          };
          e.ParseTreeResult = i;
          var f = class {
            constructor(a) {
              this.getTagDefinition = a;
            }
            parse(a, l, h) {
              let C = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false, d = arguments.length > 4 ? arguments[4] : void 0, m = (x) => function(k) {
                for (var $2 = arguments.length, t3 = new Array($2 > 1 ? $2 - 1 : 0), o = 1; o < $2; o++)
                  t3[o - 1] = arguments[o];
                return x(k.toLowerCase(), ...t3);
              }, T = C ? this.getTagDefinition : m(this.getTagDefinition), w = (x) => T(x).contentType, g = C ? d : m(d), N = d ? (x, k, $2, t3) => {
                let o = g(x, k, $2, t3);
                return o !== void 0 ? o : w(x);
              } : w, R = n.tokenize(a, l, N, h), j = h && h.canSelfClose || false, _ = h && h.allowHtmComponentClosingTags || false, O = new c(R.tokens, T, j, _, C).build();
              return new i(O.rootNodes, R.errors.concat(O.errors));
            }
          };
          e.Parser = f;
          var c = class {
            constructor(a, l, h, C, d) {
              this.tokens = a, this.getTagDefinition = l, this.canSelfClose = h, this.allowHtmComponentClosingTags = C, this.isTagNameCaseSensitive = d, this._index = -1, this._rootNodes = [], this._errors = [], this._elementStack = [], this._advance();
            }
            build() {
              for (; this._peek.type !== n.TokenType.EOF; )
                this._peek.type === n.TokenType.TAG_OPEN_START ? this._consumeStartTag(this._advance()) : this._peek.type === n.TokenType.TAG_CLOSE ? (this._closeVoidElement(), this._consumeEndTag(this._advance())) : this._peek.type === n.TokenType.CDATA_START ? (this._closeVoidElement(), this._consumeCdata(this._advance())) : this._peek.type === n.TokenType.COMMENT_START ? (this._closeVoidElement(), this._consumeComment(this._advance())) : this._peek.type === n.TokenType.TEXT || this._peek.type === n.TokenType.RAW_TEXT || this._peek.type === n.TokenType.ESCAPABLE_RAW_TEXT ? (this._closeVoidElement(), this._consumeText(this._advance())) : this._peek.type === n.TokenType.EXPANSION_FORM_START ? this._consumeExpansion(this._advance()) : this._peek.type === n.TokenType.DOC_TYPE_START ? this._consumeDocType(this._advance()) : this._advance();
              return new i(this._rootNodes, this._errors);
            }
            _advance() {
              let a = this._peek;
              return this._index < this.tokens.length - 1 && this._index++, this._peek = this.tokens[this._index], a;
            }
            _advanceIf(a) {
              return this._peek.type === a ? this._advance() : null;
            }
            _consumeCdata(a) {
              let l = this._advance(), h = this._getText(l), C = this._advanceIf(n.TokenType.CDATA_END);
              this._addToParent(new u.CDATA(h, new r.ParseSourceSpan(a.sourceSpan.start, (C || l).sourceSpan.end)));
            }
            _consumeComment(a) {
              let l = this._advanceIf(n.TokenType.RAW_TEXT), h = this._advanceIf(n.TokenType.COMMENT_END), C = l != null ? l.parts[0].trim() : null, d = new r.ParseSourceSpan(a.sourceSpan.start, (h || l || a).sourceSpan.end);
              this._addToParent(new u.Comment(C, d));
            }
            _consumeDocType(a) {
              let l = this._advanceIf(n.TokenType.RAW_TEXT), h = this._advanceIf(n.TokenType.DOC_TYPE_END), C = l != null ? l.parts[0].trim() : null, d = new r.ParseSourceSpan(a.sourceSpan.start, (h || l || a).sourceSpan.end);
              this._addToParent(new u.DocType(C, d));
            }
            _consumeExpansion(a) {
              let l = this._advance(), h = this._advance(), C = [];
              for (; this._peek.type === n.TokenType.EXPANSION_CASE_VALUE; ) {
                let m = this._parseExpansionCase();
                if (!m)
                  return;
                C.push(m);
              }
              if (this._peek.type !== n.TokenType.EXPANSION_FORM_END) {
                this._errors.push(s.create(null, this._peek.sourceSpan, "Invalid ICU message. Missing '}'."));
                return;
              }
              let d = new r.ParseSourceSpan(a.sourceSpan.start, this._peek.sourceSpan.end);
              this._addToParent(new u.Expansion(l.parts[0], h.parts[0], C, d, l.sourceSpan)), this._advance();
            }
            _parseExpansionCase() {
              let a = this._advance();
              if (this._peek.type !== n.TokenType.EXPANSION_CASE_EXP_START)
                return this._errors.push(s.create(null, this._peek.sourceSpan, "Invalid ICU message. Missing '{'.")), null;
              let l = this._advance(), h = this._collectExpansionExpTokens(l);
              if (!h)
                return null;
              let C = this._advance();
              h.push(new n.Token(n.TokenType.EOF, [], C.sourceSpan));
              let d = new c(h, this.getTagDefinition, this.canSelfClose, this.allowHtmComponentClosingTags, this.isTagNameCaseSensitive).build();
              if (d.errors.length > 0)
                return this._errors = this._errors.concat(d.errors), null;
              let m = new r.ParseSourceSpan(a.sourceSpan.start, C.sourceSpan.end), T = new r.ParseSourceSpan(l.sourceSpan.start, C.sourceSpan.end);
              return new u.ExpansionCase(a.parts[0], d.rootNodes, m, a.sourceSpan, T);
            }
            _collectExpansionExpTokens(a) {
              let l = [], h = [n.TokenType.EXPANSION_CASE_EXP_START];
              for (; ; ) {
                if ((this._peek.type === n.TokenType.EXPANSION_FORM_START || this._peek.type === n.TokenType.EXPANSION_CASE_EXP_START) && h.push(this._peek.type), this._peek.type === n.TokenType.EXPANSION_CASE_EXP_END)
                  if (F(h, n.TokenType.EXPANSION_CASE_EXP_START)) {
                    if (h.pop(), h.length == 0)
                      return l;
                  } else
                    return this._errors.push(s.create(null, a.sourceSpan, "Invalid ICU message. Missing '}'.")), null;
                if (this._peek.type === n.TokenType.EXPANSION_FORM_END)
                  if (F(h, n.TokenType.EXPANSION_FORM_START))
                    h.pop();
                  else
                    return this._errors.push(s.create(null, a.sourceSpan, "Invalid ICU message. Missing '}'.")), null;
                if (this._peek.type === n.TokenType.EOF)
                  return this._errors.push(s.create(null, a.sourceSpan, "Invalid ICU message. Missing '}'.")), null;
                l.push(this._advance());
              }
            }
            _getText(a) {
              let l = a.parts[0];
              if (l.length > 0 && l[0] == `
`) {
                let h = this._getParentElement();
                h != null && h.children.length == 0 && this.getTagDefinition(h.name).ignoreFirstLf && (l = l.substring(1));
              }
              return l;
            }
            _consumeText(a) {
              let l = this._getText(a);
              l.length > 0 && this._addToParent(new u.Text(l, a.sourceSpan));
            }
            _closeVoidElement() {
              let a = this._getParentElement();
              a && this.getTagDefinition(a.name).isVoid && this._elementStack.pop();
            }
            _consumeStartTag(a) {
              let l = a.parts[0], h = a.parts[1], C = [];
              for (; this._peek.type === n.TokenType.ATTR_NAME; )
                C.push(this._consumeAttr(this._advance()));
              let d = this._getElementFullName(l, h, this._getParentElement()), m = false;
              if (this._peek.type === n.TokenType.TAG_OPEN_END_VOID) {
                this._advance(), m = true;
                let R = this.getTagDefinition(d);
                this.canSelfClose || R.canSelfClose || D.getNsPrefix(d) !== null || R.isVoid || this._errors.push(s.create(d, a.sourceSpan, `Only void and foreign elements can be self closed "${a.parts[1]}"`));
              } else
                this._peek.type === n.TokenType.TAG_OPEN_END && (this._advance(), m = false);
              let T = this._peek.sourceSpan.start, w = new r.ParseSourceSpan(a.sourceSpan.start, T), g = new r.ParseSourceSpan(a.sourceSpan.start.moveBy(1), a.sourceSpan.end), N = new u.Element(d, C, [], w, w, void 0, g);
              this._pushElement(N), m && (this._popElement(d), N.endSourceSpan = w);
            }
            _pushElement(a) {
              let l = this._getParentElement();
              l && this.getTagDefinition(l.name).isClosedByChild(a.name) && this._elementStack.pop(), this._addToParent(a), this._elementStack.push(a);
            }
            _consumeEndTag(a) {
              let l = this.allowHtmComponentClosingTags && a.parts.length === 0 ? null : this._getElementFullName(a.parts[0], a.parts[1], this._getParentElement());
              if (this._getParentElement() && (this._getParentElement().endSourceSpan = a.sourceSpan), l && this.getTagDefinition(l).isVoid)
                this._errors.push(s.create(l, a.sourceSpan, `Void elements do not have end tags "${a.parts[1]}"`));
              else if (!this._popElement(l)) {
                let h = `Unexpected closing tag "${l}". It may happen when the tag has already been closed by another tag. For more info see https://www.w3.org/TR/html5/syntax.html#closing-elements-that-have-implied-end-tags`;
                this._errors.push(s.create(l, a.sourceSpan, h));
              }
            }
            _popElement(a) {
              for (let l = this._elementStack.length - 1; l >= 0; l--) {
                let h = this._elementStack[l];
                if (!a || (D.getNsPrefix(h.name) ? h.name == a : h.name.toLowerCase() == a.toLowerCase()))
                  return this._elementStack.splice(l, this._elementStack.length - l), true;
                if (!this.getTagDefinition(h.name).closedByParent)
                  return false;
              }
              return false;
            }
            _consumeAttr(a) {
              let l = D.mergeNsAndName(a.parts[0], a.parts[1]), h = a.sourceSpan.end, C = "", d, m;
              if (this._peek.type === n.TokenType.ATTR_QUOTE && (m = this._advance().sourceSpan.start), this._peek.type === n.TokenType.ATTR_VALUE) {
                let T = this._advance();
                C = T.parts[0], h = T.sourceSpan.end, d = T.sourceSpan;
              }
              return this._peek.type === n.TokenType.ATTR_QUOTE && (h = this._advance().sourceSpan.end, d = new r.ParseSourceSpan(m, h)), new u.Attribute(l, C, new r.ParseSourceSpan(a.sourceSpan.start, h), d, a.sourceSpan);
            }
            _getParentElement() {
              return this._elementStack.length > 0 ? this._elementStack[this._elementStack.length - 1] : null;
            }
            _getParentElementSkippingContainers() {
              let a = null;
              for (let l = this._elementStack.length - 1; l >= 0; l--) {
                if (!D.isNgContainer(this._elementStack[l].name))
                  return { parent: this._elementStack[l], container: a };
                a = this._elementStack[l];
              }
              return { parent: null, container: a };
            }
            _addToParent(a) {
              let l = this._getParentElement();
              l != null ? l.children.push(a) : this._rootNodes.push(a);
            }
            _insertBeforeContainer(a, l, h) {
              if (!l)
                this._addToParent(h), this._elementStack.push(h);
              else {
                if (a) {
                  let C = a.children.indexOf(l);
                  a.children[C] = h;
                } else
                  this._rootNodes.push(h);
                h.children.push(l), this._elementStack.splice(this._elementStack.indexOf(l), 0, h);
              }
            }
            _getElementFullName(a, l, h) {
              return a === "" && (a = this.getTagDefinition(l).implicitNamespacePrefix || "", a === "" && h != null && (a = D.getNsPrefix(h.name))), D.mergeNsAndName(a, l);
            }
          };
          function F(a, l) {
            return a.length > 0 && a[a.length - 1] === l;
          }
        } }), Ql = I({ "node_modules/angular-html-parser/lib/compiler/src/ml_parser/html_parser.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Bs(), u = ls(), n = ls();
          e.ParseTreeResult = n.ParseTreeResult, e.TreeError = n.TreeError;
          var D = class extends u.Parser {
            constructor() {
              super(r.getHtmlTagDefinition);
            }
            parse(s, i, f) {
              let c = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false, F = arguments.length > 4 ? arguments[4] : void 0;
              return super.parse(s, i, f, c, F);
            }
          };
          e.HtmlParser = D;
        } }), ws = I({ "node_modules/angular-html-parser/lib/angular-html-parser/src/index.js"(e) {
          "use strict";
          q(), Object.defineProperty(e, "__esModule", { value: true });
          var r = Ql(), u = Ze();
          e.TagContentType = u.TagContentType;
          var n = null, D = () => (n || (n = new r.HtmlParser()), n);
          function s(i) {
            let f = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, { canSelfClose: c = false, allowHtmComponentClosingTags: F = false, isTagNameCaseSensitive: a = false, getTagContentType: l } = f;
            return D().parse(i, "angular-html-parser", { tokenizeExpansionForms: false, interpolationConfig: void 0, canSelfClose: c, allowHtmComponentClosingTags: F }, a, l);
          }
          e.parse = s;
        } });
        q();
        var { ParseSourceSpan: Qe, ParseLocation: cs, ParseSourceFile: Kl } = Be(), Jl = ol(), Zl = Cs(), ec = Dl(), { inferParserByLanguage: rc } = xl(), uc = kl(), Vr = Ml(), hs = jl(), { hasPragma: tc } = Ul(), { Node: nc } = Gl(), { parseIeConditionalComment: sc } = Vl(), { locStart: ic, locEnd: ac } = Xl();
        function oc(e, r, u) {
          let { recognizeSelfClosing: n, normalizeTagName: D, normalizeAttributeName: s, allowHtmComponentClosingTags: i, isTagNameCaseSensitive: f, getTagContentType: c } = r, F = ws(), { RecursiveVisitor: a, visitAll: l } = bs(), { ParseSourceSpan: h } = Be(), { getHtmlTagDefinition: C } = Bs(), { rootNodes: d, errors: m } = F.parse(e, { canSelfClose: n, allowHtmComponentClosingTags: i, isTagNameCaseSensitive: f, getTagContentType: c });
          if (u.parser === "vue")
            if (d.some((O) => O.type === "docType" && O.value === "html" || O.type === "element" && O.name.toLowerCase() === "html")) {
              n = true, D = true, s = true, i = true, f = false;
              let O = F.parse(e, { canSelfClose: n, allowHtmComponentClosingTags: i, isTagNameCaseSensitive: f });
              d = O.rootNodes, m = O.errors;
            } else {
              let O = (x) => {
                if (!x || x.type !== "element" || x.name !== "template")
                  return false;
                let k = x.attrs.find((t3) => t3.name === "lang"), $2 = k && k.value;
                return !$2 || rc($2, u) === "html";
              };
              if (d.some(O)) {
                let x, k = () => F.parse(e, { canSelfClose: n, allowHtmComponentClosingTags: i, isTagNameCaseSensitive: f }), $2 = () => x || (x = k()), t3 = (o) => $2().rootNodes.find((E) => {
                  let { startSourceSpan: p } = E;
                  return p && p.start.offset === o.startSourceSpan.start.offset;
                });
                for (let o = 0; o < d.length; o++) {
                  let E = d[o], { endSourceSpan: p, startSourceSpan: A } = E;
                  if (p === null)
                    m = $2().errors, d[o] = t3(E) || E;
                  else if (O(E)) {
                    let M = $2(), z = A.end.offset, V = p.start.offset;
                    for (let X of M.errors) {
                      let { offset: H } = X.span.start;
                      if (z < H && H < V) {
                        m = [X];
                        break;
                      }
                    }
                    d[o] = t3(E) || E;
                  }
                }
              }
            }
          if (m.length > 0) {
            let { msg: _, span: { start: O, end: x } } = m[0];
            throw ec(_, { start: { line: O.line + 1, column: O.col + 1 }, end: { line: x.line + 1, column: x.col + 1 } });
          }
          let T = (_) => {
            let O = _.name.startsWith(":") ? _.name.slice(1).split(":")[0] : null, x = _.nameSpan.toString(), k = O !== null && x.startsWith(`${O}:`), $2 = k ? x.slice(O.length + 1) : x;
            _.name = $2, _.namespace = O, _.hasExplicitNamespace = k;
          }, w = (_) => {
            switch (_.type) {
              case "element":
                T(_);
                for (let O of _.attrs)
                  T(O), O.valueSpan ? (O.value = O.valueSpan.toString(), /["']/.test(O.value[0]) && (O.value = O.value.slice(1, -1))) : O.value = null;
                break;
              case "comment":
                _.value = _.sourceSpan.toString().slice(4, -3);
                break;
              case "text":
                _.value = _.sourceSpan.toString();
                break;
            }
          }, g = (_, O) => {
            let x = _.toLowerCase();
            return O(x) ? x : _;
          }, N = (_) => {
            if (_.type === "element" && (D && (!_.namespace || _.namespace === _.tagDefinition.implicitNamespacePrefix || hs(_)) && (_.name = g(_.name, (O) => O in uc)), s)) {
              let O = Vr[_.name] || /* @__PURE__ */ Object.create(null);
              for (let x of _.attrs)
                x.namespace || (x.name = g(x.name, (k) => _.name in Vr && (k in Vr["*"] || k in O)));
            }
          }, R = (_) => {
            _.sourceSpan && _.endSourceSpan && (_.sourceSpan = new h(_.sourceSpan.start, _.endSourceSpan.end));
          }, j = (_) => {
            if (_.type === "element") {
              let O = C(f ? _.name : _.name.toLowerCase());
              !_.namespace || _.namespace === O.implicitNamespacePrefix || hs(_) ? _.tagDefinition = O : _.tagDefinition = C("");
            }
          };
          return l(new class extends a {
            visit(_) {
              w(_), j(_), N(_), R(_);
            }
          }(), d), d;
        }
        function Ns(e, r, u) {
          let n = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true, { frontMatter: D, content: s } = n ? Jl(e) : { frontMatter: null, content: e }, i = new Kl(e, r.filepath), f = new cs(i, 0, 0, 0), c = f.moveBy(e.length), F = { type: "root", sourceSpan: new Qe(f, c), children: oc(s, u, r) };
          if (D) {
            let h = new cs(i, 0, 0, 0), C = h.moveBy(D.raw.length);
            D.sourceSpan = new Qe(h, C), F.children.unshift(D);
          }
          let a = new nc(F), l = (h, C) => {
            let { offset: d } = C, m = e.slice(0, d).replace(/[^\n\r]/g, " "), w = Ns(m + h, r, u, false);
            w.sourceSpan = new Qe(C, Zl(w.children).sourceSpan.end);
            let g = w.children[0];
            return g.length === d ? w.children.shift() : (g.sourceSpan = new Qe(g.sourceSpan.start.moveBy(d), g.sourceSpan.end), g.value = g.value.slice(d)), w;
          };
          return a.walk((h) => {
            if (h.type === "comment") {
              let C = sc(h, l);
              C && h.parent.replaceChild(h, C);
            }
          }), a;
        }
        function Ke() {
          let { name: e, recognizeSelfClosing: r = false, normalizeTagName: u = false, normalizeAttributeName: n = false, allowHtmComponentClosingTags: D = false, isTagNameCaseSensitive: s = false, getTagContentType: i } = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
          return { parse: (f, c, F) => Ns(f, Object.assign({ parser: e }, F), { recognizeSelfClosing: r, normalizeTagName: u, normalizeAttributeName: n, allowHtmComponentClosingTags: D, isTagNameCaseSensitive: s, getTagContentType: i }), hasPragma: tc, astFormat: "html", locStart: ic, locEnd: ac };
        }
        Os.exports = { parsers: { html: Ke({ name: "html", recognizeSelfClosing: true, normalizeTagName: true, normalizeAttributeName: true, allowHtmComponentClosingTags: true }), angular: Ke({ name: "angular" }), vue: Ke({ name: "vue", recognizeSelfClosing: true, isTagNameCaseSensitive: true, getTagContentType: (e, r, u, n) => {
          if (e.toLowerCase() !== "html" && !u && (e !== "template" || n.some((D) => {
            let { name: s, value: i } = D;
            return s === "lang" && i !== "html" && i !== "" && i !== void 0;
          })))
            return ws().TagContentType.RAW_TEXT;
        } }), lwc: Ke({ name: "lwc" }) } };
      });
      return Dc();
    });
  }
});

// node_modules/prettier/parser-yaml.js
var require_parser_yaml = __commonJS({
  "node_modules/prettier/parser-yaml.js"(exports, module2) {
    (function(e) {
      if (typeof exports == "object" && typeof module2 == "object")
        module2.exports = e();
      else if (typeof define == "function" && define.amd)
        define(e);
      else {
        var i = typeof globalThis < "u" ? globalThis : typeof global < "u" ? global : typeof self < "u" ? self : this || {};
        i.prettierPlugins = i.prettierPlugins || {}, i.prettierPlugins.yaml = e();
      }
    })(function() {
      "use strict";
      var yt = (n, e) => () => (e || n((e = { exports: {} }).exports, e), e.exports);
      var ln = yt((un, at) => {
        var Ye = Object.defineProperty, bt = Object.getOwnPropertyDescriptor, De = Object.getOwnPropertyNames, wt = Object.prototype.hasOwnProperty, Ke = (n, e) => function() {
          return n && (e = (0, n[De(n)[0]])(n = 0)), e;
        }, D = (n, e) => function() {
          return e || (0, n[De(n)[0]])((e = { exports: {} }).exports, e), e.exports;
        }, St = (n, e) => {
          for (var r in e)
            Ye(n, r, { get: e[r], enumerable: true });
        }, Et = (n, e, r, c) => {
          if (e && typeof e == "object" || typeof e == "function")
            for (let h of De(e))
              !wt.call(n, h) && h !== r && Ye(n, h, { get: () => e[h], enumerable: !(c = bt(e, h)) || c.enumerable });
          return n;
        }, se = (n) => Et(Ye({}, "__esModule", { value: true }), n), Te, Y = Ke({ "<define:process>"() {
          Te = { env: {}, argv: [] };
        } }), Mt = D({ "src/common/parser-create-error.js"(n, e) {
          "use strict";
          Y();
          function r(c, h) {
            let d = new SyntaxError(c + " (" + h.start.line + ":" + h.start.column + ")");
            return d.loc = h, d;
          }
          e.exports = r;
        } }), Ot = D({ "src/language-yaml/pragma.js"(n, e) {
          "use strict";
          Y();
          function r(d) {
            return /^\s*@(?:prettier|format)\s*$/.test(d);
          }
          function c(d) {
            return /^\s*#[^\S\n]*@(?:prettier|format)\s*?(?:\n|$)/.test(d);
          }
          function h(d) {
            return `# @format

${d}`;
          }
          e.exports = { isPragma: r, hasPragma: c, insertPragma: h };
        } }), Lt = D({ "src/language-yaml/loc.js"(n, e) {
          "use strict";
          Y();
          function r(h) {
            return h.position.start.offset;
          }
          function c(h) {
            return h.position.end.offset;
          }
          e.exports = { locStart: r, locEnd: c };
        } }), te = {};
        St(te, { __assign: () => qe, __asyncDelegator: () => Yt, __asyncGenerator: () => jt, __asyncValues: () => Dt, __await: () => Ce, __awaiter: () => Pt, __classPrivateFieldGet: () => Qt, __classPrivateFieldSet: () => Ut, __createBinding: () => Rt, __decorate: () => Tt, __exportStar: () => qt, __extends: () => At, __generator: () => It, __importDefault: () => Vt, __importStar: () => Wt, __makeTemplateObject: () => Ft, __metadata: () => kt, __param: () => Ct, __read: () => Je, __rest: () => Nt, __spread: () => $t, __spreadArrays: () => Bt, __values: () => je });
        function At(n, e) {
          Re(n, e);
          function r() {
            this.constructor = n;
          }
          n.prototype = e === null ? Object.create(e) : (r.prototype = e.prototype, new r());
        }
        function Nt(n, e) {
          var r = {};
          for (var c in n)
            Object.prototype.hasOwnProperty.call(n, c) && e.indexOf(c) < 0 && (r[c] = n[c]);
          if (n != null && typeof Object.getOwnPropertySymbols == "function")
            for (var h = 0, c = Object.getOwnPropertySymbols(n); h < c.length; h++)
              e.indexOf(c[h]) < 0 && Object.prototype.propertyIsEnumerable.call(n, c[h]) && (r[c[h]] = n[c[h]]);
          return r;
        }
        function Tt(n, e, r, c) {
          var h = arguments.length, d = h < 3 ? e : c === null ? c = Object.getOwnPropertyDescriptor(e, r) : c, y;
          if (typeof Reflect == "object" && typeof Reflect.decorate == "function")
            d = Reflect.decorate(n, e, r, c);
          else
            for (var E = n.length - 1; E >= 0; E--)
              (y = n[E]) && (d = (h < 3 ? y(d) : h > 3 ? y(e, r, d) : y(e, r)) || d);
          return h > 3 && d && Object.defineProperty(e, r, d), d;
        }
        function Ct(n, e) {
          return function(r, c) {
            e(r, c, n);
          };
        }
        function kt(n, e) {
          if (typeof Reflect == "object" && typeof Reflect.metadata == "function")
            return Reflect.metadata(n, e);
        }
        function Pt(n, e, r, c) {
          function h(d) {
            return d instanceof r ? d : new r(function(y) {
              y(d);
            });
          }
          return new (r || (r = Promise))(function(d, y) {
            function E(M) {
              try {
                S(c.next(M));
              } catch (T) {
                y(T);
              }
            }
            function I(M) {
              try {
                S(c.throw(M));
              } catch (T) {
                y(T);
              }
            }
            function S(M) {
              M.done ? d(M.value) : h(M.value).then(E, I);
            }
            S((c = c.apply(n, e || [])).next());
          });
        }
        function It(n, e) {
          var r = { label: 0, sent: function() {
            if (d[0] & 1)
              throw d[1];
            return d[1];
          }, trys: [], ops: [] }, c, h, d, y;
          return y = { next: E(0), throw: E(1), return: E(2) }, typeof Symbol == "function" && (y[Symbol.iterator] = function() {
            return this;
          }), y;
          function E(S) {
            return function(M) {
              return I([S, M]);
            };
          }
          function I(S) {
            if (c)
              throw new TypeError("Generator is already executing.");
            for (; r; )
              try {
                if (c = 1, h && (d = S[0] & 2 ? h.return : S[0] ? h.throw || ((d = h.return) && d.call(h), 0) : h.next) && !(d = d.call(h, S[1])).done)
                  return d;
                switch (h = 0, d && (S = [S[0] & 2, d.value]), S[0]) {
                  case 0:
                  case 1:
                    d = S;
                    break;
                  case 4:
                    return r.label++, { value: S[1], done: false };
                  case 5:
                    r.label++, h = S[1], S = [0];
                    continue;
                  case 7:
                    S = r.ops.pop(), r.trys.pop();
                    continue;
                  default:
                    if (d = r.trys, !(d = d.length > 0 && d[d.length - 1]) && (S[0] === 6 || S[0] === 2)) {
                      r = 0;
                      continue;
                    }
                    if (S[0] === 3 && (!d || S[1] > d[0] && S[1] < d[3])) {
                      r.label = S[1];
                      break;
                    }
                    if (S[0] === 6 && r.label < d[1]) {
                      r.label = d[1], d = S;
                      break;
                    }
                    if (d && r.label < d[2]) {
                      r.label = d[2], r.ops.push(S);
                      break;
                    }
                    d[2] && r.ops.pop(), r.trys.pop();
                    continue;
                }
                S = e.call(n, r);
              } catch (M) {
                S = [6, M], h = 0;
              } finally {
                c = d = 0;
              }
            if (S[0] & 5)
              throw S[1];
            return { value: S[0] ? S[1] : void 0, done: true };
          }
        }
        function Rt(n, e, r, c) {
          c === void 0 && (c = r), n[c] = e[r];
        }
        function qt(n, e) {
          for (var r in n)
            r !== "default" && !e.hasOwnProperty(r) && (e[r] = n[r]);
        }
        function je(n) {
          var e = typeof Symbol == "function" && Symbol.iterator, r = e && n[e], c = 0;
          if (r)
            return r.call(n);
          if (n && typeof n.length == "number")
            return { next: function() {
              return n && c >= n.length && (n = void 0), { value: n && n[c++], done: !n };
            } };
          throw new TypeError(e ? "Object is not iterable." : "Symbol.iterator is not defined.");
        }
        function Je(n, e) {
          var r = typeof Symbol == "function" && n[Symbol.iterator];
          if (!r)
            return n;
          var c = r.call(n), h, d = [], y;
          try {
            for (; (e === void 0 || e-- > 0) && !(h = c.next()).done; )
              d.push(h.value);
          } catch (E) {
            y = { error: E };
          } finally {
            try {
              h && !h.done && (r = c.return) && r.call(c);
            } finally {
              if (y)
                throw y.error;
            }
          }
          return d;
        }
        function $t() {
          for (var n = [], e = 0; e < arguments.length; e++)
            n = n.concat(Je(arguments[e]));
          return n;
        }
        function Bt() {
          for (var n = 0, e = 0, r = arguments.length; e < r; e++)
            n += arguments[e].length;
          for (var c = Array(n), h = 0, e = 0; e < r; e++)
            for (var d = arguments[e], y = 0, E = d.length; y < E; y++, h++)
              c[h] = d[y];
          return c;
        }
        function Ce(n) {
          return this instanceof Ce ? (this.v = n, this) : new Ce(n);
        }
        function jt(n, e, r) {
          if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
          var c = r.apply(n, e || []), h, d = [];
          return h = {}, y("next"), y("throw"), y("return"), h[Symbol.asyncIterator] = function() {
            return this;
          }, h;
          function y(P) {
            c[P] && (h[P] = function(C) {
              return new Promise(function(q, R) {
                d.push([P, C, q, R]) > 1 || E(P, C);
              });
            });
          }
          function E(P, C) {
            try {
              I(c[P](C));
            } catch (q) {
              T(d[0][3], q);
            }
          }
          function I(P) {
            P.value instanceof Ce ? Promise.resolve(P.value.v).then(S, M) : T(d[0][2], P);
          }
          function S(P) {
            E("next", P);
          }
          function M(P) {
            E("throw", P);
          }
          function T(P, C) {
            P(C), d.shift(), d.length && E(d[0][0], d[0][1]);
          }
        }
        function Yt(n) {
          var e, r;
          return e = {}, c("next"), c("throw", function(h) {
            throw h;
          }), c("return"), e[Symbol.iterator] = function() {
            return this;
          }, e;
          function c(h, d) {
            e[h] = n[h] ? function(y) {
              return (r = !r) ? { value: Ce(n[h](y)), done: h === "return" } : d ? d(y) : y;
            } : d;
          }
        }
        function Dt(n) {
          if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
          var e = n[Symbol.asyncIterator], r;
          return e ? e.call(n) : (n = typeof je == "function" ? je(n) : n[Symbol.iterator](), r = {}, c("next"), c("throw"), c("return"), r[Symbol.asyncIterator] = function() {
            return this;
          }, r);
          function c(d) {
            r[d] = n[d] && function(y) {
              return new Promise(function(E, I) {
                y = n[d](y), h(E, I, y.done, y.value);
              });
            };
          }
          function h(d, y, E, I) {
            Promise.resolve(I).then(function(S) {
              d({ value: S, done: E });
            }, y);
          }
        }
        function Ft(n, e) {
          return Object.defineProperty ? Object.defineProperty(n, "raw", { value: e }) : n.raw = e, n;
        }
        function Wt(n) {
          if (n && n.__esModule)
            return n;
          var e = {};
          if (n != null)
            for (var r in n)
              Object.hasOwnProperty.call(n, r) && (e[r] = n[r]);
          return e.default = n, e;
        }
        function Vt(n) {
          return n && n.__esModule ? n : { default: n };
        }
        function Qt(n, e) {
          if (!e.has(n))
            throw new TypeError("attempted to get private field on non-instance");
          return e.get(n);
        }
        function Ut(n, e, r) {
          if (!e.has(n))
            throw new TypeError("attempted to set private field on non-instance");
          return e.set(n, r), r;
        }
        var Re, qe, ie = Ke({ "node_modules/tslib/tslib.es6.js"() {
          Y(), Re = function(n, e) {
            return Re = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(r, c) {
              r.__proto__ = c;
            } || function(r, c) {
              for (var h in c)
                c.hasOwnProperty(h) && (r[h] = c[h]);
            }, Re(n, e);
          }, qe = function() {
            return qe = Object.assign || function(e) {
              for (var r, c = 1, h = arguments.length; c < h; c++) {
                r = arguments[c];
                for (var d in r)
                  Object.prototype.hasOwnProperty.call(r, d) && (e[d] = r[d]);
              }
              return e;
            }, qe.apply(this, arguments);
          };
        } }), Kt = D({ "node_modules/yaml-unist-parser/node_modules/lines-and-columns/build/index.js"(n) {
          "use strict";
          Y(), n.__esModule = true, n.LinesAndColumns = void 0;
          var e = `
`, r = "\r", c = function() {
            function h(d) {
              this.string = d;
              for (var y = [0], E = 0; E < d.length; )
                switch (d[E]) {
                  case e:
                    E += e.length, y.push(E);
                    break;
                  case r:
                    E += r.length, d[E] === e && (E += e.length), y.push(E);
                    break;
                  default:
                    E++;
                    break;
                }
              this.offsets = y;
            }
            return h.prototype.locationForIndex = function(d) {
              if (d < 0 || d > this.string.length)
                return null;
              for (var y = 0, E = this.offsets; E[y + 1] <= d; )
                y++;
              var I = d - E[y];
              return { line: y, column: I };
            }, h.prototype.indexForLocation = function(d) {
              var y = d.line, E = d.column;
              return y < 0 || y >= this.offsets.length || E < 0 || E > this.lengthOfLine(y) ? null : this.offsets[y] + E;
            }, h.prototype.lengthOfLine = function(d) {
              var y = this.offsets[d], E = d === this.offsets.length - 1 ? this.string.length : this.offsets[d + 1];
              return E - y;
            }, h;
          }();
          n.LinesAndColumns = c, n.default = c;
        } }), Jt = D({ "node_modules/yaml-unist-parser/lib/utils/define-parents.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c) {
            c === void 0 && (c = null), "children" in r && r.children.forEach(function(h) {
              return e(h, r);
            }), "anchor" in r && r.anchor && e(r.anchor, r), "tag" in r && r.tag && e(r.tag, r), "leadingComments" in r && r.leadingComments.forEach(function(h) {
              return e(h, r);
            }), "middleComments" in r && r.middleComments.forEach(function(h) {
              return e(h, r);
            }), "indicatorComment" in r && r.indicatorComment && e(r.indicatorComment, r), "trailingComment" in r && r.trailingComment && e(r.trailingComment, r), "endComments" in r && r.endComments.forEach(function(h) {
              return e(h, r);
            }), Object.defineProperty(r, "_parent", { value: c, enumerable: false });
          }
          n.defineParents = e;
        } }), Fe = D({ "node_modules/yaml-unist-parser/lib/utils/get-point-text.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            return r.line + ":" + r.column;
          }
          n.getPointText = e;
        } }), xt = D({ "node_modules/yaml-unist-parser/lib/attach.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Jt(), r = Fe();
          function c(S) {
            e.defineParents(S);
            var M = h(S), T = S.children.slice();
            S.comments.sort(function(P, C) {
              return P.position.start.offset - C.position.end.offset;
            }).filter(function(P) {
              return !P._parent;
            }).forEach(function(P) {
              for (; T.length > 1 && P.position.start.line > T[0].position.end.line; )
                T.shift();
              y(P, M, T[0]);
            });
          }
          n.attachComments = c;
          function h(S) {
            for (var M = Array.from(new Array(S.position.end.line), function() {
              return {};
            }), T = 0, P = S.comments; T < P.length; T++) {
              var C = P[T];
              M[C.position.start.line - 1].comment = C;
            }
            return d(M, S), M;
          }
          function d(S, M) {
            if (M.position.start.offset !== M.position.end.offset) {
              if ("leadingComments" in M) {
                var T = M.position.start, P = S[T.line - 1].leadingAttachableNode;
                (!P || T.column < P.position.start.column) && (S[T.line - 1].leadingAttachableNode = M);
              }
              if ("trailingComment" in M && M.position.end.column > 1 && M.type !== "document" && M.type !== "documentHead") {
                var C = M.position.end, q = S[C.line - 1].trailingAttachableNode;
                (!q || C.column >= q.position.end.column) && (S[C.line - 1].trailingAttachableNode = M);
              }
              if (M.type !== "root" && M.type !== "document" && M.type !== "documentHead" && M.type !== "documentBody")
                for (var R = M.position, T = R.start, C = R.end, B = [C.line].concat(T.line === C.line ? [] : T.line), U = 0, f = B; U < f.length; U++) {
                  var i = f[U], t3 = S[i - 1].trailingNode;
                  (!t3 || C.column >= t3.position.end.column) && (S[i - 1].trailingNode = M);
                }
              "children" in M && M.children.forEach(function(s) {
                d(S, s);
              });
            }
          }
          function y(S, M, T) {
            var P = S.position.start.line, C = M[P - 1].trailingAttachableNode;
            if (C) {
              if (C.trailingComment)
                throw new Error("Unexpected multiple trailing comment at " + r.getPointText(S.position.start));
              e.defineParents(S, C), C.trailingComment = S;
              return;
            }
            for (var q = P; q >= T.position.start.line; q--) {
              var R = M[q - 1].trailingNode, B = void 0;
              if (R)
                B = R;
              else if (q !== P && M[q - 1].comment)
                B = M[q - 1].comment._parent;
              else
                continue;
              if ((B.type === "sequence" || B.type === "mapping") && (B = B.children[0]), B.type === "mappingItem") {
                var U = B.children, f = U[0], i = U[1];
                B = I(f) ? f : i;
              }
              for (; ; ) {
                if (E(B, S)) {
                  e.defineParents(S, B), B.endComments.push(S);
                  return;
                }
                if (!B._parent)
                  break;
                B = B._parent;
              }
              break;
            }
            for (var q = P + 1; q <= T.position.end.line; q++) {
              var t3 = M[q - 1].leadingAttachableNode;
              if (t3) {
                e.defineParents(S, t3), t3.leadingComments.push(S);
                return;
              }
            }
            var s = T.children[1];
            e.defineParents(S, s), s.endComments.push(S);
          }
          function E(S, M) {
            if (S.position.start.offset < M.position.start.offset && S.position.end.offset > M.position.end.offset)
              switch (S.type) {
                case "flowMapping":
                case "flowSequence":
                  return S.children.length === 0 || M.position.start.line > S.children[S.children.length - 1].position.end.line;
              }
            if (M.position.end.offset < S.position.end.offset)
              return false;
            switch (S.type) {
              case "sequenceItem":
                return M.position.start.column > S.position.start.column;
              case "mappingKey":
              case "mappingValue":
                return M.position.start.column > S._parent.position.start.column && (S.children.length === 0 || S.children.length === 1 && S.children[0].type !== "blockFolded" && S.children[0].type !== "blockLiteral") && (S.type === "mappingValue" || I(S));
              default:
                return false;
            }
          }
          function I(S) {
            return S.position.start !== S.position.end && (S.children.length === 0 || S.position.start.offset !== S.children[0].position.start.offset);
          }
        } }), me = D({ "node_modules/yaml-unist-parser/lib/factories/node.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c) {
            return { type: r, position: c };
          }
          n.createNode = e;
        } }), Ht = D({ "node_modules/yaml-unist-parser/lib/factories/root.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me();
          function c(h, d, y) {
            return e.__assign(e.__assign({}, r.createNode("root", h)), { children: d, comments: y });
          }
          n.createRoot = c;
        } }), Gt = D({ "node_modules/yaml-unist-parser/lib/preprocess.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            switch (r.type) {
              case "DOCUMENT":
                for (var c = r.contents.length - 1; c >= 0; c--)
                  r.contents[c].type === "BLANK_LINE" ? r.contents.splice(c, 1) : e(r.contents[c]);
                for (var c = r.directives.length - 1; c >= 0; c--)
                  r.directives[c].type === "BLANK_LINE" && r.directives.splice(c, 1);
                break;
              case "FLOW_MAP":
              case "FLOW_SEQ":
              case "MAP":
              case "SEQ":
                for (var c = r.items.length - 1; c >= 0; c--) {
                  var h = r.items[c];
                  "char" in h || (h.type === "BLANK_LINE" ? r.items.splice(c, 1) : e(h));
                }
                break;
              case "MAP_KEY":
              case "MAP_VALUE":
              case "SEQ_ITEM":
                r.node && e(r.node);
                break;
              case "ALIAS":
              case "BLANK_LINE":
              case "BLOCK_FOLDED":
              case "BLOCK_LITERAL":
              case "COMMENT":
              case "DIRECTIVE":
              case "PLAIN":
              case "QUOTE_DOUBLE":
              case "QUOTE_SINGLE":
                break;
              default:
                throw new Error("Unexpected node type " + JSON.stringify(r.type));
            }
          }
          n.removeCstBlankLine = e;
        } }), Oe = D({ "node_modules/yaml-unist-parser/lib/factories/leading-comment-attachable.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e() {
            return { leadingComments: [] };
          }
          n.createLeadingCommentAttachable = e;
        } }), $e = D({ "node_modules/yaml-unist-parser/lib/factories/trailing-comment-attachable.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            return r === void 0 && (r = null), { trailingComment: r };
          }
          n.createTrailingCommentAttachable = e;
        } }), Se = D({ "node_modules/yaml-unist-parser/lib/factories/comment-attachable.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Oe(), c = $e();
          function h() {
            return e.__assign(e.__assign({}, r.createLeadingCommentAttachable()), c.createTrailingCommentAttachable());
          }
          n.createCommentAttachable = h;
        } }), zt = D({ "node_modules/yaml-unist-parser/lib/factories/alias.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("alias", d)), r.createCommentAttachable()), y), { value: E });
          }
          n.createAlias = h;
        } }), Zt = D({ "node_modules/yaml-unist-parser/lib/transforms/alias.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = zt();
          function r(c, h) {
            var d = c.cstNode;
            return e.createAlias(h.transformRange({ origStart: d.valueRange.origStart - 1, origEnd: d.valueRange.origEnd }), h.transformContent(c), d.rawValue);
          }
          n.transformAlias = r;
        } }), Xt = D({ "node_modules/yaml-unist-parser/lib/factories/block-folded.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te));
          function r(c) {
            return e.__assign(e.__assign({}, c), { type: "blockFolded" });
          }
          n.createBlockFolded = r;
        } }), er = D({ "node_modules/yaml-unist-parser/lib/factories/block-value.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Oe(), c = me();
          function h(d, y, E, I, S, M) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("blockValue", d)), r.createLeadingCommentAttachable()), y), { chomping: E, indent: I, value: S, indicatorComment: M });
          }
          n.createBlockValue = h;
        } }), xe = D({ "node_modules/yaml-unist-parser/lib/constants.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e;
          (function(r) {
            r.Tag = "!", r.Anchor = "&", r.Comment = "#";
          })(e = n.PropLeadingCharacter || (n.PropLeadingCharacter = {}));
        } }), tr = D({ "node_modules/yaml-unist-parser/lib/factories/anchor.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me();
          function c(h, d) {
            return e.__assign(e.__assign({}, r.createNode("anchor", h)), { value: d });
          }
          n.createAnchor = c;
        } }), We = D({ "node_modules/yaml-unist-parser/lib/factories/comment.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me();
          function c(h, d) {
            return e.__assign(e.__assign({}, r.createNode("comment", h)), { value: d });
          }
          n.createComment = c;
        } }), rr = D({ "node_modules/yaml-unist-parser/lib/factories/content.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c, h) {
            return { anchor: c, tag: r, middleComments: h };
          }
          n.createContent = e;
        } }), nr = D({ "node_modules/yaml-unist-parser/lib/factories/tag.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me();
          function c(h, d) {
            return e.__assign(e.__assign({}, r.createNode("tag", h)), { value: d });
          }
          n.createTag = c;
        } }), He = D({ "node_modules/yaml-unist-parser/lib/transforms/content.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = xe(), r = tr(), c = We(), h = rr(), d = nr();
          function y(E, I, S) {
            S === void 0 && (S = function() {
              return false;
            });
            for (var M = E.cstNode, T = [], P = null, C = null, q = null, R = 0, B = M.props; R < B.length; R++) {
              var U = B[R], f = I.text[U.origStart];
              switch (f) {
                case e.PropLeadingCharacter.Tag:
                  P = P || U, C = d.createTag(I.transformRange(U), E.tag);
                  break;
                case e.PropLeadingCharacter.Anchor:
                  P = P || U, q = r.createAnchor(I.transformRange(U), M.anchor);
                  break;
                case e.PropLeadingCharacter.Comment: {
                  var i = c.createComment(I.transformRange(U), I.text.slice(U.origStart + 1, U.origEnd));
                  I.comments.push(i), !S(i) && P && P.origEnd <= U.origStart && U.origEnd <= M.valueRange.origStart && T.push(i);
                  break;
                }
                default:
                  throw new Error("Unexpected leading character " + JSON.stringify(f));
              }
            }
            return h.createContent(C, q, T);
          }
          n.transformContent = y;
        } }), Ge = D({ "node_modules/yaml-unist-parser/lib/transforms/block-value.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = er(), r = Fe(), c = He(), h;
          (function(y) {
            y.CLIP = "clip", y.STRIP = "strip", y.KEEP = "keep";
          })(h || (h = {}));
          function d(y, E) {
            var I = y.cstNode, S = 1, M = I.chomping === "CLIP" ? 0 : 1, T = I.header.origEnd - I.header.origStart, P = T - S - M !== 0, C = E.transformRange({ origStart: I.header.origStart, origEnd: I.valueRange.origEnd }), q = null, R = c.transformContent(y, E, function(B) {
              var U = C.start.offset < B.position.start.offset && B.position.end.offset < C.end.offset;
              if (!U)
                return false;
              if (q)
                throw new Error("Unexpected multiple indicator comments at " + r.getPointText(B.position.start));
              return q = B, true;
            });
            return e.createBlockValue(C, R, h[I.chomping], P ? I.blockIndent : null, I.strValue, q);
          }
          n.transformAstBlockValue = d;
        } }), sr = D({ "node_modules/yaml-unist-parser/lib/transforms/block-folded.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Xt(), r = Ge();
          function c(h, d) {
            return e.createBlockFolded(r.transformAstBlockValue(h, d));
          }
          n.transformBlockFolded = c;
        } }), ir = D({ "node_modules/yaml-unist-parser/lib/factories/block-literal.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te));
          function r(c) {
            return e.__assign(e.__assign({}, c), { type: "blockLiteral" });
          }
          n.createBlockLiteral = r;
        } }), ar = D({ "node_modules/yaml-unist-parser/lib/transforms/block-literal.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = ir(), r = Ge();
          function c(h, d) {
            return e.createBlockLiteral(r.transformAstBlockValue(h, d));
          }
          n.transformBlockLiteral = c;
        } }), or = D({ "node_modules/yaml-unist-parser/lib/transforms/comment.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = We();
          function r(c, h) {
            return e.createComment(h.transformRange(c.range), c.comment);
          }
          n.transformComment = r;
        } }), lr = D({ "node_modules/yaml-unist-parser/lib/factories/directive.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign({}, c.createNode("directive", d)), r.createCommentAttachable()), { name: y, parameters: E });
          }
          n.createDirective = h;
        } }), Ve = D({ "node_modules/yaml-unist-parser/lib/utils/extract-prop-comments.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = xe(), r = We();
          function c(h, d) {
            for (var y = 0, E = h.props; y < E.length; y++) {
              var I = E[y], S = d.text[I.origStart];
              switch (S) {
                case e.PropLeadingCharacter.Comment:
                  d.comments.push(r.createComment(d.transformRange(I), d.text.slice(I.origStart + 1, I.origEnd)));
                  break;
                default:
                  throw new Error("Unexpected leading character " + JSON.stringify(S));
              }
            }
          }
          n.extractPropComments = c;
        } }), cr = D({ "node_modules/yaml-unist-parser/lib/transforms/directive.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = lr(), r = Ve();
          function c(h, d) {
            return r.extractPropComments(h, d), e.createDirective(d.transformRange(h.range), h.name, h.parameters);
          }
          n.transformDirective = c;
        } }), ur = D({ "node_modules/yaml-unist-parser/lib/factories/document.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me(), c = $e();
          function h(d, y, E, I) {
            return e.__assign(e.__assign(e.__assign({}, r.createNode("document", d)), c.createTrailingCommentAttachable(I)), { children: [y, E] });
          }
          n.createDocument = h;
        } }), Le = D({ "node_modules/yaml-unist-parser/lib/factories/position.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(c, h) {
            return { start: c, end: h };
          }
          n.createPosition = e;
          function r(c) {
            return { start: c, end: c };
          }
          n.createEmptyPosition = r;
        } }), Ee = D({ "node_modules/yaml-unist-parser/lib/factories/end-comment-attachable.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            return r === void 0 && (r = []), { endComments: r };
          }
          n.createEndCommentAttachable = e;
        } }), fr = D({ "node_modules/yaml-unist-parser/lib/factories/document-body.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ee(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign({}, c.createNode("documentBody", d)), r.createEndCommentAttachable(E)), { children: y ? [y] : [] });
          }
          n.createDocumentBody = h;
        } }), Ae = D({ "node_modules/yaml-unist-parser/lib/utils/get-last.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            return r[r.length - 1];
          }
          n.getLast = e;
        } }), ze = D({ "node_modules/yaml-unist-parser/lib/utils/get-match-index.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c) {
            var h = r.match(c);
            return h ? h.index : -1;
          }
          n.getMatchIndex = e;
        } }), mr = D({ "node_modules/yaml-unist-parser/lib/transforms/document-body.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = fr(), c = Ae(), h = ze(), d = Fe();
          function y(S, M, T) {
            var P, C = S.cstNode, q = E(C, M, T), R = q.comments, B = q.endComments, U = q.documentTrailingComment, f = q.documentHeadTrailingComment, i = M.transformNode(S.contents), t3 = I(C, i, M), s = t3.position, a = t3.documentEndPoint;
            return (P = M.comments).push.apply(P, e.__spreadArrays(R, B)), { documentBody: r.createDocumentBody(s, i, B), documentEndPoint: a, documentTrailingComment: U, documentHeadTrailingComment: f };
          }
          n.transformDocumentBody = y;
          function E(S, M, T) {
            for (var P = [], C = [], q = [], R = [], B = false, U = S.contents.length - 1; U >= 0; U--) {
              var f = S.contents[U];
              if (f.type === "COMMENT") {
                var i = M.transformNode(f);
                T && T.line === i.position.start.line ? R.unshift(i) : B ? P.unshift(i) : i.position.start.offset >= S.valueRange.origEnd ? q.unshift(i) : P.unshift(i);
              } else
                B = true;
            }
            if (q.length > 1)
              throw new Error("Unexpected multiple document trailing comments at " + d.getPointText(q[1].position.start));
            if (R.length > 1)
              throw new Error("Unexpected multiple documentHead trailing comments at " + d.getPointText(R[1].position.start));
            return { comments: P, endComments: C, documentTrailingComment: c.getLast(q) || null, documentHeadTrailingComment: c.getLast(R) || null };
          }
          function I(S, M, T) {
            var P = h.getMatchIndex(T.text.slice(S.valueRange.origEnd), /^\.\.\./), C = P === -1 ? S.valueRange.origEnd : Math.max(0, S.valueRange.origEnd - 1);
            T.text[C - 1] === "\r" && C--;
            var q = T.transformRange({ origStart: M !== null ? M.position.start.offset : C, origEnd: C }), R = P === -1 ? q.end : T.transformOffset(S.valueRange.origEnd + 3);
            return { position: q, documentEndPoint: R };
          }
        } }), dr = D({ "node_modules/yaml-unist-parser/lib/factories/document-head.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ee(), c = me(), h = $e();
          function d(y, E, I, S) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("documentHead", y)), r.createEndCommentAttachable(I)), h.createTrailingCommentAttachable(S)), { children: E });
          }
          n.createDocumentHead = d;
        } }), hr = D({ "node_modules/yaml-unist-parser/lib/transforms/document-head.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = dr(), c = ze();
          function h(E, I) {
            var S, M = E.cstNode, T = d(M, I), P = T.directives, C = T.comments, q = T.endComments, R = y(M, P, I), B = R.position, U = R.endMarkerPoint;
            (S = I.comments).push.apply(S, e.__spreadArrays(C, q));
            var f = function(i) {
              return i && I.comments.push(i), r.createDocumentHead(B, P, q, i);
            };
            return { createDocumentHeadWithTrailingComment: f, documentHeadEndMarkerPoint: U };
          }
          n.transformDocumentHead = h;
          function d(E, I) {
            for (var S = [], M = [], T = [], P = false, C = E.directives.length - 1; C >= 0; C--) {
              var q = I.transformNode(E.directives[C]);
              q.type === "comment" ? P ? M.unshift(q) : T.unshift(q) : (P = true, S.unshift(q));
            }
            return { directives: S, comments: M, endComments: T };
          }
          function y(E, I, S) {
            var M = c.getMatchIndex(S.text.slice(0, E.valueRange.origStart), /---\s*$/);
            M > 0 && !/[\r\n]/.test(S.text[M - 1]) && (M = -1);
            var T = M === -1 ? { origStart: E.valueRange.origStart, origEnd: E.valueRange.origStart } : { origStart: M, origEnd: M + 3 };
            return I.length !== 0 && (T.origStart = I[0].position.start.offset), { position: S.transformRange(T), endMarkerPoint: M === -1 ? null : S.transformOffset(M) };
          }
        } }), gr = D({ "node_modules/yaml-unist-parser/lib/transforms/document.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = ur(), r = Le(), c = mr(), h = hr();
          function d(y, E) {
            var I = h.transformDocumentHead(y, E), S = I.createDocumentHeadWithTrailingComment, M = I.documentHeadEndMarkerPoint, T = c.transformDocumentBody(y, E, M), P = T.documentBody, C = T.documentEndPoint, q = T.documentTrailingComment, R = T.documentHeadTrailingComment, B = S(R);
            return q && E.comments.push(q), e.createDocument(r.createPosition(B.position.start, C), B, P, q);
          }
          n.transformDocument = d;
        } }), Ze = D({ "node_modules/yaml-unist-parser/lib/factories/flow-collection.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = Ee(), h = me();
          function d(y, E, I) {
            return e.__assign(e.__assign(e.__assign(e.__assign(e.__assign({}, h.createNode("flowCollection", y)), r.createCommentAttachable()), c.createEndCommentAttachable()), E), { children: I });
          }
          n.createFlowCollection = d;
        } }), pr = D({ "node_modules/yaml-unist-parser/lib/factories/flow-mapping.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ze();
          function c(h, d, y) {
            return e.__assign(e.__assign({}, r.createFlowCollection(h, d, y)), { type: "flowMapping" });
          }
          n.createFlowMapping = c;
        } }), Xe = D({ "node_modules/yaml-unist-parser/lib/factories/flow-mapping-item.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Oe(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign({}, c.createNode("flowMappingItem", d)), r.createLeadingCommentAttachable()), { children: [y, E] });
          }
          n.createFlowMappingItem = h;
        } }), Be = D({ "node_modules/yaml-unist-parser/lib/utils/extract-comments.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c) {
            for (var h = [], d = 0, y = r; d < y.length; d++) {
              var E = y[d];
              E && "type" in E && E.type === "COMMENT" ? c.comments.push(c.transformNode(E)) : h.push(E);
            }
            return h;
          }
          n.extractComments = e;
        } }), et = D({ "node_modules/yaml-unist-parser/lib/utils/get-flow-map-item-additional-ranges.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            var c = ["?", ":"].map(function(y) {
              var E = r.find(function(I) {
                return "char" in I && I.char === y;
              });
              return E ? { origStart: E.origOffset, origEnd: E.origOffset + 1 } : null;
            }), h = c[0], d = c[1];
            return { additionalKeyRange: h, additionalValueRange: d };
          }
          n.getFlowMapItemAdditionalRanges = e;
        } }), tt = D({ "node_modules/yaml-unist-parser/lib/utils/create-slicer.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c) {
            var h = c;
            return function(d) {
              return r.slice(h, h = d);
            };
          }
          n.createSlicer = e;
        } }), rt = D({ "node_modules/yaml-unist-parser/lib/utils/group-cst-flow-collection-items.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = tt();
          function r(c) {
            for (var h = [], d = e.createSlicer(c, 1), y = false, E = 1; E < c.length - 1; E++) {
              var I = c[E];
              if ("char" in I && I.char === ",") {
                h.push(d(E)), d(E + 1), y = false;
                continue;
              }
              y = true;
            }
            return y && h.push(d(c.length - 1)), h;
          }
          n.groupCstFlowCollectionItems = r;
        } }), _r = D({ "node_modules/yaml-unist-parser/lib/factories/mapping-key.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ee(), c = me(), h = $e();
          function d(y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("mappingKey", y)), h.createTrailingCommentAttachable()), r.createEndCommentAttachable()), { children: E ? [E] : [] });
          }
          n.createMappingKey = d;
        } }), vr = D({ "node_modules/yaml-unist-parser/lib/factories/mapping-value.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = Ee(), h = me();
          function d(y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, h.createNode("mappingValue", y)), r.createCommentAttachable()), c.createEndCommentAttachable()), { children: E ? [E] : [] });
          }
          n.createMappingValue = d;
        } }), Qe = D({ "node_modules/yaml-unist-parser/lib/transforms/pair.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = _r(), r = vr(), c = Le();
          function h(d, y, E, I, S) {
            var M = y.transformNode(d.key), T = y.transformNode(d.value), P = M || I ? e.createMappingKey(y.transformRange({ origStart: I ? I.origStart : M.position.start.offset, origEnd: M ? M.position.end.offset : I.origStart + 1 }), M) : null, C = T || S ? r.createMappingValue(y.transformRange({ origStart: S ? S.origStart : T.position.start.offset, origEnd: T ? T.position.end.offset : S.origStart + 1 }), T) : null;
            return E(c.createPosition(P ? P.position.start : C.position.start, C ? C.position.end : P.position.end), P || e.createMappingKey(c.createEmptyPosition(C.position.start), null), C || r.createMappingValue(c.createEmptyPosition(P.position.end), null));
          }
          n.transformAstPair = h;
        } }), yr = D({ "node_modules/yaml-unist-parser/lib/transforms/flow-map.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = pr(), r = Xe(), c = Be(), h = et(), d = Ae(), y = rt(), E = Qe();
          function I(S, M) {
            var T = c.extractComments(S.cstNode.items, M), P = y.groupCstFlowCollectionItems(T), C = S.items.map(function(B, U) {
              var f = P[U], i = h.getFlowMapItemAdditionalRanges(f), t3 = i.additionalKeyRange, s = i.additionalValueRange;
              return E.transformAstPair(B, M, r.createFlowMappingItem, t3, s);
            }), q = T[0], R = d.getLast(T);
            return e.createFlowMapping(M.transformRange({ origStart: q.origOffset, origEnd: R.origOffset + 1 }), M.transformContent(S), C);
          }
          n.transformFlowMap = I;
        } }), br = D({ "node_modules/yaml-unist-parser/lib/factories/flow-sequence.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ze();
          function c(h, d, y) {
            return e.__assign(e.__assign({}, r.createFlowCollection(h, d, y)), { type: "flowSequence" });
          }
          n.createFlowSequence = c;
        } }), wr = D({ "node_modules/yaml-unist-parser/lib/factories/flow-sequence-item.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = me();
          function c(h, d) {
            return e.__assign(e.__assign({}, r.createNode("flowSequenceItem", h)), { children: [d] });
          }
          n.createFlowSequenceItem = c;
        } }), Sr = D({ "node_modules/yaml-unist-parser/lib/transforms/flow-seq.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Xe(), r = br(), c = wr(), h = Le(), d = Be(), y = et(), E = Ae(), I = rt(), S = Qe();
          function M(T, P) {
            var C = d.extractComments(T.cstNode.items, P), q = I.groupCstFlowCollectionItems(C), R = T.items.map(function(f, i) {
              if (f.type !== "PAIR") {
                var t3 = P.transformNode(f);
                return c.createFlowSequenceItem(h.createPosition(t3.position.start, t3.position.end), t3);
              } else {
                var s = q[i], a = y.getFlowMapItemAdditionalRanges(s), m = a.additionalKeyRange, g = a.additionalValueRange;
                return S.transformAstPair(f, P, e.createFlowMappingItem, m, g);
              }
            }), B = C[0], U = E.getLast(C);
            return r.createFlowSequence(P.transformRange({ origStart: B.origOffset, origEnd: U.origOffset + 1 }), P.transformContent(T), R);
          }
          n.transformFlowSeq = M;
        } }), Er = D({ "node_modules/yaml-unist-parser/lib/factories/mapping.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Oe(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("mapping", d)), r.createLeadingCommentAttachable()), y), { children: E });
          }
          n.createMapping = h;
        } }), Mr = D({ "node_modules/yaml-unist-parser/lib/factories/mapping-item.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Oe(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign({}, c.createNode("mappingItem", d)), r.createLeadingCommentAttachable()), { children: [y, E] });
          }
          n.createMappingItem = h;
        } }), Or = D({ "node_modules/yaml-unist-parser/lib/transforms/map.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Er(), r = Mr(), c = Le(), h = tt(), d = Be(), y = Ve(), E = Ae(), I = Qe();
          function S(T, P) {
            var C = T.cstNode;
            C.items.filter(function(U) {
              return U.type === "MAP_KEY" || U.type === "MAP_VALUE";
            }).forEach(function(U) {
              return y.extractPropComments(U, P);
            });
            var q = d.extractComments(C.items, P), R = M(q), B = T.items.map(function(U, f) {
              var i = R[f], t3 = i[0].type === "MAP_VALUE" ? [null, i[0].range] : [i[0].range, i.length === 1 ? null : i[1].range], s = t3[0], a = t3[1];
              return I.transformAstPair(U, P, r.createMappingItem, s, a);
            });
            return e.createMapping(c.createPosition(B[0].position.start, E.getLast(B).position.end), P.transformContent(T), B);
          }
          n.transformMap = S;
          function M(T) {
            for (var P = [], C = h.createSlicer(T, 0), q = false, R = 0; R < T.length; R++) {
              var B = T[R];
              if (B.type === "MAP_VALUE") {
                P.push(C(R + 1)), q = false;
                continue;
              }
              q && P.push(C(R)), q = true;
            }
            return q && P.push(C(1 / 0)), P;
          }
        } }), Lr = D({ "node_modules/yaml-unist-parser/lib/factories/plain.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("plain", d)), r.createCommentAttachable()), y), { value: E });
          }
          n.createPlain = h;
        } }), Ar = D({ "node_modules/yaml-unist-parser/lib/utils/find-last-char-index.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c, h) {
            for (var d = c; d >= 0; d--)
              if (h.test(r[d]))
                return d;
            return -1;
          }
          n.findLastCharIndex = e;
        } }), Nr = D({ "node_modules/yaml-unist-parser/lib/transforms/plain.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Lr(), r = Ar();
          function c(h, d) {
            var y = h.cstNode;
            return e.createPlain(d.transformRange({ origStart: y.valueRange.origStart, origEnd: r.findLastCharIndex(d.text, y.valueRange.origEnd - 1, /\S/) + 1 }), d.transformContent(h), y.strValue);
          }
          n.transformPlain = c;
        } }), Tr = D({ "node_modules/yaml-unist-parser/lib/factories/quote-double.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te));
          function r(c) {
            return e.__assign(e.__assign({}, c), { type: "quoteDouble" });
          }
          n.createQuoteDouble = r;
        } }), Cr = D({ "node_modules/yaml-unist-parser/lib/factories/quote-value.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = me();
          function h(d, y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, c.createNode("quoteValue", d)), y), r.createCommentAttachable()), { value: E });
          }
          n.createQuoteValue = h;
        } }), nt = D({ "node_modules/yaml-unist-parser/lib/transforms/quote-value.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Cr();
          function r(c, h) {
            var d = c.cstNode;
            return e.createQuoteValue(h.transformRange(d.valueRange), h.transformContent(c), d.strValue);
          }
          n.transformAstQuoteValue = r;
        } }), kr = D({ "node_modules/yaml-unist-parser/lib/transforms/quote-double.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Tr(), r = nt();
          function c(h, d) {
            return e.createQuoteDouble(r.transformAstQuoteValue(h, d));
          }
          n.transformQuoteDouble = c;
        } }), Pr = D({ "node_modules/yaml-unist-parser/lib/factories/quote-single.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te));
          function r(c) {
            return e.__assign(e.__assign({}, c), { type: "quoteSingle" });
          }
          n.createQuoteSingle = r;
        } }), Ir = D({ "node_modules/yaml-unist-parser/lib/transforms/quote-single.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Pr(), r = nt();
          function c(h, d) {
            return e.createQuoteSingle(r.transformAstQuoteValue(h, d));
          }
          n.transformQuoteSingle = c;
        } }), Rr = D({ "node_modules/yaml-unist-parser/lib/factories/sequence.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Ee(), c = Oe(), h = me();
          function d(y, E, I) {
            return e.__assign(e.__assign(e.__assign(e.__assign(e.__assign({}, h.createNode("sequence", y)), c.createLeadingCommentAttachable()), r.createEndCommentAttachable()), E), { children: I });
          }
          n.createSequence = d;
        } }), qr = D({ "node_modules/yaml-unist-parser/lib/factories/sequence-item.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te)), r = Se(), c = Ee(), h = me();
          function d(y, E) {
            return e.__assign(e.__assign(e.__assign(e.__assign({}, h.createNode("sequenceItem", y)), r.createCommentAttachable()), c.createEndCommentAttachable()), { children: E ? [E] : [] });
          }
          n.createSequenceItem = d;
        } }), $r = D({ "node_modules/yaml-unist-parser/lib/transforms/seq.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Le(), r = Rr(), c = qr(), h = Be(), d = Ve(), y = Ae();
          function E(I, S) {
            var M = h.extractComments(I.cstNode.items, S), T = M.map(function(P, C) {
              d.extractPropComments(P, S);
              var q = S.transformNode(I.items[C]);
              return c.createSequenceItem(e.createPosition(S.transformOffset(P.valueRange.origStart), q === null ? S.transformOffset(P.valueRange.origStart + 1) : q.position.end), q);
            });
            return r.createSequence(e.createPosition(T[0].position.start, y.getLast(T).position.end), S.transformContent(I), T);
          }
          n.transformSeq = E;
        } }), Br = D({ "node_modules/yaml-unist-parser/lib/transform.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Zt(), r = sr(), c = ar(), h = or(), d = cr(), y = gr(), E = yr(), I = Sr(), S = Or(), M = Nr(), T = kr(), P = Ir(), C = $r();
          function q(R, B) {
            if (R === null || R.type === void 0 && R.value === null)
              return null;
            switch (R.type) {
              case "ALIAS":
                return e.transformAlias(R, B);
              case "BLOCK_FOLDED":
                return r.transformBlockFolded(R, B);
              case "BLOCK_LITERAL":
                return c.transformBlockLiteral(R, B);
              case "COMMENT":
                return h.transformComment(R, B);
              case "DIRECTIVE":
                return d.transformDirective(R, B);
              case "DOCUMENT":
                return y.transformDocument(R, B);
              case "FLOW_MAP":
                return E.transformFlowMap(R, B);
              case "FLOW_SEQ":
                return I.transformFlowSeq(R, B);
              case "MAP":
                return S.transformMap(R, B);
              case "PLAIN":
                return M.transformPlain(R, B);
              case "QUOTE_DOUBLE":
                return T.transformQuoteDouble(R, B);
              case "QUOTE_SINGLE":
                return P.transformQuoteSingle(R, B);
              case "SEQ":
                return C.transformSeq(R, B);
              default:
                throw new Error("Unexpected node type " + R.type);
            }
          }
          n.transformNode = q;
        } }), jr = D({ "node_modules/yaml-unist-parser/lib/factories/error.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c, h) {
            var d = new SyntaxError(r);
            return d.name = "YAMLSyntaxError", d.source = c, d.position = h, d;
          }
          n.createError = e;
        } }), Yr = D({ "node_modules/yaml-unist-parser/lib/transforms/error.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = jr();
          function r(c, h) {
            var d = c.source.range || c.source.valueRange;
            return e.createError(c.message, h.text, h.transformRange(d));
          }
          n.transformError = r;
        } }), Dr = D({ "node_modules/yaml-unist-parser/lib/factories/point.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c, h) {
            return { offset: r, line: c, column: h };
          }
          n.createPoint = e;
        } }), Fr = D({ "node_modules/yaml-unist-parser/lib/transforms/offset.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Dr();
          function r(c, h) {
            c < 0 ? c = 0 : c > h.text.length && (c = h.text.length);
            var d = h.locator.locationForIndex(c);
            return e.createPoint(c, d.line + 1, d.column + 1);
          }
          n.transformOffset = r;
        } }), Wr = D({ "node_modules/yaml-unist-parser/lib/transforms/range.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Le();
          function r(c, h) {
            return e.createPosition(h.transformOffset(c.origStart), h.transformOffset(c.origEnd));
          }
          n.transformRange = r;
        } }), Vr = D({ "node_modules/yaml-unist-parser/lib/utils/add-orig-range.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = true;
          function r(y) {
            if (!y.setOrigRanges()) {
              var E = function(I) {
                if (h(I))
                  return I.origStart = I.start, I.origEnd = I.end, e;
                if (d(I))
                  return I.origOffset = I.offset, e;
              };
              y.forEach(function(I) {
                return c(I, E);
              });
            }
          }
          n.addOrigRange = r;
          function c(y, E) {
            if (!(!y || typeof y != "object") && E(y) !== e)
              for (var I = 0, S = Object.keys(y); I < S.length; I++) {
                var M = S[I];
                if (!(M === "context" || M === "error")) {
                  var T = y[M];
                  Array.isArray(T) ? T.forEach(function(P) {
                    return c(P, E);
                  }) : c(T, E);
                }
              }
          }
          function h(y) {
            return typeof y.start == "number";
          }
          function d(y) {
            return typeof y.offset == "number";
          }
        } }), Qr = D({ "node_modules/yaml-unist-parser/lib/utils/remove-fake-nodes.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r) {
            if ("children" in r) {
              if (r.children.length === 1) {
                var c = r.children[0];
                if (c.type === "plain" && c.tag === null && c.anchor === null && c.value === "")
                  return r.children.splice(0, 1), r;
              }
              r.children.forEach(e);
            }
            return r;
          }
          n.removeFakeNodes = e;
        } }), Ur = D({ "node_modules/yaml-unist-parser/lib/utils/create-updater.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          function e(r, c, h, d) {
            var y = c(r);
            return function(E) {
              d(y, E) && h(r, y = E);
            };
          }
          n.createUpdater = e;
        } }), Kr = D({ "node_modules/yaml-unist-parser/lib/utils/update-positions.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Ur(), r = Ae();
          function c(M) {
            if (!(M === null || !("children" in M))) {
              var T = M.children;
              if (T.forEach(c), M.type === "document") {
                var P = M.children, C = P[0], q = P[1];
                C.position.start.offset === C.position.end.offset ? C.position.start = C.position.end = q.position.start : q.position.start.offset === q.position.end.offset && (q.position.start = q.position.end = C.position.end);
              }
              var R = e.createUpdater(M.position, h, d, I), B = e.createUpdater(M.position, y, E, S);
              "endComments" in M && M.endComments.length !== 0 && (R(M.endComments[0].position.start), B(r.getLast(M.endComments).position.end));
              var U = T.filter(function(t3) {
                return t3 !== null;
              });
              if (U.length !== 0) {
                var f = U[0], i = r.getLast(U);
                R(f.position.start), B(i.position.end), "leadingComments" in f && f.leadingComments.length !== 0 && R(f.leadingComments[0].position.start), "tag" in f && f.tag && R(f.tag.position.start), "anchor" in f && f.anchor && R(f.anchor.position.start), "trailingComment" in i && i.trailingComment && B(i.trailingComment.position.end);
              }
            }
          }
          n.updatePositions = c;
          function h(M) {
            return M.start;
          }
          function d(M, T) {
            M.start = T;
          }
          function y(M) {
            return M.end;
          }
          function E(M, T) {
            M.end = T;
          }
          function I(M, T) {
            return T.offset < M.offset;
          }
          function S(M, T) {
            return T.offset > M.offset;
          }
        } }), Me = D({ "node_modules/yaml/dist/PlainValue-ec8e588e.js"(n) {
          "use strict";
          Y();
          var e = { ANCHOR: "&", COMMENT: "#", TAG: "!", DIRECTIVES_END: "-", DOCUMENT_END: "." }, r = { ALIAS: "ALIAS", BLANK_LINE: "BLANK_LINE", BLOCK_FOLDED: "BLOCK_FOLDED", BLOCK_LITERAL: "BLOCK_LITERAL", COMMENT: "COMMENT", DIRECTIVE: "DIRECTIVE", DOCUMENT: "DOCUMENT", FLOW_MAP: "FLOW_MAP", FLOW_SEQ: "FLOW_SEQ", MAP: "MAP", MAP_KEY: "MAP_KEY", MAP_VALUE: "MAP_VALUE", PLAIN: "PLAIN", QUOTE_DOUBLE: "QUOTE_DOUBLE", QUOTE_SINGLE: "QUOTE_SINGLE", SEQ: "SEQ", SEQ_ITEM: "SEQ_ITEM" }, c = "tag:yaml.org,2002:", h = { MAP: "tag:yaml.org,2002:map", SEQ: "tag:yaml.org,2002:seq", STR: "tag:yaml.org,2002:str" };
          function d(i) {
            let t3 = [0], s = i.indexOf(`
`);
            for (; s !== -1; )
              s += 1, t3.push(s), s = i.indexOf(`
`, s);
            return t3;
          }
          function y(i) {
            let t3, s;
            return typeof i == "string" ? (t3 = d(i), s = i) : (Array.isArray(i) && (i = i[0]), i && i.context && (i.lineStarts || (i.lineStarts = d(i.context.src)), t3 = i.lineStarts, s = i.context.src)), { lineStarts: t3, src: s };
          }
          function E(i, t3) {
            if (typeof i != "number" || i < 0)
              return null;
            let { lineStarts: s, src: a } = y(t3);
            if (!s || !a || i > a.length)
              return null;
            for (let g = 0; g < s.length; ++g) {
              let u = s[g];
              if (i < u)
                return { line: g, col: i - s[g - 1] + 1 };
              if (i === u)
                return { line: g + 1, col: 1 };
            }
            let m = s.length;
            return { line: m, col: i - s[m - 1] + 1 };
          }
          function I(i, t3) {
            let { lineStarts: s, src: a } = y(t3);
            if (!s || !(i >= 1) || i > s.length)
              return null;
            let m = s[i - 1], g = s[i];
            for (; g && g > m && a[g - 1] === `
`; )
              --g;
            return a.slice(m, g);
          }
          function S(i, t3) {
            let { start: s, end: a } = i, m = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : 80, g = I(s.line, t3);
            if (!g)
              return null;
            let { col: u } = s;
            if (g.length > m)
              if (u <= m - 10)
                g = g.substr(0, m - 1) + "\u2026";
              else {
                let K = Math.round(m / 2);
                g.length > u + K && (g = g.substr(0, u + K - 1) + "\u2026"), u -= g.length - m, g = "\u2026" + g.substr(1 - m);
              }
            let p = 1, L = "";
            a && (a.line === s.line && u + (a.col - s.col) <= m + 1 ? p = a.col - s.col : (p = Math.min(g.length + 1, m) - u, L = "\u2026"));
            let k = u > 1 ? " ".repeat(u - 1) : "", $2 = "^".repeat(p);
            return `${g}
${k}${$2}${L}`;
          }
          var M = class {
            static copy(i) {
              return new M(i.start, i.end);
            }
            constructor(i, t3) {
              this.start = i, this.end = t3 || i;
            }
            isEmpty() {
              return typeof this.start != "number" || !this.end || this.end <= this.start;
            }
            setOrigRange(i, t3) {
              let { start: s, end: a } = this;
              if (i.length === 0 || a <= i[0])
                return this.origStart = s, this.origEnd = a, t3;
              let m = t3;
              for (; m < i.length && !(i[m] > s); )
                ++m;
              this.origStart = s + m;
              let g = m;
              for (; m < i.length && !(i[m] >= a); )
                ++m;
              return this.origEnd = a + m, g;
            }
          }, T = class {
            static addStringTerminator(i, t3, s) {
              if (s[s.length - 1] === `
`)
                return s;
              let a = T.endOfWhiteSpace(i, t3);
              return a >= i.length || i[a] === `
` ? s + `
` : s;
            }
            static atDocumentBoundary(i, t3, s) {
              let a = i[t3];
              if (!a)
                return true;
              let m = i[t3 - 1];
              if (m && m !== `
`)
                return false;
              if (s) {
                if (a !== s)
                  return false;
              } else if (a !== e.DIRECTIVES_END && a !== e.DOCUMENT_END)
                return false;
              let g = i[t3 + 1], u = i[t3 + 2];
              if (g !== a || u !== a)
                return false;
              let p = i[t3 + 3];
              return !p || p === `
` || p === "	" || p === " ";
            }
            static endOfIdentifier(i, t3) {
              let s = i[t3], a = s === "<", m = a ? [`
`, "	", " ", ">"] : [`
`, "	", " ", "[", "]", "{", "}", ","];
              for (; s && m.indexOf(s) === -1; )
                s = i[t3 += 1];
              return a && s === ">" && (t3 += 1), t3;
            }
            static endOfIndent(i, t3) {
              let s = i[t3];
              for (; s === " "; )
                s = i[t3 += 1];
              return t3;
            }
            static endOfLine(i, t3) {
              let s = i[t3];
              for (; s && s !== `
`; )
                s = i[t3 += 1];
              return t3;
            }
            static endOfWhiteSpace(i, t3) {
              let s = i[t3];
              for (; s === "	" || s === " "; )
                s = i[t3 += 1];
              return t3;
            }
            static startOfLine(i, t3) {
              let s = i[t3 - 1];
              if (s === `
`)
                return t3;
              for (; s && s !== `
`; )
                s = i[t3 -= 1];
              return t3 + 1;
            }
            static endOfBlockIndent(i, t3, s) {
              let a = T.endOfIndent(i, s);
              if (a > s + t3)
                return a;
              {
                let m = T.endOfWhiteSpace(i, a), g = i[m];
                if (!g || g === `
`)
                  return m;
              }
              return null;
            }
            static atBlank(i, t3, s) {
              let a = i[t3];
              return a === `
` || a === "	" || a === " " || s && !a;
            }
            static nextNodeIsIndented(i, t3, s) {
              return !i || t3 < 0 ? false : t3 > 0 ? true : s && i === "-";
            }
            static normalizeOffset(i, t3) {
              let s = i[t3];
              return s ? s !== `
` && i[t3 - 1] === `
` ? t3 - 1 : T.endOfWhiteSpace(i, t3) : t3;
            }
            static foldNewline(i, t3, s) {
              let a = 0, m = false, g = "", u = i[t3 + 1];
              for (; u === " " || u === "	" || u === `
`; ) {
                switch (u) {
                  case `
`:
                    a = 0, t3 += 1, g += `
`;
                    break;
                  case "	":
                    a <= s && (m = true), t3 = T.endOfWhiteSpace(i, t3 + 2) - 1;
                    break;
                  case " ":
                    a += 1, t3 += 1;
                    break;
                }
                u = i[t3 + 1];
              }
              return g || (g = " "), u && a <= s && (m = true), { fold: g, offset: t3, error: m };
            }
            constructor(i, t3, s) {
              Object.defineProperty(this, "context", { value: s || null, writable: true }), this.error = null, this.range = null, this.valueRange = null, this.props = t3 || [], this.type = i, this.value = null;
            }
            getPropValue(i, t3, s) {
              if (!this.context)
                return null;
              let { src: a } = this.context, m = this.props[i];
              return m && a[m.start] === t3 ? a.slice(m.start + (s ? 1 : 0), m.end) : null;
            }
            get anchor() {
              for (let i = 0; i < this.props.length; ++i) {
                let t3 = this.getPropValue(i, e.ANCHOR, true);
                if (t3 != null)
                  return t3;
              }
              return null;
            }
            get comment() {
              let i = [];
              for (let t3 = 0; t3 < this.props.length; ++t3) {
                let s = this.getPropValue(t3, e.COMMENT, true);
                s != null && i.push(s);
              }
              return i.length > 0 ? i.join(`
`) : null;
            }
            commentHasRequiredWhitespace(i) {
              let { src: t3 } = this.context;
              if (this.header && i === this.header.end || !this.valueRange)
                return false;
              let { end: s } = this.valueRange;
              return i !== s || T.atBlank(t3, s - 1);
            }
            get hasComment() {
              if (this.context) {
                let { src: i } = this.context;
                for (let t3 = 0; t3 < this.props.length; ++t3)
                  if (i[this.props[t3].start] === e.COMMENT)
                    return true;
              }
              return false;
            }
            get hasProps() {
              if (this.context) {
                let { src: i } = this.context;
                for (let t3 = 0; t3 < this.props.length; ++t3)
                  if (i[this.props[t3].start] !== e.COMMENT)
                    return true;
              }
              return false;
            }
            get includesTrailingLines() {
              return false;
            }
            get jsonLike() {
              return [r.FLOW_MAP, r.FLOW_SEQ, r.QUOTE_DOUBLE, r.QUOTE_SINGLE].indexOf(this.type) !== -1;
            }
            get rangeAsLinePos() {
              if (!this.range || !this.context)
                return;
              let i = E(this.range.start, this.context.root);
              if (!i)
                return;
              let t3 = E(this.range.end, this.context.root);
              return { start: i, end: t3 };
            }
            get rawValue() {
              if (!this.valueRange || !this.context)
                return null;
              let { start: i, end: t3 } = this.valueRange;
              return this.context.src.slice(i, t3);
            }
            get tag() {
              for (let i = 0; i < this.props.length; ++i) {
                let t3 = this.getPropValue(i, e.TAG, false);
                if (t3 != null) {
                  if (t3[1] === "<")
                    return { verbatim: t3.slice(2, -1) };
                  {
                    let [s, a, m] = t3.match(/^(.*!)([^!]*)$/);
                    return { handle: a, suffix: m };
                  }
                }
              }
              return null;
            }
            get valueRangeContainsNewline() {
              if (!this.valueRange || !this.context)
                return false;
              let { start: i, end: t3 } = this.valueRange, { src: s } = this.context;
              for (let a = i; a < t3; ++a)
                if (s[a] === `
`)
                  return true;
              return false;
            }
            parseComment(i) {
              let { src: t3 } = this.context;
              if (t3[i] === e.COMMENT) {
                let s = T.endOfLine(t3, i + 1), a = new M(i, s);
                return this.props.push(a), s;
              }
              return i;
            }
            setOrigRanges(i, t3) {
              return this.range && (t3 = this.range.setOrigRange(i, t3)), this.valueRange && this.valueRange.setOrigRange(i, t3), this.props.forEach((s) => s.setOrigRange(i, t3)), t3;
            }
            toString() {
              let { context: { src: i }, range: t3, value: s } = this;
              if (s != null)
                return s;
              let a = i.slice(t3.start, t3.end);
              return T.addStringTerminator(i, t3.end, a);
            }
          }, P = class extends Error {
            constructor(i, t3, s) {
              if (!s || !(t3 instanceof T))
                throw new Error(`Invalid arguments for new ${i}`);
              super(), this.name = i, this.message = s, this.source = t3;
            }
            makePretty() {
              if (!this.source)
                return;
              this.nodeType = this.source.type;
              let i = this.source.context && this.source.context.root;
              if (typeof this.offset == "number") {
                this.range = new M(this.offset, this.offset + 1);
                let t3 = i && E(this.offset, i);
                if (t3) {
                  let s = { line: t3.line, col: t3.col + 1 };
                  this.linePos = { start: t3, end: s };
                }
                delete this.offset;
              } else
                this.range = this.source.range, this.linePos = this.source.rangeAsLinePos;
              if (this.linePos) {
                let { line: t3, col: s } = this.linePos.start;
                this.message += ` at line ${t3}, column ${s}`;
                let a = i && S(this.linePos, i);
                a && (this.message += `:

${a}
`);
              }
              delete this.source;
            }
          }, C = class extends P {
            constructor(i, t3) {
              super("YAMLReferenceError", i, t3);
            }
          }, q = class extends P {
            constructor(i, t3) {
              super("YAMLSemanticError", i, t3);
            }
          }, R = class extends P {
            constructor(i, t3) {
              super("YAMLSyntaxError", i, t3);
            }
          }, B = class extends P {
            constructor(i, t3) {
              super("YAMLWarning", i, t3);
            }
          };
          function U(i, t3, s) {
            return t3 in i ? Object.defineProperty(i, t3, { value: s, enumerable: true, configurable: true, writable: true }) : i[t3] = s, i;
          }
          var f = class extends T {
            static endOfLine(i, t3, s) {
              let a = i[t3], m = t3;
              for (; a && a !== `
` && !(s && (a === "[" || a === "]" || a === "{" || a === "}" || a === ",")); ) {
                let g = i[m + 1];
                if (a === ":" && (!g || g === `
` || g === "	" || g === " " || s && g === ",") || (a === " " || a === "	") && g === "#")
                  break;
                m += 1, a = g;
              }
              return m;
            }
            get strValue() {
              if (!this.valueRange || !this.context)
                return null;
              let { start: i, end: t3 } = this.valueRange, { src: s } = this.context, a = s[t3 - 1];
              for (; i < t3 && (a === `
` || a === "	" || a === " "); )
                a = s[--t3 - 1];
              let m = "";
              for (let u = i; u < t3; ++u) {
                let p = s[u];
                if (p === `
`) {
                  let { fold: L, offset: k } = T.foldNewline(s, u, -1);
                  m += L, u = k;
                } else if (p === " " || p === "	") {
                  let L = u, k = s[u + 1];
                  for (; u < t3 && (k === " " || k === "	"); )
                    u += 1, k = s[u + 1];
                  k !== `
` && (m += u > L ? s.slice(L, u + 1) : p);
                } else
                  m += p;
              }
              let g = s[i];
              switch (g) {
                case "	": {
                  let u = "Plain value cannot start with a tab character";
                  return { errors: [new q(this, u)], str: m };
                }
                case "@":
                case "`": {
                  let u = `Plain value cannot start with reserved character ${g}`;
                  return { errors: [new q(this, u)], str: m };
                }
                default:
                  return m;
              }
            }
            parseBlockValue(i) {
              let { indent: t3, inFlow: s, src: a } = this.context, m = i, g = i;
              for (let u = a[m]; u === `
` && !T.atDocumentBoundary(a, m + 1); u = a[m]) {
                let p = T.endOfBlockIndent(a, t3, m + 1);
                if (p === null || a[p] === "#")
                  break;
                a[p] === `
` ? m = p : (g = f.endOfLine(a, p, s), m = g);
              }
              return this.valueRange.isEmpty() && (this.valueRange.start = i), this.valueRange.end = g, g;
            }
            parse(i, t3) {
              this.context = i;
              let { inFlow: s, src: a } = i, m = t3, g = a[m];
              return g && g !== "#" && g !== `
` && (m = f.endOfLine(a, t3, s)), this.valueRange = new M(t3, m), m = T.endOfWhiteSpace(a, m), m = this.parseComment(m), (!this.hasComment || this.valueRange.isEmpty()) && (m = this.parseBlockValue(m)), m;
            }
          };
          n.Char = e, n.Node = T, n.PlainValue = f, n.Range = M, n.Type = r, n.YAMLError = P, n.YAMLReferenceError = C, n.YAMLSemanticError = q, n.YAMLSyntaxError = R, n.YAMLWarning = B, n._defineProperty = U, n.defaultTagPrefix = c, n.defaultTags = h;
        } }), Jr = D({ "node_modules/yaml/dist/parse-cst.js"(n) {
          "use strict";
          Y();
          var e = Me(), r = class extends e.Node {
            constructor() {
              super(e.Type.BLANK_LINE);
            }
            get includesTrailingLines() {
              return true;
            }
            parse(f, i) {
              return this.context = f, this.range = new e.Range(i, i + 1), i + 1;
            }
          }, c = class extends e.Node {
            constructor(f, i) {
              super(f, i), this.node = null;
            }
            get includesTrailingLines() {
              return !!this.node && this.node.includesTrailingLines;
            }
            parse(f, i) {
              this.context = f;
              let { parseNode: t3, src: s } = f, { atLineStart: a, lineStart: m } = f;
              !a && this.type === e.Type.SEQ_ITEM && (this.error = new e.YAMLSemanticError(this, "Sequence items must not have preceding content on the same line"));
              let g = a ? i - m : f.indent, u = e.Node.endOfWhiteSpace(s, i + 1), p = s[u], L = p === "#", k = [], $2 = null;
              for (; p === `
` || p === "#"; ) {
                if (p === "#") {
                  let V = e.Node.endOfLine(s, u + 1);
                  k.push(new e.Range(u, V)), u = V;
                } else {
                  a = true, m = u + 1;
                  let V = e.Node.endOfWhiteSpace(s, m);
                  s[V] === `
` && k.length === 0 && ($2 = new r(), m = $2.parse({ src: s }, m)), u = e.Node.endOfIndent(s, m);
                }
                p = s[u];
              }
              if (e.Node.nextNodeIsIndented(p, u - (m + g), this.type !== e.Type.SEQ_ITEM) ? this.node = t3({ atLineStart: a, inCollection: false, indent: g, lineStart: m, parent: this }, u) : p && m > i + 1 && (u = m - 1), this.node) {
                if ($2) {
                  let V = f.parent.items || f.parent.contents;
                  V && V.push($2);
                }
                k.length && Array.prototype.push.apply(this.props, k), u = this.node.range.end;
              } else if (L) {
                let V = k[0];
                this.props.push(V), u = V.end;
              } else
                u = e.Node.endOfLine(s, i + 1);
              let K = this.node ? this.node.valueRange.end : u;
              return this.valueRange = new e.Range(i, K), u;
            }
            setOrigRanges(f, i) {
              return i = super.setOrigRanges(f, i), this.node ? this.node.setOrigRanges(f, i) : i;
            }
            toString() {
              let { context: { src: f }, node: i, range: t3, value: s } = this;
              if (s != null)
                return s;
              let a = i ? f.slice(t3.start, i.range.start) + String(i) : f.slice(t3.start, t3.end);
              return e.Node.addStringTerminator(f, t3.end, a);
            }
          }, h = class extends e.Node {
            constructor() {
              super(e.Type.COMMENT);
            }
            parse(f, i) {
              this.context = f;
              let t3 = this.parseComment(i);
              return this.range = new e.Range(i, t3), t3;
            }
          };
          function d(f) {
            let i = f;
            for (; i instanceof c; )
              i = i.node;
            if (!(i instanceof y))
              return null;
            let t3 = i.items.length, s = -1;
            for (let g = t3 - 1; g >= 0; --g) {
              let u = i.items[g];
              if (u.type === e.Type.COMMENT) {
                let { indent: p, lineStart: L } = u.context;
                if (p > 0 && u.range.start >= L + p)
                  break;
                s = g;
              } else if (u.type === e.Type.BLANK_LINE)
                s = g;
              else
                break;
            }
            if (s === -1)
              return null;
            let a = i.items.splice(s, t3 - s), m = a[0].range.start;
            for (; i.range.end = m, i.valueRange && i.valueRange.end > m && (i.valueRange.end = m), i !== f; )
              i = i.context.parent;
            return a;
          }
          var y = class extends e.Node {
            static nextContentHasIndent(f, i, t3) {
              let s = e.Node.endOfLine(f, i) + 1;
              i = e.Node.endOfWhiteSpace(f, s);
              let a = f[i];
              return a ? i >= s + t3 ? true : a !== "#" && a !== `
` ? false : y.nextContentHasIndent(f, i, t3) : false;
            }
            constructor(f) {
              super(f.type === e.Type.SEQ_ITEM ? e.Type.SEQ : e.Type.MAP);
              for (let t3 = f.props.length - 1; t3 >= 0; --t3)
                if (f.props[t3].start < f.context.lineStart) {
                  this.props = f.props.slice(0, t3 + 1), f.props = f.props.slice(t3 + 1);
                  let s = f.props[0] || f.valueRange;
                  f.range.start = s.start;
                  break;
                }
              this.items = [f];
              let i = d(f);
              i && Array.prototype.push.apply(this.items, i);
            }
            get includesTrailingLines() {
              return this.items.length > 0;
            }
            parse(f, i) {
              this.context = f;
              let { parseNode: t3, src: s } = f, a = e.Node.startOfLine(s, i), m = this.items[0];
              m.context.parent = this, this.valueRange = e.Range.copy(m.valueRange);
              let g = m.range.start - m.context.lineStart, u = i;
              u = e.Node.normalizeOffset(s, u);
              let p = s[u], L = e.Node.endOfWhiteSpace(s, a) === u, k = false;
              for (; p; ) {
                for (; p === `
` || p === "#"; ) {
                  if (L && p === `
` && !k) {
                    let V = new r();
                    if (u = V.parse({ src: s }, u), this.valueRange.end = u, u >= s.length) {
                      p = null;
                      break;
                    }
                    this.items.push(V), u -= 1;
                  } else if (p === "#") {
                    if (u < a + g && !y.nextContentHasIndent(s, u, g))
                      return u;
                    let V = new h();
                    if (u = V.parse({ indent: g, lineStart: a, src: s }, u), this.items.push(V), this.valueRange.end = u, u >= s.length) {
                      p = null;
                      break;
                    }
                  }
                  if (a = u + 1, u = e.Node.endOfIndent(s, a), e.Node.atBlank(s, u)) {
                    let V = e.Node.endOfWhiteSpace(s, u), z = s[V];
                    (!z || z === `
` || z === "#") && (u = V);
                  }
                  p = s[u], L = true;
                }
                if (!p)
                  break;
                if (u !== a + g && (L || p !== ":")) {
                  if (u < a + g) {
                    a > i && (u = a);
                    break;
                  } else if (!this.error) {
                    let V = "All collection items must start at the same column";
                    this.error = new e.YAMLSyntaxError(this, V);
                  }
                }
                if (m.type === e.Type.SEQ_ITEM) {
                  if (p !== "-") {
                    a > i && (u = a);
                    break;
                  }
                } else if (p === "-" && !this.error) {
                  let V = s[u + 1];
                  if (!V || V === `
` || V === "	" || V === " ") {
                    let z = "A collection cannot be both a mapping and a sequence";
                    this.error = new e.YAMLSyntaxError(this, z);
                  }
                }
                let $2 = t3({ atLineStart: L, inCollection: true, indent: g, lineStart: a, parent: this }, u);
                if (!$2)
                  return u;
                if (this.items.push($2), this.valueRange.end = $2.valueRange.end, u = e.Node.normalizeOffset(s, $2.range.end), p = s[u], L = false, k = $2.includesTrailingLines, p) {
                  let V = u - 1, z = s[V];
                  for (; z === " " || z === "	"; )
                    z = s[--V];
                  z === `
` && (a = V + 1, L = true);
                }
                let K = d($2);
                K && Array.prototype.push.apply(this.items, K);
              }
              return u;
            }
            setOrigRanges(f, i) {
              return i = super.setOrigRanges(f, i), this.items.forEach((t3) => {
                i = t3.setOrigRanges(f, i);
              }), i;
            }
            toString() {
              let { context: { src: f }, items: i, range: t3, value: s } = this;
              if (s != null)
                return s;
              let a = f.slice(t3.start, i[0].range.start) + String(i[0]);
              for (let m = 1; m < i.length; ++m) {
                let g = i[m], { atLineStart: u, indent: p } = g.context;
                if (u)
                  for (let L = 0; L < p; ++L)
                    a += " ";
                a += String(g);
              }
              return e.Node.addStringTerminator(f, t3.end, a);
            }
          }, E = class extends e.Node {
            constructor() {
              super(e.Type.DIRECTIVE), this.name = null;
            }
            get parameters() {
              let f = this.rawValue;
              return f ? f.trim().split(/[ \t]+/) : [];
            }
            parseName(f) {
              let { src: i } = this.context, t3 = f, s = i[t3];
              for (; s && s !== `
` && s !== "	" && s !== " "; )
                s = i[t3 += 1];
              return this.name = i.slice(f, t3), t3;
            }
            parseParameters(f) {
              let { src: i } = this.context, t3 = f, s = i[t3];
              for (; s && s !== `
` && s !== "#"; )
                s = i[t3 += 1];
              return this.valueRange = new e.Range(f, t3), t3;
            }
            parse(f, i) {
              this.context = f;
              let t3 = this.parseName(i + 1);
              return t3 = this.parseParameters(t3), t3 = this.parseComment(t3), this.range = new e.Range(i, t3), t3;
            }
          }, I = class extends e.Node {
            static startCommentOrEndBlankLine(f, i) {
              let t3 = e.Node.endOfWhiteSpace(f, i), s = f[t3];
              return s === "#" || s === `
` ? t3 : i;
            }
            constructor() {
              super(e.Type.DOCUMENT), this.directives = null, this.contents = null, this.directivesEndMarker = null, this.documentEndMarker = null;
            }
            parseDirectives(f) {
              let { src: i } = this.context;
              this.directives = [];
              let t3 = true, s = false, a = f;
              for (; !e.Node.atDocumentBoundary(i, a, e.Char.DIRECTIVES_END); )
                switch (a = I.startCommentOrEndBlankLine(i, a), i[a]) {
                  case `
`:
                    if (t3) {
                      let m = new r();
                      a = m.parse({ src: i }, a), a < i.length && this.directives.push(m);
                    } else
                      a += 1, t3 = true;
                    break;
                  case "#":
                    {
                      let m = new h();
                      a = m.parse({ src: i }, a), this.directives.push(m), t3 = false;
                    }
                    break;
                  case "%":
                    {
                      let m = new E();
                      a = m.parse({ parent: this, src: i }, a), this.directives.push(m), s = true, t3 = false;
                    }
                    break;
                  default:
                    return s ? this.error = new e.YAMLSemanticError(this, "Missing directives-end indicator line") : this.directives.length > 0 && (this.contents = this.directives, this.directives = []), a;
                }
              return i[a] ? (this.directivesEndMarker = new e.Range(a, a + 3), a + 3) : (s ? this.error = new e.YAMLSemanticError(this, "Missing directives-end indicator line") : this.directives.length > 0 && (this.contents = this.directives, this.directives = []), a);
            }
            parseContents(f) {
              let { parseNode: i, src: t3 } = this.context;
              this.contents || (this.contents = []);
              let s = f;
              for (; t3[s - 1] === "-"; )
                s -= 1;
              let a = e.Node.endOfWhiteSpace(t3, f), m = s === f;
              for (this.valueRange = new e.Range(a); !e.Node.atDocumentBoundary(t3, a, e.Char.DOCUMENT_END); ) {
                switch (t3[a]) {
                  case `
`:
                    if (m) {
                      let g = new r();
                      a = g.parse({ src: t3 }, a), a < t3.length && this.contents.push(g);
                    } else
                      a += 1, m = true;
                    s = a;
                    break;
                  case "#":
                    {
                      let g = new h();
                      a = g.parse({ src: t3 }, a), this.contents.push(g), m = false;
                    }
                    break;
                  default: {
                    let g = e.Node.endOfIndent(t3, a), p = i({ atLineStart: m, indent: -1, inFlow: false, inCollection: false, lineStart: s, parent: this }, g);
                    if (!p)
                      return this.valueRange.end = g;
                    this.contents.push(p), a = p.range.end, m = false;
                    let L = d(p);
                    L && Array.prototype.push.apply(this.contents, L);
                  }
                }
                a = I.startCommentOrEndBlankLine(t3, a);
              }
              if (this.valueRange.end = a, t3[a] && (this.documentEndMarker = new e.Range(a, a + 3), a += 3, t3[a])) {
                if (a = e.Node.endOfWhiteSpace(t3, a), t3[a] === "#") {
                  let g = new h();
                  a = g.parse({ src: t3 }, a), this.contents.push(g);
                }
                switch (t3[a]) {
                  case `
`:
                    a += 1;
                    break;
                  case void 0:
                    break;
                  default:
                    this.error = new e.YAMLSyntaxError(this, "Document end marker line cannot have a non-comment suffix");
                }
              }
              return a;
            }
            parse(f, i) {
              f.root = this, this.context = f;
              let { src: t3 } = f, s = t3.charCodeAt(i) === 65279 ? i + 1 : i;
              return s = this.parseDirectives(s), s = this.parseContents(s), s;
            }
            setOrigRanges(f, i) {
              return i = super.setOrigRanges(f, i), this.directives.forEach((t3) => {
                i = t3.setOrigRanges(f, i);
              }), this.directivesEndMarker && (i = this.directivesEndMarker.setOrigRange(f, i)), this.contents.forEach((t3) => {
                i = t3.setOrigRanges(f, i);
              }), this.documentEndMarker && (i = this.documentEndMarker.setOrigRange(f, i)), i;
            }
            toString() {
              let { contents: f, directives: i, value: t3 } = this;
              if (t3 != null)
                return t3;
              let s = i.join("");
              return f.length > 0 && ((i.length > 0 || f[0].type === e.Type.COMMENT) && (s += `---
`), s += f.join("")), s[s.length - 1] !== `
` && (s += `
`), s;
            }
          }, S = class extends e.Node {
            parse(f, i) {
              this.context = f;
              let { src: t3 } = f, s = e.Node.endOfIdentifier(t3, i + 1);
              return this.valueRange = new e.Range(i + 1, s), s = e.Node.endOfWhiteSpace(t3, s), s = this.parseComment(s), s;
            }
          }, M = { CLIP: "CLIP", KEEP: "KEEP", STRIP: "STRIP" }, T = class extends e.Node {
            constructor(f, i) {
              super(f, i), this.blockIndent = null, this.chomping = M.CLIP, this.header = null;
            }
            get includesTrailingLines() {
              return this.chomping === M.KEEP;
            }
            get strValue() {
              if (!this.valueRange || !this.context)
                return null;
              let { start: f, end: i } = this.valueRange, { indent: t3, src: s } = this.context;
              if (this.valueRange.isEmpty())
                return "";
              let a = null, m = s[i - 1];
              for (; m === `
` || m === "	" || m === " "; ) {
                if (i -= 1, i <= f) {
                  if (this.chomping === M.KEEP)
                    break;
                  return "";
                }
                m === `
` && (a = i), m = s[i - 1];
              }
              let g = i + 1;
              a && (this.chomping === M.KEEP ? (g = a, i = this.valueRange.end) : i = a);
              let u = t3 + this.blockIndent, p = this.type === e.Type.BLOCK_FOLDED, L = true, k = "", $2 = "", K = false;
              for (let V = f; V < i; ++V) {
                for (let ae = 0; ae < u && s[V] === " "; ++ae)
                  V += 1;
                let z = s[V];
                if (z === `
`)
                  $2 === `
` ? k += `
` : $2 = `
`;
                else {
                  let ae = e.Node.endOfLine(s, V), ue = s.slice(V, ae);
                  V = ae, p && (z === " " || z === "	") && V < g ? ($2 === " " ? $2 = `
` : !K && !L && $2 === `
` && ($2 = `

`), k += $2 + ue, $2 = ae < i && s[ae] || "", K = true) : (k += $2 + ue, $2 = p && V < g ? " " : `
`, K = false), L && ue !== "" && (L = false);
                }
              }
              return this.chomping === M.STRIP ? k : k + `
`;
            }
            parseBlockHeader(f) {
              let { src: i } = this.context, t3 = f + 1, s = "";
              for (; ; ) {
                let a = i[t3];
                switch (a) {
                  case "-":
                    this.chomping = M.STRIP;
                    break;
                  case "+":
                    this.chomping = M.KEEP;
                    break;
                  case "0":
                  case "1":
                  case "2":
                  case "3":
                  case "4":
                  case "5":
                  case "6":
                  case "7":
                  case "8":
                  case "9":
                    s += a;
                    break;
                  default:
                    return this.blockIndent = Number(s) || null, this.header = new e.Range(f, t3), t3;
                }
                t3 += 1;
              }
            }
            parseBlockValue(f) {
              let { indent: i, src: t3 } = this.context, s = !!this.blockIndent, a = f, m = f, g = 1;
              for (let u = t3[a]; u === `
` && (a += 1, !e.Node.atDocumentBoundary(t3, a)); u = t3[a]) {
                let p = e.Node.endOfBlockIndent(t3, i, a);
                if (p === null)
                  break;
                let L = t3[p], k = p - (a + i);
                if (this.blockIndent) {
                  if (L && L !== `
` && k < this.blockIndent) {
                    if (t3[p] === "#")
                      break;
                    if (!this.error) {
                      let K = `Block scalars must not be less indented than their ${s ? "explicit indentation indicator" : "first line"}`;
                      this.error = new e.YAMLSemanticError(this, K);
                    }
                  }
                } else if (t3[p] !== `
`) {
                  if (k < g) {
                    let $2 = "Block scalars with more-indented leading empty lines must use an explicit indentation indicator";
                    this.error = new e.YAMLSemanticError(this, $2);
                  }
                  this.blockIndent = k;
                } else
                  k > g && (g = k);
                t3[p] === `
` ? a = p : a = m = e.Node.endOfLine(t3, p);
              }
              return this.chomping !== M.KEEP && (a = t3[m] ? m + 1 : m), this.valueRange = new e.Range(f + 1, a), a;
            }
            parse(f, i) {
              this.context = f;
              let { src: t3 } = f, s = this.parseBlockHeader(i);
              return s = e.Node.endOfWhiteSpace(t3, s), s = this.parseComment(s), s = this.parseBlockValue(s), s;
            }
            setOrigRanges(f, i) {
              return i = super.setOrigRanges(f, i), this.header ? this.header.setOrigRange(f, i) : i;
            }
          }, P = class extends e.Node {
            constructor(f, i) {
              super(f, i), this.items = null;
            }
            prevNodeIsJsonLike() {
              let f = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : this.items.length, i = this.items[f - 1];
              return !!i && (i.jsonLike || i.type === e.Type.COMMENT && this.prevNodeIsJsonLike(f - 1));
            }
            parse(f, i) {
              this.context = f;
              let { parseNode: t3, src: s } = f, { indent: a, lineStart: m } = f, g = s[i];
              this.items = [{ char: g, offset: i }];
              let u = e.Node.endOfWhiteSpace(s, i + 1);
              for (g = s[u]; g && g !== "]" && g !== "}"; ) {
                switch (g) {
                  case `
`:
                    {
                      m = u + 1;
                      let p = e.Node.endOfWhiteSpace(s, m);
                      if (s[p] === `
`) {
                        let L = new r();
                        m = L.parse({ src: s }, m), this.items.push(L);
                      }
                      if (u = e.Node.endOfIndent(s, m), u <= m + a && (g = s[u], u < m + a || g !== "]" && g !== "}")) {
                        let L = "Insufficient indentation in flow collection";
                        this.error = new e.YAMLSemanticError(this, L);
                      }
                    }
                    break;
                  case ",":
                    this.items.push({ char: g, offset: u }), u += 1;
                    break;
                  case "#":
                    {
                      let p = new h();
                      u = p.parse({ src: s }, u), this.items.push(p);
                    }
                    break;
                  case "?":
                  case ":": {
                    let p = s[u + 1];
                    if (p === `
` || p === "	" || p === " " || p === "," || g === ":" && this.prevNodeIsJsonLike()) {
                      this.items.push({ char: g, offset: u }), u += 1;
                      break;
                    }
                  }
                  default: {
                    let p = t3({ atLineStart: false, inCollection: false, inFlow: true, indent: -1, lineStart: m, parent: this }, u);
                    if (!p)
                      return this.valueRange = new e.Range(i, u), u;
                    this.items.push(p), u = e.Node.normalizeOffset(s, p.range.end);
                  }
                }
                u = e.Node.endOfWhiteSpace(s, u), g = s[u];
              }
              return this.valueRange = new e.Range(i, u + 1), g && (this.items.push({ char: g, offset: u }), u = e.Node.endOfWhiteSpace(s, u + 1), u = this.parseComment(u)), u;
            }
            setOrigRanges(f, i) {
              return i = super.setOrigRanges(f, i), this.items.forEach((t3) => {
                if (t3 instanceof e.Node)
                  i = t3.setOrigRanges(f, i);
                else if (f.length === 0)
                  t3.origOffset = t3.offset;
                else {
                  let s = i;
                  for (; s < f.length && !(f[s] > t3.offset); )
                    ++s;
                  t3.origOffset = t3.offset + s, i = s;
                }
              }), i;
            }
            toString() {
              let { context: { src: f }, items: i, range: t3, value: s } = this;
              if (s != null)
                return s;
              let a = i.filter((u) => u instanceof e.Node), m = "", g = t3.start;
              return a.forEach((u) => {
                let p = f.slice(g, u.range.start);
                g = u.range.end, m += p + String(u), m[m.length - 1] === `
` && f[g - 1] !== `
` && f[g] === `
` && (g += 1);
              }), m += f.slice(g, t3.end), e.Node.addStringTerminator(f, t3.end, m);
            }
          }, C = class extends e.Node {
            static endOfQuote(f, i) {
              let t3 = f[i];
              for (; t3 && t3 !== '"'; )
                i += t3 === "\\" ? 2 : 1, t3 = f[i];
              return i + 1;
            }
            get strValue() {
              if (!this.valueRange || !this.context)
                return null;
              let f = [], { start: i, end: t3 } = this.valueRange, { indent: s, src: a } = this.context;
              a[t3 - 1] !== '"' && f.push(new e.YAMLSyntaxError(this, 'Missing closing "quote'));
              let m = "";
              for (let g = i + 1; g < t3 - 1; ++g) {
                let u = a[g];
                if (u === `
`) {
                  e.Node.atDocumentBoundary(a, g + 1) && f.push(new e.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
                  let { fold: p, offset: L, error: k } = e.Node.foldNewline(a, g, s);
                  m += p, g = L, k && f.push(new e.YAMLSemanticError(this, "Multi-line double-quoted string needs to be sufficiently indented"));
                } else if (u === "\\")
                  switch (g += 1, a[g]) {
                    case "0":
                      m += "\0";
                      break;
                    case "a":
                      m += "\x07";
                      break;
                    case "b":
                      m += "\b";
                      break;
                    case "e":
                      m += "\x1B";
                      break;
                    case "f":
                      m += "\f";
                      break;
                    case "n":
                      m += `
`;
                      break;
                    case "r":
                      m += "\r";
                      break;
                    case "t":
                      m += "	";
                      break;
                    case "v":
                      m += "\v";
                      break;
                    case "N":
                      m += "\x85";
                      break;
                    case "_":
                      m += "\xA0";
                      break;
                    case "L":
                      m += "\u2028";
                      break;
                    case "P":
                      m += "\u2029";
                      break;
                    case " ":
                      m += " ";
                      break;
                    case '"':
                      m += '"';
                      break;
                    case "/":
                      m += "/";
                      break;
                    case "\\":
                      m += "\\";
                      break;
                    case "	":
                      m += "	";
                      break;
                    case "x":
                      m += this.parseCharCode(g + 1, 2, f), g += 2;
                      break;
                    case "u":
                      m += this.parseCharCode(g + 1, 4, f), g += 4;
                      break;
                    case "U":
                      m += this.parseCharCode(g + 1, 8, f), g += 8;
                      break;
                    case `
`:
                      for (; a[g + 1] === " " || a[g + 1] === "	"; )
                        g += 1;
                      break;
                    default:
                      f.push(new e.YAMLSyntaxError(this, `Invalid escape sequence ${a.substr(g - 1, 2)}`)), m += "\\" + a[g];
                  }
                else if (u === " " || u === "	") {
                  let p = g, L = a[g + 1];
                  for (; L === " " || L === "	"; )
                    g += 1, L = a[g + 1];
                  L !== `
` && (m += g > p ? a.slice(p, g + 1) : u);
                } else
                  m += u;
              }
              return f.length > 0 ? { errors: f, str: m } : m;
            }
            parseCharCode(f, i, t3) {
              let { src: s } = this.context, a = s.substr(f, i), g = a.length === i && /^[0-9a-fA-F]+$/.test(a) ? parseInt(a, 16) : NaN;
              return isNaN(g) ? (t3.push(new e.YAMLSyntaxError(this, `Invalid escape sequence ${s.substr(f - 2, i + 2)}`)), s.substr(f - 2, i + 2)) : String.fromCodePoint(g);
            }
            parse(f, i) {
              this.context = f;
              let { src: t3 } = f, s = C.endOfQuote(t3, i + 1);
              return this.valueRange = new e.Range(i, s), s = e.Node.endOfWhiteSpace(t3, s), s = this.parseComment(s), s;
            }
          }, q = class extends e.Node {
            static endOfQuote(f, i) {
              let t3 = f[i];
              for (; t3; )
                if (t3 === "'") {
                  if (f[i + 1] !== "'")
                    break;
                  t3 = f[i += 2];
                } else
                  t3 = f[i += 1];
              return i + 1;
            }
            get strValue() {
              if (!this.valueRange || !this.context)
                return null;
              let f = [], { start: i, end: t3 } = this.valueRange, { indent: s, src: a } = this.context;
              a[t3 - 1] !== "'" && f.push(new e.YAMLSyntaxError(this, "Missing closing 'quote"));
              let m = "";
              for (let g = i + 1; g < t3 - 1; ++g) {
                let u = a[g];
                if (u === `
`) {
                  e.Node.atDocumentBoundary(a, g + 1) && f.push(new e.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
                  let { fold: p, offset: L, error: k } = e.Node.foldNewline(a, g, s);
                  m += p, g = L, k && f.push(new e.YAMLSemanticError(this, "Multi-line single-quoted string needs to be sufficiently indented"));
                } else if (u === "'")
                  m += u, g += 1, a[g] !== "'" && f.push(new e.YAMLSyntaxError(this, "Unescaped single quote? This should not happen."));
                else if (u === " " || u === "	") {
                  let p = g, L = a[g + 1];
                  for (; L === " " || L === "	"; )
                    g += 1, L = a[g + 1];
                  L !== `
` && (m += g > p ? a.slice(p, g + 1) : u);
                } else
                  m += u;
              }
              return f.length > 0 ? { errors: f, str: m } : m;
            }
            parse(f, i) {
              this.context = f;
              let { src: t3 } = f, s = q.endOfQuote(t3, i + 1);
              return this.valueRange = new e.Range(i, s), s = e.Node.endOfWhiteSpace(t3, s), s = this.parseComment(s), s;
            }
          };
          function R(f, i) {
            switch (f) {
              case e.Type.ALIAS:
                return new S(f, i);
              case e.Type.BLOCK_FOLDED:
              case e.Type.BLOCK_LITERAL:
                return new T(f, i);
              case e.Type.FLOW_MAP:
              case e.Type.FLOW_SEQ:
                return new P(f, i);
              case e.Type.MAP_KEY:
              case e.Type.MAP_VALUE:
              case e.Type.SEQ_ITEM:
                return new c(f, i);
              case e.Type.COMMENT:
              case e.Type.PLAIN:
                return new e.PlainValue(f, i);
              case e.Type.QUOTE_DOUBLE:
                return new C(f, i);
              case e.Type.QUOTE_SINGLE:
                return new q(f, i);
              default:
                return null;
            }
          }
          var B = class {
            static parseType(f, i, t3) {
              switch (f[i]) {
                case "*":
                  return e.Type.ALIAS;
                case ">":
                  return e.Type.BLOCK_FOLDED;
                case "|":
                  return e.Type.BLOCK_LITERAL;
                case "{":
                  return e.Type.FLOW_MAP;
                case "[":
                  return e.Type.FLOW_SEQ;
                case "?":
                  return !t3 && e.Node.atBlank(f, i + 1, true) ? e.Type.MAP_KEY : e.Type.PLAIN;
                case ":":
                  return !t3 && e.Node.atBlank(f, i + 1, true) ? e.Type.MAP_VALUE : e.Type.PLAIN;
                case "-":
                  return !t3 && e.Node.atBlank(f, i + 1, true) ? e.Type.SEQ_ITEM : e.Type.PLAIN;
                case '"':
                  return e.Type.QUOTE_DOUBLE;
                case "'":
                  return e.Type.QUOTE_SINGLE;
                default:
                  return e.Type.PLAIN;
              }
            }
            constructor() {
              let f = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, { atLineStart: i, inCollection: t3, inFlow: s, indent: a, lineStart: m, parent: g } = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
              e._defineProperty(this, "parseNode", (u, p) => {
                if (e.Node.atDocumentBoundary(this.src, p))
                  return null;
                let L = new B(this, u), { props: k, type: $2, valueStart: K } = L.parseProps(p), V = R($2, k), z = V.parse(L, K);
                if (V.range = new e.Range(p, z), z <= p && (V.error = new Error("Node#parse consumed no characters"), V.error.parseEnd = z, V.error.source = V, V.range.end = p + 1), L.nodeStartsCollection(V)) {
                  !V.error && !L.atLineStart && L.parent.type === e.Type.DOCUMENT && (V.error = new e.YAMLSyntaxError(V, "Block collection must not have preceding content here (e.g. directives-end indicator)"));
                  let ae = new y(V);
                  return z = ae.parse(new B(L), z), ae.range = new e.Range(p, z), ae;
                }
                return V;
              }), this.atLineStart = i != null ? i : f.atLineStart || false, this.inCollection = t3 != null ? t3 : f.inCollection || false, this.inFlow = s != null ? s : f.inFlow || false, this.indent = a != null ? a : f.indent, this.lineStart = m != null ? m : f.lineStart, this.parent = g != null ? g : f.parent || {}, this.root = f.root, this.src = f.src;
            }
            nodeStartsCollection(f) {
              let { inCollection: i, inFlow: t3, src: s } = this;
              if (i || t3)
                return false;
              if (f instanceof c)
                return true;
              let a = f.range.end;
              return s[a] === `
` || s[a - 1] === `
` ? false : (a = e.Node.endOfWhiteSpace(s, a), s[a] === ":");
            }
            parseProps(f) {
              let { inFlow: i, parent: t3, src: s } = this, a = [], m = false;
              f = this.atLineStart ? e.Node.endOfIndent(s, f) : e.Node.endOfWhiteSpace(s, f);
              let g = s[f];
              for (; g === e.Char.ANCHOR || g === e.Char.COMMENT || g === e.Char.TAG || g === `
`; ) {
                if (g === `
`) {
                  let p = f, L;
                  do
                    L = p + 1, p = e.Node.endOfIndent(s, L);
                  while (s[p] === `
`);
                  let k = p - (L + this.indent), $2 = t3.type === e.Type.SEQ_ITEM && t3.context.atLineStart;
                  if (s[p] !== "#" && !e.Node.nextNodeIsIndented(s[p], k, !$2))
                    break;
                  this.atLineStart = true, this.lineStart = L, m = false, f = p;
                } else if (g === e.Char.COMMENT) {
                  let p = e.Node.endOfLine(s, f + 1);
                  a.push(new e.Range(f, p)), f = p;
                } else {
                  let p = e.Node.endOfIdentifier(s, f + 1);
                  g === e.Char.TAG && s[p] === "," && /^[a-zA-Z0-9-]+\.[a-zA-Z0-9-]+,\d\d\d\d(-\d\d){0,2}\/\S/.test(s.slice(f + 1, p + 13)) && (p = e.Node.endOfIdentifier(s, p + 5)), a.push(new e.Range(f, p)), m = true, f = e.Node.endOfWhiteSpace(s, p);
                }
                g = s[f];
              }
              m && g === ":" && e.Node.atBlank(s, f + 1, true) && (f -= 1);
              let u = B.parseType(s, f, i);
              return { props: a, type: u, valueStart: f };
            }
          };
          function U(f) {
            let i = [];
            f.indexOf("\r") !== -1 && (f = f.replace(/\r\n?/g, (a, m) => (a.length > 1 && i.push(m), `
`)));
            let t3 = [], s = 0;
            do {
              let a = new I(), m = new B({ src: f });
              s = a.parse(m, s), t3.push(a);
            } while (s < f.length);
            return t3.setOrigRanges = () => {
              if (i.length === 0)
                return false;
              for (let m = 1; m < i.length; ++m)
                i[m] -= m;
              let a = 0;
              for (let m = 0; m < t3.length; ++m)
                a = t3[m].setOrigRanges(i, a);
              return i.splice(0, i.length), true;
            }, t3.toString = () => t3.join(`...
`), t3;
          }
          n.parse = U;
        } }), ke = D({ "node_modules/yaml/dist/resolveSeq-d03cb037.js"(n) {
          "use strict";
          Y();
          var e = Me();
          function r(o, l, _) {
            return _ ? `#${_.replace(/[\s\S]^/gm, `$&${l}#`)}
${l}${o}` : o;
          }
          function c(o, l, _) {
            return _ ? _.indexOf(`
`) === -1 ? `${o} #${_}` : `${o}
` + _.replace(/^/gm, `${l || ""}#`) : o;
          }
          var h = class {
          };
          function d(o, l, _) {
            if (Array.isArray(o))
              return o.map((v, b) => d(v, String(b), _));
            if (o && typeof o.toJSON == "function") {
              let v = _ && _.anchors && _.anchors.get(o);
              v && (_.onCreate = (w) => {
                v.res = w, delete _.onCreate;
              });
              let b = o.toJSON(l, _);
              return v && _.onCreate && _.onCreate(b), b;
            }
            return (!_ || !_.keep) && typeof o == "bigint" ? Number(o) : o;
          }
          var y = class extends h {
            constructor(o) {
              super(), this.value = o;
            }
            toJSON(o, l) {
              return l && l.keep ? this.value : d(this.value, o, l);
            }
            toString() {
              return String(this.value);
            }
          };
          function E(o, l, _) {
            let v = _;
            for (let b = l.length - 1; b >= 0; --b) {
              let w = l[b];
              if (Number.isInteger(w) && w >= 0) {
                let A = [];
                A[w] = v, v = A;
              } else {
                let A = {};
                Object.defineProperty(A, w, { value: v, writable: true, enumerable: true, configurable: true }), v = A;
              }
            }
            return o.createNode(v, false);
          }
          var I = (o) => o == null || typeof o == "object" && o[Symbol.iterator]().next().done, S = class extends h {
            constructor(o) {
              super(), e._defineProperty(this, "items", []), this.schema = o;
            }
            addIn(o, l) {
              if (I(o))
                this.add(l);
              else {
                let [_, ...v] = o, b = this.get(_, true);
                if (b instanceof S)
                  b.addIn(v, l);
                else if (b === void 0 && this.schema)
                  this.set(_, E(this.schema, v, l));
                else
                  throw new Error(`Expected YAML collection at ${_}. Remaining path: ${v}`);
              }
            }
            deleteIn(o) {
              let [l, ..._] = o;
              if (_.length === 0)
                return this.delete(l);
              let v = this.get(l, true);
              if (v instanceof S)
                return v.deleteIn(_);
              throw new Error(`Expected YAML collection at ${l}. Remaining path: ${_}`);
            }
            getIn(o, l) {
              let [_, ...v] = o, b = this.get(_, true);
              return v.length === 0 ? !l && b instanceof y ? b.value : b : b instanceof S ? b.getIn(v, l) : void 0;
            }
            hasAllNullValues() {
              return this.items.every((o) => {
                if (!o || o.type !== "PAIR")
                  return false;
                let l = o.value;
                return l == null || l instanceof y && l.value == null && !l.commentBefore && !l.comment && !l.tag;
              });
            }
            hasIn(o) {
              let [l, ..._] = o;
              if (_.length === 0)
                return this.has(l);
              let v = this.get(l, true);
              return v instanceof S ? v.hasIn(_) : false;
            }
            setIn(o, l) {
              let [_, ...v] = o;
              if (v.length === 0)
                this.set(_, l);
              else {
                let b = this.get(_, true);
                if (b instanceof S)
                  b.setIn(v, l);
                else if (b === void 0 && this.schema)
                  this.set(_, E(this.schema, v, l));
                else
                  throw new Error(`Expected YAML collection at ${_}. Remaining path: ${v}`);
              }
            }
            toJSON() {
              return null;
            }
            toString(o, l, _, v) {
              let { blockItem: b, flowChars: w, isMap: A, itemIndent: N } = l, { indent: j, indentStep: F, stringify: Q } = o, H = this.type === e.Type.FLOW_MAP || this.type === e.Type.FLOW_SEQ || o.inFlow;
              H && (N += F);
              let oe = A && this.hasAllNullValues();
              o = Object.assign({}, o, { allNullValues: oe, indent: N, inFlow: H, type: null });
              let le = false, Z = false, ee = this.items.reduce((de, ne, he) => {
                let ce;
                ne && (!le && ne.spaceBefore && de.push({ type: "comment", str: "" }), ne.commentBefore && ne.commentBefore.match(/^.*$/gm).forEach((Ie) => {
                  de.push({ type: "comment", str: `#${Ie}` });
                }), ne.comment && (ce = ne.comment), H && (!le && ne.spaceBefore || ne.commentBefore || ne.comment || ne.key && (ne.key.commentBefore || ne.key.comment) || ne.value && (ne.value.commentBefore || ne.value.comment)) && (Z = true)), le = false;
                let fe = Q(ne, o, () => ce = null, () => le = true);
                return H && !Z && fe.includes(`
`) && (Z = true), H && he < this.items.length - 1 && (fe += ","), fe = c(fe, N, ce), le && (ce || H) && (le = false), de.push({ type: "item", str: fe }), de;
              }, []), X;
              if (ee.length === 0)
                X = w.start + w.end;
              else if (H) {
                let { start: de, end: ne } = w, he = ee.map((ce) => ce.str);
                if (Z || he.reduce((ce, fe) => ce + fe.length + 2, 2) > S.maxFlowStringSingleLineLength) {
                  X = de;
                  for (let ce of he)
                    X += ce ? `
${F}${j}${ce}` : `
`;
                  X += `
${j}${ne}`;
                } else
                  X = `${de} ${he.join(" ")} ${ne}`;
              } else {
                let de = ee.map(b);
                X = de.shift();
                for (let ne of de)
                  X += ne ? `
${j}${ne}` : `
`;
              }
              return this.comment ? (X += `
` + this.comment.replace(/^/gm, `${j}#`), _ && _()) : le && v && v(), X;
            }
          };
          e._defineProperty(S, "maxFlowStringSingleLineLength", 60);
          function M(o) {
            let l = o instanceof y ? o.value : o;
            return l && typeof l == "string" && (l = Number(l)), Number.isInteger(l) && l >= 0 ? l : null;
          }
          var T = class extends S {
            add(o) {
              this.items.push(o);
            }
            delete(o) {
              let l = M(o);
              return typeof l != "number" ? false : this.items.splice(l, 1).length > 0;
            }
            get(o, l) {
              let _ = M(o);
              if (typeof _ != "number")
                return;
              let v = this.items[_];
              return !l && v instanceof y ? v.value : v;
            }
            has(o) {
              let l = M(o);
              return typeof l == "number" && l < this.items.length;
            }
            set(o, l) {
              let _ = M(o);
              if (typeof _ != "number")
                throw new Error(`Expected a valid index, not ${o}.`);
              this.items[_] = l;
            }
            toJSON(o, l) {
              let _ = [];
              l && l.onCreate && l.onCreate(_);
              let v = 0;
              for (let b of this.items)
                _.push(d(b, String(v++), l));
              return _;
            }
            toString(o, l, _) {
              return o ? super.toString(o, { blockItem: (v) => v.type === "comment" ? v.str : `- ${v.str}`, flowChars: { start: "[", end: "]" }, isMap: false, itemIndent: (o.indent || "") + "  " }, l, _) : JSON.stringify(this);
            }
          }, P = (o, l, _) => l === null ? "" : typeof l != "object" ? String(l) : o instanceof h && _ && _.doc ? o.toString({ anchors: /* @__PURE__ */ Object.create(null), doc: _.doc, indent: "", indentStep: _.indentStep, inFlow: true, inStringifyKey: true, stringify: _.stringify }) : JSON.stringify(l), C = class extends h {
            constructor(o) {
              let l = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
              super(), this.key = o, this.value = l, this.type = C.Type.PAIR;
            }
            get commentBefore() {
              return this.key instanceof h ? this.key.commentBefore : void 0;
            }
            set commentBefore(o) {
              if (this.key == null && (this.key = new y(null)), this.key instanceof h)
                this.key.commentBefore = o;
              else {
                let l = "Pair.commentBefore is an alias for Pair.key.commentBefore. To set it, the key must be a Node.";
                throw new Error(l);
              }
            }
            addToJSMap(o, l) {
              let _ = d(this.key, "", o);
              if (l instanceof Map) {
                let v = d(this.value, _, o);
                l.set(_, v);
              } else if (l instanceof Set)
                l.add(_);
              else {
                let v = P(this.key, _, o), b = d(this.value, v, o);
                v in l ? Object.defineProperty(l, v, { value: b, writable: true, enumerable: true, configurable: true }) : l[v] = b;
              }
              return l;
            }
            toJSON(o, l) {
              let _ = l && l.mapAsMap ? /* @__PURE__ */ new Map() : {};
              return this.addToJSMap(l, _);
            }
            toString(o, l, _) {
              if (!o || !o.doc)
                return JSON.stringify(this);
              let { indent: v, indentSeq: b, simpleKeys: w } = o.doc.options, { key: A, value: N } = this, j = A instanceof h && A.comment;
              if (w) {
                if (j)
                  throw new Error("With simple keys, key nodes cannot have comments");
                if (A instanceof S) {
                  let ce = "With simple keys, collection cannot be used as a key value";
                  throw new Error(ce);
                }
              }
              let F = !w && (!A || j || (A instanceof h ? A instanceof S || A.type === e.Type.BLOCK_FOLDED || A.type === e.Type.BLOCK_LITERAL : typeof A == "object")), { doc: Q, indent: H, indentStep: oe, stringify: le } = o;
              o = Object.assign({}, o, { implicitKey: !F, indent: H + oe });
              let Z = false, ee = le(A, o, () => j = null, () => Z = true);
              if (ee = c(ee, o.indent, j), !F && ee.length > 1024) {
                if (w)
                  throw new Error("With simple keys, single line scalar must not span more than 1024 characters");
                F = true;
              }
              if (o.allNullValues && !w)
                return this.comment ? (ee = c(ee, o.indent, this.comment), l && l()) : Z && !j && _ && _(), o.inFlow && !F ? ee : `? ${ee}`;
              ee = F ? `? ${ee}
${H}:` : `${ee}:`, this.comment && (ee = c(ee, o.indent, this.comment), l && l());
              let X = "", de = null;
              if (N instanceof h) {
                if (N.spaceBefore && (X = `
`), N.commentBefore) {
                  let ce = N.commentBefore.replace(/^/gm, `${o.indent}#`);
                  X += `
${ce}`;
                }
                de = N.comment;
              } else
                N && typeof N == "object" && (N = Q.schema.createNode(N, true));
              o.implicitKey = false, !F && !this.comment && N instanceof y && (o.indentAtStart = ee.length + 1), Z = false, !b && v >= 2 && !o.inFlow && !F && N instanceof T && N.type !== e.Type.FLOW_SEQ && !N.tag && !Q.anchors.getName(N) && (o.indent = o.indent.substr(2));
              let ne = le(N, o, () => de = null, () => Z = true), he = " ";
              return X || this.comment ? he = `${X}
${o.indent}` : !F && N instanceof S ? (!(ne[0] === "[" || ne[0] === "{") || ne.includes(`
`)) && (he = `
${o.indent}`) : ne[0] === `
` && (he = ""), Z && !de && _ && _(), c(ee + he + ne, o.indent, de);
            }
          };
          e._defineProperty(C, "Type", { PAIR: "PAIR", MERGE_PAIR: "MERGE_PAIR" });
          var q = (o, l) => {
            if (o instanceof R) {
              let _ = l.get(o.source);
              return _.count * _.aliasCount;
            } else if (o instanceof S) {
              let _ = 0;
              for (let v of o.items) {
                let b = q(v, l);
                b > _ && (_ = b);
              }
              return _;
            } else if (o instanceof C) {
              let _ = q(o.key, l), v = q(o.value, l);
              return Math.max(_, v);
            }
            return 1;
          }, R = class extends h {
            static stringify(o, l) {
              let { range: _, source: v } = o, { anchors: b, doc: w, implicitKey: A, inStringifyKey: N } = l, j = Object.keys(b).find((Q) => b[Q] === v);
              if (!j && N && (j = w.anchors.getName(v) || w.anchors.newName()), j)
                return `*${j}${A ? " " : ""}`;
              let F = w.anchors.getName(v) ? "Alias node must be after source node" : "Source node not found for alias node";
              throw new Error(`${F} [${_}]`);
            }
            constructor(o) {
              super(), this.source = o, this.type = e.Type.ALIAS;
            }
            set tag(o) {
              throw new Error("Alias nodes cannot have tags");
            }
            toJSON(o, l) {
              if (!l)
                return d(this.source, o, l);
              let { anchors: _, maxAliasCount: v } = l, b = _.get(this.source);
              if (!b || b.res === void 0) {
                let w = "This should not happen: Alias anchor was not resolved?";
                throw this.cstNode ? new e.YAMLReferenceError(this.cstNode, w) : new ReferenceError(w);
              }
              if (v >= 0 && (b.count += 1, b.aliasCount === 0 && (b.aliasCount = q(this.source, _)), b.count * b.aliasCount > v)) {
                let w = "Excessive alias count indicates a resource exhaustion attack";
                throw this.cstNode ? new e.YAMLReferenceError(this.cstNode, w) : new ReferenceError(w);
              }
              return b.res;
            }
            toString(o) {
              return R.stringify(this, o);
            }
          };
          e._defineProperty(R, "default", true);
          function B(o, l) {
            let _ = l instanceof y ? l.value : l;
            for (let v of o)
              if (v instanceof C && (v.key === l || v.key === _ || v.key && v.key.value === _))
                return v;
          }
          var U = class extends S {
            add(o, l) {
              o ? o instanceof C || (o = new C(o.key || o, o.value)) : o = new C(o);
              let _ = B(this.items, o.key), v = this.schema && this.schema.sortMapEntries;
              if (_)
                if (l)
                  _.value = o.value;
                else
                  throw new Error(`Key ${o.key} already set`);
              else if (v) {
                let b = this.items.findIndex((w) => v(o, w) < 0);
                b === -1 ? this.items.push(o) : this.items.splice(b, 0, o);
              } else
                this.items.push(o);
            }
            delete(o) {
              let l = B(this.items, o);
              return l ? this.items.splice(this.items.indexOf(l), 1).length > 0 : false;
            }
            get(o, l) {
              let _ = B(this.items, o), v = _ && _.value;
              return !l && v instanceof y ? v.value : v;
            }
            has(o) {
              return !!B(this.items, o);
            }
            set(o, l) {
              this.add(new C(o, l), true);
            }
            toJSON(o, l, _) {
              let v = _ ? new _() : l && l.mapAsMap ? /* @__PURE__ */ new Map() : {};
              l && l.onCreate && l.onCreate(v);
              for (let b of this.items)
                b.addToJSMap(l, v);
              return v;
            }
            toString(o, l, _) {
              if (!o)
                return JSON.stringify(this);
              for (let v of this.items)
                if (!(v instanceof C))
                  throw new Error(`Map items must all be pairs; found ${JSON.stringify(v)} instead`);
              return super.toString(o, { blockItem: (v) => v.str, flowChars: { start: "{", end: "}" }, isMap: true, itemIndent: o.indent || "" }, l, _);
            }
          }, f = "<<", i = class extends C {
            constructor(o) {
              if (o instanceof C) {
                let l = o.value;
                l instanceof T || (l = new T(), l.items.push(o.value), l.range = o.value.range), super(o.key, l), this.range = o.range;
              } else
                super(new y(f), new T());
              this.type = C.Type.MERGE_PAIR;
            }
            addToJSMap(o, l) {
              for (let { source: _ } of this.value.items) {
                if (!(_ instanceof U))
                  throw new Error("Merge sources must be maps");
                let v = _.toJSON(null, o, Map);
                for (let [b, w] of v)
                  l instanceof Map ? l.has(b) || l.set(b, w) : l instanceof Set ? l.add(b) : Object.prototype.hasOwnProperty.call(l, b) || Object.defineProperty(l, b, { value: w, writable: true, enumerable: true, configurable: true });
              }
              return l;
            }
            toString(o, l) {
              let _ = this.value;
              if (_.items.length > 1)
                return super.toString(o, l);
              this.value = _.items[0];
              let v = super.toString(o, l);
              return this.value = _, v;
            }
          }, t3 = { defaultType: e.Type.BLOCK_LITERAL, lineWidth: 76 }, s = { trueStr: "true", falseStr: "false" }, a = { asBigInt: false }, m = { nullStr: "null" }, g = { defaultType: e.Type.PLAIN, doubleQuoted: { jsonEncoding: false, minMultiLineLength: 40 }, fold: { lineWidth: 80, minContentWidth: 20 } };
          function u(o, l, _) {
            for (let { format: v, test: b, resolve: w } of l)
              if (b) {
                let A = o.match(b);
                if (A) {
                  let N = w.apply(null, A);
                  return N instanceof y || (N = new y(N)), v && (N.format = v), N;
                }
              }
            return _ && (o = _(o)), new y(o);
          }
          var p = "flow", L = "block", k = "quoted", $2 = (o, l) => {
            let _ = o[l + 1];
            for (; _ === " " || _ === "	"; ) {
              do
                _ = o[l += 1];
              while (_ && _ !== `
`);
              _ = o[l + 1];
            }
            return l;
          };
          function K(o, l, _, v) {
            let { indentAtStart: b, lineWidth: w = 80, minContentWidth: A = 20, onFold: N, onOverflow: j } = v;
            if (!w || w < 0)
              return o;
            let F = Math.max(1 + A, 1 + w - l.length);
            if (o.length <= F)
              return o;
            let Q = [], H = {}, oe = w - l.length;
            typeof b == "number" && (b > w - Math.max(2, A) ? Q.push(0) : oe = w - b);
            let le, Z, ee = false, X = -1, de = -1, ne = -1;
            _ === L && (X = $2(o, X), X !== -1 && (oe = X + F));
            for (let ce; ce = o[X += 1]; ) {
              if (_ === k && ce === "\\") {
                switch (de = X, o[X + 1]) {
                  case "x":
                    X += 3;
                    break;
                  case "u":
                    X += 5;
                    break;
                  case "U":
                    X += 9;
                    break;
                  default:
                    X += 1;
                }
                ne = X;
              }
              if (ce === `
`)
                _ === L && (X = $2(o, X)), oe = X + F, le = void 0;
              else {
                if (ce === " " && Z && Z !== " " && Z !== `
` && Z !== "	") {
                  let fe = o[X + 1];
                  fe && fe !== " " && fe !== `
` && fe !== "	" && (le = X);
                }
                if (X >= oe)
                  if (le)
                    Q.push(le), oe = le + F, le = void 0;
                  else if (_ === k) {
                    for (; Z === " " || Z === "	"; )
                      Z = ce, ce = o[X += 1], ee = true;
                    let fe = X > ne + 1 ? X - 2 : de - 1;
                    if (H[fe])
                      return o;
                    Q.push(fe), H[fe] = true, oe = fe + F, le = void 0;
                  } else
                    ee = true;
              }
              Z = ce;
            }
            if (ee && j && j(), Q.length === 0)
              return o;
            N && N();
            let he = o.slice(0, Q[0]);
            for (let ce = 0; ce < Q.length; ++ce) {
              let fe = Q[ce], Ie = Q[ce + 1] || o.length;
              fe === 0 ? he = `
${l}${o.slice(0, Ie)}` : (_ === k && H[fe] && (he += `${o[fe]}\\`), he += `
${l}${o.slice(fe + 1, Ie)}`);
            }
            return he;
          }
          var V = (o) => {
            let { indentAtStart: l } = o;
            return l ? Object.assign({ indentAtStart: l }, g.fold) : g.fold;
          }, z = (o) => /^(%|---|\.\.\.)/m.test(o);
          function ae(o, l, _) {
            if (!l || l < 0)
              return false;
            let v = l - _, b = o.length;
            if (b <= v)
              return false;
            for (let w = 0, A = 0; w < b; ++w)
              if (o[w] === `
`) {
                if (w - A > v)
                  return true;
                if (A = w + 1, b - A <= v)
                  return false;
              }
            return true;
          }
          function ue(o, l) {
            let { implicitKey: _ } = l, { jsonEncoding: v, minMultiLineLength: b } = g.doubleQuoted, w = JSON.stringify(o);
            if (v)
              return w;
            let A = l.indent || (z(o) ? "  " : ""), N = "", j = 0;
            for (let F = 0, Q = w[F]; Q; Q = w[++F])
              if (Q === " " && w[F + 1] === "\\" && w[F + 2] === "n" && (N += w.slice(j, F) + "\\ ", F += 1, j = F, Q = "\\"), Q === "\\")
                switch (w[F + 1]) {
                  case "u":
                    {
                      N += w.slice(j, F);
                      let H = w.substr(F + 2, 4);
                      switch (H) {
                        case "0000":
                          N += "\\0";
                          break;
                        case "0007":
                          N += "\\a";
                          break;
                        case "000b":
                          N += "\\v";
                          break;
                        case "001b":
                          N += "\\e";
                          break;
                        case "0085":
                          N += "\\N";
                          break;
                        case "00a0":
                          N += "\\_";
                          break;
                        case "2028":
                          N += "\\L";
                          break;
                        case "2029":
                          N += "\\P";
                          break;
                        default:
                          H.substr(0, 2) === "00" ? N += "\\x" + H.substr(2) : N += w.substr(F, 6);
                      }
                      F += 5, j = F + 1;
                    }
                    break;
                  case "n":
                    if (_ || w[F + 2] === '"' || w.length < b)
                      F += 1;
                    else {
                      for (N += w.slice(j, F) + `

`; w[F + 2] === "\\" && w[F + 3] === "n" && w[F + 4] !== '"'; )
                        N += `
`, F += 2;
                      N += A, w[F + 2] === " " && (N += "\\"), F += 1, j = F + 1;
                    }
                    break;
                  default:
                    F += 1;
                }
            return N = j ? N + w.slice(j) : w, _ ? N : K(N, A, k, V(l));
          }
          function pe(o, l) {
            if (l.implicitKey) {
              if (/\n/.test(o))
                return ue(o, l);
            } else if (/[ \t]\n|\n[ \t]/.test(o))
              return ue(o, l);
            let _ = l.indent || (z(o) ? "  " : ""), v = "'" + o.replace(/'/g, "''").replace(/\n+/g, `$&
${_}`) + "'";
            return l.implicitKey ? v : K(v, _, p, V(l));
          }
          function ge(o, l, _, v) {
            let { comment: b, type: w, value: A } = o;
            if (/\n[\t ]+$/.test(A) || /^\s*$/.test(A))
              return ue(A, l);
            let N = l.indent || (l.forceBlockIndent || z(A) ? "  " : ""), j = N ? "2" : "1", F = w === e.Type.BLOCK_FOLDED ? false : w === e.Type.BLOCK_LITERAL ? true : !ae(A, g.fold.lineWidth, N.length), Q = F ? "|" : ">";
            if (!A)
              return Q + `
`;
            let H = "", oe = "";
            if (A = A.replace(/[\n\t ]*$/, (Z) => {
              let ee = Z.indexOf(`
`);
              return ee === -1 ? Q += "-" : (A === Z || ee !== Z.length - 1) && (Q += "+", v && v()), oe = Z.replace(/\n$/, ""), "";
            }).replace(/^[\n ]*/, (Z) => {
              Z.indexOf(" ") !== -1 && (Q += j);
              let ee = Z.match(/ +$/);
              return ee ? (H = Z.slice(0, -ee[0].length), ee[0]) : (H = Z, "");
            }), oe && (oe = oe.replace(/\n+(?!\n|$)/g, `$&${N}`)), H && (H = H.replace(/\n+/g, `$&${N}`)), b && (Q += " #" + b.replace(/ ?[\r\n]+/g, " "), _ && _()), !A)
              return `${Q}${j}
${N}${oe}`;
            if (F)
              return A = A.replace(/\n+/g, `$&${N}`), `${Q}
${N}${H}${A}${oe}`;
            A = A.replace(/\n+/g, `
$&`).replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g, "$1$2").replace(/\n+/g, `$&${N}`);
            let le = K(`${H}${A}${oe}`, N, L, g.fold);
            return `${Q}
${N}${le}`;
          }
          function O(o, l, _, v) {
            let { comment: b, type: w, value: A } = o, { actualString: N, implicitKey: j, indent: F, inFlow: Q } = l;
            if (j && /[\n[\]{},]/.test(A) || Q && /[[\]{},]/.test(A))
              return ue(A, l);
            if (!A || /^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(A))
              return j || Q || A.indexOf(`
`) === -1 ? A.indexOf('"') !== -1 && A.indexOf("'") === -1 ? pe(A, l) : ue(A, l) : ge(o, l, _, v);
            if (!j && !Q && w !== e.Type.PLAIN && A.indexOf(`
`) !== -1)
              return ge(o, l, _, v);
            if (F === "" && z(A))
              return l.forceBlockIndent = true, ge(o, l, _, v);
            let H = A.replace(/\n+/g, `$&
${F}`);
            if (N) {
              let { tags: le } = l.doc.schema;
              if (typeof u(H, le, le.scalarFallback).value != "string")
                return ue(A, l);
            }
            let oe = j ? H : K(H, F, p, V(l));
            return b && !Q && (oe.indexOf(`
`) !== -1 || b.indexOf(`
`) !== -1) ? (_ && _(), r(oe, F, b)) : oe;
          }
          function W(o, l, _, v) {
            let { defaultType: b } = g, { implicitKey: w, inFlow: A } = l, { type: N, value: j } = o;
            typeof j != "string" && (j = String(j), o = Object.assign({}, o, { value: j }));
            let F = (H) => {
              switch (H) {
                case e.Type.BLOCK_FOLDED:
                case e.Type.BLOCK_LITERAL:
                  return ge(o, l, _, v);
                case e.Type.QUOTE_DOUBLE:
                  return ue(j, l);
                case e.Type.QUOTE_SINGLE:
                  return pe(j, l);
                case e.Type.PLAIN:
                  return O(o, l, _, v);
                default:
                  return null;
              }
            };
            (N !== e.Type.QUOTE_DOUBLE && /[\x00-\x08\x0b-\x1f\x7f-\x9f]/.test(j) || (w || A) && (N === e.Type.BLOCK_FOLDED || N === e.Type.BLOCK_LITERAL)) && (N = e.Type.QUOTE_DOUBLE);
            let Q = F(N);
            if (Q === null && (Q = F(b), Q === null))
              throw new Error(`Unsupported default string type ${b}`);
            return Q;
          }
          function J(o) {
            let { format: l, minFractionDigits: _, tag: v, value: b } = o;
            if (typeof b == "bigint")
              return String(b);
            if (!isFinite(b))
              return isNaN(b) ? ".nan" : b < 0 ? "-.inf" : ".inf";
            let w = JSON.stringify(b);
            if (!l && _ && (!v || v === "tag:yaml.org,2002:float") && /^\d/.test(w)) {
              let A = w.indexOf(".");
              A < 0 && (A = w.length, w += ".");
              let N = _ - (w.length - A - 1);
              for (; N-- > 0; )
                w += "0";
            }
            return w;
          }
          function x(o, l) {
            let _, v;
            switch (l.type) {
              case e.Type.FLOW_MAP:
                _ = "}", v = "flow map";
                break;
              case e.Type.FLOW_SEQ:
                _ = "]", v = "flow sequence";
                break;
              default:
                o.push(new e.YAMLSemanticError(l, "Not a flow collection!?"));
                return;
            }
            let b;
            for (let w = l.items.length - 1; w >= 0; --w) {
              let A = l.items[w];
              if (!A || A.type !== e.Type.COMMENT) {
                b = A;
                break;
              }
            }
            if (b && b.char !== _) {
              let w = `Expected ${v} to end with ${_}`, A;
              typeof b.offset == "number" ? (A = new e.YAMLSemanticError(l, w), A.offset = b.offset + 1) : (A = new e.YAMLSemanticError(b, w), b.range && b.range.end && (A.offset = b.range.end - b.range.start)), o.push(A);
            }
          }
          function G(o, l) {
            let _ = l.context.src[l.range.start - 1];
            if (_ !== `
` && _ !== "	" && _ !== " ") {
              let v = "Comments must be separated from other tokens by white space characters";
              o.push(new e.YAMLSemanticError(l, v));
            }
          }
          function re(o, l) {
            let _ = String(l), v = _.substr(0, 8) + "..." + _.substr(-8);
            return new e.YAMLSemanticError(o, `The "${v}" key is too long`);
          }
          function _e(o, l) {
            for (let { afterKey: _, before: v, comment: b } of l) {
              let w = o.items[v];
              w ? (_ && w.value && (w = w.value), b === void 0 ? (_ || !w.commentBefore) && (w.spaceBefore = true) : w.commentBefore ? w.commentBefore += `
` + b : w.commentBefore = b) : b !== void 0 && (o.comment ? o.comment += `
` + b : o.comment = b);
            }
          }
          function ye(o, l) {
            let _ = l.strValue;
            return _ ? typeof _ == "string" ? _ : (_.errors.forEach((v) => {
              v.source || (v.source = l), o.errors.push(v);
            }), _.str) : "";
          }
          function be(o, l) {
            let { handle: _, suffix: v } = l.tag, b = o.tagPrefixes.find((w) => w.handle === _);
            if (!b) {
              let w = o.getDefaults().tagPrefixes;
              if (w && (b = w.find((A) => A.handle === _)), !b)
                throw new e.YAMLSemanticError(l, `The ${_} tag handle is non-default and was not declared.`);
            }
            if (!v)
              throw new e.YAMLSemanticError(l, `The ${_} tag has no suffix.`);
            if (_ === "!" && (o.version || o.options.version) === "1.0") {
              if (v[0] === "^")
                return o.warnings.push(new e.YAMLWarning(l, "YAML 1.0 ^ tag expansion is not supported")), v;
              if (/[:/]/.test(v)) {
                let w = v.match(/^([a-z0-9-]+)\/(.*)/i);
                return w ? `tag:${w[1]}.yaml.org,2002:${w[2]}` : `tag:${v}`;
              }
            }
            return b.prefix + decodeURIComponent(v);
          }
          function ve(o, l) {
            let { tag: _, type: v } = l, b = false;
            if (_) {
              let { handle: w, suffix: A, verbatim: N } = _;
              if (N) {
                if (N !== "!" && N !== "!!")
                  return N;
                let j = `Verbatim tags aren't resolved, so ${N} is invalid.`;
                o.errors.push(new e.YAMLSemanticError(l, j));
              } else if (w === "!" && !A)
                b = true;
              else
                try {
                  return be(o, l);
                } catch (j) {
                  o.errors.push(j);
                }
            }
            switch (v) {
              case e.Type.BLOCK_FOLDED:
              case e.Type.BLOCK_LITERAL:
              case e.Type.QUOTE_DOUBLE:
              case e.Type.QUOTE_SINGLE:
                return e.defaultTags.STR;
              case e.Type.FLOW_MAP:
              case e.Type.MAP:
                return e.defaultTags.MAP;
              case e.Type.FLOW_SEQ:
              case e.Type.SEQ:
                return e.defaultTags.SEQ;
              case e.Type.PLAIN:
                return b ? e.defaultTags.STR : null;
              default:
                return null;
            }
          }
          function Ne(o, l, _) {
            let { tags: v } = o.schema, b = [];
            for (let A of v)
              if (A.tag === _)
                if (A.test)
                  b.push(A);
                else {
                  let N = A.resolve(o, l);
                  return N instanceof S ? N : new y(N);
                }
            let w = ye(o, l);
            return typeof w == "string" && b.length > 0 ? u(w, b, v.scalarFallback) : null;
          }
          function Pe(o) {
            let { type: l } = o;
            switch (l) {
              case e.Type.FLOW_MAP:
              case e.Type.MAP:
                return e.defaultTags.MAP;
              case e.Type.FLOW_SEQ:
              case e.Type.SEQ:
                return e.defaultTags.SEQ;
              default:
                return e.defaultTags.STR;
            }
          }
          function ot(o, l, _) {
            try {
              let v = Ne(o, l, _);
              if (v)
                return _ && l.tag && (v.tag = _), v;
            } catch (v) {
              return v.source || (v.source = l), o.errors.push(v), null;
            }
            try {
              let v = Pe(l);
              if (!v)
                throw new Error(`The tag ${_} is unavailable`);
              let b = `The tag ${_} is unavailable, falling back to ${v}`;
              o.warnings.push(new e.YAMLWarning(l, b));
              let w = Ne(o, l, v);
              return w.tag = _, w;
            } catch (v) {
              let b = new e.YAMLReferenceError(l, v.message);
              return b.stack = v.stack, o.errors.push(b), null;
            }
          }
          var lt = (o) => {
            if (!o)
              return false;
            let { type: l } = o;
            return l === e.Type.MAP_KEY || l === e.Type.MAP_VALUE || l === e.Type.SEQ_ITEM;
          };
          function ct(o, l) {
            let _ = { before: [], after: [] }, v = false, b = false, w = lt(l.context.parent) ? l.context.parent.props.concat(l.props) : l.props;
            for (let { start: A, end: N } of w)
              switch (l.context.src[A]) {
                case e.Char.COMMENT: {
                  if (!l.commentHasRequiredWhitespace(A)) {
                    let H = "Comments must be separated from other tokens by white space characters";
                    o.push(new e.YAMLSemanticError(l, H));
                  }
                  let { header: j, valueRange: F } = l;
                  (F && (A > F.start || j && A > j.start) ? _.after : _.before).push(l.context.src.slice(A + 1, N));
                  break;
                }
                case e.Char.ANCHOR:
                  if (v) {
                    let j = "A node can have at most one anchor";
                    o.push(new e.YAMLSemanticError(l, j));
                  }
                  v = true;
                  break;
                case e.Char.TAG:
                  if (b) {
                    let j = "A node can have at most one tag";
                    o.push(new e.YAMLSemanticError(l, j));
                  }
                  b = true;
                  break;
              }
            return { comments: _, hasAnchor: v, hasTag: b };
          }
          function ut(o, l) {
            let { anchors: _, errors: v, schema: b } = o;
            if (l.type === e.Type.ALIAS) {
              let A = l.rawValue, N = _.getNode(A);
              if (!N) {
                let F = `Aliased anchor not found: ${A}`;
                return v.push(new e.YAMLReferenceError(l, F)), null;
              }
              let j = new R(N);
              return _._cstAliases.push(j), j;
            }
            let w = ve(o, l);
            if (w)
              return ot(o, l, w);
            if (l.type !== e.Type.PLAIN) {
              let A = `Failed to resolve ${l.type} node here`;
              return v.push(new e.YAMLSyntaxError(l, A)), null;
            }
            try {
              let A = ye(o, l);
              return u(A, b.tags, b.tags.scalarFallback);
            } catch (A) {
              return A.source || (A.source = l), v.push(A), null;
            }
          }
          function we(o, l) {
            if (!l)
              return null;
            l.error && o.errors.push(l.error);
            let { comments: _, hasAnchor: v, hasTag: b } = ct(o.errors, l);
            if (v) {
              let { anchors: A } = o, N = l.anchor, j = A.getNode(N);
              j && (A.map[A.newName(N)] = j), A.map[N] = l;
            }
            if (l.type === e.Type.ALIAS && (v || b)) {
              let A = "An alias node must not specify any properties";
              o.errors.push(new e.YAMLSemanticError(l, A));
            }
            let w = ut(o, l);
            if (w) {
              w.range = [l.range.start, l.range.end], o.options.keepCstNodes && (w.cstNode = l), o.options.keepNodeTypes && (w.type = l.type);
              let A = _.before.join(`
`);
              A && (w.commentBefore = w.commentBefore ? `${w.commentBefore}
${A}` : A);
              let N = _.after.join(`
`);
              N && (w.comment = w.comment ? `${w.comment}
${N}` : N);
            }
            return l.resolved = w;
          }
          function ft(o, l) {
            if (l.type !== e.Type.MAP && l.type !== e.Type.FLOW_MAP) {
              let A = `A ${l.type} node cannot be resolved as a mapping`;
              return o.errors.push(new e.YAMLSyntaxError(l, A)), null;
            }
            let { comments: _, items: v } = l.type === e.Type.FLOW_MAP ? gt(o, l) : ht(o, l), b = new U();
            b.items = v, _e(b, _);
            let w = false;
            for (let A = 0; A < v.length; ++A) {
              let { key: N } = v[A];
              if (N instanceof S && (w = true), o.schema.merge && N && N.value === f) {
                v[A] = new i(v[A]);
                let j = v[A].value.items, F = null;
                j.some((Q) => {
                  if (Q instanceof R) {
                    let { type: H } = Q.source;
                    return H === e.Type.MAP || H === e.Type.FLOW_MAP ? false : F = "Merge nodes aliases can only point to maps";
                  }
                  return F = "Merge nodes can only have Alias nodes as values";
                }), F && o.errors.push(new e.YAMLSemanticError(l, F));
              } else
                for (let j = A + 1; j < v.length; ++j) {
                  let { key: F } = v[j];
                  if (N === F || N && F && Object.prototype.hasOwnProperty.call(N, "value") && N.value === F.value) {
                    let Q = `Map keys must be unique; "${N}" is repeated`;
                    o.errors.push(new e.YAMLSemanticError(l, Q));
                    break;
                  }
                }
            }
            if (w && !o.options.mapAsMap) {
              let A = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
              o.warnings.push(new e.YAMLWarning(l, A));
            }
            return l.resolved = b, b;
          }
          var mt = (o) => {
            let { context: { lineStart: l, node: _, src: v }, props: b } = o;
            if (b.length === 0)
              return false;
            let { start: w } = b[0];
            if (_ && w > _.valueRange.start || v[w] !== e.Char.COMMENT)
              return false;
            for (let A = l; A < w; ++A)
              if (v[A] === `
`)
                return false;
            return true;
          };
          function dt(o, l) {
            if (!mt(o))
              return;
            let _ = o.getPropValue(0, e.Char.COMMENT, true), v = false, b = l.value.commentBefore;
            if (b && b.startsWith(_))
              l.value.commentBefore = b.substr(_.length + 1), v = true;
            else {
              let w = l.value.comment;
              !o.node && w && w.startsWith(_) && (l.value.comment = w.substr(_.length + 1), v = true);
            }
            v && (l.comment = _);
          }
          function ht(o, l) {
            let _ = [], v = [], b, w = null;
            for (let A = 0; A < l.items.length; ++A) {
              let N = l.items[A];
              switch (N.type) {
                case e.Type.BLANK_LINE:
                  _.push({ afterKey: !!b, before: v.length });
                  break;
                case e.Type.COMMENT:
                  _.push({ afterKey: !!b, before: v.length, comment: N.comment });
                  break;
                case e.Type.MAP_KEY:
                  b !== void 0 && v.push(new C(b)), N.error && o.errors.push(N.error), b = we(o, N.node), w = null;
                  break;
                case e.Type.MAP_VALUE:
                  {
                    if (b === void 0 && (b = null), N.error && o.errors.push(N.error), !N.context.atLineStart && N.node && N.node.type === e.Type.MAP && !N.node.context.atLineStart) {
                      let Q = "Nested mappings are not allowed in compact mappings";
                      o.errors.push(new e.YAMLSemanticError(N.node, Q));
                    }
                    let j = N.node;
                    if (!j && N.props.length > 0) {
                      j = new e.PlainValue(e.Type.PLAIN, []), j.context = { parent: N, src: N.context.src };
                      let Q = N.range.start + 1;
                      if (j.range = { start: Q, end: Q }, j.valueRange = { start: Q, end: Q }, typeof N.range.origStart == "number") {
                        let H = N.range.origStart + 1;
                        j.range.origStart = j.range.origEnd = H, j.valueRange.origStart = j.valueRange.origEnd = H;
                      }
                    }
                    let F = new C(b, we(o, j));
                    dt(N, F), v.push(F), b && typeof w == "number" && N.range.start > w + 1024 && o.errors.push(re(l, b)), b = void 0, w = null;
                  }
                  break;
                default:
                  b !== void 0 && v.push(new C(b)), b = we(o, N), w = N.range.start, N.error && o.errors.push(N.error);
                  e:
                    for (let j = A + 1; ; ++j) {
                      let F = l.items[j];
                      switch (F && F.type) {
                        case e.Type.BLANK_LINE:
                        case e.Type.COMMENT:
                          continue e;
                        case e.Type.MAP_VALUE:
                          break e;
                        default: {
                          let Q = "Implicit map keys need to be followed by map values";
                          o.errors.push(new e.YAMLSemanticError(N, Q));
                          break e;
                        }
                      }
                    }
                  if (N.valueRangeContainsNewline) {
                    let j = "Implicit map keys need to be on a single line";
                    o.errors.push(new e.YAMLSemanticError(N, j));
                  }
              }
            }
            return b !== void 0 && v.push(new C(b)), { comments: _, items: v };
          }
          function gt(o, l) {
            let _ = [], v = [], b, w = false, A = "{";
            for (let N = 0; N < l.items.length; ++N) {
              let j = l.items[N];
              if (typeof j.char == "string") {
                let { char: F, offset: Q } = j;
                if (F === "?" && b === void 0 && !w) {
                  w = true, A = ":";
                  continue;
                }
                if (F === ":") {
                  if (b === void 0 && (b = null), A === ":") {
                    A = ",";
                    continue;
                  }
                } else if (w && (b === void 0 && F !== "," && (b = null), w = false), b !== void 0 && (v.push(new C(b)), b = void 0, F === ",")) {
                  A = ":";
                  continue;
                }
                if (F === "}") {
                  if (N === l.items.length - 1)
                    continue;
                } else if (F === A) {
                  A = ":";
                  continue;
                }
                let H = `Flow map contains an unexpected ${F}`, oe = new e.YAMLSyntaxError(l, H);
                oe.offset = Q, o.errors.push(oe);
              } else
                j.type === e.Type.BLANK_LINE ? _.push({ afterKey: !!b, before: v.length }) : j.type === e.Type.COMMENT ? (G(o.errors, j), _.push({ afterKey: !!b, before: v.length, comment: j.comment })) : b === void 0 ? (A === "," && o.errors.push(new e.YAMLSemanticError(j, "Separator , missing in flow map")), b = we(o, j)) : (A !== "," && o.errors.push(new e.YAMLSemanticError(j, "Indicator : missing in flow map entry")), v.push(new C(b, we(o, j))), b = void 0, w = false);
            }
            return x(o.errors, l), b !== void 0 && v.push(new C(b)), { comments: _, items: v };
          }
          function pt(o, l) {
            if (l.type !== e.Type.SEQ && l.type !== e.Type.FLOW_SEQ) {
              let w = `A ${l.type} node cannot be resolved as a sequence`;
              return o.errors.push(new e.YAMLSyntaxError(l, w)), null;
            }
            let { comments: _, items: v } = l.type === e.Type.FLOW_SEQ ? vt(o, l) : _t(o, l), b = new T();
            if (b.items = v, _e(b, _), !o.options.mapAsMap && v.some((w) => w instanceof C && w.key instanceof S)) {
              let w = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
              o.warnings.push(new e.YAMLWarning(l, w));
            }
            return l.resolved = b, b;
          }
          function _t(o, l) {
            let _ = [], v = [];
            for (let b = 0; b < l.items.length; ++b) {
              let w = l.items[b];
              switch (w.type) {
                case e.Type.BLANK_LINE:
                  _.push({ before: v.length });
                  break;
                case e.Type.COMMENT:
                  _.push({ comment: w.comment, before: v.length });
                  break;
                case e.Type.SEQ_ITEM:
                  if (w.error && o.errors.push(w.error), v.push(we(o, w.node)), w.hasProps) {
                    let A = "Sequence items cannot have tags or anchors before the - indicator";
                    o.errors.push(new e.YAMLSemanticError(w, A));
                  }
                  break;
                default:
                  w.error && o.errors.push(w.error), o.errors.push(new e.YAMLSyntaxError(w, `Unexpected ${w.type} node in sequence`));
              }
            }
            return { comments: _, items: v };
          }
          function vt(o, l) {
            let _ = [], v = [], b = false, w, A = null, N = "[", j = null;
            for (let F = 0; F < l.items.length; ++F) {
              let Q = l.items[F];
              if (typeof Q.char == "string") {
                let { char: H, offset: oe } = Q;
                if (H !== ":" && (b || w !== void 0) && (b && w === void 0 && (w = N ? v.pop() : null), v.push(new C(w)), b = false, w = void 0, A = null), H === N)
                  N = null;
                else if (!N && H === "?")
                  b = true;
                else if (N !== "[" && H === ":" && w === void 0) {
                  if (N === ",") {
                    if (w = v.pop(), w instanceof C) {
                      let le = "Chaining flow sequence pairs is invalid", Z = new e.YAMLSemanticError(l, le);
                      Z.offset = oe, o.errors.push(Z);
                    }
                    if (!b && typeof A == "number") {
                      let le = Q.range ? Q.range.start : Q.offset;
                      le > A + 1024 && o.errors.push(re(l, w));
                      let { src: Z } = j.context;
                      for (let ee = A; ee < le; ++ee)
                        if (Z[ee] === `
`) {
                          let X = "Implicit keys of flow sequence pairs need to be on a single line";
                          o.errors.push(new e.YAMLSemanticError(j, X));
                          break;
                        }
                    }
                  } else
                    w = null;
                  A = null, b = false, N = null;
                } else if (N === "[" || H !== "]" || F < l.items.length - 1) {
                  let le = `Flow sequence contains an unexpected ${H}`, Z = new e.YAMLSyntaxError(l, le);
                  Z.offset = oe, o.errors.push(Z);
                }
              } else if (Q.type === e.Type.BLANK_LINE)
                _.push({ before: v.length });
              else if (Q.type === e.Type.COMMENT)
                G(o.errors, Q), _.push({ comment: Q.comment, before: v.length });
              else {
                if (N) {
                  let oe = `Expected a ${N} in flow sequence`;
                  o.errors.push(new e.YAMLSemanticError(Q, oe));
                }
                let H = we(o, Q);
                w === void 0 ? (v.push(H), j = Q) : (v.push(new C(w, H)), w = void 0), A = Q.range.start, N = ",";
              }
            }
            return x(o.errors, l), w !== void 0 && v.push(new C(w)), { comments: _, items: v };
          }
          n.Alias = R, n.Collection = S, n.Merge = i, n.Node = h, n.Pair = C, n.Scalar = y, n.YAMLMap = U, n.YAMLSeq = T, n.addComment = c, n.binaryOptions = t3, n.boolOptions = s, n.findPair = B, n.intOptions = a, n.isEmptyPath = I, n.nullOptions = m, n.resolveMap = ft, n.resolveNode = we, n.resolveSeq = pt, n.resolveString = ye, n.strOptions = g, n.stringifyNumber = J, n.stringifyString = W, n.toJSON = d;
        } }), st = D({ "node_modules/yaml/dist/warnings-1000a372.js"(n) {
          "use strict";
          Y();
          var e = Me(), r = ke(), c = { identify: (u) => u instanceof Uint8Array, default: false, tag: "tag:yaml.org,2002:binary", resolve: (u, p) => {
            let L = r.resolveString(u, p);
            if (typeof Buffer == "function")
              return Buffer.from(L, "base64");
            if (typeof atob == "function") {
              let k = atob(L.replace(/[\n\r]/g, "")), $2 = new Uint8Array(k.length);
              for (let K = 0; K < k.length; ++K)
                $2[K] = k.charCodeAt(K);
              return $2;
            } else {
              let k = "This environment does not support reading binary tags; either Buffer or atob is required";
              return u.errors.push(new e.YAMLReferenceError(p, k)), null;
            }
          }, options: r.binaryOptions, stringify: (u, p, L, k) => {
            let { comment: $2, type: K, value: V } = u, z;
            if (typeof Buffer == "function")
              z = V instanceof Buffer ? V.toString("base64") : Buffer.from(V.buffer).toString("base64");
            else if (typeof btoa == "function") {
              let ae = "";
              for (let ue = 0; ue < V.length; ++ue)
                ae += String.fromCharCode(V[ue]);
              z = btoa(ae);
            } else
              throw new Error("This environment does not support writing binary tags; either Buffer or btoa is required");
            if (K || (K = r.binaryOptions.defaultType), K === e.Type.QUOTE_DOUBLE)
              V = z;
            else {
              let { lineWidth: ae } = r.binaryOptions, ue = Math.ceil(z.length / ae), pe = new Array(ue);
              for (let ge = 0, O = 0; ge < ue; ++ge, O += ae)
                pe[ge] = z.substr(O, ae);
              V = pe.join(K === e.Type.BLOCK_LITERAL ? `
` : " ");
            }
            return r.stringifyString({ comment: $2, type: K, value: V }, p, L, k);
          } };
          function h(u, p) {
            let L = r.resolveSeq(u, p);
            for (let k = 0; k < L.items.length; ++k) {
              let $2 = L.items[k];
              if (!($2 instanceof r.Pair)) {
                if ($2 instanceof r.YAMLMap) {
                  if ($2.items.length > 1) {
                    let V = "Each pair must have its own sequence indicator";
                    throw new e.YAMLSemanticError(p, V);
                  }
                  let K = $2.items[0] || new r.Pair();
                  $2.commentBefore && (K.commentBefore = K.commentBefore ? `${$2.commentBefore}
${K.commentBefore}` : $2.commentBefore), $2.comment && (K.comment = K.comment ? `${$2.comment}
${K.comment}` : $2.comment), $2 = K;
                }
                L.items[k] = $2 instanceof r.Pair ? $2 : new r.Pair($2);
              }
            }
            return L;
          }
          function d(u, p, L) {
            let k = new r.YAMLSeq(u);
            k.tag = "tag:yaml.org,2002:pairs";
            for (let $2 of p) {
              let K, V;
              if (Array.isArray($2))
                if ($2.length === 2)
                  K = $2[0], V = $2[1];
                else
                  throw new TypeError(`Expected [key, value] tuple: ${$2}`);
              else if ($2 && $2 instanceof Object) {
                let ae = Object.keys($2);
                if (ae.length === 1)
                  K = ae[0], V = $2[K];
                else
                  throw new TypeError(`Expected { key: value } tuple: ${$2}`);
              } else
                K = $2;
              let z = u.createPair(K, V, L);
              k.items.push(z);
            }
            return k;
          }
          var y = { default: false, tag: "tag:yaml.org,2002:pairs", resolve: h, createNode: d }, E = class extends r.YAMLSeq {
            constructor() {
              super(), e._defineProperty(this, "add", r.YAMLMap.prototype.add.bind(this)), e._defineProperty(this, "delete", r.YAMLMap.prototype.delete.bind(this)), e._defineProperty(this, "get", r.YAMLMap.prototype.get.bind(this)), e._defineProperty(this, "has", r.YAMLMap.prototype.has.bind(this)), e._defineProperty(this, "set", r.YAMLMap.prototype.set.bind(this)), this.tag = E.tag;
            }
            toJSON(u, p) {
              let L = /* @__PURE__ */ new Map();
              p && p.onCreate && p.onCreate(L);
              for (let k of this.items) {
                let $2, K;
                if (k instanceof r.Pair ? ($2 = r.toJSON(k.key, "", p), K = r.toJSON(k.value, $2, p)) : $2 = r.toJSON(k, "", p), L.has($2))
                  throw new Error("Ordered maps must not include duplicate keys");
                L.set($2, K);
              }
              return L;
            }
          };
          e._defineProperty(E, "tag", "tag:yaml.org,2002:omap");
          function I(u, p) {
            let L = h(u, p), k = [];
            for (let { key: $2 } of L.items)
              if ($2 instanceof r.Scalar)
                if (k.includes($2.value)) {
                  let K = "Ordered maps must not include duplicate keys";
                  throw new e.YAMLSemanticError(p, K);
                } else
                  k.push($2.value);
            return Object.assign(new E(), L);
          }
          function S(u, p, L) {
            let k = d(u, p, L), $2 = new E();
            return $2.items = k.items, $2;
          }
          var M = { identify: (u) => u instanceof Map, nodeClass: E, default: false, tag: "tag:yaml.org,2002:omap", resolve: I, createNode: S }, T = class extends r.YAMLMap {
            constructor() {
              super(), this.tag = T.tag;
            }
            add(u) {
              let p = u instanceof r.Pair ? u : new r.Pair(u);
              r.findPair(this.items, p.key) || this.items.push(p);
            }
            get(u, p) {
              let L = r.findPair(this.items, u);
              return !p && L instanceof r.Pair ? L.key instanceof r.Scalar ? L.key.value : L.key : L;
            }
            set(u, p) {
              if (typeof p != "boolean")
                throw new Error(`Expected boolean value for set(key, value) in a YAML set, not ${typeof p}`);
              let L = r.findPair(this.items, u);
              L && !p ? this.items.splice(this.items.indexOf(L), 1) : !L && p && this.items.push(new r.Pair(u));
            }
            toJSON(u, p) {
              return super.toJSON(u, p, Set);
            }
            toString(u, p, L) {
              if (!u)
                return JSON.stringify(this);
              if (this.hasAllNullValues())
                return super.toString(u, p, L);
              throw new Error("Set items must all have null values");
            }
          };
          e._defineProperty(T, "tag", "tag:yaml.org,2002:set");
          function P(u, p) {
            let L = r.resolveMap(u, p);
            if (!L.hasAllNullValues())
              throw new e.YAMLSemanticError(p, "Set items must all have null values");
            return Object.assign(new T(), L);
          }
          function C(u, p, L) {
            let k = new T();
            for (let $2 of p)
              k.items.push(u.createPair($2, null, L));
            return k;
          }
          var q = { identify: (u) => u instanceof Set, nodeClass: T, default: false, tag: "tag:yaml.org,2002:set", resolve: P, createNode: C }, R = (u, p) => {
            let L = p.split(":").reduce((k, $2) => k * 60 + Number($2), 0);
            return u === "-" ? -L : L;
          }, B = (u) => {
            let { value: p } = u;
            if (isNaN(p) || !isFinite(p))
              return r.stringifyNumber(p);
            let L = "";
            p < 0 && (L = "-", p = Math.abs(p));
            let k = [p % 60];
            return p < 60 ? k.unshift(0) : (p = Math.round((p - k[0]) / 60), k.unshift(p % 60), p >= 60 && (p = Math.round((p - k[0]) / 60), k.unshift(p))), L + k.map(($2) => $2 < 10 ? "0" + String($2) : String($2)).join(":").replace(/000000\d*$/, "");
          }, U = { identify: (u) => typeof u == "number", default: true, tag: "tag:yaml.org,2002:int", format: "TIME", test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+)$/, resolve: (u, p, L) => R(p, L.replace(/_/g, "")), stringify: B }, f = { identify: (u) => typeof u == "number", default: true, tag: "tag:yaml.org,2002:float", format: "TIME", test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*)$/, resolve: (u, p, L) => R(p, L.replace(/_/g, "")), stringify: B }, i = { identify: (u) => u instanceof Date, default: true, tag: "tag:yaml.org,2002:timestamp", test: RegExp("^(?:([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?)$"), resolve: (u, p, L, k, $2, K, V, z, ae) => {
            z && (z = (z + "00").substr(1, 3));
            let ue = Date.UTC(p, L - 1, k, $2 || 0, K || 0, V || 0, z || 0);
            if (ae && ae !== "Z") {
              let pe = R(ae[0], ae.slice(1));
              Math.abs(pe) < 30 && (pe *= 60), ue -= 6e4 * pe;
            }
            return new Date(ue);
          }, stringify: (u) => {
            let { value: p } = u;
            return p.toISOString().replace(/((T00:00)?:00)?\.000Z$/, "");
          } };
          function t3(u) {
            let p = typeof Te < "u" && Te.env || {};
            return u ? typeof YAML_SILENCE_DEPRECATION_WARNINGS < "u" ? !YAML_SILENCE_DEPRECATION_WARNINGS : !p.YAML_SILENCE_DEPRECATION_WARNINGS : typeof YAML_SILENCE_WARNINGS < "u" ? !YAML_SILENCE_WARNINGS : !p.YAML_SILENCE_WARNINGS;
          }
          function s(u, p) {
            if (t3(false)) {
              let L = typeof Te < "u" && Te.emitWarning;
              L ? L(u, p) : console.warn(p ? `${p}: ${u}` : u);
            }
          }
          function a(u) {
            if (t3(true)) {
              let p = u.replace(/.*yaml[/\\]/i, "").replace(/\.js$/, "").replace(/\\/g, "/");
              s(`The endpoint 'yaml/${p}' will be removed in a future release.`, "DeprecationWarning");
            }
          }
          var m = {};
          function g(u, p) {
            if (!m[u] && t3(true)) {
              m[u] = true;
              let L = `The option '${u}' will be removed in a future release`;
              L += p ? `, use '${p}' instead.` : ".", s(L, "DeprecationWarning");
            }
          }
          n.binary = c, n.floatTime = f, n.intTime = U, n.omap = M, n.pairs = y, n.set = q, n.timestamp = i, n.warn = s, n.warnFileDeprecation = a, n.warnOptionDeprecation = g;
        } }), it2 = D({ "node_modules/yaml/dist/Schema-88e323a7.js"(n) {
          "use strict";
          Y();
          var e = Me(), r = ke(), c = st();
          function h(O, W, J) {
            let x = new r.YAMLMap(O);
            if (W instanceof Map)
              for (let [G, re] of W)
                x.items.push(O.createPair(G, re, J));
            else if (W && typeof W == "object")
              for (let G of Object.keys(W))
                x.items.push(O.createPair(G, W[G], J));
            return typeof O.sortMapEntries == "function" && x.items.sort(O.sortMapEntries), x;
          }
          var d = { createNode: h, default: true, nodeClass: r.YAMLMap, tag: "tag:yaml.org,2002:map", resolve: r.resolveMap };
          function y(O, W, J) {
            let x = new r.YAMLSeq(O);
            if (W && W[Symbol.iterator])
              for (let G of W) {
                let re = O.createNode(G, J.wrapScalars, null, J);
                x.items.push(re);
              }
            return x;
          }
          var E = { createNode: y, default: true, nodeClass: r.YAMLSeq, tag: "tag:yaml.org,2002:seq", resolve: r.resolveSeq }, I = { identify: (O) => typeof O == "string", default: true, tag: "tag:yaml.org,2002:str", resolve: r.resolveString, stringify(O, W, J, x) {
            return W = Object.assign({ actualString: true }, W), r.stringifyString(O, W, J, x);
          }, options: r.strOptions }, S = [d, E, I], M = (O) => typeof O == "bigint" || Number.isInteger(O), T = (O, W, J) => r.intOptions.asBigInt ? BigInt(O) : parseInt(W, J);
          function P(O, W, J) {
            let { value: x } = O;
            return M(x) && x >= 0 ? J + x.toString(W) : r.stringifyNumber(O);
          }
          var C = { identify: (O) => O == null, createNode: (O, W, J) => J.wrapScalars ? new r.Scalar(null) : null, default: true, tag: "tag:yaml.org,2002:null", test: /^(?:~|[Nn]ull|NULL)?$/, resolve: () => null, options: r.nullOptions, stringify: () => r.nullOptions.nullStr }, q = { identify: (O) => typeof O == "boolean", default: true, tag: "tag:yaml.org,2002:bool", test: /^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/, resolve: (O) => O[0] === "t" || O[0] === "T", options: r.boolOptions, stringify: (O) => {
            let { value: W } = O;
            return W ? r.boolOptions.trueStr : r.boolOptions.falseStr;
          } }, R = { identify: (O) => M(O) && O >= 0, default: true, tag: "tag:yaml.org,2002:int", format: "OCT", test: /^0o([0-7]+)$/, resolve: (O, W) => T(O, W, 8), options: r.intOptions, stringify: (O) => P(O, 8, "0o") }, B = { identify: M, default: true, tag: "tag:yaml.org,2002:int", test: /^[-+]?[0-9]+$/, resolve: (O) => T(O, O, 10), options: r.intOptions, stringify: r.stringifyNumber }, U = { identify: (O) => M(O) && O >= 0, default: true, tag: "tag:yaml.org,2002:int", format: "HEX", test: /^0x([0-9a-fA-F]+)$/, resolve: (O, W) => T(O, W, 16), options: r.intOptions, stringify: (O) => P(O, 16, "0x") }, f = { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", test: /^(?:[-+]?\.inf|(\.nan))$/i, resolve: (O, W) => W ? NaN : O[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY, stringify: r.stringifyNumber }, i = { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", format: "EXP", test: /^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/, resolve: (O) => parseFloat(O), stringify: (O) => {
            let { value: W } = O;
            return Number(W).toExponential();
          } }, t3 = { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", test: /^[-+]?(?:\.([0-9]+)|[0-9]+\.([0-9]*))$/, resolve(O, W, J) {
            let x = W || J, G = new r.Scalar(parseFloat(O));
            return x && x[x.length - 1] === "0" && (G.minFractionDigits = x.length), G;
          }, stringify: r.stringifyNumber }, s = S.concat([C, q, R, B, U, f, i, t3]), a = (O) => typeof O == "bigint" || Number.isInteger(O), m = (O) => {
            let { value: W } = O;
            return JSON.stringify(W);
          }, g = [d, E, { identify: (O) => typeof O == "string", default: true, tag: "tag:yaml.org,2002:str", resolve: r.resolveString, stringify: m }, { identify: (O) => O == null, createNode: (O, W, J) => J.wrapScalars ? new r.Scalar(null) : null, default: true, tag: "tag:yaml.org,2002:null", test: /^null$/, resolve: () => null, stringify: m }, { identify: (O) => typeof O == "boolean", default: true, tag: "tag:yaml.org,2002:bool", test: /^true|false$/, resolve: (O) => O === "true", stringify: m }, { identify: a, default: true, tag: "tag:yaml.org,2002:int", test: /^-?(?:0|[1-9][0-9]*)$/, resolve: (O) => r.intOptions.asBigInt ? BigInt(O) : parseInt(O, 10), stringify: (O) => {
            let { value: W } = O;
            return a(W) ? W.toString() : JSON.stringify(W);
          } }, { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", test: /^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/, resolve: (O) => parseFloat(O), stringify: m }];
          g.scalarFallback = (O) => {
            throw new SyntaxError(`Unresolved plain scalar ${JSON.stringify(O)}`);
          };
          var u = (O) => {
            let { value: W } = O;
            return W ? r.boolOptions.trueStr : r.boolOptions.falseStr;
          }, p = (O) => typeof O == "bigint" || Number.isInteger(O);
          function L(O, W, J) {
            let x = W.replace(/_/g, "");
            if (r.intOptions.asBigInt) {
              switch (J) {
                case 2:
                  x = `0b${x}`;
                  break;
                case 8:
                  x = `0o${x}`;
                  break;
                case 16:
                  x = `0x${x}`;
                  break;
              }
              let re = BigInt(x);
              return O === "-" ? BigInt(-1) * re : re;
            }
            let G = parseInt(x, J);
            return O === "-" ? -1 * G : G;
          }
          function k(O, W, J) {
            let { value: x } = O;
            if (p(x)) {
              let G = x.toString(W);
              return x < 0 ? "-" + J + G.substr(1) : J + G;
            }
            return r.stringifyNumber(O);
          }
          var $2 = S.concat([{ identify: (O) => O == null, createNode: (O, W, J) => J.wrapScalars ? new r.Scalar(null) : null, default: true, tag: "tag:yaml.org,2002:null", test: /^(?:~|[Nn]ull|NULL)?$/, resolve: () => null, options: r.nullOptions, stringify: () => r.nullOptions.nullStr }, { identify: (O) => typeof O == "boolean", default: true, tag: "tag:yaml.org,2002:bool", test: /^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/, resolve: () => true, options: r.boolOptions, stringify: u }, { identify: (O) => typeof O == "boolean", default: true, tag: "tag:yaml.org,2002:bool", test: /^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/i, resolve: () => false, options: r.boolOptions, stringify: u }, { identify: p, default: true, tag: "tag:yaml.org,2002:int", format: "BIN", test: /^([-+]?)0b([0-1_]+)$/, resolve: (O, W, J) => L(W, J, 2), stringify: (O) => k(O, 2, "0b") }, { identify: p, default: true, tag: "tag:yaml.org,2002:int", format: "OCT", test: /^([-+]?)0([0-7_]+)$/, resolve: (O, W, J) => L(W, J, 8), stringify: (O) => k(O, 8, "0") }, { identify: p, default: true, tag: "tag:yaml.org,2002:int", test: /^([-+]?)([0-9][0-9_]*)$/, resolve: (O, W, J) => L(W, J, 10), stringify: r.stringifyNumber }, { identify: p, default: true, tag: "tag:yaml.org,2002:int", format: "HEX", test: /^([-+]?)0x([0-9a-fA-F_]+)$/, resolve: (O, W, J) => L(W, J, 16), stringify: (O) => k(O, 16, "0x") }, { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", test: /^(?:[-+]?\.inf|(\.nan))$/i, resolve: (O, W) => W ? NaN : O[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY, stringify: r.stringifyNumber }, { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", format: "EXP", test: /^[-+]?([0-9][0-9_]*)?(\.[0-9_]*)?[eE][-+]?[0-9]+$/, resolve: (O) => parseFloat(O.replace(/_/g, "")), stringify: (O) => {
            let { value: W } = O;
            return Number(W).toExponential();
          } }, { identify: (O) => typeof O == "number", default: true, tag: "tag:yaml.org,2002:float", test: /^[-+]?(?:[0-9][0-9_]*)?\.([0-9_]*)$/, resolve(O, W) {
            let J = new r.Scalar(parseFloat(O.replace(/_/g, "")));
            if (W) {
              let x = W.replace(/_/g, "");
              x[x.length - 1] === "0" && (J.minFractionDigits = x.length);
            }
            return J;
          }, stringify: r.stringifyNumber }], c.binary, c.omap, c.pairs, c.set, c.intTime, c.floatTime, c.timestamp), K = { core: s, failsafe: S, json: g, yaml11: $2 }, V = { binary: c.binary, bool: q, float: t3, floatExp: i, floatNaN: f, floatTime: c.floatTime, int: B, intHex: U, intOct: R, intTime: c.intTime, map: d, null: C, omap: c.omap, pairs: c.pairs, seq: E, set: c.set, timestamp: c.timestamp };
          function z(O, W, J) {
            if (W) {
              let x = J.filter((re) => re.tag === W), G = x.find((re) => !re.format) || x[0];
              if (!G)
                throw new Error(`Tag ${W} not found`);
              return G;
            }
            return J.find((x) => (x.identify && x.identify(O) || x.class && O instanceof x.class) && !x.format);
          }
          function ae(O, W, J) {
            if (O instanceof r.Node)
              return O;
            let { defaultPrefix: x, onTagObj: G, prevObjects: re, schema: _e, wrapScalars: ye } = J;
            W && W.startsWith("!!") && (W = x + W.slice(2));
            let be = z(O, W, _e.tags);
            if (!be) {
              if (typeof O.toJSON == "function" && (O = O.toJSON()), !O || typeof O != "object")
                return ye ? new r.Scalar(O) : O;
              be = O instanceof Map ? d : O[Symbol.iterator] ? E : d;
            }
            G && (G(be), delete J.onTagObj);
            let ve = { value: void 0, node: void 0 };
            if (O && typeof O == "object" && re) {
              let Ne = re.get(O);
              if (Ne) {
                let Pe = new r.Alias(Ne);
                return J.aliasNodes.push(Pe), Pe;
              }
              ve.value = O, re.set(O, ve);
            }
            return ve.node = be.createNode ? be.createNode(J.schema, O, J) : ye ? new r.Scalar(O) : O, W && ve.node instanceof r.Node && (ve.node.tag = W), ve.node;
          }
          function ue(O, W, J, x) {
            let G = O[x.replace(/\W/g, "")];
            if (!G) {
              let re = Object.keys(O).map((_e) => JSON.stringify(_e)).join(", ");
              throw new Error(`Unknown schema "${x}"; use one of ${re}`);
            }
            if (Array.isArray(J))
              for (let re of J)
                G = G.concat(re);
            else
              typeof J == "function" && (G = J(G.slice()));
            for (let re = 0; re < G.length; ++re) {
              let _e = G[re];
              if (typeof _e == "string") {
                let ye = W[_e];
                if (!ye) {
                  let be = Object.keys(W).map((ve) => JSON.stringify(ve)).join(", ");
                  throw new Error(`Unknown custom tag "${_e}"; use one of ${be}`);
                }
                G[re] = ye;
              }
            }
            return G;
          }
          var pe = (O, W) => O.key < W.key ? -1 : O.key > W.key ? 1 : 0, ge = class {
            constructor(O) {
              let { customTags: W, merge: J, schema: x, sortMapEntries: G, tags: re } = O;
              this.merge = !!J, this.name = x, this.sortMapEntries = G === true ? pe : G || null, !W && re && c.warnOptionDeprecation("tags", "customTags"), this.tags = ue(K, V, W || re, x);
            }
            createNode(O, W, J, x) {
              let G = { defaultPrefix: ge.defaultPrefix, schema: this, wrapScalars: W }, re = x ? Object.assign(x, G) : G;
              return ae(O, J, re);
            }
            createPair(O, W, J) {
              J || (J = { wrapScalars: true });
              let x = this.createNode(O, J.wrapScalars, null, J), G = this.createNode(W, J.wrapScalars, null, J);
              return new r.Pair(x, G);
            }
          };
          e._defineProperty(ge, "defaultPrefix", e.defaultTagPrefix), e._defineProperty(ge, "defaultTags", e.defaultTags), n.Schema = ge;
        } }), xr = D({ "node_modules/yaml/dist/Document-9b4560a1.js"(n) {
          "use strict";
          Y();
          var e = Me(), r = ke(), c = it2(), h = { anchorPrefix: "a", customTags: null, indent: 2, indentSeq: true, keepCstNodes: false, keepNodeTypes: true, keepBlobsInJSON: true, mapAsMap: false, maxAliasCount: 100, prettyErrors: false, simpleKeys: false, version: "1.2" }, d = { get binary() {
            return r.binaryOptions;
          }, set binary(t3) {
            Object.assign(r.binaryOptions, t3);
          }, get bool() {
            return r.boolOptions;
          }, set bool(t3) {
            Object.assign(r.boolOptions, t3);
          }, get int() {
            return r.intOptions;
          }, set int(t3) {
            Object.assign(r.intOptions, t3);
          }, get null() {
            return r.nullOptions;
          }, set null(t3) {
            Object.assign(r.nullOptions, t3);
          }, get str() {
            return r.strOptions;
          }, set str(t3) {
            Object.assign(r.strOptions, t3);
          } }, y = { "1.0": { schema: "yaml-1.1", merge: true, tagPrefixes: [{ handle: "!", prefix: e.defaultTagPrefix }, { handle: "!!", prefix: "tag:private.yaml.org,2002:" }] }, 1.1: { schema: "yaml-1.1", merge: true, tagPrefixes: [{ handle: "!", prefix: "!" }, { handle: "!!", prefix: e.defaultTagPrefix }] }, 1.2: { schema: "core", merge: false, tagPrefixes: [{ handle: "!", prefix: "!" }, { handle: "!!", prefix: e.defaultTagPrefix }] } };
          function E(t3, s) {
            if ((t3.version || t3.options.version) === "1.0") {
              let g = s.match(/^tag:private\.yaml\.org,2002:([^:/]+)$/);
              if (g)
                return "!" + g[1];
              let u = s.match(/^tag:([a-zA-Z0-9-]+)\.yaml\.org,2002:(.*)/);
              return u ? `!${u[1]}/${u[2]}` : `!${s.replace(/^tag:/, "")}`;
            }
            let a = t3.tagPrefixes.find((g) => s.indexOf(g.prefix) === 0);
            if (!a) {
              let g = t3.getDefaults().tagPrefixes;
              a = g && g.find((u) => s.indexOf(u.prefix) === 0);
            }
            if (!a)
              return s[0] === "!" ? s : `!<${s}>`;
            let m = s.substr(a.prefix.length).replace(/[!,[\]{}]/g, (g) => ({ "!": "%21", ",": "%2C", "[": "%5B", "]": "%5D", "{": "%7B", "}": "%7D" })[g]);
            return a.handle + m;
          }
          function I(t3, s) {
            if (s instanceof r.Alias)
              return r.Alias;
            if (s.tag) {
              let g = t3.filter((u) => u.tag === s.tag);
              if (g.length > 0)
                return g.find((u) => u.format === s.format) || g[0];
            }
            let a, m;
            if (s instanceof r.Scalar) {
              m = s.value;
              let g = t3.filter((u) => u.identify && u.identify(m) || u.class && m instanceof u.class);
              a = g.find((u) => u.format === s.format) || g.find((u) => !u.format);
            } else
              m = s, a = t3.find((g) => g.nodeClass && m instanceof g.nodeClass);
            if (!a) {
              let g = m && m.constructor ? m.constructor.name : typeof m;
              throw new Error(`Tag not resolved for ${g} value`);
            }
            return a;
          }
          function S(t3, s, a) {
            let { anchors: m, doc: g } = a, u = [], p = g.anchors.getName(t3);
            return p && (m[p] = t3, u.push(`&${p}`)), t3.tag ? u.push(E(g, t3.tag)) : s.default || u.push(E(g, s.tag)), u.join(" ");
          }
          function M(t3, s, a, m) {
            let { anchors: g, schema: u } = s.doc, p;
            if (!(t3 instanceof r.Node)) {
              let $2 = { aliasNodes: [], onTagObj: (K) => p = K, prevObjects: /* @__PURE__ */ new Map() };
              t3 = u.createNode(t3, true, null, $2);
              for (let K of $2.aliasNodes) {
                K.source = K.source.node;
                let V = g.getName(K.source);
                V || (V = g.newName(), g.map[V] = K.source);
              }
            }
            if (t3 instanceof r.Pair)
              return t3.toString(s, a, m);
            p || (p = I(u.tags, t3));
            let L = S(t3, p, s);
            L.length > 0 && (s.indentAtStart = (s.indentAtStart || 0) + L.length + 1);
            let k = typeof p.stringify == "function" ? p.stringify(t3, s, a, m) : t3 instanceof r.Scalar ? r.stringifyString(t3, s, a, m) : t3.toString(s, a, m);
            return L ? t3 instanceof r.Scalar || k[0] === "{" || k[0] === "[" ? `${L} ${k}` : `${L}
${s.indent}${k}` : k;
          }
          var T = class {
            static validAnchorNode(t3) {
              return t3 instanceof r.Scalar || t3 instanceof r.YAMLSeq || t3 instanceof r.YAMLMap;
            }
            constructor(t3) {
              e._defineProperty(this, "map", /* @__PURE__ */ Object.create(null)), this.prefix = t3;
            }
            createAlias(t3, s) {
              return this.setAnchor(t3, s), new r.Alias(t3);
            }
            createMergePair() {
              let t3 = new r.Merge();
              for (var s = arguments.length, a = new Array(s), m = 0; m < s; m++)
                a[m] = arguments[m];
              return t3.value.items = a.map((g) => {
                if (g instanceof r.Alias) {
                  if (g.source instanceof r.YAMLMap)
                    return g;
                } else if (g instanceof r.YAMLMap)
                  return this.createAlias(g);
                throw new Error("Merge sources must be Map nodes or their Aliases");
              }), t3;
            }
            getName(t3) {
              let { map: s } = this;
              return Object.keys(s).find((a) => s[a] === t3);
            }
            getNames() {
              return Object.keys(this.map);
            }
            getNode(t3) {
              return this.map[t3];
            }
            newName(t3) {
              t3 || (t3 = this.prefix);
              let s = Object.keys(this.map);
              for (let a = 1; ; ++a) {
                let m = `${t3}${a}`;
                if (!s.includes(m))
                  return m;
              }
            }
            resolveNodes() {
              let { map: t3, _cstAliases: s } = this;
              Object.keys(t3).forEach((a) => {
                t3[a] = t3[a].resolved;
              }), s.forEach((a) => {
                a.source = a.source.resolved;
              }), delete this._cstAliases;
            }
            setAnchor(t3, s) {
              if (t3 != null && !T.validAnchorNode(t3))
                throw new Error("Anchors may only be set for Scalar, Seq and Map nodes");
              if (s && /[\x00-\x19\s,[\]{}]/.test(s))
                throw new Error("Anchor names must not contain whitespace or control characters");
              let { map: a } = this, m = t3 && Object.keys(a).find((g) => a[g] === t3);
              if (m)
                if (s)
                  m !== s && (delete a[m], a[s] = t3);
                else
                  return m;
              else {
                if (!s) {
                  if (!t3)
                    return null;
                  s = this.newName();
                }
                a[s] = t3;
              }
              return s;
            }
          }, P = (t3, s) => {
            if (t3 && typeof t3 == "object") {
              let { tag: a } = t3;
              t3 instanceof r.Collection ? (a && (s[a] = true), t3.items.forEach((m) => P(m, s))) : t3 instanceof r.Pair ? (P(t3.key, s), P(t3.value, s)) : t3 instanceof r.Scalar && a && (s[a] = true);
            }
            return s;
          }, C = (t3) => Object.keys(P(t3, {}));
          function q(t3, s) {
            let a = { before: [], after: [] }, m, g = false;
            for (let u of s)
              if (u.valueRange) {
                if (m !== void 0) {
                  let L = "Document contains trailing content not separated by a ... or --- line";
                  t3.errors.push(new e.YAMLSyntaxError(u, L));
                  break;
                }
                let p = r.resolveNode(t3, u);
                g && (p.spaceBefore = true, g = false), m = p;
              } else
                u.comment !== null ? (m === void 0 ? a.before : a.after).push(u.comment) : u.type === e.Type.BLANK_LINE && (g = true, m === void 0 && a.before.length > 0 && !t3.commentBefore && (t3.commentBefore = a.before.join(`
`), a.before = []));
            if (t3.contents = m || null, !m)
              t3.comment = a.before.concat(a.after).join(`
`) || null;
            else {
              let u = a.before.join(`
`);
              if (u) {
                let p = m instanceof r.Collection && m.items[0] ? m.items[0] : m;
                p.commentBefore = p.commentBefore ? `${u}
${p.commentBefore}` : u;
              }
              t3.comment = a.after.join(`
`) || null;
            }
          }
          function R(t3, s) {
            let { tagPrefixes: a } = t3, [m, g] = s.parameters;
            if (!m || !g) {
              let u = "Insufficient parameters given for %TAG directive";
              throw new e.YAMLSemanticError(s, u);
            }
            if (a.some((u) => u.handle === m)) {
              let u = "The %TAG directive must only be given at most once per handle in the same document.";
              throw new e.YAMLSemanticError(s, u);
            }
            return { handle: m, prefix: g };
          }
          function B(t3, s) {
            let [a] = s.parameters;
            if (s.name === "YAML:1.0" && (a = "1.0"), !a) {
              let m = "Insufficient parameters given for %YAML directive";
              throw new e.YAMLSemanticError(s, m);
            }
            if (!y[a]) {
              let g = `Document will be parsed as YAML ${t3.version || t3.options.version} rather than YAML ${a}`;
              t3.warnings.push(new e.YAMLWarning(s, g));
            }
            return a;
          }
          function U(t3, s, a) {
            let m = [], g = false;
            for (let u of s) {
              let { comment: p, name: L } = u;
              switch (L) {
                case "TAG":
                  try {
                    t3.tagPrefixes.push(R(t3, u));
                  } catch (k) {
                    t3.errors.push(k);
                  }
                  g = true;
                  break;
                case "YAML":
                case "YAML:1.0":
                  if (t3.version) {
                    let k = "The %YAML directive must only be given at most once per document.";
                    t3.errors.push(new e.YAMLSemanticError(u, k));
                  }
                  try {
                    t3.version = B(t3, u);
                  } catch (k) {
                    t3.errors.push(k);
                  }
                  g = true;
                  break;
                default:
                  if (L) {
                    let k = `YAML only supports %TAG and %YAML directives, and not %${L}`;
                    t3.warnings.push(new e.YAMLWarning(u, k));
                  }
              }
              p && m.push(p);
            }
            if (a && !g && (t3.version || a.version || t3.options.version) === "1.1") {
              let u = (p) => {
                let { handle: L, prefix: k } = p;
                return { handle: L, prefix: k };
              };
              t3.tagPrefixes = a.tagPrefixes.map(u), t3.version = a.version;
            }
            t3.commentBefore = m.join(`
`) || null;
          }
          function f(t3) {
            if (t3 instanceof r.Collection)
              return true;
            throw new Error("Expected a YAML collection as document contents");
          }
          var i = class {
            constructor(t3) {
              this.anchors = new T(t3.anchorPrefix), this.commentBefore = null, this.comment = null, this.contents = null, this.directivesEndMarker = null, this.errors = [], this.options = t3, this.schema = null, this.tagPrefixes = [], this.version = null, this.warnings = [];
            }
            add(t3) {
              return f(this.contents), this.contents.add(t3);
            }
            addIn(t3, s) {
              f(this.contents), this.contents.addIn(t3, s);
            }
            delete(t3) {
              return f(this.contents), this.contents.delete(t3);
            }
            deleteIn(t3) {
              return r.isEmptyPath(t3) ? this.contents == null ? false : (this.contents = null, true) : (f(this.contents), this.contents.deleteIn(t3));
            }
            getDefaults() {
              return i.defaults[this.version] || i.defaults[this.options.version] || {};
            }
            get(t3, s) {
              return this.contents instanceof r.Collection ? this.contents.get(t3, s) : void 0;
            }
            getIn(t3, s) {
              return r.isEmptyPath(t3) ? !s && this.contents instanceof r.Scalar ? this.contents.value : this.contents : this.contents instanceof r.Collection ? this.contents.getIn(t3, s) : void 0;
            }
            has(t3) {
              return this.contents instanceof r.Collection ? this.contents.has(t3) : false;
            }
            hasIn(t3) {
              return r.isEmptyPath(t3) ? this.contents !== void 0 : this.contents instanceof r.Collection ? this.contents.hasIn(t3) : false;
            }
            set(t3, s) {
              f(this.contents), this.contents.set(t3, s);
            }
            setIn(t3, s) {
              r.isEmptyPath(t3) ? this.contents = s : (f(this.contents), this.contents.setIn(t3, s));
            }
            setSchema(t3, s) {
              if (!t3 && !s && this.schema)
                return;
              typeof t3 == "number" && (t3 = t3.toFixed(1)), t3 === "1.0" || t3 === "1.1" || t3 === "1.2" ? (this.version ? this.version = t3 : this.options.version = t3, delete this.options.schema) : t3 && typeof t3 == "string" && (this.options.schema = t3), Array.isArray(s) && (this.options.customTags = s);
              let a = Object.assign({}, this.getDefaults(), this.options);
              this.schema = new c.Schema(a);
            }
            parse(t3, s) {
              this.options.keepCstNodes && (this.cstNode = t3), this.options.keepNodeTypes && (this.type = "DOCUMENT");
              let { directives: a = [], contents: m = [], directivesEndMarker: g, error: u, valueRange: p } = t3;
              if (u && (u.source || (u.source = this), this.errors.push(u)), U(this, a, s), g && (this.directivesEndMarker = true), this.range = p ? [p.start, p.end] : null, this.setSchema(), this.anchors._cstAliases = [], q(this, m), this.anchors.resolveNodes(), this.options.prettyErrors) {
                for (let L of this.errors)
                  L instanceof e.YAMLError && L.makePretty();
                for (let L of this.warnings)
                  L instanceof e.YAMLError && L.makePretty();
              }
              return this;
            }
            listNonDefaultTags() {
              return C(this.contents).filter((t3) => t3.indexOf(c.Schema.defaultPrefix) !== 0);
            }
            setTagPrefix(t3, s) {
              if (t3[0] !== "!" || t3[t3.length - 1] !== "!")
                throw new Error("Handle must start and end with !");
              if (s) {
                let a = this.tagPrefixes.find((m) => m.handle === t3);
                a ? a.prefix = s : this.tagPrefixes.push({ handle: t3, prefix: s });
              } else
                this.tagPrefixes = this.tagPrefixes.filter((a) => a.handle !== t3);
            }
            toJSON(t3, s) {
              let { keepBlobsInJSON: a, mapAsMap: m, maxAliasCount: g } = this.options, u = a && (typeof t3 != "string" || !(this.contents instanceof r.Scalar)), p = { doc: this, indentStep: "  ", keep: u, mapAsMap: u && !!m, maxAliasCount: g, stringify: M }, L = Object.keys(this.anchors.map);
              L.length > 0 && (p.anchors = new Map(L.map(($2) => [this.anchors.map[$2], { alias: [], aliasCount: 0, count: 1 }])));
              let k = r.toJSON(this.contents, t3, p);
              if (typeof s == "function" && p.anchors)
                for (let { count: $2, res: K } of p.anchors.values())
                  s(K, $2);
              return k;
            }
            toString() {
              if (this.errors.length > 0)
                throw new Error("Document with errors cannot be stringified");
              let t3 = this.options.indent;
              if (!Number.isInteger(t3) || t3 <= 0) {
                let L = JSON.stringify(t3);
                throw new Error(`"indent" option must be a positive integer, not ${L}`);
              }
              this.setSchema();
              let s = [], a = false;
              if (this.version) {
                let L = "%YAML 1.2";
                this.schema.name === "yaml-1.1" && (this.version === "1.0" ? L = "%YAML:1.0" : this.version === "1.1" && (L = "%YAML 1.1")), s.push(L), a = true;
              }
              let m = this.listNonDefaultTags();
              this.tagPrefixes.forEach((L) => {
                let { handle: k, prefix: $2 } = L;
                m.some((K) => K.indexOf($2) === 0) && (s.push(`%TAG ${k} ${$2}`), a = true);
              }), (a || this.directivesEndMarker) && s.push("---"), this.commentBefore && ((a || !this.directivesEndMarker) && s.unshift(""), s.unshift(this.commentBefore.replace(/^/gm, "#")));
              let g = { anchors: /* @__PURE__ */ Object.create(null), doc: this, indent: "", indentStep: " ".repeat(t3), stringify: M }, u = false, p = null;
              if (this.contents) {
                this.contents instanceof r.Node && (this.contents.spaceBefore && (a || this.directivesEndMarker) && s.push(""), this.contents.commentBefore && s.push(this.contents.commentBefore.replace(/^/gm, "#")), g.forceBlockIndent = !!this.comment, p = this.contents.comment);
                let L = p ? null : () => u = true, k = M(this.contents, g, () => p = null, L);
                s.push(r.addComment(k, "", p));
              } else
                this.contents !== void 0 && s.push(M(this.contents, g));
              return this.comment && ((!u || p) && s[s.length - 1] !== "" && s.push(""), s.push(this.comment.replace(/^/gm, "#"))), s.join(`
`) + `
`;
            }
          };
          e._defineProperty(i, "defaults", y), n.Document = i, n.defaultOptions = h, n.scalarOptions = d;
        } }), Hr = D({ "node_modules/yaml/dist/index.js"(n) {
          "use strict";
          Y();
          var e = Jr(), r = xr(), c = it2(), h = Me(), d = st();
          ke();
          function y(C) {
            let q = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true, R = arguments.length > 2 ? arguments[2] : void 0;
            R === void 0 && typeof q == "string" && (R = q, q = true);
            let B = Object.assign({}, r.Document.defaults[r.defaultOptions.version], r.defaultOptions);
            return new c.Schema(B).createNode(C, q, R);
          }
          var E = class extends r.Document {
            constructor(C) {
              super(Object.assign({}, r.defaultOptions, C));
            }
          };
          function I(C, q) {
            let R = [], B;
            for (let U of e.parse(C)) {
              let f = new E(q);
              f.parse(U, B), R.push(f), B = f;
            }
            return R;
          }
          function S(C, q) {
            let R = e.parse(C), B = new E(q).parse(R[0]);
            if (R.length > 1) {
              let U = "Source contains multiple documents; please use YAML.parseAllDocuments()";
              B.errors.unshift(new h.YAMLSemanticError(R[1], U));
            }
            return B;
          }
          function M(C, q) {
            let R = S(C, q);
            if (R.warnings.forEach((B) => d.warn(B)), R.errors.length > 0)
              throw R.errors[0];
            return R.toJSON();
          }
          function T(C, q) {
            let R = new E(q);
            return R.contents = C, String(R);
          }
          var P = { createNode: y, defaultOptions: r.defaultOptions, Document: E, parse: M, parseAllDocuments: I, parseCST: e.parse, parseDocument: S, scalarOptions: r.scalarOptions, stringify: T };
          n.YAML = P;
        } }), Ue = D({ "node_modules/yaml/index.js"(n, e) {
          Y(), e.exports = Hr().YAML;
        } }), Gr = D({ "node_modules/yaml/dist/util.js"(n) {
          "use strict";
          Y();
          var e = ke(), r = Me();
          n.findPair = e.findPair, n.parseMap = e.resolveMap, n.parseSeq = e.resolveSeq, n.stringifyNumber = e.stringifyNumber, n.stringifyString = e.stringifyString, n.toJSON = e.toJSON, n.Type = r.Type, n.YAMLError = r.YAMLError, n.YAMLReferenceError = r.YAMLReferenceError, n.YAMLSemanticError = r.YAMLSemanticError, n.YAMLSyntaxError = r.YAMLSyntaxError, n.YAMLWarning = r.YAMLWarning;
        } }), zr = D({ "node_modules/yaml/util.js"(n) {
          Y();
          var e = Gr();
          n.findPair = e.findPair, n.toJSON = e.toJSON, n.parseMap = e.parseMap, n.parseSeq = e.parseSeq, n.stringifyNumber = e.stringifyNumber, n.stringifyString = e.stringifyString, n.Type = e.Type, n.YAMLError = e.YAMLError, n.YAMLReferenceError = e.YAMLReferenceError, n.YAMLSemanticError = e.YAMLSemanticError, n.YAMLSyntaxError = e.YAMLSyntaxError, n.YAMLWarning = e.YAMLWarning;
        } }), Zr = D({ "node_modules/yaml-unist-parser/lib/yaml.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Ue();
          n.Document = e.Document;
          var r = Ue();
          n.parseCST = r.parseCST;
          var c = zr();
          n.YAMLError = c.YAMLError, n.YAMLSyntaxError = c.YAMLSyntaxError, n.YAMLSemanticError = c.YAMLSemanticError;
        } }), Xr = D({ "node_modules/yaml-unist-parser/lib/parse.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = Kt(), r = xt(), c = Ht(), h = Gt(), d = Br(), y = He(), E = Yr(), I = Fr(), S = Wr(), M = Vr(), T = Qr(), P = Kr(), C = Zr();
          function q(R) {
            var B = C.parseCST(R);
            M.addOrigRange(B);
            for (var U = B.map(function(k) {
              return new C.Document({ merge: false, keepCstNodes: true }).parse(k);
            }), f = new e.default(R), i = [], t3 = { text: R, locator: f, comments: i, transformOffset: function(k) {
              return I.transformOffset(k, t3);
            }, transformRange: function(k) {
              return S.transformRange(k, t3);
            }, transformNode: function(k) {
              return d.transformNode(k, t3);
            }, transformContent: function(k) {
              return y.transformContent(k, t3);
            } }, s = 0, a = U; s < a.length; s++)
              for (var m = a[s], g = 0, u = m.errors; g < u.length; g++) {
                var p = u[g];
                if (!(p instanceof C.YAMLSemanticError && p.message === 'Map keys must be unique; "<<" is repeated'))
                  throw E.transformError(p, t3);
              }
            U.forEach(function(k) {
              return h.removeCstBlankLine(k.cstNode);
            });
            var L = c.createRoot(t3.transformRange({ origStart: 0, origEnd: t3.text.length }), U.map(t3.transformNode), i);
            return r.attachComments(L), P.updatePositions(L), T.removeFakeNodes(L), L;
          }
          n.parse = q;
        } }), en = D({ "node_modules/yaml-unist-parser/lib/index.js"(n) {
          "use strict";
          Y(), n.__esModule = true;
          var e = (ie(), se(te));
          e.__exportStar(Xr(), n);
        } });
        Y();
        var tn = Mt(), { hasPragma: rn } = Ot(), { locStart: nn, locEnd: sn } = Lt();
        function an(n) {
          let { parse: e } = en();
          try {
            let r = e(n);
            return delete r.comments, r;
          } catch (r) {
            throw r != null && r.position ? tn(r.message, r.position) : r;
          }
        }
        var on = { astFormat: "yaml", parse: an, hasPragma: rn, locStart: nn, locEnd: sn };
        at.exports = { parsers: { yaml: on } };
      });
      return ln();
    });
  }
});

// node_modules/prettier/index.js
var require_prettier = __commonJS({
  "node_modules/prettier/index.js"(exports, module2) {
    "use strict";
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __commonJS2 = (cb, mod) => function __require() {
      return mod || (0, cb[__getOwnPropNames2(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
    };
    var require_global = __commonJS2({
      "node_modules/core-js/internals/global.js"(exports2, module22) {
        var check = function(it2) {
          return it2 && it2.Math == Math && it2;
        };
        module22.exports = check(typeof globalThis == "object" && globalThis) || check(typeof window == "object" && window) || check(typeof self == "object" && self) || check(typeof global == "object" && global) || function() {
          return this;
        }() || Function("return this")();
      }
    });
    var require_fails = __commonJS2({
      "node_modules/core-js/internals/fails.js"(exports2, module22) {
        module22.exports = function(exec2) {
          try {
            return !!exec2();
          } catch (error) {
            return true;
          }
        };
      }
    });
    var require_descriptors = __commonJS2({
      "node_modules/core-js/internals/descriptors.js"(exports2, module22) {
        var fails = require_fails();
        module22.exports = !fails(function() {
          return Object.defineProperty({}, 1, { get: function() {
            return 7;
          } })[1] != 7;
        });
      }
    });
    var require_function_bind_native = __commonJS2({
      "node_modules/core-js/internals/function-bind-native.js"(exports2, module22) {
        var fails = require_fails();
        module22.exports = !fails(function() {
          var test = function() {
          }.bind();
          return typeof test != "function" || test.hasOwnProperty("prototype");
        });
      }
    });
    var require_function_call = __commonJS2({
      "node_modules/core-js/internals/function-call.js"(exports2, module22) {
        var NATIVE_BIND = require_function_bind_native();
        var call = Function.prototype.call;
        module22.exports = NATIVE_BIND ? call.bind(call) : function() {
          return call.apply(call, arguments);
        };
      }
    });
    var require_object_property_is_enumerable = __commonJS2({
      "node_modules/core-js/internals/object-property-is-enumerable.js"(exports2) {
        "use strict";
        var $propertyIsEnumerable = {}.propertyIsEnumerable;
        var getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
        var NASHORN_BUG = getOwnPropertyDescriptor && !$propertyIsEnumerable.call({ 1: 2 }, 1);
        exports2.f = NASHORN_BUG ? function propertyIsEnumerable(V) {
          var descriptor = getOwnPropertyDescriptor(this, V);
          return !!descriptor && descriptor.enumerable;
        } : $propertyIsEnumerable;
      }
    });
    var require_create_property_descriptor = __commonJS2({
      "node_modules/core-js/internals/create-property-descriptor.js"(exports2, module22) {
        module22.exports = function(bitmap, value2) {
          return {
            enumerable: !(bitmap & 1),
            configurable: !(bitmap & 2),
            writable: !(bitmap & 4),
            value: value2
          };
        };
      }
    });
    var require_function_uncurry_this = __commonJS2({
      "node_modules/core-js/internals/function-uncurry-this.js"(exports2, module22) {
        var NATIVE_BIND = require_function_bind_native();
        var FunctionPrototype = Function.prototype;
        var call = FunctionPrototype.call;
        var uncurryThisWithBind = NATIVE_BIND && FunctionPrototype.bind.bind(call, call);
        module22.exports = NATIVE_BIND ? uncurryThisWithBind : function(fn) {
          return function() {
            return call.apply(fn, arguments);
          };
        };
      }
    });
    var require_classof_raw = __commonJS2({
      "node_modules/core-js/internals/classof-raw.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var toString = uncurryThis({}.toString);
        var stringSlice = uncurryThis("".slice);
        module22.exports = function(it2) {
          return stringSlice(toString(it2), 8, -1);
        };
      }
    });
    var require_indexed_object = __commonJS2({
      "node_modules/core-js/internals/indexed-object.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var fails = require_fails();
        var classof = require_classof_raw();
        var $Object = Object;
        var split = uncurryThis("".split);
        module22.exports = fails(function() {
          return !$Object("z").propertyIsEnumerable(0);
        }) ? function(it2) {
          return classof(it2) == "String" ? split(it2, "") : $Object(it2);
        } : $Object;
      }
    });
    var require_is_null_or_undefined = __commonJS2({
      "node_modules/core-js/internals/is-null-or-undefined.js"(exports2, module22) {
        module22.exports = function(it2) {
          return it2 === null || it2 === void 0;
        };
      }
    });
    var require_require_object_coercible = __commonJS2({
      "node_modules/core-js/internals/require-object-coercible.js"(exports2, module22) {
        var isNullOrUndefined = require_is_null_or_undefined();
        var $TypeError = TypeError;
        module22.exports = function(it2) {
          if (isNullOrUndefined(it2))
            throw $TypeError("Can't call method on " + it2);
          return it2;
        };
      }
    });
    var require_to_indexed_object = __commonJS2({
      "node_modules/core-js/internals/to-indexed-object.js"(exports2, module22) {
        var IndexedObject = require_indexed_object();
        var requireObjectCoercible = require_require_object_coercible();
        module22.exports = function(it2) {
          return IndexedObject(requireObjectCoercible(it2));
        };
      }
    });
    var require_document_all = __commonJS2({
      "node_modules/core-js/internals/document-all.js"(exports2, module22) {
        var documentAll = typeof document == "object" && document.all;
        var IS_HTMLDDA = typeof documentAll == "undefined" && documentAll !== void 0;
        module22.exports = {
          all: documentAll,
          IS_HTMLDDA
        };
      }
    });
    var require_is_callable = __commonJS2({
      "node_modules/core-js/internals/is-callable.js"(exports2, module22) {
        var $documentAll = require_document_all();
        var documentAll = $documentAll.all;
        module22.exports = $documentAll.IS_HTMLDDA ? function(argument) {
          return typeof argument == "function" || argument === documentAll;
        } : function(argument) {
          return typeof argument == "function";
        };
      }
    });
    var require_is_object = __commonJS2({
      "node_modules/core-js/internals/is-object.js"(exports2, module22) {
        var isCallable = require_is_callable();
        var $documentAll = require_document_all();
        var documentAll = $documentAll.all;
        module22.exports = $documentAll.IS_HTMLDDA ? function(it2) {
          return typeof it2 == "object" ? it2 !== null : isCallable(it2) || it2 === documentAll;
        } : function(it2) {
          return typeof it2 == "object" ? it2 !== null : isCallable(it2);
        };
      }
    });
    var require_get_built_in = __commonJS2({
      "node_modules/core-js/internals/get-built-in.js"(exports2, module22) {
        var global2 = require_global();
        var isCallable = require_is_callable();
        var aFunction = function(argument) {
          return isCallable(argument) ? argument : void 0;
        };
        module22.exports = function(namespace, method) {
          return arguments.length < 2 ? aFunction(global2[namespace]) : global2[namespace] && global2[namespace][method];
        };
      }
    });
    var require_object_is_prototype_of = __commonJS2({
      "node_modules/core-js/internals/object-is-prototype-of.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        module22.exports = uncurryThis({}.isPrototypeOf);
      }
    });
    var require_engine_user_agent = __commonJS2({
      "node_modules/core-js/internals/engine-user-agent.js"(exports2, module22) {
        var getBuiltIn = require_get_built_in();
        module22.exports = getBuiltIn("navigator", "userAgent") || "";
      }
    });
    var require_engine_v8_version = __commonJS2({
      "node_modules/core-js/internals/engine-v8-version.js"(exports2, module22) {
        var global2 = require_global();
        var userAgent = require_engine_user_agent();
        var process2 = global2.process;
        var Deno2 = global2.Deno;
        var versions = process2 && process2.versions || Deno2 && Deno2.version;
        var v8 = versions && versions.v8;
        var match;
        var version22;
        if (v8) {
          match = v8.split(".");
          version22 = match[0] > 0 && match[0] < 4 ? 1 : +(match[0] + match[1]);
        }
        if (!version22 && userAgent) {
          match = userAgent.match(/Edge\/(\d+)/);
          if (!match || match[1] >= 74) {
            match = userAgent.match(/Chrome\/(\d+)/);
            if (match)
              version22 = +match[1];
          }
        }
        module22.exports = version22;
      }
    });
    var require_symbol_constructor_detection = __commonJS2({
      "node_modules/core-js/internals/symbol-constructor-detection.js"(exports2, module22) {
        var V8_VERSION = require_engine_v8_version();
        var fails = require_fails();
        module22.exports = !!Object.getOwnPropertySymbols && !fails(function() {
          var symbol = Symbol();
          return !String(symbol) || !(Object(symbol) instanceof Symbol) || !Symbol.sham && V8_VERSION && V8_VERSION < 41;
        });
      }
    });
    var require_use_symbol_as_uid = __commonJS2({
      "node_modules/core-js/internals/use-symbol-as-uid.js"(exports2, module22) {
        var NATIVE_SYMBOL = require_symbol_constructor_detection();
        module22.exports = NATIVE_SYMBOL && !Symbol.sham && typeof Symbol.iterator == "symbol";
      }
    });
    var require_is_symbol = __commonJS2({
      "node_modules/core-js/internals/is-symbol.js"(exports2, module22) {
        var getBuiltIn = require_get_built_in();
        var isCallable = require_is_callable();
        var isPrototypeOf2 = require_object_is_prototype_of();
        var USE_SYMBOL_AS_UID = require_use_symbol_as_uid();
        var $Object = Object;
        module22.exports = USE_SYMBOL_AS_UID ? function(it2) {
          return typeof it2 == "symbol";
        } : function(it2) {
          var $Symbol = getBuiltIn("Symbol");
          return isCallable($Symbol) && isPrototypeOf2($Symbol.prototype, $Object(it2));
        };
      }
    });
    var require_try_to_string = __commonJS2({
      "node_modules/core-js/internals/try-to-string.js"(exports2, module22) {
        var $String = String;
        module22.exports = function(argument) {
          try {
            return $String(argument);
          } catch (error) {
            return "Object";
          }
        };
      }
    });
    var require_a_callable = __commonJS2({
      "node_modules/core-js/internals/a-callable.js"(exports2, module22) {
        var isCallable = require_is_callable();
        var tryToString = require_try_to_string();
        var $TypeError = TypeError;
        module22.exports = function(argument) {
          if (isCallable(argument))
            return argument;
          throw $TypeError(tryToString(argument) + " is not a function");
        };
      }
    });
    var require_get_method = __commonJS2({
      "node_modules/core-js/internals/get-method.js"(exports2, module22) {
        var aCallable = require_a_callable();
        var isNullOrUndefined = require_is_null_or_undefined();
        module22.exports = function(V, P) {
          var func = V[P];
          return isNullOrUndefined(func) ? void 0 : aCallable(func);
        };
      }
    });
    var require_ordinary_to_primitive = __commonJS2({
      "node_modules/core-js/internals/ordinary-to-primitive.js"(exports2, module22) {
        var call = require_function_call();
        var isCallable = require_is_callable();
        var isObject = require_is_object();
        var $TypeError = TypeError;
        module22.exports = function(input, pref) {
          var fn, val;
          if (pref === "string" && isCallable(fn = input.toString) && !isObject(val = call(fn, input)))
            return val;
          if (isCallable(fn = input.valueOf) && !isObject(val = call(fn, input)))
            return val;
          if (pref !== "string" && isCallable(fn = input.toString) && !isObject(val = call(fn, input)))
            return val;
          throw $TypeError("Can't convert object to primitive value");
        };
      }
    });
    var require_is_pure = __commonJS2({
      "node_modules/core-js/internals/is-pure.js"(exports2, module22) {
        module22.exports = false;
      }
    });
    var require_define_global_property = __commonJS2({
      "node_modules/core-js/internals/define-global-property.js"(exports2, module22) {
        var global2 = require_global();
        var defineProperty = Object.defineProperty;
        module22.exports = function(key, value2) {
          try {
            defineProperty(global2, key, { value: value2, configurable: true, writable: true });
          } catch (error) {
            global2[key] = value2;
          }
          return value2;
        };
      }
    });
    var require_shared_store = __commonJS2({
      "node_modules/core-js/internals/shared-store.js"(exports2, module22) {
        var global2 = require_global();
        var defineGlobalProperty = require_define_global_property();
        var SHARED = "__core-js_shared__";
        var store = global2[SHARED] || defineGlobalProperty(SHARED, {});
        module22.exports = store;
      }
    });
    var require_shared = __commonJS2({
      "node_modules/core-js/internals/shared.js"(exports2, module22) {
        var IS_PURE = require_is_pure();
        var store = require_shared_store();
        (module22.exports = function(key, value2) {
          return store[key] || (store[key] = value2 !== void 0 ? value2 : {});
        })("versions", []).push({
          version: "3.26.1",
          mode: IS_PURE ? "pure" : "global",
          copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)",
          license: "https://github.com/zloirock/core-js/blob/v3.26.1/LICENSE",
          source: "https://github.com/zloirock/core-js"
        });
      }
    });
    var require_to_object = __commonJS2({
      "node_modules/core-js/internals/to-object.js"(exports2, module22) {
        var requireObjectCoercible = require_require_object_coercible();
        var $Object = Object;
        module22.exports = function(argument) {
          return $Object(requireObjectCoercible(argument));
        };
      }
    });
    var require_has_own_property = __commonJS2({
      "node_modules/core-js/internals/has-own-property.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var toObject = require_to_object();
        var hasOwnProperty = uncurryThis({}.hasOwnProperty);
        module22.exports = Object.hasOwn || function hasOwn(it2, key) {
          return hasOwnProperty(toObject(it2), key);
        };
      }
    });
    var require_uid = __commonJS2({
      "node_modules/core-js/internals/uid.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var id = 0;
        var postfix = Math.random();
        var toString = uncurryThis(1 .toString);
        module22.exports = function(key) {
          return "Symbol(" + (key === void 0 ? "" : key) + ")_" + toString(++id + postfix, 36);
        };
      }
    });
    var require_well_known_symbol = __commonJS2({
      "node_modules/core-js/internals/well-known-symbol.js"(exports2, module22) {
        var global2 = require_global();
        var shared = require_shared();
        var hasOwn = require_has_own_property();
        var uid = require_uid();
        var NATIVE_SYMBOL = require_symbol_constructor_detection();
        var USE_SYMBOL_AS_UID = require_use_symbol_as_uid();
        var WellKnownSymbolsStore = shared("wks");
        var Symbol2 = global2.Symbol;
        var symbolFor = Symbol2 && Symbol2["for"];
        var createWellKnownSymbol = USE_SYMBOL_AS_UID ? Symbol2 : Symbol2 && Symbol2.withoutSetter || uid;
        module22.exports = function(name) {
          if (!hasOwn(WellKnownSymbolsStore, name) || !(NATIVE_SYMBOL || typeof WellKnownSymbolsStore[name] == "string")) {
            var description = "Symbol." + name;
            if (NATIVE_SYMBOL && hasOwn(Symbol2, name)) {
              WellKnownSymbolsStore[name] = Symbol2[name];
            } else if (USE_SYMBOL_AS_UID && symbolFor) {
              WellKnownSymbolsStore[name] = symbolFor(description);
            } else {
              WellKnownSymbolsStore[name] = createWellKnownSymbol(description);
            }
          }
          return WellKnownSymbolsStore[name];
        };
      }
    });
    var require_to_primitive = __commonJS2({
      "node_modules/core-js/internals/to-primitive.js"(exports2, module22) {
        var call = require_function_call();
        var isObject = require_is_object();
        var isSymbol = require_is_symbol();
        var getMethod = require_get_method();
        var ordinaryToPrimitive = require_ordinary_to_primitive();
        var wellKnownSymbol = require_well_known_symbol();
        var $TypeError = TypeError;
        var TO_PRIMITIVE = wellKnownSymbol("toPrimitive");
        module22.exports = function(input, pref) {
          if (!isObject(input) || isSymbol(input))
            return input;
          var exoticToPrim = getMethod(input, TO_PRIMITIVE);
          var result;
          if (exoticToPrim) {
            if (pref === void 0)
              pref = "default";
            result = call(exoticToPrim, input, pref);
            if (!isObject(result) || isSymbol(result))
              return result;
            throw $TypeError("Can't convert object to primitive value");
          }
          if (pref === void 0)
            pref = "number";
          return ordinaryToPrimitive(input, pref);
        };
      }
    });
    var require_to_property_key = __commonJS2({
      "node_modules/core-js/internals/to-property-key.js"(exports2, module22) {
        var toPrimitive = require_to_primitive();
        var isSymbol = require_is_symbol();
        module22.exports = function(argument) {
          var key = toPrimitive(argument, "string");
          return isSymbol(key) ? key : key + "";
        };
      }
    });
    var require_document_create_element = __commonJS2({
      "node_modules/core-js/internals/document-create-element.js"(exports2, module22) {
        var global2 = require_global();
        var isObject = require_is_object();
        var document2 = global2.document;
        var EXISTS = isObject(document2) && isObject(document2.createElement);
        module22.exports = function(it2) {
          return EXISTS ? document2.createElement(it2) : {};
        };
      }
    });
    var require_ie8_dom_define = __commonJS2({
      "node_modules/core-js/internals/ie8-dom-define.js"(exports2, module22) {
        var DESCRIPTORS = require_descriptors();
        var fails = require_fails();
        var createElement = require_document_create_element();
        module22.exports = !DESCRIPTORS && !fails(function() {
          return Object.defineProperty(createElement("div"), "a", {
            get: function() {
              return 7;
            }
          }).a != 7;
        });
      }
    });
    var require_object_get_own_property_descriptor = __commonJS2({
      "node_modules/core-js/internals/object-get-own-property-descriptor.js"(exports2) {
        var DESCRIPTORS = require_descriptors();
        var call = require_function_call();
        var propertyIsEnumerableModule = require_object_property_is_enumerable();
        var createPropertyDescriptor = require_create_property_descriptor();
        var toIndexedObject = require_to_indexed_object();
        var toPropertyKey = require_to_property_key();
        var hasOwn = require_has_own_property();
        var IE8_DOM_DEFINE = require_ie8_dom_define();
        var $getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
        exports2.f = DESCRIPTORS ? $getOwnPropertyDescriptor : function getOwnPropertyDescriptor(O, P) {
          O = toIndexedObject(O);
          P = toPropertyKey(P);
          if (IE8_DOM_DEFINE)
            try {
              return $getOwnPropertyDescriptor(O, P);
            } catch (error) {
            }
          if (hasOwn(O, P))
            return createPropertyDescriptor(!call(propertyIsEnumerableModule.f, O, P), O[P]);
        };
      }
    });
    var require_v8_prototype_define_bug = __commonJS2({
      "node_modules/core-js/internals/v8-prototype-define-bug.js"(exports2, module22) {
        var DESCRIPTORS = require_descriptors();
        var fails = require_fails();
        module22.exports = DESCRIPTORS && fails(function() {
          return Object.defineProperty(function() {
          }, "prototype", {
            value: 42,
            writable: false
          }).prototype != 42;
        });
      }
    });
    var require_an_object = __commonJS2({
      "node_modules/core-js/internals/an-object.js"(exports2, module22) {
        var isObject = require_is_object();
        var $String = String;
        var $TypeError = TypeError;
        module22.exports = function(argument) {
          if (isObject(argument))
            return argument;
          throw $TypeError($String(argument) + " is not an object");
        };
      }
    });
    var require_object_define_property = __commonJS2({
      "node_modules/core-js/internals/object-define-property.js"(exports2) {
        var DESCRIPTORS = require_descriptors();
        var IE8_DOM_DEFINE = require_ie8_dom_define();
        var V8_PROTOTYPE_DEFINE_BUG = require_v8_prototype_define_bug();
        var anObject = require_an_object();
        var toPropertyKey = require_to_property_key();
        var $TypeError = TypeError;
        var $defineProperty = Object.defineProperty;
        var $getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
        var ENUMERABLE = "enumerable";
        var CONFIGURABLE = "configurable";
        var WRITABLE = "writable";
        exports2.f = DESCRIPTORS ? V8_PROTOTYPE_DEFINE_BUG ? function defineProperty(O, P, Attributes) {
          anObject(O);
          P = toPropertyKey(P);
          anObject(Attributes);
          if (typeof O === "function" && P === "prototype" && "value" in Attributes && WRITABLE in Attributes && !Attributes[WRITABLE]) {
            var current = $getOwnPropertyDescriptor(O, P);
            if (current && current[WRITABLE]) {
              O[P] = Attributes.value;
              Attributes = {
                configurable: CONFIGURABLE in Attributes ? Attributes[CONFIGURABLE] : current[CONFIGURABLE],
                enumerable: ENUMERABLE in Attributes ? Attributes[ENUMERABLE] : current[ENUMERABLE],
                writable: false
              };
            }
          }
          return $defineProperty(O, P, Attributes);
        } : $defineProperty : function defineProperty(O, P, Attributes) {
          anObject(O);
          P = toPropertyKey(P);
          anObject(Attributes);
          if (IE8_DOM_DEFINE)
            try {
              return $defineProperty(O, P, Attributes);
            } catch (error) {
            }
          if ("get" in Attributes || "set" in Attributes)
            throw $TypeError("Accessors not supported");
          if ("value" in Attributes)
            O[P] = Attributes.value;
          return O;
        };
      }
    });
    var require_create_non_enumerable_property = __commonJS2({
      "node_modules/core-js/internals/create-non-enumerable-property.js"(exports2, module22) {
        var DESCRIPTORS = require_descriptors();
        var definePropertyModule = require_object_define_property();
        var createPropertyDescriptor = require_create_property_descriptor();
        module22.exports = DESCRIPTORS ? function(object, key, value2) {
          return definePropertyModule.f(object, key, createPropertyDescriptor(1, value2));
        } : function(object, key, value2) {
          object[key] = value2;
          return object;
        };
      }
    });
    var require_function_name = __commonJS2({
      "node_modules/core-js/internals/function-name.js"(exports2, module22) {
        var DESCRIPTORS = require_descriptors();
        var hasOwn = require_has_own_property();
        var FunctionPrototype = Function.prototype;
        var getDescriptor = DESCRIPTORS && Object.getOwnPropertyDescriptor;
        var EXISTS = hasOwn(FunctionPrototype, "name");
        var PROPER = EXISTS && function something() {
        }.name === "something";
        var CONFIGURABLE = EXISTS && (!DESCRIPTORS || DESCRIPTORS && getDescriptor(FunctionPrototype, "name").configurable);
        module22.exports = {
          EXISTS,
          PROPER,
          CONFIGURABLE
        };
      }
    });
    var require_inspect_source = __commonJS2({
      "node_modules/core-js/internals/inspect-source.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var isCallable = require_is_callable();
        var store = require_shared_store();
        var functionToString = uncurryThis(Function.toString);
        if (!isCallable(store.inspectSource)) {
          store.inspectSource = function(it2) {
            return functionToString(it2);
          };
        }
        module22.exports = store.inspectSource;
      }
    });
    var require_weak_map_basic_detection = __commonJS2({
      "node_modules/core-js/internals/weak-map-basic-detection.js"(exports2, module22) {
        var global2 = require_global();
        var isCallable = require_is_callable();
        var WeakMap2 = global2.WeakMap;
        module22.exports = isCallable(WeakMap2) && /native code/.test(String(WeakMap2));
      }
    });
    var require_shared_key = __commonJS2({
      "node_modules/core-js/internals/shared-key.js"(exports2, module22) {
        var shared = require_shared();
        var uid = require_uid();
        var keys3 = shared("keys");
        module22.exports = function(key) {
          return keys3[key] || (keys3[key] = uid(key));
        };
      }
    });
    var require_hidden_keys = __commonJS2({
      "node_modules/core-js/internals/hidden-keys.js"(exports2, module22) {
        module22.exports = {};
      }
    });
    var require_internal_state = __commonJS2({
      "node_modules/core-js/internals/internal-state.js"(exports2, module22) {
        var NATIVE_WEAK_MAP = require_weak_map_basic_detection();
        var global2 = require_global();
        var isObject = require_is_object();
        var createNonEnumerableProperty = require_create_non_enumerable_property();
        var hasOwn = require_has_own_property();
        var shared = require_shared_store();
        var sharedKey = require_shared_key();
        var hiddenKeys = require_hidden_keys();
        var OBJECT_ALREADY_INITIALIZED = "Object already initialized";
        var TypeError2 = global2.TypeError;
        var WeakMap2 = global2.WeakMap;
        var set;
        var get;
        var has;
        var enforce = function(it2) {
          return has(it2) ? get(it2) : set(it2, {});
        };
        var getterFor = function(TYPE) {
          return function(it2) {
            var state;
            if (!isObject(it2) || (state = get(it2)).type !== TYPE) {
              throw TypeError2("Incompatible receiver, " + TYPE + " required");
            }
            return state;
          };
        };
        if (NATIVE_WEAK_MAP || shared.state) {
          store = shared.state || (shared.state = new WeakMap2());
          store.get = store.get;
          store.has = store.has;
          store.set = store.set;
          set = function(it2, metadata) {
            if (store.has(it2))
              throw TypeError2(OBJECT_ALREADY_INITIALIZED);
            metadata.facade = it2;
            store.set(it2, metadata);
            return metadata;
          };
          get = function(it2) {
            return store.get(it2) || {};
          };
          has = function(it2) {
            return store.has(it2);
          };
        } else {
          STATE = sharedKey("state");
          hiddenKeys[STATE] = true;
          set = function(it2, metadata) {
            if (hasOwn(it2, STATE))
              throw TypeError2(OBJECT_ALREADY_INITIALIZED);
            metadata.facade = it2;
            createNonEnumerableProperty(it2, STATE, metadata);
            return metadata;
          };
          get = function(it2) {
            return hasOwn(it2, STATE) ? it2[STATE] : {};
          };
          has = function(it2) {
            return hasOwn(it2, STATE);
          };
        }
        var store;
        var STATE;
        module22.exports = {
          set,
          get,
          has,
          enforce,
          getterFor
        };
      }
    });
    var require_make_built_in = __commonJS2({
      "node_modules/core-js/internals/make-built-in.js"(exports2, module22) {
        var fails = require_fails();
        var isCallable = require_is_callable();
        var hasOwn = require_has_own_property();
        var DESCRIPTORS = require_descriptors();
        var CONFIGURABLE_FUNCTION_NAME = require_function_name().CONFIGURABLE;
        var inspectSource = require_inspect_source();
        var InternalStateModule = require_internal_state();
        var enforceInternalState = InternalStateModule.enforce;
        var getInternalState = InternalStateModule.get;
        var defineProperty = Object.defineProperty;
        var CONFIGURABLE_LENGTH = DESCRIPTORS && !fails(function() {
          return defineProperty(function() {
          }, "length", { value: 8 }).length !== 8;
        });
        var TEMPLATE = String(String).split("String");
        var makeBuiltIn = module22.exports = function(value2, name, options) {
          if (String(name).slice(0, 7) === "Symbol(") {
            name = "[" + String(name).replace(/^Symbol\(([^)]*)\)/, "$1") + "]";
          }
          if (options && options.getter)
            name = "get " + name;
          if (options && options.setter)
            name = "set " + name;
          if (!hasOwn(value2, "name") || CONFIGURABLE_FUNCTION_NAME && value2.name !== name) {
            if (DESCRIPTORS)
              defineProperty(value2, "name", { value: name, configurable: true });
            else
              value2.name = name;
          }
          if (CONFIGURABLE_LENGTH && options && hasOwn(options, "arity") && value2.length !== options.arity) {
            defineProperty(value2, "length", { value: options.arity });
          }
          try {
            if (options && hasOwn(options, "constructor") && options.constructor) {
              if (DESCRIPTORS)
                defineProperty(value2, "prototype", { writable: false });
            } else if (value2.prototype)
              value2.prototype = void 0;
          } catch (error) {
          }
          var state = enforceInternalState(value2);
          if (!hasOwn(state, "source")) {
            state.source = TEMPLATE.join(typeof name == "string" ? name : "");
          }
          return value2;
        };
        Function.prototype.toString = makeBuiltIn(function toString() {
          return isCallable(this) && getInternalState(this).source || inspectSource(this);
        }, "toString");
      }
    });
    var require_define_built_in = __commonJS2({
      "node_modules/core-js/internals/define-built-in.js"(exports2, module22) {
        var isCallable = require_is_callable();
        var definePropertyModule = require_object_define_property();
        var makeBuiltIn = require_make_built_in();
        var defineGlobalProperty = require_define_global_property();
        module22.exports = function(O, key, value2, options) {
          if (!options)
            options = {};
          var simple = options.enumerable;
          var name = options.name !== void 0 ? options.name : key;
          if (isCallable(value2))
            makeBuiltIn(value2, name, options);
          if (options.global) {
            if (simple)
              O[key] = value2;
            else
              defineGlobalProperty(key, value2);
          } else {
            try {
              if (!options.unsafe)
                delete O[key];
              else if (O[key])
                simple = true;
            } catch (error) {
            }
            if (simple)
              O[key] = value2;
            else
              definePropertyModule.f(O, key, {
                value: value2,
                enumerable: false,
                configurable: !options.nonConfigurable,
                writable: !options.nonWritable
              });
          }
          return O;
        };
      }
    });
    var require_math_trunc = __commonJS2({
      "node_modules/core-js/internals/math-trunc.js"(exports2, module22) {
        var ceil = Math.ceil;
        var floor = Math.floor;
        module22.exports = Math.trunc || function trunc(x) {
          var n = +x;
          return (n > 0 ? floor : ceil)(n);
        };
      }
    });
    var require_to_integer_or_infinity = __commonJS2({
      "node_modules/core-js/internals/to-integer-or-infinity.js"(exports2, module22) {
        var trunc = require_math_trunc();
        module22.exports = function(argument) {
          var number = +argument;
          return number !== number || number === 0 ? 0 : trunc(number);
        };
      }
    });
    var require_to_absolute_index = __commonJS2({
      "node_modules/core-js/internals/to-absolute-index.js"(exports2, module22) {
        var toIntegerOrInfinity = require_to_integer_or_infinity();
        var max2 = Math.max;
        var min2 = Math.min;
        module22.exports = function(index, length) {
          var integer = toIntegerOrInfinity(index);
          return integer < 0 ? max2(integer + length, 0) : min2(integer, length);
        };
      }
    });
    var require_to_length = __commonJS2({
      "node_modules/core-js/internals/to-length.js"(exports2, module22) {
        var toIntegerOrInfinity = require_to_integer_or_infinity();
        var min2 = Math.min;
        module22.exports = function(argument) {
          return argument > 0 ? min2(toIntegerOrInfinity(argument), 9007199254740991) : 0;
        };
      }
    });
    var require_length_of_array_like = __commonJS2({
      "node_modules/core-js/internals/length-of-array-like.js"(exports2, module22) {
        var toLength = require_to_length();
        module22.exports = function(obj) {
          return toLength(obj.length);
        };
      }
    });
    var require_array_includes = __commonJS2({
      "node_modules/core-js/internals/array-includes.js"(exports2, module22) {
        var toIndexedObject = require_to_indexed_object();
        var toAbsoluteIndex = require_to_absolute_index();
        var lengthOfArrayLike = require_length_of_array_like();
        var createMethod = function(IS_INCLUDES) {
          return function($this, el, fromIndex) {
            var O = toIndexedObject($this);
            var length = lengthOfArrayLike(O);
            var index = toAbsoluteIndex(fromIndex, length);
            var value2;
            if (IS_INCLUDES && el != el)
              while (length > index) {
                value2 = O[index++];
                if (value2 != value2)
                  return true;
              }
            else
              for (; length > index; index++) {
                if ((IS_INCLUDES || index in O) && O[index] === el)
                  return IS_INCLUDES || index || 0;
              }
            return !IS_INCLUDES && -1;
          };
        };
        module22.exports = {
          includes: createMethod(true),
          indexOf: createMethod(false)
        };
      }
    });
    var require_object_keys_internal = __commonJS2({
      "node_modules/core-js/internals/object-keys-internal.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var hasOwn = require_has_own_property();
        var toIndexedObject = require_to_indexed_object();
        var indexOf = require_array_includes().indexOf;
        var hiddenKeys = require_hidden_keys();
        var push = uncurryThis([].push);
        module22.exports = function(object, names) {
          var O = toIndexedObject(object);
          var i = 0;
          var result = [];
          var key;
          for (key in O)
            !hasOwn(hiddenKeys, key) && hasOwn(O, key) && push(result, key);
          while (names.length > i)
            if (hasOwn(O, key = names[i++])) {
              ~indexOf(result, key) || push(result, key);
            }
          return result;
        };
      }
    });
    var require_enum_bug_keys = __commonJS2({
      "node_modules/core-js/internals/enum-bug-keys.js"(exports2, module22) {
        module22.exports = [
          "constructor",
          "hasOwnProperty",
          "isPrototypeOf",
          "propertyIsEnumerable",
          "toLocaleString",
          "toString",
          "valueOf"
        ];
      }
    });
    var require_object_get_own_property_names = __commonJS2({
      "node_modules/core-js/internals/object-get-own-property-names.js"(exports2) {
        var internalObjectKeys = require_object_keys_internal();
        var enumBugKeys = require_enum_bug_keys();
        var hiddenKeys = enumBugKeys.concat("length", "prototype");
        exports2.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
          return internalObjectKeys(O, hiddenKeys);
        };
      }
    });
    var require_object_get_own_property_symbols = __commonJS2({
      "node_modules/core-js/internals/object-get-own-property-symbols.js"(exports2) {
        exports2.f = Object.getOwnPropertySymbols;
      }
    });
    var require_own_keys = __commonJS2({
      "node_modules/core-js/internals/own-keys.js"(exports2, module22) {
        var getBuiltIn = require_get_built_in();
        var uncurryThis = require_function_uncurry_this();
        var getOwnPropertyNamesModule = require_object_get_own_property_names();
        var getOwnPropertySymbolsModule = require_object_get_own_property_symbols();
        var anObject = require_an_object();
        var concat = uncurryThis([].concat);
        module22.exports = getBuiltIn("Reflect", "ownKeys") || function ownKeys(it2) {
          var keys3 = getOwnPropertyNamesModule.f(anObject(it2));
          var getOwnPropertySymbols = getOwnPropertySymbolsModule.f;
          return getOwnPropertySymbols ? concat(keys3, getOwnPropertySymbols(it2)) : keys3;
        };
      }
    });
    var require_copy_constructor_properties = __commonJS2({
      "node_modules/core-js/internals/copy-constructor-properties.js"(exports2, module22) {
        var hasOwn = require_has_own_property();
        var ownKeys = require_own_keys();
        var getOwnPropertyDescriptorModule = require_object_get_own_property_descriptor();
        var definePropertyModule = require_object_define_property();
        module22.exports = function(target, source, exceptions) {
          var keys3 = ownKeys(source);
          var defineProperty = definePropertyModule.f;
          var getOwnPropertyDescriptor = getOwnPropertyDescriptorModule.f;
          for (var i = 0; i < keys3.length; i++) {
            var key = keys3[i];
            if (!hasOwn(target, key) && !(exceptions && hasOwn(exceptions, key))) {
              defineProperty(target, key, getOwnPropertyDescriptor(source, key));
            }
          }
        };
      }
    });
    var require_is_forced = __commonJS2({
      "node_modules/core-js/internals/is-forced.js"(exports2, module22) {
        var fails = require_fails();
        var isCallable = require_is_callable();
        var replacement = /#|\.prototype\./;
        var isForced = function(feature, detection) {
          var value2 = data[normalize(feature)];
          return value2 == POLYFILL ? true : value2 == NATIVE ? false : isCallable(detection) ? fails(detection) : !!detection;
        };
        var normalize = isForced.normalize = function(string) {
          return String(string).replace(replacement, ".").toLowerCase();
        };
        var data = isForced.data = {};
        var NATIVE = isForced.NATIVE = "N";
        var POLYFILL = isForced.POLYFILL = "P";
        module22.exports = isForced;
      }
    });
    var require_export = __commonJS2({
      "node_modules/core-js/internals/export.js"(exports2, module22) {
        var global2 = require_global();
        var getOwnPropertyDescriptor = require_object_get_own_property_descriptor().f;
        var createNonEnumerableProperty = require_create_non_enumerable_property();
        var defineBuiltIn = require_define_built_in();
        var defineGlobalProperty = require_define_global_property();
        var copyConstructorProperties = require_copy_constructor_properties();
        var isForced = require_is_forced();
        module22.exports = function(options, source) {
          var TARGET = options.target;
          var GLOBAL = options.global;
          var STATIC = options.stat;
          var FORCED, target, key, targetProperty, sourceProperty, descriptor;
          if (GLOBAL) {
            target = global2;
          } else if (STATIC) {
            target = global2[TARGET] || defineGlobalProperty(TARGET, {});
          } else {
            target = (global2[TARGET] || {}).prototype;
          }
          if (target)
            for (key in source) {
              sourceProperty = source[key];
              if (options.dontCallGetSet) {
                descriptor = getOwnPropertyDescriptor(target, key);
                targetProperty = descriptor && descriptor.value;
              } else
                targetProperty = target[key];
              FORCED = isForced(GLOBAL ? key : TARGET + (STATIC ? "." : "#") + key, options.forced);
              if (!FORCED && targetProperty !== void 0) {
                if (typeof sourceProperty == typeof targetProperty)
                  continue;
                copyConstructorProperties(sourceProperty, targetProperty);
              }
              if (options.sham || targetProperty && targetProperty.sham) {
                createNonEnumerableProperty(sourceProperty, "sham", true);
              }
              defineBuiltIn(target, key, sourceProperty, options);
            }
        };
      }
    });
    var require_is_array = __commonJS2({
      "node_modules/core-js/internals/is-array.js"(exports2, module22) {
        var classof = require_classof_raw();
        module22.exports = Array.isArray || function isArray2(argument) {
          return classof(argument) == "Array";
        };
      }
    });
    var require_does_not_exceed_safe_integer = __commonJS2({
      "node_modules/core-js/internals/does-not-exceed-safe-integer.js"(exports2, module22) {
        var $TypeError = TypeError;
        var MAX_SAFE_INTEGER = 9007199254740991;
        module22.exports = function(it2) {
          if (it2 > MAX_SAFE_INTEGER)
            throw $TypeError("Maximum allowed index exceeded");
          return it2;
        };
      }
    });
    var require_function_uncurry_this_clause = __commonJS2({
      "node_modules/core-js/internals/function-uncurry-this-clause.js"(exports2, module22) {
        var classofRaw = require_classof_raw();
        var uncurryThis = require_function_uncurry_this();
        module22.exports = function(fn) {
          if (classofRaw(fn) === "Function")
            return uncurryThis(fn);
        };
      }
    });
    var require_function_bind_context = __commonJS2({
      "node_modules/core-js/internals/function-bind-context.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this_clause();
        var aCallable = require_a_callable();
        var NATIVE_BIND = require_function_bind_native();
        var bind = uncurryThis(uncurryThis.bind);
        module22.exports = function(fn, that) {
          aCallable(fn);
          return that === void 0 ? fn : NATIVE_BIND ? bind(fn, that) : function() {
            return fn.apply(that, arguments);
          };
        };
      }
    });
    var require_flatten_into_array = __commonJS2({
      "node_modules/core-js/internals/flatten-into-array.js"(exports2, module22) {
        "use strict";
        var isArray2 = require_is_array();
        var lengthOfArrayLike = require_length_of_array_like();
        var doesNotExceedSafeInteger = require_does_not_exceed_safe_integer();
        var bind = require_function_bind_context();
        var flattenIntoArray = function(target, original, source, sourceLen, start, depth, mapper, thisArg) {
          var targetIndex = start;
          var sourceIndex = 0;
          var mapFn = mapper ? bind(mapper, thisArg) : false;
          var element, elementLen;
          while (sourceIndex < sourceLen) {
            if (sourceIndex in source) {
              element = mapFn ? mapFn(source[sourceIndex], sourceIndex, original) : source[sourceIndex];
              if (depth > 0 && isArray2(element)) {
                elementLen = lengthOfArrayLike(element);
                targetIndex = flattenIntoArray(target, original, element, elementLen, targetIndex, depth - 1) - 1;
              } else {
                doesNotExceedSafeInteger(targetIndex + 1);
                target[targetIndex] = element;
              }
              targetIndex++;
            }
            sourceIndex++;
          }
          return targetIndex;
        };
        module22.exports = flattenIntoArray;
      }
    });
    var require_to_string_tag_support = __commonJS2({
      "node_modules/core-js/internals/to-string-tag-support.js"(exports2, module22) {
        var wellKnownSymbol = require_well_known_symbol();
        var TO_STRING_TAG = wellKnownSymbol("toStringTag");
        var test = {};
        test[TO_STRING_TAG] = "z";
        module22.exports = String(test) === "[object z]";
      }
    });
    var require_classof = __commonJS2({
      "node_modules/core-js/internals/classof.js"(exports2, module22) {
        var TO_STRING_TAG_SUPPORT = require_to_string_tag_support();
        var isCallable = require_is_callable();
        var classofRaw = require_classof_raw();
        var wellKnownSymbol = require_well_known_symbol();
        var TO_STRING_TAG = wellKnownSymbol("toStringTag");
        var $Object = Object;
        var CORRECT_ARGUMENTS = classofRaw(function() {
          return arguments;
        }()) == "Arguments";
        var tryGet = function(it2, key) {
          try {
            return it2[key];
          } catch (error) {
          }
        };
        module22.exports = TO_STRING_TAG_SUPPORT ? classofRaw : function(it2) {
          var O, tag, result;
          return it2 === void 0 ? "Undefined" : it2 === null ? "Null" : typeof (tag = tryGet(O = $Object(it2), TO_STRING_TAG)) == "string" ? tag : CORRECT_ARGUMENTS ? classofRaw(O) : (result = classofRaw(O)) == "Object" && isCallable(O.callee) ? "Arguments" : result;
        };
      }
    });
    var require_is_constructor = __commonJS2({
      "node_modules/core-js/internals/is-constructor.js"(exports2, module22) {
        var uncurryThis = require_function_uncurry_this();
        var fails = require_fails();
        var isCallable = require_is_callable();
        var classof = require_classof();
        var getBuiltIn = require_get_built_in();
        var inspectSource = require_inspect_source();
        var noop = function() {
        };
        var empty = [];
        var construct = getBuiltIn("Reflect", "construct");
        var constructorRegExp = /^\s*(?:class|function)\b/;
        var exec2 = uncurryThis(constructorRegExp.exec);
        var INCORRECT_TO_STRING = !constructorRegExp.exec(noop);
        var isConstructorModern = function isConstructor(argument) {
          if (!isCallable(argument))
            return false;
          try {
            construct(noop, empty, argument);
            return true;
          } catch (error) {
            return false;
          }
        };
        var isConstructorLegacy = function isConstructor(argument) {
          if (!isCallable(argument))
            return false;
          switch (classof(argument)) {
            case "AsyncFunction":
            case "GeneratorFunction":
            case "AsyncGeneratorFunction":
              return false;
          }
          try {
            return INCORRECT_TO_STRING || !!exec2(constructorRegExp, inspectSource(argument));
          } catch (error) {
            return true;
          }
        };
        isConstructorLegacy.sham = true;
        module22.exports = !construct || fails(function() {
          var called;
          return isConstructorModern(isConstructorModern.call) || !isConstructorModern(Object) || !isConstructorModern(function() {
            called = true;
          }) || called;
        }) ? isConstructorLegacy : isConstructorModern;
      }
    });
    var require_array_species_constructor = __commonJS2({
      "node_modules/core-js/internals/array-species-constructor.js"(exports2, module22) {
        var isArray2 = require_is_array();
        var isConstructor = require_is_constructor();
        var isObject = require_is_object();
        var wellKnownSymbol = require_well_known_symbol();
        var SPECIES = wellKnownSymbol("species");
        var $Array = Array;
        module22.exports = function(originalArray) {
          var C;
          if (isArray2(originalArray)) {
            C = originalArray.constructor;
            if (isConstructor(C) && (C === $Array || isArray2(C.prototype)))
              C = void 0;
            else if (isObject(C)) {
              C = C[SPECIES];
              if (C === null)
                C = void 0;
            }
          }
          return C === void 0 ? $Array : C;
        };
      }
    });
    var require_array_species_create = __commonJS2({
      "node_modules/core-js/internals/array-species-create.js"(exports2, module22) {
        var arraySpeciesConstructor = require_array_species_constructor();
        module22.exports = function(originalArray, length) {
          return new (arraySpeciesConstructor(originalArray))(length === 0 ? 0 : length);
        };
      }
    });
    var require_es_array_flat_map = __commonJS2({
      "node_modules/core-js/modules/es.array.flat-map.js"() {
        "use strict";
        var $2 = require_export();
        var flattenIntoArray = require_flatten_into_array();
        var aCallable = require_a_callable();
        var toObject = require_to_object();
        var lengthOfArrayLike = require_length_of_array_like();
        var arraySpeciesCreate = require_array_species_create();
        $2({ target: "Array", proto: true }, {
          flatMap: function flatMap(callbackfn) {
            var O = toObject(this);
            var sourceLen = lengthOfArrayLike(O);
            var A;
            aCallable(callbackfn);
            A = arraySpeciesCreate(O, 0);
            A.length = flattenIntoArray(A, O, O, sourceLen, 0, 1, callbackfn, arguments.length > 1 ? arguments[1] : void 0);
            return A;
          }
        });
      }
    });
    var require_iterators = __commonJS2({
      "node_modules/core-js/internals/iterators.js"(exports2, module22) {
        module22.exports = {};
      }
    });
    var require_is_array_iterator_method = __commonJS2({
      "node_modules/core-js/internals/is-array-iterator-method.js"(exports2, module22) {
        var wellKnownSymbol = require_well_known_symbol();
        var Iterators = require_iterators();
        var ITERATOR = wellKnownSymbol("iterator");
        var ArrayPrototype = Array.prototype;
        module22.exports = function(it2) {
          return it2 !== void 0 && (Iterators.Array === it2 || ArrayPrototype[ITERATOR] === it2);
        };
      }
    });
    var require_get_iterator_method = __commonJS2({
      "node_modules/core-js/internals/get-iterator-method.js"(exports2, module22) {
        var classof = require_classof();
        var getMethod = require_get_method();
        var isNullOrUndefined = require_is_null_or_undefined();
        var Iterators = require_iterators();
        var wellKnownSymbol = require_well_known_symbol();
        var ITERATOR = wellKnownSymbol("iterator");
        module22.exports = function(it2) {
          if (!isNullOrUndefined(it2))
            return getMethod(it2, ITERATOR) || getMethod(it2, "@@iterator") || Iterators[classof(it2)];
        };
      }
    });
    var require_get_iterator = __commonJS2({
      "node_modules/core-js/internals/get-iterator.js"(exports2, module22) {
        var call = require_function_call();
        var aCallable = require_a_callable();
        var anObject = require_an_object();
        var tryToString = require_try_to_string();
        var getIteratorMethod = require_get_iterator_method();
        var $TypeError = TypeError;
        module22.exports = function(argument, usingIterator) {
          var iteratorMethod = arguments.length < 2 ? getIteratorMethod(argument) : usingIterator;
          if (aCallable(iteratorMethod))
            return anObject(call(iteratorMethod, argument));
          throw $TypeError(tryToString(argument) + " is not iterable");
        };
      }
    });
    var require_iterator_close = __commonJS2({
      "node_modules/core-js/internals/iterator-close.js"(exports2, module22) {
        var call = require_function_call();
        var anObject = require_an_object();
        var getMethod = require_get_method();
        module22.exports = function(iterator, kind, value2) {
          var innerResult, innerError;
          anObject(iterator);
          try {
            innerResult = getMethod(iterator, "return");
            if (!innerResult) {
              if (kind === "throw")
                throw value2;
              return value2;
            }
            innerResult = call(innerResult, iterator);
          } catch (error) {
            innerError = true;
            innerResult = error;
          }
          if (kind === "throw")
            throw value2;
          if (innerError)
            throw innerResult;
          anObject(innerResult);
          return value2;
        };
      }
    });
    var require_iterate = __commonJS2({
      "node_modules/core-js/internals/iterate.js"(exports2, module22) {
        var bind = require_function_bind_context();
        var call = require_function_call();
        var anObject = require_an_object();
        var tryToString = require_try_to_string();
        var isArrayIteratorMethod = require_is_array_iterator_method();
        var lengthOfArrayLike = require_length_of_array_like();
        var isPrototypeOf2 = require_object_is_prototype_of();
        var getIterator = require_get_iterator();
        var getIteratorMethod = require_get_iterator_method();
        var iteratorClose = require_iterator_close();
        var $TypeError = TypeError;
        var Result = function(stopped, result) {
          this.stopped = stopped;
          this.result = result;
        };
        var ResultPrototype = Result.prototype;
        module22.exports = function(iterable, unboundFunction, options) {
          var that = options && options.that;
          var AS_ENTRIES = !!(options && options.AS_ENTRIES);
          var IS_RECORD = !!(options && options.IS_RECORD);
          var IS_ITERATOR = !!(options && options.IS_ITERATOR);
          var INTERRUPTED = !!(options && options.INTERRUPTED);
          var fn = bind(unboundFunction, that);
          var iterator, iterFn, index, length, result, next, step;
          var stop = function(condition) {
            if (iterator)
              iteratorClose(iterator, "normal", condition);
            return new Result(true, condition);
          };
          var callFn = function(value2) {
            if (AS_ENTRIES) {
              anObject(value2);
              return INTERRUPTED ? fn(value2[0], value2[1], stop) : fn(value2[0], value2[1]);
            }
            return INTERRUPTED ? fn(value2, stop) : fn(value2);
          };
          if (IS_RECORD) {
            iterator = iterable.iterator;
          } else if (IS_ITERATOR) {
            iterator = iterable;
          } else {
            iterFn = getIteratorMethod(iterable);
            if (!iterFn)
              throw $TypeError(tryToString(iterable) + " is not iterable");
            if (isArrayIteratorMethod(iterFn)) {
              for (index = 0, length = lengthOfArrayLike(iterable); length > index; index++) {
                result = callFn(iterable[index]);
                if (result && isPrototypeOf2(ResultPrototype, result))
                  return result;
              }
              return new Result(false);
            }
            iterator = getIterator(iterable, iterFn);
          }
          next = IS_RECORD ? iterable.next : iterator.next;
          while (!(step = call(next, iterator)).done) {
            try {
              result = callFn(step.value);
            } catch (error) {
              iteratorClose(iterator, "throw", error);
            }
            if (typeof result == "object" && result && isPrototypeOf2(ResultPrototype, result))
              return result;
          }
          return new Result(false);
        };
      }
    });
    var require_create_property = __commonJS2({
      "node_modules/core-js/internals/create-property.js"(exports2, module22) {
        "use strict";
        var toPropertyKey = require_to_property_key();
        var definePropertyModule = require_object_define_property();
        var createPropertyDescriptor = require_create_property_descriptor();
        module22.exports = function(object, key, value2) {
          var propertyKey = toPropertyKey(key);
          if (propertyKey in object)
            definePropertyModule.f(object, propertyKey, createPropertyDescriptor(0, value2));
          else
            object[propertyKey] = value2;
        };
      }
    });
    var require_es_object_from_entries = __commonJS2({
      "node_modules/core-js/modules/es.object.from-entries.js"() {
        var $2 = require_export();
        var iterate = require_iterate();
        var createProperty = require_create_property();
        $2({ target: "Object", stat: true }, {
          fromEntries: function fromEntries(iterable) {
            var obj = {};
            iterate(iterable, function(k, v) {
              createProperty(obj, k, v);
            }, { AS_ENTRIES: true });
            return obj;
          }
        });
      }
    });
    var require_define_built_in_accessor = __commonJS2({
      "node_modules/core-js/internals/define-built-in-accessor.js"(exports2, module22) {
        var makeBuiltIn = require_make_built_in();
        var defineProperty = require_object_define_property();
        module22.exports = function(target, name, descriptor) {
          if (descriptor.get)
            makeBuiltIn(descriptor.get, name, { getter: true });
          if (descriptor.set)
            makeBuiltIn(descriptor.set, name, { setter: true });
          return defineProperty.f(target, name, descriptor);
        };
      }
    });
    var require_regexp_flags = __commonJS2({
      "node_modules/core-js/internals/regexp-flags.js"(exports2, module22) {
        "use strict";
        var anObject = require_an_object();
        module22.exports = function() {
          var that = anObject(this);
          var result = "";
          if (that.hasIndices)
            result += "d";
          if (that.global)
            result += "g";
          if (that.ignoreCase)
            result += "i";
          if (that.multiline)
            result += "m";
          if (that.dotAll)
            result += "s";
          if (that.unicode)
            result += "u";
          if (that.unicodeSets)
            result += "v";
          if (that.sticky)
            result += "y";
          return result;
        };
      }
    });
    var require_es_regexp_flags = __commonJS2({
      "node_modules/core-js/modules/es.regexp.flags.js"() {
        var global2 = require_global();
        var DESCRIPTORS = require_descriptors();
        var defineBuiltInAccessor = require_define_built_in_accessor();
        var regExpFlags = require_regexp_flags();
        var fails = require_fails();
        var RegExp2 = global2.RegExp;
        var RegExpPrototype = RegExp2.prototype;
        var FORCED = DESCRIPTORS && fails(function() {
          var INDICES_SUPPORT = true;
          try {
            RegExp2(".", "d");
          } catch (error) {
            INDICES_SUPPORT = false;
          }
          var O = {};
          var calls = "";
          var expected = INDICES_SUPPORT ? "dgimsy" : "gimsy";
          var addGetter = function(key2, chr) {
            Object.defineProperty(O, key2, { get: function() {
              calls += chr;
              return true;
            } });
          };
          var pairs = {
            dotAll: "s",
            global: "g",
            ignoreCase: "i",
            multiline: "m",
            sticky: "y"
          };
          if (INDICES_SUPPORT)
            pairs.hasIndices = "d";
          for (var key in pairs)
            addGetter(key, pairs[key]);
          var result = Object.getOwnPropertyDescriptor(RegExpPrototype, "flags").get.call(O);
          return result !== expected || calls !== expected;
        });
        if (FORCED)
          defineBuiltInAccessor(RegExpPrototype, "flags", {
            configurable: true,
            get: regExpFlags
          });
      }
    });
    var require_es_array_flat = __commonJS2({
      "node_modules/core-js/modules/es.array.flat.js"() {
        "use strict";
        var $2 = require_export();
        var flattenIntoArray = require_flatten_into_array();
        var toObject = require_to_object();
        var lengthOfArrayLike = require_length_of_array_like();
        var toIntegerOrInfinity = require_to_integer_or_infinity();
        var arraySpeciesCreate = require_array_species_create();
        $2({ target: "Array", proto: true }, {
          flat: function flat() {
            var depthArg = arguments.length ? arguments[0] : void 0;
            var O = toObject(this);
            var sourceLen = lengthOfArrayLike(O);
            var A = arraySpeciesCreate(O, 0);
            A.length = flattenIntoArray(A, O, O, sourceLen, 0, depthArg === void 0 ? 1 : toIntegerOrInfinity(depthArg));
            return A;
          }
        });
      }
    });
    var _excluded = ["cliName", "cliCategory", "cliDescription"];
    var _excluded2 = ["_"];
    var _excluded3 = ["overrides"];
    var _excluded4 = ["languageId"];
    function _objectWithoutProperties(source, excluded) {
      if (source == null)
        return {};
      var target = _objectWithoutPropertiesLoose(source, excluded);
      var key, i;
      if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
          key = sourceSymbolKeys[i];
          if (excluded.indexOf(key) >= 0)
            continue;
          if (!Object.prototype.propertyIsEnumerable.call(source, key))
            continue;
          target[key] = source[key];
        }
      }
      return target;
    }
    function _objectWithoutPropertiesLoose(source, excluded) {
      if (source == null)
        return {};
      var target = {};
      var sourceKeys = Object.keys(source);
      var key, i;
      for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0)
          continue;
        target[key] = source[key];
      }
      return target;
    }
    require_es_array_flat_map();
    require_es_object_from_entries();
    require_es_regexp_flags();
    require_es_array_flat();
    var __create2 = Object.create;
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames22 = Object.getOwnPropertyNames;
    var __getProtoOf2 = Object.getPrototypeOf;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __esm = (fn, res) => function __init() {
      return fn && (res = (0, fn[__getOwnPropNames22(fn)[0]])(fn = 0)), res;
    };
    var __commonJS22 = (cb, mod) => function __require() {
      return mod || (0, cb[__getOwnPropNames22(cb)[0]])((mod = {
        exports: {}
      }).exports, mod), mod.exports;
    };
    var __export = (target, all) => {
      for (var name in all)
        __defProp2(target, name, {
          get: all[name],
          enumerable: true
        });
    };
    var __copyProps2 = (to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames22(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, {
              get: () => from[key],
              enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable
            });
      }
      return to;
    };
    var __toESM2 = (mod, isNodeMode, target) => (target = mod != null ? __create2(__getProtoOf2(mod)) : {}, __copyProps2(isNodeMode || !mod || !mod.__esModule ? __defProp2(target, "default", {
      value: mod,
      enumerable: true
    }) : target, mod));
    var __toCommonJS = (mod) => __copyProps2(__defProp2({}, "__esModule", {
      value: true
    }), mod);
    var require_base3 = __commonJS22({
      "node_modules/diff/lib/diff/base.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2["default"] = Diff;
        function Diff() {
        }
        Diff.prototype = {
          diff: function diff(oldString, newString) {
            var options = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
            var callback = options.callback;
            if (typeof options === "function") {
              callback = options;
              options = {};
            }
            this.options = options;
            var self2 = this;
            function done(value2) {
              if (callback) {
                setTimeout(function() {
                  callback(void 0, value2);
                }, 0);
                return true;
              } else {
                return value2;
              }
            }
            oldString = this.castInput(oldString);
            newString = this.castInput(newString);
            oldString = this.removeEmpty(this.tokenize(oldString));
            newString = this.removeEmpty(this.tokenize(newString));
            var newLen = newString.length, oldLen = oldString.length;
            var editLength = 1;
            var maxEditLength = newLen + oldLen;
            var bestPath = [{
              newPos: -1,
              components: []
            }];
            var oldPos = this.extractCommon(bestPath[0], newString, oldString, 0);
            if (bestPath[0].newPos + 1 >= newLen && oldPos + 1 >= oldLen) {
              return done([{
                value: this.join(newString),
                count: newString.length
              }]);
            }
            function execEditLength() {
              for (var diagonalPath = -1 * editLength; diagonalPath <= editLength; diagonalPath += 2) {
                var basePath = void 0;
                var addPath = bestPath[diagonalPath - 1], removePath = bestPath[diagonalPath + 1], _oldPos = (removePath ? removePath.newPos : 0) - diagonalPath;
                if (addPath) {
                  bestPath[diagonalPath - 1] = void 0;
                }
                var canAdd = addPath && addPath.newPos + 1 < newLen, canRemove = removePath && 0 <= _oldPos && _oldPos < oldLen;
                if (!canAdd && !canRemove) {
                  bestPath[diagonalPath] = void 0;
                  continue;
                }
                if (!canAdd || canRemove && addPath.newPos < removePath.newPos) {
                  basePath = clonePath(removePath);
                  self2.pushComponent(basePath.components, void 0, true);
                } else {
                  basePath = addPath;
                  basePath.newPos++;
                  self2.pushComponent(basePath.components, true, void 0);
                }
                _oldPos = self2.extractCommon(basePath, newString, oldString, diagonalPath);
                if (basePath.newPos + 1 >= newLen && _oldPos + 1 >= oldLen) {
                  return done(buildValues(self2, basePath.components, newString, oldString, self2.useLongestToken));
                } else {
                  bestPath[diagonalPath] = basePath;
                }
              }
              editLength++;
            }
            if (callback) {
              (function exec2() {
                setTimeout(function() {
                  if (editLength > maxEditLength) {
                    return callback();
                  }
                  if (!execEditLength()) {
                    exec2();
                  }
                }, 0);
              })();
            } else {
              while (editLength <= maxEditLength) {
                var ret = execEditLength();
                if (ret) {
                  return ret;
                }
              }
            }
          },
          pushComponent: function pushComponent(components, added, removed) {
            var last2 = components[components.length - 1];
            if (last2 && last2.added === added && last2.removed === removed) {
              components[components.length - 1] = {
                count: last2.count + 1,
                added,
                removed
              };
            } else {
              components.push({
                count: 1,
                added,
                removed
              });
            }
          },
          extractCommon: function extractCommon(basePath, newString, oldString, diagonalPath) {
            var newLen = newString.length, oldLen = oldString.length, newPos = basePath.newPos, oldPos = newPos - diagonalPath, commonCount = 0;
            while (newPos + 1 < newLen && oldPos + 1 < oldLen && this.equals(newString[newPos + 1], oldString[oldPos + 1])) {
              newPos++;
              oldPos++;
              commonCount++;
            }
            if (commonCount) {
              basePath.components.push({
                count: commonCount
              });
            }
            basePath.newPos = newPos;
            return oldPos;
          },
          equals: function equals(left, right) {
            if (this.options.comparator) {
              return this.options.comparator(left, right);
            } else {
              return left === right || this.options.ignoreCase && left.toLowerCase() === right.toLowerCase();
            }
          },
          removeEmpty: function removeEmpty(array) {
            var ret = [];
            for (var i = 0; i < array.length; i++) {
              if (array[i]) {
                ret.push(array[i]);
              }
            }
            return ret;
          },
          castInput: function castInput(value2) {
            return value2;
          },
          tokenize: function tokenize(value2) {
            return value2.split("");
          },
          join: function join(chars) {
            return chars.join("");
          }
        };
        function buildValues(diff, components, newString, oldString, useLongestToken) {
          var componentPos = 0, componentLen = components.length, newPos = 0, oldPos = 0;
          for (; componentPos < componentLen; componentPos++) {
            var component = components[componentPos];
            if (!component.removed) {
              if (!component.added && useLongestToken) {
                var value2 = newString.slice(newPos, newPos + component.count);
                value2 = value2.map(function(value22, i) {
                  var oldValue = oldString[oldPos + i];
                  return oldValue.length > value22.length ? oldValue : value22;
                });
                component.value = diff.join(value2);
              } else {
                component.value = diff.join(newString.slice(newPos, newPos + component.count));
              }
              newPos += component.count;
              if (!component.added) {
                oldPos += component.count;
              }
            } else {
              component.value = diff.join(oldString.slice(oldPos, oldPos + component.count));
              oldPos += component.count;
              if (componentPos && components[componentPos - 1].added) {
                var tmp = components[componentPos - 1];
                components[componentPos - 1] = components[componentPos];
                components[componentPos] = tmp;
              }
            }
          }
          var lastComponent = components[componentLen - 1];
          if (componentLen > 1 && typeof lastComponent.value === "string" && (lastComponent.added || lastComponent.removed) && diff.equals("", lastComponent.value)) {
            components[componentLen - 2].value += lastComponent.value;
            components.pop();
          }
          return components;
        }
        function clonePath(path2) {
          return {
            newPos: path2.newPos,
            components: path2.components.slice(0)
          };
        }
      }
    });
    var require_array = __commonJS22({
      "node_modules/diff/lib/diff/array.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.diffArrays = diffArrays;
        exports2.arrayDiff = void 0;
        var _base = _interopRequireDefault(require_base3());
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            "default": obj
          };
        }
        var arrayDiff = new _base["default"]();
        exports2.arrayDiff = arrayDiff;
        arrayDiff.tokenize = function(value2) {
          return value2.slice();
        };
        arrayDiff.join = arrayDiff.removeEmpty = function(value2) {
          return value2;
        };
        function diffArrays(oldArr, newArr, callback) {
          return arrayDiff.diff(oldArr, newArr, callback);
        }
      }
    });
    var escape_string_regexp_exports = {};
    __export(escape_string_regexp_exports, {
      default: () => escapeStringRegexp
    });
    function escapeStringRegexp(string) {
      if (typeof string !== "string") {
        throw new TypeError("Expected a string");
      }
      return string.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
    }
    var init_escape_string_regexp = __esm({
      "node_modules/escape-string-regexp/index.js"() {
      }
    });
    var require_get_last = __commonJS22({
      "src/utils/get-last.js"(exports2, module22) {
        "use strict";
        var getLast = (arr) => arr[arr.length - 1];
        module22.exports = getLast;
      }
    });
    var require_debug2 = __commonJS22({
      "node_modules/semver/internal/debug.js"(exports2, module22) {
        var debug = typeof process === "object" && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG) ? (...args) => console.error("SEMVER", ...args) : () => {
        };
        module22.exports = debug;
      }
    });
    var require_constants4 = __commonJS22({
      "node_modules/semver/internal/constants.js"(exports2, module22) {
        var SEMVER_SPEC_VERSION = "2.0.0";
        var MAX_LENGTH = 256;
        var MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER || 9007199254740991;
        var MAX_SAFE_COMPONENT_LENGTH = 16;
        module22.exports = {
          SEMVER_SPEC_VERSION,
          MAX_LENGTH,
          MAX_SAFE_INTEGER,
          MAX_SAFE_COMPONENT_LENGTH
        };
      }
    });
    var require_re = __commonJS22({
      "node_modules/semver/internal/re.js"(exports2, module22) {
        var {
          MAX_SAFE_COMPONENT_LENGTH
        } = require_constants4();
        var debug = require_debug2();
        exports2 = module22.exports = {};
        var re = exports2.re = [];
        var src = exports2.src = [];
        var t3 = exports2.t = {};
        var R = 0;
        var createToken = (name, value2, isGlobal) => {
          const index = R++;
          debug(name, index, value2);
          t3[name] = index;
          src[index] = value2;
          re[index] = new RegExp(value2, isGlobal ? "g" : void 0);
        };
        createToken("NUMERICIDENTIFIER", "0|[1-9]\\d*");
        createToken("NUMERICIDENTIFIERLOOSE", "[0-9]+");
        createToken("NONNUMERICIDENTIFIER", "\\d*[a-zA-Z-][a-zA-Z0-9-]*");
        createToken("MAINVERSION", `(${src[t3.NUMERICIDENTIFIER]})\\.(${src[t3.NUMERICIDENTIFIER]})\\.(${src[t3.NUMERICIDENTIFIER]})`);
        createToken("MAINVERSIONLOOSE", `(${src[t3.NUMERICIDENTIFIERLOOSE]})\\.(${src[t3.NUMERICIDENTIFIERLOOSE]})\\.(${src[t3.NUMERICIDENTIFIERLOOSE]})`);
        createToken("PRERELEASEIDENTIFIER", `(?:${src[t3.NUMERICIDENTIFIER]}|${src[t3.NONNUMERICIDENTIFIER]})`);
        createToken("PRERELEASEIDENTIFIERLOOSE", `(?:${src[t3.NUMERICIDENTIFIERLOOSE]}|${src[t3.NONNUMERICIDENTIFIER]})`);
        createToken("PRERELEASE", `(?:-(${src[t3.PRERELEASEIDENTIFIER]}(?:\\.${src[t3.PRERELEASEIDENTIFIER]})*))`);
        createToken("PRERELEASELOOSE", `(?:-?(${src[t3.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${src[t3.PRERELEASEIDENTIFIERLOOSE]})*))`);
        createToken("BUILDIDENTIFIER", "[0-9A-Za-z-]+");
        createToken("BUILD", `(?:\\+(${src[t3.BUILDIDENTIFIER]}(?:\\.${src[t3.BUILDIDENTIFIER]})*))`);
        createToken("FULLPLAIN", `v?${src[t3.MAINVERSION]}${src[t3.PRERELEASE]}?${src[t3.BUILD]}?`);
        createToken("FULL", `^${src[t3.FULLPLAIN]}$`);
        createToken("LOOSEPLAIN", `[v=\\s]*${src[t3.MAINVERSIONLOOSE]}${src[t3.PRERELEASELOOSE]}?${src[t3.BUILD]}?`);
        createToken("LOOSE", `^${src[t3.LOOSEPLAIN]}$`);
        createToken("GTLT", "((?:<|>)?=?)");
        createToken("XRANGEIDENTIFIERLOOSE", `${src[t3.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`);
        createToken("XRANGEIDENTIFIER", `${src[t3.NUMERICIDENTIFIER]}|x|X|\\*`);
        createToken("XRANGEPLAIN", `[v=\\s]*(${src[t3.XRANGEIDENTIFIER]})(?:\\.(${src[t3.XRANGEIDENTIFIER]})(?:\\.(${src[t3.XRANGEIDENTIFIER]})(?:${src[t3.PRERELEASE]})?${src[t3.BUILD]}?)?)?`);
        createToken("XRANGEPLAINLOOSE", `[v=\\s]*(${src[t3.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t3.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t3.XRANGEIDENTIFIERLOOSE]})(?:${src[t3.PRERELEASELOOSE]})?${src[t3.BUILD]}?)?)?`);
        createToken("XRANGE", `^${src[t3.GTLT]}\\s*${src[t3.XRANGEPLAIN]}$`);
        createToken("XRANGELOOSE", `^${src[t3.GTLT]}\\s*${src[t3.XRANGEPLAINLOOSE]}$`);
        createToken("COERCE", `${"(^|[^\\d])(\\d{1,"}${MAX_SAFE_COMPONENT_LENGTH}})(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?(?:$|[^\\d])`);
        createToken("COERCERTL", src[t3.COERCE], true);
        createToken("LONETILDE", "(?:~>?)");
        createToken("TILDETRIM", `(\\s*)${src[t3.LONETILDE]}\\s+`, true);
        exports2.tildeTrimReplace = "$1~";
        createToken("TILDE", `^${src[t3.LONETILDE]}${src[t3.XRANGEPLAIN]}$`);
        createToken("TILDELOOSE", `^${src[t3.LONETILDE]}${src[t3.XRANGEPLAINLOOSE]}$`);
        createToken("LONECARET", "(?:\\^)");
        createToken("CARETTRIM", `(\\s*)${src[t3.LONECARET]}\\s+`, true);
        exports2.caretTrimReplace = "$1^";
        createToken("CARET", `^${src[t3.LONECARET]}${src[t3.XRANGEPLAIN]}$`);
        createToken("CARETLOOSE", `^${src[t3.LONECARET]}${src[t3.XRANGEPLAINLOOSE]}$`);
        createToken("COMPARATORLOOSE", `^${src[t3.GTLT]}\\s*(${src[t3.LOOSEPLAIN]})$|^$`);
        createToken("COMPARATOR", `^${src[t3.GTLT]}\\s*(${src[t3.FULLPLAIN]})$|^$`);
        createToken("COMPARATORTRIM", `(\\s*)${src[t3.GTLT]}\\s*(${src[t3.LOOSEPLAIN]}|${src[t3.XRANGEPLAIN]})`, true);
        exports2.comparatorTrimReplace = "$1$2$3";
        createToken("HYPHENRANGE", `^\\s*(${src[t3.XRANGEPLAIN]})\\s+-\\s+(${src[t3.XRANGEPLAIN]})\\s*$`);
        createToken("HYPHENRANGELOOSE", `^\\s*(${src[t3.XRANGEPLAINLOOSE]})\\s+-\\s+(${src[t3.XRANGEPLAINLOOSE]})\\s*$`);
        createToken("STAR", "(<|>)?=?\\s*\\*");
        createToken("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$");
        createToken("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
      }
    });
    var require_parse_options = __commonJS22({
      "node_modules/semver/internal/parse-options.js"(exports2, module22) {
        var opts = ["includePrerelease", "loose", "rtl"];
        var parseOptions = (options) => !options ? {} : typeof options !== "object" ? {
          loose: true
        } : opts.filter((k) => options[k]).reduce((o, k) => {
          o[k] = true;
          return o;
        }, {});
        module22.exports = parseOptions;
      }
    });
    var require_identifiers = __commonJS22({
      "node_modules/semver/internal/identifiers.js"(exports2, module22) {
        var numeric = /^[0-9]+$/;
        var compareIdentifiers = (a, b) => {
          const anum = numeric.test(a);
          const bnum = numeric.test(b);
          if (anum && bnum) {
            a = +a;
            b = +b;
          }
          return a === b ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a < b ? -1 : 1;
        };
        var rcompareIdentifiers = (a, b) => compareIdentifiers(b, a);
        module22.exports = {
          compareIdentifiers,
          rcompareIdentifiers
        };
      }
    });
    var require_semver2 = __commonJS22({
      "node_modules/semver/classes/semver.js"(exports2, module22) {
        var debug = require_debug2();
        var {
          MAX_LENGTH,
          MAX_SAFE_INTEGER
        } = require_constants4();
        var {
          re,
          t: t3
        } = require_re();
        var parseOptions = require_parse_options();
        var {
          compareIdentifiers
        } = require_identifiers();
        var SemVer = class {
          constructor(version22, options) {
            options = parseOptions(options);
            if (version22 instanceof SemVer) {
              if (version22.loose === !!options.loose && version22.includePrerelease === !!options.includePrerelease) {
                return version22;
              } else {
                version22 = version22.version;
              }
            } else if (typeof version22 !== "string") {
              throw new TypeError(`Invalid Version: ${version22}`);
            }
            if (version22.length > MAX_LENGTH) {
              throw new TypeError(`version is longer than ${MAX_LENGTH} characters`);
            }
            debug("SemVer", version22, options);
            this.options = options;
            this.loose = !!options.loose;
            this.includePrerelease = !!options.includePrerelease;
            const m = version22.trim().match(options.loose ? re[t3.LOOSE] : re[t3.FULL]);
            if (!m) {
              throw new TypeError(`Invalid Version: ${version22}`);
            }
            this.raw = version22;
            this.major = +m[1];
            this.minor = +m[2];
            this.patch = +m[3];
            if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
              throw new TypeError("Invalid major version");
            }
            if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
              throw new TypeError("Invalid minor version");
            }
            if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
              throw new TypeError("Invalid patch version");
            }
            if (!m[4]) {
              this.prerelease = [];
            } else {
              this.prerelease = m[4].split(".").map((id) => {
                if (/^[0-9]+$/.test(id)) {
                  const num = +id;
                  if (num >= 0 && num < MAX_SAFE_INTEGER) {
                    return num;
                  }
                }
                return id;
              });
            }
            this.build = m[5] ? m[5].split(".") : [];
            this.format();
          }
          format() {
            this.version = `${this.major}.${this.minor}.${this.patch}`;
            if (this.prerelease.length) {
              this.version += `-${this.prerelease.join(".")}`;
            }
            return this.version;
          }
          toString() {
            return this.version;
          }
          compare(other) {
            debug("SemVer.compare", this.version, this.options, other);
            if (!(other instanceof SemVer)) {
              if (typeof other === "string" && other === this.version) {
                return 0;
              }
              other = new SemVer(other, this.options);
            }
            if (other.version === this.version) {
              return 0;
            }
            return this.compareMain(other) || this.comparePre(other);
          }
          compareMain(other) {
            if (!(other instanceof SemVer)) {
              other = new SemVer(other, this.options);
            }
            return compareIdentifiers(this.major, other.major) || compareIdentifiers(this.minor, other.minor) || compareIdentifiers(this.patch, other.patch);
          }
          comparePre(other) {
            if (!(other instanceof SemVer)) {
              other = new SemVer(other, this.options);
            }
            if (this.prerelease.length && !other.prerelease.length) {
              return -1;
            } else if (!this.prerelease.length && other.prerelease.length) {
              return 1;
            } else if (!this.prerelease.length && !other.prerelease.length) {
              return 0;
            }
            let i = 0;
            do {
              const a = this.prerelease[i];
              const b = other.prerelease[i];
              debug("prerelease compare", i, a, b);
              if (a === void 0 && b === void 0) {
                return 0;
              } else if (b === void 0) {
                return 1;
              } else if (a === void 0) {
                return -1;
              } else if (a === b) {
                continue;
              } else {
                return compareIdentifiers(a, b);
              }
            } while (++i);
          }
          compareBuild(other) {
            if (!(other instanceof SemVer)) {
              other = new SemVer(other, this.options);
            }
            let i = 0;
            do {
              const a = this.build[i];
              const b = other.build[i];
              debug("prerelease compare", i, a, b);
              if (a === void 0 && b === void 0) {
                return 0;
              } else if (b === void 0) {
                return 1;
              } else if (a === void 0) {
                return -1;
              } else if (a === b) {
                continue;
              } else {
                return compareIdentifiers(a, b);
              }
            } while (++i);
          }
          inc(release, identifier3) {
            switch (release) {
              case "premajor":
                this.prerelease.length = 0;
                this.patch = 0;
                this.minor = 0;
                this.major++;
                this.inc("pre", identifier3);
                break;
              case "preminor":
                this.prerelease.length = 0;
                this.patch = 0;
                this.minor++;
                this.inc("pre", identifier3);
                break;
              case "prepatch":
                this.prerelease.length = 0;
                this.inc("patch", identifier3);
                this.inc("pre", identifier3);
                break;
              case "prerelease":
                if (this.prerelease.length === 0) {
                  this.inc("patch", identifier3);
                }
                this.inc("pre", identifier3);
                break;
              case "major":
                if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {
                  this.major++;
                }
                this.minor = 0;
                this.patch = 0;
                this.prerelease = [];
                break;
              case "minor":
                if (this.patch !== 0 || this.prerelease.length === 0) {
                  this.minor++;
                }
                this.patch = 0;
                this.prerelease = [];
                break;
              case "patch":
                if (this.prerelease.length === 0) {
                  this.patch++;
                }
                this.prerelease = [];
                break;
              case "pre":
                if (this.prerelease.length === 0) {
                  this.prerelease = [0];
                } else {
                  let i = this.prerelease.length;
                  while (--i >= 0) {
                    if (typeof this.prerelease[i] === "number") {
                      this.prerelease[i]++;
                      i = -2;
                    }
                  }
                  if (i === -1) {
                    this.prerelease.push(0);
                  }
                }
                if (identifier3) {
                  if (compareIdentifiers(this.prerelease[0], identifier3) === 0) {
                    if (isNaN(this.prerelease[1])) {
                      this.prerelease = [identifier3, 0];
                    }
                  } else {
                    this.prerelease = [identifier3, 0];
                  }
                }
                break;
              default:
                throw new Error(`invalid increment argument: ${release}`);
            }
            this.format();
            this.raw = this.version;
            return this;
          }
        };
        module22.exports = SemVer;
      }
    });
    var require_compare = __commonJS22({
      "node_modules/semver/functions/compare.js"(exports2, module22) {
        var SemVer = require_semver2();
        var compare = (a, b, loose) => new SemVer(a, loose).compare(new SemVer(b, loose));
        module22.exports = compare;
      }
    });
    var require_lt = __commonJS22({
      "node_modules/semver/functions/lt.js"(exports2, module22) {
        var compare = require_compare();
        var lt = (a, b, loose) => compare(a, b, loose) < 0;
        module22.exports = lt;
      }
    });
    var require_gte = __commonJS22({
      "node_modules/semver/functions/gte.js"(exports2, module22) {
        var compare = require_compare();
        var gte = (a, b, loose) => compare(a, b, loose) >= 0;
        module22.exports = gte;
      }
    });
    var require_arrayify = __commonJS22({
      "src/utils/arrayify.js"(exports2, module22) {
        "use strict";
        module22.exports = (object, keyName) => Object.entries(object).map(([key, value2]) => Object.assign({
          [keyName]: key
        }, value2));
      }
    });
    var require_lib33 = __commonJS22({
      "node_modules/outdent/lib/index.js"(exports2, module22) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.outdent = void 0;
        function noop() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
          }
        }
        function createWeakMap() {
          if (typeof WeakMap !== "undefined") {
            return /* @__PURE__ */ new WeakMap();
          } else {
            return fakeSetOrMap();
          }
        }
        function fakeSetOrMap() {
          return {
            add: noop,
            delete: noop,
            get: noop,
            set: noop,
            has: function(k) {
              return false;
            }
          };
        }
        var hop = Object.prototype.hasOwnProperty;
        var has = function(obj, prop) {
          return hop.call(obj, prop);
        };
        function extend(target, source) {
          for (var prop in source) {
            if (has(source, prop)) {
              target[prop] = source[prop];
            }
          }
          return target;
        }
        var reLeadingNewline = /^[ \t]*(?:\r\n|\r|\n)/;
        var reTrailingNewline = /(?:\r\n|\r|\n)[ \t]*$/;
        var reStartsWithNewlineOrIsEmpty = /^(?:[\r\n]|$)/;
        var reDetectIndentation = /(?:\r\n|\r|\n)([ \t]*)(?:[^ \t\r\n]|$)/;
        var reOnlyWhitespaceWithAtLeastOneNewline = /^[ \t]*[\r\n][ \t\r\n]*$/;
        function _outdentArray(strings, firstInterpolatedValueSetsIndentationLevel, options) {
          var indentationLevel = 0;
          var match = strings[0].match(reDetectIndentation);
          if (match) {
            indentationLevel = match[1].length;
          }
          var reSource = "(\\r\\n|\\r|\\n).{0," + indentationLevel + "}";
          var reMatchIndent = new RegExp(reSource, "g");
          if (firstInterpolatedValueSetsIndentationLevel) {
            strings = strings.slice(1);
          }
          var newline = options.newline, trimLeadingNewline = options.trimLeadingNewline, trimTrailingNewline = options.trimTrailingNewline;
          var normalizeNewlines = typeof newline === "string";
          var l = strings.length;
          var outdentedStrings = strings.map(function(v, i) {
            v = v.replace(reMatchIndent, "$1");
            if (i === 0 && trimLeadingNewline) {
              v = v.replace(reLeadingNewline, "");
            }
            if (i === l - 1 && trimTrailingNewline) {
              v = v.replace(reTrailingNewline, "");
            }
            if (normalizeNewlines) {
              v = v.replace(/\r\n|\n|\r/g, function(_) {
                return newline;
              });
            }
            return v;
          });
          return outdentedStrings;
        }
        function concatStringsAndValues(strings, values2) {
          var ret = "";
          for (var i = 0, l = strings.length; i < l; i++) {
            ret += strings[i];
            if (i < l - 1) {
              ret += values2[i];
            }
          }
          return ret;
        }
        function isTemplateStringsArray(v) {
          return has(v, "raw") && has(v, "length");
        }
        function createInstance(options) {
          var arrayAutoIndentCache = createWeakMap();
          var arrayFirstInterpSetsIndentCache = createWeakMap();
          function outdent(stringsOrOptions) {
            var values2 = [];
            for (var _i = 1; _i < arguments.length; _i++) {
              values2[_i - 1] = arguments[_i];
            }
            if (isTemplateStringsArray(stringsOrOptions)) {
              var strings = stringsOrOptions;
              var firstInterpolatedValueSetsIndentationLevel = (values2[0] === outdent || values2[0] === defaultOutdent) && reOnlyWhitespaceWithAtLeastOneNewline.test(strings[0]) && reStartsWithNewlineOrIsEmpty.test(strings[1]);
              var cache = firstInterpolatedValueSetsIndentationLevel ? arrayFirstInterpSetsIndentCache : arrayAutoIndentCache;
              var renderedArray = cache.get(strings);
              if (!renderedArray) {
                renderedArray = _outdentArray(strings, firstInterpolatedValueSetsIndentationLevel, options);
                cache.set(strings, renderedArray);
              }
              if (values2.length === 0) {
                return renderedArray[0];
              }
              var rendered = concatStringsAndValues(renderedArray, firstInterpolatedValueSetsIndentationLevel ? values2.slice(1) : values2);
              return rendered;
            } else {
              return createInstance(extend(extend({}, options), stringsOrOptions || {}));
            }
          }
          var fullOutdent = extend(outdent, {
            string: function(str) {
              return _outdentArray([str], false, options)[0];
            }
          });
          return fullOutdent;
        }
        var defaultOutdent = createInstance({
          trimLeadingNewline: true,
          trimTrailingNewline: true
        });
        exports2.outdent = defaultOutdent;
        exports2.default = defaultOutdent;
        if (typeof module22 !== "undefined") {
          try {
            module22.exports = defaultOutdent;
            Object.defineProperty(defaultOutdent, "__esModule", {
              value: true
            });
            defaultOutdent.default = defaultOutdent;
            defaultOutdent.outdent = defaultOutdent;
          } catch (e) {
          }
        }
      }
    });
    var require_core_options = __commonJS22({
      "src/main/core-options.js"(exports2, module22) {
        "use strict";
        var {
          outdent
        } = require_lib33();
        var CATEGORY_CONFIG = "Config";
        var CATEGORY_EDITOR = "Editor";
        var CATEGORY_FORMAT = "Format";
        var CATEGORY_OTHER = "Other";
        var CATEGORY_OUTPUT = "Output";
        var CATEGORY_GLOBAL = "Global";
        var CATEGORY_SPECIAL = "Special";
        var options = {
          cursorOffset: {
            since: "1.4.0",
            category: CATEGORY_SPECIAL,
            type: "int",
            default: -1,
            range: {
              start: -1,
              end: Number.POSITIVE_INFINITY,
              step: 1
            },
            description: outdent`
      Print (to stderr) where a cursor at the given position would move to after formatting.
      This option cannot be used with --range-start and --range-end.
    `,
            cliCategory: CATEGORY_EDITOR
          },
          endOfLine: {
            since: "1.15.0",
            category: CATEGORY_GLOBAL,
            type: "choice",
            default: [{
              since: "1.15.0",
              value: "auto"
            }, {
              since: "2.0.0",
              value: "lf"
            }],
            description: "Which end of line characters to apply.",
            choices: [{
              value: "lf",
              description: "Line Feed only (\\n), common on Linux and macOS as well as inside git repos"
            }, {
              value: "crlf",
              description: "Carriage Return + Line Feed characters (\\r\\n), common on Windows"
            }, {
              value: "cr",
              description: "Carriage Return character only (\\r), used very rarely"
            }, {
              value: "auto",
              description: outdent`
          Maintain existing
          (mixed values within one file are normalised by looking at what's used after the first line)
        `
            }]
          },
          filepath: {
            since: "1.4.0",
            category: CATEGORY_SPECIAL,
            type: "path",
            description: "Specify the input filepath. This will be used to do parser inference.",
            cliName: "stdin-filepath",
            cliCategory: CATEGORY_OTHER,
            cliDescription: "Path to the file to pretend that stdin comes from."
          },
          insertPragma: {
            since: "1.8.0",
            category: CATEGORY_SPECIAL,
            type: "boolean",
            default: false,
            description: "Insert @format pragma into file's first docblock comment.",
            cliCategory: CATEGORY_OTHER
          },
          parser: {
            since: "0.0.10",
            category: CATEGORY_GLOBAL,
            type: "choice",
            default: [{
              since: "0.0.10",
              value: "babylon"
            }, {
              since: "1.13.0",
              value: void 0
            }],
            description: "Which parser to use.",
            exception: (value2) => typeof value2 === "string" || typeof value2 === "function",
            choices: [{
              value: "flow",
              description: "Flow"
            }, {
              value: "babel",
              since: "1.16.0",
              description: "JavaScript"
            }, {
              value: "babel-flow",
              since: "1.16.0",
              description: "Flow"
            }, {
              value: "babel-ts",
              since: "2.0.0",
              description: "TypeScript"
            }, {
              value: "typescript",
              since: "1.4.0",
              description: "TypeScript"
            }, {
              value: "acorn",
              since: "2.6.0",
              description: "JavaScript"
            }, {
              value: "espree",
              since: "2.2.0",
              description: "JavaScript"
            }, {
              value: "meriyah",
              since: "2.2.0",
              description: "JavaScript"
            }, {
              value: "css",
              since: "1.7.1",
              description: "CSS"
            }, {
              value: "less",
              since: "1.7.1",
              description: "Less"
            }, {
              value: "scss",
              since: "1.7.1",
              description: "SCSS"
            }, {
              value: "json",
              since: "1.5.0",
              description: "JSON"
            }, {
              value: "json5",
              since: "1.13.0",
              description: "JSON5"
            }, {
              value: "json-stringify",
              since: "1.13.0",
              description: "JSON.stringify"
            }, {
              value: "graphql",
              since: "1.5.0",
              description: "GraphQL"
            }, {
              value: "markdown",
              since: "1.8.0",
              description: "Markdown"
            }, {
              value: "mdx",
              since: "1.15.0",
              description: "MDX"
            }, {
              value: "vue",
              since: "1.10.0",
              description: "Vue"
            }, {
              value: "yaml",
              since: "1.14.0",
              description: "YAML"
            }, {
              value: "glimmer",
              since: "2.3.0",
              description: "Ember / Handlebars"
            }, {
              value: "html",
              since: "1.15.0",
              description: "HTML"
            }, {
              value: "angular",
              since: "1.15.0",
              description: "Angular"
            }, {
              value: "lwc",
              since: "1.17.0",
              description: "Lightning Web Components"
            }]
          },
          plugins: {
            since: "1.10.0",
            type: "path",
            array: true,
            default: [{
              value: []
            }],
            category: CATEGORY_GLOBAL,
            description: "Add a plugin. Multiple plugins can be passed as separate `--plugin`s.",
            exception: (value2) => typeof value2 === "string" || typeof value2 === "object",
            cliName: "plugin",
            cliCategory: CATEGORY_CONFIG
          },
          pluginSearchDirs: {
            since: "1.13.0",
            type: "path",
            array: true,
            default: [{
              value: []
            }],
            category: CATEGORY_GLOBAL,
            description: outdent`
      Custom directory that contains prettier plugins in node_modules subdirectory.
      Overrides default behavior when plugins are searched relatively to the location of Prettier.
      Multiple values are accepted.
    `,
            exception: (value2) => typeof value2 === "string" || typeof value2 === "object",
            cliName: "plugin-search-dir",
            cliCategory: CATEGORY_CONFIG
          },
          printWidth: {
            since: "0.0.0",
            category: CATEGORY_GLOBAL,
            type: "int",
            default: 80,
            description: "The line length where Prettier will try wrap.",
            range: {
              start: 0,
              end: Number.POSITIVE_INFINITY,
              step: 1
            }
          },
          rangeEnd: {
            since: "1.4.0",
            category: CATEGORY_SPECIAL,
            type: "int",
            default: Number.POSITIVE_INFINITY,
            range: {
              start: 0,
              end: Number.POSITIVE_INFINITY,
              step: 1
            },
            description: outdent`
      Format code ending at a given character offset (exclusive).
      The range will extend forwards to the end of the selected statement.
      This option cannot be used with --cursor-offset.
    `,
            cliCategory: CATEGORY_EDITOR
          },
          rangeStart: {
            since: "1.4.0",
            category: CATEGORY_SPECIAL,
            type: "int",
            default: 0,
            range: {
              start: 0,
              end: Number.POSITIVE_INFINITY,
              step: 1
            },
            description: outdent`
      Format code starting at a given character offset.
      The range will extend backwards to the start of the first line containing the selected statement.
      This option cannot be used with --cursor-offset.
    `,
            cliCategory: CATEGORY_EDITOR
          },
          requirePragma: {
            since: "1.7.0",
            category: CATEGORY_SPECIAL,
            type: "boolean",
            default: false,
            description: outdent`
      Require either '@prettier' or '@format' to be present in the file's first docblock comment
      in order for it to be formatted.
    `,
            cliCategory: CATEGORY_OTHER
          },
          tabWidth: {
            type: "int",
            category: CATEGORY_GLOBAL,
            default: 2,
            description: "Number of spaces per indentation level.",
            range: {
              start: 0,
              end: Number.POSITIVE_INFINITY,
              step: 1
            }
          },
          useTabs: {
            since: "1.0.0",
            category: CATEGORY_GLOBAL,
            type: "boolean",
            default: false,
            description: "Indent with tabs instead of spaces."
          },
          embeddedLanguageFormatting: {
            since: "2.1.0",
            category: CATEGORY_GLOBAL,
            type: "choice",
            default: [{
              since: "2.1.0",
              value: "auto"
            }],
            description: "Control how Prettier formats quoted code embedded in the file.",
            choices: [{
              value: "auto",
              description: "Format embedded code if Prettier can automatically identify it."
            }, {
              value: "off",
              description: "Never automatically format embedded code."
            }]
          }
        };
        module22.exports = {
          CATEGORY_CONFIG,
          CATEGORY_EDITOR,
          CATEGORY_FORMAT,
          CATEGORY_OTHER,
          CATEGORY_OUTPUT,
          CATEGORY_GLOBAL,
          CATEGORY_SPECIAL,
          options
        };
      }
    });
    var require_support = __commonJS22({
      "src/main/support.js"(exports2, module22) {
        "use strict";
        var semver = {
          compare: require_compare(),
          lt: require_lt(),
          gte: require_gte()
        };
        var arrayify = require_arrayify();
        var currentVersion = require_package7().version;
        var coreOptions = require_core_options().options;
        function getSupportInfo2({
          plugins: plugins2 = [],
          showUnreleased = false,
          showDeprecated = false,
          showInternal = false
        } = {}) {
          const version22 = currentVersion.split("-", 1)[0];
          const languages = plugins2.flatMap((plugin) => plugin.languages || []).filter(filterSince);
          const options = arrayify(Object.assign({}, ...plugins2.map(({
            options: options2
          }) => options2), coreOptions), "name").filter((option) => filterSince(option) && filterDeprecated(option)).sort((a, b) => a.name === b.name ? 0 : a.name < b.name ? -1 : 1).map(mapInternal).map((option) => {
            option = Object.assign({}, option);
            if (Array.isArray(option.default)) {
              option.default = option.default.length === 1 ? option.default[0].value : option.default.filter(filterSince).sort((info1, info2) => semver.compare(info2.since, info1.since))[0].value;
            }
            if (Array.isArray(option.choices)) {
              option.choices = option.choices.filter((option2) => filterSince(option2) && filterDeprecated(option2));
              if (option.name === "parser") {
                collectParsersFromLanguages(option, languages, plugins2);
              }
            }
            const pluginDefaults = Object.fromEntries(plugins2.filter((plugin) => plugin.defaultOptions && plugin.defaultOptions[option.name] !== void 0).map((plugin) => [plugin.name, plugin.defaultOptions[option.name]]));
            return Object.assign(Object.assign({}, option), {}, {
              pluginDefaults
            });
          });
          return {
            languages,
            options
          };
          function filterSince(object) {
            return showUnreleased || !("since" in object) || object.since && semver.gte(version22, object.since);
          }
          function filterDeprecated(object) {
            return showDeprecated || !("deprecated" in object) || object.deprecated && semver.lt(version22, object.deprecated);
          }
          function mapInternal(object) {
            if (showInternal) {
              return object;
            }
            const {
              cliName,
              cliCategory,
              cliDescription
            } = object, newObject = _objectWithoutProperties(object, _excluded);
            return newObject;
          }
        }
        function collectParsersFromLanguages(option, languages, plugins2) {
          const existingValues = new Set(option.choices.map((choice) => choice.value));
          for (const language of languages) {
            if (language.parsers) {
              for (const value2 of language.parsers) {
                if (!existingValues.has(value2)) {
                  existingValues.add(value2);
                  const plugin = plugins2.find((plugin2) => plugin2.parsers && plugin2.parsers[value2]);
                  let description = language.name;
                  if (plugin && plugin.name) {
                    description += ` (plugin: ${plugin.name})`;
                  }
                  option.choices.push({
                    value: value2,
                    description
                  });
                }
              }
            }
          }
        }
        module22.exports = {
          getSupportInfo: getSupportInfo2
        };
      }
    });
    var require_is_non_empty_array = __commonJS22({
      "src/utils/is-non-empty-array.js"(exports2, module22) {
        "use strict";
        function isNonEmptyArray(object) {
          return Array.isArray(object) && object.length > 0;
        }
        module22.exports = isNonEmptyArray;
      }
    });
    function ansiRegex({
      onlyFirst = false
    } = {}) {
      const pattern = ["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)", "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"].join("|");
      return new RegExp(pattern, onlyFirst ? void 0 : "g");
    }
    var init_ansi_regex = __esm({
      "node_modules/strip-ansi/node_modules/ansi-regex/index.js"() {
      }
    });
    function stripAnsi(string) {
      if (typeof string !== "string") {
        throw new TypeError(`Expected a \`string\`, got \`${typeof string}\``);
      }
      return string.replace(ansiRegex(), "");
    }
    var init_strip_ansi = __esm({
      "node_modules/strip-ansi/index.js"() {
        init_ansi_regex();
      }
    });
    function isFullwidthCodePoint(codePoint) {
      if (!Number.isInteger(codePoint)) {
        return false;
      }
      return codePoint >= 4352 && (codePoint <= 4447 || codePoint === 9001 || codePoint === 9002 || 11904 <= codePoint && codePoint <= 12871 && codePoint !== 12351 || 12880 <= codePoint && codePoint <= 19903 || 19968 <= codePoint && codePoint <= 42182 || 43360 <= codePoint && codePoint <= 43388 || 44032 <= codePoint && codePoint <= 55203 || 63744 <= codePoint && codePoint <= 64255 || 65040 <= codePoint && codePoint <= 65049 || 65072 <= codePoint && codePoint <= 65131 || 65281 <= codePoint && codePoint <= 65376 || 65504 <= codePoint && codePoint <= 65510 || 110592 <= codePoint && codePoint <= 110593 || 127488 <= codePoint && codePoint <= 127569 || 131072 <= codePoint && codePoint <= 262141);
    }
    var init_is_fullwidth_code_point = __esm({
      "node_modules/is-fullwidth-code-point/index.js"() {
      }
    });
    var require_emoji_regex2 = __commonJS22({
      "node_modules/emoji-regex/index.js"(exports2, module22) {
        "use strict";
        module22.exports = function() {
          return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67)\uDB40\uDC7F|(?:\uD83E\uDDD1\uD83C\uDFFF\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFC-\uDFFF])|\uD83D\uDC68(?:\uD83C\uDFFB(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|[\u2695\u2696\u2708]\uFE0F|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))?|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFF]))|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])\uFE0F|\u200D(?:(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D[\uDC66\uDC67])|\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC)?|(?:\uD83D\uDC69(?:\uD83C\uDFFB\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|(?:\uD83C[\uDFFC-\uDFFF])\u200D\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69]))|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC69(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83E\uDDD1(?:\u200D(?:\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF7C\uDF84\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|\uD83D\uDE36\u200D\uD83C\uDF2B|\uD83C\uDFF3\uFE0F\u200D\u26A7|\uD83D\uDC3B\u200D\u2744|(?:(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\uD83C\uDFF4\u200D\u2620|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])\u200D[\u2640\u2642]|[\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u2328\u23CF\u23ED-\u23EF\u23F1\u23F2\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB\u25FC\u2600-\u2604\u260E\u2611\u2618\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u2692\u2694-\u2697\u2699\u269B\u269C\u26A0\u26A7\u26B0\u26B1\u26C8\u26CF\u26D1\u26D3\u26E9\u26F0\u26F1\u26F4\u26F7\u26F8\u2702\u2708\u2709\u270F\u2712\u2714\u2716\u271D\u2721\u2733\u2734\u2744\u2747\u2763\u27A1\u2934\u2935\u2B05-\u2B07\u3030\u303D\u3297\u3299]|\uD83C[\uDD70\uDD71\uDD7E\uDD7F\uDE02\uDE37\uDF21\uDF24-\uDF2C\uDF36\uDF7D\uDF96\uDF97\uDF99-\uDF9B\uDF9E\uDF9F\uDFCD\uDFCE\uDFD4-\uDFDF\uDFF5\uDFF7]|\uD83D[\uDC3F\uDCFD\uDD49\uDD4A\uDD6F\uDD70\uDD73\uDD76-\uDD79\uDD87\uDD8A-\uDD8D\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA\uDECB\uDECD-\uDECF\uDEE0-\uDEE5\uDEE9\uDEF0\uDEF3])\uFE0F|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDE35\u200D\uD83D\uDCAB|\uD83D\uDE2E\u200D\uD83D\uDCA8|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83E\uDDD1(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83D\uDC69(?:\uD83C\uDFFF|\uD83C\uDFFE|\uD83C\uDFFD|\uD83C\uDFFC|\uD83C\uDFFB)?|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF6\uD83C\uDDE6|\uD83C\uDDF4\uD83C\uDDF2|\uD83D\uDC08\u200D\u2B1B|\u2764\uFE0F\u200D(?:\uD83D\uDD25|\uD83E\uDE79)|\uD83D\uDC41\uFE0F|\uD83C\uDFF3\uFE0F|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|[#\*0-9]\uFE0F\u20E3|\u2764\uFE0F|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|\uD83C\uDFF4|(?:[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270C\u270D]|\uD83D[\uDD74\uDD90])(?:\uFE0F|\uD83C[\uDFFB-\uDFFF])|[\u270A\u270B]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC08\uDC15\uDC3B\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDC8F\uDC91\uDCAA\uDD7A\uDD95\uDD96\uDE2E\uDE35\uDE36\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD34\uDD36\uDD77\uDDB5\uDDB6\uDDBB\uDDD2\uDDD3\uDDD5]|\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC70\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD35\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD4\uDDD6-\uDDDD]|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF]|[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF84\uDF86-\uDF93\uDFA0-\uDFC1\uDFC5\uDFC6\uDFC8\uDFC9\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC07\uDC09-\uDC14\uDC16-\uDC3A\uDC3C-\uDC3E\uDC40\uDC44\uDC45\uDC51-\uDC65\uDC6A\uDC79-\uDC7B\uDC7D-\uDC80\uDC84\uDC88-\uDC8E\uDC90\uDC92-\uDCA9\uDCAB-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDDA4\uDDFB-\uDE2D\uDE2F-\uDE34\uDE37-\uDE44\uDE48-\uDE4A\uDE80-\uDEA2\uDEA4-\uDEB3\uDEB7-\uDEBF\uDEC1-\uDEC5\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0D\uDD0E\uDD10-\uDD17\uDD1D\uDD20-\uDD25\uDD27-\uDD2F\uDD3A\uDD3F-\uDD45\uDD47-\uDD76\uDD78\uDD7A-\uDDB4\uDDB7\uDDBA\uDDBC-\uDDCB\uDDD0\uDDE0-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6]|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5-\uDED7\uDEEB\uDEEC\uDEF4-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26A7\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5-\uDED7\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFC\uDFE0-\uDFEB]|\uD83E[\uDD0C-\uDD3A\uDD3C-\uDD45\uDD47-\uDD78\uDD7A-\uDDCB\uDDCD-\uDDFF\uDE70-\uDE74\uDE78-\uDE7A\uDE80-\uDE86\uDE90-\uDEA8\uDEB0-\uDEB6\uDEC0-\uDEC2\uDED0-\uDED6])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0C\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDD77\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
        };
      }
    });
    var string_width_exports = {};
    __export(string_width_exports, {
      default: () => stringWidth
    });
    function stringWidth(string) {
      if (typeof string !== "string" || string.length === 0) {
        return 0;
      }
      string = stripAnsi(string);
      if (string.length === 0) {
        return 0;
      }
      string = string.replace((0, import_emoji_regex.default)(), "  ");
      let width = 0;
      for (let index = 0; index < string.length; index++) {
        const codePoint = string.codePointAt(index);
        if (codePoint <= 31 || codePoint >= 127 && codePoint <= 159) {
          continue;
        }
        if (codePoint >= 768 && codePoint <= 879) {
          continue;
        }
        if (codePoint > 65535) {
          index++;
        }
        width += isFullwidthCodePoint(codePoint) ? 2 : 1;
      }
      return width;
    }
    var import_emoji_regex;
    var init_string_width = __esm({
      "node_modules/string-width/index.js"() {
        init_strip_ansi();
        init_is_fullwidth_code_point();
        import_emoji_regex = __toESM2(require_emoji_regex2());
      }
    });
    var require_get_string_width = __commonJS22({
      "src/utils/get-string-width.js"(exports2, module22) {
        "use strict";
        var stringWidth2 = (init_string_width(), __toCommonJS(string_width_exports)).default;
        var notAsciiRegex = /[^\x20-\x7F]/;
        function getStringWidth(text) {
          if (!text) {
            return 0;
          }
          if (!notAsciiRegex.test(text)) {
            return text.length;
          }
          return stringWidth2(text);
        }
        module22.exports = getStringWidth;
      }
    });
    var require_skip2 = __commonJS22({
      "src/utils/text/skip.js"(exports2, module22) {
        "use strict";
        function skip(chars) {
          return (text, index, opts) => {
            const backwards = opts && opts.backwards;
            if (index === false) {
              return false;
            }
            const {
              length
            } = text;
            let cursor = index;
            while (cursor >= 0 && cursor < length) {
              const c = text.charAt(cursor);
              if (chars instanceof RegExp) {
                if (!chars.test(c)) {
                  return cursor;
                }
              } else if (!chars.includes(c)) {
                return cursor;
              }
              backwards ? cursor-- : cursor++;
            }
            if (cursor === -1 || cursor === length) {
              return cursor;
            }
            return false;
          };
        }
        var skipWhitespace = skip(/\s/);
        var skipSpaces = skip(" 	");
        var skipToLineEnd = skip(",; 	");
        var skipEverythingButNewLine = skip(/[^\n\r]/);
        module22.exports = {
          skipWhitespace,
          skipSpaces,
          skipToLineEnd,
          skipEverythingButNewLine
        };
      }
    });
    var require_skip_inline_comment = __commonJS22({
      "src/utils/text/skip-inline-comment.js"(exports2, module22) {
        "use strict";
        function skipInlineComment(text, index) {
          if (index === false) {
            return false;
          }
          if (text.charAt(index) === "/" && text.charAt(index + 1) === "*") {
            for (let i = index + 2; i < text.length; ++i) {
              if (text.charAt(i) === "*" && text.charAt(i + 1) === "/") {
                return i + 2;
              }
            }
          }
          return index;
        }
        module22.exports = skipInlineComment;
      }
    });
    var require_skip_trailing_comment = __commonJS22({
      "src/utils/text/skip-trailing-comment.js"(exports2, module22) {
        "use strict";
        var {
          skipEverythingButNewLine
        } = require_skip2();
        function skipTrailingComment(text, index) {
          if (index === false) {
            return false;
          }
          if (text.charAt(index) === "/" && text.charAt(index + 1) === "/") {
            return skipEverythingButNewLine(text, index);
          }
          return index;
        }
        module22.exports = skipTrailingComment;
      }
    });
    var require_skip_newline = __commonJS22({
      "src/utils/text/skip-newline.js"(exports2, module22) {
        "use strict";
        function skipNewline(text, index, opts) {
          const backwards = opts && opts.backwards;
          if (index === false) {
            return false;
          }
          const atIndex = text.charAt(index);
          if (backwards) {
            if (text.charAt(index - 1) === "\r" && atIndex === "\n") {
              return index - 2;
            }
            if (atIndex === "\n" || atIndex === "\r" || atIndex === "\u2028" || atIndex === "\u2029") {
              return index - 1;
            }
          } else {
            if (atIndex === "\r" && text.charAt(index + 1) === "\n") {
              return index + 2;
            }
            if (atIndex === "\n" || atIndex === "\r" || atIndex === "\u2028" || atIndex === "\u2029") {
              return index + 1;
            }
          }
          return index;
        }
        module22.exports = skipNewline;
      }
    });
    var require_get_next_non_space_non_comment_character_index_with_start_index = __commonJS22({
      "src/utils/text/get-next-non-space-non-comment-character-index-with-start-index.js"(exports2, module22) {
        "use strict";
        var skipInlineComment = require_skip_inline_comment();
        var skipNewline = require_skip_newline();
        var skipTrailingComment = require_skip_trailing_comment();
        var {
          skipSpaces
        } = require_skip2();
        function getNextNonSpaceNonCommentCharacterIndexWithStartIndex(text, idx) {
          let oldIdx = null;
          let nextIdx = idx;
          while (nextIdx !== oldIdx) {
            oldIdx = nextIdx;
            nextIdx = skipSpaces(text, nextIdx);
            nextIdx = skipInlineComment(text, nextIdx);
            nextIdx = skipTrailingComment(text, nextIdx);
            nextIdx = skipNewline(text, nextIdx);
          }
          return nextIdx;
        }
        module22.exports = getNextNonSpaceNonCommentCharacterIndexWithStartIndex;
      }
    });
    var require_util6 = __commonJS22({
      "src/common/util.js"(exports2, module22) {
        "use strict";
        var {
          default: escapeStringRegexp2
        } = (init_escape_string_regexp(), __toCommonJS(escape_string_regexp_exports));
        var getLast = require_get_last();
        var {
          getSupportInfo: getSupportInfo2
        } = require_support();
        var isNonEmptyArray = require_is_non_empty_array();
        var getStringWidth = require_get_string_width();
        var {
          skipWhitespace,
          skipSpaces,
          skipToLineEnd,
          skipEverythingButNewLine
        } = require_skip2();
        var skipInlineComment = require_skip_inline_comment();
        var skipTrailingComment = require_skip_trailing_comment();
        var skipNewline = require_skip_newline();
        var getNextNonSpaceNonCommentCharacterIndexWithStartIndex = require_get_next_non_space_non_comment_character_index_with_start_index();
        var getPenultimate = (arr) => arr[arr.length - 2];
        function skip(chars) {
          return (text, index, opts) => {
            const backwards = opts && opts.backwards;
            if (index === false) {
              return false;
            }
            const {
              length
            } = text;
            let cursor = index;
            while (cursor >= 0 && cursor < length) {
              const c = text.charAt(cursor);
              if (chars instanceof RegExp) {
                if (!chars.test(c)) {
                  return cursor;
                }
              } else if (!chars.includes(c)) {
                return cursor;
              }
              backwards ? cursor-- : cursor++;
            }
            if (cursor === -1 || cursor === length) {
              return cursor;
            }
            return false;
          };
        }
        function hasNewline(text, index, opts = {}) {
          const idx = skipSpaces(text, opts.backwards ? index - 1 : index, opts);
          const idx2 = skipNewline(text, idx, opts);
          return idx !== idx2;
        }
        function hasNewlineInRange(text, start, end) {
          for (let i = start; i < end; ++i) {
            if (text.charAt(i) === "\n") {
              return true;
            }
          }
          return false;
        }
        function isPreviousLineEmpty(text, node, locStart) {
          let idx = locStart(node) - 1;
          idx = skipSpaces(text, idx, {
            backwards: true
          });
          idx = skipNewline(text, idx, {
            backwards: true
          });
          idx = skipSpaces(text, idx, {
            backwards: true
          });
          const idx2 = skipNewline(text, idx, {
            backwards: true
          });
          return idx !== idx2;
        }
        function isNextLineEmptyAfterIndex(text, index) {
          let oldIdx = null;
          let idx = index;
          while (idx !== oldIdx) {
            oldIdx = idx;
            idx = skipToLineEnd(text, idx);
            idx = skipInlineComment(text, idx);
            idx = skipSpaces(text, idx);
          }
          idx = skipTrailingComment(text, idx);
          idx = skipNewline(text, idx);
          return idx !== false && hasNewline(text, idx);
        }
        function isNextLineEmpty(text, node, locEnd) {
          return isNextLineEmptyAfterIndex(text, locEnd(node));
        }
        function getNextNonSpaceNonCommentCharacterIndex(text, node, locEnd) {
          return getNextNonSpaceNonCommentCharacterIndexWithStartIndex(text, locEnd(node));
        }
        function getNextNonSpaceNonCommentCharacter(text, node, locEnd) {
          return text.charAt(getNextNonSpaceNonCommentCharacterIndex(text, node, locEnd));
        }
        function hasSpaces(text, index, opts = {}) {
          const idx = skipSpaces(text, opts.backwards ? index - 1 : index, opts);
          return idx !== index;
        }
        function getAlignmentSize(value2, tabWidth, startIndex = 0) {
          let size = 0;
          for (let i = startIndex; i < value2.length; ++i) {
            if (value2[i] === "	") {
              size = size + tabWidth - size % tabWidth;
            } else {
              size++;
            }
          }
          return size;
        }
        function getIndentSize(value2, tabWidth) {
          const lastNewlineIndex = value2.lastIndexOf("\n");
          if (lastNewlineIndex === -1) {
            return 0;
          }
          return getAlignmentSize(value2.slice(lastNewlineIndex + 1).match(/^[\t ]*/)[0], tabWidth);
        }
        function getPreferredQuote(rawContent, preferredQuote) {
          const double = {
            quote: '"',
            regex: /"/g,
            escaped: "&quot;"
          };
          const single = {
            quote: "'",
            regex: /'/g,
            escaped: "&apos;"
          };
          const preferred = preferredQuote === "'" ? single : double;
          const alternate = preferred === single ? double : single;
          let result = preferred;
          if (rawContent.includes(preferred.quote) || rawContent.includes(alternate.quote)) {
            const numPreferredQuotes = (rawContent.match(preferred.regex) || []).length;
            const numAlternateQuotes = (rawContent.match(alternate.regex) || []).length;
            result = numPreferredQuotes > numAlternateQuotes ? alternate : preferred;
          }
          return result;
        }
        function printString(raw, options) {
          const rawContent = raw.slice(1, -1);
          const enclosingQuote = options.parser === "json" || options.parser === "json5" && options.quoteProps === "preserve" && !options.singleQuote ? '"' : options.__isInHtmlAttribute ? "'" : getPreferredQuote(rawContent, options.singleQuote ? "'" : '"').quote;
          return makeString(rawContent, enclosingQuote, !(options.parser === "css" || options.parser === "less" || options.parser === "scss" || options.__embeddedInHtml));
        }
        function makeString(rawContent, enclosingQuote, unescapeUnnecessaryEscapes) {
          const otherQuote = enclosingQuote === '"' ? "'" : '"';
          const regex = /\\(.)|(["'])/gs;
          const newContent = rawContent.replace(regex, (match, escaped, quote) => {
            if (escaped === otherQuote) {
              return escaped;
            }
            if (quote === enclosingQuote) {
              return "\\" + quote;
            }
            if (quote) {
              return quote;
            }
            return unescapeUnnecessaryEscapes && /^[^\n\r"'0-7\\bfnrt-vx\u2028\u2029]$/.test(escaped) ? escaped : "\\" + escaped;
          });
          return enclosingQuote + newContent + enclosingQuote;
        }
        function printNumber(rawNumber) {
          return rawNumber.toLowerCase().replace(/^([+-]?[\d.]+e)(?:\+|(-))?0*(\d)/, "$1$2$3").replace(/^([+-]?[\d.]+)e[+-]?0+$/, "$1").replace(/^([+-])?\./, "$10.").replace(/(\.\d+?)0+(?=e|$)/, "$1").replace(/\.(?=e|$)/, "");
        }
        function getMaxContinuousCount(str, target) {
          const results = str.match(new RegExp(`(${escapeStringRegexp2(target)})+`, "g"));
          if (results === null) {
            return 0;
          }
          return results.reduce((maxCount, result) => Math.max(maxCount, result.length / target.length), 0);
        }
        function getMinNotPresentContinuousCount(str, target) {
          const matches = str.match(new RegExp(`(${escapeStringRegexp2(target)})+`, "g"));
          if (matches === null) {
            return 0;
          }
          const countPresent = /* @__PURE__ */ new Map();
          let max2 = 0;
          for (const match of matches) {
            const count = match.length / target.length;
            countPresent.set(count, true);
            if (count > max2) {
              max2 = count;
            }
          }
          for (let i = 1; i < max2; i++) {
            if (!countPresent.get(i)) {
              return i;
            }
          }
          return max2 + 1;
        }
        function addCommentHelper(node, comment) {
          const comments = node.comments || (node.comments = []);
          comments.push(comment);
          comment.printed = false;
          comment.nodeDescription = describeNodeForDebugging(node);
        }
        function addLeadingComment(node, comment) {
          comment.leading = true;
          comment.trailing = false;
          addCommentHelper(node, comment);
        }
        function addDanglingComment(node, comment, marker) {
          comment.leading = false;
          comment.trailing = false;
          if (marker) {
            comment.marker = marker;
          }
          addCommentHelper(node, comment);
        }
        function addTrailingComment(node, comment) {
          comment.leading = false;
          comment.trailing = true;
          addCommentHelper(node, comment);
        }
        function inferParserByLanguage(language, options) {
          const {
            languages
          } = getSupportInfo2({
            plugins: options.plugins
          });
          const matched = languages.find(({
            name
          }) => name.toLowerCase() === language) || languages.find(({
            aliases
          }) => Array.isArray(aliases) && aliases.includes(language)) || languages.find(({
            extensions
          }) => Array.isArray(extensions) && extensions.includes(`.${language}`));
          return matched && matched.parsers[0];
        }
        function isFrontMatterNode(node) {
          return node && node.type === "front-matter";
        }
        function createGroupIdMapper(description) {
          const groupIds = /* @__PURE__ */ new WeakMap();
          return function(node) {
            if (!groupIds.has(node)) {
              groupIds.set(node, Symbol(description));
            }
            return groupIds.get(node);
          };
        }
        function describeNodeForDebugging(node) {
          const nodeType = node.type || node.kind || "(unknown type)";
          let nodeName = String(node.name || node.id && (typeof node.id === "object" ? node.id.name : node.id) || node.key && (typeof node.key === "object" ? node.key.name : node.key) || node.value && (typeof node.value === "object" ? "" : String(node.value)) || node.operator || "");
          if (nodeName.length > 20) {
            nodeName = nodeName.slice(0, 19) + "\u2026";
          }
          return nodeType + (nodeName ? " " + nodeName : "");
        }
        module22.exports = {
          inferParserByLanguage,
          getStringWidth,
          getMaxContinuousCount,
          getMinNotPresentContinuousCount,
          getPenultimate,
          getLast,
          getNextNonSpaceNonCommentCharacterIndexWithStartIndex,
          getNextNonSpaceNonCommentCharacterIndex,
          getNextNonSpaceNonCommentCharacter,
          skip,
          skipWhitespace,
          skipSpaces,
          skipToLineEnd,
          skipEverythingButNewLine,
          skipInlineComment,
          skipTrailingComment,
          skipNewline,
          isNextLineEmptyAfterIndex,
          isNextLineEmpty,
          isPreviousLineEmpty,
          hasNewline,
          hasNewlineInRange,
          hasSpaces,
          getAlignmentSize,
          getIndentSize,
          getPreferredQuote,
          printString,
          printNumber,
          makeString,
          addLeadingComment,
          addDanglingComment,
          addTrailingComment,
          isFrontMatterNode,
          isNonEmptyArray,
          createGroupIdMapper
        };
      }
    });
    var require_end_of_line = __commonJS22({
      "src/common/end-of-line.js"(exports2, module22) {
        "use strict";
        function guessEndOfLine(text) {
          const index = text.indexOf("\r");
          if (index >= 0) {
            return text.charAt(index + 1) === "\n" ? "crlf" : "cr";
          }
          return "lf";
        }
        function convertEndOfLineToChars(value2) {
          switch (value2) {
            case "cr":
              return "\r";
            case "crlf":
              return "\r\n";
            default:
              return "\n";
          }
        }
        function countEndOfLineChars(text, eol) {
          let regex;
          switch (eol) {
            case "\n":
              regex = /\n/g;
              break;
            case "\r":
              regex = /\r/g;
              break;
            case "\r\n":
              regex = /\r\n/g;
              break;
            default:
              throw new Error(`Unexpected "eol" ${JSON.stringify(eol)}.`);
          }
          const endOfLines = text.match(regex);
          return endOfLines ? endOfLines.length : 0;
        }
        function normalizeEndOfLine(text) {
          return text.replace(/\r\n?/g, "\n");
        }
        module22.exports = {
          guessEndOfLine,
          convertEndOfLineToChars,
          countEndOfLineChars,
          normalizeEndOfLine
        };
      }
    });
    var require_errors2 = __commonJS22({
      "src/common/errors.js"(exports2, module22) {
        "use strict";
        var ConfigError = class extends Error {
        };
        var DebugError = class extends Error {
        };
        var UndefinedParserError = class extends Error {
        };
        var ArgExpansionBailout = class extends Error {
        };
        module22.exports = {
          ConfigError,
          DebugError,
          UndefinedParserError,
          ArgExpansionBailout
        };
      }
    });
    var tslib_es6_exports = {};
    __export(tslib_es6_exports, {
      __assign: () => __assign,
      __asyncDelegator: () => __asyncDelegator,
      __asyncGenerator: () => __asyncGenerator,
      __asyncValues: () => __asyncValues,
      __await: () => __await,
      __awaiter: () => __awaiter,
      __classPrivateFieldGet: () => __classPrivateFieldGet,
      __classPrivateFieldSet: () => __classPrivateFieldSet,
      __createBinding: () => __createBinding,
      __decorate: () => __decorate,
      __exportStar: () => __exportStar,
      __extends: () => __extends,
      __generator: () => __generator,
      __importDefault: () => __importDefault,
      __importStar: () => __importStar,
      __makeTemplateObject: () => __makeTemplateObject,
      __metadata: () => __metadata,
      __param: () => __param,
      __read: () => __read,
      __rest: () => __rest,
      __spread: () => __spread,
      __spreadArrays: () => __spreadArrays,
      __values: () => __values
    });
    function __extends(d, b) {
      extendStatics(d, b);
      function __() {
        this.constructor = d;
      }
      d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    function __rest(s, e) {
      var t3 = {};
      for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
          t3[p] = s[p];
      if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
          if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
            t3[p[i]] = s[p[i]];
        }
      return t3;
    }
    function __decorate(decorators, target, key, desc) {
      var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
      if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
      else
        for (var i = decorators.length - 1; i >= 0; i--)
          if (d = decorators[i])
            r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
      return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
      return function(target, key) {
        decorator(target, key, paramIndex);
      };
    }
    function __metadata(metadataKey, metadataValue) {
      if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
      function adopt(value2) {
        return value2 instanceof P ? value2 : new P(function(resolve) {
          resolve(value2);
        });
      }
      return new (P || (P = Promise))(function(resolve, reject) {
        function fulfilled(value2) {
          try {
            step(generator.next(value2));
          } catch (e) {
            reject(e);
          }
        }
        function rejected(value2) {
          try {
            step(generator["throw"](value2));
          } catch (e) {
            reject(e);
          }
        }
        function step(result) {
          result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
      });
    }
    function __generator(thisArg, body) {
      var _ = {
        label: 0,
        sent: function() {
          if (t3[0] & 1)
            throw t3[1];
          return t3[1];
        },
        trys: [],
        ops: []
      }, f, y, t3, g;
      return g = {
        next: verb(0),
        "throw": verb(1),
        "return": verb(2)
      }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
        return this;
      }), g;
      function verb(n) {
        return function(v) {
          return step([n, v]);
        };
      }
      function step(op) {
        if (f)
          throw new TypeError("Generator is already executing.");
        while (_)
          try {
            if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
              return t3;
            if (y = 0, t3)
              op = [op[0] & 2, t3.value];
            switch (op[0]) {
              case 0:
              case 1:
                t3 = op;
                break;
              case 4:
                _.label++;
                return {
                  value: op[1],
                  done: false
                };
              case 5:
                _.label++;
                y = op[1];
                op = [0];
                continue;
              case 7:
                op = _.ops.pop();
                _.trys.pop();
                continue;
              default:
                if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                  _ = 0;
                  continue;
                }
                if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                  _.label = op[1];
                  break;
                }
                if (op[0] === 6 && _.label < t3[1]) {
                  _.label = t3[1];
                  t3 = op;
                  break;
                }
                if (t3 && _.label < t3[2]) {
                  _.label = t3[2];
                  _.ops.push(op);
                  break;
                }
                if (t3[2])
                  _.ops.pop();
                _.trys.pop();
                continue;
            }
            op = body.call(thisArg, _);
          } catch (e) {
            op = [6, e];
            y = 0;
          } finally {
            f = t3 = 0;
          }
        if (op[0] & 5)
          throw op[1];
        return {
          value: op[0] ? op[1] : void 0,
          done: true
        };
      }
    }
    function __createBinding(o, m, k, k2) {
      if (k2 === void 0)
        k2 = k;
      o[k2] = m[k];
    }
    function __exportStar(m, exports2) {
      for (var p in m)
        if (p !== "default" && !exports2.hasOwnProperty(p))
          exports2[p] = m[p];
    }
    function __values(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = void 0;
            return {
              value: o && o[i++],
              done: !o
            };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = {
          error
        };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    }
    function __spread() {
      for (var ar = [], i = 0; i < arguments.length; i++)
        ar = ar.concat(__read(arguments[i]));
      return ar;
    }
    function __spreadArrays() {
      for (var s = 0, i = 0, il = arguments.length; i < il; i++)
        s += arguments[i].length;
      for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
          r[k] = a[j];
      return r;
    }
    function __await(v) {
      return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var g = generator.apply(thisArg, _arguments || []), i, q = [];
      return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i;
      function verb(n) {
        if (g[n])
          i[n] = function(v) {
            return new Promise(function(a, b) {
              q.push([n, v, a, b]) > 1 || resume(n, v);
            });
          };
      }
      function resume(n, v) {
        try {
          step(g[n](v));
        } catch (e) {
          settle(q[0][3], e);
        }
      }
      function step(r) {
        r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);
      }
      function fulfill(value2) {
        resume("next", value2);
      }
      function reject(value2) {
        resume("throw", value2);
      }
      function settle(f, v) {
        if (f(v), q.shift(), q.length)
          resume(q[0][0], q[0][1]);
      }
    }
    function __asyncDelegator(o) {
      var i, p;
      return i = {}, verb("next"), verb("throw", function(e) {
        throw e;
      }), verb("return"), i[Symbol.iterator] = function() {
        return this;
      }, i;
      function verb(n, f) {
        i[n] = o[n] ? function(v) {
          return (p = !p) ? {
            value: __await(o[n](v)),
            done: n === "return"
          } : f ? f(v) : v;
        } : f;
      }
    }
    function __asyncValues(o) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var m = o[Symbol.asyncIterator], i;
      return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i);
      function verb(n) {
        i[n] = o[n] && function(v) {
          return new Promise(function(resolve, reject) {
            v = o[n](v), settle(resolve, reject, v.done, v.value);
          });
        };
      }
      function settle(resolve, reject, d, v) {
        Promise.resolve(v).then(function(v2) {
          resolve({
            value: v2,
            done: d
          });
        }, reject);
      }
    }
    function __makeTemplateObject(cooked, raw) {
      if (Object.defineProperty) {
        Object.defineProperty(cooked, "raw", {
          value: raw
        });
      } else {
        cooked.raw = raw;
      }
      return cooked;
    }
    function __importStar(mod) {
      if (mod && mod.__esModule)
        return mod;
      var result = {};
      if (mod != null) {
        for (var k in mod)
          if (Object.hasOwnProperty.call(mod, k))
            result[k] = mod[k];
      }
      result.default = mod;
      return result;
    }
    function __importDefault(mod) {
      return mod && mod.__esModule ? mod : {
        default: mod
      };
    }
    function __classPrivateFieldGet(receiver, privateMap) {
      if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
      }
      return privateMap.get(receiver);
    }
    function __classPrivateFieldSet(receiver, privateMap, value2) {
      if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
      }
      privateMap.set(receiver, value2);
      return value2;
    }
    var extendStatics;
    var __assign;
    var init_tslib_es6 = __esm({
      "node_modules/tslib/tslib.es6.js"() {
        extendStatics = function(d, b) {
          extendStatics = Object.setPrototypeOf || {
            __proto__: []
          } instanceof Array && function(d2, b2) {
            d2.__proto__ = b2;
          } || function(d2, b2) {
            for (var p in b2)
              if (b2.hasOwnProperty(p))
                d2[p] = b2[p];
          };
          return extendStatics(d, b);
        };
        __assign = function() {
          __assign = Object.assign || function __assign2(t3) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
              s = arguments[i];
              for (var p in s)
                if (Object.prototype.hasOwnProperty.call(s, p))
                  t3[p] = s[p];
            }
            return t3;
          };
          return __assign.apply(this, arguments);
        };
      }
    });
    var require_api3 = __commonJS22({
      "node_modules/vnopts/lib/descriptors/api.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.apiDescriptor = {
          key: (key) => /^[$_a-zA-Z][$_a-zA-Z0-9]*$/.test(key) ? key : JSON.stringify(key),
          value(value2) {
            if (value2 === null || typeof value2 !== "object") {
              return JSON.stringify(value2);
            }
            if (Array.isArray(value2)) {
              return `[${value2.map((subValue) => exports2.apiDescriptor.value(subValue)).join(", ")}]`;
            }
            const keys3 = Object.keys(value2);
            return keys3.length === 0 ? "{}" : `{ ${keys3.map((key) => `${exports2.apiDescriptor.key(key)}: ${exports2.apiDescriptor.value(value2[key])}`).join(", ")} }`;
          },
          pair: ({
            key,
            value: value2
          }) => exports2.apiDescriptor.value({
            [key]: value2
          })
        };
      }
    });
    var require_descriptors2 = __commonJS22({
      "node_modules/vnopts/lib/descriptors/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_api3(), exports2);
      }
    });
    var require_escape_string_regexp3 = __commonJS22({
      "node_modules/vnopts/node_modules/escape-string-regexp/index.js"(exports2, module22) {
        "use strict";
        var matchOperatorsRe = /[|\\{}()[\]^$+*?.]/g;
        module22.exports = function(str) {
          if (typeof str !== "string") {
            throw new TypeError("Expected a string");
          }
          return str.replace(matchOperatorsRe, "\\$&");
        };
      }
    });
    var require_color_name3 = __commonJS22({
      "node_modules/color-name/index.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          "aliceblue": [240, 248, 255],
          "antiquewhite": [250, 235, 215],
          "aqua": [0, 255, 255],
          "aquamarine": [127, 255, 212],
          "azure": [240, 255, 255],
          "beige": [245, 245, 220],
          "bisque": [255, 228, 196],
          "black": [0, 0, 0],
          "blanchedalmond": [255, 235, 205],
          "blue": [0, 0, 255],
          "blueviolet": [138, 43, 226],
          "brown": [165, 42, 42],
          "burlywood": [222, 184, 135],
          "cadetblue": [95, 158, 160],
          "chartreuse": [127, 255, 0],
          "chocolate": [210, 105, 30],
          "coral": [255, 127, 80],
          "cornflowerblue": [100, 149, 237],
          "cornsilk": [255, 248, 220],
          "crimson": [220, 20, 60],
          "cyan": [0, 255, 255],
          "darkblue": [0, 0, 139],
          "darkcyan": [0, 139, 139],
          "darkgoldenrod": [184, 134, 11],
          "darkgray": [169, 169, 169],
          "darkgreen": [0, 100, 0],
          "darkgrey": [169, 169, 169],
          "darkkhaki": [189, 183, 107],
          "darkmagenta": [139, 0, 139],
          "darkolivegreen": [85, 107, 47],
          "darkorange": [255, 140, 0],
          "darkorchid": [153, 50, 204],
          "darkred": [139, 0, 0],
          "darksalmon": [233, 150, 122],
          "darkseagreen": [143, 188, 143],
          "darkslateblue": [72, 61, 139],
          "darkslategray": [47, 79, 79],
          "darkslategrey": [47, 79, 79],
          "darkturquoise": [0, 206, 209],
          "darkviolet": [148, 0, 211],
          "deeppink": [255, 20, 147],
          "deepskyblue": [0, 191, 255],
          "dimgray": [105, 105, 105],
          "dimgrey": [105, 105, 105],
          "dodgerblue": [30, 144, 255],
          "firebrick": [178, 34, 34],
          "floralwhite": [255, 250, 240],
          "forestgreen": [34, 139, 34],
          "fuchsia": [255, 0, 255],
          "gainsboro": [220, 220, 220],
          "ghostwhite": [248, 248, 255],
          "gold": [255, 215, 0],
          "goldenrod": [218, 165, 32],
          "gray": [128, 128, 128],
          "green": [0, 128, 0],
          "greenyellow": [173, 255, 47],
          "grey": [128, 128, 128],
          "honeydew": [240, 255, 240],
          "hotpink": [255, 105, 180],
          "indianred": [205, 92, 92],
          "indigo": [75, 0, 130],
          "ivory": [255, 255, 240],
          "khaki": [240, 230, 140],
          "lavender": [230, 230, 250],
          "lavenderblush": [255, 240, 245],
          "lawngreen": [124, 252, 0],
          "lemonchiffon": [255, 250, 205],
          "lightblue": [173, 216, 230],
          "lightcoral": [240, 128, 128],
          "lightcyan": [224, 255, 255],
          "lightgoldenrodyellow": [250, 250, 210],
          "lightgray": [211, 211, 211],
          "lightgreen": [144, 238, 144],
          "lightgrey": [211, 211, 211],
          "lightpink": [255, 182, 193],
          "lightsalmon": [255, 160, 122],
          "lightseagreen": [32, 178, 170],
          "lightskyblue": [135, 206, 250],
          "lightslategray": [119, 136, 153],
          "lightslategrey": [119, 136, 153],
          "lightsteelblue": [176, 196, 222],
          "lightyellow": [255, 255, 224],
          "lime": [0, 255, 0],
          "limegreen": [50, 205, 50],
          "linen": [250, 240, 230],
          "magenta": [255, 0, 255],
          "maroon": [128, 0, 0],
          "mediumaquamarine": [102, 205, 170],
          "mediumblue": [0, 0, 205],
          "mediumorchid": [186, 85, 211],
          "mediumpurple": [147, 112, 219],
          "mediumseagreen": [60, 179, 113],
          "mediumslateblue": [123, 104, 238],
          "mediumspringgreen": [0, 250, 154],
          "mediumturquoise": [72, 209, 204],
          "mediumvioletred": [199, 21, 133],
          "midnightblue": [25, 25, 112],
          "mintcream": [245, 255, 250],
          "mistyrose": [255, 228, 225],
          "moccasin": [255, 228, 181],
          "navajowhite": [255, 222, 173],
          "navy": [0, 0, 128],
          "oldlace": [253, 245, 230],
          "olive": [128, 128, 0],
          "olivedrab": [107, 142, 35],
          "orange": [255, 165, 0],
          "orangered": [255, 69, 0],
          "orchid": [218, 112, 214],
          "palegoldenrod": [238, 232, 170],
          "palegreen": [152, 251, 152],
          "paleturquoise": [175, 238, 238],
          "palevioletred": [219, 112, 147],
          "papayawhip": [255, 239, 213],
          "peachpuff": [255, 218, 185],
          "peru": [205, 133, 63],
          "pink": [255, 192, 203],
          "plum": [221, 160, 221],
          "powderblue": [176, 224, 230],
          "purple": [128, 0, 128],
          "rebeccapurple": [102, 51, 153],
          "red": [255, 0, 0],
          "rosybrown": [188, 143, 143],
          "royalblue": [65, 105, 225],
          "saddlebrown": [139, 69, 19],
          "salmon": [250, 128, 114],
          "sandybrown": [244, 164, 96],
          "seagreen": [46, 139, 87],
          "seashell": [255, 245, 238],
          "sienna": [160, 82, 45],
          "silver": [192, 192, 192],
          "skyblue": [135, 206, 235],
          "slateblue": [106, 90, 205],
          "slategray": [112, 128, 144],
          "slategrey": [112, 128, 144],
          "snow": [255, 250, 250],
          "springgreen": [0, 255, 127],
          "steelblue": [70, 130, 180],
          "tan": [210, 180, 140],
          "teal": [0, 128, 128],
          "thistle": [216, 191, 216],
          "tomato": [255, 99, 71],
          "turquoise": [64, 224, 208],
          "violet": [238, 130, 238],
          "wheat": [245, 222, 179],
          "white": [255, 255, 255],
          "whitesmoke": [245, 245, 245],
          "yellow": [255, 255, 0],
          "yellowgreen": [154, 205, 50]
        };
      }
    });
    var require_conversions3 = __commonJS22({
      "node_modules/color-convert/conversions.js"(exports2, module22) {
        var cssKeywords = require_color_name3();
        var reverseKeywords = {};
        for (key in cssKeywords) {
          if (cssKeywords.hasOwnProperty(key)) {
            reverseKeywords[cssKeywords[key]] = key;
          }
        }
        var key;
        var convert = module22.exports = {
          rgb: {
            channels: 3,
            labels: "rgb"
          },
          hsl: {
            channels: 3,
            labels: "hsl"
          },
          hsv: {
            channels: 3,
            labels: "hsv"
          },
          hwb: {
            channels: 3,
            labels: "hwb"
          },
          cmyk: {
            channels: 4,
            labels: "cmyk"
          },
          xyz: {
            channels: 3,
            labels: "xyz"
          },
          lab: {
            channels: 3,
            labels: "lab"
          },
          lch: {
            channels: 3,
            labels: "lch"
          },
          hex: {
            channels: 1,
            labels: ["hex"]
          },
          keyword: {
            channels: 1,
            labels: ["keyword"]
          },
          ansi16: {
            channels: 1,
            labels: ["ansi16"]
          },
          ansi256: {
            channels: 1,
            labels: ["ansi256"]
          },
          hcg: {
            channels: 3,
            labels: ["h", "c", "g"]
          },
          apple: {
            channels: 3,
            labels: ["r16", "g16", "b16"]
          },
          gray: {
            channels: 1,
            labels: ["gray"]
          }
        };
        for (model in convert) {
          if (convert.hasOwnProperty(model)) {
            if (!("channels" in convert[model])) {
              throw new Error("missing channels property: " + model);
            }
            if (!("labels" in convert[model])) {
              throw new Error("missing channel labels property: " + model);
            }
            if (convert[model].labels.length !== convert[model].channels) {
              throw new Error("channel and label counts mismatch: " + model);
            }
            channels = convert[model].channels;
            labels = convert[model].labels;
            delete convert[model].channels;
            delete convert[model].labels;
            Object.defineProperty(convert[model], "channels", {
              value: channels
            });
            Object.defineProperty(convert[model], "labels", {
              value: labels
            });
          }
        }
        var channels;
        var labels;
        var model;
        convert.rgb.hsl = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var min2 = Math.min(r, g, b);
          var max2 = Math.max(r, g, b);
          var delta = max2 - min2;
          var h;
          var s;
          var l;
          if (max2 === min2) {
            h = 0;
          } else if (r === max2) {
            h = (g - b) / delta;
          } else if (g === max2) {
            h = 2 + (b - r) / delta;
          } else if (b === max2) {
            h = 4 + (r - g) / delta;
          }
          h = Math.min(h * 60, 360);
          if (h < 0) {
            h += 360;
          }
          l = (min2 + max2) / 2;
          if (max2 === min2) {
            s = 0;
          } else if (l <= 0.5) {
            s = delta / (max2 + min2);
          } else {
            s = delta / (2 - max2 - min2);
          }
          return [h, s * 100, l * 100];
        };
        convert.rgb.hsv = function(rgb) {
          var rdif;
          var gdif;
          var bdif;
          var h;
          var s;
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var v = Math.max(r, g, b);
          var diff = v - Math.min(r, g, b);
          var diffc = function(c) {
            return (v - c) / 6 / diff + 1 / 2;
          };
          if (diff === 0) {
            h = s = 0;
          } else {
            s = diff / v;
            rdif = diffc(r);
            gdif = diffc(g);
            bdif = diffc(b);
            if (r === v) {
              h = bdif - gdif;
            } else if (g === v) {
              h = 1 / 3 + rdif - bdif;
            } else if (b === v) {
              h = 2 / 3 + gdif - rdif;
            }
            if (h < 0) {
              h += 1;
            } else if (h > 1) {
              h -= 1;
            }
          }
          return [h * 360, s * 100, v * 100];
        };
        convert.rgb.hwb = function(rgb) {
          var r = rgb[0];
          var g = rgb[1];
          var b = rgb[2];
          var h = convert.rgb.hsl(rgb)[0];
          var w = 1 / 255 * Math.min(r, Math.min(g, b));
          b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
          return [h, w * 100, b * 100];
        };
        convert.rgb.cmyk = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var c;
          var m;
          var y;
          var k;
          k = Math.min(1 - r, 1 - g, 1 - b);
          c = (1 - r - k) / (1 - k) || 0;
          m = (1 - g - k) / (1 - k) || 0;
          y = (1 - b - k) / (1 - k) || 0;
          return [c * 100, m * 100, y * 100, k * 100];
        };
        function comparativeDistance(x, y) {
          return Math.pow(x[0] - y[0], 2) + Math.pow(x[1] - y[1], 2) + Math.pow(x[2] - y[2], 2);
        }
        convert.rgb.keyword = function(rgb) {
          var reversed = reverseKeywords[rgb];
          if (reversed) {
            return reversed;
          }
          var currentClosestDistance = Infinity;
          var currentClosestKeyword;
          for (var keyword in cssKeywords) {
            if (cssKeywords.hasOwnProperty(keyword)) {
              var value2 = cssKeywords[keyword];
              var distance = comparativeDistance(rgb, value2);
              if (distance < currentClosestDistance) {
                currentClosestDistance = distance;
                currentClosestKeyword = keyword;
              }
            }
          }
          return currentClosestKeyword;
        };
        convert.keyword.rgb = function(keyword) {
          return cssKeywords[keyword];
        };
        convert.rgb.xyz = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          r = r > 0.04045 ? Math.pow((r + 0.055) / 1.055, 2.4) : r / 12.92;
          g = g > 0.04045 ? Math.pow((g + 0.055) / 1.055, 2.4) : g / 12.92;
          b = b > 0.04045 ? Math.pow((b + 0.055) / 1.055, 2.4) : b / 12.92;
          var x = r * 0.4124 + g * 0.3576 + b * 0.1805;
          var y = r * 0.2126 + g * 0.7152 + b * 0.0722;
          var z = r * 0.0193 + g * 0.1192 + b * 0.9505;
          return [x * 100, y * 100, z * 100];
        };
        convert.rgb.lab = function(rgb) {
          var xyz = convert.rgb.xyz(rgb);
          var x = xyz[0];
          var y = xyz[1];
          var z = xyz[2];
          var l;
          var a;
          var b;
          x /= 95.047;
          y /= 100;
          z /= 108.883;
          x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
          y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
          z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
          l = 116 * y - 16;
          a = 500 * (x - y);
          b = 200 * (y - z);
          return [l, a, b];
        };
        convert.hsl.rgb = function(hsl) {
          var h = hsl[0] / 360;
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var t1;
          var t22;
          var t3;
          var rgb;
          var val;
          if (s === 0) {
            val = l * 255;
            return [val, val, val];
          }
          if (l < 0.5) {
            t22 = l * (1 + s);
          } else {
            t22 = l + s - l * s;
          }
          t1 = 2 * l - t22;
          rgb = [0, 0, 0];
          for (var i = 0; i < 3; i++) {
            t3 = h + 1 / 3 * -(i - 1);
            if (t3 < 0) {
              t3++;
            }
            if (t3 > 1) {
              t3--;
            }
            if (6 * t3 < 1) {
              val = t1 + (t22 - t1) * 6 * t3;
            } else if (2 * t3 < 1) {
              val = t22;
            } else if (3 * t3 < 2) {
              val = t1 + (t22 - t1) * (2 / 3 - t3) * 6;
            } else {
              val = t1;
            }
            rgb[i] = val * 255;
          }
          return rgb;
        };
        convert.hsl.hsv = function(hsl) {
          var h = hsl[0];
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var smin = s;
          var lmin = Math.max(l, 0.01);
          var sv;
          var v;
          l *= 2;
          s *= l <= 1 ? l : 2 - l;
          smin *= lmin <= 1 ? lmin : 2 - lmin;
          v = (l + s) / 2;
          sv = l === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l + s);
          return [h, sv * 100, v * 100];
        };
        convert.hsv.rgb = function(hsv) {
          var h = hsv[0] / 60;
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var hi = Math.floor(h) % 6;
          var f = h - Math.floor(h);
          var p = 255 * v * (1 - s);
          var q = 255 * v * (1 - s * f);
          var t3 = 255 * v * (1 - s * (1 - f));
          v *= 255;
          switch (hi) {
            case 0:
              return [v, t3, p];
            case 1:
              return [q, v, p];
            case 2:
              return [p, v, t3];
            case 3:
              return [p, q, v];
            case 4:
              return [t3, p, v];
            case 5:
              return [v, p, q];
          }
        };
        convert.hsv.hsl = function(hsv) {
          var h = hsv[0];
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var vmin = Math.max(v, 0.01);
          var lmin;
          var sl;
          var l;
          l = (2 - s) * v;
          lmin = (2 - s) * vmin;
          sl = s * vmin;
          sl /= lmin <= 1 ? lmin : 2 - lmin;
          sl = sl || 0;
          l /= 2;
          return [h, sl * 100, l * 100];
        };
        convert.hwb.rgb = function(hwb) {
          var h = hwb[0] / 360;
          var wh = hwb[1] / 100;
          var bl = hwb[2] / 100;
          var ratio = wh + bl;
          var i;
          var v;
          var f;
          var n;
          if (ratio > 1) {
            wh /= ratio;
            bl /= ratio;
          }
          i = Math.floor(6 * h);
          v = 1 - bl;
          f = 6 * h - i;
          if ((i & 1) !== 0) {
            f = 1 - f;
          }
          n = wh + f * (v - wh);
          var r;
          var g;
          var b;
          switch (i) {
            default:
            case 6:
            case 0:
              r = v;
              g = n;
              b = wh;
              break;
            case 1:
              r = n;
              g = v;
              b = wh;
              break;
            case 2:
              r = wh;
              g = v;
              b = n;
              break;
            case 3:
              r = wh;
              g = n;
              b = v;
              break;
            case 4:
              r = n;
              g = wh;
              b = v;
              break;
            case 5:
              r = v;
              g = wh;
              b = n;
              break;
          }
          return [r * 255, g * 255, b * 255];
        };
        convert.cmyk.rgb = function(cmyk) {
          var c = cmyk[0] / 100;
          var m = cmyk[1] / 100;
          var y = cmyk[2] / 100;
          var k = cmyk[3] / 100;
          var r;
          var g;
          var b;
          r = 1 - Math.min(1, c * (1 - k) + k);
          g = 1 - Math.min(1, m * (1 - k) + k);
          b = 1 - Math.min(1, y * (1 - k) + k);
          return [r * 255, g * 255, b * 255];
        };
        convert.xyz.rgb = function(xyz) {
          var x = xyz[0] / 100;
          var y = xyz[1] / 100;
          var z = xyz[2] / 100;
          var r;
          var g;
          var b;
          r = x * 3.2406 + y * -1.5372 + z * -0.4986;
          g = x * -0.9689 + y * 1.8758 + z * 0.0415;
          b = x * 0.0557 + y * -0.204 + z * 1.057;
          r = r > 31308e-7 ? 1.055 * Math.pow(r, 1 / 2.4) - 0.055 : r * 12.92;
          g = g > 31308e-7 ? 1.055 * Math.pow(g, 1 / 2.4) - 0.055 : g * 12.92;
          b = b > 31308e-7 ? 1.055 * Math.pow(b, 1 / 2.4) - 0.055 : b * 12.92;
          r = Math.min(Math.max(0, r), 1);
          g = Math.min(Math.max(0, g), 1);
          b = Math.min(Math.max(0, b), 1);
          return [r * 255, g * 255, b * 255];
        };
        convert.xyz.lab = function(xyz) {
          var x = xyz[0];
          var y = xyz[1];
          var z = xyz[2];
          var l;
          var a;
          var b;
          x /= 95.047;
          y /= 100;
          z /= 108.883;
          x = x > 8856e-6 ? Math.pow(x, 1 / 3) : 7.787 * x + 16 / 116;
          y = y > 8856e-6 ? Math.pow(y, 1 / 3) : 7.787 * y + 16 / 116;
          z = z > 8856e-6 ? Math.pow(z, 1 / 3) : 7.787 * z + 16 / 116;
          l = 116 * y - 16;
          a = 500 * (x - y);
          b = 200 * (y - z);
          return [l, a, b];
        };
        convert.lab.xyz = function(lab) {
          var l = lab[0];
          var a = lab[1];
          var b = lab[2];
          var x;
          var y;
          var z;
          y = (l + 16) / 116;
          x = a / 500 + y;
          z = y - b / 200;
          var y2 = Math.pow(y, 3);
          var x2 = Math.pow(x, 3);
          var z2 = Math.pow(z, 3);
          y = y2 > 8856e-6 ? y2 : (y - 16 / 116) / 7.787;
          x = x2 > 8856e-6 ? x2 : (x - 16 / 116) / 7.787;
          z = z2 > 8856e-6 ? z2 : (z - 16 / 116) / 7.787;
          x *= 95.047;
          y *= 100;
          z *= 108.883;
          return [x, y, z];
        };
        convert.lab.lch = function(lab) {
          var l = lab[0];
          var a = lab[1];
          var b = lab[2];
          var hr;
          var h;
          var c;
          hr = Math.atan2(b, a);
          h = hr * 360 / 2 / Math.PI;
          if (h < 0) {
            h += 360;
          }
          c = Math.sqrt(a * a + b * b);
          return [l, c, h];
        };
        convert.lch.lab = function(lch) {
          var l = lch[0];
          var c = lch[1];
          var h = lch[2];
          var a;
          var b;
          var hr;
          hr = h / 360 * 2 * Math.PI;
          a = c * Math.cos(hr);
          b = c * Math.sin(hr);
          return [l, a, b];
        };
        convert.rgb.ansi16 = function(args) {
          var r = args[0];
          var g = args[1];
          var b = args[2];
          var value2 = 1 in arguments ? arguments[1] : convert.rgb.hsv(args)[2];
          value2 = Math.round(value2 / 50);
          if (value2 === 0) {
            return 30;
          }
          var ansi = 30 + (Math.round(b / 255) << 2 | Math.round(g / 255) << 1 | Math.round(r / 255));
          if (value2 === 2) {
            ansi += 60;
          }
          return ansi;
        };
        convert.hsv.ansi16 = function(args) {
          return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
        };
        convert.rgb.ansi256 = function(args) {
          var r = args[0];
          var g = args[1];
          var b = args[2];
          if (r === g && g === b) {
            if (r < 8) {
              return 16;
            }
            if (r > 248) {
              return 231;
            }
            return Math.round((r - 8) / 247 * 24) + 232;
          }
          var ansi = 16 + 36 * Math.round(r / 255 * 5) + 6 * Math.round(g / 255 * 5) + Math.round(b / 255 * 5);
          return ansi;
        };
        convert.ansi16.rgb = function(args) {
          var color = args % 10;
          if (color === 0 || color === 7) {
            if (args > 50) {
              color += 3.5;
            }
            color = color / 10.5 * 255;
            return [color, color, color];
          }
          var mult = (~~(args > 50) + 1) * 0.5;
          var r = (color & 1) * mult * 255;
          var g = (color >> 1 & 1) * mult * 255;
          var b = (color >> 2 & 1) * mult * 255;
          return [r, g, b];
        };
        convert.ansi256.rgb = function(args) {
          if (args >= 232) {
            var c = (args - 232) * 10 + 8;
            return [c, c, c];
          }
          args -= 16;
          var rem;
          var r = Math.floor(args / 36) / 5 * 255;
          var g = Math.floor((rem = args % 36) / 6) / 5 * 255;
          var b = rem % 6 / 5 * 255;
          return [r, g, b];
        };
        convert.rgb.hex = function(args) {
          var integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
          var string = integer.toString(16).toUpperCase();
          return "000000".substring(string.length) + string;
        };
        convert.hex.rgb = function(args) {
          var match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
          if (!match) {
            return [0, 0, 0];
          }
          var colorString = match[0];
          if (match[0].length === 3) {
            colorString = colorString.split("").map(function(char) {
              return char + char;
            }).join("");
          }
          var integer = parseInt(colorString, 16);
          var r = integer >> 16 & 255;
          var g = integer >> 8 & 255;
          var b = integer & 255;
          return [r, g, b];
        };
        convert.rgb.hcg = function(rgb) {
          var r = rgb[0] / 255;
          var g = rgb[1] / 255;
          var b = rgb[2] / 255;
          var max2 = Math.max(Math.max(r, g), b);
          var min2 = Math.min(Math.min(r, g), b);
          var chroma = max2 - min2;
          var grayscale;
          var hue;
          if (chroma < 1) {
            grayscale = min2 / (1 - chroma);
          } else {
            grayscale = 0;
          }
          if (chroma <= 0) {
            hue = 0;
          } else if (max2 === r) {
            hue = (g - b) / chroma % 6;
          } else if (max2 === g) {
            hue = 2 + (b - r) / chroma;
          } else {
            hue = 4 + (r - g) / chroma + 4;
          }
          hue /= 6;
          hue %= 1;
          return [hue * 360, chroma * 100, grayscale * 100];
        };
        convert.hsl.hcg = function(hsl) {
          var s = hsl[1] / 100;
          var l = hsl[2] / 100;
          var c = 1;
          var f = 0;
          if (l < 0.5) {
            c = 2 * s * l;
          } else {
            c = 2 * s * (1 - l);
          }
          if (c < 1) {
            f = (l - 0.5 * c) / (1 - c);
          }
          return [hsl[0], c * 100, f * 100];
        };
        convert.hsv.hcg = function(hsv) {
          var s = hsv[1] / 100;
          var v = hsv[2] / 100;
          var c = s * v;
          var f = 0;
          if (c < 1) {
            f = (v - c) / (1 - c);
          }
          return [hsv[0], c * 100, f * 100];
        };
        convert.hcg.rgb = function(hcg) {
          var h = hcg[0] / 360;
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          if (c === 0) {
            return [g * 255, g * 255, g * 255];
          }
          var pure = [0, 0, 0];
          var hi = h % 1 * 6;
          var v = hi % 1;
          var w = 1 - v;
          var mg = 0;
          switch (Math.floor(hi)) {
            case 0:
              pure[0] = 1;
              pure[1] = v;
              pure[2] = 0;
              break;
            case 1:
              pure[0] = w;
              pure[1] = 1;
              pure[2] = 0;
              break;
            case 2:
              pure[0] = 0;
              pure[1] = 1;
              pure[2] = v;
              break;
            case 3:
              pure[0] = 0;
              pure[1] = w;
              pure[2] = 1;
              break;
            case 4:
              pure[0] = v;
              pure[1] = 0;
              pure[2] = 1;
              break;
            default:
              pure[0] = 1;
              pure[1] = 0;
              pure[2] = w;
          }
          mg = (1 - c) * g;
          return [(c * pure[0] + mg) * 255, (c * pure[1] + mg) * 255, (c * pure[2] + mg) * 255];
        };
        convert.hcg.hsv = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var v = c + g * (1 - c);
          var f = 0;
          if (v > 0) {
            f = c / v;
          }
          return [hcg[0], f * 100, v * 100];
        };
        convert.hcg.hsl = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var l = g * (1 - c) + 0.5 * c;
          var s = 0;
          if (l > 0 && l < 0.5) {
            s = c / (2 * l);
          } else if (l >= 0.5 && l < 1) {
            s = c / (2 * (1 - l));
          }
          return [hcg[0], s * 100, l * 100];
        };
        convert.hcg.hwb = function(hcg) {
          var c = hcg[1] / 100;
          var g = hcg[2] / 100;
          var v = c + g * (1 - c);
          return [hcg[0], (v - c) * 100, (1 - v) * 100];
        };
        convert.hwb.hcg = function(hwb) {
          var w = hwb[1] / 100;
          var b = hwb[2] / 100;
          var v = 1 - b;
          var c = v - w;
          var g = 0;
          if (c < 1) {
            g = (v - c) / (1 - c);
          }
          return [hwb[0], c * 100, g * 100];
        };
        convert.apple.rgb = function(apple) {
          return [apple[0] / 65535 * 255, apple[1] / 65535 * 255, apple[2] / 65535 * 255];
        };
        convert.rgb.apple = function(rgb) {
          return [rgb[0] / 255 * 65535, rgb[1] / 255 * 65535, rgb[2] / 255 * 65535];
        };
        convert.gray.rgb = function(args) {
          return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
        };
        convert.gray.hsl = convert.gray.hsv = function(args) {
          return [0, 0, args[0]];
        };
        convert.gray.hwb = function(gray) {
          return [0, 100, gray[0]];
        };
        convert.gray.cmyk = function(gray) {
          return [0, 0, 0, gray[0]];
        };
        convert.gray.lab = function(gray) {
          return [gray[0], 0, 0];
        };
        convert.gray.hex = function(gray) {
          var val = Math.round(gray[0] / 100 * 255) & 255;
          var integer = (val << 16) + (val << 8) + val;
          var string = integer.toString(16).toUpperCase();
          return "000000".substring(string.length) + string;
        };
        convert.rgb.gray = function(rgb) {
          var val = (rgb[0] + rgb[1] + rgb[2]) / 3;
          return [val / 255 * 100];
        };
      }
    });
    var require_route3 = __commonJS22({
      "node_modules/color-convert/route.js"(exports2, module22) {
        var conversions = require_conversions3();
        function buildGraph() {
          var graph = {};
          var models = Object.keys(conversions);
          for (var len = models.length, i = 0; i < len; i++) {
            graph[models[i]] = {
              distance: -1,
              parent: null
            };
          }
          return graph;
        }
        function deriveBFS(fromModel) {
          var graph = buildGraph();
          var queue = [fromModel];
          graph[fromModel].distance = 0;
          while (queue.length) {
            var current = queue.pop();
            var adjacents = Object.keys(conversions[current]);
            for (var len = adjacents.length, i = 0; i < len; i++) {
              var adjacent = adjacents[i];
              var node = graph[adjacent];
              if (node.distance === -1) {
                node.distance = graph[current].distance + 1;
                node.parent = current;
                queue.unshift(adjacent);
              }
            }
          }
          return graph;
        }
        function link(from, to) {
          return function(args) {
            return to(from(args));
          };
        }
        function wrapConversion(toModel, graph) {
          var path2 = [graph[toModel].parent, toModel];
          var fn = conversions[graph[toModel].parent][toModel];
          var cur = graph[toModel].parent;
          while (graph[cur].parent) {
            path2.unshift(graph[cur].parent);
            fn = link(conversions[graph[cur].parent][cur], fn);
            cur = graph[cur].parent;
          }
          fn.conversion = path2;
          return fn;
        }
        module22.exports = function(fromModel) {
          var graph = deriveBFS(fromModel);
          var conversion = {};
          var models = Object.keys(graph);
          for (var len = models.length, i = 0; i < len; i++) {
            var toModel = models[i];
            var node = graph[toModel];
            if (node.parent === null) {
              continue;
            }
            conversion[toModel] = wrapConversion(toModel, graph);
          }
          return conversion;
        };
      }
    });
    var require_color_convert3 = __commonJS22({
      "node_modules/color-convert/index.js"(exports2, module22) {
        var conversions = require_conversions3();
        var route = require_route3();
        var convert = {};
        var models = Object.keys(conversions);
        function wrapRaw(fn) {
          var wrappedFn = function(args) {
            if (args === void 0 || args === null) {
              return args;
            }
            if (arguments.length > 1) {
              args = Array.prototype.slice.call(arguments);
            }
            return fn(args);
          };
          if ("conversion" in fn) {
            wrappedFn.conversion = fn.conversion;
          }
          return wrappedFn;
        }
        function wrapRounded(fn) {
          var wrappedFn = function(args) {
            if (args === void 0 || args === null) {
              return args;
            }
            if (arguments.length > 1) {
              args = Array.prototype.slice.call(arguments);
            }
            var result = fn(args);
            if (typeof result === "object") {
              for (var len = result.length, i = 0; i < len; i++) {
                result[i] = Math.round(result[i]);
              }
            }
            return result;
          };
          if ("conversion" in fn) {
            wrappedFn.conversion = fn.conversion;
          }
          return wrappedFn;
        }
        models.forEach(function(fromModel) {
          convert[fromModel] = {};
          Object.defineProperty(convert[fromModel], "channels", {
            value: conversions[fromModel].channels
          });
          Object.defineProperty(convert[fromModel], "labels", {
            value: conversions[fromModel].labels
          });
          var routes = route(fromModel);
          var routeModels = Object.keys(routes);
          routeModels.forEach(function(toModel) {
            var fn = routes[toModel];
            convert[fromModel][toModel] = wrapRounded(fn);
            convert[fromModel][toModel].raw = wrapRaw(fn);
          });
        });
        module22.exports = convert;
      }
    });
    var require_ansi_styles3 = __commonJS22({
      "node_modules/ansi-styles/index.js"(exports2, module22) {
        "use strict";
        var colorConvert = require_color_convert3();
        var wrapAnsi16 = (fn, offset) => function() {
          const code = fn.apply(colorConvert, arguments);
          return `\x1B[${code + offset}m`;
        };
        var wrapAnsi256 = (fn, offset) => function() {
          const code = fn.apply(colorConvert, arguments);
          return `\x1B[${38 + offset};5;${code}m`;
        };
        var wrapAnsi16m = (fn, offset) => function() {
          const rgb = fn.apply(colorConvert, arguments);
          return `\x1B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
        };
        function assembleStyles() {
          const codes = /* @__PURE__ */ new Map();
          const styles = {
            modifier: {
              reset: [0, 0],
              bold: [1, 22],
              dim: [2, 22],
              italic: [3, 23],
              underline: [4, 24],
              inverse: [7, 27],
              hidden: [8, 28],
              strikethrough: [9, 29]
            },
            color: {
              black: [30, 39],
              red: [31, 39],
              green: [32, 39],
              yellow: [33, 39],
              blue: [34, 39],
              magenta: [35, 39],
              cyan: [36, 39],
              white: [37, 39],
              gray: [90, 39],
              redBright: [91, 39],
              greenBright: [92, 39],
              yellowBright: [93, 39],
              blueBright: [94, 39],
              magentaBright: [95, 39],
              cyanBright: [96, 39],
              whiteBright: [97, 39]
            },
            bgColor: {
              bgBlack: [40, 49],
              bgRed: [41, 49],
              bgGreen: [42, 49],
              bgYellow: [43, 49],
              bgBlue: [44, 49],
              bgMagenta: [45, 49],
              bgCyan: [46, 49],
              bgWhite: [47, 49],
              bgBlackBright: [100, 49],
              bgRedBright: [101, 49],
              bgGreenBright: [102, 49],
              bgYellowBright: [103, 49],
              bgBlueBright: [104, 49],
              bgMagentaBright: [105, 49],
              bgCyanBright: [106, 49],
              bgWhiteBright: [107, 49]
            }
          };
          styles.color.grey = styles.color.gray;
          for (const groupName of Object.keys(styles)) {
            const group = styles[groupName];
            for (const styleName of Object.keys(group)) {
              const style = group[styleName];
              styles[styleName] = {
                open: `\x1B[${style[0]}m`,
                close: `\x1B[${style[1]}m`
              };
              group[styleName] = styles[styleName];
              codes.set(style[0], style[1]);
            }
            Object.defineProperty(styles, groupName, {
              value: group,
              enumerable: false
            });
            Object.defineProperty(styles, "codes", {
              value: codes,
              enumerable: false
            });
          }
          const ansi2ansi = (n) => n;
          const rgb2rgb = (r, g, b) => [r, g, b];
          styles.color.close = "\x1B[39m";
          styles.bgColor.close = "\x1B[49m";
          styles.color.ansi = {
            ansi: wrapAnsi16(ansi2ansi, 0)
          };
          styles.color.ansi256 = {
            ansi256: wrapAnsi256(ansi2ansi, 0)
          };
          styles.color.ansi16m = {
            rgb: wrapAnsi16m(rgb2rgb, 0)
          };
          styles.bgColor.ansi = {
            ansi: wrapAnsi16(ansi2ansi, 10)
          };
          styles.bgColor.ansi256 = {
            ansi256: wrapAnsi256(ansi2ansi, 10)
          };
          styles.bgColor.ansi16m = {
            rgb: wrapAnsi16m(rgb2rgb, 10)
          };
          for (let key of Object.keys(colorConvert)) {
            if (typeof colorConvert[key] !== "object") {
              continue;
            }
            const suite = colorConvert[key];
            if (key === "ansi16") {
              key = "ansi";
            }
            if ("ansi16" in suite) {
              styles.color.ansi[key] = wrapAnsi16(suite.ansi16, 0);
              styles.bgColor.ansi[key] = wrapAnsi16(suite.ansi16, 10);
            }
            if ("ansi256" in suite) {
              styles.color.ansi256[key] = wrapAnsi256(suite.ansi256, 0);
              styles.bgColor.ansi256[key] = wrapAnsi256(suite.ansi256, 10);
            }
            if ("rgb" in suite) {
              styles.color.ansi16m[key] = wrapAnsi16m(suite.rgb, 0);
              styles.bgColor.ansi16m[key] = wrapAnsi16m(suite.rgb, 10);
            }
          }
          return styles;
        }
        Object.defineProperty(module22, "exports", {
          enumerable: true,
          get: assembleStyles
        });
      }
    });
    var require_has_flag3 = __commonJS22({
      "node_modules/vnopts/node_modules/has-flag/index.js"(exports2, module22) {
        "use strict";
        module22.exports = (flag, argv) => {
          argv = argv || process.argv;
          const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
          const pos = argv.indexOf(prefix + flag);
          const terminatorPos = argv.indexOf("--");
          return pos !== -1 && (terminatorPos === -1 ? true : pos < terminatorPos);
        };
      }
    });
    var require_supports_color3 = __commonJS22({
      "node_modules/vnopts/node_modules/supports-color/index.js"(exports2, module22) {
        "use strict";
        var os = require("os");
        var hasFlag = require_has_flag3();
        var env = process.env;
        var forceColor;
        if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false")) {
          forceColor = false;
        } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
          forceColor = true;
        }
        if ("FORCE_COLOR" in env) {
          forceColor = env.FORCE_COLOR.length === 0 || parseInt(env.FORCE_COLOR, 10) !== 0;
        }
        function translateLevel(level) {
          if (level === 0) {
            return false;
          }
          return {
            level,
            hasBasic: true,
            has256: level >= 2,
            has16m: level >= 3
          };
        }
        function supportsColor(stream) {
          if (forceColor === false) {
            return 0;
          }
          if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
            return 3;
          }
          if (hasFlag("color=256")) {
            return 2;
          }
          if (stream && !stream.isTTY && forceColor !== true) {
            return 0;
          }
          const min2 = forceColor ? 1 : 0;
          if (process.platform === "win32") {
            const osRelease = os.release().split(".");
            if (Number(process.versions.node.split(".")[0]) >= 8 && Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
              return Number(osRelease[2]) >= 14931 ? 3 : 2;
            }
            return 1;
          }
          if ("CI" in env) {
            if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
              return 1;
            }
            return min2;
          }
          if ("TEAMCITY_VERSION" in env) {
            return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
          }
          if (env.COLORTERM === "truecolor") {
            return 3;
          }
          if ("TERM_PROGRAM" in env) {
            const version22 = parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
            switch (env.TERM_PROGRAM) {
              case "iTerm.app":
                return version22 >= 3 ? 3 : 2;
              case "Apple_Terminal":
                return 2;
            }
          }
          if (/-256(color)?$/i.test(env.TERM)) {
            return 2;
          }
          if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
            return 1;
          }
          if ("COLORTERM" in env) {
            return 1;
          }
          if (env.TERM === "dumb") {
            return min2;
          }
          return min2;
        }
        function getSupportLevel(stream) {
          const level = supportsColor(stream);
          return translateLevel(level);
        }
        module22.exports = {
          supportsColor: getSupportLevel,
          stdout: getSupportLevel(process.stdout),
          stderr: getSupportLevel(process.stderr)
        };
      }
    });
    var require_templates3 = __commonJS22({
      "node_modules/vnopts/node_modules/chalk/templates.js"(exports2, module22) {
        "use strict";
        var TEMPLATE_REGEX = /(?:\\(u[a-f\d]{4}|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
        var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
        var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
        var ESCAPE_REGEX = /\\(u[a-f\d]{4}|x[a-f\d]{2}|.)|([^\\])/gi;
        var ESCAPES = /* @__PURE__ */ new Map([["n", "\n"], ["r", "\r"], ["t", "	"], ["b", "\b"], ["f", "\f"], ["v", "\v"], ["0", "\0"], ["\\", "\\"], ["e", "\x1B"], ["a", "\x07"]]);
        function unescape2(c) {
          if (c[0] === "u" && c.length === 5 || c[0] === "x" && c.length === 3) {
            return String.fromCharCode(parseInt(c.slice(1), 16));
          }
          return ESCAPES.get(c) || c;
        }
        function parseArguments(name, args) {
          const results = [];
          const chunks = args.trim().split(/\s*,\s*/g);
          let matches;
          for (const chunk of chunks) {
            if (!isNaN(chunk)) {
              results.push(Number(chunk));
            } else if (matches = chunk.match(STRING_REGEX)) {
              results.push(matches[2].replace(ESCAPE_REGEX, (m, escape2, chr) => escape2 ? unescape2(escape2) : chr));
            } else {
              throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
            }
          }
          return results;
        }
        function parseStyle(style) {
          STYLE_REGEX.lastIndex = 0;
          const results = [];
          let matches;
          while ((matches = STYLE_REGEX.exec(style)) !== null) {
            const name = matches[1];
            if (matches[2]) {
              const args = parseArguments(name, matches[2]);
              results.push([name].concat(args));
            } else {
              results.push([name]);
            }
          }
          return results;
        }
        function buildStyle(chalk3, styles) {
          const enabled = {};
          for (const layer of styles) {
            for (const style of layer.styles) {
              enabled[style[0]] = layer.inverse ? null : style.slice(1);
            }
          }
          let current = chalk3;
          for (const styleName of Object.keys(enabled)) {
            if (Array.isArray(enabled[styleName])) {
              if (!(styleName in current)) {
                throw new Error(`Unknown Chalk style: ${styleName}`);
              }
              if (enabled[styleName].length > 0) {
                current = current[styleName].apply(current, enabled[styleName]);
              } else {
                current = current[styleName];
              }
            }
          }
          return current;
        }
        module22.exports = (chalk3, tmp) => {
          const styles = [];
          const chunks = [];
          let chunk = [];
          tmp.replace(TEMPLATE_REGEX, (m, escapeChar, inverse, style, close, chr) => {
            if (escapeChar) {
              chunk.push(unescape2(escapeChar));
            } else if (style) {
              const str = chunk.join("");
              chunk = [];
              chunks.push(styles.length === 0 ? str : buildStyle(chalk3, styles)(str));
              styles.push({
                inverse,
                styles: parseStyle(style)
              });
            } else if (close) {
              if (styles.length === 0) {
                throw new Error("Found extraneous } in Chalk template literal");
              }
              chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
              chunk = [];
              styles.pop();
            } else {
              chunk.push(chr);
            }
          });
          chunks.push(chunk.join(""));
          if (styles.length > 0) {
            const errMsg = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
            throw new Error(errMsg);
          }
          return chunks.join("");
        };
      }
    });
    var require_chalk2 = __commonJS22({
      "node_modules/vnopts/node_modules/chalk/index.js"(exports2, module22) {
        "use strict";
        var escapeStringRegexp2 = require_escape_string_regexp3();
        var ansiStyles = require_ansi_styles3();
        var stdoutColor = require_supports_color3().stdout;
        var template = require_templates3();
        var isSimpleWindowsTerm = process.platform === "win32" && !(process.env.TERM || "").toLowerCase().startsWith("xterm");
        var levelMapping = ["ansi", "ansi", "ansi256", "ansi16m"];
        var skipModels = /* @__PURE__ */ new Set(["gray"]);
        var styles = /* @__PURE__ */ Object.create(null);
        function applyOptions(obj, options) {
          options = options || {};
          const scLevel = stdoutColor ? stdoutColor.level : 0;
          obj.level = options.level === void 0 ? scLevel : options.level;
          obj.enabled = "enabled" in options ? options.enabled : obj.level > 0;
        }
        function Chalk(options) {
          if (!this || !(this instanceof Chalk) || this.template) {
            const chalk3 = {};
            applyOptions(chalk3, options);
            chalk3.template = function() {
              const args = [].slice.call(arguments);
              return chalkTag.apply(null, [chalk3.template].concat(args));
            };
            Object.setPrototypeOf(chalk3, Chalk.prototype);
            Object.setPrototypeOf(chalk3.template, chalk3);
            chalk3.template.constructor = Chalk;
            return chalk3.template;
          }
          applyOptions(this, options);
        }
        if (isSimpleWindowsTerm) {
          ansiStyles.blue.open = "\x1B[94m";
        }
        for (const key of Object.keys(ansiStyles)) {
          ansiStyles[key].closeRe = new RegExp(escapeStringRegexp2(ansiStyles[key].close), "g");
          styles[key] = {
            get() {
              const codes = ansiStyles[key];
              return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, key);
            }
          };
        }
        styles.visible = {
          get() {
            return build.call(this, this._styles || [], true, "visible");
          }
        };
        ansiStyles.color.closeRe = new RegExp(escapeStringRegexp2(ansiStyles.color.close), "g");
        for (const model of Object.keys(ansiStyles.color.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          styles[model] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.color[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.color.close,
                  closeRe: ansiStyles.color.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        ansiStyles.bgColor.closeRe = new RegExp(escapeStringRegexp2(ansiStyles.bgColor.close), "g");
        for (const model of Object.keys(ansiStyles.bgColor.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
          styles[bgModel] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.bgColor[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.bgColor.close,
                  closeRe: ansiStyles.bgColor.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        var proto = Object.defineProperties(() => {
        }, styles);
        function build(_styles, _empty, key) {
          const builder = function() {
            return applyStyle.apply(builder, arguments);
          };
          builder._styles = _styles;
          builder._empty = _empty;
          const self2 = this;
          Object.defineProperty(builder, "level", {
            enumerable: true,
            get() {
              return self2.level;
            },
            set(level) {
              self2.level = level;
            }
          });
          Object.defineProperty(builder, "enabled", {
            enumerable: true,
            get() {
              return self2.enabled;
            },
            set(enabled) {
              self2.enabled = enabled;
            }
          });
          builder.hasGrey = this.hasGrey || key === "gray" || key === "grey";
          builder.__proto__ = proto;
          return builder;
        }
        function applyStyle() {
          const args = arguments;
          const argsLen = args.length;
          let str = String(arguments[0]);
          if (argsLen === 0) {
            return "";
          }
          if (argsLen > 1) {
            for (let a = 1; a < argsLen; a++) {
              str += " " + args[a];
            }
          }
          if (!this.enabled || this.level <= 0 || !str) {
            return this._empty ? "" : str;
          }
          const originalDim = ansiStyles.dim.open;
          if (isSimpleWindowsTerm && this.hasGrey) {
            ansiStyles.dim.open = "";
          }
          for (const code of this._styles.slice().reverse()) {
            str = code.open + str.replace(code.closeRe, code.open) + code.close;
            str = str.replace(/\r?\n/g, `${code.close}$&${code.open}`);
          }
          ansiStyles.dim.open = originalDim;
          return str;
        }
        function chalkTag(chalk3, strings) {
          if (!Array.isArray(strings)) {
            return [].slice.call(arguments, 1).join(" ");
          }
          const args = [].slice.call(arguments, 2);
          const parts = [strings.raw[0]];
          for (let i = 1; i < strings.length; i++) {
            parts.push(String(args[i - 1]).replace(/[{}\\]/g, "\\$&"));
            parts.push(String(strings.raw[i]));
          }
          return template(chalk3, parts.join(""));
        }
        Object.defineProperties(Chalk.prototype, styles);
        module22.exports = Chalk();
        module22.exports.supportsColor = stdoutColor;
        module22.exports.default = module22.exports;
      }
    });
    var require_common5 = __commonJS22({
      "node_modules/vnopts/lib/handlers/deprecated/common.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var chalk_1 = require_chalk2();
        exports2.commonDeprecatedHandler = (keyOrPair, redirectTo, {
          descriptor
        }) => {
          const messages = [`${chalk_1.default.yellow(typeof keyOrPair === "string" ? descriptor.key(keyOrPair) : descriptor.pair(keyOrPair))} is deprecated`];
          if (redirectTo) {
            messages.push(`we now treat it as ${chalk_1.default.blue(typeof redirectTo === "string" ? descriptor.key(redirectTo) : descriptor.pair(redirectTo))}`);
          }
          return messages.join("; ") + ".";
        };
      }
    });
    var require_deprecated = __commonJS22({
      "node_modules/vnopts/lib/handlers/deprecated/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_common5(), exports2);
      }
    });
    var require_common22 = __commonJS22({
      "node_modules/vnopts/lib/handlers/invalid/common.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var chalk_1 = require_chalk2();
        exports2.commonInvalidHandler = (key, value2, utils2) => [`Invalid ${chalk_1.default.red(utils2.descriptor.key(key))} value.`, `Expected ${chalk_1.default.blue(utils2.schemas[key].expected(utils2))},`, `but received ${chalk_1.default.red(utils2.descriptor.value(value2))}.`].join(" ");
      }
    });
    var require_invalid = __commonJS22({
      "node_modules/vnopts/lib/handlers/invalid/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_common22(), exports2);
      }
    });
    var require_leven = __commonJS22({
      "node_modules/vnopts/node_modules/leven/index.js"(exports2, module22) {
        "use strict";
        var arr = [];
        var charCodeCache = [];
        module22.exports = function(a, b) {
          if (a === b) {
            return 0;
          }
          var swap = a;
          if (a.length > b.length) {
            a = b;
            b = swap;
          }
          var aLen = a.length;
          var bLen = b.length;
          if (aLen === 0) {
            return bLen;
          }
          if (bLen === 0) {
            return aLen;
          }
          while (aLen > 0 && a.charCodeAt(~-aLen) === b.charCodeAt(~-bLen)) {
            aLen--;
            bLen--;
          }
          if (aLen === 0) {
            return bLen;
          }
          var start = 0;
          while (start < aLen && a.charCodeAt(start) === b.charCodeAt(start)) {
            start++;
          }
          aLen -= start;
          bLen -= start;
          if (aLen === 0) {
            return bLen;
          }
          var bCharCode;
          var ret;
          var tmp;
          var tmp2;
          var i = 0;
          var j = 0;
          while (i < aLen) {
            charCodeCache[start + i] = a.charCodeAt(start + i);
            arr[i] = ++i;
          }
          while (j < bLen) {
            bCharCode = b.charCodeAt(start + j);
            tmp = j++;
            ret = j;
            for (i = 0; i < aLen; i++) {
              tmp2 = bCharCode === charCodeCache[start + i] ? tmp : tmp + 1;
              tmp = arr[i];
              ret = arr[i] = tmp > ret ? tmp2 > ret ? ret + 1 : tmp2 : tmp2 > tmp ? tmp + 1 : tmp2;
            }
          }
          return ret;
        };
      }
    });
    var require_leven2 = __commonJS22({
      "node_modules/vnopts/lib/handlers/unknown/leven.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var chalk_1 = require_chalk2();
        var leven = require_leven();
        exports2.levenUnknownHandler = (key, value2, {
          descriptor,
          logger,
          schemas
        }) => {
          const messages = [`Ignored unknown option ${chalk_1.default.yellow(descriptor.pair({
            key,
            value: value2
          }))}.`];
          const suggestion = Object.keys(schemas).sort().find((knownKey) => leven(key, knownKey) < 3);
          if (suggestion) {
            messages.push(`Did you mean ${chalk_1.default.blue(descriptor.key(suggestion))}?`);
          }
          logger.warn(messages.join(" "));
        };
      }
    });
    var require_unknown = __commonJS22({
      "node_modules/vnopts/lib/handlers/unknown/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_leven2(), exports2);
      }
    });
    var require_handlers = __commonJS22({
      "node_modules/vnopts/lib/handlers/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_deprecated(), exports2);
        tslib_1.__exportStar(require_invalid(), exports2);
        tslib_1.__exportStar(require_unknown(), exports2);
      }
    });
    var require_schema = __commonJS22({
      "node_modules/vnopts/lib/schema.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var HANDLER_KEYS = ["default", "expected", "validate", "deprecated", "forward", "redirect", "overlap", "preprocess", "postprocess"];
        function createSchema(SchemaConstructor, parameters) {
          const schema = new SchemaConstructor(parameters);
          const subSchema = Object.create(schema);
          for (const handlerKey of HANDLER_KEYS) {
            if (handlerKey in parameters) {
              subSchema[handlerKey] = normalizeHandler(parameters[handlerKey], schema, Schema.prototype[handlerKey].length);
            }
          }
          return subSchema;
        }
        exports2.createSchema = createSchema;
        var Schema = class {
          constructor(parameters) {
            this.name = parameters.name;
          }
          static create(parameters) {
            return createSchema(this, parameters);
          }
          default(_utils) {
            return void 0;
          }
          expected(_utils) {
            return "nothing";
          }
          validate(_value, _utils) {
            return false;
          }
          deprecated(_value, _utils) {
            return false;
          }
          forward(_value, _utils) {
            return void 0;
          }
          redirect(_value, _utils) {
            return void 0;
          }
          overlap(currentValue, _newValue, _utils) {
            return currentValue;
          }
          preprocess(value2, _utils) {
            return value2;
          }
          postprocess(value2, _utils) {
            return value2;
          }
        };
        exports2.Schema = Schema;
        function normalizeHandler(handler, superSchema, handlerArgumentsLength) {
          return typeof handler === "function" ? (...args) => handler(...args.slice(0, handlerArgumentsLength - 1), superSchema, ...args.slice(handlerArgumentsLength - 1)) : () => handler;
        }
      }
    });
    var require_alias = __commonJS22({
      "node_modules/vnopts/lib/schemas/alias.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var AliasSchema = class extends schema_1.Schema {
          constructor(parameters) {
            super(parameters);
            this._sourceName = parameters.sourceName;
          }
          expected(utils2) {
            return utils2.schemas[this._sourceName].expected(utils2);
          }
          validate(value2, utils2) {
            return utils2.schemas[this._sourceName].validate(value2, utils2);
          }
          redirect(_value, _utils) {
            return this._sourceName;
          }
        };
        exports2.AliasSchema = AliasSchema;
      }
    });
    var require_any = __commonJS22({
      "node_modules/vnopts/lib/schemas/any.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var AnySchema = class extends schema_1.Schema {
          expected() {
            return "anything";
          }
          validate() {
            return true;
          }
        };
        exports2.AnySchema = AnySchema;
      }
    });
    var require_array2 = __commonJS22({
      "node_modules/vnopts/lib/schemas/array.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        var schema_1 = require_schema();
        var ArraySchema = class extends schema_1.Schema {
          constructor(_a) {
            var {
              valueSchema,
              name = valueSchema.name
            } = _a, handlers = tslib_1.__rest(_a, ["valueSchema", "name"]);
            super(Object.assign({}, handlers, {
              name
            }));
            this._valueSchema = valueSchema;
          }
          expected(utils2) {
            return `an array of ${this._valueSchema.expected(utils2)}`;
          }
          validate(value2, utils2) {
            if (!Array.isArray(value2)) {
              return false;
            }
            const invalidValues = [];
            for (const subValue of value2) {
              const subValidateResult = utils2.normalizeValidateResult(this._valueSchema.validate(subValue, utils2), subValue);
              if (subValidateResult !== true) {
                invalidValues.push(subValidateResult.value);
              }
            }
            return invalidValues.length === 0 ? true : {
              value: invalidValues
            };
          }
          deprecated(value2, utils2) {
            const deprecatedResult = [];
            for (const subValue of value2) {
              const subDeprecatedResult = utils2.normalizeDeprecatedResult(this._valueSchema.deprecated(subValue, utils2), subValue);
              if (subDeprecatedResult !== false) {
                deprecatedResult.push(...subDeprecatedResult.map(({
                  value: deprecatedValue
                }) => ({
                  value: [deprecatedValue]
                })));
              }
            }
            return deprecatedResult;
          }
          forward(value2, utils2) {
            const forwardResult = [];
            for (const subValue of value2) {
              const subForwardResult = utils2.normalizeForwardResult(this._valueSchema.forward(subValue, utils2), subValue);
              forwardResult.push(...subForwardResult.map(wrapTransferResult));
            }
            return forwardResult;
          }
          redirect(value2, utils2) {
            const remain = [];
            const redirect = [];
            for (const subValue of value2) {
              const subRedirectResult = utils2.normalizeRedirectResult(this._valueSchema.redirect(subValue, utils2), subValue);
              if ("remain" in subRedirectResult) {
                remain.push(subRedirectResult.remain);
              }
              redirect.push(...subRedirectResult.redirect.map(wrapTransferResult));
            }
            return remain.length === 0 ? {
              redirect
            } : {
              redirect,
              remain
            };
          }
          overlap(currentValue, newValue) {
            return currentValue.concat(newValue);
          }
        };
        exports2.ArraySchema = ArraySchema;
        function wrapTransferResult({
          from,
          to
        }) {
          return {
            from: [from],
            to
          };
        }
      }
    });
    var require_boolean = __commonJS22({
      "node_modules/vnopts/lib/schemas/boolean.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var BooleanSchema = class extends schema_1.Schema {
          expected() {
            return "true or false";
          }
          validate(value2) {
            return typeof value2 === "boolean";
          }
        };
        exports2.BooleanSchema = BooleanSchema;
      }
    });
    var require_utils10 = __commonJS22({
      "node_modules/vnopts/lib/utils.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        function recordFromArray(array, mainKey) {
          const record = /* @__PURE__ */ Object.create(null);
          for (const value2 of array) {
            const key = value2[mainKey];
            if (record[key]) {
              throw new Error(`Duplicate ${mainKey} ${JSON.stringify(key)}`);
            }
            record[key] = value2;
          }
          return record;
        }
        exports2.recordFromArray = recordFromArray;
        function mapFromArray(array, mainKey) {
          const map = /* @__PURE__ */ new Map();
          for (const value2 of array) {
            const key = value2[mainKey];
            if (map.has(key)) {
              throw new Error(`Duplicate ${mainKey} ${JSON.stringify(key)}`);
            }
            map.set(key, value2);
          }
          return map;
        }
        exports2.mapFromArray = mapFromArray;
        function createAutoChecklist() {
          const map = /* @__PURE__ */ Object.create(null);
          return (id) => {
            const idString = JSON.stringify(id);
            if (map[idString]) {
              return true;
            }
            map[idString] = true;
            return false;
          };
        }
        exports2.createAutoChecklist = createAutoChecklist;
        function partition(array, predicate) {
          const trueArray = [];
          const falseArray = [];
          for (const value2 of array) {
            if (predicate(value2)) {
              trueArray.push(value2);
            } else {
              falseArray.push(value2);
            }
          }
          return [trueArray, falseArray];
        }
        exports2.partition = partition;
        function isInt(value2) {
          return value2 === Math.floor(value2);
        }
        exports2.isInt = isInt;
        function comparePrimitive(a, b) {
          if (a === b) {
            return 0;
          }
          const typeofA = typeof a;
          const typeofB = typeof b;
          const orders = ["undefined", "object", "boolean", "number", "string"];
          if (typeofA !== typeofB) {
            return orders.indexOf(typeofA) - orders.indexOf(typeofB);
          }
          if (typeofA !== "string") {
            return Number(a) - Number(b);
          }
          return a.localeCompare(b);
        }
        exports2.comparePrimitive = comparePrimitive;
        function normalizeDefaultResult(result) {
          return result === void 0 ? {} : result;
        }
        exports2.normalizeDefaultResult = normalizeDefaultResult;
        function normalizeValidateResult(result, value2) {
          return result === true ? true : result === false ? {
            value: value2
          } : result;
        }
        exports2.normalizeValidateResult = normalizeValidateResult;
        function normalizeDeprecatedResult(result, value2, doNotNormalizeTrue = false) {
          return result === false ? false : result === true ? doNotNormalizeTrue ? true : [{
            value: value2
          }] : "value" in result ? [result] : result.length === 0 ? false : result;
        }
        exports2.normalizeDeprecatedResult = normalizeDeprecatedResult;
        function normalizeTransferResult(result, value2) {
          return typeof result === "string" || "key" in result ? {
            from: value2,
            to: result
          } : "from" in result ? {
            from: result.from,
            to: result.to
          } : {
            from: value2,
            to: result.to
          };
        }
        exports2.normalizeTransferResult = normalizeTransferResult;
        function normalizeForwardResult(result, value2) {
          return result === void 0 ? [] : Array.isArray(result) ? result.map((transferResult) => normalizeTransferResult(transferResult, value2)) : [normalizeTransferResult(result, value2)];
        }
        exports2.normalizeForwardResult = normalizeForwardResult;
        function normalizeRedirectResult(result, value2) {
          const redirect = normalizeForwardResult(typeof result === "object" && "redirect" in result ? result.redirect : result, value2);
          return redirect.length === 0 ? {
            remain: value2,
            redirect
          } : typeof result === "object" && "remain" in result ? {
            remain: result.remain,
            redirect
          } : {
            redirect
          };
        }
        exports2.normalizeRedirectResult = normalizeRedirectResult;
      }
    });
    var require_choice2 = __commonJS22({
      "node_modules/vnopts/lib/schemas/choice.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var utils_1 = require_utils10();
        var ChoiceSchema = class extends schema_1.Schema {
          constructor(parameters) {
            super(parameters);
            this._choices = utils_1.mapFromArray(parameters.choices.map((choice) => choice && typeof choice === "object" ? choice : {
              value: choice
            }), "value");
          }
          expected({
            descriptor
          }) {
            const choiceValues = Array.from(this._choices.keys()).map((value2) => this._choices.get(value2)).filter((choiceInfo) => !choiceInfo.deprecated).map((choiceInfo) => choiceInfo.value).sort(utils_1.comparePrimitive).map(descriptor.value);
            const head = choiceValues.slice(0, -2);
            const tail = choiceValues.slice(-2);
            return head.concat(tail.join(" or ")).join(", ");
          }
          validate(value2) {
            return this._choices.has(value2);
          }
          deprecated(value2) {
            const choiceInfo = this._choices.get(value2);
            return choiceInfo && choiceInfo.deprecated ? {
              value: value2
            } : false;
          }
          forward(value2) {
            const choiceInfo = this._choices.get(value2);
            return choiceInfo ? choiceInfo.forward : void 0;
          }
          redirect(value2) {
            const choiceInfo = this._choices.get(value2);
            return choiceInfo ? choiceInfo.redirect : void 0;
          }
        };
        exports2.ChoiceSchema = ChoiceSchema;
      }
    });
    var require_number2 = __commonJS22({
      "node_modules/vnopts/lib/schemas/number.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var NumberSchema = class extends schema_1.Schema {
          expected() {
            return "a number";
          }
          validate(value2, _utils) {
            return typeof value2 === "number";
          }
        };
        exports2.NumberSchema = NumberSchema;
      }
    });
    var require_integer = __commonJS22({
      "node_modules/vnopts/lib/schemas/integer.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils_1 = require_utils10();
        var number_1 = require_number2();
        var IntegerSchema = class extends number_1.NumberSchema {
          expected() {
            return "an integer";
          }
          validate(value2, utils2) {
            return utils2.normalizeValidateResult(super.validate(value2, utils2), value2) === true && utils_1.isInt(value2);
          }
        };
        exports2.IntegerSchema = IntegerSchema;
      }
    });
    var require_string2 = __commonJS22({
      "node_modules/vnopts/lib/schemas/string.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var schema_1 = require_schema();
        var StringSchema = class extends schema_1.Schema {
          expected() {
            return "a string";
          }
          validate(value2) {
            return typeof value2 === "string";
          }
        };
        exports2.StringSchema = StringSchema;
      }
    });
    var require_schemas = __commonJS22({
      "node_modules/vnopts/lib/schemas/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_alias(), exports2);
        tslib_1.__exportStar(require_any(), exports2);
        tslib_1.__exportStar(require_array2(), exports2);
        tslib_1.__exportStar(require_boolean(), exports2);
        tslib_1.__exportStar(require_choice2(), exports2);
        tslib_1.__exportStar(require_integer(), exports2);
        tslib_1.__exportStar(require_number2(), exports2);
        tslib_1.__exportStar(require_string2(), exports2);
      }
    });
    var require_defaults3 = __commonJS22({
      "node_modules/vnopts/lib/defaults.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var api_1 = require_api3();
        var common_1 = require_common5();
        var invalid_1 = require_invalid();
        var leven_1 = require_leven2();
        exports2.defaultDescriptor = api_1.apiDescriptor;
        exports2.defaultUnknownHandler = leven_1.levenUnknownHandler;
        exports2.defaultInvalidHandler = invalid_1.commonInvalidHandler;
        exports2.defaultDeprecatedHandler = common_1.commonDeprecatedHandler;
      }
    });
    var require_normalize = __commonJS22({
      "node_modules/vnopts/lib/normalize.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var defaults_1 = require_defaults3();
        var utils_1 = require_utils10();
        exports2.normalize = (options, schemas, opts) => new Normalizer(schemas, opts).normalize(options);
        var Normalizer = class {
          constructor(schemas, opts) {
            const {
              logger = console,
              descriptor = defaults_1.defaultDescriptor,
              unknown = defaults_1.defaultUnknownHandler,
              invalid = defaults_1.defaultInvalidHandler,
              deprecated = defaults_1.defaultDeprecatedHandler
            } = opts || {};
            this._utils = {
              descriptor,
              logger: logger || {
                warn: () => {
                }
              },
              schemas: utils_1.recordFromArray(schemas, "name"),
              normalizeDefaultResult: utils_1.normalizeDefaultResult,
              normalizeDeprecatedResult: utils_1.normalizeDeprecatedResult,
              normalizeForwardResult: utils_1.normalizeForwardResult,
              normalizeRedirectResult: utils_1.normalizeRedirectResult,
              normalizeValidateResult: utils_1.normalizeValidateResult
            };
            this._unknownHandler = unknown;
            this._invalidHandler = invalid;
            this._deprecatedHandler = deprecated;
            this.cleanHistory();
          }
          cleanHistory() {
            this._hasDeprecationWarned = utils_1.createAutoChecklist();
          }
          normalize(options) {
            const normalized = {};
            const restOptionsArray = [options];
            const applyNormalization = () => {
              while (restOptionsArray.length !== 0) {
                const currentOptions = restOptionsArray.shift();
                const transferredOptionsArray = this._applyNormalization(currentOptions, normalized);
                restOptionsArray.push(...transferredOptionsArray);
              }
            };
            applyNormalization();
            for (const key of Object.keys(this._utils.schemas)) {
              const schema = this._utils.schemas[key];
              if (!(key in normalized)) {
                const defaultResult = utils_1.normalizeDefaultResult(schema.default(this._utils));
                if ("value" in defaultResult) {
                  restOptionsArray.push({
                    [key]: defaultResult.value
                  });
                }
              }
            }
            applyNormalization();
            for (const key of Object.keys(this._utils.schemas)) {
              const schema = this._utils.schemas[key];
              if (key in normalized) {
                normalized[key] = schema.postprocess(normalized[key], this._utils);
              }
            }
            return normalized;
          }
          _applyNormalization(options, normalized) {
            const transferredOptionsArray = [];
            const [knownOptionNames, unknownOptionNames] = utils_1.partition(Object.keys(options), (key) => key in this._utils.schemas);
            for (const key of knownOptionNames) {
              const schema = this._utils.schemas[key];
              const value2 = schema.preprocess(options[key], this._utils);
              const validateResult = utils_1.normalizeValidateResult(schema.validate(value2, this._utils), value2);
              if (validateResult !== true) {
                const {
                  value: invalidValue
                } = validateResult;
                const errorMessageOrError = this._invalidHandler(key, invalidValue, this._utils);
                throw typeof errorMessageOrError === "string" ? new Error(errorMessageOrError) : errorMessageOrError;
              }
              const appendTransferredOptions = ({
                from,
                to
              }) => {
                transferredOptionsArray.push(typeof to === "string" ? {
                  [to]: from
                } : {
                  [to.key]: to.value
                });
              };
              const warnDeprecated = ({
                value: currentValue,
                redirectTo
              }) => {
                const deprecatedResult = utils_1.normalizeDeprecatedResult(schema.deprecated(currentValue, this._utils), value2, true);
                if (deprecatedResult === false) {
                  return;
                }
                if (deprecatedResult === true) {
                  if (!this._hasDeprecationWarned(key)) {
                    this._utils.logger.warn(this._deprecatedHandler(key, redirectTo, this._utils));
                  }
                } else {
                  for (const {
                    value: deprecatedValue
                  } of deprecatedResult) {
                    const pair = {
                      key,
                      value: deprecatedValue
                    };
                    if (!this._hasDeprecationWarned(pair)) {
                      const redirectToPair = typeof redirectTo === "string" ? {
                        key: redirectTo,
                        value: deprecatedValue
                      } : redirectTo;
                      this._utils.logger.warn(this._deprecatedHandler(pair, redirectToPair, this._utils));
                    }
                  }
                }
              };
              const forwardResult = utils_1.normalizeForwardResult(schema.forward(value2, this._utils), value2);
              forwardResult.forEach(appendTransferredOptions);
              const redirectResult = utils_1.normalizeRedirectResult(schema.redirect(value2, this._utils), value2);
              redirectResult.redirect.forEach(appendTransferredOptions);
              if ("remain" in redirectResult) {
                const remainingValue = redirectResult.remain;
                normalized[key] = key in normalized ? schema.overlap(normalized[key], remainingValue, this._utils) : remainingValue;
                warnDeprecated({
                  value: remainingValue
                });
              }
              for (const {
                from,
                to
              } of redirectResult.redirect) {
                warnDeprecated({
                  value: from,
                  redirectTo: to
                });
              }
            }
            for (const key of unknownOptionNames) {
              const value2 = options[key];
              const unknownResult = this._unknownHandler(key, value2, this._utils);
              if (unknownResult) {
                for (const unknownKey of Object.keys(unknownResult)) {
                  const unknownOption = {
                    [unknownKey]: unknownResult[unknownKey]
                  };
                  if (unknownKey in this._utils.schemas) {
                    transferredOptionsArray.push(unknownOption);
                  } else {
                    Object.assign(normalized, unknownOption);
                  }
                }
              }
            }
            return transferredOptionsArray;
          }
        };
        exports2.Normalizer = Normalizer;
      }
    });
    var require_lib210 = __commonJS22({
      "node_modules/vnopts/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
        tslib_1.__exportStar(require_descriptors2(), exports2);
        tslib_1.__exportStar(require_handlers(), exports2);
        tslib_1.__exportStar(require_schemas(), exports2);
        tslib_1.__exportStar(require_normalize(), exports2);
        tslib_1.__exportStar(require_schema(), exports2);
      }
    });
    var require_options_normalizer = __commonJS22({
      "src/main/options-normalizer.js"(exports2, module22) {
        "use strict";
        var vnopts = require_lib210();
        var getLast = require_get_last();
        var cliDescriptor = {
          key: (key) => key.length === 1 ? `-${key}` : `--${key}`,
          value: (value2) => vnopts.apiDescriptor.value(value2),
          pair: ({
            key,
            value: value2
          }) => value2 === false ? `--no-${key}` : value2 === true ? cliDescriptor.key(key) : value2 === "" ? `${cliDescriptor.key(key)} without an argument` : `${cliDescriptor.key(key)}=${value2}`
        };
        var getFlagSchema = ({
          colorsModule,
          levenshteinDistance
        }) => class FlagSchema extends vnopts.ChoiceSchema {
          constructor({
            name,
            flags
          }) {
            super({
              name,
              choices: flags
            });
            this._flags = [...flags].sort();
          }
          preprocess(value2, utils2) {
            if (typeof value2 === "string" && value2.length > 0 && !this._flags.includes(value2)) {
              const suggestion = this._flags.find((flag) => levenshteinDistance(flag, value2) < 3);
              if (suggestion) {
                utils2.logger.warn([`Unknown flag ${colorsModule.yellow(utils2.descriptor.value(value2))},`, `did you mean ${colorsModule.blue(utils2.descriptor.value(suggestion))}?`].join(" "));
                return suggestion;
              }
            }
            return value2;
          }
          expected() {
            return "a flag";
          }
        };
        var hasDeprecationWarned;
        function normalizeOptions(options, optionInfos, {
          logger = false,
          isCLI = false,
          passThrough = false,
          colorsModule = null,
          levenshteinDistance = null
        } = {}) {
          const unknown = !passThrough ? (key, value2, options2) => {
            const _options2$schemas = options2.schemas, {
              _
            } = _options2$schemas, schemas2 = _objectWithoutProperties(_options2$schemas, _excluded2);
            return vnopts.levenUnknownHandler(key, value2, Object.assign(Object.assign({}, options2), {}, {
              schemas: schemas2
            }));
          } : Array.isArray(passThrough) ? (key, value2) => !passThrough.includes(key) ? void 0 : {
            [key]: value2
          } : (key, value2) => ({
            [key]: value2
          });
          const descriptor = isCLI ? cliDescriptor : vnopts.apiDescriptor;
          const schemas = optionInfosToSchemas(optionInfos, {
            isCLI,
            colorsModule,
            levenshteinDistance
          });
          const normalizer = new vnopts.Normalizer(schemas, {
            logger,
            unknown,
            descriptor
          });
          const shouldSuppressDuplicateDeprecationWarnings = logger !== false;
          if (shouldSuppressDuplicateDeprecationWarnings && hasDeprecationWarned) {
            normalizer._hasDeprecationWarned = hasDeprecationWarned;
          }
          const normalized = normalizer.normalize(options);
          if (shouldSuppressDuplicateDeprecationWarnings) {
            hasDeprecationWarned = normalizer._hasDeprecationWarned;
          }
          if (isCLI && normalized["plugin-search"] === false) {
            normalized["plugin-search-dir"] = false;
          }
          return normalized;
        }
        function optionInfosToSchemas(optionInfos, {
          isCLI,
          colorsModule,
          levenshteinDistance
        }) {
          const schemas = [];
          if (isCLI) {
            schemas.push(vnopts.AnySchema.create({
              name: "_"
            }));
          }
          for (const optionInfo of optionInfos) {
            schemas.push(optionInfoToSchema(optionInfo, {
              isCLI,
              optionInfos,
              colorsModule,
              levenshteinDistance
            }));
            if (optionInfo.alias && isCLI) {
              schemas.push(vnopts.AliasSchema.create({
                name: optionInfo.alias,
                sourceName: optionInfo.name
              }));
            }
          }
          return schemas;
        }
        function optionInfoToSchema(optionInfo, {
          isCLI,
          optionInfos,
          colorsModule,
          levenshteinDistance
        }) {
          const {
            name
          } = optionInfo;
          if (name === "plugin-search-dir" || name === "pluginSearchDirs") {
            return vnopts.AnySchema.create({
              name,
              preprocess(value2) {
                if (value2 === false) {
                  return value2;
                }
                value2 = Array.isArray(value2) ? value2 : [value2];
                return value2;
              },
              validate(value2) {
                if (value2 === false) {
                  return true;
                }
                return value2.every((dir) => typeof dir === "string");
              },
              expected() {
                return "false or paths to plugin search dir";
              }
            });
          }
          const parameters = {
            name
          };
          let SchemaConstructor;
          const handlers = {};
          switch (optionInfo.type) {
            case "int":
              SchemaConstructor = vnopts.IntegerSchema;
              if (isCLI) {
                parameters.preprocess = Number;
              }
              break;
            case "string":
              SchemaConstructor = vnopts.StringSchema;
              break;
            case "choice":
              SchemaConstructor = vnopts.ChoiceSchema;
              parameters.choices = optionInfo.choices.map((choiceInfo) => typeof choiceInfo === "object" && choiceInfo.redirect ? Object.assign(Object.assign({}, choiceInfo), {}, {
                redirect: {
                  to: {
                    key: optionInfo.name,
                    value: choiceInfo.redirect
                  }
                }
              }) : choiceInfo);
              break;
            case "boolean":
              SchemaConstructor = vnopts.BooleanSchema;
              break;
            case "flag":
              SchemaConstructor = getFlagSchema({
                colorsModule,
                levenshteinDistance
              });
              parameters.flags = optionInfos.flatMap((optionInfo2) => [optionInfo2.alias, optionInfo2.description && optionInfo2.name, optionInfo2.oppositeDescription && `no-${optionInfo2.name}`].filter(Boolean));
              break;
            case "path":
              SchemaConstructor = vnopts.StringSchema;
              break;
            default:
              throw new Error(`Unexpected type ${optionInfo.type}`);
          }
          if (optionInfo.exception) {
            parameters.validate = (value2, schema, utils2) => optionInfo.exception(value2) || schema.validate(value2, utils2);
          } else {
            parameters.validate = (value2, schema, utils2) => value2 === void 0 || schema.validate(value2, utils2);
          }
          if (optionInfo.redirect) {
            handlers.redirect = (value2) => !value2 ? void 0 : {
              to: {
                key: optionInfo.redirect.option,
                value: optionInfo.redirect.value
              }
            };
          }
          if (optionInfo.deprecated) {
            handlers.deprecated = true;
          }
          if (isCLI && !optionInfo.array) {
            const originalPreprocess = parameters.preprocess || ((x) => x);
            parameters.preprocess = (value2, schema, utils2) => schema.preprocess(originalPreprocess(Array.isArray(value2) ? getLast(value2) : value2), utils2);
          }
          return optionInfo.array ? vnopts.ArraySchema.create(Object.assign(Object.assign(Object.assign({}, isCLI ? {
            preprocess: (v) => Array.isArray(v) ? v : [v]
          } : {}), handlers), {}, {
            valueSchema: SchemaConstructor.create(parameters)
          })) : SchemaConstructor.create(Object.assign(Object.assign({}, parameters), handlers));
        }
        function normalizeApiOptions(options, optionInfos, opts) {
          return normalizeOptions(options, optionInfos, opts);
        }
        function normalizeCliOptions(options, optionInfos, opts) {
          if (false) {
            if (!opts.colorsModule) {
              throw new Error("'colorsModule' option is required.");
            }
            if (!opts.levenshteinDistance) {
              throw new Error("'levenshteinDistance' option is required.");
            }
          }
          return normalizeOptions(options, optionInfos, Object.assign({
            isCLI: true
          }, opts));
        }
        module22.exports = {
          normalizeApiOptions,
          normalizeCliOptions
        };
      }
    });
    var require_loc = __commonJS22({
      "src/language-js/loc.js"(exports2, module22) {
        "use strict";
        var isNonEmptyArray = require_is_non_empty_array();
        function locStart(node) {
          var _node$declaration$dec, _node$declaration;
          const start = node.range ? node.range[0] : node.start;
          const decorators = (_node$declaration$dec = (_node$declaration = node.declaration) === null || _node$declaration === void 0 ? void 0 : _node$declaration.decorators) !== null && _node$declaration$dec !== void 0 ? _node$declaration$dec : node.decorators;
          if (isNonEmptyArray(decorators)) {
            return Math.min(locStart(decorators[0]), start);
          }
          return start;
        }
        function locEnd(node) {
          return node.range ? node.range[1] : node.end;
        }
        function hasSameLocStart(nodeA, nodeB) {
          const nodeAStart = locStart(nodeA);
          return Number.isInteger(nodeAStart) && nodeAStart === locStart(nodeB);
        }
        function hasSameLocEnd(nodeA, nodeB) {
          const nodeAEnd = locEnd(nodeA);
          return Number.isInteger(nodeAEnd) && nodeAEnd === locEnd(nodeB);
        }
        function hasSameLoc(nodeA, nodeB) {
          return hasSameLocStart(nodeA, nodeB) && hasSameLocEnd(nodeA, nodeB);
        }
        module22.exports = {
          locStart,
          locEnd,
          hasSameLocStart,
          hasSameLoc
        };
      }
    });
    var require_load_parser = __commonJS22({
      "src/main/load-parser.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var {
          ConfigError
        } = require_errors2();
        var {
          locStart,
          locEnd
        } = require_loc();
        function requireParser(parser) {
          try {
            return {
              parse: require(path2.resolve(process.cwd(), parser)),
              astFormat: "estree",
              locStart,
              locEnd
            };
          } catch {
            throw new ConfigError(`Couldn't resolve parser "${parser}"`);
          }
        }
        module22.exports = requireParser;
      }
    });
    var require_js_tokens2 = __commonJS22({
      "node_modules/js-tokens/index.js"(exports2) {
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.default = /((['"])(?:(?!\2|\\).|\\(?:\r\n|[\s\S]))*(\2)?|`(?:[^`\\$]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{[^}]*\}?)*\}?)*(`)?)|(\/\/.*)|(\/\*(?:[^*]|\*(?!\/))*(\*\/)?)|(\/(?!\*)(?:\[(?:(?![\]\\]).|\\.)*\]|(?![\/\]\\]).|\\.)+\/(?:(?!\s*(?:\b|[\u0080-\uFFFF$\\'"~({]|[+\-!](?!=)|\.?\d))|[gmiyus]{1,6}\b(?![\u0080-\uFFFF$\\]|\s*(?:[+\-*%&|^<>!=?({]|\/(?![\/*])))))|(0[xX][\da-fA-F]+|0[oO][0-7]+|0[bB][01]+|(?:\d*\.\d+|\d+\.?)(?:[eE][+-]?\d+)?)|((?!\d)(?:(?!\s)[$\w\u0080-\uFFFF]|\\u[\da-fA-F]{4}|\\u\{[\da-fA-F]+\})+)|(--|\+\+|&&|\|\||=>|\.{3}|(?:[+\-\/%&|^]|\*{1,2}|<{1,2}|>{1,3}|!=?|={1,2})=?|[?~.,:;[\](){}])|(\s+)|(^$|[\s\S])/g;
        exports2.matchToToken = function(match) {
          var token = {
            type: "invalid",
            value: match[0],
            closed: void 0
          };
          if (match[1])
            token.type = "string", token.closed = !!(match[3] || match[4]);
          else if (match[5])
            token.type = "comment";
          else if (match[6])
            token.type = "comment", token.closed = !!match[7];
          else if (match[8])
            token.type = "regex";
          else if (match[9])
            token.type = "number";
          else if (match[10])
            token.type = "name";
          else if (match[11])
            token.type = "punctuator";
          else if (match[12])
            token.type = "whitespace";
          return token;
        };
      }
    });
    var require_identifier3 = __commonJS22({
      "node_modules/@babel/helper-validator-identifier/lib/identifier.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isIdentifierChar = isIdentifierChar;
        exports2.isIdentifierName = isIdentifierName;
        exports2.isIdentifierStart = isIdentifierStart;
        var nonASCIIidentifierStartChars = "\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BF\u31F0-\u31FF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC";
        var nonASCIIidentifierChars = "\u200C\u200D\xB7\u0300-\u036F\u0387\u0483-\u0487\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u0669\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u06F0-\u06F9\u0711\u0730-\u074A\u07A6-\u07B0\u07C0-\u07C9\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u0898-\u089F\u08CA-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0966-\u096F\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09E6-\u09EF\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A66-\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AE6-\u0AEF\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B55-\u0B57\u0B62\u0B63\u0B66-\u0B6F\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0BE6-\u0BEF\u0C00-\u0C04\u0C3C\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0CE6-\u0CEF\u0CF3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D66-\u0D6F\u0D81-\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0E50-\u0E59\u0EB1\u0EB4-\u0EBC\u0EC8-\u0ECE\u0ED0-\u0ED9\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1040-\u1049\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F-\u109D\u135D-\u135F\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u17E0-\u17E9\u180B-\u180D\u180F-\u1819\u18A9\u1920-\u192B\u1930-\u193B\u1946-\u194F\u19D0-\u19DA\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AB0-\u1ABD\u1ABF-\u1ACE\u1B00-\u1B04\u1B34-\u1B44\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BB0-\u1BB9\u1BE6-\u1BF3\u1C24-\u1C37\u1C40-\u1C49\u1C50-\u1C59\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DFF\u203F\u2040\u2054\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA620-\uA629\uA66F\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA82C\uA880\uA881\uA8B4-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F1\uA8FF-\uA909\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9D0-\uA9D9\uA9E5\uA9F0-\uA9F9\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA50-\uAA59\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uABF0-\uABF9\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFF10-\uFF19\uFF3F";
        var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
        var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
        nonASCIIidentifierStartChars = nonASCIIidentifierChars = null;
        var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 3104, 541, 1507, 4938, 6, 4191];
        var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
        function isInAstralSet(code, set) {
          let pos = 65536;
          for (let i = 0, length = set.length; i < length; i += 2) {
            pos += set[i];
            if (pos > code)
              return false;
            pos += set[i + 1];
            if (pos >= code)
              return true;
          }
          return false;
        }
        function isIdentifierStart(code) {
          if (code < 65)
            return code === 36;
          if (code <= 90)
            return true;
          if (code < 97)
            return code === 95;
          if (code <= 122)
            return true;
          if (code <= 65535) {
            return code >= 170 && nonASCIIidentifierStart.test(String.fromCharCode(code));
          }
          return isInAstralSet(code, astralIdentifierStartCodes);
        }
        function isIdentifierChar(code) {
          if (code < 48)
            return code === 36;
          if (code < 58)
            return true;
          if (code < 65)
            return false;
          if (code <= 90)
            return true;
          if (code < 97)
            return code === 95;
          if (code <= 122)
            return true;
          if (code <= 65535) {
            return code >= 170 && nonASCIIidentifier.test(String.fromCharCode(code));
          }
          return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
        }
        function isIdentifierName(name) {
          let isFirst = true;
          for (let i = 0; i < name.length; i++) {
            let cp = name.charCodeAt(i);
            if ((cp & 64512) === 55296 && i + 1 < name.length) {
              const trail = name.charCodeAt(++i);
              if ((trail & 64512) === 56320) {
                cp = 65536 + ((cp & 1023) << 10) + (trail & 1023);
              }
            }
            if (isFirst) {
              isFirst = false;
              if (!isIdentifierStart(cp)) {
                return false;
              }
            } else if (!isIdentifierChar(cp)) {
              return false;
            }
          }
          return !isFirst;
        }
      }
    });
    var require_keyword5 = __commonJS22({
      "node_modules/@babel/helper-validator-identifier/lib/keyword.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isKeyword = isKeyword;
        exports2.isReservedWord = isReservedWord;
        exports2.isStrictBindOnlyReservedWord = isStrictBindOnlyReservedWord;
        exports2.isStrictBindReservedWord = isStrictBindReservedWord;
        exports2.isStrictReservedWord = isStrictReservedWord;
        var reservedWords = {
          keyword: ["break", "case", "catch", "continue", "debugger", "default", "do", "else", "finally", "for", "function", "if", "return", "switch", "throw", "try", "var", "const", "while", "with", "new", "this", "super", "class", "extends", "export", "import", "null", "true", "false", "in", "instanceof", "typeof", "void", "delete"],
          strict: ["implements", "interface", "let", "package", "private", "protected", "public", "static", "yield"],
          strictBind: ["eval", "arguments"]
        };
        var keywords = new Set(reservedWords.keyword);
        var reservedWordsStrictSet = new Set(reservedWords.strict);
        var reservedWordsStrictBindSet = new Set(reservedWords.strictBind);
        function isReservedWord(word, inModule) {
          return inModule && word === "await" || word === "enum";
        }
        function isStrictReservedWord(word, inModule) {
          return isReservedWord(word, inModule) || reservedWordsStrictSet.has(word);
        }
        function isStrictBindOnlyReservedWord(word) {
          return reservedWordsStrictBindSet.has(word);
        }
        function isStrictBindReservedWord(word, inModule) {
          return isStrictReservedWord(word, inModule) || isStrictBindOnlyReservedWord(word);
        }
        function isKeyword(word) {
          return keywords.has(word);
        }
      }
    });
    var require_lib34 = __commonJS22({
      "node_modules/@babel/helper-validator-identifier/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        Object.defineProperty(exports2, "isIdentifierChar", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierChar;
          }
        });
        Object.defineProperty(exports2, "isIdentifierName", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierName;
          }
        });
        Object.defineProperty(exports2, "isIdentifierStart", {
          enumerable: true,
          get: function() {
            return _identifier.isIdentifierStart;
          }
        });
        Object.defineProperty(exports2, "isKeyword", {
          enumerable: true,
          get: function() {
            return _keyword.isKeyword;
          }
        });
        Object.defineProperty(exports2, "isReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictBindOnlyReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictBindOnlyReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictBindReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictBindReservedWord;
          }
        });
        Object.defineProperty(exports2, "isStrictReservedWord", {
          enumerable: true,
          get: function() {
            return _keyword.isStrictReservedWord;
          }
        });
        var _identifier = require_identifier3();
        var _keyword = require_keyword5();
      }
    });
    var require_escape_string_regexp22 = __commonJS22({
      "node_modules/@babel/highlight/node_modules/escape-string-regexp/index.js"(exports2, module22) {
        "use strict";
        var matchOperatorsRe = /[|\\{}()[\]^$+*?.]/g;
        module22.exports = function(str) {
          if (typeof str !== "string") {
            throw new TypeError("Expected a string");
          }
          return str.replace(matchOperatorsRe, "\\$&");
        };
      }
    });
    var require_has_flag22 = __commonJS22({
      "node_modules/@babel/highlight/node_modules/has-flag/index.js"(exports2, module22) {
        "use strict";
        module22.exports = (flag, argv) => {
          argv = argv || process.argv;
          const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
          const pos = argv.indexOf(prefix + flag);
          const terminatorPos = argv.indexOf("--");
          return pos !== -1 && (terminatorPos === -1 ? true : pos < terminatorPos);
        };
      }
    });
    var require_supports_color22 = __commonJS22({
      "node_modules/@babel/highlight/node_modules/supports-color/index.js"(exports2, module22) {
        "use strict";
        var os = require("os");
        var hasFlag = require_has_flag22();
        var env = process.env;
        var forceColor;
        if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false")) {
          forceColor = false;
        } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
          forceColor = true;
        }
        if ("FORCE_COLOR" in env) {
          forceColor = env.FORCE_COLOR.length === 0 || parseInt(env.FORCE_COLOR, 10) !== 0;
        }
        function translateLevel(level) {
          if (level === 0) {
            return false;
          }
          return {
            level,
            hasBasic: true,
            has256: level >= 2,
            has16m: level >= 3
          };
        }
        function supportsColor(stream) {
          if (forceColor === false) {
            return 0;
          }
          if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
            return 3;
          }
          if (hasFlag("color=256")) {
            return 2;
          }
          if (stream && !stream.isTTY && forceColor !== true) {
            return 0;
          }
          const min2 = forceColor ? 1 : 0;
          if (process.platform === "win32") {
            const osRelease = os.release().split(".");
            if (Number(process.versions.node.split(".")[0]) >= 8 && Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
              return Number(osRelease[2]) >= 14931 ? 3 : 2;
            }
            return 1;
          }
          if ("CI" in env) {
            if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
              return 1;
            }
            return min2;
          }
          if ("TEAMCITY_VERSION" in env) {
            return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
          }
          if (env.COLORTERM === "truecolor") {
            return 3;
          }
          if ("TERM_PROGRAM" in env) {
            const version22 = parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
            switch (env.TERM_PROGRAM) {
              case "iTerm.app":
                return version22 >= 3 ? 3 : 2;
              case "Apple_Terminal":
                return 2;
            }
          }
          if (/-256(color)?$/i.test(env.TERM)) {
            return 2;
          }
          if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
            return 1;
          }
          if ("COLORTERM" in env) {
            return 1;
          }
          if (env.TERM === "dumb") {
            return min2;
          }
          return min2;
        }
        function getSupportLevel(stream) {
          const level = supportsColor(stream);
          return translateLevel(level);
        }
        module22.exports = {
          supportsColor: getSupportLevel,
          stdout: getSupportLevel(process.stdout),
          stderr: getSupportLevel(process.stderr)
        };
      }
    });
    var require_templates22 = __commonJS22({
      "node_modules/@babel/highlight/node_modules/chalk/templates.js"(exports2, module22) {
        "use strict";
        var TEMPLATE_REGEX = /(?:\\(u[a-f\d]{4}|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
        var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
        var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
        var ESCAPE_REGEX = /\\(u[a-f\d]{4}|x[a-f\d]{2}|.)|([^\\])/gi;
        var ESCAPES = /* @__PURE__ */ new Map([["n", "\n"], ["r", "\r"], ["t", "	"], ["b", "\b"], ["f", "\f"], ["v", "\v"], ["0", "\0"], ["\\", "\\"], ["e", "\x1B"], ["a", "\x07"]]);
        function unescape2(c) {
          if (c[0] === "u" && c.length === 5 || c[0] === "x" && c.length === 3) {
            return String.fromCharCode(parseInt(c.slice(1), 16));
          }
          return ESCAPES.get(c) || c;
        }
        function parseArguments(name, args) {
          const results = [];
          const chunks = args.trim().split(/\s*,\s*/g);
          let matches;
          for (const chunk of chunks) {
            if (!isNaN(chunk)) {
              results.push(Number(chunk));
            } else if (matches = chunk.match(STRING_REGEX)) {
              results.push(matches[2].replace(ESCAPE_REGEX, (m, escape2, chr) => escape2 ? unescape2(escape2) : chr));
            } else {
              throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
            }
          }
          return results;
        }
        function parseStyle(style) {
          STYLE_REGEX.lastIndex = 0;
          const results = [];
          let matches;
          while ((matches = STYLE_REGEX.exec(style)) !== null) {
            const name = matches[1];
            if (matches[2]) {
              const args = parseArguments(name, matches[2]);
              results.push([name].concat(args));
            } else {
              results.push([name]);
            }
          }
          return results;
        }
        function buildStyle(chalk3, styles) {
          const enabled = {};
          for (const layer of styles) {
            for (const style of layer.styles) {
              enabled[style[0]] = layer.inverse ? null : style.slice(1);
            }
          }
          let current = chalk3;
          for (const styleName of Object.keys(enabled)) {
            if (Array.isArray(enabled[styleName])) {
              if (!(styleName in current)) {
                throw new Error(`Unknown Chalk style: ${styleName}`);
              }
              if (enabled[styleName].length > 0) {
                current = current[styleName].apply(current, enabled[styleName]);
              } else {
                current = current[styleName];
              }
            }
          }
          return current;
        }
        module22.exports = (chalk3, tmp) => {
          const styles = [];
          const chunks = [];
          let chunk = [];
          tmp.replace(TEMPLATE_REGEX, (m, escapeChar, inverse, style, close, chr) => {
            if (escapeChar) {
              chunk.push(unescape2(escapeChar));
            } else if (style) {
              const str = chunk.join("");
              chunk = [];
              chunks.push(styles.length === 0 ? str : buildStyle(chalk3, styles)(str));
              styles.push({
                inverse,
                styles: parseStyle(style)
              });
            } else if (close) {
              if (styles.length === 0) {
                throw new Error("Found extraneous } in Chalk template literal");
              }
              chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
              chunk = [];
              styles.pop();
            } else {
              chunk.push(chr);
            }
          });
          chunks.push(chunk.join(""));
          if (styles.length > 0) {
            const errMsg = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
            throw new Error(errMsg);
          }
          return chunks.join("");
        };
      }
    });
    var require_chalk22 = __commonJS22({
      "node_modules/@babel/highlight/node_modules/chalk/index.js"(exports2, module22) {
        "use strict";
        var escapeStringRegexp2 = require_escape_string_regexp22();
        var ansiStyles = require_ansi_styles3();
        var stdoutColor = require_supports_color22().stdout;
        var template = require_templates22();
        var isSimpleWindowsTerm = process.platform === "win32" && !(process.env.TERM || "").toLowerCase().startsWith("xterm");
        var levelMapping = ["ansi", "ansi", "ansi256", "ansi16m"];
        var skipModels = /* @__PURE__ */ new Set(["gray"]);
        var styles = /* @__PURE__ */ Object.create(null);
        function applyOptions(obj, options) {
          options = options || {};
          const scLevel = stdoutColor ? stdoutColor.level : 0;
          obj.level = options.level === void 0 ? scLevel : options.level;
          obj.enabled = "enabled" in options ? options.enabled : obj.level > 0;
        }
        function Chalk(options) {
          if (!this || !(this instanceof Chalk) || this.template) {
            const chalk3 = {};
            applyOptions(chalk3, options);
            chalk3.template = function() {
              const args = [].slice.call(arguments);
              return chalkTag.apply(null, [chalk3.template].concat(args));
            };
            Object.setPrototypeOf(chalk3, Chalk.prototype);
            Object.setPrototypeOf(chalk3.template, chalk3);
            chalk3.template.constructor = Chalk;
            return chalk3.template;
          }
          applyOptions(this, options);
        }
        if (isSimpleWindowsTerm) {
          ansiStyles.blue.open = "\x1B[94m";
        }
        for (const key of Object.keys(ansiStyles)) {
          ansiStyles[key].closeRe = new RegExp(escapeStringRegexp2(ansiStyles[key].close), "g");
          styles[key] = {
            get() {
              const codes = ansiStyles[key];
              return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, key);
            }
          };
        }
        styles.visible = {
          get() {
            return build.call(this, this._styles || [], true, "visible");
          }
        };
        ansiStyles.color.closeRe = new RegExp(escapeStringRegexp2(ansiStyles.color.close), "g");
        for (const model of Object.keys(ansiStyles.color.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          styles[model] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.color[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.color.close,
                  closeRe: ansiStyles.color.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        ansiStyles.bgColor.closeRe = new RegExp(escapeStringRegexp2(ansiStyles.bgColor.close), "g");
        for (const model of Object.keys(ansiStyles.bgColor.ansi)) {
          if (skipModels.has(model)) {
            continue;
          }
          const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
          styles[bgModel] = {
            get() {
              const level = this.level;
              return function() {
                const open = ansiStyles.bgColor[levelMapping[level]][model].apply(null, arguments);
                const codes = {
                  open,
                  close: ansiStyles.bgColor.close,
                  closeRe: ansiStyles.bgColor.closeRe
                };
                return build.call(this, this._styles ? this._styles.concat(codes) : [codes], this._empty, model);
              };
            }
          };
        }
        var proto = Object.defineProperties(() => {
        }, styles);
        function build(_styles, _empty, key) {
          const builder = function() {
            return applyStyle.apply(builder, arguments);
          };
          builder._styles = _styles;
          builder._empty = _empty;
          const self2 = this;
          Object.defineProperty(builder, "level", {
            enumerable: true,
            get() {
              return self2.level;
            },
            set(level) {
              self2.level = level;
            }
          });
          Object.defineProperty(builder, "enabled", {
            enumerable: true,
            get() {
              return self2.enabled;
            },
            set(enabled) {
              self2.enabled = enabled;
            }
          });
          builder.hasGrey = this.hasGrey || key === "gray" || key === "grey";
          builder.__proto__ = proto;
          return builder;
        }
        function applyStyle() {
          const args = arguments;
          const argsLen = args.length;
          let str = String(arguments[0]);
          if (argsLen === 0) {
            return "";
          }
          if (argsLen > 1) {
            for (let a = 1; a < argsLen; a++) {
              str += " " + args[a];
            }
          }
          if (!this.enabled || this.level <= 0 || !str) {
            return this._empty ? "" : str;
          }
          const originalDim = ansiStyles.dim.open;
          if (isSimpleWindowsTerm && this.hasGrey) {
            ansiStyles.dim.open = "";
          }
          for (const code of this._styles.slice().reverse()) {
            str = code.open + str.replace(code.closeRe, code.open) + code.close;
            str = str.replace(/\r?\n/g, `${code.close}$&${code.open}`);
          }
          ansiStyles.dim.open = originalDim;
          return str;
        }
        function chalkTag(chalk3, strings) {
          if (!Array.isArray(strings)) {
            return [].slice.call(arguments, 1).join(" ");
          }
          const args = [].slice.call(arguments, 2);
          const parts = [strings.raw[0]];
          for (let i = 1; i < strings.length; i++) {
            parts.push(String(args[i - 1]).replace(/[{}\\]/g, "\\$&"));
            parts.push(String(strings.raw[i]));
          }
          return template(chalk3, parts.join(""));
        }
        Object.defineProperties(Chalk.prototype, styles);
        module22.exports = Chalk();
        module22.exports.supportsColor = stdoutColor;
        module22.exports.default = module22.exports;
      }
    });
    var require_lib42 = __commonJS22({
      "node_modules/@babel/highlight/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.default = highlight;
        exports2.getChalk = getChalk;
        exports2.shouldHighlight = shouldHighlight;
        var _jsTokens = require_js_tokens2();
        var _helperValidatorIdentifier = require_lib34();
        var _chalk = require_chalk22();
        var sometimesKeywords = /* @__PURE__ */ new Set(["as", "async", "from", "get", "of", "set"]);
        function getDefs(chalk3) {
          return {
            keyword: chalk3.cyan,
            capitalized: chalk3.yellow,
            jsxIdentifier: chalk3.yellow,
            punctuator: chalk3.yellow,
            number: chalk3.magenta,
            string: chalk3.green,
            regex: chalk3.magenta,
            comment: chalk3.grey,
            invalid: chalk3.white.bgRed.bold
          };
        }
        var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
        var BRACKET = /^[()[\]{}]$/;
        var tokenize;
        {
          const JSX_TAG = /^[a-z][\w-]*$/i;
          const getTokenType = function(token, offset, text) {
            if (token.type === "name") {
              if ((0, _helperValidatorIdentifier.isKeyword)(token.value) || (0, _helperValidatorIdentifier.isStrictReservedWord)(token.value, true) || sometimesKeywords.has(token.value)) {
                return "keyword";
              }
              if (JSX_TAG.test(token.value) && (text[offset - 1] === "<" || text.slice(offset - 2, offset) == "</")) {
                return "jsxIdentifier";
              }
              if (token.value[0] !== token.value[0].toLowerCase()) {
                return "capitalized";
              }
            }
            if (token.type === "punctuator" && BRACKET.test(token.value)) {
              return "bracket";
            }
            if (token.type === "invalid" && (token.value === "@" || token.value === "#")) {
              return "punctuator";
            }
            return token.type;
          };
          tokenize = function* (text) {
            let match;
            while (match = _jsTokens.default.exec(text)) {
              const token = _jsTokens.matchToToken(match);
              yield {
                type: getTokenType(token, match.index, text),
                value: token.value
              };
            }
          };
        }
        function highlightTokens(defs, text) {
          let highlighted = "";
          for (const {
            type,
            value: value2
          } of tokenize(text)) {
            const colorize = defs[type];
            if (colorize) {
              highlighted += value2.split(NEWLINE).map((str) => colorize(str)).join("\n");
            } else {
              highlighted += value2;
            }
          }
          return highlighted;
        }
        function shouldHighlight(options) {
          return !!_chalk.supportsColor || options.forceColor;
        }
        function getChalk(options) {
          return options.forceColor ? new _chalk.constructor({
            enabled: true,
            level: 1
          }) : _chalk;
        }
        function highlight(code, options = {}) {
          if (code !== "" && shouldHighlight(options)) {
            const chalk3 = getChalk(options);
            const defs = getDefs(chalk3);
            return highlightTokens(defs, code);
          } else {
            return code;
          }
        }
      }
    });
    var require_lib52 = __commonJS22({
      "node_modules/@babel/code-frame/lib/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.codeFrameColumns = codeFrameColumns;
        exports2.default = _default;
        var _highlight = require_lib42();
        var deprecationWarningShown = false;
        function getDefs(chalk3) {
          return {
            gutter: chalk3.grey,
            marker: chalk3.red.bold,
            message: chalk3.red.bold
          };
        }
        var NEWLINE = /\r\n|[\n\r\u2028\u2029]/;
        function getMarkerLines(loc, source, opts) {
          const startLoc = Object.assign({
            column: 0,
            line: -1
          }, loc.start);
          const endLoc = Object.assign({}, startLoc, loc.end);
          const {
            linesAbove = 2,
            linesBelow = 3
          } = opts || {};
          const startLine = startLoc.line;
          const startColumn = startLoc.column;
          const endLine = endLoc.line;
          const endColumn = endLoc.column;
          let start = Math.max(startLine - (linesAbove + 1), 0);
          let end = Math.min(source.length, endLine + linesBelow);
          if (startLine === -1) {
            start = 0;
          }
          if (endLine === -1) {
            end = source.length;
          }
          const lineDiff = endLine - startLine;
          const markerLines = {};
          if (lineDiff) {
            for (let i = 0; i <= lineDiff; i++) {
              const lineNumber = i + startLine;
              if (!startColumn) {
                markerLines[lineNumber] = true;
              } else if (i === 0) {
                const sourceLength = source[lineNumber - 1].length;
                markerLines[lineNumber] = [startColumn, sourceLength - startColumn + 1];
              } else if (i === lineDiff) {
                markerLines[lineNumber] = [0, endColumn];
              } else {
                const sourceLength = source[lineNumber - i].length;
                markerLines[lineNumber] = [0, sourceLength];
              }
            }
          } else {
            if (startColumn === endColumn) {
              if (startColumn) {
                markerLines[startLine] = [startColumn, 0];
              } else {
                markerLines[startLine] = true;
              }
            } else {
              markerLines[startLine] = [startColumn, endColumn - startColumn];
            }
          }
          return {
            start,
            end,
            markerLines
          };
        }
        function codeFrameColumns(rawLines, loc, opts = {}) {
          const highlighted = (opts.highlightCode || opts.forceColor) && (0, _highlight.shouldHighlight)(opts);
          const chalk3 = (0, _highlight.getChalk)(opts);
          const defs = getDefs(chalk3);
          const maybeHighlight = (chalkFn, string) => {
            return highlighted ? chalkFn(string) : string;
          };
          const lines = rawLines.split(NEWLINE);
          const {
            start,
            end,
            markerLines
          } = getMarkerLines(loc, lines, opts);
          const hasColumns = loc.start && typeof loc.start.column === "number";
          const numberMaxWidth = String(end).length;
          const highlightedLines = highlighted ? (0, _highlight.default)(rawLines, opts) : rawLines;
          let frame = highlightedLines.split(NEWLINE, end).slice(start, end).map((line, index) => {
            const number = start + 1 + index;
            const paddedNumber = ` ${number}`.slice(-numberMaxWidth);
            const gutter = ` ${paddedNumber} |`;
            const hasMarker = markerLines[number];
            const lastMarkerLine = !markerLines[number + 1];
            if (hasMarker) {
              let markerLine = "";
              if (Array.isArray(hasMarker)) {
                const markerSpacing = line.slice(0, Math.max(hasMarker[0] - 1, 0)).replace(/[^\t]/g, " ");
                const numberOfMarkers = hasMarker[1] || 1;
                markerLine = ["\n ", maybeHighlight(defs.gutter, gutter.replace(/\d/g, " ")), " ", markerSpacing, maybeHighlight(defs.marker, "^").repeat(numberOfMarkers)].join("");
                if (lastMarkerLine && opts.message) {
                  markerLine += " " + maybeHighlight(defs.message, opts.message);
                }
              }
              return [maybeHighlight(defs.marker, ">"), maybeHighlight(defs.gutter, gutter), line.length > 0 ? ` ${line}` : "", markerLine].join("");
            } else {
              return ` ${maybeHighlight(defs.gutter, gutter)}${line.length > 0 ? ` ${line}` : ""}`;
            }
          }).join("\n");
          if (opts.message && !hasColumns) {
            frame = `${" ".repeat(numberMaxWidth + 1)}${opts.message}
${frame}`;
          }
          if (highlighted) {
            return chalk3.reset(frame);
          } else {
            return frame;
          }
        }
        function _default(rawLines, lineNumber, colNumber, opts = {}) {
          if (!deprecationWarningShown) {
            deprecationWarningShown = true;
            const message = "Passing lineNumber and colNumber is deprecated to @babel/code-frame. Please use `codeFrameColumns`.";
            if (process.emitWarning) {
              process.emitWarning(message, "DeprecationWarning");
            } else {
              const deprecationError = new Error(message);
              deprecationError.name = "DeprecationWarning";
              console.warn(new Error(message));
            }
          }
          colNumber = Math.max(colNumber, 0);
          const location = {
            start: {
              column: colNumber,
              line: lineNumber
            }
          };
          return codeFrameColumns(rawLines, location, opts);
        }
      }
    });
    var require_parser2 = __commonJS22({
      "src/main/parser.js"(exports2, module22) {
        "use strict";
        var {
          ConfigError
        } = require_errors2();
        var jsLoc = require_loc();
        var loadParser = require_load_parser();
        var {
          locStart,
          locEnd
        } = jsLoc;
        var ownNames = Object.getOwnPropertyNames;
        var ownDescriptor = Object.getOwnPropertyDescriptor;
        function getParsers(options) {
          const parsers = {};
          for (const plugin of options.plugins) {
            if (!plugin.parsers) {
              continue;
            }
            for (const name of ownNames(plugin.parsers)) {
              Object.defineProperty(parsers, name, ownDescriptor(plugin.parsers, name));
            }
          }
          return parsers;
        }
        function resolveParser(opts, parsers = getParsers(opts)) {
          if (typeof opts.parser === "function") {
            return {
              parse: opts.parser,
              astFormat: "estree",
              locStart,
              locEnd
            };
          }
          if (typeof opts.parser === "string") {
            if (Object.prototype.hasOwnProperty.call(parsers, opts.parser)) {
              return parsers[opts.parser];
            }
            if (false) {
              throw new ConfigError(`Couldn't resolve parser "${opts.parser}". Parsers must be explicitly added to the standalone bundle.`);
            }
            return loadParser(opts.parser);
          }
        }
        function parse3(text, opts) {
          const parsers = getParsers(opts);
          const parsersForCustomParserApi = Object.defineProperties({}, Object.fromEntries(Object.keys(parsers).map((parserName) => [parserName, {
            enumerable: true,
            get() {
              return parsers[parserName].parse;
            }
          }])));
          const parser = resolveParser(opts, parsers);
          try {
            if (parser.preprocess) {
              text = parser.preprocess(text, opts);
            }
            return {
              text,
              ast: parser.parse(text, parsersForCustomParserApi, opts)
            };
          } catch (error) {
            const {
              loc
            } = error;
            if (loc) {
              const {
                codeFrameColumns
              } = require_lib52();
              error.codeFrame = codeFrameColumns(text, loc, {
                highlightCode: true
              });
              error.message += "\n" + error.codeFrame;
              throw error;
            }
            throw error;
          }
        }
        module22.exports = {
          parse: parse3,
          resolveParser
        };
      }
    });
    var require_readlines = __commonJS22({
      "node_modules/n-readlines/readlines.js"(exports2, module22) {
        "use strict";
        var fs2 = require("fs");
        var LineByLine = class {
          constructor(file, options) {
            options = options || {};
            if (!options.readChunk)
              options.readChunk = 1024;
            if (!options.newLineCharacter) {
              options.newLineCharacter = 10;
            } else {
              options.newLineCharacter = options.newLineCharacter.charCodeAt(0);
            }
            if (typeof file === "number") {
              this.fd = file;
            } else {
              this.fd = fs2.openSync(file, "r");
            }
            this.options = options;
            this.newLineCharacter = options.newLineCharacter;
            this.reset();
          }
          _searchInBuffer(buffer, hexNeedle) {
            let found = -1;
            for (let i = 0; i <= buffer.length; i++) {
              let b_byte = buffer[i];
              if (b_byte === hexNeedle) {
                found = i;
                break;
              }
            }
            return found;
          }
          reset() {
            this.eofReached = false;
            this.linesCache = [];
            this.fdPosition = 0;
          }
          close() {
            fs2.closeSync(this.fd);
            this.fd = null;
          }
          _extractLines(buffer) {
            let line;
            const lines = [];
            let bufferPosition = 0;
            let lastNewLineBufferPosition = 0;
            while (true) {
              let bufferPositionValue = buffer[bufferPosition++];
              if (bufferPositionValue === this.newLineCharacter) {
                line = buffer.slice(lastNewLineBufferPosition, bufferPosition);
                lines.push(line);
                lastNewLineBufferPosition = bufferPosition;
              } else if (bufferPositionValue === void 0) {
                break;
              }
            }
            let leftovers = buffer.slice(lastNewLineBufferPosition, bufferPosition);
            if (leftovers.length) {
              lines.push(leftovers);
            }
            return lines;
          }
          _readChunk(lineLeftovers) {
            let totalBytesRead = 0;
            let bytesRead;
            const buffers = [];
            do {
              const readBuffer = new Buffer(this.options.readChunk);
              bytesRead = fs2.readSync(this.fd, readBuffer, 0, this.options.readChunk, this.fdPosition);
              totalBytesRead = totalBytesRead + bytesRead;
              this.fdPosition = this.fdPosition + bytesRead;
              buffers.push(readBuffer);
            } while (bytesRead && this._searchInBuffer(buffers[buffers.length - 1], this.options.newLineCharacter) === -1);
            let bufferData = Buffer.concat(buffers);
            if (bytesRead < this.options.readChunk) {
              this.eofReached = true;
              bufferData = bufferData.slice(0, totalBytesRead);
            }
            if (totalBytesRead) {
              this.linesCache = this._extractLines(bufferData);
              if (lineLeftovers) {
                this.linesCache[0] = Buffer.concat([lineLeftovers, this.linesCache[0]]);
              }
            }
            return totalBytesRead;
          }
          next() {
            if (!this.fd)
              return false;
            let line = false;
            if (this.eofReached && this.linesCache.length === 0) {
              return line;
            }
            let bytesRead;
            if (!this.linesCache.length) {
              bytesRead = this._readChunk();
            }
            if (this.linesCache.length) {
              line = this.linesCache.shift();
              const lastLineCharacter = line[line.length - 1];
              if (lastLineCharacter !== this.newLineCharacter) {
                bytesRead = this._readChunk(line);
                if (bytesRead) {
                  line = this.linesCache.shift();
                }
              }
            }
            if (this.eofReached && this.linesCache.length === 0) {
              this.close();
            }
            if (line && line[line.length - 1] === this.newLineCharacter) {
              line = line.slice(0, line.length - 1);
            }
            return line;
          }
        };
        module22.exports = LineByLine;
      }
    });
    var require_get_interpreter = __commonJS22({
      "src/utils/get-interpreter.js"(exports2, module22) {
        "use strict";
        var fs2 = require("fs");
        var readlines = require_readlines();
        function getInterpreter(filepath) {
          if (typeof filepath !== "string") {
            return "";
          }
          let fd;
          try {
            fd = fs2.openSync(filepath, "r");
          } catch {
            return "";
          }
          try {
            const liner = new readlines(fd);
            const firstLine = liner.next().toString("utf8");
            const m1 = firstLine.match(/^#!\/(?:usr\/)?bin\/env\s+(\S+)/);
            if (m1) {
              return m1[1];
            }
            const m2 = firstLine.match(/^#!\/(?:usr\/(?:local\/)?)?bin\/(\S+)/);
            if (m2) {
              return m2[1];
            }
            return "";
          } catch {
            return "";
          } finally {
            try {
              fs2.closeSync(fd);
            } catch {
            }
          }
        }
        module22.exports = getInterpreter;
      }
    });
    var require_options4 = __commonJS22({
      "src/main/options.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var {
          UndefinedParserError
        } = require_errors2();
        var {
          getSupportInfo: getSupportInfo2
        } = require_support();
        var normalizer = require_options_normalizer();
        var {
          resolveParser
        } = require_parser2();
        var hiddenDefaults = {
          astFormat: "estree",
          printer: {},
          originalText: void 0,
          locStart: null,
          locEnd: null
        };
        function normalize(options, opts = {}) {
          const rawOptions = Object.assign({}, options);
          const supportOptions = getSupportInfo2({
            plugins: options.plugins,
            showUnreleased: true,
            showDeprecated: true
          }).options;
          const defaults = Object.assign(Object.assign({}, hiddenDefaults), Object.fromEntries(supportOptions.filter((optionInfo) => optionInfo.default !== void 0).map((option) => [option.name, option.default])));
          if (!rawOptions.parser) {
            if (!rawOptions.filepath) {
              const logger = opts.logger || console;
              logger.warn("No parser and no filepath given, using 'babel' the parser now but this will throw an error in the future. Please specify a parser or a filepath so one can be inferred.");
              rawOptions.parser = "babel";
            } else {
              rawOptions.parser = inferParser(rawOptions.filepath, rawOptions.plugins);
              if (!rawOptions.parser) {
                throw new UndefinedParserError(`No parser could be inferred for file: ${rawOptions.filepath}`);
              }
            }
          }
          const parser = resolveParser(normalizer.normalizeApiOptions(rawOptions, [supportOptions.find((x) => x.name === "parser")], {
            passThrough: true,
            logger: false
          }));
          rawOptions.astFormat = parser.astFormat;
          rawOptions.locEnd = parser.locEnd;
          rawOptions.locStart = parser.locStart;
          const plugin = getPlugin(rawOptions);
          rawOptions.printer = plugin.printers[rawOptions.astFormat];
          const pluginDefaults = Object.fromEntries(supportOptions.filter((optionInfo) => optionInfo.pluginDefaults && optionInfo.pluginDefaults[plugin.name] !== void 0).map((optionInfo) => [optionInfo.name, optionInfo.pluginDefaults[plugin.name]]));
          const mixedDefaults = Object.assign(Object.assign({}, defaults), pluginDefaults);
          for (const [k, value2] of Object.entries(mixedDefaults)) {
            if (rawOptions[k] === null || rawOptions[k] === void 0) {
              rawOptions[k] = value2;
            }
          }
          if (rawOptions.parser === "json") {
            rawOptions.trailingComma = "none";
          }
          return normalizer.normalizeApiOptions(rawOptions, supportOptions, Object.assign({
            passThrough: Object.keys(hiddenDefaults)
          }, opts));
        }
        function getPlugin(options) {
          const {
            astFormat
          } = options;
          if (!astFormat) {
            throw new Error("getPlugin() requires astFormat to be set");
          }
          const printerPlugin = options.plugins.find((plugin) => plugin.printers && plugin.printers[astFormat]);
          if (!printerPlugin) {
            throw new Error(`Couldn't find plugin for AST format "${astFormat}"`);
          }
          return printerPlugin;
        }
        function inferParser(filepath, plugins2) {
          const filename = path2.basename(filepath).toLowerCase();
          const languages = getSupportInfo2({
            plugins: plugins2
          }).languages.filter((language2) => language2.since !== null);
          let language = languages.find((language2) => language2.extensions && language2.extensions.some((extension) => filename.endsWith(extension)) || language2.filenames && language2.filenames.some((name) => name.toLowerCase() === filename));
          if (!language && !filename.includes(".")) {
            const getInterpreter = require_get_interpreter();
            const interpreter = getInterpreter(filepath);
            language = languages.find((language2) => language2.interpreters && language2.interpreters.includes(interpreter));
          }
          return language && language.parsers[0];
        }
        module22.exports = {
          normalize,
          hiddenDefaults,
          inferParser
        };
      }
    });
    var require_massage_ast = __commonJS22({
      "src/main/massage-ast.js"(exports2, module22) {
        "use strict";
        function massageAST(ast, options, parent) {
          if (Array.isArray(ast)) {
            return ast.map((e) => massageAST(e, options, parent)).filter(Boolean);
          }
          if (!ast || typeof ast !== "object") {
            return ast;
          }
          const cleanFunction = options.printer.massageAstNode;
          let ignoredProperties;
          if (cleanFunction && cleanFunction.ignoredProperties) {
            ignoredProperties = cleanFunction.ignoredProperties;
          } else {
            ignoredProperties = /* @__PURE__ */ new Set();
          }
          const newObj = {};
          for (const [key, value2] of Object.entries(ast)) {
            if (!ignoredProperties.has(key) && typeof value2 !== "function") {
              newObj[key] = massageAST(value2, options, ast);
            }
          }
          if (cleanFunction) {
            const result = cleanFunction(ast, newObj, parent);
            if (result === null) {
              return;
            }
            if (result) {
              return result;
            }
          }
          return newObj;
        }
        module22.exports = massageAST;
      }
    });
    var require_comments2 = __commonJS22({
      "src/main/comments.js"(exports2, module22) {
        "use strict";
        var assert = require("assert");
        var {
          builders: {
            line,
            hardline,
            breakParent,
            indent,
            lineSuffix,
            join,
            cursor
          }
        } = require_doc();
        var {
          hasNewline,
          skipNewline,
          skipSpaces,
          isPreviousLineEmpty,
          addLeadingComment,
          addDanglingComment,
          addTrailingComment
        } = require_util6();
        var childNodesCache = /* @__PURE__ */ new WeakMap();
        function getSortedChildNodes(node, options, resultArray) {
          if (!node) {
            return;
          }
          const {
            printer,
            locStart,
            locEnd
          } = options;
          if (resultArray) {
            if (printer.canAttachComment && printer.canAttachComment(node)) {
              let i;
              for (i = resultArray.length - 1; i >= 0; --i) {
                if (locStart(resultArray[i]) <= locStart(node) && locEnd(resultArray[i]) <= locEnd(node)) {
                  break;
                }
              }
              resultArray.splice(i + 1, 0, node);
              return;
            }
          } else if (childNodesCache.has(node)) {
            return childNodesCache.get(node);
          }
          const childNodes = printer.getCommentChildNodes && printer.getCommentChildNodes(node, options) || typeof node === "object" && Object.entries(node).filter(([key]) => key !== "enclosingNode" && key !== "precedingNode" && key !== "followingNode" && key !== "tokens" && key !== "comments" && key !== "parent").map(([, value2]) => value2);
          if (!childNodes) {
            return;
          }
          if (!resultArray) {
            resultArray = [];
            childNodesCache.set(node, resultArray);
          }
          for (const childNode of childNodes) {
            getSortedChildNodes(childNode, options, resultArray);
          }
          return resultArray;
        }
        function decorateComment(node, comment, options, enclosingNode) {
          const {
            locStart,
            locEnd
          } = options;
          const commentStart = locStart(comment);
          const commentEnd = locEnd(comment);
          const childNodes = getSortedChildNodes(node, options);
          let precedingNode;
          let followingNode;
          let left = 0;
          let right = childNodes.length;
          while (left < right) {
            const middle = left + right >> 1;
            const child = childNodes[middle];
            const start = locStart(child);
            const end = locEnd(child);
            if (start <= commentStart && commentEnd <= end) {
              return decorateComment(child, comment, options, child);
            }
            if (end <= commentStart) {
              precedingNode = child;
              left = middle + 1;
              continue;
            }
            if (commentEnd <= start) {
              followingNode = child;
              right = middle;
              continue;
            }
            throw new Error("Comment location overlaps with node location");
          }
          if (enclosingNode && enclosingNode.type === "TemplateLiteral") {
            const {
              quasis
            } = enclosingNode;
            const commentIndex = findExpressionIndexForComment(quasis, comment, options);
            if (precedingNode && findExpressionIndexForComment(quasis, precedingNode, options) !== commentIndex) {
              precedingNode = null;
            }
            if (followingNode && findExpressionIndexForComment(quasis, followingNode, options) !== commentIndex) {
              followingNode = null;
            }
          }
          return {
            enclosingNode,
            precedingNode,
            followingNode
          };
        }
        var returnFalse = () => false;
        function attach(comments, ast, text, options) {
          if (!Array.isArray(comments)) {
            return;
          }
          const tiesToBreak = [];
          const {
            locStart,
            locEnd,
            printer: {
              handleComments = {}
            }
          } = options;
          const {
            avoidAstMutation,
            ownLine: handleOwnLineComment = returnFalse,
            endOfLine: handleEndOfLineComment = returnFalse,
            remaining: handleRemainingComment = returnFalse
          } = handleComments;
          const decoratedComments = comments.map((comment, index) => Object.assign(Object.assign({}, decorateComment(ast, comment, options)), {}, {
            comment,
            text,
            options,
            ast,
            isLastComment: comments.length - 1 === index
          }));
          for (const [index, context] of decoratedComments.entries()) {
            const {
              comment,
              precedingNode,
              enclosingNode,
              followingNode,
              text: text2,
              options: options2,
              ast: ast2,
              isLastComment
            } = context;
            if (options2.parser === "json" || options2.parser === "json5" || options2.parser === "__js_expression" || options2.parser === "__vue_expression" || options2.parser === "__vue_ts_expression") {
              if (locStart(comment) - locStart(ast2) <= 0) {
                addLeadingComment(ast2, comment);
                continue;
              }
              if (locEnd(comment) - locEnd(ast2) >= 0) {
                addTrailingComment(ast2, comment);
                continue;
              }
            }
            let args;
            if (avoidAstMutation) {
              args = [context];
            } else {
              comment.enclosingNode = enclosingNode;
              comment.precedingNode = precedingNode;
              comment.followingNode = followingNode;
              args = [comment, text2, options2, ast2, isLastComment];
            }
            if (isOwnLineComment(text2, options2, decoratedComments, index)) {
              comment.placement = "ownLine";
              if (handleOwnLineComment(...args)) {
              } else if (followingNode) {
                addLeadingComment(followingNode, comment);
              } else if (precedingNode) {
                addTrailingComment(precedingNode, comment);
              } else if (enclosingNode) {
                addDanglingComment(enclosingNode, comment);
              } else {
                addDanglingComment(ast2, comment);
              }
            } else if (isEndOfLineComment(text2, options2, decoratedComments, index)) {
              comment.placement = "endOfLine";
              if (handleEndOfLineComment(...args)) {
              } else if (precedingNode) {
                addTrailingComment(precedingNode, comment);
              } else if (followingNode) {
                addLeadingComment(followingNode, comment);
              } else if (enclosingNode) {
                addDanglingComment(enclosingNode, comment);
              } else {
                addDanglingComment(ast2, comment);
              }
            } else {
              comment.placement = "remaining";
              if (handleRemainingComment(...args)) {
              } else if (precedingNode && followingNode) {
                const tieCount = tiesToBreak.length;
                if (tieCount > 0) {
                  const lastTie = tiesToBreak[tieCount - 1];
                  if (lastTie.followingNode !== followingNode) {
                    breakTies(tiesToBreak, text2, options2);
                  }
                }
                tiesToBreak.push(context);
              } else if (precedingNode) {
                addTrailingComment(precedingNode, comment);
              } else if (followingNode) {
                addLeadingComment(followingNode, comment);
              } else if (enclosingNode) {
                addDanglingComment(enclosingNode, comment);
              } else {
                addDanglingComment(ast2, comment);
              }
            }
          }
          breakTies(tiesToBreak, text, options);
          if (!avoidAstMutation) {
            for (const comment of comments) {
              delete comment.precedingNode;
              delete comment.enclosingNode;
              delete comment.followingNode;
            }
          }
        }
        var isAllEmptyAndNoLineBreak = (text) => !/[\S\n\u2028\u2029]/.test(text);
        function isOwnLineComment(text, options, decoratedComments, commentIndex) {
          const {
            comment,
            precedingNode
          } = decoratedComments[commentIndex];
          const {
            locStart,
            locEnd
          } = options;
          let start = locStart(comment);
          if (precedingNode) {
            for (let index = commentIndex - 1; index >= 0; index--) {
              const {
                comment: comment2,
                precedingNode: currentCommentPrecedingNode
              } = decoratedComments[index];
              if (currentCommentPrecedingNode !== precedingNode || !isAllEmptyAndNoLineBreak(text.slice(locEnd(comment2), start))) {
                break;
              }
              start = locStart(comment2);
            }
          }
          return hasNewline(text, start, {
            backwards: true
          });
        }
        function isEndOfLineComment(text, options, decoratedComments, commentIndex) {
          const {
            comment,
            followingNode
          } = decoratedComments[commentIndex];
          const {
            locStart,
            locEnd
          } = options;
          let end = locEnd(comment);
          if (followingNode) {
            for (let index = commentIndex + 1; index < decoratedComments.length; index++) {
              const {
                comment: comment2,
                followingNode: currentCommentFollowingNode
              } = decoratedComments[index];
              if (currentCommentFollowingNode !== followingNode || !isAllEmptyAndNoLineBreak(text.slice(end, locStart(comment2)))) {
                break;
              }
              end = locEnd(comment2);
            }
          }
          return hasNewline(text, end);
        }
        function breakTies(tiesToBreak, text, options) {
          const tieCount = tiesToBreak.length;
          if (tieCount === 0) {
            return;
          }
          const {
            precedingNode,
            followingNode,
            enclosingNode
          } = tiesToBreak[0];
          const gapRegExp = options.printer.getGapRegex && options.printer.getGapRegex(enclosingNode) || /^[\s(]*$/;
          let gapEndPos = options.locStart(followingNode);
          let indexOfFirstLeadingComment;
          for (indexOfFirstLeadingComment = tieCount; indexOfFirstLeadingComment > 0; --indexOfFirstLeadingComment) {
            const {
              comment,
              precedingNode: currentCommentPrecedingNode,
              followingNode: currentCommentFollowingNode
            } = tiesToBreak[indexOfFirstLeadingComment - 1];
            assert.strictEqual(currentCommentPrecedingNode, precedingNode);
            assert.strictEqual(currentCommentFollowingNode, followingNode);
            const gap = text.slice(options.locEnd(comment), gapEndPos);
            if (gapRegExp.test(gap)) {
              gapEndPos = options.locStart(comment);
            } else {
              break;
            }
          }
          for (const [i, {
            comment
          }] of tiesToBreak.entries()) {
            if (i < indexOfFirstLeadingComment) {
              addTrailingComment(precedingNode, comment);
            } else {
              addLeadingComment(followingNode, comment);
            }
          }
          for (const node of [precedingNode, followingNode]) {
            if (node.comments && node.comments.length > 1) {
              node.comments.sort((a, b) => options.locStart(a) - options.locStart(b));
            }
          }
          tiesToBreak.length = 0;
        }
        function printComment(path2, options) {
          const comment = path2.getValue();
          comment.printed = true;
          return options.printer.printComment(path2, options);
        }
        function findExpressionIndexForComment(quasis, comment, options) {
          const startPos = options.locStart(comment) - 1;
          for (let i = 1; i < quasis.length; ++i) {
            if (startPos < options.locStart(quasis[i])) {
              return i - 1;
            }
          }
          return 0;
        }
        function printLeadingComment(path2, options) {
          const comment = path2.getValue();
          const parts = [printComment(path2, options)];
          const {
            printer,
            originalText,
            locStart,
            locEnd
          } = options;
          const isBlock = printer.isBlockComment && printer.isBlockComment(comment);
          if (isBlock) {
            const lineBreak = hasNewline(originalText, locEnd(comment)) ? hasNewline(originalText, locStart(comment), {
              backwards: true
            }) ? hardline : line : " ";
            parts.push(lineBreak);
          } else {
            parts.push(hardline);
          }
          const index = skipNewline(originalText, skipSpaces(originalText, locEnd(comment)));
          if (index !== false && hasNewline(originalText, index)) {
            parts.push(hardline);
          }
          return parts;
        }
        function printTrailingComment(path2, options) {
          const comment = path2.getValue();
          const printed = printComment(path2, options);
          const {
            printer,
            originalText,
            locStart
          } = options;
          const isBlock = printer.isBlockComment && printer.isBlockComment(comment);
          if (hasNewline(originalText, locStart(comment), {
            backwards: true
          })) {
            const isLineBeforeEmpty = isPreviousLineEmpty(originalText, comment, locStart);
            return lineSuffix([hardline, isLineBeforeEmpty ? hardline : "", printed]);
          }
          let parts = [" ", printed];
          if (!isBlock) {
            parts = [lineSuffix(parts), breakParent];
          }
          return parts;
        }
        function printDanglingComments(path2, options, sameIndent, filter) {
          const parts = [];
          const node = path2.getValue();
          if (!node || !node.comments) {
            return "";
          }
          path2.each(() => {
            const comment = path2.getValue();
            if (!comment.leading && !comment.trailing && (!filter || filter(comment))) {
              parts.push(printComment(path2, options));
            }
          }, "comments");
          if (parts.length === 0) {
            return "";
          }
          if (sameIndent) {
            return join(hardline, parts);
          }
          return indent([hardline, join(hardline, parts)]);
        }
        function printCommentsSeparately(path2, options, ignored) {
          const value2 = path2.getValue();
          if (!value2) {
            return {};
          }
          let comments = value2.comments || [];
          if (ignored) {
            comments = comments.filter((comment) => !ignored.has(comment));
          }
          const isCursorNode = value2 === options.cursorNode;
          if (comments.length === 0) {
            const maybeCursor = isCursorNode ? cursor : "";
            return {
              leading: maybeCursor,
              trailing: maybeCursor
            };
          }
          const leadingParts = [];
          const trailingParts = [];
          path2.each(() => {
            const comment = path2.getValue();
            if (ignored && ignored.has(comment)) {
              return;
            }
            const {
              leading,
              trailing
            } = comment;
            if (leading) {
              leadingParts.push(printLeadingComment(path2, options));
            } else if (trailing) {
              trailingParts.push(printTrailingComment(path2, options));
            }
          }, "comments");
          if (isCursorNode) {
            leadingParts.unshift(cursor);
            trailingParts.push(cursor);
          }
          return {
            leading: leadingParts,
            trailing: trailingParts
          };
        }
        function printComments(path2, doc2, options, ignored) {
          const {
            leading,
            trailing
          } = printCommentsSeparately(path2, options, ignored);
          if (!leading && !trailing) {
            return doc2;
          }
          return [leading, doc2, trailing];
        }
        function ensureAllCommentsPrinted(astComments) {
          if (!astComments) {
            return;
          }
          for (const comment of astComments) {
            if (!comment.printed) {
              throw new Error('Comment "' + comment.value.trim() + '" was not printed. Please report this error!');
            }
            delete comment.printed;
          }
        }
        module22.exports = {
          attach,
          printComments,
          printCommentsSeparately,
          printDanglingComments,
          getSortedChildNodes,
          ensureAllCommentsPrinted
        };
      }
    });
    var require_ast_path = __commonJS22({
      "src/common/ast-path.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        function getNodeHelper(path2, count) {
          const stackIndex = getNodeStackIndexHelper(path2.stack, count);
          return stackIndex === -1 ? null : path2.stack[stackIndex];
        }
        function getNodeStackIndexHelper(stack, count) {
          for (let i = stack.length - 1; i >= 0; i -= 2) {
            const value2 = stack[i];
            if (value2 && !Array.isArray(value2) && --count < 0) {
              return i;
            }
          }
          return -1;
        }
        var AstPath = class {
          constructor(value2) {
            this.stack = [value2];
          }
          getName() {
            const {
              stack
            } = this;
            const {
              length
            } = stack;
            if (length > 1) {
              return stack[length - 2];
            }
            return null;
          }
          getValue() {
            return getLast(this.stack);
          }
          getNode(count = 0) {
            return getNodeHelper(this, count);
          }
          getParentNode(count = 0) {
            return getNodeHelper(this, count + 1);
          }
          call(callback, ...names) {
            const {
              stack
            } = this;
            const {
              length
            } = stack;
            let value2 = getLast(stack);
            for (const name of names) {
              value2 = value2[name];
              stack.push(name, value2);
            }
            const result = callback(this);
            stack.length = length;
            return result;
          }
          callParent(callback, count = 0) {
            const stackIndex = getNodeStackIndexHelper(this.stack, count + 1);
            const parentValues = this.stack.splice(stackIndex + 1);
            const result = callback(this);
            this.stack.push(...parentValues);
            return result;
          }
          each(callback, ...names) {
            const {
              stack
            } = this;
            const {
              length
            } = stack;
            let value2 = getLast(stack);
            for (const name of names) {
              value2 = value2[name];
              stack.push(name, value2);
            }
            for (let i = 0; i < value2.length; ++i) {
              stack.push(i, value2[i]);
              callback(this, i, value2);
              stack.length -= 2;
            }
            stack.length = length;
          }
          map(callback, ...names) {
            const result = [];
            this.each((path2, index, value2) => {
              result[index] = callback(path2, index, value2);
            }, ...names);
            return result;
          }
          try(callback) {
            const {
              stack
            } = this;
            const stackBackup = [...stack];
            try {
              return callback();
            } finally {
              stack.length = 0;
              stack.push(...stackBackup);
            }
          }
          match(...predicates) {
            let stackPointer = this.stack.length - 1;
            let name = null;
            let node = this.stack[stackPointer--];
            for (const predicate of predicates) {
              if (node === void 0) {
                return false;
              }
              let number = null;
              if (typeof name === "number") {
                number = name;
                name = this.stack[stackPointer--];
                node = this.stack[stackPointer--];
              }
              if (predicate && !predicate(node, name, number)) {
                return false;
              }
              name = this.stack[stackPointer--];
              node = this.stack[stackPointer--];
            }
            return true;
          }
          findAncestor(predicate) {
            let stackPointer = this.stack.length - 1;
            let name = null;
            let node = this.stack[stackPointer--];
            while (node) {
              let number = null;
              if (typeof name === "number") {
                number = name;
                name = this.stack[stackPointer--];
                node = this.stack[stackPointer--];
              }
              if (name !== null && predicate(node, name, number)) {
                return node;
              }
              name = this.stack[stackPointer--];
              node = this.stack[stackPointer--];
            }
          }
        };
        module22.exports = AstPath;
      }
    });
    var require_multiparser = __commonJS22({
      "src/main/multiparser.js"(exports2, module22) {
        "use strict";
        var {
          utils: {
            stripTrailingHardline
          }
        } = require_doc();
        var {
          normalize
        } = require_options4();
        var comments = require_comments2();
        function printSubtree(path2, print, options, printAstToDoc) {
          if (options.printer.embed && options.embeddedLanguageFormatting === "auto") {
            return options.printer.embed(path2, print, (text, partialNextOptions, textToDocOptions) => textToDoc(text, partialNextOptions, options, printAstToDoc, textToDocOptions), options);
          }
        }
        function textToDoc(text, partialNextOptions, parentOptions, printAstToDoc, {
          stripTrailingHardline: shouldStripTrailingHardline = false
        } = {}) {
          const nextOptions = normalize(Object.assign(Object.assign(Object.assign({}, parentOptions), partialNextOptions), {}, {
            parentParser: parentOptions.parser,
            originalText: text
          }), {
            passThrough: true
          });
          const result = require_parser2().parse(text, nextOptions);
          const {
            ast
          } = result;
          text = result.text;
          const astComments = ast.comments;
          delete ast.comments;
          comments.attach(astComments, ast, text, nextOptions);
          nextOptions[Symbol.for("comments")] = astComments || [];
          nextOptions[Symbol.for("tokens")] = ast.tokens || [];
          const doc2 = printAstToDoc(ast, nextOptions);
          comments.ensureAllCommentsPrinted(astComments);
          if (shouldStripTrailingHardline) {
            if (typeof doc2 === "string") {
              return doc2.replace(/(?:\r?\n)*$/, "");
            }
            return stripTrailingHardline(doc2);
          }
          return doc2;
        }
        module22.exports = {
          printSubtree
        };
      }
    });
    var require_ast_to_doc = __commonJS22({
      "src/main/ast-to-doc.js"(exports2, module22) {
        "use strict";
        var AstPath = require_ast_path();
        var {
          builders: {
            hardline,
            addAlignmentToDoc
          },
          utils: {
            propagateBreaks
          }
        } = require_doc();
        var {
          printComments
        } = require_comments2();
        var multiparser = require_multiparser();
        function printAstToDoc(ast, options, alignmentSize = 0) {
          const {
            printer
          } = options;
          if (printer.preprocess) {
            ast = printer.preprocess(ast, options);
          }
          const cache = /* @__PURE__ */ new Map();
          const path2 = new AstPath(ast);
          let doc2 = mainPrint();
          if (alignmentSize > 0) {
            doc2 = addAlignmentToDoc([hardline, doc2], alignmentSize, options.tabWidth);
          }
          propagateBreaks(doc2);
          return doc2;
          function mainPrint(selector, args) {
            if (selector === void 0 || selector === path2) {
              return mainPrintInternal(args);
            }
            if (Array.isArray(selector)) {
              return path2.call(() => mainPrintInternal(args), ...selector);
            }
            return path2.call(() => mainPrintInternal(args), selector);
          }
          function mainPrintInternal(args) {
            const value2 = path2.getValue();
            const shouldCache = value2 && typeof value2 === "object" && args === void 0;
            if (shouldCache && cache.has(value2)) {
              return cache.get(value2);
            }
            const doc3 = callPluginPrintFunction(path2, options, mainPrint, args);
            if (shouldCache) {
              cache.set(value2, doc3);
            }
            return doc3;
          }
        }
        function printPrettierIgnoredNode(node, options) {
          const {
            originalText,
            [Symbol.for("comments")]: comments,
            locStart,
            locEnd
          } = options;
          const start = locStart(node);
          const end = locEnd(node);
          const printedComments = /* @__PURE__ */ new Set();
          for (const comment of comments) {
            if (locStart(comment) >= start && locEnd(comment) <= end) {
              comment.printed = true;
              printedComments.add(comment);
            }
          }
          return {
            doc: originalText.slice(start, end),
            printedComments
          };
        }
        function callPluginPrintFunction(path2, options, printPath, args) {
          const node = path2.getValue();
          const {
            printer
          } = options;
          let doc2;
          let printedComments;
          if (printer.hasPrettierIgnore && printer.hasPrettierIgnore(path2)) {
            ({
              doc: doc2,
              printedComments
            } = printPrettierIgnoredNode(node, options));
          } else {
            if (node) {
              try {
                doc2 = multiparser.printSubtree(path2, printPath, options, printAstToDoc);
              } catch (error) {
                if (process.env.PRETTIER_DEBUG) {
                  throw error;
                }
              }
            }
            if (!doc2) {
              doc2 = printer.print(path2, options, printPath, args);
            }
          }
          if (!printer.willPrintOwnComments || !printer.willPrintOwnComments(path2, options)) {
            doc2 = printComments(path2, doc2, options, printedComments);
          }
          return doc2;
        }
        module22.exports = printAstToDoc;
      }
    });
    var require_range_util = __commonJS22({
      "src/main/range-util.js"(exports2, module22) {
        "use strict";
        var assert = require("assert");
        var comments = require_comments2();
        var isJsonParser = ({
          parser
        }) => parser === "json" || parser === "json5" || parser === "json-stringify";
        function findCommonAncestor(startNodeAndParents, endNodeAndParents) {
          const startNodeAndAncestors = [startNodeAndParents.node, ...startNodeAndParents.parentNodes];
          const endNodeAndAncestors = /* @__PURE__ */ new Set([endNodeAndParents.node, ...endNodeAndParents.parentNodes]);
          return startNodeAndAncestors.find((node) => jsonSourceElements.has(node.type) && endNodeAndAncestors.has(node));
        }
        function dropRootParents(parents) {
          let lastParentIndex = parents.length - 1;
          for (; ; ) {
            const parent = parents[lastParentIndex];
            if (parent && (parent.type === "Program" || parent.type === "File")) {
              lastParentIndex--;
            } else {
              break;
            }
          }
          return parents.slice(0, lastParentIndex + 1);
        }
        function findSiblingAncestors(startNodeAndParents, endNodeAndParents, {
          locStart,
          locEnd
        }) {
          let resultStartNode = startNodeAndParents.node;
          let resultEndNode = endNodeAndParents.node;
          if (resultStartNode === resultEndNode) {
            return {
              startNode: resultStartNode,
              endNode: resultEndNode
            };
          }
          const startNodeStart = locStart(startNodeAndParents.node);
          for (const endParent of dropRootParents(endNodeAndParents.parentNodes)) {
            if (locStart(endParent) >= startNodeStart) {
              resultEndNode = endParent;
            } else {
              break;
            }
          }
          const endNodeEnd = locEnd(endNodeAndParents.node);
          for (const startParent of dropRootParents(startNodeAndParents.parentNodes)) {
            if (locEnd(startParent) <= endNodeEnd) {
              resultStartNode = startParent;
            } else {
              break;
            }
            if (resultStartNode === resultEndNode) {
              break;
            }
          }
          return {
            startNode: resultStartNode,
            endNode: resultEndNode
          };
        }
        function findNodeAtOffset(node, offset, options, predicate, parentNodes = [], type) {
          const {
            locStart,
            locEnd
          } = options;
          const start = locStart(node);
          const end = locEnd(node);
          if (offset > end || offset < start || type === "rangeEnd" && offset === start || type === "rangeStart" && offset === end) {
            return;
          }
          for (const childNode of comments.getSortedChildNodes(node, options)) {
            const childResult = findNodeAtOffset(childNode, offset, options, predicate, [node, ...parentNodes], type);
            if (childResult) {
              return childResult;
            }
          }
          if (!predicate || predicate(node, parentNodes[0])) {
            return {
              node,
              parentNodes
            };
          }
        }
        function isJsSourceElement(type, parentType) {
          return parentType !== "DeclareExportDeclaration" && type !== "TypeParameterDeclaration" && (type === "Directive" || type === "TypeAlias" || type === "TSExportAssignment" || type.startsWith("Declare") || type.startsWith("TSDeclare") || type.endsWith("Statement") || type.endsWith("Declaration"));
        }
        var jsonSourceElements = /* @__PURE__ */ new Set(["ObjectExpression", "ArrayExpression", "StringLiteral", "NumericLiteral", "BooleanLiteral", "NullLiteral", "UnaryExpression", "TemplateLiteral"]);
        var graphqlSourceElements = /* @__PURE__ */ new Set(["OperationDefinition", "FragmentDefinition", "VariableDefinition", "TypeExtensionDefinition", "ObjectTypeDefinition", "FieldDefinition", "DirectiveDefinition", "EnumTypeDefinition", "EnumValueDefinition", "InputValueDefinition", "InputObjectTypeDefinition", "SchemaDefinition", "OperationTypeDefinition", "InterfaceTypeDefinition", "UnionTypeDefinition", "ScalarTypeDefinition"]);
        function isSourceElement(opts, node, parentNode) {
          if (!node) {
            return false;
          }
          switch (opts.parser) {
            case "flow":
            case "babel":
            case "babel-flow":
            case "babel-ts":
            case "typescript":
            case "acorn":
            case "espree":
            case "meriyah":
            case "__babel_estree":
              return isJsSourceElement(node.type, parentNode && parentNode.type);
            case "json":
            case "json5":
            case "json-stringify":
              return jsonSourceElements.has(node.type);
            case "graphql":
              return graphqlSourceElements.has(node.kind);
            case "vue":
              return node.tag !== "root";
          }
          return false;
        }
        function calculateRange(text, opts, ast) {
          let {
            rangeStart: start,
            rangeEnd: end,
            locStart,
            locEnd
          } = opts;
          assert.ok(end > start);
          const firstNonWhitespaceCharacterIndex = text.slice(start, end).search(/\S/);
          const isAllWhitespace = firstNonWhitespaceCharacterIndex === -1;
          if (!isAllWhitespace) {
            start += firstNonWhitespaceCharacterIndex;
            for (; end > start; --end) {
              if (/\S/.test(text[end - 1])) {
                break;
              }
            }
          }
          const startNodeAndParents = findNodeAtOffset(ast, start, opts, (node, parentNode) => isSourceElement(opts, node, parentNode), [], "rangeStart");
          const endNodeAndParents = isAllWhitespace ? startNodeAndParents : findNodeAtOffset(ast, end, opts, (node) => isSourceElement(opts, node), [], "rangeEnd");
          if (!startNodeAndParents || !endNodeAndParents) {
            return {
              rangeStart: 0,
              rangeEnd: 0
            };
          }
          let startNode;
          let endNode;
          if (isJsonParser(opts)) {
            const commonAncestor = findCommonAncestor(startNodeAndParents, endNodeAndParents);
            startNode = commonAncestor;
            endNode = commonAncestor;
          } else {
            ({
              startNode,
              endNode
            } = findSiblingAncestors(startNodeAndParents, endNodeAndParents, opts));
          }
          return {
            rangeStart: Math.min(locStart(startNode), locStart(endNode)),
            rangeEnd: Math.max(locEnd(startNode), locEnd(endNode))
          };
        }
        module22.exports = {
          calculateRange,
          findNodeAtOffset
        };
      }
    });
    var require_core3 = __commonJS22({
      "src/main/core.js"(exports2, module22) {
        "use strict";
        var {
          diffArrays
        } = require_array();
        var {
          printer: {
            printDocToString
          },
          debug: {
            printDocToDebug
          }
        } = require_doc();
        var {
          getAlignmentSize
        } = require_util6();
        var {
          guessEndOfLine,
          convertEndOfLineToChars,
          countEndOfLineChars,
          normalizeEndOfLine
        } = require_end_of_line();
        var normalizeOptions = require_options4().normalize;
        var massageAST = require_massage_ast();
        var comments = require_comments2();
        var parser = require_parser2();
        var printAstToDoc = require_ast_to_doc();
        var rangeUtil = require_range_util();
        var BOM = "\uFEFF";
        var CURSOR = Symbol("cursor");
        function attachComments(text, ast, opts) {
          const astComments = ast.comments;
          if (astComments) {
            delete ast.comments;
            comments.attach(astComments, ast, text, opts);
          }
          opts[Symbol.for("comments")] = astComments || [];
          opts[Symbol.for("tokens")] = ast.tokens || [];
          opts.originalText = text;
          return astComments;
        }
        function coreFormat(originalText, opts, addAlignmentSize = 0) {
          if (!originalText || originalText.trim().length === 0) {
            return {
              formatted: "",
              cursorOffset: -1,
              comments: []
            };
          }
          const {
            ast,
            text
          } = parser.parse(originalText, opts);
          if (opts.cursorOffset >= 0) {
            const nodeResult = rangeUtil.findNodeAtOffset(ast, opts.cursorOffset, opts);
            if (nodeResult && nodeResult.node) {
              opts.cursorNode = nodeResult.node;
            }
          }
          const astComments = attachComments(text, ast, opts);
          const doc2 = printAstToDoc(ast, opts, addAlignmentSize);
          const result = printDocToString(doc2, opts);
          comments.ensureAllCommentsPrinted(astComments);
          if (addAlignmentSize > 0) {
            const trimmed = result.formatted.trim();
            if (result.cursorNodeStart !== void 0) {
              result.cursorNodeStart -= result.formatted.indexOf(trimmed);
            }
            result.formatted = trimmed + convertEndOfLineToChars(opts.endOfLine);
          }
          if (opts.cursorOffset >= 0) {
            let oldCursorNodeStart;
            let oldCursorNodeText;
            let cursorOffsetRelativeToOldCursorNode;
            let newCursorNodeStart;
            let newCursorNodeText;
            if (opts.cursorNode && result.cursorNodeText) {
              oldCursorNodeStart = opts.locStart(opts.cursorNode);
              oldCursorNodeText = text.slice(oldCursorNodeStart, opts.locEnd(opts.cursorNode));
              cursorOffsetRelativeToOldCursorNode = opts.cursorOffset - oldCursorNodeStart;
              newCursorNodeStart = result.cursorNodeStart;
              newCursorNodeText = result.cursorNodeText;
            } else {
              oldCursorNodeStart = 0;
              oldCursorNodeText = text;
              cursorOffsetRelativeToOldCursorNode = opts.cursorOffset;
              newCursorNodeStart = 0;
              newCursorNodeText = result.formatted;
            }
            if (oldCursorNodeText === newCursorNodeText) {
              return {
                formatted: result.formatted,
                cursorOffset: newCursorNodeStart + cursorOffsetRelativeToOldCursorNode,
                comments: astComments
              };
            }
            const oldCursorNodeCharArray = [...oldCursorNodeText];
            oldCursorNodeCharArray.splice(cursorOffsetRelativeToOldCursorNode, 0, CURSOR);
            const newCursorNodeCharArray = [...newCursorNodeText];
            const cursorNodeDiff = diffArrays(oldCursorNodeCharArray, newCursorNodeCharArray);
            let cursorOffset = newCursorNodeStart;
            for (const entry of cursorNodeDiff) {
              if (entry.removed) {
                if (entry.value.includes(CURSOR)) {
                  break;
                }
              } else {
                cursorOffset += entry.count;
              }
            }
            return {
              formatted: result.formatted,
              cursorOffset,
              comments: astComments
            };
          }
          return {
            formatted: result.formatted,
            cursorOffset: -1,
            comments: astComments
          };
        }
        function formatRange(originalText, opts) {
          const {
            ast,
            text
          } = parser.parse(originalText, opts);
          const {
            rangeStart,
            rangeEnd
          } = rangeUtil.calculateRange(text, opts, ast);
          const rangeString = text.slice(rangeStart, rangeEnd);
          const rangeStart2 = Math.min(rangeStart, text.lastIndexOf("\n", rangeStart) + 1);
          const indentString = text.slice(rangeStart2, rangeStart).match(/^\s*/)[0];
          const alignmentSize = getAlignmentSize(indentString, opts.tabWidth);
          const rangeResult = coreFormat(rangeString, Object.assign(Object.assign({}, opts), {}, {
            rangeStart: 0,
            rangeEnd: Number.POSITIVE_INFINITY,
            cursorOffset: opts.cursorOffset > rangeStart && opts.cursorOffset <= rangeEnd ? opts.cursorOffset - rangeStart : -1,
            endOfLine: "lf"
          }), alignmentSize);
          const rangeTrimmed = rangeResult.formatted.trimEnd();
          let {
            cursorOffset
          } = opts;
          if (cursorOffset > rangeEnd) {
            cursorOffset += rangeTrimmed.length - rangeString.length;
          } else if (rangeResult.cursorOffset >= 0) {
            cursorOffset = rangeResult.cursorOffset + rangeStart;
          }
          let formatted = text.slice(0, rangeStart) + rangeTrimmed + text.slice(rangeEnd);
          if (opts.endOfLine !== "lf") {
            const eol = convertEndOfLineToChars(opts.endOfLine);
            if (cursorOffset >= 0 && eol === "\r\n") {
              cursorOffset += countEndOfLineChars(formatted.slice(0, cursorOffset), "\n");
            }
            formatted = formatted.replace(/\n/g, eol);
          }
          return {
            formatted,
            cursorOffset,
            comments: rangeResult.comments
          };
        }
        function ensureIndexInText(text, index, defaultValue) {
          if (typeof index !== "number" || Number.isNaN(index) || index < 0 || index > text.length) {
            return defaultValue;
          }
          return index;
        }
        function normalizeIndexes(text, options) {
          let {
            cursorOffset,
            rangeStart,
            rangeEnd
          } = options;
          cursorOffset = ensureIndexInText(text, cursorOffset, -1);
          rangeStart = ensureIndexInText(text, rangeStart, 0);
          rangeEnd = ensureIndexInText(text, rangeEnd, text.length);
          return Object.assign(Object.assign({}, options), {}, {
            cursorOffset,
            rangeStart,
            rangeEnd
          });
        }
        function normalizeInputAndOptions(text, options) {
          let {
            cursorOffset,
            rangeStart,
            rangeEnd,
            endOfLine
          } = normalizeIndexes(text, options);
          const hasBOM = text.charAt(0) === BOM;
          if (hasBOM) {
            text = text.slice(1);
            cursorOffset--;
            rangeStart--;
            rangeEnd--;
          }
          if (endOfLine === "auto") {
            endOfLine = guessEndOfLine(text);
          }
          if (text.includes("\r")) {
            const countCrlfBefore = (index) => countEndOfLineChars(text.slice(0, Math.max(index, 0)), "\r\n");
            cursorOffset -= countCrlfBefore(cursorOffset);
            rangeStart -= countCrlfBefore(rangeStart);
            rangeEnd -= countCrlfBefore(rangeEnd);
            text = normalizeEndOfLine(text);
          }
          return {
            hasBOM,
            text,
            options: normalizeIndexes(text, Object.assign(Object.assign({}, options), {}, {
              cursorOffset,
              rangeStart,
              rangeEnd,
              endOfLine
            }))
          };
        }
        function hasPragma(text, options) {
          const selectedParser = parser.resolveParser(options);
          return !selectedParser.hasPragma || selectedParser.hasPragma(text);
        }
        function formatWithCursor2(originalText, originalOptions) {
          let {
            hasBOM,
            text,
            options
          } = normalizeInputAndOptions(originalText, normalizeOptions(originalOptions));
          if (options.rangeStart >= options.rangeEnd && text !== "" || options.requirePragma && !hasPragma(text, options)) {
            return {
              formatted: originalText,
              cursorOffset: originalOptions.cursorOffset,
              comments: []
            };
          }
          let result;
          if (options.rangeStart > 0 || options.rangeEnd < text.length) {
            result = formatRange(text, options);
          } else {
            if (!options.requirePragma && options.insertPragma && options.printer.insertPragma && !hasPragma(text, options)) {
              text = options.printer.insertPragma(text);
            }
            result = coreFormat(text, options);
          }
          if (hasBOM) {
            result.formatted = BOM + result.formatted;
            if (result.cursorOffset >= 0) {
              result.cursorOffset++;
            }
          }
          return result;
        }
        module22.exports = {
          formatWithCursor: formatWithCursor2,
          parse(originalText, originalOptions, massage) {
            const {
              text,
              options
            } = normalizeInputAndOptions(originalText, normalizeOptions(originalOptions));
            const parsed = parser.parse(text, options);
            if (massage) {
              parsed.ast = massageAST(parsed.ast, options);
            }
            return parsed;
          },
          formatAST(ast, options) {
            options = normalizeOptions(options);
            const doc2 = printAstToDoc(ast, options);
            return printDocToString(doc2, options);
          },
          formatDoc(doc2, options) {
            return formatWithCursor2(printDocToDebug(doc2), Object.assign(Object.assign({}, options), {}, {
              parser: "__js_expression"
            })).formatted;
          },
          printToDoc(originalText, options) {
            options = normalizeOptions(options);
            const {
              ast,
              text
            } = parser.parse(originalText, options);
            attachComments(text, ast, options);
            return printAstToDoc(ast, options);
          },
          printDocToString(doc2, options) {
            return printDocToString(doc2, normalizeOptions(options));
          }
        };
      }
    });
    var require_utils22 = __commonJS22({
      "node_modules/braces/lib/utils.js"(exports2) {
        "use strict";
        exports2.isInteger = (num) => {
          if (typeof num === "number") {
            return Number.isInteger(num);
          }
          if (typeof num === "string" && num.trim() !== "") {
            return Number.isInteger(Number(num));
          }
          return false;
        };
        exports2.find = (node, type) => node.nodes.find((node2) => node2.type === type);
        exports2.exceedsLimit = (min2, max2, step = 1, limit) => {
          if (limit === false)
            return false;
          if (!exports2.isInteger(min2) || !exports2.isInteger(max2))
            return false;
          return (Number(max2) - Number(min2)) / Number(step) >= limit;
        };
        exports2.escapeNode = (block, n = 0, type) => {
          let node = block.nodes[n];
          if (!node)
            return;
          if (type && node.type === type || node.type === "open" || node.type === "close") {
            if (node.escaped !== true) {
              node.value = "\\" + node.value;
              node.escaped = true;
            }
          }
        };
        exports2.encloseBrace = (node) => {
          if (node.type !== "brace")
            return false;
          if (node.commas >> 0 + node.ranges >> 0 === 0) {
            node.invalid = true;
            return true;
          }
          return false;
        };
        exports2.isInvalidBrace = (block) => {
          if (block.type !== "brace")
            return false;
          if (block.invalid === true || block.dollar)
            return true;
          if (block.commas >> 0 + block.ranges >> 0 === 0) {
            block.invalid = true;
            return true;
          }
          if (block.open !== true || block.close !== true) {
            block.invalid = true;
            return true;
          }
          return false;
        };
        exports2.isOpenOrClose = (node) => {
          if (node.type === "open" || node.type === "close") {
            return true;
          }
          return node.open === true || node.close === true;
        };
        exports2.reduce = (nodes) => nodes.reduce((acc, node) => {
          if (node.type === "text")
            acc.push(node.value);
          if (node.type === "range")
            node.type = "text";
          return acc;
        }, []);
        exports2.flatten = (...args) => {
          const result = [];
          const flat = (arr) => {
            for (let i = 0; i < arr.length; i++) {
              let ele = arr[i];
              Array.isArray(ele) ? flat(ele, result) : ele !== void 0 && result.push(ele);
            }
            return result;
          };
          flat(args);
          return result;
        };
      }
    });
    var require_stringify2 = __commonJS22({
      "node_modules/braces/lib/stringify.js"(exports2, module22) {
        "use strict";
        var utils2 = require_utils22();
        module22.exports = (ast, options = {}) => {
          let stringify = (node, parent = {}) => {
            let invalidBlock = options.escapeInvalid && utils2.isInvalidBrace(parent);
            let invalidNode = node.invalid === true && options.escapeInvalid === true;
            let output = "";
            if (node.value) {
              if ((invalidBlock || invalidNode) && utils2.isOpenOrClose(node)) {
                return "\\" + node.value;
              }
              return node.value;
            }
            if (node.value) {
              return node.value;
            }
            if (node.nodes) {
              for (let child of node.nodes) {
                output += stringify(child);
              }
            }
            return output;
          };
          return stringify(ast);
        };
      }
    });
    var require_is_number = __commonJS22({
      "node_modules/is-number/index.js"(exports2, module22) {
        "use strict";
        module22.exports = function(num) {
          if (typeof num === "number") {
            return num - num === 0;
          }
          if (typeof num === "string" && num.trim() !== "") {
            return Number.isFinite ? Number.isFinite(+num) : isFinite(+num);
          }
          return false;
        };
      }
    });
    var require_to_regex_range = __commonJS22({
      "node_modules/to-regex-range/index.js"(exports2, module22) {
        "use strict";
        var isNumber = require_is_number();
        var toRegexRange = (min2, max2, options) => {
          if (isNumber(min2) === false) {
            throw new TypeError("toRegexRange: expected the first argument to be a number");
          }
          if (max2 === void 0 || min2 === max2) {
            return String(min2);
          }
          if (isNumber(max2) === false) {
            throw new TypeError("toRegexRange: expected the second argument to be a number.");
          }
          let opts = Object.assign({
            relaxZeros: true
          }, options);
          if (typeof opts.strictZeros === "boolean") {
            opts.relaxZeros = opts.strictZeros === false;
          }
          let relax = String(opts.relaxZeros);
          let shorthand = String(opts.shorthand);
          let capture = String(opts.capture);
          let wrap = String(opts.wrap);
          let cacheKey = min2 + ":" + max2 + "=" + relax + shorthand + capture + wrap;
          if (toRegexRange.cache.hasOwnProperty(cacheKey)) {
            return toRegexRange.cache[cacheKey].result;
          }
          let a = Math.min(min2, max2);
          let b = Math.max(min2, max2);
          if (Math.abs(a - b) === 1) {
            let result = min2 + "|" + max2;
            if (opts.capture) {
              return `(${result})`;
            }
            if (opts.wrap === false) {
              return result;
            }
            return `(?:${result})`;
          }
          let isPadded = hasPadding(min2) || hasPadding(max2);
          let state = {
            min: min2,
            max: max2,
            a,
            b
          };
          let positives = [];
          let negatives = [];
          if (isPadded) {
            state.isPadded = isPadded;
            state.maxLen = String(state.max).length;
          }
          if (a < 0) {
            let newMin = b < 0 ? Math.abs(b) : 1;
            negatives = splitToPatterns(newMin, Math.abs(a), state, opts);
            a = state.a = 0;
          }
          if (b >= 0) {
            positives = splitToPatterns(a, b, state, opts);
          }
          state.negatives = negatives;
          state.positives = positives;
          state.result = collatePatterns(negatives, positives, opts);
          if (opts.capture === true) {
            state.result = `(${state.result})`;
          } else if (opts.wrap !== false && positives.length + negatives.length > 1) {
            state.result = `(?:${state.result})`;
          }
          toRegexRange.cache[cacheKey] = state;
          return state.result;
        };
        function collatePatterns(neg, pos, options) {
          let onlyNegative = filterPatterns(neg, pos, "-", false, options) || [];
          let onlyPositive = filterPatterns(pos, neg, "", false, options) || [];
          let intersected = filterPatterns(neg, pos, "-?", true, options) || [];
          let subpatterns = onlyNegative.concat(intersected).concat(onlyPositive);
          return subpatterns.join("|");
        }
        function splitToRanges(min2, max2) {
          let nines = 1;
          let zeros = 1;
          let stop = countNines(min2, nines);
          let stops = /* @__PURE__ */ new Set([max2]);
          while (min2 <= stop && stop <= max2) {
            stops.add(stop);
            nines += 1;
            stop = countNines(min2, nines);
          }
          stop = countZeros(max2 + 1, zeros) - 1;
          while (min2 < stop && stop <= max2) {
            stops.add(stop);
            zeros += 1;
            stop = countZeros(max2 + 1, zeros) - 1;
          }
          stops = [...stops];
          stops.sort(compare);
          return stops;
        }
        function rangeToPattern(start, stop, options) {
          if (start === stop) {
            return {
              pattern: start,
              count: [],
              digits: 0
            };
          }
          let zipped = zip(start, stop);
          let digits = zipped.length;
          let pattern = "";
          let count = 0;
          for (let i = 0; i < digits; i++) {
            let [startDigit, stopDigit] = zipped[i];
            if (startDigit === stopDigit) {
              pattern += startDigit;
            } else if (startDigit !== "0" || stopDigit !== "9") {
              pattern += toCharacterClass(startDigit, stopDigit, options);
            } else {
              count++;
            }
          }
          if (count) {
            pattern += options.shorthand === true ? "\\d" : "[0-9]";
          }
          return {
            pattern,
            count: [count],
            digits
          };
        }
        function splitToPatterns(min2, max2, tok, options) {
          let ranges = splitToRanges(min2, max2);
          let tokens = [];
          let start = min2;
          let prev;
          for (let i = 0; i < ranges.length; i++) {
            let max22 = ranges[i];
            let obj = rangeToPattern(String(start), String(max22), options);
            let zeros = "";
            if (!tok.isPadded && prev && prev.pattern === obj.pattern) {
              if (prev.count.length > 1) {
                prev.count.pop();
              }
              prev.count.push(obj.count[0]);
              prev.string = prev.pattern + toQuantifier(prev.count);
              start = max22 + 1;
              continue;
            }
            if (tok.isPadded) {
              zeros = padZeros(max22, tok, options);
            }
            obj.string = zeros + obj.pattern + toQuantifier(obj.count);
            tokens.push(obj);
            start = max22 + 1;
            prev = obj;
          }
          return tokens;
        }
        function filterPatterns(arr, comparison, prefix, intersection, options) {
          let result = [];
          for (let ele of arr) {
            let {
              string
            } = ele;
            if (!intersection && !contains(comparison, "string", string)) {
              result.push(prefix + string);
            }
            if (intersection && contains(comparison, "string", string)) {
              result.push(prefix + string);
            }
          }
          return result;
        }
        function zip(a, b) {
          let arr = [];
          for (let i = 0; i < a.length; i++)
            arr.push([a[i], b[i]]);
          return arr;
        }
        function compare(a, b) {
          return a > b ? 1 : b > a ? -1 : 0;
        }
        function contains(arr, key, val) {
          return arr.some((ele) => ele[key] === val);
        }
        function countNines(min2, len) {
          return Number(String(min2).slice(0, -len) + "9".repeat(len));
        }
        function countZeros(integer, zeros) {
          return integer - integer % Math.pow(10, zeros);
        }
        function toQuantifier(digits) {
          let [start = 0, stop = ""] = digits;
          if (stop || start > 1) {
            return `{${start + (stop ? "," + stop : "")}}`;
          }
          return "";
        }
        function toCharacterClass(a, b, options) {
          return `[${a}${b - a === 1 ? "" : "-"}${b}]`;
        }
        function hasPadding(str) {
          return /^-?(0+)\d/.test(str);
        }
        function padZeros(value2, tok, options) {
          if (!tok.isPadded) {
            return value2;
          }
          let diff = Math.abs(tok.maxLen - String(value2).length);
          let relax = options.relaxZeros !== false;
          switch (diff) {
            case 0:
              return "";
            case 1:
              return relax ? "0?" : "0";
            case 2:
              return relax ? "0{0,2}" : "00";
            default: {
              return relax ? `0{0,${diff}}` : `0{${diff}}`;
            }
          }
        }
        toRegexRange.cache = {};
        toRegexRange.clearCache = () => toRegexRange.cache = {};
        module22.exports = toRegexRange;
      }
    });
    var require_fill_range = __commonJS22({
      "node_modules/fill-range/index.js"(exports2, module22) {
        "use strict";
        var util = require("util");
        var toRegexRange = require_to_regex_range();
        var isObject = (val) => val !== null && typeof val === "object" && !Array.isArray(val);
        var transform = (toNumber) => {
          return (value2) => toNumber === true ? Number(value2) : String(value2);
        };
        var isValidValue = (value2) => {
          return typeof value2 === "number" || typeof value2 === "string" && value2 !== "";
        };
        var isNumber = (num) => Number.isInteger(+num);
        var zeros = (input) => {
          let value2 = `${input}`;
          let index = -1;
          if (value2[0] === "-")
            value2 = value2.slice(1);
          if (value2 === "0")
            return false;
          while (value2[++index] === "0")
            ;
          return index > 0;
        };
        var stringify = (start, end, options) => {
          if (typeof start === "string" || typeof end === "string") {
            return true;
          }
          return options.stringify === true;
        };
        var pad = (input, maxLength, toNumber) => {
          if (maxLength > 0) {
            let dash = input[0] === "-" ? "-" : "";
            if (dash)
              input = input.slice(1);
            input = dash + input.padStart(dash ? maxLength - 1 : maxLength, "0");
          }
          if (toNumber === false) {
            return String(input);
          }
          return input;
        };
        var toMaxLen = (input, maxLength) => {
          let negative = input[0] === "-" ? "-" : "";
          if (negative) {
            input = input.slice(1);
            maxLength--;
          }
          while (input.length < maxLength)
            input = "0" + input;
          return negative ? "-" + input : input;
        };
        var toSequence = (parts, options) => {
          parts.negatives.sort((a, b) => a < b ? -1 : a > b ? 1 : 0);
          parts.positives.sort((a, b) => a < b ? -1 : a > b ? 1 : 0);
          let prefix = options.capture ? "" : "?:";
          let positives = "";
          let negatives = "";
          let result;
          if (parts.positives.length) {
            positives = parts.positives.join("|");
          }
          if (parts.negatives.length) {
            negatives = `-(${prefix}${parts.negatives.join("|")})`;
          }
          if (positives && negatives) {
            result = `${positives}|${negatives}`;
          } else {
            result = positives || negatives;
          }
          if (options.wrap) {
            return `(${prefix}${result})`;
          }
          return result;
        };
        var toRange = (a, b, isNumbers, options) => {
          if (isNumbers) {
            return toRegexRange(a, b, Object.assign({
              wrap: false
            }, options));
          }
          let start = String.fromCharCode(a);
          if (a === b)
            return start;
          let stop = String.fromCharCode(b);
          return `[${start}-${stop}]`;
        };
        var toRegex = (start, end, options) => {
          if (Array.isArray(start)) {
            let wrap = options.wrap === true;
            let prefix = options.capture ? "" : "?:";
            return wrap ? `(${prefix}${start.join("|")})` : start.join("|");
          }
          return toRegexRange(start, end, options);
        };
        var rangeError = (...args) => {
          return new RangeError("Invalid range arguments: " + util.inspect(...args));
        };
        var invalidRange = (start, end, options) => {
          if (options.strictRanges === true)
            throw rangeError([start, end]);
          return [];
        };
        var invalidStep = (step, options) => {
          if (options.strictRanges === true) {
            throw new TypeError(`Expected step "${step}" to be a number`);
          }
          return [];
        };
        var fillNumbers = (start, end, step = 1, options = {}) => {
          let a = Number(start);
          let b = Number(end);
          if (!Number.isInteger(a) || !Number.isInteger(b)) {
            if (options.strictRanges === true)
              throw rangeError([start, end]);
            return [];
          }
          if (a === 0)
            a = 0;
          if (b === 0)
            b = 0;
          let descending = a > b;
          let startString = String(start);
          let endString = String(end);
          let stepString = String(step);
          step = Math.max(Math.abs(step), 1);
          let padded = zeros(startString) || zeros(endString) || zeros(stepString);
          let maxLen = padded ? Math.max(startString.length, endString.length, stepString.length) : 0;
          let toNumber = padded === false && stringify(start, end, options) === false;
          let format2 = options.transform || transform(toNumber);
          if (options.toRegex && step === 1) {
            return toRange(toMaxLen(start, maxLen), toMaxLen(end, maxLen), true, options);
          }
          let parts = {
            negatives: [],
            positives: []
          };
          let push = (num) => parts[num < 0 ? "negatives" : "positives"].push(Math.abs(num));
          let range = [];
          let index = 0;
          while (descending ? a >= b : a <= b) {
            if (options.toRegex === true && step > 1) {
              push(a);
            } else {
              range.push(pad(format2(a, index), maxLen, toNumber));
            }
            a = descending ? a - step : a + step;
            index++;
          }
          if (options.toRegex === true) {
            return step > 1 ? toSequence(parts, options) : toRegex(range, null, Object.assign({
              wrap: false
            }, options));
          }
          return range;
        };
        var fillLetters = (start, end, step = 1, options = {}) => {
          if (!isNumber(start) && start.length > 1 || !isNumber(end) && end.length > 1) {
            return invalidRange(start, end, options);
          }
          let format2 = options.transform || ((val) => String.fromCharCode(val));
          let a = `${start}`.charCodeAt(0);
          let b = `${end}`.charCodeAt(0);
          let descending = a > b;
          let min2 = Math.min(a, b);
          let max2 = Math.max(a, b);
          if (options.toRegex && step === 1) {
            return toRange(min2, max2, false, options);
          }
          let range = [];
          let index = 0;
          while (descending ? a >= b : a <= b) {
            range.push(format2(a, index));
            a = descending ? a - step : a + step;
            index++;
          }
          if (options.toRegex === true) {
            return toRegex(range, null, {
              wrap: false,
              options
            });
          }
          return range;
        };
        var fill = (start, end, step, options = {}) => {
          if (end == null && isValidValue(start)) {
            return [start];
          }
          if (!isValidValue(start) || !isValidValue(end)) {
            return invalidRange(start, end, options);
          }
          if (typeof step === "function") {
            return fill(start, end, 1, {
              transform: step
            });
          }
          if (isObject(step)) {
            return fill(start, end, 0, step);
          }
          let opts = Object.assign({}, options);
          if (opts.capture === true)
            opts.wrap = true;
          step = step || opts.step || 1;
          if (!isNumber(step)) {
            if (step != null && !isObject(step))
              return invalidStep(step, opts);
            return fill(start, end, 1, step);
          }
          if (isNumber(start) && isNumber(end)) {
            return fillNumbers(start, end, step, opts);
          }
          return fillLetters(start, end, Math.max(Math.abs(step), 1), opts);
        };
        module22.exports = fill;
      }
    });
    var require_compile2 = __commonJS22({
      "node_modules/braces/lib/compile.js"(exports2, module22) {
        "use strict";
        var fill = require_fill_range();
        var utils2 = require_utils22();
        var compile = (ast, options = {}) => {
          let walk = (node, parent = {}) => {
            let invalidBlock = utils2.isInvalidBrace(parent);
            let invalidNode = node.invalid === true && options.escapeInvalid === true;
            let invalid = invalidBlock === true || invalidNode === true;
            let prefix = options.escapeInvalid === true ? "\\" : "";
            let output = "";
            if (node.isOpen === true) {
              return prefix + node.value;
            }
            if (node.isClose === true) {
              return prefix + node.value;
            }
            if (node.type === "open") {
              return invalid ? prefix + node.value : "(";
            }
            if (node.type === "close") {
              return invalid ? prefix + node.value : ")";
            }
            if (node.type === "comma") {
              return node.prev.type === "comma" ? "" : invalid ? node.value : "|";
            }
            if (node.value) {
              return node.value;
            }
            if (node.nodes && node.ranges > 0) {
              let args = utils2.reduce(node.nodes);
              let range = fill(...args, Object.assign(Object.assign({}, options), {}, {
                wrap: false,
                toRegex: true
              }));
              if (range.length !== 0) {
                return args.length > 1 && range.length > 1 ? `(${range})` : range;
              }
            }
            if (node.nodes) {
              for (let child of node.nodes) {
                output += walk(child, node);
              }
            }
            return output;
          };
          return walk(ast);
        };
        module22.exports = compile;
      }
    });
    var require_expand3 = __commonJS22({
      "node_modules/braces/lib/expand.js"(exports2, module22) {
        "use strict";
        var fill = require_fill_range();
        var stringify = require_stringify2();
        var utils2 = require_utils22();
        var append = (queue = "", stash = "", enclose = false) => {
          let result = [];
          queue = [].concat(queue);
          stash = [].concat(stash);
          if (!stash.length)
            return queue;
          if (!queue.length) {
            return enclose ? utils2.flatten(stash).map((ele) => `{${ele}}`) : stash;
          }
          for (let item of queue) {
            if (Array.isArray(item)) {
              for (let value2 of item) {
                result.push(append(value2, stash, enclose));
              }
            } else {
              for (let ele of stash) {
                if (enclose === true && typeof ele === "string")
                  ele = `{${ele}}`;
                result.push(Array.isArray(ele) ? append(item, ele, enclose) : item + ele);
              }
            }
          }
          return utils2.flatten(result);
        };
        var expand = (ast, options = {}) => {
          let rangeLimit = options.rangeLimit === void 0 ? 1e3 : options.rangeLimit;
          let walk = (node, parent = {}) => {
            node.queue = [];
            let p = parent;
            let q = parent.queue;
            while (p.type !== "brace" && p.type !== "root" && p.parent) {
              p = p.parent;
              q = p.queue;
            }
            if (node.invalid || node.dollar) {
              q.push(append(q.pop(), stringify(node, options)));
              return;
            }
            if (node.type === "brace" && node.invalid !== true && node.nodes.length === 2) {
              q.push(append(q.pop(), ["{}"]));
              return;
            }
            if (node.nodes && node.ranges > 0) {
              let args = utils2.reduce(node.nodes);
              if (utils2.exceedsLimit(...args, options.step, rangeLimit)) {
                throw new RangeError("expanded array length exceeds range limit. Use options.rangeLimit to increase or disable the limit.");
              }
              let range = fill(...args, options);
              if (range.length === 0) {
                range = stringify(node, options);
              }
              q.push(append(q.pop(), range));
              node.nodes = [];
              return;
            }
            let enclose = utils2.encloseBrace(node);
            let queue = node.queue;
            let block = node;
            while (block.type !== "brace" && block.type !== "root" && block.parent) {
              block = block.parent;
              queue = block.queue;
            }
            for (let i = 0; i < node.nodes.length; i++) {
              let child = node.nodes[i];
              if (child.type === "comma" && node.type === "brace") {
                if (i === 1)
                  queue.push("");
                queue.push("");
                continue;
              }
              if (child.type === "close") {
                q.push(append(q.pop(), queue, enclose));
                continue;
              }
              if (child.value && child.type !== "open") {
                queue.push(append(queue.pop(), child.value));
                continue;
              }
              if (child.nodes) {
                walk(child, node);
              }
            }
            return queue;
          };
          return utils2.flatten(walk(ast));
        };
        module22.exports = expand;
      }
    });
    var require_constants22 = __commonJS22({
      "node_modules/braces/lib/constants.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          MAX_LENGTH: 1024 * 64,
          CHAR_0: "0",
          CHAR_9: "9",
          CHAR_UPPERCASE_A: "A",
          CHAR_LOWERCASE_A: "a",
          CHAR_UPPERCASE_Z: "Z",
          CHAR_LOWERCASE_Z: "z",
          CHAR_LEFT_PARENTHESES: "(",
          CHAR_RIGHT_PARENTHESES: ")",
          CHAR_ASTERISK: "*",
          CHAR_AMPERSAND: "&",
          CHAR_AT: "@",
          CHAR_BACKSLASH: "\\",
          CHAR_BACKTICK: "`",
          CHAR_CARRIAGE_RETURN: "\r",
          CHAR_CIRCUMFLEX_ACCENT: "^",
          CHAR_COLON: ":",
          CHAR_COMMA: ",",
          CHAR_DOLLAR: "$",
          CHAR_DOT: ".",
          CHAR_DOUBLE_QUOTE: '"',
          CHAR_EQUAL: "=",
          CHAR_EXCLAMATION_MARK: "!",
          CHAR_FORM_FEED: "\f",
          CHAR_FORWARD_SLASH: "/",
          CHAR_HASH: "#",
          CHAR_HYPHEN_MINUS: "-",
          CHAR_LEFT_ANGLE_BRACKET: "<",
          CHAR_LEFT_CURLY_BRACE: "{",
          CHAR_LEFT_SQUARE_BRACKET: "[",
          CHAR_LINE_FEED: "\n",
          CHAR_NO_BREAK_SPACE: "\xA0",
          CHAR_PERCENT: "%",
          CHAR_PLUS: "+",
          CHAR_QUESTION_MARK: "?",
          CHAR_RIGHT_ANGLE_BRACKET: ">",
          CHAR_RIGHT_CURLY_BRACE: "}",
          CHAR_RIGHT_SQUARE_BRACKET: "]",
          CHAR_SEMICOLON: ";",
          CHAR_SINGLE_QUOTE: "'",
          CHAR_SPACE: " ",
          CHAR_TAB: "	",
          CHAR_UNDERSCORE: "_",
          CHAR_VERTICAL_LINE: "|",
          CHAR_ZERO_WIDTH_NOBREAK_SPACE: "\uFEFF"
        };
      }
    });
    var require_parse5 = __commonJS22({
      "node_modules/braces/lib/parse.js"(exports2, module22) {
        "use strict";
        var stringify = require_stringify2();
        var {
          MAX_LENGTH,
          CHAR_BACKSLASH,
          CHAR_BACKTICK,
          CHAR_COMMA,
          CHAR_DOT,
          CHAR_LEFT_PARENTHESES,
          CHAR_RIGHT_PARENTHESES,
          CHAR_LEFT_CURLY_BRACE,
          CHAR_RIGHT_CURLY_BRACE,
          CHAR_LEFT_SQUARE_BRACKET,
          CHAR_RIGHT_SQUARE_BRACKET,
          CHAR_DOUBLE_QUOTE,
          CHAR_SINGLE_QUOTE,
          CHAR_NO_BREAK_SPACE,
          CHAR_ZERO_WIDTH_NOBREAK_SPACE
        } = require_constants22();
        var parse3 = (input, options = {}) => {
          if (typeof input !== "string") {
            throw new TypeError("Expected a string");
          }
          let opts = options || {};
          let max2 = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
          if (input.length > max2) {
            throw new SyntaxError(`Input length (${input.length}), exceeds max characters (${max2})`);
          }
          let ast = {
            type: "root",
            input,
            nodes: []
          };
          let stack = [ast];
          let block = ast;
          let prev = ast;
          let brackets = 0;
          let length = input.length;
          let index = 0;
          let depth = 0;
          let value2;
          let memo = {};
          const advance = () => input[index++];
          const push = (node) => {
            if (node.type === "text" && prev.type === "dot") {
              prev.type = "text";
            }
            if (prev && prev.type === "text" && node.type === "text") {
              prev.value += node.value;
              return;
            }
            block.nodes.push(node);
            node.parent = block;
            node.prev = prev;
            prev = node;
            return node;
          };
          push({
            type: "bos"
          });
          while (index < length) {
            block = stack[stack.length - 1];
            value2 = advance();
            if (value2 === CHAR_ZERO_WIDTH_NOBREAK_SPACE || value2 === CHAR_NO_BREAK_SPACE) {
              continue;
            }
            if (value2 === CHAR_BACKSLASH) {
              push({
                type: "text",
                value: (options.keepEscaping ? value2 : "") + advance()
              });
              continue;
            }
            if (value2 === CHAR_RIGHT_SQUARE_BRACKET) {
              push({
                type: "text",
                value: "\\" + value2
              });
              continue;
            }
            if (value2 === CHAR_LEFT_SQUARE_BRACKET) {
              brackets++;
              let closed = true;
              let next;
              while (index < length && (next = advance())) {
                value2 += next;
                if (next === CHAR_LEFT_SQUARE_BRACKET) {
                  brackets++;
                  continue;
                }
                if (next === CHAR_BACKSLASH) {
                  value2 += advance();
                  continue;
                }
                if (next === CHAR_RIGHT_SQUARE_BRACKET) {
                  brackets--;
                  if (brackets === 0) {
                    break;
                  }
                }
              }
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (value2 === CHAR_LEFT_PARENTHESES) {
              block = push({
                type: "paren",
                nodes: []
              });
              stack.push(block);
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (value2 === CHAR_RIGHT_PARENTHESES) {
              if (block.type !== "paren") {
                push({
                  type: "text",
                  value: value2
                });
                continue;
              }
              block = stack.pop();
              push({
                type: "text",
                value: value2
              });
              block = stack[stack.length - 1];
              continue;
            }
            if (value2 === CHAR_DOUBLE_QUOTE || value2 === CHAR_SINGLE_QUOTE || value2 === CHAR_BACKTICK) {
              let open = value2;
              let next;
              if (options.keepQuotes !== true) {
                value2 = "";
              }
              while (index < length && (next = advance())) {
                if (next === CHAR_BACKSLASH) {
                  value2 += next + advance();
                  continue;
                }
                if (next === open) {
                  if (options.keepQuotes === true)
                    value2 += next;
                  break;
                }
                value2 += next;
              }
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (value2 === CHAR_LEFT_CURLY_BRACE) {
              depth++;
              let dollar = prev.value && prev.value.slice(-1) === "$" || block.dollar === true;
              let brace = {
                type: "brace",
                open: true,
                close: false,
                dollar,
                depth,
                commas: 0,
                ranges: 0,
                nodes: []
              };
              block = push(brace);
              stack.push(block);
              push({
                type: "open",
                value: value2
              });
              continue;
            }
            if (value2 === CHAR_RIGHT_CURLY_BRACE) {
              if (block.type !== "brace") {
                push({
                  type: "text",
                  value: value2
                });
                continue;
              }
              let type = "close";
              block = stack.pop();
              block.close = true;
              push({
                type,
                value: value2
              });
              depth--;
              block = stack[stack.length - 1];
              continue;
            }
            if (value2 === CHAR_COMMA && depth > 0) {
              if (block.ranges > 0) {
                block.ranges = 0;
                let open = block.nodes.shift();
                block.nodes = [open, {
                  type: "text",
                  value: stringify(block)
                }];
              }
              push({
                type: "comma",
                value: value2
              });
              block.commas++;
              continue;
            }
            if (value2 === CHAR_DOT && depth > 0 && block.commas === 0) {
              let siblings = block.nodes;
              if (depth === 0 || siblings.length === 0) {
                push({
                  type: "text",
                  value: value2
                });
                continue;
              }
              if (prev.type === "dot") {
                block.range = [];
                prev.value += value2;
                prev.type = "range";
                if (block.nodes.length !== 3 && block.nodes.length !== 5) {
                  block.invalid = true;
                  block.ranges = 0;
                  prev.type = "text";
                  continue;
                }
                block.ranges++;
                block.args = [];
                continue;
              }
              if (prev.type === "range") {
                siblings.pop();
                let before = siblings[siblings.length - 1];
                before.value += prev.value + value2;
                prev = before;
                block.ranges--;
                continue;
              }
              push({
                type: "dot",
                value: value2
              });
              continue;
            }
            push({
              type: "text",
              value: value2
            });
          }
          do {
            block = stack.pop();
            if (block.type !== "root") {
              block.nodes.forEach((node) => {
                if (!node.nodes) {
                  if (node.type === "open")
                    node.isOpen = true;
                  if (node.type === "close")
                    node.isClose = true;
                  if (!node.nodes)
                    node.type = "text";
                  node.invalid = true;
                }
              });
              let parent = stack[stack.length - 1];
              let index2 = parent.nodes.indexOf(block);
              parent.nodes.splice(index2, 1, ...block.nodes);
            }
          } while (stack.length > 0);
          push({
            type: "eos"
          });
          return ast;
        };
        module22.exports = parse3;
      }
    });
    var require_braces = __commonJS22({
      "node_modules/braces/index.js"(exports2, module22) {
        "use strict";
        var stringify = require_stringify2();
        var compile = require_compile2();
        var expand = require_expand3();
        var parse3 = require_parse5();
        var braces = (input, options = {}) => {
          let output = [];
          if (Array.isArray(input)) {
            for (let pattern of input) {
              let result = braces.create(pattern, options);
              if (Array.isArray(result)) {
                output.push(...result);
              } else {
                output.push(result);
              }
            }
          } else {
            output = [].concat(braces.create(input, options));
          }
          if (options && options.expand === true && options.nodupes === true) {
            output = [...new Set(output)];
          }
          return output;
        };
        braces.parse = (input, options = {}) => parse3(input, options);
        braces.stringify = (input, options = {}) => {
          if (typeof input === "string") {
            return stringify(braces.parse(input, options), options);
          }
          return stringify(input, options);
        };
        braces.compile = (input, options = {}) => {
          if (typeof input === "string") {
            input = braces.parse(input, options);
          }
          return compile(input, options);
        };
        braces.expand = (input, options = {}) => {
          if (typeof input === "string") {
            input = braces.parse(input, options);
          }
          let result = expand(input, options);
          if (options.noempty === true) {
            result = result.filter(Boolean);
          }
          if (options.nodupes === true) {
            result = [...new Set(result)];
          }
          return result;
        };
        braces.create = (input, options = {}) => {
          if (input === "" || input.length < 3) {
            return [input];
          }
          return options.expand !== true ? braces.compile(input, options) : braces.expand(input, options);
        };
        module22.exports = braces;
      }
    });
    var require_constants32 = __commonJS22({
      "node_modules/picomatch/lib/constants.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var WIN_SLASH = "\\\\/";
        var WIN_NO_SLASH = `[^${WIN_SLASH}]`;
        var DOT_LITERAL = "\\.";
        var PLUS_LITERAL = "\\+";
        var QMARK_LITERAL = "\\?";
        var SLASH_LITERAL = "\\/";
        var ONE_CHAR = "(?=.)";
        var QMARK = "[^/]";
        var END_ANCHOR = `(?:${SLASH_LITERAL}|$)`;
        var START_ANCHOR = `(?:^|${SLASH_LITERAL})`;
        var DOTS_SLASH = `${DOT_LITERAL}{1,2}${END_ANCHOR}`;
        var NO_DOT = `(?!${DOT_LITERAL})`;
        var NO_DOTS = `(?!${START_ANCHOR}${DOTS_SLASH})`;
        var NO_DOT_SLASH = `(?!${DOT_LITERAL}{0,1}${END_ANCHOR})`;
        var NO_DOTS_SLASH = `(?!${DOTS_SLASH})`;
        var QMARK_NO_DOT = `[^.${SLASH_LITERAL}]`;
        var STAR = `${QMARK}*?`;
        var POSIX_CHARS = {
          DOT_LITERAL,
          PLUS_LITERAL,
          QMARK_LITERAL,
          SLASH_LITERAL,
          ONE_CHAR,
          QMARK,
          END_ANCHOR,
          DOTS_SLASH,
          NO_DOT,
          NO_DOTS,
          NO_DOT_SLASH,
          NO_DOTS_SLASH,
          QMARK_NO_DOT,
          STAR,
          START_ANCHOR
        };
        var WINDOWS_CHARS = Object.assign(Object.assign({}, POSIX_CHARS), {}, {
          SLASH_LITERAL: `[${WIN_SLASH}]`,
          QMARK: WIN_NO_SLASH,
          STAR: `${WIN_NO_SLASH}*?`,
          DOTS_SLASH: `${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$)`,
          NO_DOT: `(?!${DOT_LITERAL})`,
          NO_DOTS: `(?!(?:^|[${WIN_SLASH}])${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
          NO_DOT_SLASH: `(?!${DOT_LITERAL}{0,1}(?:[${WIN_SLASH}]|$))`,
          NO_DOTS_SLASH: `(?!${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
          QMARK_NO_DOT: `[^.${WIN_SLASH}]`,
          START_ANCHOR: `(?:^|[${WIN_SLASH}])`,
          END_ANCHOR: `(?:[${WIN_SLASH}]|$)`
        });
        var POSIX_REGEX_SOURCE = {
          alnum: "a-zA-Z0-9",
          alpha: "a-zA-Z",
          ascii: "\\x00-\\x7F",
          blank: " \\t",
          cntrl: "\\x00-\\x1F\\x7F",
          digit: "0-9",
          graph: "\\x21-\\x7E",
          lower: "a-z",
          print: "\\x20-\\x7E ",
          punct: "\\-!\"#$%&'()\\*+,./:;<=>?@[\\]^_`{|}~",
          space: " \\t\\r\\n\\v\\f",
          upper: "A-Z",
          word: "A-Za-z0-9_",
          xdigit: "A-Fa-f0-9"
        };
        module22.exports = {
          MAX_LENGTH: 1024 * 64,
          POSIX_REGEX_SOURCE,
          REGEX_BACKSLASH: /\\(?![*+?^${}(|)[\]])/g,
          REGEX_NON_SPECIAL_CHARS: /^[^@![\].,$*+?^{}()|\\/]+/,
          REGEX_SPECIAL_CHARS: /[-*+?.^${}(|)[\]]/,
          REGEX_SPECIAL_CHARS_BACKREF: /(\\?)((\W)(\3*))/g,
          REGEX_SPECIAL_CHARS_GLOBAL: /([-*+?.^${}(|)[\]])/g,
          REGEX_REMOVE_BACKSLASH: /(?:\[.*?[^\\]\]|\\(?=.))/g,
          REPLACEMENTS: {
            "***": "*",
            "**/**": "**",
            "**/**/**": "**"
          },
          CHAR_0: 48,
          CHAR_9: 57,
          CHAR_UPPERCASE_A: 65,
          CHAR_LOWERCASE_A: 97,
          CHAR_UPPERCASE_Z: 90,
          CHAR_LOWERCASE_Z: 122,
          CHAR_LEFT_PARENTHESES: 40,
          CHAR_RIGHT_PARENTHESES: 41,
          CHAR_ASTERISK: 42,
          CHAR_AMPERSAND: 38,
          CHAR_AT: 64,
          CHAR_BACKWARD_SLASH: 92,
          CHAR_CARRIAGE_RETURN: 13,
          CHAR_CIRCUMFLEX_ACCENT: 94,
          CHAR_COLON: 58,
          CHAR_COMMA: 44,
          CHAR_DOT: 46,
          CHAR_DOUBLE_QUOTE: 34,
          CHAR_EQUAL: 61,
          CHAR_EXCLAMATION_MARK: 33,
          CHAR_FORM_FEED: 12,
          CHAR_FORWARD_SLASH: 47,
          CHAR_GRAVE_ACCENT: 96,
          CHAR_HASH: 35,
          CHAR_HYPHEN_MINUS: 45,
          CHAR_LEFT_ANGLE_BRACKET: 60,
          CHAR_LEFT_CURLY_BRACE: 123,
          CHAR_LEFT_SQUARE_BRACKET: 91,
          CHAR_LINE_FEED: 10,
          CHAR_NO_BREAK_SPACE: 160,
          CHAR_PERCENT: 37,
          CHAR_PLUS: 43,
          CHAR_QUESTION_MARK: 63,
          CHAR_RIGHT_ANGLE_BRACKET: 62,
          CHAR_RIGHT_CURLY_BRACE: 125,
          CHAR_RIGHT_SQUARE_BRACKET: 93,
          CHAR_SEMICOLON: 59,
          CHAR_SINGLE_QUOTE: 39,
          CHAR_SPACE: 32,
          CHAR_TAB: 9,
          CHAR_UNDERSCORE: 95,
          CHAR_VERTICAL_LINE: 124,
          CHAR_ZERO_WIDTH_NOBREAK_SPACE: 65279,
          SEP: path2.sep,
          extglobChars(chars) {
            return {
              "!": {
                type: "negate",
                open: "(?:(?!(?:",
                close: `))${chars.STAR})`
              },
              "?": {
                type: "qmark",
                open: "(?:",
                close: ")?"
              },
              "+": {
                type: "plus",
                open: "(?:",
                close: ")+"
              },
              "*": {
                type: "star",
                open: "(?:",
                close: ")*"
              },
              "@": {
                type: "at",
                open: "(?:",
                close: ")"
              }
            };
          },
          globChars(win32) {
            return win32 === true ? WINDOWS_CHARS : POSIX_CHARS;
          }
        };
      }
    });
    var require_utils32 = __commonJS22({
      "node_modules/picomatch/lib/utils.js"(exports2) {
        "use strict";
        var path2 = require("path");
        var win32 = process.platform === "win32";
        var {
          REGEX_BACKSLASH,
          REGEX_REMOVE_BACKSLASH,
          REGEX_SPECIAL_CHARS,
          REGEX_SPECIAL_CHARS_GLOBAL
        } = require_constants32();
        exports2.isObject = (val) => val !== null && typeof val === "object" && !Array.isArray(val);
        exports2.hasRegexChars = (str) => REGEX_SPECIAL_CHARS.test(str);
        exports2.isRegexChar = (str) => str.length === 1 && exports2.hasRegexChars(str);
        exports2.escapeRegex = (str) => str.replace(REGEX_SPECIAL_CHARS_GLOBAL, "\\$1");
        exports2.toPosixSlashes = (str) => str.replace(REGEX_BACKSLASH, "/");
        exports2.removeBackslashes = (str) => {
          return str.replace(REGEX_REMOVE_BACKSLASH, (match) => {
            return match === "\\" ? "" : match;
          });
        };
        exports2.supportsLookbehinds = () => {
          const segs = process.version.slice(1).split(".").map(Number);
          if (segs.length === 3 && segs[0] >= 9 || segs[0] === 8 && segs[1] >= 10) {
            return true;
          }
          return false;
        };
        exports2.isWindows = (options) => {
          if (options && typeof options.windows === "boolean") {
            return options.windows;
          }
          return win32 === true || path2.sep === "\\";
        };
        exports2.escapeLast = (input, char, lastIdx) => {
          const idx = input.lastIndexOf(char, lastIdx);
          if (idx === -1)
            return input;
          if (input[idx - 1] === "\\")
            return exports2.escapeLast(input, char, idx - 1);
          return `${input.slice(0, idx)}\\${input.slice(idx)}`;
        };
        exports2.removePrefix = (input, state = {}) => {
          let output = input;
          if (output.startsWith("./")) {
            output = output.slice(2);
            state.prefix = "./";
          }
          return output;
        };
        exports2.wrapOutput = (input, state = {}, options = {}) => {
          const prepend = options.contains ? "" : "^";
          const append = options.contains ? "" : "$";
          let output = `${prepend}(?:${input})${append}`;
          if (state.negated === true) {
            output = `(?:^(?!${output}).*$)`;
          }
          return output;
        };
      }
    });
    var require_scan2 = __commonJS22({
      "node_modules/picomatch/lib/scan.js"(exports2, module22) {
        "use strict";
        var utils2 = require_utils32();
        var {
          CHAR_ASTERISK,
          CHAR_AT,
          CHAR_BACKWARD_SLASH,
          CHAR_COMMA,
          CHAR_DOT,
          CHAR_EXCLAMATION_MARK,
          CHAR_FORWARD_SLASH,
          CHAR_LEFT_CURLY_BRACE,
          CHAR_LEFT_PARENTHESES,
          CHAR_LEFT_SQUARE_BRACKET,
          CHAR_PLUS,
          CHAR_QUESTION_MARK,
          CHAR_RIGHT_CURLY_BRACE,
          CHAR_RIGHT_PARENTHESES,
          CHAR_RIGHT_SQUARE_BRACKET
        } = require_constants32();
        var isPathSeparator = (code) => {
          return code === CHAR_FORWARD_SLASH || code === CHAR_BACKWARD_SLASH;
        };
        var depth = (token) => {
          if (token.isPrefix !== true) {
            token.depth = token.isGlobstar ? Infinity : 1;
          }
        };
        var scan = (input, options) => {
          const opts = options || {};
          const length = input.length - 1;
          const scanToEnd = opts.parts === true || opts.scanToEnd === true;
          const slashes = [];
          const tokens = [];
          const parts = [];
          let str = input;
          let index = -1;
          let start = 0;
          let lastIndex = 0;
          let isBrace = false;
          let isBracket = false;
          let isGlob = false;
          let isExtglob = false;
          let isGlobstar = false;
          let braceEscaped = false;
          let backslashes = false;
          let negated = false;
          let negatedExtglob = false;
          let finished = false;
          let braces = 0;
          let prev;
          let code;
          let token = {
            value: "",
            depth: 0,
            isGlob: false
          };
          const eos = () => index >= length;
          const peek = () => str.charCodeAt(index + 1);
          const advance = () => {
            prev = code;
            return str.charCodeAt(++index);
          };
          while (index < length) {
            code = advance();
            let next;
            if (code === CHAR_BACKWARD_SLASH) {
              backslashes = token.backslashes = true;
              code = advance();
              if (code === CHAR_LEFT_CURLY_BRACE) {
                braceEscaped = true;
              }
              continue;
            }
            if (braceEscaped === true || code === CHAR_LEFT_CURLY_BRACE) {
              braces++;
              while (eos() !== true && (code = advance())) {
                if (code === CHAR_BACKWARD_SLASH) {
                  backslashes = token.backslashes = true;
                  advance();
                  continue;
                }
                if (code === CHAR_LEFT_CURLY_BRACE) {
                  braces++;
                  continue;
                }
                if (braceEscaped !== true && code === CHAR_DOT && (code = advance()) === CHAR_DOT) {
                  isBrace = token.isBrace = true;
                  isGlob = token.isGlob = true;
                  finished = true;
                  if (scanToEnd === true) {
                    continue;
                  }
                  break;
                }
                if (braceEscaped !== true && code === CHAR_COMMA) {
                  isBrace = token.isBrace = true;
                  isGlob = token.isGlob = true;
                  finished = true;
                  if (scanToEnd === true) {
                    continue;
                  }
                  break;
                }
                if (code === CHAR_RIGHT_CURLY_BRACE) {
                  braces--;
                  if (braces === 0) {
                    braceEscaped = false;
                    isBrace = token.isBrace = true;
                    finished = true;
                    break;
                  }
                }
              }
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (code === CHAR_FORWARD_SLASH) {
              slashes.push(index);
              tokens.push(token);
              token = {
                value: "",
                depth: 0,
                isGlob: false
              };
              if (finished === true)
                continue;
              if (prev === CHAR_DOT && index === start + 1) {
                start += 2;
                continue;
              }
              lastIndex = index + 1;
              continue;
            }
            if (opts.noext !== true) {
              const isExtglobChar = code === CHAR_PLUS || code === CHAR_AT || code === CHAR_ASTERISK || code === CHAR_QUESTION_MARK || code === CHAR_EXCLAMATION_MARK;
              if (isExtglobChar === true && peek() === CHAR_LEFT_PARENTHESES) {
                isGlob = token.isGlob = true;
                isExtglob = token.isExtglob = true;
                finished = true;
                if (code === CHAR_EXCLAMATION_MARK && index === start) {
                  negatedExtglob = true;
                }
                if (scanToEnd === true) {
                  while (eos() !== true && (code = advance())) {
                    if (code === CHAR_BACKWARD_SLASH) {
                      backslashes = token.backslashes = true;
                      code = advance();
                      continue;
                    }
                    if (code === CHAR_RIGHT_PARENTHESES) {
                      isGlob = token.isGlob = true;
                      finished = true;
                      break;
                    }
                  }
                  continue;
                }
                break;
              }
            }
            if (code === CHAR_ASTERISK) {
              if (prev === CHAR_ASTERISK)
                isGlobstar = token.isGlobstar = true;
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (code === CHAR_QUESTION_MARK) {
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (code === CHAR_LEFT_SQUARE_BRACKET) {
              while (eos() !== true && (next = advance())) {
                if (next === CHAR_BACKWARD_SLASH) {
                  backslashes = token.backslashes = true;
                  advance();
                  continue;
                }
                if (next === CHAR_RIGHT_SQUARE_BRACKET) {
                  isBracket = token.isBracket = true;
                  isGlob = token.isGlob = true;
                  finished = true;
                  break;
                }
              }
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (opts.nonegate !== true && code === CHAR_EXCLAMATION_MARK && index === start) {
              negated = token.negated = true;
              start++;
              continue;
            }
            if (opts.noparen !== true && code === CHAR_LEFT_PARENTHESES) {
              isGlob = token.isGlob = true;
              if (scanToEnd === true) {
                while (eos() !== true && (code = advance())) {
                  if (code === CHAR_LEFT_PARENTHESES) {
                    backslashes = token.backslashes = true;
                    code = advance();
                    continue;
                  }
                  if (code === CHAR_RIGHT_PARENTHESES) {
                    finished = true;
                    break;
                  }
                }
                continue;
              }
              break;
            }
            if (isGlob === true) {
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
          }
          if (opts.noext === true) {
            isExtglob = false;
            isGlob = false;
          }
          let base = str;
          let prefix = "";
          let glob2 = "";
          if (start > 0) {
            prefix = str.slice(0, start);
            str = str.slice(start);
            lastIndex -= start;
          }
          if (base && isGlob === true && lastIndex > 0) {
            base = str.slice(0, lastIndex);
            glob2 = str.slice(lastIndex);
          } else if (isGlob === true) {
            base = "";
            glob2 = str;
          } else {
            base = str;
          }
          if (base && base !== "" && base !== "/" && base !== str) {
            if (isPathSeparator(base.charCodeAt(base.length - 1))) {
              base = base.slice(0, -1);
            }
          }
          if (opts.unescape === true) {
            if (glob2)
              glob2 = utils2.removeBackslashes(glob2);
            if (base && backslashes === true) {
              base = utils2.removeBackslashes(base);
            }
          }
          const state = {
            prefix,
            input,
            start,
            base,
            glob: glob2,
            isBrace,
            isBracket,
            isGlob,
            isExtglob,
            isGlobstar,
            negated,
            negatedExtglob
          };
          if (opts.tokens === true) {
            state.maxDepth = 0;
            if (!isPathSeparator(code)) {
              tokens.push(token);
            }
            state.tokens = tokens;
          }
          if (opts.parts === true || opts.tokens === true) {
            let prevIndex;
            for (let idx = 0; idx < slashes.length; idx++) {
              const n = prevIndex ? prevIndex + 1 : start;
              const i = slashes[idx];
              const value2 = input.slice(n, i);
              if (opts.tokens) {
                if (idx === 0 && start !== 0) {
                  tokens[idx].isPrefix = true;
                  tokens[idx].value = prefix;
                } else {
                  tokens[idx].value = value2;
                }
                depth(tokens[idx]);
                state.maxDepth += tokens[idx].depth;
              }
              if (idx !== 0 || value2 !== "") {
                parts.push(value2);
              }
              prevIndex = i;
            }
            if (prevIndex && prevIndex + 1 < input.length) {
              const value2 = input.slice(prevIndex + 1);
              parts.push(value2);
              if (opts.tokens) {
                tokens[tokens.length - 1].value = value2;
                depth(tokens[tokens.length - 1]);
                state.maxDepth += tokens[tokens.length - 1].depth;
              }
            }
            state.slashes = slashes;
            state.parts = parts;
          }
          return state;
        };
        module22.exports = scan;
      }
    });
    var require_parse22 = __commonJS22({
      "node_modules/picomatch/lib/parse.js"(exports2, module22) {
        "use strict";
        var constants = require_constants32();
        var utils2 = require_utils32();
        var {
          MAX_LENGTH,
          POSIX_REGEX_SOURCE,
          REGEX_NON_SPECIAL_CHARS,
          REGEX_SPECIAL_CHARS_BACKREF,
          REPLACEMENTS
        } = constants;
        var expandRange = (args, options) => {
          if (typeof options.expandRange === "function") {
            return options.expandRange(...args, options);
          }
          args.sort();
          const value2 = `[${args.join("-")}]`;
          try {
            new RegExp(value2);
          } catch (ex) {
            return args.map((v) => utils2.escapeRegex(v)).join("..");
          }
          return value2;
        };
        var syntaxError = (type, char) => {
          return `Missing ${type}: "${char}" - use "\\\\${char}" to match literal characters`;
        };
        var parse3 = (input, options) => {
          if (typeof input !== "string") {
            throw new TypeError("Expected a string");
          }
          input = REPLACEMENTS[input] || input;
          const opts = Object.assign({}, options);
          const max2 = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
          let len = input.length;
          if (len > max2) {
            throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max2}`);
          }
          const bos = {
            type: "bos",
            value: "",
            output: opts.prepend || ""
          };
          const tokens = [bos];
          const capture = opts.capture ? "" : "?:";
          const win32 = utils2.isWindows(options);
          const PLATFORM_CHARS = constants.globChars(win32);
          const EXTGLOB_CHARS = constants.extglobChars(PLATFORM_CHARS);
          const {
            DOT_LITERAL,
            PLUS_LITERAL,
            SLASH_LITERAL,
            ONE_CHAR,
            DOTS_SLASH,
            NO_DOT,
            NO_DOT_SLASH,
            NO_DOTS_SLASH,
            QMARK,
            QMARK_NO_DOT,
            STAR,
            START_ANCHOR
          } = PLATFORM_CHARS;
          const globstar = (opts2) => {
            return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
          };
          const nodot = opts.dot ? "" : NO_DOT;
          const qmarkNoDot = opts.dot ? QMARK : QMARK_NO_DOT;
          let star = opts.bash === true ? globstar(opts) : STAR;
          if (opts.capture) {
            star = `(${star})`;
          }
          if (typeof opts.noext === "boolean") {
            opts.noextglob = opts.noext;
          }
          const state = {
            input,
            index: -1,
            start: 0,
            dot: opts.dot === true,
            consumed: "",
            output: "",
            prefix: "",
            backtrack: false,
            negated: false,
            brackets: 0,
            braces: 0,
            parens: 0,
            quotes: 0,
            globstar: false,
            tokens
          };
          input = utils2.removePrefix(input, state);
          len = input.length;
          const extglobs = [];
          const braces = [];
          const stack = [];
          let prev = bos;
          let value2;
          const eos = () => state.index === len - 1;
          const peek = state.peek = (n = 1) => input[state.index + n];
          const advance = state.advance = () => input[++state.index] || "";
          const remaining = () => input.slice(state.index + 1);
          const consume = (value22 = "", num = 0) => {
            state.consumed += value22;
            state.index += num;
          };
          const append = (token) => {
            state.output += token.output != null ? token.output : token.value;
            consume(token.value);
          };
          const negate = () => {
            let count = 1;
            while (peek() === "!" && (peek(2) !== "(" || peek(3) === "?")) {
              advance();
              state.start++;
              count++;
            }
            if (count % 2 === 0) {
              return false;
            }
            state.negated = true;
            state.start++;
            return true;
          };
          const increment = (type) => {
            state[type]++;
            stack.push(type);
          };
          const decrement = (type) => {
            state[type]--;
            stack.pop();
          };
          const push = (tok) => {
            if (prev.type === "globstar") {
              const isBrace = state.braces > 0 && (tok.type === "comma" || tok.type === "brace");
              const isExtglob = tok.extglob === true || extglobs.length && (tok.type === "pipe" || tok.type === "paren");
              if (tok.type !== "slash" && tok.type !== "paren" && !isBrace && !isExtglob) {
                state.output = state.output.slice(0, -prev.output.length);
                prev.type = "star";
                prev.value = "*";
                prev.output = star;
                state.output += prev.output;
              }
            }
            if (extglobs.length && tok.type !== "paren") {
              extglobs[extglobs.length - 1].inner += tok.value;
            }
            if (tok.value || tok.output)
              append(tok);
            if (prev && prev.type === "text" && tok.type === "text") {
              prev.value += tok.value;
              prev.output = (prev.output || "") + tok.value;
              return;
            }
            tok.prev = prev;
            tokens.push(tok);
            prev = tok;
          };
          const extglobOpen = (type, value22) => {
            const token = Object.assign(Object.assign({}, EXTGLOB_CHARS[value22]), {}, {
              conditions: 1,
              inner: ""
            });
            token.prev = prev;
            token.parens = state.parens;
            token.output = state.output;
            const output = (opts.capture ? "(" : "") + token.open;
            increment("parens");
            push({
              type,
              value: value22,
              output: state.output ? "" : ONE_CHAR
            });
            push({
              type: "paren",
              extglob: true,
              value: advance(),
              output
            });
            extglobs.push(token);
          };
          const extglobClose = (token) => {
            let output = token.close + (opts.capture ? ")" : "");
            let rest;
            if (token.type === "negate") {
              let extglobStar = star;
              if (token.inner && token.inner.length > 1 && token.inner.includes("/")) {
                extglobStar = globstar(opts);
              }
              if (extglobStar !== star || eos() || /^\)+$/.test(remaining())) {
                output = token.close = `)$))${extglobStar}`;
              }
              if (token.inner.includes("*") && (rest = remaining()) && /^\.[^\\/.]+$/.test(rest)) {
                const expression = parse3(rest, Object.assign(Object.assign({}, options), {}, {
                  fastpaths: false
                })).output;
                output = token.close = `)${expression})${extglobStar})`;
              }
              if (token.prev.type === "bos") {
                state.negatedExtglob = true;
              }
            }
            push({
              type: "paren",
              extglob: true,
              value: value2,
              output
            });
            decrement("parens");
          };
          if (opts.fastpaths !== false && !/(^[*!]|[/()[\]{}"])/.test(input)) {
            let backslashes = false;
            let output = input.replace(REGEX_SPECIAL_CHARS_BACKREF, (m, esc, chars, first2, rest, index) => {
              if (first2 === "\\") {
                backslashes = true;
                return m;
              }
              if (first2 === "?") {
                if (esc) {
                  return esc + first2 + (rest ? QMARK.repeat(rest.length) : "");
                }
                if (index === 0) {
                  return qmarkNoDot + (rest ? QMARK.repeat(rest.length) : "");
                }
                return QMARK.repeat(chars.length);
              }
              if (first2 === ".") {
                return DOT_LITERAL.repeat(chars.length);
              }
              if (first2 === "*") {
                if (esc) {
                  return esc + first2 + (rest ? star : "");
                }
                return star;
              }
              return esc ? m : `\\${m}`;
            });
            if (backslashes === true) {
              if (opts.unescape === true) {
                output = output.replace(/\\/g, "");
              } else {
                output = output.replace(/\\+/g, (m) => {
                  return m.length % 2 === 0 ? "\\\\" : m ? "\\" : "";
                });
              }
            }
            if (output === input && opts.contains === true) {
              state.output = input;
              return state;
            }
            state.output = utils2.wrapOutput(output, state, options);
            return state;
          }
          while (!eos()) {
            value2 = advance();
            if (value2 === "\0") {
              continue;
            }
            if (value2 === "\\") {
              const next = peek();
              if (next === "/" && opts.bash !== true) {
                continue;
              }
              if (next === "." || next === ";") {
                continue;
              }
              if (!next) {
                value2 += "\\";
                push({
                  type: "text",
                  value: value2
                });
                continue;
              }
              const match = /^\\+/.exec(remaining());
              let slashes = 0;
              if (match && match[0].length > 2) {
                slashes = match[0].length;
                state.index += slashes;
                if (slashes % 2 !== 0) {
                  value2 += "\\";
                }
              }
              if (opts.unescape === true) {
                value2 = advance();
              } else {
                value2 += advance();
              }
              if (state.brackets === 0) {
                push({
                  type: "text",
                  value: value2
                });
                continue;
              }
            }
            if (state.brackets > 0 && (value2 !== "]" || prev.value === "[" || prev.value === "[^")) {
              if (opts.posix !== false && value2 === ":") {
                const inner = prev.value.slice(1);
                if (inner.includes("[")) {
                  prev.posix = true;
                  if (inner.includes(":")) {
                    const idx = prev.value.lastIndexOf("[");
                    const pre = prev.value.slice(0, idx);
                    const rest2 = prev.value.slice(idx + 2);
                    const posix = POSIX_REGEX_SOURCE[rest2];
                    if (posix) {
                      prev.value = pre + posix;
                      state.backtrack = true;
                      advance();
                      if (!bos.output && tokens.indexOf(prev) === 1) {
                        bos.output = ONE_CHAR;
                      }
                      continue;
                    }
                  }
                }
              }
              if (value2 === "[" && peek() !== ":" || value2 === "-" && peek() === "]") {
                value2 = `\\${value2}`;
              }
              if (value2 === "]" && (prev.value === "[" || prev.value === "[^")) {
                value2 = `\\${value2}`;
              }
              if (opts.posix === true && value2 === "!" && prev.value === "[") {
                value2 = "^";
              }
              prev.value += value2;
              append({
                value: value2
              });
              continue;
            }
            if (state.quotes === 1 && value2 !== '"') {
              value2 = utils2.escapeRegex(value2);
              prev.value += value2;
              append({
                value: value2
              });
              continue;
            }
            if (value2 === '"') {
              state.quotes = state.quotes === 1 ? 0 : 1;
              if (opts.keepQuotes === true) {
                push({
                  type: "text",
                  value: value2
                });
              }
              continue;
            }
            if (value2 === "(") {
              increment("parens");
              push({
                type: "paren",
                value: value2
              });
              continue;
            }
            if (value2 === ")") {
              if (state.parens === 0 && opts.strictBrackets === true) {
                throw new SyntaxError(syntaxError("opening", "("));
              }
              const extglob = extglobs[extglobs.length - 1];
              if (extglob && state.parens === extglob.parens + 1) {
                extglobClose(extglobs.pop());
                continue;
              }
              push({
                type: "paren",
                value: value2,
                output: state.parens ? ")" : "\\)"
              });
              decrement("parens");
              continue;
            }
            if (value2 === "[") {
              if (opts.nobracket === true || !remaining().includes("]")) {
                if (opts.nobracket !== true && opts.strictBrackets === true) {
                  throw new SyntaxError(syntaxError("closing", "]"));
                }
                value2 = `\\${value2}`;
              } else {
                increment("brackets");
              }
              push({
                type: "bracket",
                value: value2
              });
              continue;
            }
            if (value2 === "]") {
              if (opts.nobracket === true || prev && prev.type === "bracket" && prev.value.length === 1) {
                push({
                  type: "text",
                  value: value2,
                  output: `\\${value2}`
                });
                continue;
              }
              if (state.brackets === 0) {
                if (opts.strictBrackets === true) {
                  throw new SyntaxError(syntaxError("opening", "["));
                }
                push({
                  type: "text",
                  value: value2,
                  output: `\\${value2}`
                });
                continue;
              }
              decrement("brackets");
              const prevValue = prev.value.slice(1);
              if (prev.posix !== true && prevValue[0] === "^" && !prevValue.includes("/")) {
                value2 = `/${value2}`;
              }
              prev.value += value2;
              append({
                value: value2
              });
              if (opts.literalBrackets === false || utils2.hasRegexChars(prevValue)) {
                continue;
              }
              const escaped = utils2.escapeRegex(prev.value);
              state.output = state.output.slice(0, -prev.value.length);
              if (opts.literalBrackets === true) {
                state.output += escaped;
                prev.value = escaped;
                continue;
              }
              prev.value = `(${capture}${escaped}|${prev.value})`;
              state.output += prev.value;
              continue;
            }
            if (value2 === "{" && opts.nobrace !== true) {
              increment("braces");
              const open = {
                type: "brace",
                value: value2,
                output: "(",
                outputIndex: state.output.length,
                tokensIndex: state.tokens.length
              };
              braces.push(open);
              push(open);
              continue;
            }
            if (value2 === "}") {
              const brace = braces[braces.length - 1];
              if (opts.nobrace === true || !brace) {
                push({
                  type: "text",
                  value: value2,
                  output: value2
                });
                continue;
              }
              let output = ")";
              if (brace.dots === true) {
                const arr = tokens.slice();
                const range = [];
                for (let i = arr.length - 1; i >= 0; i--) {
                  tokens.pop();
                  if (arr[i].type === "brace") {
                    break;
                  }
                  if (arr[i].type !== "dots") {
                    range.unshift(arr[i].value);
                  }
                }
                output = expandRange(range, opts);
                state.backtrack = true;
              }
              if (brace.comma !== true && brace.dots !== true) {
                const out = state.output.slice(0, brace.outputIndex);
                const toks = state.tokens.slice(brace.tokensIndex);
                brace.value = brace.output = "\\{";
                value2 = output = "\\}";
                state.output = out;
                for (const t3 of toks) {
                  state.output += t3.output || t3.value;
                }
              }
              push({
                type: "brace",
                value: value2,
                output
              });
              decrement("braces");
              braces.pop();
              continue;
            }
            if (value2 === "|") {
              if (extglobs.length > 0) {
                extglobs[extglobs.length - 1].conditions++;
              }
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (value2 === ",") {
              let output = value2;
              const brace = braces[braces.length - 1];
              if (brace && stack[stack.length - 1] === "braces") {
                brace.comma = true;
                output = "|";
              }
              push({
                type: "comma",
                value: value2,
                output
              });
              continue;
            }
            if (value2 === "/") {
              if (prev.type === "dot" && state.index === state.start + 1) {
                state.start = state.index + 1;
                state.consumed = "";
                state.output = "";
                tokens.pop();
                prev = bos;
                continue;
              }
              push({
                type: "slash",
                value: value2,
                output: SLASH_LITERAL
              });
              continue;
            }
            if (value2 === ".") {
              if (state.braces > 0 && prev.type === "dot") {
                if (prev.value === ".")
                  prev.output = DOT_LITERAL;
                const brace = braces[braces.length - 1];
                prev.type = "dots";
                prev.output += value2;
                prev.value += value2;
                brace.dots = true;
                continue;
              }
              if (state.braces + state.parens === 0 && prev.type !== "bos" && prev.type !== "slash") {
                push({
                  type: "text",
                  value: value2,
                  output: DOT_LITERAL
                });
                continue;
              }
              push({
                type: "dot",
                value: value2,
                output: DOT_LITERAL
              });
              continue;
            }
            if (value2 === "?") {
              const isGroup = prev && prev.value === "(";
              if (!isGroup && opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
                extglobOpen("qmark", value2);
                continue;
              }
              if (prev && prev.type === "paren") {
                const next = peek();
                let output = value2;
                if (next === "<" && !utils2.supportsLookbehinds()) {
                  throw new Error("Node.js v10 or higher is required for regex lookbehinds");
                }
                if (prev.value === "(" && !/[!=<:]/.test(next) || next === "<" && !/<([!=]|\w+>)/.test(remaining())) {
                  output = `\\${value2}`;
                }
                push({
                  type: "text",
                  value: value2,
                  output
                });
                continue;
              }
              if (opts.dot !== true && (prev.type === "slash" || prev.type === "bos")) {
                push({
                  type: "qmark",
                  value: value2,
                  output: QMARK_NO_DOT
                });
                continue;
              }
              push({
                type: "qmark",
                value: value2,
                output: QMARK
              });
              continue;
            }
            if (value2 === "!") {
              if (opts.noextglob !== true && peek() === "(") {
                if (peek(2) !== "?" || !/[!=<:]/.test(peek(3))) {
                  extglobOpen("negate", value2);
                  continue;
                }
              }
              if (opts.nonegate !== true && state.index === 0) {
                negate();
                continue;
              }
            }
            if (value2 === "+") {
              if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
                extglobOpen("plus", value2);
                continue;
              }
              if (prev && prev.value === "(" || opts.regex === false) {
                push({
                  type: "plus",
                  value: value2,
                  output: PLUS_LITERAL
                });
                continue;
              }
              if (prev && (prev.type === "bracket" || prev.type === "paren" || prev.type === "brace") || state.parens > 0) {
                push({
                  type: "plus",
                  value: value2
                });
                continue;
              }
              push({
                type: "plus",
                value: PLUS_LITERAL
              });
              continue;
            }
            if (value2 === "@") {
              if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
                push({
                  type: "at",
                  extglob: true,
                  value: value2,
                  output: ""
                });
                continue;
              }
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (value2 !== "*") {
              if (value2 === "$" || value2 === "^") {
                value2 = `\\${value2}`;
              }
              const match = REGEX_NON_SPECIAL_CHARS.exec(remaining());
              if (match) {
                value2 += match[0];
                state.index += match[0].length;
              }
              push({
                type: "text",
                value: value2
              });
              continue;
            }
            if (prev && (prev.type === "globstar" || prev.star === true)) {
              prev.type = "star";
              prev.star = true;
              prev.value += value2;
              prev.output = star;
              state.backtrack = true;
              state.globstar = true;
              consume(value2);
              continue;
            }
            let rest = remaining();
            if (opts.noextglob !== true && /^\([^?]/.test(rest)) {
              extglobOpen("star", value2);
              continue;
            }
            if (prev.type === "star") {
              if (opts.noglobstar === true) {
                consume(value2);
                continue;
              }
              const prior = prev.prev;
              const before = prior.prev;
              const isStart = prior.type === "slash" || prior.type === "bos";
              const afterStar = before && (before.type === "star" || before.type === "globstar");
              if (opts.bash === true && (!isStart || rest[0] && rest[0] !== "/")) {
                push({
                  type: "star",
                  value: value2,
                  output: ""
                });
                continue;
              }
              const isBrace = state.braces > 0 && (prior.type === "comma" || prior.type === "brace");
              const isExtglob = extglobs.length && (prior.type === "pipe" || prior.type === "paren");
              if (!isStart && prior.type !== "paren" && !isBrace && !isExtglob) {
                push({
                  type: "star",
                  value: value2,
                  output: ""
                });
                continue;
              }
              while (rest.slice(0, 3) === "/**") {
                const after = input[state.index + 4];
                if (after && after !== "/") {
                  break;
                }
                rest = rest.slice(3);
                consume("/**", 3);
              }
              if (prior.type === "bos" && eos()) {
                prev.type = "globstar";
                prev.value += value2;
                prev.output = globstar(opts);
                state.output = prev.output;
                state.globstar = true;
                consume(value2);
                continue;
              }
              if (prior.type === "slash" && prior.prev.type !== "bos" && !afterStar && eos()) {
                state.output = state.output.slice(0, -(prior.output + prev.output).length);
                prior.output = `(?:${prior.output}`;
                prev.type = "globstar";
                prev.output = globstar(opts) + (opts.strictSlashes ? ")" : "|$)");
                prev.value += value2;
                state.globstar = true;
                state.output += prior.output + prev.output;
                consume(value2);
                continue;
              }
              if (prior.type === "slash" && prior.prev.type !== "bos" && rest[0] === "/") {
                const end = rest[1] !== void 0 ? "|$" : "";
                state.output = state.output.slice(0, -(prior.output + prev.output).length);
                prior.output = `(?:${prior.output}`;
                prev.type = "globstar";
                prev.output = `${globstar(opts)}${SLASH_LITERAL}|${SLASH_LITERAL}${end})`;
                prev.value += value2;
                state.output += prior.output + prev.output;
                state.globstar = true;
                consume(value2 + advance());
                push({
                  type: "slash",
                  value: "/",
                  output: ""
                });
                continue;
              }
              if (prior.type === "bos" && rest[0] === "/") {
                prev.type = "globstar";
                prev.value += value2;
                prev.output = `(?:^|${SLASH_LITERAL}|${globstar(opts)}${SLASH_LITERAL})`;
                state.output = prev.output;
                state.globstar = true;
                consume(value2 + advance());
                push({
                  type: "slash",
                  value: "/",
                  output: ""
                });
                continue;
              }
              state.output = state.output.slice(0, -prev.output.length);
              prev.type = "globstar";
              prev.output = globstar(opts);
              prev.value += value2;
              state.output += prev.output;
              state.globstar = true;
              consume(value2);
              continue;
            }
            const token = {
              type: "star",
              value: value2,
              output: star
            };
            if (opts.bash === true) {
              token.output = ".*?";
              if (prev.type === "bos" || prev.type === "slash") {
                token.output = nodot + token.output;
              }
              push(token);
              continue;
            }
            if (prev && (prev.type === "bracket" || prev.type === "paren") && opts.regex === true) {
              token.output = value2;
              push(token);
              continue;
            }
            if (state.index === state.start || prev.type === "slash" || prev.type === "dot") {
              if (prev.type === "dot") {
                state.output += NO_DOT_SLASH;
                prev.output += NO_DOT_SLASH;
              } else if (opts.dot === true) {
                state.output += NO_DOTS_SLASH;
                prev.output += NO_DOTS_SLASH;
              } else {
                state.output += nodot;
                prev.output += nodot;
              }
              if (peek() !== "*") {
                state.output += ONE_CHAR;
                prev.output += ONE_CHAR;
              }
            }
            push(token);
          }
          while (state.brackets > 0) {
            if (opts.strictBrackets === true)
              throw new SyntaxError(syntaxError("closing", "]"));
            state.output = utils2.escapeLast(state.output, "[");
            decrement("brackets");
          }
          while (state.parens > 0) {
            if (opts.strictBrackets === true)
              throw new SyntaxError(syntaxError("closing", ")"));
            state.output = utils2.escapeLast(state.output, "(");
            decrement("parens");
          }
          while (state.braces > 0) {
            if (opts.strictBrackets === true)
              throw new SyntaxError(syntaxError("closing", "}"));
            state.output = utils2.escapeLast(state.output, "{");
            decrement("braces");
          }
          if (opts.strictSlashes !== true && (prev.type === "star" || prev.type === "bracket")) {
            push({
              type: "maybe_slash",
              value: "",
              output: `${SLASH_LITERAL}?`
            });
          }
          if (state.backtrack === true) {
            state.output = "";
            for (const token of state.tokens) {
              state.output += token.output != null ? token.output : token.value;
              if (token.suffix) {
                state.output += token.suffix;
              }
            }
          }
          return state;
        };
        parse3.fastpaths = (input, options) => {
          const opts = Object.assign({}, options);
          const max2 = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
          const len = input.length;
          if (len > max2) {
            throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max2}`);
          }
          input = REPLACEMENTS[input] || input;
          const win32 = utils2.isWindows(options);
          const {
            DOT_LITERAL,
            SLASH_LITERAL,
            ONE_CHAR,
            DOTS_SLASH,
            NO_DOT,
            NO_DOTS,
            NO_DOTS_SLASH,
            STAR,
            START_ANCHOR
          } = constants.globChars(win32);
          const nodot = opts.dot ? NO_DOTS : NO_DOT;
          const slashDot = opts.dot ? NO_DOTS_SLASH : NO_DOT;
          const capture = opts.capture ? "" : "?:";
          const state = {
            negated: false,
            prefix: ""
          };
          let star = opts.bash === true ? ".*?" : STAR;
          if (opts.capture) {
            star = `(${star})`;
          }
          const globstar = (opts2) => {
            if (opts2.noglobstar === true)
              return star;
            return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
          };
          const create = (str) => {
            switch (str) {
              case "*":
                return `${nodot}${ONE_CHAR}${star}`;
              case ".*":
                return `${DOT_LITERAL}${ONE_CHAR}${star}`;
              case "*.*":
                return `${nodot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
              case "*/*":
                return `${nodot}${star}${SLASH_LITERAL}${ONE_CHAR}${slashDot}${star}`;
              case "**":
                return nodot + globstar(opts);
              case "**/*":
                return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${ONE_CHAR}${star}`;
              case "**/*.*":
                return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
              case "**/.*":
                return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${DOT_LITERAL}${ONE_CHAR}${star}`;
              default: {
                const match = /^(.*?)\.(\w+)$/.exec(str);
                if (!match)
                  return;
                const source2 = create(match[1]);
                if (!source2)
                  return;
                return source2 + DOT_LITERAL + match[2];
              }
            }
          };
          const output = utils2.removePrefix(input, state);
          let source = create(output);
          if (source && opts.strictSlashes !== true) {
            source += `${SLASH_LITERAL}?`;
          }
          return source;
        };
        module22.exports = parse3;
      }
    });
    var require_picomatch = __commonJS22({
      "node_modules/picomatch/lib/picomatch.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var scan = require_scan2();
        var parse3 = require_parse22();
        var utils2 = require_utils32();
        var constants = require_constants32();
        var isObject = (val) => val && typeof val === "object" && !Array.isArray(val);
        var picomatch = (glob2, options, returnState = false) => {
          if (Array.isArray(glob2)) {
            const fns = glob2.map((input) => picomatch(input, options, returnState));
            const arrayMatcher = (str) => {
              for (const isMatch of fns) {
                const state2 = isMatch(str);
                if (state2)
                  return state2;
              }
              return false;
            };
            return arrayMatcher;
          }
          const isState = isObject(glob2) && glob2.tokens && glob2.input;
          if (glob2 === "" || typeof glob2 !== "string" && !isState) {
            throw new TypeError("Expected pattern to be a non-empty string");
          }
          const opts = options || {};
          const posix = utils2.isWindows(options);
          const regex = isState ? picomatch.compileRe(glob2, options) : picomatch.makeRe(glob2, options, false, true);
          const state = regex.state;
          delete regex.state;
          let isIgnored = () => false;
          if (opts.ignore) {
            const ignoreOpts = Object.assign(Object.assign({}, options), {}, {
              ignore: null,
              onMatch: null,
              onResult: null
            });
            isIgnored = picomatch(opts.ignore, ignoreOpts, returnState);
          }
          const matcher = (input, returnObject = false) => {
            const {
              isMatch,
              match,
              output
            } = picomatch.test(input, regex, options, {
              glob: glob2,
              posix
            });
            const result = {
              glob: glob2,
              state,
              regex,
              posix,
              input,
              output,
              match,
              isMatch
            };
            if (typeof opts.onResult === "function") {
              opts.onResult(result);
            }
            if (isMatch === false) {
              result.isMatch = false;
              return returnObject ? result : false;
            }
            if (isIgnored(input)) {
              if (typeof opts.onIgnore === "function") {
                opts.onIgnore(result);
              }
              result.isMatch = false;
              return returnObject ? result : false;
            }
            if (typeof opts.onMatch === "function") {
              opts.onMatch(result);
            }
            return returnObject ? result : true;
          };
          if (returnState) {
            matcher.state = state;
          }
          return matcher;
        };
        picomatch.test = (input, regex, options, {
          glob: glob2,
          posix
        } = {}) => {
          if (typeof input !== "string") {
            throw new TypeError("Expected input to be a string");
          }
          if (input === "") {
            return {
              isMatch: false,
              output: ""
            };
          }
          const opts = options || {};
          const format2 = opts.format || (posix ? utils2.toPosixSlashes : null);
          let match = input === glob2;
          let output = match && format2 ? format2(input) : input;
          if (match === false) {
            output = format2 ? format2(input) : input;
            match = output === glob2;
          }
          if (match === false || opts.capture === true) {
            if (opts.matchBase === true || opts.basename === true) {
              match = picomatch.matchBase(input, regex, options, posix);
            } else {
              match = regex.exec(output);
            }
          }
          return {
            isMatch: Boolean(match),
            match,
            output
          };
        };
        picomatch.matchBase = (input, glob2, options, posix = utils2.isWindows(options)) => {
          const regex = glob2 instanceof RegExp ? glob2 : picomatch.makeRe(glob2, options);
          return regex.test(path2.basename(input));
        };
        picomatch.isMatch = (str, patterns, options) => picomatch(patterns, options)(str);
        picomatch.parse = (pattern, options) => {
          if (Array.isArray(pattern))
            return pattern.map((p) => picomatch.parse(p, options));
          return parse3(pattern, Object.assign(Object.assign({}, options), {}, {
            fastpaths: false
          }));
        };
        picomatch.scan = (input, options) => scan(input, options);
        picomatch.compileRe = (state, options, returnOutput = false, returnState = false) => {
          if (returnOutput === true) {
            return state.output;
          }
          const opts = options || {};
          const prepend = opts.contains ? "" : "^";
          const append = opts.contains ? "" : "$";
          let source = `${prepend}(?:${state.output})${append}`;
          if (state && state.negated === true) {
            source = `^(?!${source}).*$`;
          }
          const regex = picomatch.toRegex(source, options);
          if (returnState === true) {
            regex.state = state;
          }
          return regex;
        };
        picomatch.makeRe = (input, options = {}, returnOutput = false, returnState = false) => {
          if (!input || typeof input !== "string") {
            throw new TypeError("Expected a non-empty string");
          }
          let parsed = {
            negated: false,
            fastpaths: true
          };
          if (options.fastpaths !== false && (input[0] === "." || input[0] === "*")) {
            parsed.output = parse3.fastpaths(input, options);
          }
          if (!parsed.output) {
            parsed = parse3(input, options);
          }
          return picomatch.compileRe(parsed, options, returnOutput, returnState);
        };
        picomatch.toRegex = (source, options) => {
          try {
            const opts = options || {};
            return new RegExp(source, opts.flags || (opts.nocase ? "i" : ""));
          } catch (err) {
            if (options && options.debug === true)
              throw err;
            return /$^/;
          }
        };
        picomatch.constants = constants;
        module22.exports = picomatch;
      }
    });
    var require_picomatch2 = __commonJS22({
      "node_modules/picomatch/index.js"(exports2, module22) {
        "use strict";
        module22.exports = require_picomatch();
      }
    });
    var require_micromatch = __commonJS22({
      "node_modules/micromatch/index.js"(exports2, module22) {
        "use strict";
        var util = require("util");
        var braces = require_braces();
        var picomatch = require_picomatch2();
        var utils2 = require_utils32();
        var isEmptyString = (val) => val === "" || val === "./";
        var micromatch = (list, patterns, options) => {
          patterns = [].concat(patterns);
          list = [].concat(list);
          let omit = /* @__PURE__ */ new Set();
          let keep = /* @__PURE__ */ new Set();
          let items = /* @__PURE__ */ new Set();
          let negatives = 0;
          let onResult = (state) => {
            items.add(state.output);
            if (options && options.onResult) {
              options.onResult(state);
            }
          };
          for (let i = 0; i < patterns.length; i++) {
            let isMatch = picomatch(String(patterns[i]), Object.assign(Object.assign({}, options), {}, {
              onResult
            }), true);
            let negated = isMatch.state.negated || isMatch.state.negatedExtglob;
            if (negated)
              negatives++;
            for (let item of list) {
              let matched = isMatch(item, true);
              let match = negated ? !matched.isMatch : matched.isMatch;
              if (!match)
                continue;
              if (negated) {
                omit.add(matched.output);
              } else {
                omit.delete(matched.output);
                keep.add(matched.output);
              }
            }
          }
          let result = negatives === patterns.length ? [...items] : [...keep];
          let matches = result.filter((item) => !omit.has(item));
          if (options && matches.length === 0) {
            if (options.failglob === true) {
              throw new Error(`No matches found for "${patterns.join(", ")}"`);
            }
            if (options.nonull === true || options.nullglob === true) {
              return options.unescape ? patterns.map((p) => p.replace(/\\/g, "")) : patterns;
            }
          }
          return matches;
        };
        micromatch.match = micromatch;
        micromatch.matcher = (pattern, options) => picomatch(pattern, options);
        micromatch.isMatch = (str, patterns, options) => picomatch(patterns, options)(str);
        micromatch.any = micromatch.isMatch;
        micromatch.not = (list, patterns, options = {}) => {
          patterns = [].concat(patterns).map(String);
          let result = /* @__PURE__ */ new Set();
          let items = [];
          let onResult = (state) => {
            if (options.onResult)
              options.onResult(state);
            items.push(state.output);
          };
          let matches = new Set(micromatch(list, patterns, Object.assign(Object.assign({}, options), {}, {
            onResult
          })));
          for (let item of items) {
            if (!matches.has(item)) {
              result.add(item);
            }
          }
          return [...result];
        };
        micromatch.contains = (str, pattern, options) => {
          if (typeof str !== "string") {
            throw new TypeError(`Expected a string: "${util.inspect(str)}"`);
          }
          if (Array.isArray(pattern)) {
            return pattern.some((p) => micromatch.contains(str, p, options));
          }
          if (typeof pattern === "string") {
            if (isEmptyString(str) || isEmptyString(pattern)) {
              return false;
            }
            if (str.includes(pattern) || str.startsWith("./") && str.slice(2).includes(pattern)) {
              return true;
            }
          }
          return micromatch.isMatch(str, pattern, Object.assign(Object.assign({}, options), {}, {
            contains: true
          }));
        };
        micromatch.matchKeys = (obj, patterns, options) => {
          if (!utils2.isObject(obj)) {
            throw new TypeError("Expected the first argument to be an object");
          }
          let keys3 = micromatch(Object.keys(obj), patterns, options);
          let res = {};
          for (let key of keys3)
            res[key] = obj[key];
          return res;
        };
        micromatch.some = (list, patterns, options) => {
          let items = [].concat(list);
          for (let pattern of [].concat(patterns)) {
            let isMatch = picomatch(String(pattern), options);
            if (items.some((item) => isMatch(item))) {
              return true;
            }
          }
          return false;
        };
        micromatch.every = (list, patterns, options) => {
          let items = [].concat(list);
          for (let pattern of [].concat(patterns)) {
            let isMatch = picomatch(String(pattern), options);
            if (!items.every((item) => isMatch(item))) {
              return false;
            }
          }
          return true;
        };
        micromatch.all = (str, patterns, options) => {
          if (typeof str !== "string") {
            throw new TypeError(`Expected a string: "${util.inspect(str)}"`);
          }
          return [].concat(patterns).every((p) => picomatch(p, options)(str));
        };
        micromatch.capture = (glob2, input, options) => {
          let posix = utils2.isWindows(options);
          let regex = picomatch.makeRe(String(glob2), Object.assign(Object.assign({}, options), {}, {
            capture: true
          }));
          let match = regex.exec(posix ? utils2.toPosixSlashes(input) : input);
          if (match) {
            return match.slice(1).map((v) => v === void 0 ? "" : v);
          }
        };
        micromatch.makeRe = (...args) => picomatch.makeRe(...args);
        micromatch.scan = (...args) => picomatch.scan(...args);
        micromatch.parse = (patterns, options) => {
          let res = [];
          for (let pattern of [].concat(patterns || [])) {
            for (let str of braces(String(pattern), options)) {
              res.push(picomatch.parse(str, options));
            }
          }
          return res;
        };
        micromatch.braces = (pattern, options) => {
          if (typeof pattern !== "string")
            throw new TypeError("Expected a string");
          if (options && options.nobrace === true || !/\{.*\}/.test(pattern)) {
            return [pattern];
          }
          return braces(pattern, options);
        };
        micromatch.braceExpand = (pattern, options) => {
          if (typeof pattern !== "string")
            throw new TypeError("Expected a string");
          return micromatch.braces(pattern, Object.assign(Object.assign({}, options), {}, {
            expand: true
          }));
        };
        module22.exports = micromatch;
      }
    });
    var require_parser22 = __commonJS22({
      "node_modules/@iarna/toml/lib/parser.js"(exports2, module22) {
        "use strict";
        var ParserEND = 1114112;
        var ParserError = class extends Error {
          constructor(msg, filename, linenumber) {
            super("[ParserError] " + msg, filename, linenumber);
            this.name = "ParserError";
            this.code = "ParserError";
            if (Error.captureStackTrace)
              Error.captureStackTrace(this, ParserError);
          }
        };
        var State = class {
          constructor(parser) {
            this.parser = parser;
            this.buf = "";
            this.returned = null;
            this.result = null;
            this.resultTable = null;
            this.resultArr = null;
          }
        };
        var Parser2 = class {
          constructor() {
            this.pos = 0;
            this.col = 0;
            this.line = 0;
            this.obj = {};
            this.ctx = this.obj;
            this.stack = [];
            this._buf = "";
            this.char = null;
            this.ii = 0;
            this.state = new State(this.parseStart);
          }
          parse(str) {
            if (str.length === 0 || str.length == null)
              return;
            this._buf = String(str);
            this.ii = -1;
            this.char = -1;
            let getNext;
            while (getNext === false || this.nextChar()) {
              getNext = this.runOne();
            }
            this._buf = null;
          }
          nextChar() {
            if (this.char === 10) {
              ++this.line;
              this.col = -1;
            }
            ++this.ii;
            this.char = this._buf.codePointAt(this.ii);
            ++this.pos;
            ++this.col;
            return this.haveBuffer();
          }
          haveBuffer() {
            return this.ii < this._buf.length;
          }
          runOne() {
            return this.state.parser.call(this, this.state.returned);
          }
          finish() {
            this.char = ParserEND;
            let last2;
            do {
              last2 = this.state.parser;
              this.runOne();
            } while (this.state.parser !== last2);
            this.ctx = null;
            this.state = null;
            this._buf = null;
            return this.obj;
          }
          next(fn) {
            if (typeof fn !== "function")
              throw new ParserError("Tried to set state to non-existent state: " + JSON.stringify(fn));
            this.state.parser = fn;
          }
          goto(fn) {
            this.next(fn);
            return this.runOne();
          }
          call(fn, returnWith) {
            if (returnWith)
              this.next(returnWith);
            this.stack.push(this.state);
            this.state = new State(fn);
          }
          callNow(fn, returnWith) {
            this.call(fn, returnWith);
            return this.runOne();
          }
          return(value2) {
            if (this.stack.length === 0)
              throw this.error(new ParserError("Stack underflow"));
            if (value2 === void 0)
              value2 = this.state.buf;
            this.state = this.stack.pop();
            this.state.returned = value2;
          }
          returnNow(value2) {
            this.return(value2);
            return this.runOne();
          }
          consume() {
            if (this.char === ParserEND)
              throw this.error(new ParserError("Unexpected end-of-buffer"));
            this.state.buf += this._buf[this.ii];
          }
          error(err) {
            err.line = this.line;
            err.col = this.col;
            err.pos = this.pos;
            return err;
          }
          parseStart() {
            throw new ParserError("Must declare a parseStart method");
          }
        };
        Parser2.END = ParserEND;
        Parser2.Error = ParserError;
        module22.exports = Parser2;
      }
    });
    var require_create_datetime = __commonJS22({
      "node_modules/@iarna/toml/lib/create-datetime.js"(exports2, module22) {
        "use strict";
        module22.exports = (value2) => {
          const date = new Date(value2);
          if (isNaN(date)) {
            throw new TypeError("Invalid Datetime");
          } else {
            return date;
          }
        };
      }
    });
    var require_format_num = __commonJS22({
      "node_modules/@iarna/toml/lib/format-num.js"(exports2, module22) {
        "use strict";
        module22.exports = (d, num) => {
          num = String(num);
          while (num.length < d)
            num = "0" + num;
          return num;
        };
      }
    });
    var require_create_datetime_float = __commonJS22({
      "node_modules/@iarna/toml/lib/create-datetime-float.js"(exports2, module22) {
        "use strict";
        var f = require_format_num();
        var FloatingDateTime = class extends Date {
          constructor(value2) {
            super(value2 + "Z");
            this.isFloating = true;
          }
          toISOString() {
            const date = `${this.getUTCFullYear()}-${f(2, this.getUTCMonth() + 1)}-${f(2, this.getUTCDate())}`;
            const time = `${f(2, this.getUTCHours())}:${f(2, this.getUTCMinutes())}:${f(2, this.getUTCSeconds())}.${f(3, this.getUTCMilliseconds())}`;
            return `${date}T${time}`;
          }
        };
        module22.exports = (value2) => {
          const date = new FloatingDateTime(value2);
          if (isNaN(date)) {
            throw new TypeError("Invalid Datetime");
          } else {
            return date;
          }
        };
      }
    });
    var require_create_date = __commonJS22({
      "node_modules/@iarna/toml/lib/create-date.js"(exports2, module22) {
        "use strict";
        var f = require_format_num();
        var DateTime = global.Date;
        var Date2 = class extends DateTime {
          constructor(value2) {
            super(value2);
            this.isDate = true;
          }
          toISOString() {
            return `${this.getUTCFullYear()}-${f(2, this.getUTCMonth() + 1)}-${f(2, this.getUTCDate())}`;
          }
        };
        module22.exports = (value2) => {
          const date = new Date2(value2);
          if (isNaN(date)) {
            throw new TypeError("Invalid Datetime");
          } else {
            return date;
          }
        };
      }
    });
    var require_create_time = __commonJS22({
      "node_modules/@iarna/toml/lib/create-time.js"(exports2, module22) {
        "use strict";
        var f = require_format_num();
        var Time = class extends Date {
          constructor(value2) {
            super(`0000-01-01T${value2}Z`);
            this.isTime = true;
          }
          toISOString() {
            return `${f(2, this.getUTCHours())}:${f(2, this.getUTCMinutes())}:${f(2, this.getUTCSeconds())}.${f(3, this.getUTCMilliseconds())}`;
          }
        };
        module22.exports = (value2) => {
          const date = new Time(value2);
          if (isNaN(date)) {
            throw new TypeError("Invalid Datetime");
          } else {
            return date;
          }
        };
      }
    });
    var require_toml_parser = __commonJS22({
      "node_modules/@iarna/toml/lib/toml-parser.js"(exports2, module22) {
        "use strict";
        module22.exports = makeParserClass(require_parser22());
        module22.exports.makeParserClass = makeParserClass;
        var TomlError = class extends Error {
          constructor(msg) {
            super(msg);
            this.name = "TomlError";
            if (Error.captureStackTrace)
              Error.captureStackTrace(this, TomlError);
            this.fromTOML = true;
            this.wrapped = null;
          }
        };
        TomlError.wrap = (err) => {
          const terr = new TomlError(err.message);
          terr.code = err.code;
          terr.wrapped = err;
          return terr;
        };
        module22.exports.TomlError = TomlError;
        var createDateTime = require_create_datetime();
        var createDateTimeFloat = require_create_datetime_float();
        var createDate = require_create_date();
        var createTime = require_create_time();
        var CTRL_I = 9;
        var CTRL_J = 10;
        var CTRL_M = 13;
        var CTRL_CHAR_BOUNDARY = 31;
        var CHAR_SP = 32;
        var CHAR_QUOT = 34;
        var CHAR_NUM = 35;
        var CHAR_APOS = 39;
        var CHAR_PLUS = 43;
        var CHAR_COMMA = 44;
        var CHAR_HYPHEN = 45;
        var CHAR_PERIOD = 46;
        var CHAR_0 = 48;
        var CHAR_1 = 49;
        var CHAR_7 = 55;
        var CHAR_9 = 57;
        var CHAR_COLON = 58;
        var CHAR_EQUALS = 61;
        var CHAR_A = 65;
        var CHAR_E = 69;
        var CHAR_F = 70;
        var CHAR_T = 84;
        var CHAR_U = 85;
        var CHAR_Z = 90;
        var CHAR_LOWBAR = 95;
        var CHAR_a = 97;
        var CHAR_b = 98;
        var CHAR_e = 101;
        var CHAR_f = 102;
        var CHAR_i = 105;
        var CHAR_l = 108;
        var CHAR_n = 110;
        var CHAR_o = 111;
        var CHAR_r = 114;
        var CHAR_s = 115;
        var CHAR_t = 116;
        var CHAR_u = 117;
        var CHAR_x = 120;
        var CHAR_z = 122;
        var CHAR_LCUB = 123;
        var CHAR_RCUB = 125;
        var CHAR_LSQB = 91;
        var CHAR_BSOL = 92;
        var CHAR_RSQB = 93;
        var CHAR_DEL = 127;
        var SURROGATE_FIRST = 55296;
        var SURROGATE_LAST = 57343;
        var escapes = {
          [CHAR_b]: "\b",
          [CHAR_t]: "	",
          [CHAR_n]: "\n",
          [CHAR_f]: "\f",
          [CHAR_r]: "\r",
          [CHAR_QUOT]: '"',
          [CHAR_BSOL]: "\\"
        };
        function isDigit(cp) {
          return cp >= CHAR_0 && cp <= CHAR_9;
        }
        function isHexit(cp) {
          return cp >= CHAR_A && cp <= CHAR_F || cp >= CHAR_a && cp <= CHAR_f || cp >= CHAR_0 && cp <= CHAR_9;
        }
        function isBit(cp) {
          return cp === CHAR_1 || cp === CHAR_0;
        }
        function isOctit(cp) {
          return cp >= CHAR_0 && cp <= CHAR_7;
        }
        function isAlphaNumQuoteHyphen(cp) {
          return cp >= CHAR_A && cp <= CHAR_Z || cp >= CHAR_a && cp <= CHAR_z || cp >= CHAR_0 && cp <= CHAR_9 || cp === CHAR_APOS || cp === CHAR_QUOT || cp === CHAR_LOWBAR || cp === CHAR_HYPHEN;
        }
        function isAlphaNumHyphen(cp) {
          return cp >= CHAR_A && cp <= CHAR_Z || cp >= CHAR_a && cp <= CHAR_z || cp >= CHAR_0 && cp <= CHAR_9 || cp === CHAR_LOWBAR || cp === CHAR_HYPHEN;
        }
        var _type = Symbol("type");
        var _declared = Symbol("declared");
        var hasOwnProperty = Object.prototype.hasOwnProperty;
        var defineProperty = Object.defineProperty;
        var descriptor = {
          configurable: true,
          enumerable: true,
          writable: true,
          value: void 0
        };
        function hasKey(obj, key) {
          if (hasOwnProperty.call(obj, key))
            return true;
          if (key === "__proto__")
            defineProperty(obj, "__proto__", descriptor);
          return false;
        }
        var INLINE_TABLE = Symbol("inline-table");
        function InlineTable() {
          return Object.defineProperties({}, {
            [_type]: {
              value: INLINE_TABLE
            }
          });
        }
        function isInlineTable(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === INLINE_TABLE;
        }
        var TABLE = Symbol("table");
        function Table() {
          return Object.defineProperties({}, {
            [_type]: {
              value: TABLE
            },
            [_declared]: {
              value: false,
              writable: true
            }
          });
        }
        function isTable(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === TABLE;
        }
        var _contentType = Symbol("content-type");
        var INLINE_LIST = Symbol("inline-list");
        function InlineList(type) {
          return Object.defineProperties([], {
            [_type]: {
              value: INLINE_LIST
            },
            [_contentType]: {
              value: type
            }
          });
        }
        function isInlineList(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === INLINE_LIST;
        }
        var LIST = Symbol("list");
        function List() {
          return Object.defineProperties([], {
            [_type]: {
              value: LIST
            }
          });
        }
        function isList(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === LIST;
        }
        var _custom;
        try {
          const utilInspect = require("util").inspect;
          _custom = utilInspect.custom;
        } catch (_) {
        }
        var _inspect = _custom || "inspect";
        var BoxedBigInt = class {
          constructor(value2) {
            try {
              this.value = global.BigInt.asIntN(64, value2);
            } catch (_) {
              this.value = null;
            }
            Object.defineProperty(this, _type, {
              value: INTEGER
            });
          }
          isNaN() {
            return this.value === null;
          }
          toString() {
            return String(this.value);
          }
          [_inspect]() {
            return `[BigInt: ${this.toString()}]}`;
          }
          valueOf() {
            return this.value;
          }
        };
        var INTEGER = Symbol("integer");
        function Integer(value2) {
          let num = Number(value2);
          if (Object.is(num, -0))
            num = 0;
          if (global.BigInt && !Number.isSafeInteger(num)) {
            return new BoxedBigInt(value2);
          } else {
            return Object.defineProperties(new Number(num), {
              isNaN: {
                value: function() {
                  return isNaN(this);
                }
              },
              [_type]: {
                value: INTEGER
              },
              [_inspect]: {
                value: () => `[Integer: ${value2}]`
              }
            });
          }
        }
        function isInteger(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === INTEGER;
        }
        var FLOAT = Symbol("float");
        function Float(value2) {
          return Object.defineProperties(new Number(value2), {
            [_type]: {
              value: FLOAT
            },
            [_inspect]: {
              value: () => `[Float: ${value2}]`
            }
          });
        }
        function isFloat(obj) {
          if (obj === null || typeof obj !== "object")
            return false;
          return obj[_type] === FLOAT;
        }
        function tomlType(value2) {
          const type = typeof value2;
          if (type === "object") {
            if (value2 === null)
              return "null";
            if (value2 instanceof Date)
              return "datetime";
            if (_type in value2) {
              switch (value2[_type]) {
                case INLINE_TABLE:
                  return "inline-table";
                case INLINE_LIST:
                  return "inline-list";
                case TABLE:
                  return "table";
                case LIST:
                  return "list";
                case FLOAT:
                  return "float";
                case INTEGER:
                  return "integer";
              }
            }
          }
          return type;
        }
        function makeParserClass(Parser2) {
          class TOMLParser extends Parser2 {
            constructor() {
              super();
              this.ctx = this.obj = Table();
            }
            atEndOfWord() {
              return this.char === CHAR_NUM || this.char === CTRL_I || this.char === CHAR_SP || this.atEndOfLine();
            }
            atEndOfLine() {
              return this.char === Parser2.END || this.char === CTRL_J || this.char === CTRL_M;
            }
            parseStart() {
              if (this.char === Parser2.END) {
                return null;
              } else if (this.char === CHAR_LSQB) {
                return this.call(this.parseTableOrList);
              } else if (this.char === CHAR_NUM) {
                return this.call(this.parseComment);
              } else if (this.char === CTRL_J || this.char === CHAR_SP || this.char === CTRL_I || this.char === CTRL_M) {
                return null;
              } else if (isAlphaNumQuoteHyphen(this.char)) {
                return this.callNow(this.parseAssignStatement);
              } else {
                throw this.error(new TomlError(`Unknown character "${this.char}"`));
              }
            }
            parseWhitespaceToEOL() {
              if (this.char === CHAR_SP || this.char === CTRL_I || this.char === CTRL_M) {
                return null;
              } else if (this.char === CHAR_NUM) {
                return this.goto(this.parseComment);
              } else if (this.char === Parser2.END || this.char === CTRL_J) {
                return this.return();
              } else {
                throw this.error(new TomlError("Unexpected character, expected only whitespace or comments till end of line"));
              }
            }
            parseAssignStatement() {
              return this.callNow(this.parseAssign, this.recordAssignStatement);
            }
            recordAssignStatement(kv) {
              let target = this.ctx;
              let finalKey = kv.key.pop();
              for (let kw of kv.key) {
                if (hasKey(target, kw) && (!isTable(target[kw]) || target[kw][_declared])) {
                  throw this.error(new TomlError("Can't redefine existing key"));
                }
                target = target[kw] = target[kw] || Table();
              }
              if (hasKey(target, finalKey)) {
                throw this.error(new TomlError("Can't redefine existing key"));
              }
              if (isInteger(kv.value) || isFloat(kv.value)) {
                target[finalKey] = kv.value.valueOf();
              } else {
                target[finalKey] = kv.value;
              }
              return this.goto(this.parseWhitespaceToEOL);
            }
            parseAssign() {
              return this.callNow(this.parseKeyword, this.recordAssignKeyword);
            }
            recordAssignKeyword(key) {
              if (this.state.resultTable) {
                this.state.resultTable.push(key);
              } else {
                this.state.resultTable = [key];
              }
              return this.goto(this.parseAssignKeywordPreDot);
            }
            parseAssignKeywordPreDot() {
              if (this.char === CHAR_PERIOD) {
                return this.next(this.parseAssignKeywordPostDot);
              } else if (this.char !== CHAR_SP && this.char !== CTRL_I) {
                return this.goto(this.parseAssignEqual);
              }
            }
            parseAssignKeywordPostDot() {
              if (this.char !== CHAR_SP && this.char !== CTRL_I) {
                return this.callNow(this.parseKeyword, this.recordAssignKeyword);
              }
            }
            parseAssignEqual() {
              if (this.char === CHAR_EQUALS) {
                return this.next(this.parseAssignPreValue);
              } else {
                throw this.error(new TomlError('Invalid character, expected "="'));
              }
            }
            parseAssignPreValue() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else {
                return this.callNow(this.parseValue, this.recordAssignValue);
              }
            }
            recordAssignValue(value2) {
              return this.returnNow({
                key: this.state.resultTable,
                value: value2
              });
            }
            parseComment() {
              do {
                if (this.char === Parser2.END || this.char === CTRL_J) {
                  return this.return();
                }
              } while (this.nextChar());
            }
            parseTableOrList() {
              if (this.char === CHAR_LSQB) {
                this.next(this.parseList);
              } else {
                return this.goto(this.parseTable);
              }
            }
            parseTable() {
              this.ctx = this.obj;
              return this.goto(this.parseTableNext);
            }
            parseTableNext() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else {
                return this.callNow(this.parseKeyword, this.parseTableMore);
              }
            }
            parseTableMore(keyword) {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else if (this.char === CHAR_RSQB) {
                if (hasKey(this.ctx, keyword) && (!isTable(this.ctx[keyword]) || this.ctx[keyword][_declared])) {
                  throw this.error(new TomlError("Can't redefine existing key"));
                } else {
                  this.ctx = this.ctx[keyword] = this.ctx[keyword] || Table();
                  this.ctx[_declared] = true;
                }
                return this.next(this.parseWhitespaceToEOL);
              } else if (this.char === CHAR_PERIOD) {
                if (!hasKey(this.ctx, keyword)) {
                  this.ctx = this.ctx[keyword] = Table();
                } else if (isTable(this.ctx[keyword])) {
                  this.ctx = this.ctx[keyword];
                } else if (isList(this.ctx[keyword])) {
                  this.ctx = this.ctx[keyword][this.ctx[keyword].length - 1];
                } else {
                  throw this.error(new TomlError("Can't redefine existing key"));
                }
                return this.next(this.parseTableNext);
              } else {
                throw this.error(new TomlError("Unexpected character, expected whitespace, . or ]"));
              }
            }
            parseList() {
              this.ctx = this.obj;
              return this.goto(this.parseListNext);
            }
            parseListNext() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else {
                return this.callNow(this.parseKeyword, this.parseListMore);
              }
            }
            parseListMore(keyword) {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else if (this.char === CHAR_RSQB) {
                if (!hasKey(this.ctx, keyword)) {
                  this.ctx[keyword] = List();
                }
                if (isInlineList(this.ctx[keyword])) {
                  throw this.error(new TomlError("Can't extend an inline array"));
                } else if (isList(this.ctx[keyword])) {
                  const next = Table();
                  this.ctx[keyword].push(next);
                  this.ctx = next;
                } else {
                  throw this.error(new TomlError("Can't redefine an existing key"));
                }
                return this.next(this.parseListEnd);
              } else if (this.char === CHAR_PERIOD) {
                if (!hasKey(this.ctx, keyword)) {
                  this.ctx = this.ctx[keyword] = Table();
                } else if (isInlineList(this.ctx[keyword])) {
                  throw this.error(new TomlError("Can't extend an inline array"));
                } else if (isInlineTable(this.ctx[keyword])) {
                  throw this.error(new TomlError("Can't extend an inline table"));
                } else if (isList(this.ctx[keyword])) {
                  this.ctx = this.ctx[keyword][this.ctx[keyword].length - 1];
                } else if (isTable(this.ctx[keyword])) {
                  this.ctx = this.ctx[keyword];
                } else {
                  throw this.error(new TomlError("Can't redefine an existing key"));
                }
                return this.next(this.parseListNext);
              } else {
                throw this.error(new TomlError("Unexpected character, expected whitespace, . or ]"));
              }
            }
            parseListEnd(keyword) {
              if (this.char === CHAR_RSQB) {
                return this.next(this.parseWhitespaceToEOL);
              } else {
                throw this.error(new TomlError("Unexpected character, expected whitespace, . or ]"));
              }
            }
            parseValue() {
              if (this.char === Parser2.END) {
                throw this.error(new TomlError("Key without value"));
              } else if (this.char === CHAR_QUOT) {
                return this.next(this.parseDoubleString);
              }
              if (this.char === CHAR_APOS) {
                return this.next(this.parseSingleString);
              } else if (this.char === CHAR_HYPHEN || this.char === CHAR_PLUS) {
                return this.goto(this.parseNumberSign);
              } else if (this.char === CHAR_i) {
                return this.next(this.parseInf);
              } else if (this.char === CHAR_n) {
                return this.next(this.parseNan);
              } else if (isDigit(this.char)) {
                return this.goto(this.parseNumberOrDateTime);
              } else if (this.char === CHAR_t || this.char === CHAR_f) {
                return this.goto(this.parseBoolean);
              } else if (this.char === CHAR_LSQB) {
                return this.call(this.parseInlineList, this.recordValue);
              } else if (this.char === CHAR_LCUB) {
                return this.call(this.parseInlineTable, this.recordValue);
              } else {
                throw this.error(new TomlError("Unexpected character, expecting string, number, datetime, boolean, inline array or inline table"));
              }
            }
            recordValue(value2) {
              return this.returnNow(value2);
            }
            parseInf() {
              if (this.char === CHAR_n) {
                return this.next(this.parseInf2);
              } else {
                throw this.error(new TomlError('Unexpected character, expected "inf", "+inf" or "-inf"'));
              }
            }
            parseInf2() {
              if (this.char === CHAR_f) {
                if (this.state.buf === "-") {
                  return this.return(-Infinity);
                } else {
                  return this.return(Infinity);
                }
              } else {
                throw this.error(new TomlError('Unexpected character, expected "inf", "+inf" or "-inf"'));
              }
            }
            parseNan() {
              if (this.char === CHAR_a) {
                return this.next(this.parseNan2);
              } else {
                throw this.error(new TomlError('Unexpected character, expected "nan"'));
              }
            }
            parseNan2() {
              if (this.char === CHAR_n) {
                return this.return(NaN);
              } else {
                throw this.error(new TomlError('Unexpected character, expected "nan"'));
              }
            }
            parseKeyword() {
              if (this.char === CHAR_QUOT) {
                return this.next(this.parseBasicString);
              } else if (this.char === CHAR_APOS) {
                return this.next(this.parseLiteralString);
              } else {
                return this.goto(this.parseBareKey);
              }
            }
            parseBareKey() {
              do {
                if (this.char === Parser2.END) {
                  throw this.error(new TomlError("Key ended without value"));
                } else if (isAlphaNumHyphen(this.char)) {
                  this.consume();
                } else if (this.state.buf.length === 0) {
                  throw this.error(new TomlError("Empty bare keys are not allowed"));
                } else {
                  return this.returnNow();
                }
              } while (this.nextChar());
            }
            parseSingleString() {
              if (this.char === CHAR_APOS) {
                return this.next(this.parseLiteralMultiStringMaybe);
              } else {
                return this.goto(this.parseLiteralString);
              }
            }
            parseLiteralString() {
              do {
                if (this.char === CHAR_APOS) {
                  return this.return();
                } else if (this.atEndOfLine()) {
                  throw this.error(new TomlError("Unterminated string"));
                } else if (this.char === CHAR_DEL || this.char <= CTRL_CHAR_BOUNDARY && this.char !== CTRL_I) {
                  throw this.errorControlCharInString();
                } else {
                  this.consume();
                }
              } while (this.nextChar());
            }
            parseLiteralMultiStringMaybe() {
              if (this.char === CHAR_APOS) {
                return this.next(this.parseLiteralMultiString);
              } else {
                return this.returnNow();
              }
            }
            parseLiteralMultiString() {
              if (this.char === CTRL_M) {
                return null;
              } else if (this.char === CTRL_J) {
                return this.next(this.parseLiteralMultiStringContent);
              } else {
                return this.goto(this.parseLiteralMultiStringContent);
              }
            }
            parseLiteralMultiStringContent() {
              do {
                if (this.char === CHAR_APOS) {
                  return this.next(this.parseLiteralMultiEnd);
                } else if (this.char === Parser2.END) {
                  throw this.error(new TomlError("Unterminated multi-line string"));
                } else if (this.char === CHAR_DEL || this.char <= CTRL_CHAR_BOUNDARY && this.char !== CTRL_I && this.char !== CTRL_J && this.char !== CTRL_M) {
                  throw this.errorControlCharInString();
                } else {
                  this.consume();
                }
              } while (this.nextChar());
            }
            parseLiteralMultiEnd() {
              if (this.char === CHAR_APOS) {
                return this.next(this.parseLiteralMultiEnd2);
              } else {
                this.state.buf += "'";
                return this.goto(this.parseLiteralMultiStringContent);
              }
            }
            parseLiteralMultiEnd2() {
              if (this.char === CHAR_APOS) {
                return this.return();
              } else {
                this.state.buf += "''";
                return this.goto(this.parseLiteralMultiStringContent);
              }
            }
            parseDoubleString() {
              if (this.char === CHAR_QUOT) {
                return this.next(this.parseMultiStringMaybe);
              } else {
                return this.goto(this.parseBasicString);
              }
            }
            parseBasicString() {
              do {
                if (this.char === CHAR_BSOL) {
                  return this.call(this.parseEscape, this.recordEscapeReplacement);
                } else if (this.char === CHAR_QUOT) {
                  return this.return();
                } else if (this.atEndOfLine()) {
                  throw this.error(new TomlError("Unterminated string"));
                } else if (this.char === CHAR_DEL || this.char <= CTRL_CHAR_BOUNDARY && this.char !== CTRL_I) {
                  throw this.errorControlCharInString();
                } else {
                  this.consume();
                }
              } while (this.nextChar());
            }
            recordEscapeReplacement(replacement) {
              this.state.buf += replacement;
              return this.goto(this.parseBasicString);
            }
            parseMultiStringMaybe() {
              if (this.char === CHAR_QUOT) {
                return this.next(this.parseMultiString);
              } else {
                return this.returnNow();
              }
            }
            parseMultiString() {
              if (this.char === CTRL_M) {
                return null;
              } else if (this.char === CTRL_J) {
                return this.next(this.parseMultiStringContent);
              } else {
                return this.goto(this.parseMultiStringContent);
              }
            }
            parseMultiStringContent() {
              do {
                if (this.char === CHAR_BSOL) {
                  return this.call(this.parseMultiEscape, this.recordMultiEscapeReplacement);
                } else if (this.char === CHAR_QUOT) {
                  return this.next(this.parseMultiEnd);
                } else if (this.char === Parser2.END) {
                  throw this.error(new TomlError("Unterminated multi-line string"));
                } else if (this.char === CHAR_DEL || this.char <= CTRL_CHAR_BOUNDARY && this.char !== CTRL_I && this.char !== CTRL_J && this.char !== CTRL_M) {
                  throw this.errorControlCharInString();
                } else {
                  this.consume();
                }
              } while (this.nextChar());
            }
            errorControlCharInString() {
              let displayCode = "\\u00";
              if (this.char < 16) {
                displayCode += "0";
              }
              displayCode += this.char.toString(16);
              return this.error(new TomlError(`Control characters (codes < 0x1f and 0x7f) are not allowed in strings, use ${displayCode} instead`));
            }
            recordMultiEscapeReplacement(replacement) {
              this.state.buf += replacement;
              return this.goto(this.parseMultiStringContent);
            }
            parseMultiEnd() {
              if (this.char === CHAR_QUOT) {
                return this.next(this.parseMultiEnd2);
              } else {
                this.state.buf += '"';
                return this.goto(this.parseMultiStringContent);
              }
            }
            parseMultiEnd2() {
              if (this.char === CHAR_QUOT) {
                return this.return();
              } else {
                this.state.buf += '""';
                return this.goto(this.parseMultiStringContent);
              }
            }
            parseMultiEscape() {
              if (this.char === CTRL_M || this.char === CTRL_J) {
                return this.next(this.parseMultiTrim);
              } else if (this.char === CHAR_SP || this.char === CTRL_I) {
                return this.next(this.parsePreMultiTrim);
              } else {
                return this.goto(this.parseEscape);
              }
            }
            parsePreMultiTrim() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else if (this.char === CTRL_M || this.char === CTRL_J) {
                return this.next(this.parseMultiTrim);
              } else {
                throw this.error(new TomlError("Can't escape whitespace"));
              }
            }
            parseMultiTrim() {
              if (this.char === CTRL_J || this.char === CHAR_SP || this.char === CTRL_I || this.char === CTRL_M) {
                return null;
              } else {
                return this.returnNow();
              }
            }
            parseEscape() {
              if (this.char in escapes) {
                return this.return(escapes[this.char]);
              } else if (this.char === CHAR_u) {
                return this.call(this.parseSmallUnicode, this.parseUnicodeReturn);
              } else if (this.char === CHAR_U) {
                return this.call(this.parseLargeUnicode, this.parseUnicodeReturn);
              } else {
                throw this.error(new TomlError("Unknown escape character: " + this.char));
              }
            }
            parseUnicodeReturn(char) {
              try {
                const codePoint = parseInt(char, 16);
                if (codePoint >= SURROGATE_FIRST && codePoint <= SURROGATE_LAST) {
                  throw this.error(new TomlError("Invalid unicode, character in range 0xD800 - 0xDFFF is reserved"));
                }
                return this.returnNow(String.fromCodePoint(codePoint));
              } catch (err) {
                throw this.error(TomlError.wrap(err));
              }
            }
            parseSmallUnicode() {
              if (!isHexit(this.char)) {
                throw this.error(new TomlError("Invalid character in unicode sequence, expected hex"));
              } else {
                this.consume();
                if (this.state.buf.length >= 4)
                  return this.return();
              }
            }
            parseLargeUnicode() {
              if (!isHexit(this.char)) {
                throw this.error(new TomlError("Invalid character in unicode sequence, expected hex"));
              } else {
                this.consume();
                if (this.state.buf.length >= 8)
                  return this.return();
              }
            }
            parseNumberSign() {
              this.consume();
              return this.next(this.parseMaybeSignedInfOrNan);
            }
            parseMaybeSignedInfOrNan() {
              if (this.char === CHAR_i) {
                return this.next(this.parseInf);
              } else if (this.char === CHAR_n) {
                return this.next(this.parseNan);
              } else {
                return this.callNow(this.parseNoUnder, this.parseNumberIntegerStart);
              }
            }
            parseNumberIntegerStart() {
              if (this.char === CHAR_0) {
                this.consume();
                return this.next(this.parseNumberIntegerExponentOrDecimal);
              } else {
                return this.goto(this.parseNumberInteger);
              }
            }
            parseNumberIntegerExponentOrDecimal() {
              if (this.char === CHAR_PERIOD) {
                this.consume();
                return this.call(this.parseNoUnder, this.parseNumberFloat);
              } else if (this.char === CHAR_E || this.char === CHAR_e) {
                this.consume();
                return this.next(this.parseNumberExponentSign);
              } else {
                return this.returnNow(Integer(this.state.buf));
              }
            }
            parseNumberInteger() {
              if (isDigit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnder);
              } else if (this.char === CHAR_E || this.char === CHAR_e) {
                this.consume();
                return this.next(this.parseNumberExponentSign);
              } else if (this.char === CHAR_PERIOD) {
                this.consume();
                return this.call(this.parseNoUnder, this.parseNumberFloat);
              } else {
                const result = Integer(this.state.buf);
                if (result.isNaN()) {
                  throw this.error(new TomlError("Invalid number"));
                } else {
                  return this.returnNow(result);
                }
              }
            }
            parseNoUnder() {
              if (this.char === CHAR_LOWBAR || this.char === CHAR_PERIOD || this.char === CHAR_E || this.char === CHAR_e) {
                throw this.error(new TomlError("Unexpected character, expected digit"));
              } else if (this.atEndOfWord()) {
                throw this.error(new TomlError("Incomplete number"));
              }
              return this.returnNow();
            }
            parseNoUnderHexOctBinLiteral() {
              if (this.char === CHAR_LOWBAR || this.char === CHAR_PERIOD) {
                throw this.error(new TomlError("Unexpected character, expected digit"));
              } else if (this.atEndOfWord()) {
                throw this.error(new TomlError("Incomplete number"));
              }
              return this.returnNow();
            }
            parseNumberFloat() {
              if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnder, this.parseNumberFloat);
              } else if (isDigit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_E || this.char === CHAR_e) {
                this.consume();
                return this.next(this.parseNumberExponentSign);
              } else {
                return this.returnNow(Float(this.state.buf));
              }
            }
            parseNumberExponentSign() {
              if (isDigit(this.char)) {
                return this.goto(this.parseNumberExponent);
              } else if (this.char === CHAR_HYPHEN || this.char === CHAR_PLUS) {
                this.consume();
                this.call(this.parseNoUnder, this.parseNumberExponent);
              } else {
                throw this.error(new TomlError("Unexpected character, expected -, + or digit"));
              }
            }
            parseNumberExponent() {
              if (isDigit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnder);
              } else {
                return this.returnNow(Float(this.state.buf));
              }
            }
            parseNumberOrDateTime() {
              if (this.char === CHAR_0) {
                this.consume();
                return this.next(this.parseNumberBaseOrDateTime);
              } else {
                return this.goto(this.parseNumberOrDateTimeOnly);
              }
            }
            parseNumberOrDateTimeOnly() {
              if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnder, this.parseNumberInteger);
              } else if (isDigit(this.char)) {
                this.consume();
                if (this.state.buf.length > 4)
                  this.next(this.parseNumberInteger);
              } else if (this.char === CHAR_E || this.char === CHAR_e) {
                this.consume();
                return this.next(this.parseNumberExponentSign);
              } else if (this.char === CHAR_PERIOD) {
                this.consume();
                return this.call(this.parseNoUnder, this.parseNumberFloat);
              } else if (this.char === CHAR_HYPHEN) {
                return this.goto(this.parseDateTime);
              } else if (this.char === CHAR_COLON) {
                return this.goto(this.parseOnlyTimeHour);
              } else {
                return this.returnNow(Integer(this.state.buf));
              }
            }
            parseDateTimeOnly() {
              if (this.state.buf.length < 4) {
                if (isDigit(this.char)) {
                  return this.consume();
                } else if (this.char === CHAR_COLON) {
                  return this.goto(this.parseOnlyTimeHour);
                } else {
                  throw this.error(new TomlError("Expected digit while parsing year part of a date"));
                }
              } else {
                if (this.char === CHAR_HYPHEN) {
                  return this.goto(this.parseDateTime);
                } else {
                  throw this.error(new TomlError("Expected hyphen (-) while parsing year part of date"));
                }
              }
            }
            parseNumberBaseOrDateTime() {
              if (this.char === CHAR_b) {
                this.consume();
                return this.call(this.parseNoUnderHexOctBinLiteral, this.parseIntegerBin);
              } else if (this.char === CHAR_o) {
                this.consume();
                return this.call(this.parseNoUnderHexOctBinLiteral, this.parseIntegerOct);
              } else if (this.char === CHAR_x) {
                this.consume();
                return this.call(this.parseNoUnderHexOctBinLiteral, this.parseIntegerHex);
              } else if (this.char === CHAR_PERIOD) {
                return this.goto(this.parseNumberInteger);
              } else if (isDigit(this.char)) {
                return this.goto(this.parseDateTimeOnly);
              } else {
                return this.returnNow(Integer(this.state.buf));
              }
            }
            parseIntegerHex() {
              if (isHexit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnderHexOctBinLiteral);
              } else {
                const result = Integer(this.state.buf);
                if (result.isNaN()) {
                  throw this.error(new TomlError("Invalid number"));
                } else {
                  return this.returnNow(result);
                }
              }
            }
            parseIntegerOct() {
              if (isOctit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnderHexOctBinLiteral);
              } else {
                const result = Integer(this.state.buf);
                if (result.isNaN()) {
                  throw this.error(new TomlError("Invalid number"));
                } else {
                  return this.returnNow(result);
                }
              }
            }
            parseIntegerBin() {
              if (isBit(this.char)) {
                this.consume();
              } else if (this.char === CHAR_LOWBAR) {
                return this.call(this.parseNoUnderHexOctBinLiteral);
              } else {
                const result = Integer(this.state.buf);
                if (result.isNaN()) {
                  throw this.error(new TomlError("Invalid number"));
                } else {
                  return this.returnNow(result);
                }
              }
            }
            parseDateTime() {
              if (this.state.buf.length < 4) {
                throw this.error(new TomlError("Years less than 1000 must be zero padded to four characters"));
              }
              this.state.result = this.state.buf;
              this.state.buf = "";
              return this.next(this.parseDateMonth);
            }
            parseDateMonth() {
              if (this.char === CHAR_HYPHEN) {
                if (this.state.buf.length < 2) {
                  throw this.error(new TomlError("Months less than 10 must be zero padded to two characters"));
                }
                this.state.result += "-" + this.state.buf;
                this.state.buf = "";
                return this.next(this.parseDateDay);
              } else if (isDigit(this.char)) {
                this.consume();
              } else {
                throw this.error(new TomlError("Incomplete datetime"));
              }
            }
            parseDateDay() {
              if (this.char === CHAR_T || this.char === CHAR_SP) {
                if (this.state.buf.length < 2) {
                  throw this.error(new TomlError("Days less than 10 must be zero padded to two characters"));
                }
                this.state.result += "-" + this.state.buf;
                this.state.buf = "";
                return this.next(this.parseStartTimeHour);
              } else if (this.atEndOfWord()) {
                return this.returnNow(createDate(this.state.result + "-" + this.state.buf));
              } else if (isDigit(this.char)) {
                this.consume();
              } else {
                throw this.error(new TomlError("Incomplete datetime"));
              }
            }
            parseStartTimeHour() {
              if (this.atEndOfWord()) {
                return this.returnNow(createDate(this.state.result));
              } else {
                return this.goto(this.parseTimeHour);
              }
            }
            parseTimeHour() {
              if (this.char === CHAR_COLON) {
                if (this.state.buf.length < 2) {
                  throw this.error(new TomlError("Hours less than 10 must be zero padded to two characters"));
                }
                this.state.result += "T" + this.state.buf;
                this.state.buf = "";
                return this.next(this.parseTimeMin);
              } else if (isDigit(this.char)) {
                this.consume();
              } else {
                throw this.error(new TomlError("Incomplete datetime"));
              }
            }
            parseTimeMin() {
              if (this.state.buf.length < 2 && isDigit(this.char)) {
                this.consume();
              } else if (this.state.buf.length === 2 && this.char === CHAR_COLON) {
                this.state.result += ":" + this.state.buf;
                this.state.buf = "";
                return this.next(this.parseTimeSec);
              } else {
                throw this.error(new TomlError("Incomplete datetime"));
              }
            }
            parseTimeSec() {
              if (isDigit(this.char)) {
                this.consume();
                if (this.state.buf.length === 2) {
                  this.state.result += ":" + this.state.buf;
                  this.state.buf = "";
                  return this.next(this.parseTimeZoneOrFraction);
                }
              } else {
                throw this.error(new TomlError("Incomplete datetime"));
              }
            }
            parseOnlyTimeHour() {
              if (this.char === CHAR_COLON) {
                if (this.state.buf.length < 2) {
                  throw this.error(new TomlError("Hours less than 10 must be zero padded to two characters"));
                }
                this.state.result = this.state.buf;
                this.state.buf = "";
                return this.next(this.parseOnlyTimeMin);
              } else {
                throw this.error(new TomlError("Incomplete time"));
              }
            }
            parseOnlyTimeMin() {
              if (this.state.buf.length < 2 && isDigit(this.char)) {
                this.consume();
              } else if (this.state.buf.length === 2 && this.char === CHAR_COLON) {
                this.state.result += ":" + this.state.buf;
                this.state.buf = "";
                return this.next(this.parseOnlyTimeSec);
              } else {
                throw this.error(new TomlError("Incomplete time"));
              }
            }
            parseOnlyTimeSec() {
              if (isDigit(this.char)) {
                this.consume();
                if (this.state.buf.length === 2) {
                  return this.next(this.parseOnlyTimeFractionMaybe);
                }
              } else {
                throw this.error(new TomlError("Incomplete time"));
              }
            }
            parseOnlyTimeFractionMaybe() {
              this.state.result += ":" + this.state.buf;
              if (this.char === CHAR_PERIOD) {
                this.state.buf = "";
                this.next(this.parseOnlyTimeFraction);
              } else {
                return this.return(createTime(this.state.result));
              }
            }
            parseOnlyTimeFraction() {
              if (isDigit(this.char)) {
                this.consume();
              } else if (this.atEndOfWord()) {
                if (this.state.buf.length === 0)
                  throw this.error(new TomlError("Expected digit in milliseconds"));
                return this.returnNow(createTime(this.state.result + "." + this.state.buf));
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected period (.), minus (-), plus (+) or Z"));
              }
            }
            parseTimeZoneOrFraction() {
              if (this.char === CHAR_PERIOD) {
                this.consume();
                this.next(this.parseDateTimeFraction);
              } else if (this.char === CHAR_HYPHEN || this.char === CHAR_PLUS) {
                this.consume();
                this.next(this.parseTimeZoneHour);
              } else if (this.char === CHAR_Z) {
                this.consume();
                return this.return(createDateTime(this.state.result + this.state.buf));
              } else if (this.atEndOfWord()) {
                return this.returnNow(createDateTimeFloat(this.state.result + this.state.buf));
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected period (.), minus (-), plus (+) or Z"));
              }
            }
            parseDateTimeFraction() {
              if (isDigit(this.char)) {
                this.consume();
              } else if (this.state.buf.length === 1) {
                throw this.error(new TomlError("Expected digit in milliseconds"));
              } else if (this.char === CHAR_HYPHEN || this.char === CHAR_PLUS) {
                this.consume();
                this.next(this.parseTimeZoneHour);
              } else if (this.char === CHAR_Z) {
                this.consume();
                return this.return(createDateTime(this.state.result + this.state.buf));
              } else if (this.atEndOfWord()) {
                return this.returnNow(createDateTimeFloat(this.state.result + this.state.buf));
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected period (.), minus (-), plus (+) or Z"));
              }
            }
            parseTimeZoneHour() {
              if (isDigit(this.char)) {
                this.consume();
                if (/\d\d$/.test(this.state.buf))
                  return this.next(this.parseTimeZoneSep);
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected digit"));
              }
            }
            parseTimeZoneSep() {
              if (this.char === CHAR_COLON) {
                this.consume();
                this.next(this.parseTimeZoneMin);
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected colon"));
              }
            }
            parseTimeZoneMin() {
              if (isDigit(this.char)) {
                this.consume();
                if (/\d\d$/.test(this.state.buf))
                  return this.return(createDateTime(this.state.result + this.state.buf));
              } else {
                throw this.error(new TomlError("Unexpected character in datetime, expected digit"));
              }
            }
            parseBoolean() {
              if (this.char === CHAR_t) {
                this.consume();
                return this.next(this.parseTrue_r);
              } else if (this.char === CHAR_f) {
                this.consume();
                return this.next(this.parseFalse_a);
              }
            }
            parseTrue_r() {
              if (this.char === CHAR_r) {
                this.consume();
                return this.next(this.parseTrue_u);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseTrue_u() {
              if (this.char === CHAR_u) {
                this.consume();
                return this.next(this.parseTrue_e);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseTrue_e() {
              if (this.char === CHAR_e) {
                return this.return(true);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseFalse_a() {
              if (this.char === CHAR_a) {
                this.consume();
                return this.next(this.parseFalse_l);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseFalse_l() {
              if (this.char === CHAR_l) {
                this.consume();
                return this.next(this.parseFalse_s);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseFalse_s() {
              if (this.char === CHAR_s) {
                this.consume();
                return this.next(this.parseFalse_e);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseFalse_e() {
              if (this.char === CHAR_e) {
                return this.return(false);
              } else {
                throw this.error(new TomlError("Invalid boolean, expected true or false"));
              }
            }
            parseInlineList() {
              if (this.char === CHAR_SP || this.char === CTRL_I || this.char === CTRL_M || this.char === CTRL_J) {
                return null;
              } else if (this.char === Parser2.END) {
                throw this.error(new TomlError("Unterminated inline array"));
              } else if (this.char === CHAR_NUM) {
                return this.call(this.parseComment);
              } else if (this.char === CHAR_RSQB) {
                return this.return(this.state.resultArr || InlineList());
              } else {
                return this.callNow(this.parseValue, this.recordInlineListValue);
              }
            }
            recordInlineListValue(value2) {
              if (this.state.resultArr) {
                const listType = this.state.resultArr[_contentType];
                const valueType = tomlType(value2);
                if (listType !== valueType) {
                  throw this.error(new TomlError(`Inline lists must be a single type, not a mix of ${listType} and ${valueType}`));
                }
              } else {
                this.state.resultArr = InlineList(tomlType(value2));
              }
              if (isFloat(value2) || isInteger(value2)) {
                this.state.resultArr.push(value2.valueOf());
              } else {
                this.state.resultArr.push(value2);
              }
              return this.goto(this.parseInlineListNext);
            }
            parseInlineListNext() {
              if (this.char === CHAR_SP || this.char === CTRL_I || this.char === CTRL_M || this.char === CTRL_J) {
                return null;
              } else if (this.char === CHAR_NUM) {
                return this.call(this.parseComment);
              } else if (this.char === CHAR_COMMA) {
                return this.next(this.parseInlineList);
              } else if (this.char === CHAR_RSQB) {
                return this.goto(this.parseInlineList);
              } else {
                throw this.error(new TomlError("Invalid character, expected whitespace, comma (,) or close bracket (])"));
              }
            }
            parseInlineTable() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else if (this.char === Parser2.END || this.char === CHAR_NUM || this.char === CTRL_J || this.char === CTRL_M) {
                throw this.error(new TomlError("Unterminated inline array"));
              } else if (this.char === CHAR_RCUB) {
                return this.return(this.state.resultTable || InlineTable());
              } else {
                if (!this.state.resultTable)
                  this.state.resultTable = InlineTable();
                return this.callNow(this.parseAssign, this.recordInlineTableValue);
              }
            }
            recordInlineTableValue(kv) {
              let target = this.state.resultTable;
              let finalKey = kv.key.pop();
              for (let kw of kv.key) {
                if (hasKey(target, kw) && (!isTable(target[kw]) || target[kw][_declared])) {
                  throw this.error(new TomlError("Can't redefine existing key"));
                }
                target = target[kw] = target[kw] || Table();
              }
              if (hasKey(target, finalKey)) {
                throw this.error(new TomlError("Can't redefine existing key"));
              }
              if (isInteger(kv.value) || isFloat(kv.value)) {
                target[finalKey] = kv.value.valueOf();
              } else {
                target[finalKey] = kv.value;
              }
              return this.goto(this.parseInlineTableNext);
            }
            parseInlineTableNext() {
              if (this.char === CHAR_SP || this.char === CTRL_I) {
                return null;
              } else if (this.char === Parser2.END || this.char === CHAR_NUM || this.char === CTRL_J || this.char === CTRL_M) {
                throw this.error(new TomlError("Unterminated inline array"));
              } else if (this.char === CHAR_COMMA) {
                return this.next(this.parseInlineTable);
              } else if (this.char === CHAR_RCUB) {
                return this.goto(this.parseInlineTable);
              } else {
                throw this.error(new TomlError("Invalid character, expected whitespace, comma (,) or close bracket (])"));
              }
            }
          }
          return TOMLParser;
        }
      }
    });
    var require_parse_pretty_error = __commonJS22({
      "node_modules/@iarna/toml/parse-pretty-error.js"(exports2, module22) {
        "use strict";
        module22.exports = prettyError;
        function prettyError(err, buf) {
          if (err.pos == null || err.line == null)
            return err;
          let msg = err.message;
          msg += ` at row ${err.line + 1}, col ${err.col + 1}, pos ${err.pos}:
`;
          if (buf && buf.split) {
            const lines = buf.split(/\n/);
            const lineNumWidth = String(Math.min(lines.length, err.line + 3)).length;
            let linePadding = " ";
            while (linePadding.length < lineNumWidth)
              linePadding += " ";
            for (let ii = Math.max(0, err.line - 1); ii < Math.min(lines.length, err.line + 2); ++ii) {
              let lineNum = String(ii + 1);
              if (lineNum.length < lineNumWidth)
                lineNum = " " + lineNum;
              if (err.line === ii) {
                msg += lineNum + "> " + lines[ii] + "\n";
                msg += linePadding + "  ";
                for (let hh = 0; hh < err.col; ++hh) {
                  msg += " ";
                }
                msg += "^\n";
              } else {
                msg += lineNum + ": " + lines[ii] + "\n";
              }
            }
          }
          err.message = msg + "\n";
          return err;
        }
      }
    });
    var require_parse_string2 = __commonJS22({
      "node_modules/@iarna/toml/parse-string.js"(exports2, module22) {
        "use strict";
        module22.exports = parseString;
        var TOMLParser = require_toml_parser();
        var prettyError = require_parse_pretty_error();
        function parseString(str) {
          if (global.Buffer && global.Buffer.isBuffer(str)) {
            str = str.toString("utf8");
          }
          const parser = new TOMLParser();
          try {
            parser.parse(str);
            return parser.finish();
          } catch (err) {
            throw prettyError(err, str);
          }
        }
      }
    });
    var require_load_toml = __commonJS22({
      "src/utils/load-toml.js"(exports2, module22) {
        "use strict";
        var parse3 = require_parse_string2();
        module22.exports = function(filePath, content) {
          try {
            return parse3(content);
          } catch (error) {
            error.message = `TOML Error in ${filePath}:
${error.message}`;
            throw error;
          }
        };
      }
    });
    var require_unicode4 = __commonJS22({
      "node_modules/json5/lib/unicode.js"(exports2, module22) {
        module22.exports.Space_Separator = /[\u1680\u2000-\u200A\u202F\u205F\u3000]/;
        module22.exports.ID_Start = /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]/;
        module22.exports.ID_Continue = /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u09FC\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9-\u0AFF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D00-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF9\u1D00-\u1DF9\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDE00-\uDE3E\uDE47\uDE50-\uDE83\uDE86-\uDE99\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD36\uDD3A\uDD3C\uDD3D\uDD3F-\uDD47\uDD50-\uDD59]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/;
      }
    });
    var require_util22 = __commonJS22({
      "node_modules/json5/lib/util.js"(exports2, module22) {
        var unicode = require_unicode4();
        module22.exports = {
          isSpaceSeparator(c) {
            return typeof c === "string" && unicode.Space_Separator.test(c);
          },
          isIdStartChar(c) {
            return typeof c === "string" && (c >= "a" && c <= "z" || c >= "A" && c <= "Z" || c === "$" || c === "_" || unicode.ID_Start.test(c));
          },
          isIdContinueChar(c) {
            return typeof c === "string" && (c >= "a" && c <= "z" || c >= "A" && c <= "Z" || c >= "0" && c <= "9" || c === "$" || c === "_" || c === "\u200C" || c === "\u200D" || unicode.ID_Continue.test(c));
          },
          isDigit(c) {
            return typeof c === "string" && /[0-9]/.test(c);
          },
          isHexDigit(c) {
            return typeof c === "string" && /[0-9A-Fa-f]/.test(c);
          }
        };
      }
    });
    var require_parse32 = __commonJS22({
      "node_modules/json5/lib/parse.js"(exports2, module22) {
        var util = require_util22();
        var source;
        var parseState;
        var stack;
        var pos;
        var line;
        var column;
        var token;
        var key;
        var root2;
        module22.exports = function parse3(text, reviver) {
          source = String(text);
          parseState = "start";
          stack = [];
          pos = 0;
          line = 1;
          column = 0;
          token = void 0;
          key = void 0;
          root2 = void 0;
          do {
            token = lex();
            parseStates[parseState]();
          } while (token.type !== "eof");
          if (typeof reviver === "function") {
            return internalize({
              "": root2
            }, "", reviver);
          }
          return root2;
        };
        function internalize(holder, name, reviver) {
          const value2 = holder[name];
          if (value2 != null && typeof value2 === "object") {
            if (Array.isArray(value2)) {
              for (let i = 0; i < value2.length; i++) {
                const key2 = String(i);
                const replacement = internalize(value2, key2, reviver);
                if (replacement === void 0) {
                  delete value2[key2];
                } else {
                  Object.defineProperty(value2, key2, {
                    value: replacement,
                    writable: true,
                    enumerable: true,
                    configurable: true
                  });
                }
              }
            } else {
              for (const key2 in value2) {
                const replacement = internalize(value2, key2, reviver);
                if (replacement === void 0) {
                  delete value2[key2];
                } else {
                  Object.defineProperty(value2, key2, {
                    value: replacement,
                    writable: true,
                    enumerable: true,
                    configurable: true
                  });
                }
              }
            }
          }
          return reviver.call(holder, name, value2);
        }
        var lexState;
        var buffer;
        var doubleQuote;
        var sign;
        var c;
        function lex() {
          lexState = "default";
          buffer = "";
          doubleQuote = false;
          sign = 1;
          for (; ; ) {
            c = peek();
            const token2 = lexStates[lexState]();
            if (token2) {
              return token2;
            }
          }
        }
        function peek() {
          if (source[pos]) {
            return String.fromCodePoint(source.codePointAt(pos));
          }
        }
        function read() {
          const c2 = peek();
          if (c2 === "\n") {
            line++;
            column = 0;
          } else if (c2) {
            column += c2.length;
          } else {
            column++;
          }
          if (c2) {
            pos += c2.length;
          }
          return c2;
        }
        var lexStates = {
          default() {
            switch (c) {
              case "	":
              case "\v":
              case "\f":
              case " ":
              case "\xA0":
              case "\uFEFF":
              case "\n":
              case "\r":
              case "\u2028":
              case "\u2029":
                read();
                return;
              case "/":
                read();
                lexState = "comment";
                return;
              case void 0:
                read();
                return newToken("eof");
            }
            if (util.isSpaceSeparator(c)) {
              read();
              return;
            }
            return lexStates[parseState]();
          },
          comment() {
            switch (c) {
              case "*":
                read();
                lexState = "multiLineComment";
                return;
              case "/":
                read();
                lexState = "singleLineComment";
                return;
            }
            throw invalidChar(read());
          },
          multiLineComment() {
            switch (c) {
              case "*":
                read();
                lexState = "multiLineCommentAsterisk";
                return;
              case void 0:
                throw invalidChar(read());
            }
            read();
          },
          multiLineCommentAsterisk() {
            switch (c) {
              case "*":
                read();
                return;
              case "/":
                read();
                lexState = "default";
                return;
              case void 0:
                throw invalidChar(read());
            }
            read();
            lexState = "multiLineComment";
          },
          singleLineComment() {
            switch (c) {
              case "\n":
              case "\r":
              case "\u2028":
              case "\u2029":
                read();
                lexState = "default";
                return;
              case void 0:
                read();
                return newToken("eof");
            }
            read();
          },
          value() {
            switch (c) {
              case "{":
              case "[":
                return newToken("punctuator", read());
              case "n":
                read();
                literal("ull");
                return newToken("null", null);
              case "t":
                read();
                literal("rue");
                return newToken("boolean", true);
              case "f":
                read();
                literal("alse");
                return newToken("boolean", false);
              case "-":
              case "+":
                if (read() === "-") {
                  sign = -1;
                }
                lexState = "sign";
                return;
              case ".":
                buffer = read();
                lexState = "decimalPointLeading";
                return;
              case "0":
                buffer = read();
                lexState = "zero";
                return;
              case "1":
              case "2":
              case "3":
              case "4":
              case "5":
              case "6":
              case "7":
              case "8":
              case "9":
                buffer = read();
                lexState = "decimalInteger";
                return;
              case "I":
                read();
                literal("nfinity");
                return newToken("numeric", Infinity);
              case "N":
                read();
                literal("aN");
                return newToken("numeric", NaN);
              case '"':
              case "'":
                doubleQuote = read() === '"';
                buffer = "";
                lexState = "string";
                return;
            }
            throw invalidChar(read());
          },
          identifierNameStartEscape() {
            if (c !== "u") {
              throw invalidChar(read());
            }
            read();
            const u = unicodeEscape();
            switch (u) {
              case "$":
              case "_":
                break;
              default:
                if (!util.isIdStartChar(u)) {
                  throw invalidIdentifier();
                }
                break;
            }
            buffer += u;
            lexState = "identifierName";
          },
          identifierName() {
            switch (c) {
              case "$":
              case "_":
              case "\u200C":
              case "\u200D":
                buffer += read();
                return;
              case "\\":
                read();
                lexState = "identifierNameEscape";
                return;
            }
            if (util.isIdContinueChar(c)) {
              buffer += read();
              return;
            }
            return newToken("identifier", buffer);
          },
          identifierNameEscape() {
            if (c !== "u") {
              throw invalidChar(read());
            }
            read();
            const u = unicodeEscape();
            switch (u) {
              case "$":
              case "_":
              case "\u200C":
              case "\u200D":
                break;
              default:
                if (!util.isIdContinueChar(u)) {
                  throw invalidIdentifier();
                }
                break;
            }
            buffer += u;
            lexState = "identifierName";
          },
          sign() {
            switch (c) {
              case ".":
                buffer = read();
                lexState = "decimalPointLeading";
                return;
              case "0":
                buffer = read();
                lexState = "zero";
                return;
              case "1":
              case "2":
              case "3":
              case "4":
              case "5":
              case "6":
              case "7":
              case "8":
              case "9":
                buffer = read();
                lexState = "decimalInteger";
                return;
              case "I":
                read();
                literal("nfinity");
                return newToken("numeric", sign * Infinity);
              case "N":
                read();
                literal("aN");
                return newToken("numeric", NaN);
            }
            throw invalidChar(read());
          },
          zero() {
            switch (c) {
              case ".":
                buffer += read();
                lexState = "decimalPoint";
                return;
              case "e":
              case "E":
                buffer += read();
                lexState = "decimalExponent";
                return;
              case "x":
              case "X":
                buffer += read();
                lexState = "hexadecimal";
                return;
            }
            return newToken("numeric", sign * 0);
          },
          decimalInteger() {
            switch (c) {
              case ".":
                buffer += read();
                lexState = "decimalPoint";
                return;
              case "e":
              case "E":
                buffer += read();
                lexState = "decimalExponent";
                return;
            }
            if (util.isDigit(c)) {
              buffer += read();
              return;
            }
            return newToken("numeric", sign * Number(buffer));
          },
          decimalPointLeading() {
            if (util.isDigit(c)) {
              buffer += read();
              lexState = "decimalFraction";
              return;
            }
            throw invalidChar(read());
          },
          decimalPoint() {
            switch (c) {
              case "e":
              case "E":
                buffer += read();
                lexState = "decimalExponent";
                return;
            }
            if (util.isDigit(c)) {
              buffer += read();
              lexState = "decimalFraction";
              return;
            }
            return newToken("numeric", sign * Number(buffer));
          },
          decimalFraction() {
            switch (c) {
              case "e":
              case "E":
                buffer += read();
                lexState = "decimalExponent";
                return;
            }
            if (util.isDigit(c)) {
              buffer += read();
              return;
            }
            return newToken("numeric", sign * Number(buffer));
          },
          decimalExponent() {
            switch (c) {
              case "+":
              case "-":
                buffer += read();
                lexState = "decimalExponentSign";
                return;
            }
            if (util.isDigit(c)) {
              buffer += read();
              lexState = "decimalExponentInteger";
              return;
            }
            throw invalidChar(read());
          },
          decimalExponentSign() {
            if (util.isDigit(c)) {
              buffer += read();
              lexState = "decimalExponentInteger";
              return;
            }
            throw invalidChar(read());
          },
          decimalExponentInteger() {
            if (util.isDigit(c)) {
              buffer += read();
              return;
            }
            return newToken("numeric", sign * Number(buffer));
          },
          hexadecimal() {
            if (util.isHexDigit(c)) {
              buffer += read();
              lexState = "hexadecimalInteger";
              return;
            }
            throw invalidChar(read());
          },
          hexadecimalInteger() {
            if (util.isHexDigit(c)) {
              buffer += read();
              return;
            }
            return newToken("numeric", sign * Number(buffer));
          },
          string() {
            switch (c) {
              case "\\":
                read();
                buffer += escape2();
                return;
              case '"':
                if (doubleQuote) {
                  read();
                  return newToken("string", buffer);
                }
                buffer += read();
                return;
              case "'":
                if (!doubleQuote) {
                  read();
                  return newToken("string", buffer);
                }
                buffer += read();
                return;
              case "\n":
              case "\r":
                throw invalidChar(read());
              case "\u2028":
              case "\u2029":
                separatorChar(c);
                break;
              case void 0:
                throw invalidChar(read());
            }
            buffer += read();
          },
          start() {
            switch (c) {
              case "{":
              case "[":
                return newToken("punctuator", read());
            }
            lexState = "value";
          },
          beforePropertyName() {
            switch (c) {
              case "$":
              case "_":
                buffer = read();
                lexState = "identifierName";
                return;
              case "\\":
                read();
                lexState = "identifierNameStartEscape";
                return;
              case "}":
                return newToken("punctuator", read());
              case '"':
              case "'":
                doubleQuote = read() === '"';
                lexState = "string";
                return;
            }
            if (util.isIdStartChar(c)) {
              buffer += read();
              lexState = "identifierName";
              return;
            }
            throw invalidChar(read());
          },
          afterPropertyName() {
            if (c === ":") {
              return newToken("punctuator", read());
            }
            throw invalidChar(read());
          },
          beforePropertyValue() {
            lexState = "value";
          },
          afterPropertyValue() {
            switch (c) {
              case ",":
              case "}":
                return newToken("punctuator", read());
            }
            throw invalidChar(read());
          },
          beforeArrayValue() {
            if (c === "]") {
              return newToken("punctuator", read());
            }
            lexState = "value";
          },
          afterArrayValue() {
            switch (c) {
              case ",":
              case "]":
                return newToken("punctuator", read());
            }
            throw invalidChar(read());
          },
          end() {
            throw invalidChar(read());
          }
        };
        function newToken(type, value2) {
          return {
            type,
            value: value2,
            line,
            column
          };
        }
        function literal(s) {
          for (const c2 of s) {
            const p = peek();
            if (p !== c2) {
              throw invalidChar(read());
            }
            read();
          }
        }
        function escape2() {
          const c2 = peek();
          switch (c2) {
            case "b":
              read();
              return "\b";
            case "f":
              read();
              return "\f";
            case "n":
              read();
              return "\n";
            case "r":
              read();
              return "\r";
            case "t":
              read();
              return "	";
            case "v":
              read();
              return "\v";
            case "0":
              read();
              if (util.isDigit(peek())) {
                throw invalidChar(read());
              }
              return "\0";
            case "x":
              read();
              return hexEscape();
            case "u":
              read();
              return unicodeEscape();
            case "\n":
            case "\u2028":
            case "\u2029":
              read();
              return "";
            case "\r":
              read();
              if (peek() === "\n") {
                read();
              }
              return "";
            case "1":
            case "2":
            case "3":
            case "4":
            case "5":
            case "6":
            case "7":
            case "8":
            case "9":
              throw invalidChar(read());
            case void 0:
              throw invalidChar(read());
          }
          return read();
        }
        function hexEscape() {
          let buffer2 = "";
          let c2 = peek();
          if (!util.isHexDigit(c2)) {
            throw invalidChar(read());
          }
          buffer2 += read();
          c2 = peek();
          if (!util.isHexDigit(c2)) {
            throw invalidChar(read());
          }
          buffer2 += read();
          return String.fromCodePoint(parseInt(buffer2, 16));
        }
        function unicodeEscape() {
          let buffer2 = "";
          let count = 4;
          while (count-- > 0) {
            const c2 = peek();
            if (!util.isHexDigit(c2)) {
              throw invalidChar(read());
            }
            buffer2 += read();
          }
          return String.fromCodePoint(parseInt(buffer2, 16));
        }
        var parseStates = {
          start() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            push();
          },
          beforePropertyName() {
            switch (token.type) {
              case "identifier":
              case "string":
                key = token.value;
                parseState = "afterPropertyName";
                return;
              case "punctuator":
                pop();
                return;
              case "eof":
                throw invalidEOF();
            }
          },
          afterPropertyName() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            parseState = "beforePropertyValue";
          },
          beforePropertyValue() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            push();
          },
          beforeArrayValue() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            if (token.type === "punctuator" && token.value === "]") {
              pop();
              return;
            }
            push();
          },
          afterPropertyValue() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            switch (token.value) {
              case ",":
                parseState = "beforePropertyName";
                return;
              case "}":
                pop();
            }
          },
          afterArrayValue() {
            if (token.type === "eof") {
              throw invalidEOF();
            }
            switch (token.value) {
              case ",":
                parseState = "beforeArrayValue";
                return;
              case "]":
                pop();
            }
          },
          end() {
          }
        };
        function push() {
          let value2;
          switch (token.type) {
            case "punctuator":
              switch (token.value) {
                case "{":
                  value2 = {};
                  break;
                case "[":
                  value2 = [];
                  break;
              }
              break;
            case "null":
            case "boolean":
            case "numeric":
            case "string":
              value2 = token.value;
              break;
          }
          if (root2 === void 0) {
            root2 = value2;
          } else {
            const parent = stack[stack.length - 1];
            if (Array.isArray(parent)) {
              parent.push(value2);
            } else {
              Object.defineProperty(parent, key, {
                value: value2,
                writable: true,
                enumerable: true,
                configurable: true
              });
            }
          }
          if (value2 !== null && typeof value2 === "object") {
            stack.push(value2);
            if (Array.isArray(value2)) {
              parseState = "beforeArrayValue";
            } else {
              parseState = "beforePropertyName";
            }
          } else {
            const current = stack[stack.length - 1];
            if (current == null) {
              parseState = "end";
            } else if (Array.isArray(current)) {
              parseState = "afterArrayValue";
            } else {
              parseState = "afterPropertyValue";
            }
          }
        }
        function pop() {
          stack.pop();
          const current = stack[stack.length - 1];
          if (current == null) {
            parseState = "end";
          } else if (Array.isArray(current)) {
            parseState = "afterArrayValue";
          } else {
            parseState = "afterPropertyValue";
          }
        }
        function invalidChar(c2) {
          if (c2 === void 0) {
            return syntaxError(`JSON5: invalid end of input at ${line}:${column}`);
          }
          return syntaxError(`JSON5: invalid character '${formatChar(c2)}' at ${line}:${column}`);
        }
        function invalidEOF() {
          return syntaxError(`JSON5: invalid end of input at ${line}:${column}`);
        }
        function invalidIdentifier() {
          column -= 5;
          return syntaxError(`JSON5: invalid identifier character at ${line}:${column}`);
        }
        function separatorChar(c2) {
          console.warn(`JSON5: '${formatChar(c2)}' in strings is not valid ECMAScript; consider escaping`);
        }
        function formatChar(c2) {
          const replacements = {
            "'": "\\'",
            '"': '\\"',
            "\\": "\\\\",
            "\b": "\\b",
            "\f": "\\f",
            "\n": "\\n",
            "\r": "\\r",
            "	": "\\t",
            "\v": "\\v",
            "\0": "\\0",
            "\u2028": "\\u2028",
            "\u2029": "\\u2029"
          };
          if (replacements[c2]) {
            return replacements[c2];
          }
          if (c2 < " ") {
            const hexString = c2.charCodeAt(0).toString(16);
            return "\\x" + ("00" + hexString).substring(hexString.length);
          }
          return c2;
        }
        function syntaxError(message) {
          const err = new SyntaxError(message);
          err.lineNumber = line;
          err.columnNumber = column;
          return err;
        }
      }
    });
    var require_stringify22 = __commonJS22({
      "node_modules/json5/lib/stringify.js"(exports2, module22) {
        var util = require_util22();
        module22.exports = function stringify(value2, replacer, space) {
          const stack = [];
          let indent = "";
          let propertyList;
          let replacerFunc;
          let gap = "";
          let quote;
          if (replacer != null && typeof replacer === "object" && !Array.isArray(replacer)) {
            space = replacer.space;
            quote = replacer.quote;
            replacer = replacer.replacer;
          }
          if (typeof replacer === "function") {
            replacerFunc = replacer;
          } else if (Array.isArray(replacer)) {
            propertyList = [];
            for (const v of replacer) {
              let item;
              if (typeof v === "string") {
                item = v;
              } else if (typeof v === "number" || v instanceof String || v instanceof Number) {
                item = String(v);
              }
              if (item !== void 0 && propertyList.indexOf(item) < 0) {
                propertyList.push(item);
              }
            }
          }
          if (space instanceof Number) {
            space = Number(space);
          } else if (space instanceof String) {
            space = String(space);
          }
          if (typeof space === "number") {
            if (space > 0) {
              space = Math.min(10, Math.floor(space));
              gap = "          ".substr(0, space);
            }
          } else if (typeof space === "string") {
            gap = space.substr(0, 10);
          }
          return serializeProperty("", {
            "": value2
          });
          function serializeProperty(key, holder) {
            let value22 = holder[key];
            if (value22 != null) {
              if (typeof value22.toJSON5 === "function") {
                value22 = value22.toJSON5(key);
              } else if (typeof value22.toJSON === "function") {
                value22 = value22.toJSON(key);
              }
            }
            if (replacerFunc) {
              value22 = replacerFunc.call(holder, key, value22);
            }
            if (value22 instanceof Number) {
              value22 = Number(value22);
            } else if (value22 instanceof String) {
              value22 = String(value22);
            } else if (value22 instanceof Boolean) {
              value22 = value22.valueOf();
            }
            switch (value22) {
              case null:
                return "null";
              case true:
                return "true";
              case false:
                return "false";
            }
            if (typeof value22 === "string") {
              return quoteString(value22, false);
            }
            if (typeof value22 === "number") {
              return String(value22);
            }
            if (typeof value22 === "object") {
              return Array.isArray(value22) ? serializeArray(value22) : serializeObject(value22);
            }
            return void 0;
          }
          function quoteString(value22) {
            const quotes = {
              "'": 0.1,
              '"': 0.2
            };
            const replacements = {
              "'": "\\'",
              '"': '\\"',
              "\\": "\\\\",
              "\b": "\\b",
              "\f": "\\f",
              "\n": "\\n",
              "\r": "\\r",
              "	": "\\t",
              "\v": "\\v",
              "\0": "\\0",
              "\u2028": "\\u2028",
              "\u2029": "\\u2029"
            };
            let product = "";
            for (let i = 0; i < value22.length; i++) {
              const c = value22[i];
              switch (c) {
                case "'":
                case '"':
                  quotes[c]++;
                  product += c;
                  continue;
                case "\0":
                  if (util.isDigit(value22[i + 1])) {
                    product += "\\x00";
                    continue;
                  }
              }
              if (replacements[c]) {
                product += replacements[c];
                continue;
              }
              if (c < " ") {
                let hexString = c.charCodeAt(0).toString(16);
                product += "\\x" + ("00" + hexString).substring(hexString.length);
                continue;
              }
              product += c;
            }
            const quoteChar = quote || Object.keys(quotes).reduce((a, b) => quotes[a] < quotes[b] ? a : b);
            product = product.replace(new RegExp(quoteChar, "g"), replacements[quoteChar]);
            return quoteChar + product + quoteChar;
          }
          function serializeObject(value22) {
            if (stack.indexOf(value22) >= 0) {
              throw TypeError("Converting circular structure to JSON5");
            }
            stack.push(value22);
            let stepback = indent;
            indent = indent + gap;
            let keys3 = propertyList || Object.keys(value22);
            let partial = [];
            for (const key of keys3) {
              const propertyString = serializeProperty(key, value22);
              if (propertyString !== void 0) {
                let member = serializeKey(key) + ":";
                if (gap !== "") {
                  member += " ";
                }
                member += propertyString;
                partial.push(member);
              }
            }
            let final;
            if (partial.length === 0) {
              final = "{}";
            } else {
              let properties;
              if (gap === "") {
                properties = partial.join(",");
                final = "{" + properties + "}";
              } else {
                let separator = ",\n" + indent;
                properties = partial.join(separator);
                final = "{\n" + indent + properties + ",\n" + stepback + "}";
              }
            }
            stack.pop();
            indent = stepback;
            return final;
          }
          function serializeKey(key) {
            if (key.length === 0) {
              return quoteString(key, true);
            }
            const firstChar = String.fromCodePoint(key.codePointAt(0));
            if (!util.isIdStartChar(firstChar)) {
              return quoteString(key, true);
            }
            for (let i = firstChar.length; i < key.length; i++) {
              if (!util.isIdContinueChar(String.fromCodePoint(key.codePointAt(i)))) {
                return quoteString(key, true);
              }
            }
            return key;
          }
          function serializeArray(value22) {
            if (stack.indexOf(value22) >= 0) {
              throw TypeError("Converting circular structure to JSON5");
            }
            stack.push(value22);
            let stepback = indent;
            indent = indent + gap;
            let partial = [];
            for (let i = 0; i < value22.length; i++) {
              const propertyString = serializeProperty(String(i), value22);
              partial.push(propertyString !== void 0 ? propertyString : "null");
            }
            let final;
            if (partial.length === 0) {
              final = "[]";
            } else {
              if (gap === "") {
                let properties = partial.join(",");
                final = "[" + properties + "]";
              } else {
                let separator = ",\n" + indent;
                let properties = partial.join(separator);
                final = "[\n" + indent + properties + ",\n" + stepback + "]";
              }
            }
            stack.pop();
            indent = stepback;
            return final;
          }
        };
      }
    });
    var require_lib62 = __commonJS22({
      "node_modules/json5/lib/index.js"(exports2, module22) {
        var parse3 = require_parse32();
        var stringify = require_stringify22();
        var JSON5 = {
          parse: parse3,
          stringify
        };
        module22.exports = JSON5;
      }
    });
    var require_load_json5 = __commonJS22({
      "src/utils/load-json5.js"(exports2, module22) {
        "use strict";
        var {
          parse: parse3
        } = require_lib62();
        module22.exports = function(filePath, content) {
          try {
            return parse3(content);
          } catch (error) {
            error.message = `JSON5 Error in ${filePath}:
${error.message}`;
            throw error;
          }
        };
      }
    });
    var require_partition3 = __commonJS22({
      "src/utils/partition.js"(exports2, module22) {
        "use strict";
        function partition(array, predicate) {
          const result = [[], []];
          for (const value2 of array) {
            result[predicate(value2) ? 0 : 1].push(value2);
          }
          return result;
        }
        module22.exports = partition;
      }
    });
    var require_homedir = __commonJS22({
      "node_modules/resolve/lib/homedir.js"(exports2, module22) {
        "use strict";
        var os = require("os");
        module22.exports = os.homedir || function homedir() {
          var home = process.env.HOME;
          var user = process.env.LOGNAME || process.env.USER || process.env.LNAME || process.env.USERNAME;
          if (process.platform === "win32") {
            return process.env.USERPROFILE || process.env.HOMEDRIVE + process.env.HOMEPATH || home || null;
          }
          if (process.platform === "darwin") {
            return home || (user ? "/Users/" + user : null);
          }
          if (process.platform === "linux") {
            return home || (process.getuid() === 0 ? "/root" : user ? "/home/" + user : null);
          }
          return home || null;
        };
      }
    });
    var require_caller = __commonJS22({
      "node_modules/resolve/lib/caller.js"(exports2, module22) {
        module22.exports = function() {
          var origPrepareStackTrace = Error.prepareStackTrace;
          Error.prepareStackTrace = function(_, stack2) {
            return stack2;
          };
          var stack = new Error().stack;
          Error.prepareStackTrace = origPrepareStackTrace;
          return stack[2].getFileName();
        };
      }
    });
    var require_path_parse = __commonJS22({
      "node_modules/path-parse/index.js"(exports2, module22) {
        "use strict";
        var isWindows = process.platform === "win32";
        var splitWindowsRe = /^(((?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?[\\\/]?)(?:[^\\\/]*[\\\/])*)((\.{1,2}|[^\\\/]+?|)(\.[^.\/\\]*|))[\\\/]*$/;
        var win32 = {};
        function win32SplitPath(filename) {
          return splitWindowsRe.exec(filename).slice(1);
        }
        win32.parse = function(pathString) {
          if (typeof pathString !== "string") {
            throw new TypeError("Parameter 'pathString' must be a string, not " + typeof pathString);
          }
          var allParts = win32SplitPath(pathString);
          if (!allParts || allParts.length !== 5) {
            throw new TypeError("Invalid path '" + pathString + "'");
          }
          return {
            root: allParts[1],
            dir: allParts[0] === allParts[1] ? allParts[0] : allParts[0].slice(0, -1),
            base: allParts[2],
            ext: allParts[4],
            name: allParts[3]
          };
        };
        var splitPathRe = /^((\/?)(?:[^\/]*\/)*)((\.{1,2}|[^\/]+?|)(\.[^.\/]*|))[\/]*$/;
        var posix = {};
        function posixSplitPath(filename) {
          return splitPathRe.exec(filename).slice(1);
        }
        posix.parse = function(pathString) {
          if (typeof pathString !== "string") {
            throw new TypeError("Parameter 'pathString' must be a string, not " + typeof pathString);
          }
          var allParts = posixSplitPath(pathString);
          if (!allParts || allParts.length !== 5) {
            throw new TypeError("Invalid path '" + pathString + "'");
          }
          return {
            root: allParts[1],
            dir: allParts[0].slice(0, -1),
            base: allParts[2],
            ext: allParts[4],
            name: allParts[3]
          };
        };
        if (isWindows)
          module22.exports = win32.parse;
        else
          module22.exports = posix.parse;
        module22.exports.posix = posix.parse;
        module22.exports.win32 = win32.parse;
      }
    });
    var require_node_modules_paths = __commonJS22({
      "node_modules/resolve/lib/node-modules-paths.js"(exports2, module22) {
        var path2 = require("path");
        var parse3 = path2.parse || require_path_parse();
        var getNodeModulesDirs = function getNodeModulesDirs2(absoluteStart, modules) {
          var prefix = "/";
          if (/^([A-Za-z]:)/.test(absoluteStart)) {
            prefix = "";
          } else if (/^\\\\/.test(absoluteStart)) {
            prefix = "\\\\";
          }
          var paths = [absoluteStart];
          var parsed = parse3(absoluteStart);
          while (parsed.dir !== paths[paths.length - 1]) {
            paths.push(parsed.dir);
            parsed = parse3(parsed.dir);
          }
          return paths.reduce(function(dirs, aPath) {
            return dirs.concat(modules.map(function(moduleDir) {
              return path2.resolve(prefix, aPath, moduleDir);
            }));
          }, []);
        };
        module22.exports = function nodeModulesPaths(start, opts, request) {
          var modules = opts && opts.moduleDirectory ? [].concat(opts.moduleDirectory) : ["node_modules"];
          if (opts && typeof opts.paths === "function") {
            return opts.paths(request, start, function() {
              return getNodeModulesDirs(start, modules);
            }, opts);
          }
          var dirs = getNodeModulesDirs(start, modules);
          return opts && opts.paths ? dirs.concat(opts.paths) : dirs;
        };
      }
    });
    var require_normalize_options = __commonJS22({
      "node_modules/resolve/lib/normalize-options.js"(exports2, module22) {
        module22.exports = function(x, opts) {
          return opts || {};
        };
      }
    });
    var require_implementation = __commonJS22({
      "node_modules/function-bind/implementation.js"(exports2, module22) {
        "use strict";
        var ERROR_MESSAGE = "Function.prototype.bind called on incompatible ";
        var slice = Array.prototype.slice;
        var toStr = Object.prototype.toString;
        var funcType = "[object Function]";
        module22.exports = function bind(that) {
          var target = this;
          if (typeof target !== "function" || toStr.call(target) !== funcType) {
            throw new TypeError(ERROR_MESSAGE + target);
          }
          var args = slice.call(arguments, 1);
          var bound;
          var binder = function() {
            if (this instanceof bound) {
              var result = target.apply(this, args.concat(slice.call(arguments)));
              if (Object(result) === result) {
                return result;
              }
              return this;
            } else {
              return target.apply(that, args.concat(slice.call(arguments)));
            }
          };
          var boundLength = Math.max(0, target.length - args.length);
          var boundArgs = [];
          for (var i = 0; i < boundLength; i++) {
            boundArgs.push("$" + i);
          }
          bound = Function("binder", "return function (" + boundArgs.join(",") + "){ return binder.apply(this,arguments); }")(binder);
          if (target.prototype) {
            var Empty = function Empty2() {
            };
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            Empty.prototype = null;
          }
          return bound;
        };
      }
    });
    var require_function_bind = __commonJS22({
      "node_modules/function-bind/index.js"(exports2, module22) {
        "use strict";
        var implementation = require_implementation();
        module22.exports = Function.prototype.bind || implementation;
      }
    });
    var require_src3 = __commonJS22({
      "node_modules/has/src/index.js"(exports2, module22) {
        "use strict";
        var bind = require_function_bind();
        module22.exports = bind.call(Function.call, Object.prototype.hasOwnProperty);
      }
    });
    var require_core22 = __commonJS22({
      "node_modules/is-core-module/core.json"(exports2, module22) {
        module22.exports = {
          assert: true,
          "node:assert": [">= 14.18 && < 15", ">= 16"],
          "assert/strict": ">= 15",
          "node:assert/strict": ">= 16",
          async_hooks: ">= 8",
          "node:async_hooks": [">= 14.18 && < 15", ">= 16"],
          buffer_ieee754: ">= 0.5 && < 0.9.7",
          buffer: true,
          "node:buffer": [">= 14.18 && < 15", ">= 16"],
          child_process: true,
          "node:child_process": [">= 14.18 && < 15", ">= 16"],
          cluster: ">= 0.5",
          "node:cluster": [">= 14.18 && < 15", ">= 16"],
          console: true,
          "node:console": [">= 14.18 && < 15", ">= 16"],
          constants: true,
          "node:constants": [">= 14.18 && < 15", ">= 16"],
          crypto: true,
          "node:crypto": [">= 14.18 && < 15", ">= 16"],
          _debug_agent: ">= 1 && < 8",
          _debugger: "< 8",
          dgram: true,
          "node:dgram": [">= 14.18 && < 15", ">= 16"],
          diagnostics_channel: [">= 14.17 && < 15", ">= 15.1"],
          "node:diagnostics_channel": [">= 14.18 && < 15", ">= 16"],
          dns: true,
          "node:dns": [">= 14.18 && < 15", ">= 16"],
          "dns/promises": ">= 15",
          "node:dns/promises": ">= 16",
          domain: ">= 0.7.12",
          "node:domain": [">= 14.18 && < 15", ">= 16"],
          events: true,
          "node:events": [">= 14.18 && < 15", ">= 16"],
          freelist: "< 6",
          fs: true,
          "node:fs": [">= 14.18 && < 15", ">= 16"],
          "fs/promises": [">= 10 && < 10.1", ">= 14"],
          "node:fs/promises": [">= 14.18 && < 15", ">= 16"],
          _http_agent: ">= 0.11.1",
          "node:_http_agent": [">= 14.18 && < 15", ">= 16"],
          _http_client: ">= 0.11.1",
          "node:_http_client": [">= 14.18 && < 15", ">= 16"],
          _http_common: ">= 0.11.1",
          "node:_http_common": [">= 14.18 && < 15", ">= 16"],
          _http_incoming: ">= 0.11.1",
          "node:_http_incoming": [">= 14.18 && < 15", ">= 16"],
          _http_outgoing: ">= 0.11.1",
          "node:_http_outgoing": [">= 14.18 && < 15", ">= 16"],
          _http_server: ">= 0.11.1",
          "node:_http_server": [">= 14.18 && < 15", ">= 16"],
          http: true,
          "node:http": [">= 14.18 && < 15", ">= 16"],
          http2: ">= 8.8",
          "node:http2": [">= 14.18 && < 15", ">= 16"],
          https: true,
          "node:https": [">= 14.18 && < 15", ">= 16"],
          inspector: ">= 8",
          "node:inspector": [">= 14.18 && < 15", ">= 16"],
          "inspector/promises": [">= 19"],
          "node:inspector/promises": [">= 19"],
          _linklist: "< 8",
          module: true,
          "node:module": [">= 14.18 && < 15", ">= 16"],
          net: true,
          "node:net": [">= 14.18 && < 15", ">= 16"],
          "node-inspect/lib/_inspect": ">= 7.6 && < 12",
          "node-inspect/lib/internal/inspect_client": ">= 7.6 && < 12",
          "node-inspect/lib/internal/inspect_repl": ">= 7.6 && < 12",
          os: true,
          "node:os": [">= 14.18 && < 15", ">= 16"],
          path: true,
          "node:path": [">= 14.18 && < 15", ">= 16"],
          "path/posix": ">= 15.3",
          "node:path/posix": ">= 16",
          "path/win32": ">= 15.3",
          "node:path/win32": ">= 16",
          perf_hooks: ">= 8.5",
          "node:perf_hooks": [">= 14.18 && < 15", ">= 16"],
          process: ">= 1",
          "node:process": [">= 14.18 && < 15", ">= 16"],
          punycode: ">= 0.5",
          "node:punycode": [">= 14.18 && < 15", ">= 16"],
          querystring: true,
          "node:querystring": [">= 14.18 && < 15", ">= 16"],
          readline: true,
          "node:readline": [">= 14.18 && < 15", ">= 16"],
          "readline/promises": ">= 17",
          "node:readline/promises": ">= 17",
          repl: true,
          "node:repl": [">= 14.18 && < 15", ">= 16"],
          smalloc: ">= 0.11.5 && < 3",
          _stream_duplex: ">= 0.9.4",
          "node:_stream_duplex": [">= 14.18 && < 15", ">= 16"],
          _stream_transform: ">= 0.9.4",
          "node:_stream_transform": [">= 14.18 && < 15", ">= 16"],
          _stream_wrap: ">= 1.4.1",
          "node:_stream_wrap": [">= 14.18 && < 15", ">= 16"],
          _stream_passthrough: ">= 0.9.4",
          "node:_stream_passthrough": [">= 14.18 && < 15", ">= 16"],
          _stream_readable: ">= 0.9.4",
          "node:_stream_readable": [">= 14.18 && < 15", ">= 16"],
          _stream_writable: ">= 0.9.4",
          "node:_stream_writable": [">= 14.18 && < 15", ">= 16"],
          stream: true,
          "node:stream": [">= 14.18 && < 15", ">= 16"],
          "stream/consumers": ">= 16.7",
          "node:stream/consumers": ">= 16.7",
          "stream/promises": ">= 15",
          "node:stream/promises": ">= 16",
          "stream/web": ">= 16.5",
          "node:stream/web": ">= 16.5",
          string_decoder: true,
          "node:string_decoder": [">= 14.18 && < 15", ">= 16"],
          sys: [">= 0.4 && < 0.7", ">= 0.8"],
          "node:sys": [">= 14.18 && < 15", ">= 16"],
          "node:test": [">= 16.17 && < 17", ">= 18"],
          timers: true,
          "node:timers": [">= 14.18 && < 15", ">= 16"],
          "timers/promises": ">= 15",
          "node:timers/promises": ">= 16",
          _tls_common: ">= 0.11.13",
          "node:_tls_common": [">= 14.18 && < 15", ">= 16"],
          _tls_legacy: ">= 0.11.3 && < 10",
          _tls_wrap: ">= 0.11.3",
          "node:_tls_wrap": [">= 14.18 && < 15", ">= 16"],
          tls: true,
          "node:tls": [">= 14.18 && < 15", ">= 16"],
          trace_events: ">= 10",
          "node:trace_events": [">= 14.18 && < 15", ">= 16"],
          tty: true,
          "node:tty": [">= 14.18 && < 15", ">= 16"],
          url: true,
          "node:url": [">= 14.18 && < 15", ">= 16"],
          util: true,
          "node:util": [">= 14.18 && < 15", ">= 16"],
          "util/types": ">= 15.3",
          "node:util/types": ">= 16",
          "v8/tools/arguments": ">= 10 && < 12",
          "v8/tools/codemap": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/consarray": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/csvparser": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/logreader": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/profile_view": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/splaytree": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          v8: ">= 1",
          "node:v8": [">= 14.18 && < 15", ">= 16"],
          vm: true,
          "node:vm": [">= 14.18 && < 15", ">= 16"],
          wasi: ">= 13.4 && < 13.5",
          worker_threads: ">= 11.7",
          "node:worker_threads": [">= 14.18 && < 15", ">= 16"],
          zlib: ">= 0.5",
          "node:zlib": [">= 14.18 && < 15", ">= 16"]
        };
      }
    });
    var require_is_core_module = __commonJS22({
      "node_modules/is-core-module/index.js"(exports2, module22) {
        "use strict";
        var has = require_src3();
        function specifierIncluded(current, specifier) {
          var nodeParts = current.split(".");
          var parts = specifier.split(" ");
          var op = parts.length > 1 ? parts[0] : "=";
          var versionParts = (parts.length > 1 ? parts[1] : parts[0]).split(".");
          for (var i = 0; i < 3; ++i) {
            var cur = parseInt(nodeParts[i] || 0, 10);
            var ver = parseInt(versionParts[i] || 0, 10);
            if (cur === ver) {
              continue;
            }
            if (op === "<") {
              return cur < ver;
            }
            if (op === ">=") {
              return cur >= ver;
            }
            return false;
          }
          return op === ">=";
        }
        function matchesRange(current, range) {
          var specifiers = range.split(/ ?&& ?/);
          if (specifiers.length === 0) {
            return false;
          }
          for (var i = 0; i < specifiers.length; ++i) {
            if (!specifierIncluded(current, specifiers[i])) {
              return false;
            }
          }
          return true;
        }
        function versionIncluded(nodeVersion, specifierValue) {
          if (typeof specifierValue === "boolean") {
            return specifierValue;
          }
          var current = typeof nodeVersion === "undefined" ? process.versions && process.versions.node : nodeVersion;
          if (typeof current !== "string") {
            throw new TypeError(typeof nodeVersion === "undefined" ? "Unable to determine current node version" : "If provided, a valid node version is required");
          }
          if (specifierValue && typeof specifierValue === "object") {
            for (var i = 0; i < specifierValue.length; ++i) {
              if (matchesRange(current, specifierValue[i])) {
                return true;
              }
            }
            return false;
          }
          return matchesRange(current, specifierValue);
        }
        var data = require_core22();
        module22.exports = function isCore(x, nodeVersion) {
          return has(data, x) && versionIncluded(nodeVersion, data[x]);
        };
      }
    });
    var require_async8 = __commonJS22({
      "node_modules/resolve/lib/async.js"(exports2, module22) {
        var fs2 = require("fs");
        var getHomedir = require_homedir();
        var path2 = require("path");
        var caller = require_caller();
        var nodeModulesPaths = require_node_modules_paths();
        var normalizeOptions = require_normalize_options();
        var isCore = require_is_core_module();
        var realpathFS = process.platform !== "win32" && fs2.realpath && typeof fs2.realpath.native === "function" ? fs2.realpath.native : fs2.realpath;
        var homedir = getHomedir();
        var defaultPaths = function() {
          return [path2.join(homedir, ".node_modules"), path2.join(homedir, ".node_libraries")];
        };
        var defaultIsFile = function isFile2(file, cb) {
          fs2.stat(file, function(err, stat) {
            if (!err) {
              return cb(null, stat.isFile() || stat.isFIFO());
            }
            if (err.code === "ENOENT" || err.code === "ENOTDIR")
              return cb(null, false);
            return cb(err);
          });
        };
        var defaultIsDir = function isDirectory(dir, cb) {
          fs2.stat(dir, function(err, stat) {
            if (!err) {
              return cb(null, stat.isDirectory());
            }
            if (err.code === "ENOENT" || err.code === "ENOTDIR")
              return cb(null, false);
            return cb(err);
          });
        };
        var defaultRealpath = function realpath(x, cb) {
          realpathFS(x, function(realpathErr, realPath) {
            if (realpathErr && realpathErr.code !== "ENOENT")
              cb(realpathErr);
            else
              cb(null, realpathErr ? x : realPath);
          });
        };
        var maybeRealpath = function maybeRealpath2(realpath, x, opts, cb) {
          if (opts && opts.preserveSymlinks === false) {
            realpath(x, cb);
          } else {
            cb(null, x);
          }
        };
        var defaultReadPackage = function defaultReadPackage2(readFile, pkgfile, cb) {
          readFile(pkgfile, function(readFileErr, body) {
            if (readFileErr)
              cb(readFileErr);
            else {
              try {
                var pkg = JSON.parse(body);
                cb(null, pkg);
              } catch (jsonErr) {
                cb(null);
              }
            }
          });
        };
        var getPackageCandidates = function getPackageCandidates2(x, start, opts) {
          var dirs = nodeModulesPaths(start, opts, x);
          for (var i = 0; i < dirs.length; i++) {
            dirs[i] = path2.join(dirs[i], x);
          }
          return dirs;
        };
        module22.exports = function resolve(x, options, callback) {
          var cb = callback;
          var opts = options;
          if (typeof options === "function") {
            cb = opts;
            opts = {};
          }
          if (typeof x !== "string") {
            var err = new TypeError("Path must be a string.");
            return process.nextTick(function() {
              cb(err);
            });
          }
          opts = normalizeOptions(x, opts);
          var isFile2 = opts.isFile || defaultIsFile;
          var isDirectory = opts.isDirectory || defaultIsDir;
          var readFile = opts.readFile || fs2.readFile;
          var realpath = opts.realpath || defaultRealpath;
          var readPackage = opts.readPackage || defaultReadPackage;
          if (opts.readFile && opts.readPackage) {
            var conflictErr = new TypeError("`readFile` and `readPackage` are mutually exclusive.");
            return process.nextTick(function() {
              cb(conflictErr);
            });
          }
          var packageIterator = opts.packageIterator;
          var extensions = opts.extensions || [".js"];
          var includeCoreModules = opts.includeCoreModules !== false;
          var basedir = opts.basedir || path2.dirname(caller());
          var parent = opts.filename || basedir;
          opts.paths = opts.paths || defaultPaths();
          var absoluteStart = path2.resolve(basedir);
          maybeRealpath(realpath, absoluteStart, opts, function(err2, realStart) {
            if (err2)
              cb(err2);
            else
              init(realStart);
          });
          var res;
          function init(basedir2) {
            if (/^(?:\.\.?(?:\/|$)|\/|([A-Za-z]:)?[/\\])/.test(x)) {
              res = path2.resolve(basedir2, x);
              if (x === "." || x === ".." || x.slice(-1) === "/")
                res += "/";
              if (/\/$/.test(x) && res === basedir2) {
                loadAsDirectory(res, opts.package, onfile);
              } else
                loadAsFile(res, opts.package, onfile);
            } else if (includeCoreModules && isCore(x)) {
              return cb(null, x);
            } else
              loadNodeModules(x, basedir2, function(err2, n, pkg) {
                if (err2)
                  cb(err2);
                else if (n) {
                  return maybeRealpath(realpath, n, opts, function(err3, realN) {
                    if (err3) {
                      cb(err3);
                    } else {
                      cb(null, realN, pkg);
                    }
                  });
                } else {
                  var moduleError = new Error("Cannot find module '" + x + "' from '" + parent + "'");
                  moduleError.code = "MODULE_NOT_FOUND";
                  cb(moduleError);
                }
              });
          }
          function onfile(err2, m, pkg) {
            if (err2)
              cb(err2);
            else if (m)
              cb(null, m, pkg);
            else
              loadAsDirectory(res, function(err3, d, pkg2) {
                if (err3)
                  cb(err3);
                else if (d) {
                  maybeRealpath(realpath, d, opts, function(err4, realD) {
                    if (err4) {
                      cb(err4);
                    } else {
                      cb(null, realD, pkg2);
                    }
                  });
                } else {
                  var moduleError = new Error("Cannot find module '" + x + "' from '" + parent + "'");
                  moduleError.code = "MODULE_NOT_FOUND";
                  cb(moduleError);
                }
              });
          }
          function loadAsFile(x2, thePackage, callback2) {
            var loadAsFilePackage = thePackage;
            var cb2 = callback2;
            if (typeof loadAsFilePackage === "function") {
              cb2 = loadAsFilePackage;
              loadAsFilePackage = void 0;
            }
            var exts = [""].concat(extensions);
            load(exts, x2, loadAsFilePackage);
            function load(exts2, x3, loadPackage) {
              if (exts2.length === 0)
                return cb2(null, void 0, loadPackage);
              var file = x3 + exts2[0];
              var pkg = loadPackage;
              if (pkg)
                onpkg(null, pkg);
              else
                loadpkg(path2.dirname(file), onpkg);
              function onpkg(err2, pkg_, dir) {
                pkg = pkg_;
                if (err2)
                  return cb2(err2);
                if (dir && pkg && opts.pathFilter) {
                  var rfile = path2.relative(dir, file);
                  var rel = rfile.slice(0, rfile.length - exts2[0].length);
                  var r = opts.pathFilter(pkg, x3, rel);
                  if (r)
                    return load([""].concat(extensions.slice()), path2.resolve(dir, r), pkg);
                }
                isFile2(file, onex);
              }
              function onex(err2, ex) {
                if (err2)
                  return cb2(err2);
                if (ex)
                  return cb2(null, file, pkg);
                load(exts2.slice(1), x3, pkg);
              }
            }
          }
          function loadpkg(dir, cb2) {
            if (dir === "" || dir === "/")
              return cb2(null);
            if (process.platform === "win32" && /^\w:[/\\]*$/.test(dir)) {
              return cb2(null);
            }
            if (/[/\\]node_modules[/\\]*$/.test(dir))
              return cb2(null);
            maybeRealpath(realpath, dir, opts, function(unwrapErr, pkgdir) {
              if (unwrapErr)
                return loadpkg(path2.dirname(dir), cb2);
              var pkgfile = path2.join(pkgdir, "package.json");
              isFile2(pkgfile, function(err2, ex) {
                if (!ex)
                  return loadpkg(path2.dirname(dir), cb2);
                readPackage(readFile, pkgfile, function(err3, pkgParam) {
                  if (err3)
                    cb2(err3);
                  var pkg = pkgParam;
                  if (pkg && opts.packageFilter) {
                    pkg = opts.packageFilter(pkg, pkgfile);
                  }
                  cb2(null, pkg, dir);
                });
              });
            });
          }
          function loadAsDirectory(x2, loadAsDirectoryPackage, callback2) {
            var cb2 = callback2;
            var fpkg = loadAsDirectoryPackage;
            if (typeof fpkg === "function") {
              cb2 = fpkg;
              fpkg = opts.package;
            }
            maybeRealpath(realpath, x2, opts, function(unwrapErr, pkgdir) {
              if (unwrapErr)
                return cb2(unwrapErr);
              var pkgfile = path2.join(pkgdir, "package.json");
              isFile2(pkgfile, function(err2, ex) {
                if (err2)
                  return cb2(err2);
                if (!ex)
                  return loadAsFile(path2.join(x2, "index"), fpkg, cb2);
                readPackage(readFile, pkgfile, function(err3, pkgParam) {
                  if (err3)
                    return cb2(err3);
                  var pkg = pkgParam;
                  if (pkg && opts.packageFilter) {
                    pkg = opts.packageFilter(pkg, pkgfile);
                  }
                  if (pkg && pkg.main) {
                    if (typeof pkg.main !== "string") {
                      var mainError = new TypeError("package \u201C" + pkg.name + "\u201D `main` must be a string");
                      mainError.code = "INVALID_PACKAGE_MAIN";
                      return cb2(mainError);
                    }
                    if (pkg.main === "." || pkg.main === "./") {
                      pkg.main = "index";
                    }
                    loadAsFile(path2.resolve(x2, pkg.main), pkg, function(err4, m, pkg2) {
                      if (err4)
                        return cb2(err4);
                      if (m)
                        return cb2(null, m, pkg2);
                      if (!pkg2)
                        return loadAsFile(path2.join(x2, "index"), pkg2, cb2);
                      var dir = path2.resolve(x2, pkg2.main);
                      loadAsDirectory(dir, pkg2, function(err5, n, pkg3) {
                        if (err5)
                          return cb2(err5);
                        if (n)
                          return cb2(null, n, pkg3);
                        loadAsFile(path2.join(x2, "index"), pkg3, cb2);
                      });
                    });
                    return;
                  }
                  loadAsFile(path2.join(x2, "/index"), pkg, cb2);
                });
              });
            });
          }
          function processDirs(cb2, dirs) {
            if (dirs.length === 0)
              return cb2(null, void 0);
            var dir = dirs[0];
            isDirectory(path2.dirname(dir), isdir);
            function isdir(err2, isdir2) {
              if (err2)
                return cb2(err2);
              if (!isdir2)
                return processDirs(cb2, dirs.slice(1));
              loadAsFile(dir, opts.package, onfile2);
            }
            function onfile2(err2, m, pkg) {
              if (err2)
                return cb2(err2);
              if (m)
                return cb2(null, m, pkg);
              loadAsDirectory(dir, opts.package, ondir);
            }
            function ondir(err2, n, pkg) {
              if (err2)
                return cb2(err2);
              if (n)
                return cb2(null, n, pkg);
              processDirs(cb2, dirs.slice(1));
            }
          }
          function loadNodeModules(x2, start, cb2) {
            var thunk = function() {
              return getPackageCandidates(x2, start, opts);
            };
            processDirs(cb2, packageIterator ? packageIterator(x2, start, thunk, opts) : thunk());
          }
        };
      }
    });
    var require_core32 = __commonJS22({
      "node_modules/resolve/lib/core.json"(exports2, module22) {
        module22.exports = {
          assert: true,
          "node:assert": [">= 14.18 && < 15", ">= 16"],
          "assert/strict": ">= 15",
          "node:assert/strict": ">= 16",
          async_hooks: ">= 8",
          "node:async_hooks": [">= 14.18 && < 15", ">= 16"],
          buffer_ieee754: ">= 0.5 && < 0.9.7",
          buffer: true,
          "node:buffer": [">= 14.18 && < 15", ">= 16"],
          child_process: true,
          "node:child_process": [">= 14.18 && < 15", ">= 16"],
          cluster: ">= 0.5",
          "node:cluster": [">= 14.18 && < 15", ">= 16"],
          console: true,
          "node:console": [">= 14.18 && < 15", ">= 16"],
          constants: true,
          "node:constants": [">= 14.18 && < 15", ">= 16"],
          crypto: true,
          "node:crypto": [">= 14.18 && < 15", ">= 16"],
          _debug_agent: ">= 1 && < 8",
          _debugger: "< 8",
          dgram: true,
          "node:dgram": [">= 14.18 && < 15", ">= 16"],
          diagnostics_channel: [">= 14.17 && < 15", ">= 15.1"],
          "node:diagnostics_channel": [">= 14.18 && < 15", ">= 16"],
          dns: true,
          "node:dns": [">= 14.18 && < 15", ">= 16"],
          "dns/promises": ">= 15",
          "node:dns/promises": ">= 16",
          domain: ">= 0.7.12",
          "node:domain": [">= 14.18 && < 15", ">= 16"],
          events: true,
          "node:events": [">= 14.18 && < 15", ">= 16"],
          freelist: "< 6",
          fs: true,
          "node:fs": [">= 14.18 && < 15", ">= 16"],
          "fs/promises": [">= 10 && < 10.1", ">= 14"],
          "node:fs/promises": [">= 14.18 && < 15", ">= 16"],
          _http_agent: ">= 0.11.1",
          "node:_http_agent": [">= 14.18 && < 15", ">= 16"],
          _http_client: ">= 0.11.1",
          "node:_http_client": [">= 14.18 && < 15", ">= 16"],
          _http_common: ">= 0.11.1",
          "node:_http_common": [">= 14.18 && < 15", ">= 16"],
          _http_incoming: ">= 0.11.1",
          "node:_http_incoming": [">= 14.18 && < 15", ">= 16"],
          _http_outgoing: ">= 0.11.1",
          "node:_http_outgoing": [">= 14.18 && < 15", ">= 16"],
          _http_server: ">= 0.11.1",
          "node:_http_server": [">= 14.18 && < 15", ">= 16"],
          http: true,
          "node:http": [">= 14.18 && < 15", ">= 16"],
          http2: ">= 8.8",
          "node:http2": [">= 14.18 && < 15", ">= 16"],
          https: true,
          "node:https": [">= 14.18 && < 15", ">= 16"],
          inspector: ">= 8",
          "node:inspector": [">= 14.18 && < 15", ">= 16"],
          _linklist: "< 8",
          module: true,
          "node:module": [">= 14.18 && < 15", ">= 16"],
          net: true,
          "node:net": [">= 14.18 && < 15", ">= 16"],
          "node-inspect/lib/_inspect": ">= 7.6 && < 12",
          "node-inspect/lib/internal/inspect_client": ">= 7.6 && < 12",
          "node-inspect/lib/internal/inspect_repl": ">= 7.6 && < 12",
          os: true,
          "node:os": [">= 14.18 && < 15", ">= 16"],
          path: true,
          "node:path": [">= 14.18 && < 15", ">= 16"],
          "path/posix": ">= 15.3",
          "node:path/posix": ">= 16",
          "path/win32": ">= 15.3",
          "node:path/win32": ">= 16",
          perf_hooks: ">= 8.5",
          "node:perf_hooks": [">= 14.18 && < 15", ">= 16"],
          process: ">= 1",
          "node:process": [">= 14.18 && < 15", ">= 16"],
          punycode: ">= 0.5",
          "node:punycode": [">= 14.18 && < 15", ">= 16"],
          querystring: true,
          "node:querystring": [">= 14.18 && < 15", ">= 16"],
          readline: true,
          "node:readline": [">= 14.18 && < 15", ">= 16"],
          "readline/promises": ">= 17",
          "node:readline/promises": ">= 17",
          repl: true,
          "node:repl": [">= 14.18 && < 15", ">= 16"],
          smalloc: ">= 0.11.5 && < 3",
          _stream_duplex: ">= 0.9.4",
          "node:_stream_duplex": [">= 14.18 && < 15", ">= 16"],
          _stream_transform: ">= 0.9.4",
          "node:_stream_transform": [">= 14.18 && < 15", ">= 16"],
          _stream_wrap: ">= 1.4.1",
          "node:_stream_wrap": [">= 14.18 && < 15", ">= 16"],
          _stream_passthrough: ">= 0.9.4",
          "node:_stream_passthrough": [">= 14.18 && < 15", ">= 16"],
          _stream_readable: ">= 0.9.4",
          "node:_stream_readable": [">= 14.18 && < 15", ">= 16"],
          _stream_writable: ">= 0.9.4",
          "node:_stream_writable": [">= 14.18 && < 15", ">= 16"],
          stream: true,
          "node:stream": [">= 14.18 && < 15", ">= 16"],
          "stream/consumers": ">= 16.7",
          "node:stream/consumers": ">= 16.7",
          "stream/promises": ">= 15",
          "node:stream/promises": ">= 16",
          "stream/web": ">= 16.5",
          "node:stream/web": ">= 16.5",
          string_decoder: true,
          "node:string_decoder": [">= 14.18 && < 15", ">= 16"],
          sys: [">= 0.4 && < 0.7", ">= 0.8"],
          "node:sys": [">= 14.18 && < 15", ">= 16"],
          "node:test": ">= 18",
          timers: true,
          "node:timers": [">= 14.18 && < 15", ">= 16"],
          "timers/promises": ">= 15",
          "node:timers/promises": ">= 16",
          _tls_common: ">= 0.11.13",
          "node:_tls_common": [">= 14.18 && < 15", ">= 16"],
          _tls_legacy: ">= 0.11.3 && < 10",
          _tls_wrap: ">= 0.11.3",
          "node:_tls_wrap": [">= 14.18 && < 15", ">= 16"],
          tls: true,
          "node:tls": [">= 14.18 && < 15", ">= 16"],
          trace_events: ">= 10",
          "node:trace_events": [">= 14.18 && < 15", ">= 16"],
          tty: true,
          "node:tty": [">= 14.18 && < 15", ">= 16"],
          url: true,
          "node:url": [">= 14.18 && < 15", ">= 16"],
          util: true,
          "node:util": [">= 14.18 && < 15", ">= 16"],
          "util/types": ">= 15.3",
          "node:util/types": ">= 16",
          "v8/tools/arguments": ">= 10 && < 12",
          "v8/tools/codemap": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/consarray": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/csvparser": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/logreader": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/profile_view": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          "v8/tools/splaytree": [">= 4.4 && < 5", ">= 5.2 && < 12"],
          v8: ">= 1",
          "node:v8": [">= 14.18 && < 15", ">= 16"],
          vm: true,
          "node:vm": [">= 14.18 && < 15", ">= 16"],
          wasi: ">= 13.4 && < 13.5",
          worker_threads: ">= 11.7",
          "node:worker_threads": [">= 14.18 && < 15", ">= 16"],
          zlib: ">= 0.5",
          "node:zlib": [">= 14.18 && < 15", ">= 16"]
        };
      }
    });
    var require_core4 = __commonJS22({
      "node_modules/resolve/lib/core.js"(exports2, module22) {
        var current = process.versions && process.versions.node && process.versions.node.split(".") || [];
        function specifierIncluded(specifier) {
          var parts = specifier.split(" ");
          var op = parts.length > 1 ? parts[0] : "=";
          var versionParts = (parts.length > 1 ? parts[1] : parts[0]).split(".");
          for (var i = 0; i < 3; ++i) {
            var cur = parseInt(current[i] || 0, 10);
            var ver = parseInt(versionParts[i] || 0, 10);
            if (cur === ver) {
              continue;
            }
            if (op === "<") {
              return cur < ver;
            } else if (op === ">=") {
              return cur >= ver;
            }
            return false;
          }
          return op === ">=";
        }
        function matchesRange(range) {
          var specifiers = range.split(/ ?&& ?/);
          if (specifiers.length === 0) {
            return false;
          }
          for (var i = 0; i < specifiers.length; ++i) {
            if (!specifierIncluded(specifiers[i])) {
              return false;
            }
          }
          return true;
        }
        function versionIncluded(specifierValue) {
          if (typeof specifierValue === "boolean") {
            return specifierValue;
          }
          if (specifierValue && typeof specifierValue === "object") {
            for (var i = 0; i < specifierValue.length; ++i) {
              if (matchesRange(specifierValue[i])) {
                return true;
              }
            }
            return false;
          }
          return matchesRange(specifierValue);
        }
        var data = require_core32();
        var core2 = {};
        for (mod in data) {
          if (Object.prototype.hasOwnProperty.call(data, mod)) {
            core2[mod] = versionIncluded(data[mod]);
          }
        }
        var mod;
        module22.exports = core2;
      }
    });
    var require_is_core = __commonJS22({
      "node_modules/resolve/lib/is-core.js"(exports2, module22) {
        var isCoreModule = require_is_core_module();
        module22.exports = function isCore(x) {
          return isCoreModule(x);
        };
      }
    });
    var require_sync6 = __commonJS22({
      "node_modules/resolve/lib/sync.js"(exports2, module22) {
        var isCore = require_is_core_module();
        var fs2 = require("fs");
        var path2 = require("path");
        var getHomedir = require_homedir();
        var caller = require_caller();
        var nodeModulesPaths = require_node_modules_paths();
        var normalizeOptions = require_normalize_options();
        var realpathFS = process.platform !== "win32" && fs2.realpathSync && typeof fs2.realpathSync.native === "function" ? fs2.realpathSync.native : fs2.realpathSync;
        var homedir = getHomedir();
        var defaultPaths = function() {
          return [path2.join(homedir, ".node_modules"), path2.join(homedir, ".node_libraries")];
        };
        var defaultIsFile = function isFile2(file) {
          try {
            var stat = fs2.statSync(file, {
              throwIfNoEntry: false
            });
          } catch (e) {
            if (e && (e.code === "ENOENT" || e.code === "ENOTDIR"))
              return false;
            throw e;
          }
          return !!stat && (stat.isFile() || stat.isFIFO());
        };
        var defaultIsDir = function isDirectory(dir) {
          try {
            var stat = fs2.statSync(dir, {
              throwIfNoEntry: false
            });
          } catch (e) {
            if (e && (e.code === "ENOENT" || e.code === "ENOTDIR"))
              return false;
            throw e;
          }
          return !!stat && stat.isDirectory();
        };
        var defaultRealpathSync = function realpathSync(x) {
          try {
            return realpathFS(x);
          } catch (realpathErr) {
            if (realpathErr.code !== "ENOENT") {
              throw realpathErr;
            }
          }
          return x;
        };
        var maybeRealpathSync = function maybeRealpathSync2(realpathSync, x, opts) {
          if (opts && opts.preserveSymlinks === false) {
            return realpathSync(x);
          }
          return x;
        };
        var defaultReadPackageSync = function defaultReadPackageSync2(readFileSync, pkgfile) {
          var body = readFileSync(pkgfile);
          try {
            var pkg = JSON.parse(body);
            return pkg;
          } catch (jsonErr) {
          }
        };
        var getPackageCandidates = function getPackageCandidates2(x, start, opts) {
          var dirs = nodeModulesPaths(start, opts, x);
          for (var i = 0; i < dirs.length; i++) {
            dirs[i] = path2.join(dirs[i], x);
          }
          return dirs;
        };
        module22.exports = function resolveSync(x, options) {
          if (typeof x !== "string") {
            throw new TypeError("Path must be a string.");
          }
          var opts = normalizeOptions(x, options);
          var isFile2 = opts.isFile || defaultIsFile;
          var readFileSync = opts.readFileSync || fs2.readFileSync;
          var isDirectory = opts.isDirectory || defaultIsDir;
          var realpathSync = opts.realpathSync || defaultRealpathSync;
          var readPackageSync = opts.readPackageSync || defaultReadPackageSync;
          if (opts.readFileSync && opts.readPackageSync) {
            throw new TypeError("`readFileSync` and `readPackageSync` are mutually exclusive.");
          }
          var packageIterator = opts.packageIterator;
          var extensions = opts.extensions || [".js"];
          var includeCoreModules = opts.includeCoreModules !== false;
          var basedir = opts.basedir || path2.dirname(caller());
          var parent = opts.filename || basedir;
          opts.paths = opts.paths || defaultPaths();
          var absoluteStart = maybeRealpathSync(realpathSync, path2.resolve(basedir), opts);
          if (/^(?:\.\.?(?:\/|$)|\/|([A-Za-z]:)?[/\\])/.test(x)) {
            var res = path2.resolve(absoluteStart, x);
            if (x === "." || x === ".." || x.slice(-1) === "/")
              res += "/";
            var m = loadAsFileSync(res) || loadAsDirectorySync(res);
            if (m)
              return maybeRealpathSync(realpathSync, m, opts);
          } else if (includeCoreModules && isCore(x)) {
            return x;
          } else {
            var n = loadNodeModulesSync(x, absoluteStart);
            if (n)
              return maybeRealpathSync(realpathSync, n, opts);
          }
          var err = new Error("Cannot find module '" + x + "' from '" + parent + "'");
          err.code = "MODULE_NOT_FOUND";
          throw err;
          function loadAsFileSync(x2) {
            var pkg = loadpkg(path2.dirname(x2));
            if (pkg && pkg.dir && pkg.pkg && opts.pathFilter) {
              var rfile = path2.relative(pkg.dir, x2);
              var r = opts.pathFilter(pkg.pkg, x2, rfile);
              if (r) {
                x2 = path2.resolve(pkg.dir, r);
              }
            }
            if (isFile2(x2)) {
              return x2;
            }
            for (var i = 0; i < extensions.length; i++) {
              var file = x2 + extensions[i];
              if (isFile2(file)) {
                return file;
              }
            }
          }
          function loadpkg(dir) {
            if (dir === "" || dir === "/")
              return;
            if (process.platform === "win32" && /^\w:[/\\]*$/.test(dir)) {
              return;
            }
            if (/[/\\]node_modules[/\\]*$/.test(dir))
              return;
            var pkgfile = path2.join(maybeRealpathSync(realpathSync, dir, opts), "package.json");
            if (!isFile2(pkgfile)) {
              return loadpkg(path2.dirname(dir));
            }
            var pkg = readPackageSync(readFileSync, pkgfile);
            if (pkg && opts.packageFilter) {
              pkg = opts.packageFilter(pkg, dir);
            }
            return {
              pkg,
              dir
            };
          }
          function loadAsDirectorySync(x2) {
            var pkgfile = path2.join(maybeRealpathSync(realpathSync, x2, opts), "/package.json");
            if (isFile2(pkgfile)) {
              try {
                var pkg = readPackageSync(readFileSync, pkgfile);
              } catch (e) {
              }
              if (pkg && opts.packageFilter) {
                pkg = opts.packageFilter(pkg, x2);
              }
              if (pkg && pkg.main) {
                if (typeof pkg.main !== "string") {
                  var mainError = new TypeError("package \u201C" + pkg.name + "\u201D `main` must be a string");
                  mainError.code = "INVALID_PACKAGE_MAIN";
                  throw mainError;
                }
                if (pkg.main === "." || pkg.main === "./") {
                  pkg.main = "index";
                }
                try {
                  var m2 = loadAsFileSync(path2.resolve(x2, pkg.main));
                  if (m2)
                    return m2;
                  var n2 = loadAsDirectorySync(path2.resolve(x2, pkg.main));
                  if (n2)
                    return n2;
                } catch (e) {
                }
              }
            }
            return loadAsFileSync(path2.join(x2, "/index"));
          }
          function loadNodeModulesSync(x2, start) {
            var thunk = function() {
              return getPackageCandidates(x2, start, opts);
            };
            var dirs = packageIterator ? packageIterator(x2, start, thunk, opts) : thunk();
            for (var i = 0; i < dirs.length; i++) {
              var dir = dirs[i];
              if (isDirectory(path2.dirname(dir))) {
                var m2 = loadAsFileSync(dir);
                if (m2)
                  return m2;
                var n2 = loadAsDirectorySync(dir);
                if (n2)
                  return n2;
              }
            }
          }
        };
      }
    });
    var require_resolve2 = __commonJS22({
      "node_modules/resolve/index.js"(exports2, module22) {
        var async = require_async8();
        async.core = require_core4();
        async.isCore = require_is_core();
        async.sync = require_sync6();
        module22.exports = async;
      }
    });
    var require_resolve22 = __commonJS22({
      "src/common/resolve.js"(exports2, module22) {
        "use strict";
        var {
          resolve
        } = require;
        if (resolve.length === 1 || process.env.PRETTIER_FALLBACK_RESOLVE) {
          resolve = (id, options) => {
            let basedir;
            if (options && options.paths && options.paths.length === 1) {
              basedir = options.paths[0];
            }
            return require_resolve2().sync(id, {
              basedir
            });
          };
        }
        module22.exports = resolve;
      }
    });
    function mimicFunction(to, from, {
      ignoreNonConfigurable = false
    } = {}) {
      const {
        name
      } = to;
      for (const property of Reflect.ownKeys(from)) {
        copyProperty(to, from, property, ignoreNonConfigurable);
      }
      changePrototype(to, from);
      changeToString(to, from, name);
      return to;
    }
    var copyProperty;
    var canCopyProperty;
    var changePrototype;
    var wrappedToString;
    var toStringDescriptor;
    var toStringName;
    var changeToString;
    var init_mimic_fn = __esm({
      "node_modules/mimic-fn/index.js"() {
        copyProperty = (to, from, property, ignoreNonConfigurable) => {
          if (property === "length" || property === "prototype") {
            return;
          }
          if (property === "arguments" || property === "caller") {
            return;
          }
          const toDescriptor = Object.getOwnPropertyDescriptor(to, property);
          const fromDescriptor = Object.getOwnPropertyDescriptor(from, property);
          if (!canCopyProperty(toDescriptor, fromDescriptor) && ignoreNonConfigurable) {
            return;
          }
          Object.defineProperty(to, property, fromDescriptor);
        };
        canCopyProperty = function(toDescriptor, fromDescriptor) {
          return toDescriptor === void 0 || toDescriptor.configurable || toDescriptor.writable === fromDescriptor.writable && toDescriptor.enumerable === fromDescriptor.enumerable && toDescriptor.configurable === fromDescriptor.configurable && (toDescriptor.writable || toDescriptor.value === fromDescriptor.value);
        };
        changePrototype = (to, from) => {
          const fromPrototype = Object.getPrototypeOf(from);
          if (fromPrototype === Object.getPrototypeOf(to)) {
            return;
          }
          Object.setPrototypeOf(to, fromPrototype);
        };
        wrappedToString = (withName, fromBody) => `/* Wrapped ${withName}*/
${fromBody}`;
        toStringDescriptor = Object.getOwnPropertyDescriptor(Function.prototype, "toString");
        toStringName = Object.getOwnPropertyDescriptor(Function.prototype.toString, "name");
        changeToString = (to, from, name) => {
          const withName = name === "" ? "" : `with ${name.trim()}() `;
          const newToString = wrappedToString.bind(null, withName, from.toString());
          Object.defineProperty(newToString, "name", toStringName);
          Object.defineProperty(to, "toString", Object.assign(Object.assign({}, toStringDescriptor), {}, {
            value: newToString
          }));
        };
      }
    });
    var require_p_defer = __commonJS22({
      "node_modules/p-defer/index.js"(exports2, module22) {
        "use strict";
        module22.exports = () => {
          const ret = {};
          ret.promise = new Promise((resolve, reject) => {
            ret.resolve = resolve;
            ret.reject = reject;
          });
          return ret;
        };
      }
    });
    var require_dist = __commonJS22({
      "node_modules/map-age-cleaner/dist/index.js"(exports2, module22) {
        "use strict";
        var __awaiter2 = exports2 && exports2.__awaiter || function(thisArg, _arguments, P, generator) {
          return new (P || (P = Promise))(function(resolve, reject) {
            function fulfilled(value2) {
              try {
                step(generator.next(value2));
              } catch (e) {
                reject(e);
              }
            }
            function rejected(value2) {
              try {
                step(generator["throw"](value2));
              } catch (e) {
                reject(e);
              }
            }
            function step(result) {
              result.done ? resolve(result.value) : new P(function(resolve2) {
                resolve2(result.value);
              }).then(fulfilled, rejected);
            }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
          });
        };
        var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
          return mod && mod.__esModule ? mod : {
            "default": mod
          };
        };
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var p_defer_1 = __importDefault2(require_p_defer());
        function mapAgeCleaner2(map, property = "maxAge") {
          let processingKey;
          let processingTimer;
          let processingDeferred;
          const cleanup = () => __awaiter2(this, void 0, void 0, function* () {
            if (processingKey !== void 0) {
              return;
            }
            const setupTimer = (item) => __awaiter2(this, void 0, void 0, function* () {
              processingDeferred = p_defer_1.default();
              const delay = item[1][property] - Date.now();
              if (delay <= 0) {
                map.delete(item[0]);
                processingDeferred.resolve();
                return;
              }
              processingKey = item[0];
              processingTimer = setTimeout(() => {
                map.delete(item[0]);
                if (processingDeferred) {
                  processingDeferred.resolve();
                }
              }, delay);
              if (typeof processingTimer.unref === "function") {
                processingTimer.unref();
              }
              return processingDeferred.promise;
            });
            try {
              for (const entry of map) {
                yield setupTimer(entry);
              }
            } catch (_a) {
            }
            processingKey = void 0;
          });
          const reset = () => {
            processingKey = void 0;
            if (processingTimer !== void 0) {
              clearTimeout(processingTimer);
              processingTimer = void 0;
            }
            if (processingDeferred !== void 0) {
              processingDeferred.reject(void 0);
              processingDeferred = void 0;
            }
          };
          const originalSet = map.set.bind(map);
          map.set = (key, value2) => {
            if (map.has(key)) {
              map.delete(key);
            }
            const result = originalSet(key, value2);
            if (processingKey && processingKey === key) {
              reset();
            }
            cleanup();
            return result;
          };
          cleanup();
          return map;
        }
        exports2.default = mapAgeCleaner2;
        module22.exports = mapAgeCleaner2;
        module22.exports.default = mapAgeCleaner2;
      }
    });
    var dist_exports = {};
    __export(dist_exports, {
      default: () => mem,
      memClear: () => memClear,
      memDecorator: () => memDecorator
    });
    function mem(fn, {
      cacheKey,
      cache = /* @__PURE__ */ new Map(),
      maxAge
    } = {}) {
      if (typeof maxAge === "number") {
        (0, import_map_age_cleaner.default)(cache);
      }
      const memoized = function(...arguments_) {
        const key = cacheKey ? cacheKey(arguments_) : arguments_[0];
        const cacheItem = cache.get(key);
        if (cacheItem) {
          return cacheItem.data;
        }
        const result = fn.apply(this, arguments_);
        cache.set(key, {
          data: result,
          maxAge: maxAge ? Date.now() + maxAge : Number.POSITIVE_INFINITY
        });
        return result;
      };
      mimicFunction(memoized, fn, {
        ignoreNonConfigurable: true
      });
      cacheStore.set(memoized, cache);
      return memoized;
    }
    function memDecorator(options = {}) {
      const instanceMap = /* @__PURE__ */ new WeakMap();
      return (target, propertyKey, descriptor) => {
        const input = target[propertyKey];
        if (typeof input !== "function") {
          throw new TypeError("The decorated value must be a function");
        }
        delete descriptor.value;
        delete descriptor.writable;
        descriptor.get = function() {
          if (!instanceMap.has(this)) {
            const value2 = mem(input, options);
            instanceMap.set(this, value2);
            return value2;
          }
          return instanceMap.get(this);
        };
      };
    }
    function memClear(fn) {
      const cache = cacheStore.get(fn);
      if (!cache) {
        throw new TypeError("Can't clear a function that was not memoized!");
      }
      if (typeof cache.clear !== "function") {
        throw new TypeError("The cache Map can't be cleared!");
      }
      cache.clear();
    }
    var import_map_age_cleaner;
    var cacheStore;
    var init_dist = __esm({
      "node_modules/mem/dist/index.js"() {
        init_mimic_fn();
        import_map_age_cleaner = __toESM2(require_dist());
        cacheStore = /* @__PURE__ */ new WeakMap();
      }
    });
    var require_pseudomap = __commonJS22({
      "node_modules/pseudomap/pseudomap.js"(exports2, module22) {
        var hasOwnProperty = Object.prototype.hasOwnProperty;
        module22.exports = PseudoMap;
        function PseudoMap(set2) {
          if (!(this instanceof PseudoMap))
            throw new TypeError("Constructor PseudoMap requires 'new'");
          this.clear();
          if (set2) {
            if (set2 instanceof PseudoMap || typeof Map === "function" && set2 instanceof Map)
              set2.forEach(function(value2, key) {
                this.set(key, value2);
              }, this);
            else if (Array.isArray(set2))
              set2.forEach(function(kv) {
                this.set(kv[0], kv[1]);
              }, this);
            else
              throw new TypeError("invalid argument");
          }
        }
        PseudoMap.prototype.forEach = function(fn, thisp) {
          thisp = thisp || this;
          Object.keys(this._data).forEach(function(k) {
            if (k !== "size")
              fn.call(thisp, this._data[k].value, this._data[k].key);
          }, this);
        };
        PseudoMap.prototype.has = function(k) {
          return !!find(this._data, k);
        };
        PseudoMap.prototype.get = function(k) {
          var res = find(this._data, k);
          return res && res.value;
        };
        PseudoMap.prototype.set = function(k, v) {
          set(this._data, k, v);
        };
        PseudoMap.prototype.delete = function(k) {
          var res = find(this._data, k);
          if (res) {
            delete this._data[res._index];
            this._data.size--;
          }
        };
        PseudoMap.prototype.clear = function() {
          var data = /* @__PURE__ */ Object.create(null);
          data.size = 0;
          Object.defineProperty(this, "_data", {
            value: data,
            enumerable: false,
            configurable: true,
            writable: false
          });
        };
        Object.defineProperty(PseudoMap.prototype, "size", {
          get: function() {
            return this._data.size;
          },
          set: function(n) {
          },
          enumerable: true,
          configurable: true
        });
        PseudoMap.prototype.values = PseudoMap.prototype.keys = PseudoMap.prototype.entries = function() {
          throw new Error("iterators are not implemented in this version");
        };
        function same(a, b) {
          return a === b || a !== a && b !== b;
        }
        function Entry(k, v, i) {
          this.key = k;
          this.value = v;
          this._index = i;
        }
        function find(data, k) {
          for (var i = 0, s = "_" + k, key = s; hasOwnProperty.call(data, key); key = s + i++) {
            if (same(data[key].key, k))
              return data[key];
          }
        }
        function set(data, k, v) {
          for (var i = 0, s = "_" + k, key = s; hasOwnProperty.call(data, key); key = s + i++) {
            if (same(data[key].key, k)) {
              data[key].value = v;
              return;
            }
          }
          data.size++;
          data[key] = new Entry(k, v, key);
        }
      }
    });
    var require_map3 = __commonJS22({
      "node_modules/pseudomap/map.js"(exports2, module22) {
        if (process.env.npm_package_name === "pseudomap" && process.env.npm_lifecycle_script === "test")
          process.env.TEST_PSEUDOMAP = "true";
        if (typeof Map === "function" && !process.env.TEST_PSEUDOMAP) {
          module22.exports = Map;
        } else {
          module22.exports = require_pseudomap();
        }
      }
    });
    var require_yallist2 = __commonJS22({
      "node_modules/editorconfig/node_modules/yallist/yallist.js"(exports2, module22) {
        module22.exports = Yallist;
        Yallist.Node = Node2;
        Yallist.create = Yallist;
        function Yallist(list) {
          var self2 = this;
          if (!(self2 instanceof Yallist)) {
            self2 = new Yallist();
          }
          self2.tail = null;
          self2.head = null;
          self2.length = 0;
          if (list && typeof list.forEach === "function") {
            list.forEach(function(item) {
              self2.push(item);
            });
          } else if (arguments.length > 0) {
            for (var i = 0, l = arguments.length; i < l; i++) {
              self2.push(arguments[i]);
            }
          }
          return self2;
        }
        Yallist.prototype.removeNode = function(node) {
          if (node.list !== this) {
            throw new Error("removing node which does not belong to this list");
          }
          var next = node.next;
          var prev = node.prev;
          if (next) {
            next.prev = prev;
          }
          if (prev) {
            prev.next = next;
          }
          if (node === this.head) {
            this.head = next;
          }
          if (node === this.tail) {
            this.tail = prev;
          }
          node.list.length--;
          node.next = null;
          node.prev = null;
          node.list = null;
        };
        Yallist.prototype.unshiftNode = function(node) {
          if (node === this.head) {
            return;
          }
          if (node.list) {
            node.list.removeNode(node);
          }
          var head = this.head;
          node.list = this;
          node.next = head;
          if (head) {
            head.prev = node;
          }
          this.head = node;
          if (!this.tail) {
            this.tail = node;
          }
          this.length++;
        };
        Yallist.prototype.pushNode = function(node) {
          if (node === this.tail) {
            return;
          }
          if (node.list) {
            node.list.removeNode(node);
          }
          var tail = this.tail;
          node.list = this;
          node.prev = tail;
          if (tail) {
            tail.next = node;
          }
          this.tail = node;
          if (!this.head) {
            this.head = node;
          }
          this.length++;
        };
        Yallist.prototype.push = function() {
          for (var i = 0, l = arguments.length; i < l; i++) {
            push(this, arguments[i]);
          }
          return this.length;
        };
        Yallist.prototype.unshift = function() {
          for (var i = 0, l = arguments.length; i < l; i++) {
            unshift(this, arguments[i]);
          }
          return this.length;
        };
        Yallist.prototype.pop = function() {
          if (!this.tail) {
            return void 0;
          }
          var res = this.tail.value;
          this.tail = this.tail.prev;
          if (this.tail) {
            this.tail.next = null;
          } else {
            this.head = null;
          }
          this.length--;
          return res;
        };
        Yallist.prototype.shift = function() {
          if (!this.head) {
            return void 0;
          }
          var res = this.head.value;
          this.head = this.head.next;
          if (this.head) {
            this.head.prev = null;
          } else {
            this.tail = null;
          }
          this.length--;
          return res;
        };
        Yallist.prototype.forEach = function(fn, thisp) {
          thisp = thisp || this;
          for (var walker = this.head, i = 0; walker !== null; i++) {
            fn.call(thisp, walker.value, i, this);
            walker = walker.next;
          }
        };
        Yallist.prototype.forEachReverse = function(fn, thisp) {
          thisp = thisp || this;
          for (var walker = this.tail, i = this.length - 1; walker !== null; i--) {
            fn.call(thisp, walker.value, i, this);
            walker = walker.prev;
          }
        };
        Yallist.prototype.get = function(n) {
          for (var i = 0, walker = this.head; walker !== null && i < n; i++) {
            walker = walker.next;
          }
          if (i === n && walker !== null) {
            return walker.value;
          }
        };
        Yallist.prototype.getReverse = function(n) {
          for (var i = 0, walker = this.tail; walker !== null && i < n; i++) {
            walker = walker.prev;
          }
          if (i === n && walker !== null) {
            return walker.value;
          }
        };
        Yallist.prototype.map = function(fn, thisp) {
          thisp = thisp || this;
          var res = new Yallist();
          for (var walker = this.head; walker !== null; ) {
            res.push(fn.call(thisp, walker.value, this));
            walker = walker.next;
          }
          return res;
        };
        Yallist.prototype.mapReverse = function(fn, thisp) {
          thisp = thisp || this;
          var res = new Yallist();
          for (var walker = this.tail; walker !== null; ) {
            res.push(fn.call(thisp, walker.value, this));
            walker = walker.prev;
          }
          return res;
        };
        Yallist.prototype.reduce = function(fn, initial) {
          var acc;
          var walker = this.head;
          if (arguments.length > 1) {
            acc = initial;
          } else if (this.head) {
            walker = this.head.next;
            acc = this.head.value;
          } else {
            throw new TypeError("Reduce of empty list with no initial value");
          }
          for (var i = 0; walker !== null; i++) {
            acc = fn(acc, walker.value, i);
            walker = walker.next;
          }
          return acc;
        };
        Yallist.prototype.reduceReverse = function(fn, initial) {
          var acc;
          var walker = this.tail;
          if (arguments.length > 1) {
            acc = initial;
          } else if (this.tail) {
            walker = this.tail.prev;
            acc = this.tail.value;
          } else {
            throw new TypeError("Reduce of empty list with no initial value");
          }
          for (var i = this.length - 1; walker !== null; i--) {
            acc = fn(acc, walker.value, i);
            walker = walker.prev;
          }
          return acc;
        };
        Yallist.prototype.toArray = function() {
          var arr = new Array(this.length);
          for (var i = 0, walker = this.head; walker !== null; i++) {
            arr[i] = walker.value;
            walker = walker.next;
          }
          return arr;
        };
        Yallist.prototype.toArrayReverse = function() {
          var arr = new Array(this.length);
          for (var i = 0, walker = this.tail; walker !== null; i++) {
            arr[i] = walker.value;
            walker = walker.prev;
          }
          return arr;
        };
        Yallist.prototype.slice = function(from, to) {
          to = to || this.length;
          if (to < 0) {
            to += this.length;
          }
          from = from || 0;
          if (from < 0) {
            from += this.length;
          }
          var ret = new Yallist();
          if (to < from || to < 0) {
            return ret;
          }
          if (from < 0) {
            from = 0;
          }
          if (to > this.length) {
            to = this.length;
          }
          for (var i = 0, walker = this.head; walker !== null && i < from; i++) {
            walker = walker.next;
          }
          for (; walker !== null && i < to; i++, walker = walker.next) {
            ret.push(walker.value);
          }
          return ret;
        };
        Yallist.prototype.sliceReverse = function(from, to) {
          to = to || this.length;
          if (to < 0) {
            to += this.length;
          }
          from = from || 0;
          if (from < 0) {
            from += this.length;
          }
          var ret = new Yallist();
          if (to < from || to < 0) {
            return ret;
          }
          if (from < 0) {
            from = 0;
          }
          if (to > this.length) {
            to = this.length;
          }
          for (var i = this.length, walker = this.tail; walker !== null && i > to; i--) {
            walker = walker.prev;
          }
          for (; walker !== null && i > from; i--, walker = walker.prev) {
            ret.push(walker.value);
          }
          return ret;
        };
        Yallist.prototype.reverse = function() {
          var head = this.head;
          var tail = this.tail;
          for (var walker = head; walker !== null; walker = walker.prev) {
            var p = walker.prev;
            walker.prev = walker.next;
            walker.next = p;
          }
          this.head = tail;
          this.tail = head;
          return this;
        };
        function push(self2, item) {
          self2.tail = new Node2(item, self2.tail, null, self2);
          if (!self2.head) {
            self2.head = self2.tail;
          }
          self2.length++;
        }
        function unshift(self2, item) {
          self2.head = new Node2(item, null, self2.head, self2);
          if (!self2.tail) {
            self2.tail = self2.head;
          }
          self2.length++;
        }
        function Node2(value2, prev, next, list) {
          if (!(this instanceof Node2)) {
            return new Node2(value2, prev, next, list);
          }
          this.list = list;
          this.value = value2;
          if (prev) {
            prev.next = this;
            this.prev = prev;
          } else {
            this.prev = null;
          }
          if (next) {
            next.prev = this;
            this.next = next;
          } else {
            this.next = null;
          }
        }
      }
    });
    var require_lru_cache2 = __commonJS22({
      "node_modules/editorconfig/node_modules/lru-cache/index.js"(exports2, module22) {
        "use strict";
        module22.exports = LRUCache;
        var Map2 = require_map3();
        var util = require("util");
        var Yallist = require_yallist2();
        var hasSymbol = typeof Symbol === "function" && process.env._nodeLRUCacheForceNoSymbol !== "1";
        var makeSymbol;
        if (hasSymbol) {
          makeSymbol = function(key) {
            return Symbol(key);
          };
        } else {
          makeSymbol = function(key) {
            return "_" + key;
          };
        }
        var MAX = makeSymbol("max");
        var LENGTH = makeSymbol("length");
        var LENGTH_CALCULATOR = makeSymbol("lengthCalculator");
        var ALLOW_STALE = makeSymbol("allowStale");
        var MAX_AGE = makeSymbol("maxAge");
        var DISPOSE = makeSymbol("dispose");
        var NO_DISPOSE_ON_SET = makeSymbol("noDisposeOnSet");
        var LRU_LIST = makeSymbol("lruList");
        var CACHE = makeSymbol("cache");
        function naiveLength() {
          return 1;
        }
        function LRUCache(options) {
          if (!(this instanceof LRUCache)) {
            return new LRUCache(options);
          }
          if (typeof options === "number") {
            options = {
              max: options
            };
          }
          if (!options) {
            options = {};
          }
          var max2 = this[MAX] = options.max;
          if (!max2 || !(typeof max2 === "number") || max2 <= 0) {
            this[MAX] = Infinity;
          }
          var lc = options.length || naiveLength;
          if (typeof lc !== "function") {
            lc = naiveLength;
          }
          this[LENGTH_CALCULATOR] = lc;
          this[ALLOW_STALE] = options.stale || false;
          this[MAX_AGE] = options.maxAge || 0;
          this[DISPOSE] = options.dispose;
          this[NO_DISPOSE_ON_SET] = options.noDisposeOnSet || false;
          this.reset();
        }
        Object.defineProperty(LRUCache.prototype, "max", {
          set: function(mL) {
            if (!mL || !(typeof mL === "number") || mL <= 0) {
              mL = Infinity;
            }
            this[MAX] = mL;
            trim(this);
          },
          get: function() {
            return this[MAX];
          },
          enumerable: true
        });
        Object.defineProperty(LRUCache.prototype, "allowStale", {
          set: function(allowStale) {
            this[ALLOW_STALE] = !!allowStale;
          },
          get: function() {
            return this[ALLOW_STALE];
          },
          enumerable: true
        });
        Object.defineProperty(LRUCache.prototype, "maxAge", {
          set: function(mA) {
            if (!mA || !(typeof mA === "number") || mA < 0) {
              mA = 0;
            }
            this[MAX_AGE] = mA;
            trim(this);
          },
          get: function() {
            return this[MAX_AGE];
          },
          enumerable: true
        });
        Object.defineProperty(LRUCache.prototype, "lengthCalculator", {
          set: function(lC) {
            if (typeof lC !== "function") {
              lC = naiveLength;
            }
            if (lC !== this[LENGTH_CALCULATOR]) {
              this[LENGTH_CALCULATOR] = lC;
              this[LENGTH] = 0;
              this[LRU_LIST].forEach(function(hit) {
                hit.length = this[LENGTH_CALCULATOR](hit.value, hit.key);
                this[LENGTH] += hit.length;
              }, this);
            }
            trim(this);
          },
          get: function() {
            return this[LENGTH_CALCULATOR];
          },
          enumerable: true
        });
        Object.defineProperty(LRUCache.prototype, "length", {
          get: function() {
            return this[LENGTH];
          },
          enumerable: true
        });
        Object.defineProperty(LRUCache.prototype, "itemCount", {
          get: function() {
            return this[LRU_LIST].length;
          },
          enumerable: true
        });
        LRUCache.prototype.rforEach = function(fn, thisp) {
          thisp = thisp || this;
          for (var walker = this[LRU_LIST].tail; walker !== null; ) {
            var prev = walker.prev;
            forEachStep(this, fn, walker, thisp);
            walker = prev;
          }
        };
        function forEachStep(self2, fn, node, thisp) {
          var hit = node.value;
          if (isStale(self2, hit)) {
            del(self2, node);
            if (!self2[ALLOW_STALE]) {
              hit = void 0;
            }
          }
          if (hit) {
            fn.call(thisp, hit.value, hit.key, self2);
          }
        }
        LRUCache.prototype.forEach = function(fn, thisp) {
          thisp = thisp || this;
          for (var walker = this[LRU_LIST].head; walker !== null; ) {
            var next = walker.next;
            forEachStep(this, fn, walker, thisp);
            walker = next;
          }
        };
        LRUCache.prototype.keys = function() {
          return this[LRU_LIST].toArray().map(function(k) {
            return k.key;
          }, this);
        };
        LRUCache.prototype.values = function() {
          return this[LRU_LIST].toArray().map(function(k) {
            return k.value;
          }, this);
        };
        LRUCache.prototype.reset = function() {
          if (this[DISPOSE] && this[LRU_LIST] && this[LRU_LIST].length) {
            this[LRU_LIST].forEach(function(hit) {
              this[DISPOSE](hit.key, hit.value);
            }, this);
          }
          this[CACHE] = new Map2();
          this[LRU_LIST] = new Yallist();
          this[LENGTH] = 0;
        };
        LRUCache.prototype.dump = function() {
          return this[LRU_LIST].map(function(hit) {
            if (!isStale(this, hit)) {
              return {
                k: hit.key,
                v: hit.value,
                e: hit.now + (hit.maxAge || 0)
              };
            }
          }, this).toArray().filter(function(h) {
            return h;
          });
        };
        LRUCache.prototype.dumpLru = function() {
          return this[LRU_LIST];
        };
        LRUCache.prototype.inspect = function(n, opts) {
          var str = "LRUCache {";
          var extras = false;
          var as = this[ALLOW_STALE];
          if (as) {
            str += "\n  allowStale: true";
            extras = true;
          }
          var max2 = this[MAX];
          if (max2 && max2 !== Infinity) {
            if (extras) {
              str += ",";
            }
            str += "\n  max: " + util.inspect(max2, opts);
            extras = true;
          }
          var maxAge = this[MAX_AGE];
          if (maxAge) {
            if (extras) {
              str += ",";
            }
            str += "\n  maxAge: " + util.inspect(maxAge, opts);
            extras = true;
          }
          var lc = this[LENGTH_CALCULATOR];
          if (lc && lc !== naiveLength) {
            if (extras) {
              str += ",";
            }
            str += "\n  length: " + util.inspect(this[LENGTH], opts);
            extras = true;
          }
          var didFirst = false;
          this[LRU_LIST].forEach(function(item) {
            if (didFirst) {
              str += ",\n  ";
            } else {
              if (extras) {
                str += ",\n";
              }
              didFirst = true;
              str += "\n  ";
            }
            var key = util.inspect(item.key).split("\n").join("\n  ");
            var val = {
              value: item.value
            };
            if (item.maxAge !== maxAge) {
              val.maxAge = item.maxAge;
            }
            if (lc !== naiveLength) {
              val.length = item.length;
            }
            if (isStale(this, item)) {
              val.stale = true;
            }
            val = util.inspect(val, opts).split("\n").join("\n  ");
            str += key + " => " + val;
          });
          if (didFirst || extras) {
            str += "\n";
          }
          str += "}";
          return str;
        };
        LRUCache.prototype.set = function(key, value2, maxAge) {
          maxAge = maxAge || this[MAX_AGE];
          var now = maxAge ? Date.now() : 0;
          var len = this[LENGTH_CALCULATOR](value2, key);
          if (this[CACHE].has(key)) {
            if (len > this[MAX]) {
              del(this, this[CACHE].get(key));
              return false;
            }
            var node = this[CACHE].get(key);
            var item = node.value;
            if (this[DISPOSE]) {
              if (!this[NO_DISPOSE_ON_SET]) {
                this[DISPOSE](key, item.value);
              }
            }
            item.now = now;
            item.maxAge = maxAge;
            item.value = value2;
            this[LENGTH] += len - item.length;
            item.length = len;
            this.get(key);
            trim(this);
            return true;
          }
          var hit = new Entry(key, value2, len, now, maxAge);
          if (hit.length > this[MAX]) {
            if (this[DISPOSE]) {
              this[DISPOSE](key, value2);
            }
            return false;
          }
          this[LENGTH] += hit.length;
          this[LRU_LIST].unshift(hit);
          this[CACHE].set(key, this[LRU_LIST].head);
          trim(this);
          return true;
        };
        LRUCache.prototype.has = function(key) {
          if (!this[CACHE].has(key))
            return false;
          var hit = this[CACHE].get(key).value;
          if (isStale(this, hit)) {
            return false;
          }
          return true;
        };
        LRUCache.prototype.get = function(key) {
          return get(this, key, true);
        };
        LRUCache.prototype.peek = function(key) {
          return get(this, key, false);
        };
        LRUCache.prototype.pop = function() {
          var node = this[LRU_LIST].tail;
          if (!node)
            return null;
          del(this, node);
          return node.value;
        };
        LRUCache.prototype.del = function(key) {
          del(this, this[CACHE].get(key));
        };
        LRUCache.prototype.load = function(arr) {
          this.reset();
          var now = Date.now();
          for (var l = arr.length - 1; l >= 0; l--) {
            var hit = arr[l];
            var expiresAt = hit.e || 0;
            if (expiresAt === 0) {
              this.set(hit.k, hit.v);
            } else {
              var maxAge = expiresAt - now;
              if (maxAge > 0) {
                this.set(hit.k, hit.v, maxAge);
              }
            }
          }
        };
        LRUCache.prototype.prune = function() {
          var self2 = this;
          this[CACHE].forEach(function(value2, key) {
            get(self2, key, false);
          });
        };
        function get(self2, key, doUse) {
          var node = self2[CACHE].get(key);
          if (node) {
            var hit = node.value;
            if (isStale(self2, hit)) {
              del(self2, node);
              if (!self2[ALLOW_STALE])
                hit = void 0;
            } else {
              if (doUse) {
                self2[LRU_LIST].unshiftNode(node);
              }
            }
            if (hit)
              hit = hit.value;
          }
          return hit;
        }
        function isStale(self2, hit) {
          if (!hit || !hit.maxAge && !self2[MAX_AGE]) {
            return false;
          }
          var stale = false;
          var diff = Date.now() - hit.now;
          if (hit.maxAge) {
            stale = diff > hit.maxAge;
          } else {
            stale = self2[MAX_AGE] && diff > self2[MAX_AGE];
          }
          return stale;
        }
        function trim(self2) {
          if (self2[LENGTH] > self2[MAX]) {
            for (var walker = self2[LRU_LIST].tail; self2[LENGTH] > self2[MAX] && walker !== null; ) {
              var prev = walker.prev;
              del(self2, walker);
              walker = prev;
            }
          }
        }
        function del(self2, node) {
          if (node) {
            var hit = node.value;
            if (self2[DISPOSE]) {
              self2[DISPOSE](hit.key, hit.value);
            }
            self2[LENGTH] -= hit.length;
            self2[CACHE].delete(hit.key);
            self2[LRU_LIST].removeNode(node);
          }
        }
        function Entry(key, value2, length, now, maxAge) {
          this.key = key;
          this.value = value2;
          this.length = length;
          this.now = now;
          this.maxAge = maxAge || 0;
        }
      }
    });
    var require_sigmund = __commonJS22({
      "node_modules/sigmund/sigmund.js"(exports2, module22) {
        module22.exports = sigmund;
        function sigmund(subject, maxSessions) {
          maxSessions = maxSessions || 10;
          var notes = [];
          var analysis = "";
          var RE = RegExp;
          function psychoAnalyze(subject2, session) {
            if (session > maxSessions)
              return;
            if (typeof subject2 === "function" || typeof subject2 === "undefined") {
              return;
            }
            if (typeof subject2 !== "object" || !subject2 || subject2 instanceof RE) {
              analysis += subject2;
              return;
            }
            if (notes.indexOf(subject2) !== -1 || session === maxSessions)
              return;
            notes.push(subject2);
            analysis += "{";
            Object.keys(subject2).forEach(function(issue, _, __) {
              if (issue.charAt(0) === "_")
                return;
              var to = typeof subject2[issue];
              if (to === "function" || to === "undefined")
                return;
              analysis += issue;
              psychoAnalyze(subject2[issue], session + 1);
            });
          }
          psychoAnalyze(subject, 0);
          return analysis;
        }
      }
    });
    var require_fnmatch = __commonJS22({
      "node_modules/editorconfig/src/lib/fnmatch.js"(exports2, module22) {
        var platform = typeof process === "object" ? process.platform : "win32";
        if (module22)
          module22.exports = minimatch;
        else
          exports2.minimatch = minimatch;
        minimatch.Minimatch = Minimatch;
        var LRU = require_lru_cache2();
        var cache = minimatch.cache = new LRU({
          max: 100
        });
        var GLOBSTAR = minimatch.GLOBSTAR = Minimatch.GLOBSTAR = {};
        var sigmund = require_sigmund();
        var path2 = require("path");
        var qmark = "[^/]";
        var star = qmark + "*?";
        var twoStarDot = "(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?";
        var twoStarNoDot = "(?:(?!(?:\\/|^)\\.).)*?";
        var reSpecials = charSet("().*{}+?[]^$\\!");
        function charSet(s) {
          return s.split("").reduce(function(set, c) {
            set[c] = true;
            return set;
          }, {});
        }
        var slashSplit = /\/+/;
        minimatch.monkeyPatch = monkeyPatch;
        function monkeyPatch() {
          var desc = Object.getOwnPropertyDescriptor(String.prototype, "match");
          var orig = desc.value;
          desc.value = function(p) {
            if (p instanceof Minimatch)
              return p.match(this);
            return orig.call(this, p);
          };
          Object.defineProperty(String.prototype, desc);
        }
        minimatch.filter = filter;
        function filter(pattern, options) {
          options = options || {};
          return function(p, i, list) {
            return minimatch(p, pattern, options);
          };
        }
        function ext(a, b) {
          a = a || {};
          b = b || {};
          var t3 = {};
          Object.keys(b).forEach(function(k) {
            t3[k] = b[k];
          });
          Object.keys(a).forEach(function(k) {
            t3[k] = a[k];
          });
          return t3;
        }
        minimatch.defaults = function(def) {
          if (!def || !Object.keys(def).length)
            return minimatch;
          var orig = minimatch;
          var m = function minimatch2(p, pattern, options) {
            return orig.minimatch(p, pattern, ext(def, options));
          };
          m.Minimatch = function Minimatch2(pattern, options) {
            return new orig.Minimatch(pattern, ext(def, options));
          };
          return m;
        };
        Minimatch.defaults = function(def) {
          if (!def || !Object.keys(def).length)
            return Minimatch;
          return minimatch.defaults(def).Minimatch;
        };
        function minimatch(p, pattern, options) {
          if (typeof pattern !== "string") {
            throw new TypeError("glob pattern string required");
          }
          if (!options)
            options = {};
          if (!options.nocomment && pattern.charAt(0) === "#") {
            return false;
          }
          if (pattern.trim() === "")
            return p === "";
          return new Minimatch(pattern, options).match(p);
        }
        function Minimatch(pattern, options) {
          if (!(this instanceof Minimatch)) {
            return new Minimatch(pattern, options, cache);
          }
          if (typeof pattern !== "string") {
            throw new TypeError("glob pattern string required");
          }
          if (!options)
            options = {};
          if (platform === "win32") {
            pattern = pattern.split("\\").join("/");
          }
          var cacheKey = pattern + "\n" + sigmund(options);
          var cached = minimatch.cache.get(cacheKey);
          if (cached)
            return cached;
          minimatch.cache.set(cacheKey, this);
          this.options = options;
          this.set = [];
          this.pattern = pattern;
          this.regexp = null;
          this.negate = false;
          this.comment = false;
          this.empty = false;
          this.make();
        }
        Minimatch.prototype.make = make;
        function make() {
          if (this._made)
            return;
          var pattern = this.pattern;
          var options = this.options;
          if (!options.nocomment && pattern.charAt(0) === "#") {
            this.comment = true;
            return;
          }
          if (!pattern) {
            this.empty = true;
            return;
          }
          this.parseNegate();
          var set = this.globSet = this.braceExpand();
          if (options.debug)
            console.error(this.pattern, set);
          set = this.globParts = set.map(function(s) {
            return s.split(slashSplit);
          });
          if (options.debug)
            console.error(this.pattern, set);
          set = set.map(function(s, si, set2) {
            return s.map(this.parse, this);
          }, this);
          if (options.debug)
            console.error(this.pattern, set);
          set = set.filter(function(s) {
            return -1 === s.indexOf(false);
          });
          if (options.debug)
            console.error(this.pattern, set);
          this.set = set;
        }
        Minimatch.prototype.parseNegate = parseNegate;
        function parseNegate() {
          var pattern = this.pattern, negate = false, options = this.options, negateOffset = 0;
          if (options.nonegate)
            return;
          for (var i = 0, l = pattern.length; i < l && pattern.charAt(i) === "!"; i++) {
            negate = !negate;
            negateOffset++;
          }
          if (negateOffset)
            this.pattern = pattern.substr(negateOffset);
          this.negate = negate;
        }
        minimatch.braceExpand = function(pattern, options) {
          return new Minimatch(pattern, options).braceExpand();
        };
        Minimatch.prototype.braceExpand = braceExpand;
        function braceExpand(pattern, options) {
          options = options || this.options;
          pattern = typeof pattern === "undefined" ? this.pattern : pattern;
          if (typeof pattern === "undefined") {
            throw new Error("undefined pattern");
          }
          if (options.nobrace || !pattern.match(/\{.*\}/)) {
            return [pattern];
          }
          var escaping = false;
          if (pattern.charAt(0) !== "{") {
            var prefix = null;
            for (var i = 0, l = pattern.length; i < l; i++) {
              var c = pattern.charAt(i);
              if (c === "\\") {
                escaping = !escaping;
              } else if (c === "{" && !escaping) {
                prefix = pattern.substr(0, i);
                break;
              }
            }
            if (prefix === null) {
              return [pattern];
            }
            var tail = braceExpand(pattern.substr(i), options);
            return tail.map(function(t3) {
              return prefix + t3;
            });
          }
          var numset = pattern.match(/^\{(-?[0-9]+)\.\.(-?[0-9]+)\}/);
          if (numset) {
            var suf = braceExpand(pattern.substr(numset[0].length), options), start = +numset[1], end = +numset[2], inc = start > end ? -1 : 1, set = [];
            for (var i = start; i != end + inc; i += inc) {
              for (var ii = 0, ll = suf.length; ii < ll; ii++) {
                set.push(i + suf[ii]);
              }
            }
            return set;
          }
          var i = 1, depth = 1, set = [], member = "", sawEnd = false, escaping = false;
          function addMember() {
            set.push(member);
            member = "";
          }
          FOR:
            for (i = 1, l = pattern.length; i < l; i++) {
              var c = pattern.charAt(i);
              if (escaping) {
                escaping = false;
                member += "\\" + c;
              } else {
                switch (c) {
                  case "\\":
                    escaping = true;
                    continue;
                  case "{":
                    depth++;
                    member += "{";
                    continue;
                  case "}":
                    depth--;
                    if (depth === 0) {
                      addMember();
                      i++;
                      break FOR;
                    } else {
                      member += c;
                      continue;
                    }
                  case ",":
                    if (depth === 1) {
                      addMember();
                    } else {
                      member += c;
                    }
                    continue;
                  default:
                    member += c;
                    continue;
                }
              }
            }
          if (depth !== 0) {
            return braceExpand("\\" + pattern, options);
          }
          var suf = braceExpand(pattern.substr(i), options);
          var addBraces = set.length === 1;
          set = set.map(function(p) {
            return braceExpand(p, options);
          });
          set = set.reduce(function(l2, r) {
            return l2.concat(r);
          });
          if (addBraces) {
            set = set.map(function(s) {
              return "{" + s + "}";
            });
          }
          var ret = [];
          for (var i = 0, l = set.length; i < l; i++) {
            for (var ii = 0, ll = suf.length; ii < ll; ii++) {
              ret.push(set[i] + suf[ii]);
            }
          }
          return ret;
        }
        Minimatch.prototype.parse = parse3;
        var SUBPARSE = {};
        function parse3(pattern, isSub) {
          var options = this.options;
          if (!options.noglobstar && pattern === "**")
            return GLOBSTAR;
          if (pattern === "")
            return "";
          var re = "", hasMagic = !!options.nocase, escaping = false, patternListStack = [], plType, stateChar, inClass = false, reClassStart = -1, classStart = -1, patternStart = pattern.charAt(0) === "." ? "" : options.dot ? "(?!(?:^|\\/)\\.{1,2}(?:$|\\/))" : "(?!\\.)";
          function clearStateChar() {
            if (stateChar) {
              switch (stateChar) {
                case "*":
                  re += star;
                  hasMagic = true;
                  break;
                case "?":
                  re += qmark;
                  hasMagic = true;
                  break;
                default:
                  re += "\\" + stateChar;
                  break;
              }
              stateChar = false;
            }
          }
          for (var i = 0, len = pattern.length, c; i < len && (c = pattern.charAt(i)); i++) {
            if (options.debug) {
              console.error("%s	%s %s %j", pattern, i, re, c);
            }
            if (escaping && reSpecials[c]) {
              re += "\\" + c;
              escaping = false;
              continue;
            }
            SWITCH:
              switch (c) {
                case "/":
                  return false;
                case "\\":
                  clearStateChar();
                  escaping = true;
                  continue;
                case "?":
                case "*":
                case "+":
                case "@":
                case "!":
                  if (options.debug) {
                    console.error("%s	%s %s %j <-- stateChar", pattern, i, re, c);
                  }
                  if (inClass) {
                    if (c === "!" && i === classStart + 1)
                      c = "^";
                    re += c;
                    continue;
                  }
                  clearStateChar();
                  stateChar = c;
                  if (options.noext)
                    clearStateChar();
                  continue;
                case "(":
                  if (inClass) {
                    re += "(";
                    continue;
                  }
                  if (!stateChar) {
                    re += "\\(";
                    continue;
                  }
                  plType = stateChar;
                  patternListStack.push({
                    type: plType,
                    start: i - 1,
                    reStart: re.length
                  });
                  re += stateChar === "!" ? "(?:(?!" : "(?:";
                  stateChar = false;
                  continue;
                case ")":
                  if (inClass || !patternListStack.length) {
                    re += "\\)";
                    continue;
                  }
                  hasMagic = true;
                  re += ")";
                  plType = patternListStack.pop().type;
                  switch (plType) {
                    case "!":
                      re += "[^/]*?)";
                      break;
                    case "?":
                    case "+":
                    case "*":
                      re += plType;
                    case "@":
                      break;
                  }
                  continue;
                case "|":
                  if (inClass || !patternListStack.length || escaping) {
                    re += "\\|";
                    escaping = false;
                    continue;
                  }
                  re += "|";
                  continue;
                case "[":
                  clearStateChar();
                  if (inClass) {
                    re += "\\" + c;
                    continue;
                  }
                  inClass = true;
                  classStart = i;
                  reClassStart = re.length;
                  re += c;
                  continue;
                case "]":
                  if (i === classStart + 1 || !inClass) {
                    re += "\\" + c;
                    escaping = false;
                    continue;
                  }
                  hasMagic = true;
                  inClass = false;
                  re += c;
                  continue;
                default:
                  clearStateChar();
                  if (escaping) {
                    escaping = false;
                  } else if (reSpecials[c] && !(c === "^" && inClass)) {
                    re += "\\";
                  }
                  re += c;
              }
          }
          if (inClass) {
            var cs = pattern.substr(classStart + 1), sp = this.parse(cs, SUBPARSE);
            re = re.substr(0, reClassStart) + "\\[" + sp[0];
            hasMagic = hasMagic || sp[1];
          }
          var pl;
          while (pl = patternListStack.pop()) {
            var tail = re.slice(pl.reStart + 3);
            tail = tail.replace(/((?:\\{2})*)(\\?)\|/g, function(_, $1, $2) {
              if (!$2) {
                $2 = "\\";
              }
              return $1 + $1 + $2 + "|";
            });
            var t3 = pl.type === "*" ? star : pl.type === "?" ? qmark : "\\" + pl.type;
            hasMagic = true;
            re = re.slice(0, pl.reStart) + t3 + "\\(" + tail;
          }
          clearStateChar();
          if (escaping) {
            re += "\\\\";
          }
          var addPatternStart = false;
          switch (re.charAt(0)) {
            case ".":
            case "[":
            case "(":
              addPatternStart = true;
          }
          if (re !== "" && hasMagic)
            re = "(?=.)" + re;
          if (addPatternStart)
            re = patternStart + re;
          if (isSub === SUBPARSE) {
            return [re, hasMagic];
          }
          if (!hasMagic) {
            return globUnescape(pattern);
          }
          var flags = options.nocase ? "i" : "", regExp = new RegExp("^" + re + "$", flags);
          regExp._glob = pattern;
          regExp._src = re;
          return regExp;
        }
        minimatch.makeRe = function(pattern, options) {
          return new Minimatch(pattern, options || {}).makeRe();
        };
        Minimatch.prototype.makeRe = makeRe;
        function makeRe() {
          if (this.regexp || this.regexp === false)
            return this.regexp;
          var set = this.set;
          if (!set.length)
            return this.regexp = false;
          var options = this.options;
          var twoStar = options.noglobstar ? star : options.dot ? twoStarDot : twoStarNoDot, flags = options.nocase ? "i" : "";
          var re = set.map(function(pattern) {
            return pattern.map(function(p) {
              return p === GLOBSTAR ? twoStar : typeof p === "string" ? regExpEscape(p) : p._src;
            }).join("\\/");
          }).join("|");
          re = "^(?:" + re + ")$";
          if (this.negate)
            re = "^(?!" + re + ").*$";
          try {
            return this.regexp = new RegExp(re, flags);
          } catch (ex) {
            return this.regexp = false;
          }
        }
        minimatch.match = function(list, pattern, options) {
          var mm = new Minimatch(pattern, options);
          list = list.filter(function(f) {
            return mm.match(f);
          });
          if (options.nonull && !list.length) {
            list.push(pattern);
          }
          return list;
        };
        Minimatch.prototype.match = match;
        function match(f, partial) {
          if (this.comment)
            return false;
          if (this.empty)
            return f === "";
          if (f === "/" && partial)
            return true;
          var options = this.options;
          if (platform === "win32") {
            f = f.split("\\").join("/");
          }
          f = f.split(slashSplit);
          if (options.debug) {
            console.error(this.pattern, "split", f);
          }
          var set = this.set;
          for (var i = 0, l = set.length; i < l; i++) {
            var pattern = set[i];
            var hit = this.matchOne(f, pattern, partial);
            if (hit) {
              if (options.flipNegate)
                return true;
              return !this.negate;
            }
          }
          if (options.flipNegate)
            return false;
          return this.negate;
        }
        Minimatch.prototype.matchOne = function(file, pattern, partial) {
          var options = this.options;
          if (options.debug) {
            console.error("matchOne", {
              "this": this,
              file,
              pattern
            });
          }
          if (options.matchBase && pattern.length === 1) {
            file = path2.basename(file.join("/")).split("/");
          }
          if (options.debug) {
            console.error("matchOne", file.length, pattern.length);
          }
          for (var fi = 0, pi = 0, fl = file.length, pl = pattern.length; fi < fl && pi < pl; fi++, pi++) {
            if (options.debug) {
              console.error("matchOne loop");
            }
            var p = pattern[pi], f = file[fi];
            if (options.debug) {
              console.error(pattern, p, f);
            }
            if (p === false)
              return false;
            if (p === GLOBSTAR) {
              if (options.debug)
                console.error("GLOBSTAR", [pattern, p, f]);
              var fr = fi, pr = pi + 1;
              if (pr === pl) {
                if (options.debug)
                  console.error("** at the end");
                for (; fi < fl; fi++) {
                  if (file[fi] === "." || file[fi] === ".." || !options.dot && file[fi].charAt(0) === ".")
                    return false;
                }
                return true;
              }
              WHILE:
                while (fr < fl) {
                  var swallowee = file[fr];
                  if (options.debug) {
                    console.error("\nglobstar while", file, fr, pattern, pr, swallowee);
                  }
                  if (this.matchOne(file.slice(fr), pattern.slice(pr), partial)) {
                    if (options.debug)
                      console.error("globstar found match!", fr, fl, swallowee);
                    return true;
                  } else {
                    if (swallowee === "." || swallowee === ".." || !options.dot && swallowee.charAt(0) === ".") {
                      if (options.debug)
                        console.error("dot detected!", file, fr, pattern, pr);
                      break WHILE;
                    }
                    if (options.debug)
                      console.error("globstar swallow a segment, and continue");
                    fr++;
                  }
                }
              if (partial) {
                if (fr === fl)
                  return true;
              }
              return false;
            }
            var hit;
            if (typeof p === "string") {
              if (options.nocase) {
                hit = f.toLowerCase() === p.toLowerCase();
              } else {
                hit = f === p;
              }
              if (options.debug) {
                console.error("string match", p, f, hit);
              }
            } else {
              hit = f.match(p);
              if (options.debug) {
                console.error("pattern match", p, f, hit);
              }
            }
            if (!hit)
              return false;
          }
          if (fi === fl && pi === pl) {
            return true;
          } else if (fi === fl) {
            return partial;
          } else if (pi === pl) {
            var emptyFileEnd = fi === fl - 1 && file[fi] === "";
            return emptyFileEnd;
          }
          throw new Error("wtf?");
        };
        function globUnescape(s) {
          return s.replace(/\\(.)/g, "$1");
        }
        function regExpEscape(s) {
          return s.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
        }
      }
    });
    var require_ini = __commonJS22({
      "node_modules/editorconfig/src/lib/ini.js"(exports2) {
        "use strict";
        var __awaiter2 = exports2 && exports2.__awaiter || function(thisArg, _arguments, P, generator) {
          return new (P || (P = Promise))(function(resolve, reject) {
            function fulfilled(value2) {
              try {
                step(generator.next(value2));
              } catch (e) {
                reject(e);
              }
            }
            function rejected(value2) {
              try {
                step(generator["throw"](value2));
              } catch (e) {
                reject(e);
              }
            }
            function step(result) {
              result.done ? resolve(result.value) : new P(function(resolve2) {
                resolve2(result.value);
              }).then(fulfilled, rejected);
            }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
          });
        };
        var __generator2 = exports2 && exports2.__generator || function(thisArg, body) {
          var _ = {
            label: 0,
            sent: function() {
              if (t3[0] & 1)
                throw t3[1];
              return t3[1];
            },
            trys: [],
            ops: []
          }, f, y, t3, g;
          return g = {
            next: verb(0),
            "throw": verb(1),
            "return": verb(2)
          }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
            return this;
          }), g;
          function verb(n) {
            return function(v) {
              return step([n, v]);
            };
          }
          function step(op) {
            if (f)
              throw new TypeError("Generator is already executing.");
            while (_)
              try {
                if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
                  return t3;
                if (y = 0, t3)
                  op = [op[0] & 2, t3.value];
                switch (op[0]) {
                  case 0:
                  case 1:
                    t3 = op;
                    break;
                  case 4:
                    _.label++;
                    return {
                      value: op[1],
                      done: false
                    };
                  case 5:
                    _.label++;
                    y = op[1];
                    op = [0];
                    continue;
                  case 7:
                    op = _.ops.pop();
                    _.trys.pop();
                    continue;
                  default:
                    if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                      _ = 0;
                      continue;
                    }
                    if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                      _.label = op[1];
                      break;
                    }
                    if (op[0] === 6 && _.label < t3[1]) {
                      _.label = t3[1];
                      t3 = op;
                      break;
                    }
                    if (t3 && _.label < t3[2]) {
                      _.label = t3[2];
                      _.ops.push(op);
                      break;
                    }
                    if (t3[2])
                      _.ops.pop();
                    _.trys.pop();
                    continue;
                }
                op = body.call(thisArg, _);
              } catch (e) {
                op = [6, e];
                y = 0;
              } finally {
                f = t3 = 0;
              }
            if (op[0] & 5)
              throw op[1];
            return {
              value: op[0] ? op[1] : void 0,
              done: true
            };
          }
        };
        var __importStar2 = exports2 && exports2.__importStar || function(mod) {
          if (mod && mod.__esModule)
            return mod;
          var result = {};
          if (mod != null) {
            for (var k in mod)
              if (Object.hasOwnProperty.call(mod, k))
                result[k] = mod[k];
          }
          result["default"] = mod;
          return result;
        };
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fs2 = __importStar2(require("fs"));
        var regex = {
          section: /^\s*\[(([^#;]|\\#|\\;)+)\]\s*([#;].*)?$/,
          param: /^\s*([\w\.\-\_]+)\s*[=:]\s*(.*?)\s*([#;].*)?$/,
          comment: /^\s*[#;].*$/
        };
        function parse3(file) {
          return __awaiter2(this, void 0, void 0, function() {
            return __generator2(this, function(_a) {
              return [2, new Promise(function(resolve, reject) {
                fs2.readFile(file, "utf8", function(err, data) {
                  if (err) {
                    reject(err);
                    return;
                  }
                  resolve(parseString(data));
                });
              })];
            });
          });
        }
        exports2.parse = parse3;
        function parseSync(file) {
          return parseString(fs2.readFileSync(file, "utf8"));
        }
        exports2.parseSync = parseSync;
        function parseString(data) {
          var sectionBody = {};
          var sectionName = null;
          var value2 = [[sectionName, sectionBody]];
          var lines = data.split(/\r\n|\r|\n/);
          lines.forEach(function(line) {
            var match;
            if (regex.comment.test(line)) {
              return;
            }
            if (regex.param.test(line)) {
              match = line.match(regex.param);
              sectionBody[match[1]] = match[2];
            } else if (regex.section.test(line)) {
              match = line.match(regex.section);
              sectionName = match[1];
              sectionBody = {};
              value2.push([sectionName, sectionBody]);
            }
          });
          return value2;
        }
        exports2.parseString = parseString;
      }
    });
    var require_package8 = __commonJS22({
      "node_modules/editorconfig/package.json"(exports2, module22) {
        module22.exports = {
          name: "editorconfig",
          version: "0.15.3",
          description: "EditorConfig File Locator and Interpreter for Node.js",
          keywords: ["editorconfig", "core"],
          main: "src/index.js",
          contributors: ["Hong Xu (topbug.net)", "Jed Mao (https://github.com/jedmao/)", "Trey Hunner (http://treyhunner.com)"],
          directories: {
            bin: "./bin",
            lib: "./lib"
          },
          scripts: {
            clean: "rimraf dist",
            prebuild: "npm run clean",
            build: "tsc",
            pretest: "npm run lint && npm run build && npm run copy && cmake .",
            test: "ctest .",
            "pretest:ci": "npm run pretest",
            "test:ci": "ctest -VV --output-on-failure .",
            lint: "npm run eclint && npm run tslint",
            eclint: 'eclint check --indent_size ignore "src/**"',
            tslint: "tslint --project tsconfig.json --exclude package.json",
            copy: "cpy .npmignore LICENSE README.md CHANGELOG.md dist && cpy bin/* dist/bin && cpy src/lib/fnmatch*.* dist/src/lib",
            prepub: "npm run lint && npm run build && npm run copy",
            pub: "npm publish ./dist"
          },
          repository: {
            type: "git",
            url: "git://github.com/editorconfig/editorconfig-core-js.git"
          },
          bugs: "https://github.com/editorconfig/editorconfig-core-js/issues",
          author: "EditorConfig Team",
          license: "MIT",
          dependencies: {
            commander: "^2.19.0",
            "lru-cache": "^4.1.5",
            semver: "^5.6.0",
            sigmund: "^1.0.1"
          },
          devDependencies: {
            "@types/mocha": "^5.2.6",
            "@types/node": "^10.12.29",
            "@types/semver": "^5.5.0",
            "cpy-cli": "^2.0.0",
            eclint: "^2.8.1",
            mocha: "^5.2.0",
            rimraf: "^2.6.3",
            should: "^13.2.3",
            tslint: "^5.13.1",
            typescript: "^3.3.3333"
          }
        };
      }
    });
    var require_src22 = __commonJS22({
      "node_modules/editorconfig/src/index.js"(exports2) {
        "use strict";
        var __awaiter2 = exports2 && exports2.__awaiter || function(thisArg, _arguments, P, generator) {
          return new (P || (P = Promise))(function(resolve, reject) {
            function fulfilled(value2) {
              try {
                step(generator.next(value2));
              } catch (e) {
                reject(e);
              }
            }
            function rejected(value2) {
              try {
                step(generator["throw"](value2));
              } catch (e) {
                reject(e);
              }
            }
            function step(result) {
              result.done ? resolve(result.value) : new P(function(resolve2) {
                resolve2(result.value);
              }).then(fulfilled, rejected);
            }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
          });
        };
        var __generator2 = exports2 && exports2.__generator || function(thisArg, body) {
          var _ = {
            label: 0,
            sent: function() {
              if (t3[0] & 1)
                throw t3[1];
              return t3[1];
            },
            trys: [],
            ops: []
          }, f, y, t3, g;
          return g = {
            next: verb(0),
            "throw": verb(1),
            "return": verb(2)
          }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
            return this;
          }), g;
          function verb(n) {
            return function(v) {
              return step([n, v]);
            };
          }
          function step(op) {
            if (f)
              throw new TypeError("Generator is already executing.");
            while (_)
              try {
                if (f = 1, y && (t3 = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t3 = y["return"]) && t3.call(y), 0) : y.next) && !(t3 = t3.call(y, op[1])).done)
                  return t3;
                if (y = 0, t3)
                  op = [op[0] & 2, t3.value];
                switch (op[0]) {
                  case 0:
                  case 1:
                    t3 = op;
                    break;
                  case 4:
                    _.label++;
                    return {
                      value: op[1],
                      done: false
                    };
                  case 5:
                    _.label++;
                    y = op[1];
                    op = [0];
                    continue;
                  case 7:
                    op = _.ops.pop();
                    _.trys.pop();
                    continue;
                  default:
                    if (!(t3 = _.trys, t3 = t3.length > 0 && t3[t3.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                      _ = 0;
                      continue;
                    }
                    if (op[0] === 3 && (!t3 || op[1] > t3[0] && op[1] < t3[3])) {
                      _.label = op[1];
                      break;
                    }
                    if (op[0] === 6 && _.label < t3[1]) {
                      _.label = t3[1];
                      t3 = op;
                      break;
                    }
                    if (t3 && _.label < t3[2]) {
                      _.label = t3[2];
                      _.ops.push(op);
                      break;
                    }
                    if (t3[2])
                      _.ops.pop();
                    _.trys.pop();
                    continue;
                }
                op = body.call(thisArg, _);
              } catch (e) {
                op = [6, e];
                y = 0;
              } finally {
                f = t3 = 0;
              }
            if (op[0] & 5)
              throw op[1];
            return {
              value: op[0] ? op[1] : void 0,
              done: true
            };
          }
        };
        var __importStar2 = exports2 && exports2.__importStar || function(mod) {
          if (mod && mod.__esModule)
            return mod;
          var result = {};
          if (mod != null) {
            for (var k in mod)
              if (Object.hasOwnProperty.call(mod, k))
                result[k] = mod[k];
          }
          result["default"] = mod;
          return result;
        };
        var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
          return mod && mod.__esModule ? mod : {
            "default": mod
          };
        };
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fs2 = __importStar2(require("fs"));
        var path2 = __importStar2(require("path"));
        var semver = {
          gte: require_gte()
        };
        var fnmatch_1 = __importDefault2(require_fnmatch());
        var ini_1 = require_ini();
        exports2.parseString = ini_1.parseString;
        var package_json_1 = __importDefault2(require_package8());
        var knownProps = {
          end_of_line: true,
          indent_style: true,
          indent_size: true,
          insert_final_newline: true,
          trim_trailing_whitespace: true,
          charset: true
        };
        function fnmatch(filepath, glob2) {
          var matchOptions = {
            matchBase: true,
            dot: true,
            noext: true
          };
          glob2 = glob2.replace(/\*\*/g, "{*,**/**/**}");
          return fnmatch_1.default(filepath, glob2, matchOptions);
        }
        function getConfigFileNames(filepath, options) {
          var paths = [];
          do {
            filepath = path2.dirname(filepath);
            paths.push(path2.join(filepath, options.config));
          } while (filepath !== options.root);
          return paths;
        }
        function processMatches(matches, version22) {
          if ("indent_style" in matches && matches.indent_style === "tab" && !("indent_size" in matches) && semver.gte(version22, "0.10.0")) {
            matches.indent_size = "tab";
          }
          if ("indent_size" in matches && !("tab_width" in matches) && matches.indent_size !== "tab") {
            matches.tab_width = matches.indent_size;
          }
          if ("indent_size" in matches && "tab_width" in matches && matches.indent_size === "tab") {
            matches.indent_size = matches.tab_width;
          }
          return matches;
        }
        function processOptions(options, filepath) {
          if (options === void 0) {
            options = {};
          }
          return {
            config: options.config || ".editorconfig",
            version: options.version || package_json_1.default.version,
            root: path2.resolve(options.root || path2.parse(filepath).root)
          };
        }
        function buildFullGlob(pathPrefix, glob2) {
          switch (glob2.indexOf("/")) {
            case -1:
              glob2 = "**/" + glob2;
              break;
            case 0:
              glob2 = glob2.substring(1);
              break;
            default:
              break;
          }
          return path2.join(pathPrefix, glob2);
        }
        function extendProps(props, options) {
          if (props === void 0) {
            props = {};
          }
          if (options === void 0) {
            options = {};
          }
          for (var key in options) {
            if (options.hasOwnProperty(key)) {
              var value2 = options[key];
              var key2 = key.toLowerCase();
              var value22 = value2;
              if (knownProps[key2]) {
                value22 = value2.toLowerCase();
              }
              try {
                value22 = JSON.parse(value2);
              } catch (e) {
              }
              if (typeof value2 === "undefined" || value2 === null) {
                value22 = String(value2);
              }
              props[key2] = value22;
            }
          }
          return props;
        }
        function parseFromConfigs(configs, filepath, options) {
          return processMatches(configs.reverse().reduce(function(matches, file) {
            var pathPrefix = path2.dirname(file.name);
            file.contents.forEach(function(section) {
              var glob2 = section[0];
              var options2 = section[1];
              if (!glob2) {
                return;
              }
              var fullGlob = buildFullGlob(pathPrefix, glob2);
              if (!fnmatch(filepath, fullGlob)) {
                return;
              }
              matches = extendProps(matches, options2);
            });
            return matches;
          }, {}), options.version);
        }
        function getConfigsForFiles(files) {
          var configs = [];
          for (var i in files) {
            if (files.hasOwnProperty(i)) {
              var file = files[i];
              var contents = ini_1.parseString(file.contents);
              configs.push({
                name: file.name,
                contents
              });
              if ((contents[0][1].root || "").toLowerCase() === "true") {
                break;
              }
            }
          }
          return configs;
        }
        function readConfigFiles(filepaths) {
          return __awaiter2(this, void 0, void 0, function() {
            return __generator2(this, function(_a) {
              return [2, Promise.all(filepaths.map(function(name) {
                return new Promise(function(resolve) {
                  fs2.readFile(name, "utf8", function(err, data) {
                    resolve({
                      name,
                      contents: err ? "" : data
                    });
                  });
                });
              }))];
            });
          });
        }
        function readConfigFilesSync(filepaths) {
          var files = [];
          var file;
          filepaths.forEach(function(filepath) {
            try {
              file = fs2.readFileSync(filepath, "utf8");
            } catch (e) {
              file = "";
            }
            files.push({
              name: filepath,
              contents: file
            });
          });
          return files;
        }
        function opts(filepath, options) {
          if (options === void 0) {
            options = {};
          }
          var resolvedFilePath = path2.resolve(filepath);
          return [resolvedFilePath, processOptions(options, resolvedFilePath)];
        }
        function parseFromFiles(filepath, files, options) {
          if (options === void 0) {
            options = {};
          }
          return __awaiter2(this, void 0, void 0, function() {
            var _a, resolvedFilePath, processedOptions;
            return __generator2(this, function(_b) {
              _a = opts(filepath, options), resolvedFilePath = _a[0], processedOptions = _a[1];
              return [2, files.then(getConfigsForFiles).then(function(configs) {
                return parseFromConfigs(configs, resolvedFilePath, processedOptions);
              })];
            });
          });
        }
        exports2.parseFromFiles = parseFromFiles;
        function parseFromFilesSync(filepath, files, options) {
          if (options === void 0) {
            options = {};
          }
          var _a = opts(filepath, options), resolvedFilePath = _a[0], processedOptions = _a[1];
          return parseFromConfigs(getConfigsForFiles(files), resolvedFilePath, processedOptions);
        }
        exports2.parseFromFilesSync = parseFromFilesSync;
        function parse3(_filepath, _options) {
          if (_options === void 0) {
            _options = {};
          }
          return __awaiter2(this, void 0, void 0, function() {
            var _a, resolvedFilePath, processedOptions, filepaths;
            return __generator2(this, function(_b) {
              _a = opts(_filepath, _options), resolvedFilePath = _a[0], processedOptions = _a[1];
              filepaths = getConfigFileNames(resolvedFilePath, processedOptions);
              return [2, readConfigFiles(filepaths).then(getConfigsForFiles).then(function(configs) {
                return parseFromConfigs(configs, resolvedFilePath, processedOptions);
              })];
            });
          });
        }
        exports2.parse = parse3;
        function parseSync(_filepath, _options) {
          if (_options === void 0) {
            _options = {};
          }
          var _a = opts(_filepath, _options), resolvedFilePath = _a[0], processedOptions = _a[1];
          var filepaths = getConfigFileNames(resolvedFilePath, processedOptions);
          var files = readConfigFilesSync(filepaths);
          return parseFromConfigs(getConfigsForFiles(files), resolvedFilePath, processedOptions);
        }
        exports2.parseSync = parseSync;
      }
    });
    var require_editorconfig_to_prettier = __commonJS22({
      "node_modules/editorconfig-to-prettier/index.js"(exports2, module22) {
        module22.exports = editorConfigToPrettier;
        function removeUnset(editorConfig) {
          const result = {};
          const keys3 = Object.keys(editorConfig);
          for (let i = 0; i < keys3.length; i++) {
            const key = keys3[i];
            if (editorConfig[key] === "unset") {
              continue;
            }
            result[key] = editorConfig[key];
          }
          return result;
        }
        function editorConfigToPrettier(editorConfig) {
          if (!editorConfig) {
            return null;
          }
          editorConfig = removeUnset(editorConfig);
          if (Object.keys(editorConfig).length === 0) {
            return null;
          }
          const result = {};
          if (editorConfig.indent_style) {
            result.useTabs = editorConfig.indent_style === "tab";
          }
          if (editorConfig.indent_size === "tab") {
            result.useTabs = true;
          }
          if (result.useTabs && editorConfig.tab_width) {
            result.tabWidth = editorConfig.tab_width;
          } else if (editorConfig.indent_style === "space" && editorConfig.indent_size && editorConfig.indent_size !== "tab") {
            result.tabWidth = editorConfig.indent_size;
          } else if (editorConfig.tab_width !== void 0) {
            result.tabWidth = editorConfig.tab_width;
          }
          if (editorConfig.max_line_length && editorConfig.max_line_length !== "off") {
            result.printWidth = editorConfig.max_line_length;
          }
          if (editorConfig.quote_type === "single") {
            result.singleQuote = true;
          } else if (editorConfig.quote_type === "double") {
            result.singleQuote = false;
          }
          if (["cr", "crlf", "lf"].indexOf(editorConfig.end_of_line) !== -1) {
            result.endOfLine = editorConfig.end_of_line;
          }
          if (editorConfig.insert_final_newline === false || editorConfig.insert_final_newline === true) {
            result.insertFinalNewline = editorConfig.insert_final_newline;
          }
          return result;
        }
      }
    });
    var require_find_project_root = __commonJS22({
      "src/config/find-project-root.js"(exports2, module22) {
        "use strict";
        var fs2 = require("fs");
        var path2 = require("path");
        var MARKERS = [".git", ".hg"];
        var markerExists = (directory) => MARKERS.some((mark) => fs2.existsSync(path2.join(directory, mark)));
        function findProjectRoot(directory) {
          while (!markerExists(directory)) {
            const parentDirectory = path2.resolve(directory, "..");
            if (parentDirectory === directory) {
              break;
            }
            directory = parentDirectory;
          }
          return directory;
        }
        module22.exports = findProjectRoot;
      }
    });
    var require_resolve_config_editorconfig = __commonJS22({
      "src/config/resolve-config-editorconfig.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var editorconfig = require_src22();
        var editorConfigToPrettier = require_editorconfig_to_prettier();
        var {
          default: mem2,
          memClear: memClear2
        } = (init_dist(), __toCommonJS(dist_exports));
        var findProjectRoot = require_find_project_root();
        var jsonStringifyMem = (fn) => mem2(fn, {
          cacheKey: JSON.stringify
        });
        var maybeParse = (filePath, parse3) => filePath && parse3(filePath, {
          root: findProjectRoot(path2.dirname(path2.resolve(filePath)))
        });
        var editorconfigAsyncNoCache = async (filePath) => editorConfigToPrettier(await maybeParse(filePath, editorconfig.parse));
        var editorconfigAsyncWithCache = jsonStringifyMem(editorconfigAsyncNoCache);
        var editorconfigSyncNoCache = (filePath) => editorConfigToPrettier(maybeParse(filePath, editorconfig.parseSync));
        var editorconfigSyncWithCache = jsonStringifyMem(editorconfigSyncNoCache);
        function getLoadFunction(opts) {
          if (!opts.editorconfig) {
            return () => null;
          }
          if (opts.sync) {
            return opts.cache ? editorconfigSyncWithCache : editorconfigSyncNoCache;
          }
          return opts.cache ? editorconfigAsyncWithCache : editorconfigAsyncNoCache;
        }
        function clearCache() {
          memClear2(editorconfigSyncWithCache);
          memClear2(editorconfigAsyncWithCache);
        }
        module22.exports = {
          getLoadFunction,
          clearCache
        };
      }
    });
    var require_resolve_config = __commonJS22({
      "src/config/resolve-config.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var micromatch = require_micromatch();
        var thirdParty = require_third_party();
        var loadToml = require_load_toml();
        var loadJson5 = require_load_json5();
        var partition = require_partition3();
        var resolve = require_resolve22();
        var {
          default: mem2,
          memClear: memClear2
        } = (init_dist(), __toCommonJS(dist_exports));
        var resolveEditorConfig = require_resolve_config_editorconfig();
        var getExplorerMemoized = mem2((opts) => {
          const cosmiconfig = thirdParty["cosmiconfig" + (opts.sync ? "Sync" : "")];
          const explorer = cosmiconfig("prettier", {
            cache: opts.cache,
            transform: (result) => {
              if (result && result.config) {
                if (typeof result.config === "string") {
                  const dir = path2.dirname(result.filepath);
                  const modulePath = resolve(result.config, {
                    paths: [dir]
                  });
                  result.config = require(modulePath);
                }
                if (typeof result.config !== "object") {
                  throw new TypeError(`Config is only allowed to be an object, but received ${typeof result.config} in "${result.filepath}"`);
                }
                delete result.config.$schema;
              }
              return result;
            },
            searchPlaces: ["package.json", ".prettierrc", ".prettierrc.json", ".prettierrc.yaml", ".prettierrc.yml", ".prettierrc.json5", ".prettierrc.js", ".prettierrc.cjs", "prettier.config.js", "prettier.config.cjs", ".prettierrc.toml"],
            loaders: {
              ".toml": loadToml,
              ".json5": loadJson5
            }
          });
          return explorer;
        }, {
          cacheKey: JSON.stringify
        });
        function getExplorer(opts) {
          opts = Object.assign({
            sync: false,
            cache: false
          }, opts);
          return getExplorerMemoized(opts);
        }
        function _resolveConfig(filePath, opts, sync) {
          opts = Object.assign({
            useCache: true
          }, opts);
          const loadOpts = {
            cache: Boolean(opts.useCache),
            sync: Boolean(sync),
            editorconfig: Boolean(opts.editorconfig)
          };
          const {
            load,
            search
          } = getExplorer(loadOpts);
          const loadEditorConfig = resolveEditorConfig.getLoadFunction(loadOpts);
          const arr = [opts.config ? load(opts.config) : search(filePath), loadEditorConfig(filePath)];
          const unwrapAndMerge = ([result, editorConfigured]) => {
            const merged = Object.assign(Object.assign({}, editorConfigured), mergeOverrides(result, filePath));
            for (const optionName of ["plugins", "pluginSearchDirs"]) {
              if (Array.isArray(merged[optionName])) {
                merged[optionName] = merged[optionName].map((value2) => typeof value2 === "string" && value2.startsWith(".") ? path2.resolve(path2.dirname(result.filepath), value2) : value2);
              }
            }
            if (!result && !editorConfigured) {
              return null;
            }
            delete merged.insertFinalNewline;
            return merged;
          };
          if (loadOpts.sync) {
            return unwrapAndMerge(arr);
          }
          return Promise.all(arr).then(unwrapAndMerge);
        }
        var resolveConfig = (filePath, opts) => _resolveConfig(filePath, opts, false);
        resolveConfig.sync = (filePath, opts) => _resolveConfig(filePath, opts, true);
        function clearCache() {
          memClear2(getExplorerMemoized);
          resolveEditorConfig.clearCache();
        }
        async function resolveConfigFile(filePath) {
          const {
            search
          } = getExplorer({
            sync: false
          });
          const result = await search(filePath);
          return result ? result.filepath : null;
        }
        resolveConfigFile.sync = (filePath) => {
          const {
            search
          } = getExplorer({
            sync: true
          });
          const result = search(filePath);
          return result ? result.filepath : null;
        };
        function mergeOverrides(configResult, filePath) {
          const {
            config: config2,
            filepath: configPath
          } = configResult || {};
          const _ref = config2 || {}, {
            overrides
          } = _ref, options = _objectWithoutProperties(_ref, _excluded3);
          if (filePath && overrides) {
            const relativeFilePath = path2.relative(path2.dirname(configPath), filePath);
            for (const override of overrides) {
              if (pathMatchesGlobs(relativeFilePath, override.files, override.excludeFiles)) {
                Object.assign(options, override.options);
              }
            }
          }
          return options;
        }
        function pathMatchesGlobs(filePath, patterns, excludedPatterns) {
          const patternList = Array.isArray(patterns) ? patterns : [patterns];
          const [withSlashes, withoutSlashes] = partition(patternList, (pattern) => pattern.includes("/"));
          return micromatch.isMatch(filePath, withoutSlashes, {
            ignore: excludedPatterns,
            basename: true,
            dot: true
          }) || micromatch.isMatch(filePath, withSlashes, {
            ignore: excludedPatterns,
            basename: false,
            dot: true
          });
        }
        module22.exports = {
          resolveConfig,
          resolveConfigFile,
          clearCache
        };
      }
    });
    var require_ignore2 = __commonJS22({
      "node_modules/ignore/index.js"(exports2, module22) {
        function makeArray(subject) {
          return Array.isArray(subject) ? subject : [subject];
        }
        var EMPTY = "";
        var SPACE = " ";
        var ESCAPE = "\\";
        var REGEX_TEST_BLANK_LINE = /^\s+$/;
        var REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION = /^\\!/;
        var REGEX_REPLACE_LEADING_EXCAPED_HASH = /^\\#/;
        var REGEX_SPLITALL_CRLF = /\r?\n/g;
        var REGEX_TEST_INVALID_PATH = /^\.*\/|^\.+$/;
        var SLASH = "/";
        var KEY_IGNORE = typeof Symbol !== "undefined" ? Symbol.for("node-ignore") : "node-ignore";
        var define2 = (object, key, value2) => Object.defineProperty(object, key, {
          value: value2
        });
        var REGEX_REGEXP_RANGE = /([0-z])-([0-z])/g;
        var RETURN_FALSE = () => false;
        var sanitizeRange = (range) => range.replace(REGEX_REGEXP_RANGE, (match, from, to) => from.charCodeAt(0) <= to.charCodeAt(0) ? match : EMPTY);
        var cleanRangeBackSlash = (slashes) => {
          const {
            length
          } = slashes;
          return slashes.slice(0, length - length % 2);
        };
        var REPLACERS = [[/\\?\s+$/, (match) => match.indexOf("\\") === 0 ? SPACE : EMPTY], [/\\\s/g, () => SPACE], [/[\\$.|*+(){^]/g, (match) => `\\${match}`], [/(?!\\)\?/g, () => "[^/]"], [/^\//, () => "^"], [/\//g, () => "\\/"], [/^\^*\\\*\\\*\\\//, () => "^(?:.*\\/)?"], [/^(?=[^^])/, function startingReplacer() {
          return !/\/(?!$)/.test(this) ? "(?:^|\\/)" : "^";
        }], [/\\\/\\\*\\\*(?=\\\/|$)/g, (_, index, str) => index + 6 < str.length ? "(?:\\/[^\\/]+)*" : "\\/.+"], [/(^|[^\\]+)\\\*(?=.+)/g, (_, p1) => `${p1}[^\\/]*`], [/\\\\\\(?=[$.|*+(){^])/g, () => ESCAPE], [/\\\\/g, () => ESCAPE], [/(\\)?\[([^\]/]*?)(\\*)($|\])/g, (match, leadEscape, range, endEscape, close) => leadEscape === ESCAPE ? `\\[${range}${cleanRangeBackSlash(endEscape)}${close}` : close === "]" ? endEscape.length % 2 === 0 ? `[${sanitizeRange(range)}${endEscape}]` : "[]" : "[]"], [/(?:[^*])$/, (match) => /\/$/.test(match) ? `${match}$` : `${match}(?=$|\\/$)`], [/(\^|\\\/)?\\\*$/, (_, p1) => {
          const prefix = p1 ? `${p1}[^/]+` : "[^/]*";
          return `${prefix}(?=$|\\/$)`;
        }]];
        var regexCache = /* @__PURE__ */ Object.create(null);
        var makeRegex = (pattern, ignoreCase) => {
          let source = regexCache[pattern];
          if (!source) {
            source = REPLACERS.reduce((prev, current) => prev.replace(current[0], current[1].bind(pattern)), pattern);
            regexCache[pattern] = source;
          }
          return ignoreCase ? new RegExp(source, "i") : new RegExp(source);
        };
        var isString = (subject) => typeof subject === "string";
        var checkPattern = (pattern) => pattern && isString(pattern) && !REGEX_TEST_BLANK_LINE.test(pattern) && pattern.indexOf("#") !== 0;
        var splitPattern = (pattern) => pattern.split(REGEX_SPLITALL_CRLF);
        var IgnoreRule = class {
          constructor(origin, pattern, negative, regex) {
            this.origin = origin;
            this.pattern = pattern;
            this.negative = negative;
            this.regex = regex;
          }
        };
        var createRule = (pattern, ignoreCase) => {
          const origin = pattern;
          let negative = false;
          if (pattern.indexOf("!") === 0) {
            negative = true;
            pattern = pattern.substr(1);
          }
          pattern = pattern.replace(REGEX_REPLACE_LEADING_EXCAPED_EXCLAMATION, "!").replace(REGEX_REPLACE_LEADING_EXCAPED_HASH, "#");
          const regex = makeRegex(pattern, ignoreCase);
          return new IgnoreRule(origin, pattern, negative, regex);
        };
        var throwError = (message, Ctor) => {
          throw new Ctor(message);
        };
        var checkPath = (path2, originalPath, doThrow) => {
          if (!isString(path2)) {
            return doThrow(`path must be a string, but got \`${originalPath}\``, TypeError);
          }
          if (!path2) {
            return doThrow(`path must not be empty`, TypeError);
          }
          if (checkPath.isNotRelative(path2)) {
            const r = "`path.relative()`d";
            return doThrow(`path should be a ${r} string, but got "${originalPath}"`, RangeError);
          }
          return true;
        };
        var isNotRelative = (path2) => REGEX_TEST_INVALID_PATH.test(path2);
        checkPath.isNotRelative = isNotRelative;
        checkPath.convert = (p) => p;
        var Ignore = class {
          constructor({
            ignorecase = true,
            ignoreCase = ignorecase,
            allowRelativePaths = false
          } = {}) {
            define2(this, KEY_IGNORE, true);
            this._rules = [];
            this._ignoreCase = ignoreCase;
            this._allowRelativePaths = allowRelativePaths;
            this._initCache();
          }
          _initCache() {
            this._ignoreCache = /* @__PURE__ */ Object.create(null);
            this._testCache = /* @__PURE__ */ Object.create(null);
          }
          _addPattern(pattern) {
            if (pattern && pattern[KEY_IGNORE]) {
              this._rules = this._rules.concat(pattern._rules);
              this._added = true;
              return;
            }
            if (checkPattern(pattern)) {
              const rule = createRule(pattern, this._ignoreCase);
              this._added = true;
              this._rules.push(rule);
            }
          }
          add(pattern) {
            this._added = false;
            makeArray(isString(pattern) ? splitPattern(pattern) : pattern).forEach(this._addPattern, this);
            if (this._added) {
              this._initCache();
            }
            return this;
          }
          addPattern(pattern) {
            return this.add(pattern);
          }
          _testOne(path2, checkUnignored) {
            let ignored = false;
            let unignored = false;
            this._rules.forEach((rule) => {
              const {
                negative
              } = rule;
              if (unignored === negative && ignored !== unignored || negative && !ignored && !unignored && !checkUnignored) {
                return;
              }
              const matched = rule.regex.test(path2);
              if (matched) {
                ignored = !negative;
                unignored = negative;
              }
            });
            return {
              ignored,
              unignored
            };
          }
          _test(originalPath, cache, checkUnignored, slices) {
            const path2 = originalPath && checkPath.convert(originalPath);
            checkPath(path2, originalPath, this._allowRelativePaths ? RETURN_FALSE : throwError);
            return this._t(path2, cache, checkUnignored, slices);
          }
          _t(path2, cache, checkUnignored, slices) {
            if (path2 in cache) {
              return cache[path2];
            }
            if (!slices) {
              slices = path2.split(SLASH);
            }
            slices.pop();
            if (!slices.length) {
              return cache[path2] = this._testOne(path2, checkUnignored);
            }
            const parent = this._t(slices.join(SLASH) + SLASH, cache, checkUnignored, slices);
            return cache[path2] = parent.ignored ? parent : this._testOne(path2, checkUnignored);
          }
          ignores(path2) {
            return this._test(path2, this._ignoreCache, false).ignored;
          }
          createFilter() {
            return (path2) => !this.ignores(path2);
          }
          filter(paths) {
            return makeArray(paths).filter(this.createFilter());
          }
          test(path2) {
            return this._test(path2, this._testCache, true);
          }
        };
        var factory = (options) => new Ignore(options);
        var isPathValid = (path2) => checkPath(path2 && checkPath.convert(path2), path2, RETURN_FALSE);
        factory.isPathValid = isPathValid;
        factory.default = factory;
        module22.exports = factory;
        if (typeof process !== "undefined" && (process.env && process.env.IGNORE_TEST_WIN32 || process.platform === "win32")) {
          const makePosix = (str) => /^\\\\\?\\/.test(str) || /["<>|\u0000-\u001F]+/u.test(str) ? str : str.replace(/\\/g, "/");
          checkPath.convert = makePosix;
          const REGIX_IS_WINDOWS_PATH_ABSOLUTE = /^[a-z]:\//i;
          checkPath.isNotRelative = (path2) => REGIX_IS_WINDOWS_PATH_ABSOLUTE.test(path2) || isNotRelative(path2);
        }
      }
    });
    var require_get_file_content_or_null = __commonJS22({
      "src/utils/get-file-content-or-null.js"(exports2, module22) {
        "use strict";
        var fs2 = require("fs");
        var fsAsync = fs2.promises;
        async function getFileContentOrNull(filename) {
          try {
            return await fsAsync.readFile(filename, "utf8");
          } catch (error) {
            return handleError(filename, error);
          }
        }
        getFileContentOrNull.sync = function(filename) {
          try {
            return fs2.readFileSync(filename, "utf8");
          } catch (error) {
            return handleError(filename, error);
          }
        };
        function handleError(filename, error) {
          if (error && error.code === "ENOENT") {
            return null;
          }
          throw new Error(`Unable to read ${filename}: ${error.message}`);
        }
        module22.exports = getFileContentOrNull;
      }
    });
    var require_create_ignorer = __commonJS22({
      "src/common/create-ignorer.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var ignore = require_ignore2().default;
        var getFileContentOrNull = require_get_file_content_or_null();
        async function createIgnorer(ignorePath, withNodeModules) {
          const ignoreContent = ignorePath ? await getFileContentOrNull(path2.resolve(ignorePath)) : null;
          return _createIgnorer(ignoreContent, withNodeModules);
        }
        createIgnorer.sync = function(ignorePath, withNodeModules) {
          const ignoreContent = !ignorePath ? null : getFileContentOrNull.sync(path2.resolve(ignorePath));
          return _createIgnorer(ignoreContent, withNodeModules);
        };
        function _createIgnorer(ignoreContent, withNodeModules) {
          const ignorer = ignore({
            allowRelativePaths: true
          }).add(ignoreContent || "");
          if (!withNodeModules) {
            ignorer.add("node_modules");
          }
          return ignorer;
        }
        module22.exports = createIgnorer;
      }
    });
    var require_get_file_info = __commonJS22({
      "src/common/get-file-info.js"(exports2, module22) {
        "use strict";
        var path2 = require("path");
        var options = require_options4();
        var config2 = require_resolve_config();
        var createIgnorer = require_create_ignorer();
        async function getFileInfo2(filePath, opts) {
          if (typeof filePath !== "string") {
            throw new TypeError(`expect \`filePath\` to be a string, got \`${typeof filePath}\``);
          }
          const ignorer = await createIgnorer(opts.ignorePath, opts.withNodeModules);
          return _getFileInfo({
            ignorer,
            filePath,
            plugins: opts.plugins,
            resolveConfig: opts.resolveConfig,
            ignorePath: opts.ignorePath,
            sync: false
          });
        }
        getFileInfo2.sync = function(filePath, opts) {
          if (typeof filePath !== "string") {
            throw new TypeError(`expect \`filePath\` to be a string, got \`${typeof filePath}\``);
          }
          const ignorer = createIgnorer.sync(opts.ignorePath, opts.withNodeModules);
          return _getFileInfo({
            ignorer,
            filePath,
            plugins: opts.plugins,
            resolveConfig: opts.resolveConfig,
            ignorePath: opts.ignorePath,
            sync: true
          });
        };
        function getFileParser(resolvedConfig, filePath, plugins2) {
          if (resolvedConfig && resolvedConfig.parser) {
            return resolvedConfig.parser;
          }
          const inferredParser = options.inferParser(filePath, plugins2);
          if (inferredParser) {
            return inferredParser;
          }
          return null;
        }
        function _getFileInfo({
          ignorer,
          filePath,
          plugins: plugins2,
          resolveConfig = false,
          ignorePath,
          sync = false
        }) {
          const normalizedFilePath = normalizeFilePath(filePath, ignorePath);
          const fileInfo = {
            ignored: ignorer.ignores(normalizedFilePath),
            inferredParser: null
          };
          if (fileInfo.ignored) {
            return fileInfo;
          }
          let resolvedConfig;
          if (resolveConfig) {
            if (sync) {
              resolvedConfig = config2.resolveConfig.sync(filePath);
            } else {
              return config2.resolveConfig(filePath).then((resolvedConfig2) => {
                fileInfo.inferredParser = getFileParser(resolvedConfig2, filePath, plugins2);
                return fileInfo;
              });
            }
          }
          fileInfo.inferredParser = getFileParser(resolvedConfig, filePath, plugins2);
          return fileInfo;
        }
        function normalizeFilePath(filePath, ignorePath) {
          return ignorePath ? path2.relative(path2.dirname(ignorePath), filePath) : filePath;
        }
        module22.exports = getFileInfo2;
      }
    });
    var require_util_shared = __commonJS22({
      "src/common/util-shared.js"(exports2, module22) {
        "use strict";
        var {
          getMaxContinuousCount,
          getStringWidth,
          getAlignmentSize,
          getIndentSize,
          skip,
          skipWhitespace,
          skipSpaces,
          skipNewline,
          skipToLineEnd,
          skipEverythingButNewLine,
          skipInlineComment,
          skipTrailingComment,
          hasNewline,
          hasNewlineInRange,
          hasSpaces,
          isNextLineEmpty,
          isNextLineEmptyAfterIndex,
          isPreviousLineEmpty,
          getNextNonSpaceNonCommentCharacterIndex,
          makeString,
          addLeadingComment,
          addDanglingComment,
          addTrailingComment
        } = require_util6();
        module22.exports = {
          getMaxContinuousCount,
          getStringWidth,
          getAlignmentSize,
          getIndentSize,
          skip,
          skipWhitespace,
          skipSpaces,
          skipNewline,
          skipToLineEnd,
          skipEverythingButNewLine,
          skipInlineComment,
          skipTrailingComment,
          hasNewline,
          hasNewlineInRange,
          hasSpaces,
          isNextLineEmpty,
          isNextLineEmptyAfterIndex,
          isPreviousLineEmpty,
          getNextNonSpaceNonCommentCharacterIndex,
          makeString,
          addLeadingComment,
          addDanglingComment,
          addTrailingComment
        };
      }
    });
    var require_array3 = __commonJS22({
      "node_modules/fast-glob/out/utils/array.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.splitWhen = exports2.flatten = void 0;
        function flatten(items) {
          return items.reduce((collection, item) => [].concat(collection, item), []);
        }
        exports2.flatten = flatten;
        function splitWhen(items, predicate) {
          const result = [[]];
          let groupIndex = 0;
          for (const item of items) {
            if (predicate(item)) {
              groupIndex++;
              result[groupIndex] = [];
            } else {
              result[groupIndex].push(item);
            }
          }
          return result;
        }
        exports2.splitWhen = splitWhen;
      }
    });
    var require_errno = __commonJS22({
      "node_modules/fast-glob/out/utils/errno.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isEnoentCodeError = void 0;
        function isEnoentCodeError(error) {
          return error.code === "ENOENT";
        }
        exports2.isEnoentCodeError = isEnoentCodeError;
      }
    });
    var require_fs6 = __commonJS22({
      "node_modules/fast-glob/out/utils/fs.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.createDirentFromStats = void 0;
        var DirentFromStats = class {
          constructor(name, stats) {
            this.name = name;
            this.isBlockDevice = stats.isBlockDevice.bind(stats);
            this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
            this.isDirectory = stats.isDirectory.bind(stats);
            this.isFIFO = stats.isFIFO.bind(stats);
            this.isFile = stats.isFile.bind(stats);
            this.isSocket = stats.isSocket.bind(stats);
            this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
          }
        };
        function createDirentFromStats(name, stats) {
          return new DirentFromStats(name, stats);
        }
        exports2.createDirentFromStats = createDirentFromStats;
      }
    });
    var require_path2 = __commonJS22({
      "node_modules/fast-glob/out/utils/path.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.removeLeadingDotSegment = exports2.escape = exports2.makeAbsolute = exports2.unixify = void 0;
        var path2 = require("path");
        var LEADING_DOT_SEGMENT_CHARACTERS_COUNT = 2;
        var UNESCAPED_GLOB_SYMBOLS_RE = /(\\?)([()*?[\]{|}]|^!|[!+@](?=\())/g;
        function unixify(filepath) {
          return filepath.replace(/\\/g, "/");
        }
        exports2.unixify = unixify;
        function makeAbsolute(cwd, filepath) {
          return path2.resolve(cwd, filepath);
        }
        exports2.makeAbsolute = makeAbsolute;
        function escape2(pattern) {
          return pattern.replace(UNESCAPED_GLOB_SYMBOLS_RE, "\\$2");
        }
        exports2.escape = escape2;
        function removeLeadingDotSegment(entry) {
          if (entry.charAt(0) === ".") {
            const secondCharactery = entry.charAt(1);
            if (secondCharactery === "/" || secondCharactery === "\\") {
              return entry.slice(LEADING_DOT_SEGMENT_CHARACTERS_COUNT);
            }
          }
          return entry;
        }
        exports2.removeLeadingDotSegment = removeLeadingDotSegment;
      }
    });
    var require_is_extglob2 = __commonJS22({
      "node_modules/is-extglob/index.js"(exports2, module22) {
        module22.exports = function isExtglob(str) {
          if (typeof str !== "string" || str === "") {
            return false;
          }
          var match;
          while (match = /(\\).|([@?!+*]\(.*\))/g.exec(str)) {
            if (match[2])
              return true;
            str = str.slice(match.index + match[0].length);
          }
          return false;
        };
      }
    });
    var require_is_glob2 = __commonJS22({
      "node_modules/is-glob/index.js"(exports2, module22) {
        var isExtglob = require_is_extglob2();
        var chars = {
          "{": "}",
          "(": ")",
          "[": "]"
        };
        var strictCheck = function(str) {
          if (str[0] === "!") {
            return true;
          }
          var index = 0;
          var pipeIndex = -2;
          var closeSquareIndex = -2;
          var closeCurlyIndex = -2;
          var closeParenIndex = -2;
          var backSlashIndex = -2;
          while (index < str.length) {
            if (str[index] === "*") {
              return true;
            }
            if (str[index + 1] === "?" && /[\].+)]/.test(str[index])) {
              return true;
            }
            if (closeSquareIndex !== -1 && str[index] === "[" && str[index + 1] !== "]") {
              if (closeSquareIndex < index) {
                closeSquareIndex = str.indexOf("]", index);
              }
              if (closeSquareIndex > index) {
                if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
                  return true;
                }
                backSlashIndex = str.indexOf("\\", index);
                if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
                  return true;
                }
              }
            }
            if (closeCurlyIndex !== -1 && str[index] === "{" && str[index + 1] !== "}") {
              closeCurlyIndex = str.indexOf("}", index);
              if (closeCurlyIndex > index) {
                backSlashIndex = str.indexOf("\\", index);
                if (backSlashIndex === -1 || backSlashIndex > closeCurlyIndex) {
                  return true;
                }
              }
            }
            if (closeParenIndex !== -1 && str[index] === "(" && str[index + 1] === "?" && /[:!=]/.test(str[index + 2]) && str[index + 3] !== ")") {
              closeParenIndex = str.indexOf(")", index);
              if (closeParenIndex > index) {
                backSlashIndex = str.indexOf("\\", index);
                if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                  return true;
                }
              }
            }
            if (pipeIndex !== -1 && str[index] === "(" && str[index + 1] !== "|") {
              if (pipeIndex < index) {
                pipeIndex = str.indexOf("|", index);
              }
              if (pipeIndex !== -1 && str[pipeIndex + 1] !== ")") {
                closeParenIndex = str.indexOf(")", pipeIndex);
                if (closeParenIndex > pipeIndex) {
                  backSlashIndex = str.indexOf("\\", pipeIndex);
                  if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                    return true;
                  }
                }
              }
            }
            if (str[index] === "\\") {
              var open = str[index + 1];
              index += 2;
              var close = chars[open];
              if (close) {
                var n = str.indexOf(close, index);
                if (n !== -1) {
                  index = n + 1;
                }
              }
              if (str[index] === "!") {
                return true;
              }
            } else {
              index++;
            }
          }
          return false;
        };
        var relaxedCheck = function(str) {
          if (str[0] === "!") {
            return true;
          }
          var index = 0;
          while (index < str.length) {
            if (/[*?{}()[\]]/.test(str[index])) {
              return true;
            }
            if (str[index] === "\\") {
              var open = str[index + 1];
              index += 2;
              var close = chars[open];
              if (close) {
                var n = str.indexOf(close, index);
                if (n !== -1) {
                  index = n + 1;
                }
              }
              if (str[index] === "!") {
                return true;
              }
            } else {
              index++;
            }
          }
          return false;
        };
        module22.exports = function isGlob(str, options) {
          if (typeof str !== "string" || str === "") {
            return false;
          }
          if (isExtglob(str)) {
            return true;
          }
          var check = strictCheck;
          if (options && options.strict === false) {
            check = relaxedCheck;
          }
          return check(str);
        };
      }
    });
    var require_glob_parent2 = __commonJS22({
      "node_modules/glob-parent/index.js"(exports2, module22) {
        "use strict";
        var isGlob = require_is_glob2();
        var pathPosixDirname = require("path").posix.dirname;
        var isWin32 = require("os").platform() === "win32";
        var slash = "/";
        var backslash = /\\/g;
        var enclosure = /[\{\[].*[\}\]]$/;
        var globby = /(^|[^\\])([\{\[]|\([^\)]+$)/;
        var escaped = /\\([\!\*\?\|\[\]\(\)\{\}])/g;
        module22.exports = function globParent(str, opts) {
          var options = Object.assign({
            flipBackslashes: true
          }, opts);
          if (options.flipBackslashes && isWin32 && str.indexOf(slash) < 0) {
            str = str.replace(backslash, slash);
          }
          if (enclosure.test(str)) {
            str += slash;
          }
          str += "a";
          do {
            str = pathPosixDirname(str);
          } while (isGlob(str) || globby.test(str));
          return str.replace(escaped, "$1");
        };
      }
    });
    var require_pattern2 = __commonJS22({
      "node_modules/fast-glob/out/utils/pattern.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.matchAny = exports2.convertPatternsToRe = exports2.makeRe = exports2.getPatternParts = exports2.expandBraceExpansion = exports2.expandPatternsWithBraceExpansion = exports2.isAffectDepthOfReadingPattern = exports2.endsWithSlashGlobStar = exports2.hasGlobStar = exports2.getBaseDirectory = exports2.isPatternRelatedToParentDirectory = exports2.getPatternsOutsideCurrentDirectory = exports2.getPatternsInsideCurrentDirectory = exports2.getPositivePatterns = exports2.getNegativePatterns = exports2.isPositivePattern = exports2.isNegativePattern = exports2.convertToNegativePattern = exports2.convertToPositivePattern = exports2.isDynamicPattern = exports2.isStaticPattern = void 0;
        var path2 = require("path");
        var globParent = require_glob_parent2();
        var micromatch = require_micromatch();
        var GLOBSTAR = "**";
        var ESCAPE_SYMBOL = "\\";
        var COMMON_GLOB_SYMBOLS_RE = /[*?]|^!/;
        var REGEX_CHARACTER_CLASS_SYMBOLS_RE = /\[[^[]*]/;
        var REGEX_GROUP_SYMBOLS_RE = /(?:^|[^!*+?@])\([^(]*\|[^|]*\)/;
        var GLOB_EXTENSION_SYMBOLS_RE = /[!*+?@]\([^(]*\)/;
        var BRACE_EXPANSION_SEPARATORS_RE = /,|\.\./;
        function isStaticPattern(pattern, options = {}) {
          return !isDynamicPattern(pattern, options);
        }
        exports2.isStaticPattern = isStaticPattern;
        function isDynamicPattern(pattern, options = {}) {
          if (pattern === "") {
            return false;
          }
          if (options.caseSensitiveMatch === false || pattern.includes(ESCAPE_SYMBOL)) {
            return true;
          }
          if (COMMON_GLOB_SYMBOLS_RE.test(pattern) || REGEX_CHARACTER_CLASS_SYMBOLS_RE.test(pattern) || REGEX_GROUP_SYMBOLS_RE.test(pattern)) {
            return true;
          }
          if (options.extglob !== false && GLOB_EXTENSION_SYMBOLS_RE.test(pattern)) {
            return true;
          }
          if (options.braceExpansion !== false && hasBraceExpansion(pattern)) {
            return true;
          }
          return false;
        }
        exports2.isDynamicPattern = isDynamicPattern;
        function hasBraceExpansion(pattern) {
          const openingBraceIndex = pattern.indexOf("{");
          if (openingBraceIndex === -1) {
            return false;
          }
          const closingBraceIndex = pattern.indexOf("}", openingBraceIndex + 1);
          if (closingBraceIndex === -1) {
            return false;
          }
          const braceContent = pattern.slice(openingBraceIndex, closingBraceIndex);
          return BRACE_EXPANSION_SEPARATORS_RE.test(braceContent);
        }
        function convertToPositivePattern(pattern) {
          return isNegativePattern(pattern) ? pattern.slice(1) : pattern;
        }
        exports2.convertToPositivePattern = convertToPositivePattern;
        function convertToNegativePattern(pattern) {
          return "!" + pattern;
        }
        exports2.convertToNegativePattern = convertToNegativePattern;
        function isNegativePattern(pattern) {
          return pattern.startsWith("!") && pattern[1] !== "(";
        }
        exports2.isNegativePattern = isNegativePattern;
        function isPositivePattern(pattern) {
          return !isNegativePattern(pattern);
        }
        exports2.isPositivePattern = isPositivePattern;
        function getNegativePatterns(patterns) {
          return patterns.filter(isNegativePattern);
        }
        exports2.getNegativePatterns = getNegativePatterns;
        function getPositivePatterns(patterns) {
          return patterns.filter(isPositivePattern);
        }
        exports2.getPositivePatterns = getPositivePatterns;
        function getPatternsInsideCurrentDirectory(patterns) {
          return patterns.filter((pattern) => !isPatternRelatedToParentDirectory(pattern));
        }
        exports2.getPatternsInsideCurrentDirectory = getPatternsInsideCurrentDirectory;
        function getPatternsOutsideCurrentDirectory(patterns) {
          return patterns.filter(isPatternRelatedToParentDirectory);
        }
        exports2.getPatternsOutsideCurrentDirectory = getPatternsOutsideCurrentDirectory;
        function isPatternRelatedToParentDirectory(pattern) {
          return pattern.startsWith("..") || pattern.startsWith("./..");
        }
        exports2.isPatternRelatedToParentDirectory = isPatternRelatedToParentDirectory;
        function getBaseDirectory(pattern) {
          return globParent(pattern, {
            flipBackslashes: false
          });
        }
        exports2.getBaseDirectory = getBaseDirectory;
        function hasGlobStar(pattern) {
          return pattern.includes(GLOBSTAR);
        }
        exports2.hasGlobStar = hasGlobStar;
        function endsWithSlashGlobStar(pattern) {
          return pattern.endsWith("/" + GLOBSTAR);
        }
        exports2.endsWithSlashGlobStar = endsWithSlashGlobStar;
        function isAffectDepthOfReadingPattern(pattern) {
          const basename = path2.basename(pattern);
          return endsWithSlashGlobStar(pattern) || isStaticPattern(basename);
        }
        exports2.isAffectDepthOfReadingPattern = isAffectDepthOfReadingPattern;
        function expandPatternsWithBraceExpansion(patterns) {
          return patterns.reduce((collection, pattern) => {
            return collection.concat(expandBraceExpansion(pattern));
          }, []);
        }
        exports2.expandPatternsWithBraceExpansion = expandPatternsWithBraceExpansion;
        function expandBraceExpansion(pattern) {
          return micromatch.braces(pattern, {
            expand: true,
            nodupes: true
          });
        }
        exports2.expandBraceExpansion = expandBraceExpansion;
        function getPatternParts(pattern, options) {
          let {
            parts
          } = micromatch.scan(pattern, Object.assign(Object.assign({}, options), {
            parts: true
          }));
          if (parts.length === 0) {
            parts = [pattern];
          }
          if (parts[0].startsWith("/")) {
            parts[0] = parts[0].slice(1);
            parts.unshift("");
          }
          return parts;
        }
        exports2.getPatternParts = getPatternParts;
        function makeRe(pattern, options) {
          return micromatch.makeRe(pattern, options);
        }
        exports2.makeRe = makeRe;
        function convertPatternsToRe(patterns, options) {
          return patterns.map((pattern) => makeRe(pattern, options));
        }
        exports2.convertPatternsToRe = convertPatternsToRe;
        function matchAny(entry, patternsRe) {
          return patternsRe.some((patternRe) => patternRe.test(entry));
        }
        exports2.matchAny = matchAny;
      }
    });
    var require_merge22 = __commonJS22({
      "node_modules/merge2/index.js"(exports2, module22) {
        "use strict";
        var Stream = require("stream");
        var PassThrough = Stream.PassThrough;
        var slice = Array.prototype.slice;
        module22.exports = merge22;
        function merge22() {
          const streamsQueue = [];
          const args = slice.call(arguments);
          let merging = false;
          let options = args[args.length - 1];
          if (options && !Array.isArray(options) && options.pipe == null) {
            args.pop();
          } else {
            options = {};
          }
          const doEnd = options.end !== false;
          const doPipeError = options.pipeError === true;
          if (options.objectMode == null) {
            options.objectMode = true;
          }
          if (options.highWaterMark == null) {
            options.highWaterMark = 64 * 1024;
          }
          const mergedStream = PassThrough(options);
          function addStream() {
            for (let i = 0, len = arguments.length; i < len; i++) {
              streamsQueue.push(pauseStreams(arguments[i], options));
            }
            mergeStream();
            return this;
          }
          function mergeStream() {
            if (merging) {
              return;
            }
            merging = true;
            let streams = streamsQueue.shift();
            if (!streams) {
              process.nextTick(endStream);
              return;
            }
            if (!Array.isArray(streams)) {
              streams = [streams];
            }
            let pipesCount = streams.length + 1;
            function next() {
              if (--pipesCount > 0) {
                return;
              }
              merging = false;
              mergeStream();
            }
            function pipe(stream) {
              function onend() {
                stream.removeListener("merge2UnpipeEnd", onend);
                stream.removeListener("end", onend);
                if (doPipeError) {
                  stream.removeListener("error", onerror);
                }
                next();
              }
              function onerror(err) {
                mergedStream.emit("error", err);
              }
              if (stream._readableState.endEmitted) {
                return next();
              }
              stream.on("merge2UnpipeEnd", onend);
              stream.on("end", onend);
              if (doPipeError) {
                stream.on("error", onerror);
              }
              stream.pipe(mergedStream, {
                end: false
              });
              stream.resume();
            }
            for (let i = 0; i < streams.length; i++) {
              pipe(streams[i]);
            }
            next();
          }
          function endStream() {
            merging = false;
            mergedStream.emit("queueDrain");
            if (doEnd) {
              mergedStream.end();
            }
          }
          mergedStream.setMaxListeners(0);
          mergedStream.add = addStream;
          mergedStream.on("unpipe", function(stream) {
            stream.emit("merge2UnpipeEnd");
          });
          if (args.length) {
            addStream.apply(null, args);
          }
          return mergedStream;
        }
        function pauseStreams(streams, options) {
          if (!Array.isArray(streams)) {
            if (!streams._readableState && streams.pipe) {
              streams = streams.pipe(PassThrough(options));
            }
            if (!streams._readableState || !streams.pause || !streams.pipe) {
              throw new Error("Only readable stream can be merged.");
            }
            streams.pause();
          } else {
            for (let i = 0, len = streams.length; i < len; i++) {
              streams[i] = pauseStreams(streams[i], options);
            }
          }
          return streams;
        }
      }
    });
    var require_stream3 = __commonJS22({
      "node_modules/fast-glob/out/utils/stream.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.merge = void 0;
        var merge22 = require_merge22();
        function merge4(streams) {
          const mergedStream = merge22(streams);
          streams.forEach((stream) => {
            stream.once("error", (error) => mergedStream.emit("error", error));
          });
          mergedStream.once("close", () => propagateCloseEventToSources(streams));
          mergedStream.once("end", () => propagateCloseEventToSources(streams));
          return mergedStream;
        }
        exports2.merge = merge4;
        function propagateCloseEventToSources(streams) {
          streams.forEach((stream) => stream.emit("close"));
        }
      }
    });
    var require_string22 = __commonJS22({
      "node_modules/fast-glob/out/utils/string.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.isEmpty = exports2.isString = void 0;
        function isString(input) {
          return typeof input === "string";
        }
        exports2.isString = isString;
        function isEmpty2(input) {
          return input === "";
        }
        exports2.isEmpty = isEmpty2;
      }
    });
    var require_utils42 = __commonJS22({
      "node_modules/fast-glob/out/utils/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.string = exports2.stream = exports2.pattern = exports2.path = exports2.fs = exports2.errno = exports2.array = void 0;
        var array = require_array3();
        exports2.array = array;
        var errno = require_errno();
        exports2.errno = errno;
        var fs2 = require_fs6();
        exports2.fs = fs2;
        var path2 = require_path2();
        exports2.path = path2;
        var pattern = require_pattern2();
        exports2.pattern = pattern;
        var stream = require_stream3();
        exports2.stream = stream;
        var string = require_string22();
        exports2.string = string;
      }
    });
    var require_tasks = __commonJS22({
      "node_modules/fast-glob/out/managers/tasks.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.convertPatternGroupToTask = exports2.convertPatternGroupsToTasks = exports2.groupPatternsByBaseDirectory = exports2.getNegativePatternsAsPositive = exports2.getPositivePatterns = exports2.convertPatternsToTasks = exports2.generate = void 0;
        var utils2 = require_utils42();
        function generate2(patterns, settings) {
          const positivePatterns = getPositivePatterns(patterns);
          const negativePatterns = getNegativePatternsAsPositive(patterns, settings.ignore);
          const staticPatterns = positivePatterns.filter((pattern) => utils2.pattern.isStaticPattern(pattern, settings));
          const dynamicPatterns = positivePatterns.filter((pattern) => utils2.pattern.isDynamicPattern(pattern, settings));
          const staticTasks = convertPatternsToTasks(staticPatterns, negativePatterns, false);
          const dynamicTasks = convertPatternsToTasks(dynamicPatterns, negativePatterns, true);
          return staticTasks.concat(dynamicTasks);
        }
        exports2.generate = generate2;
        function convertPatternsToTasks(positive, negative, dynamic) {
          const tasks = [];
          const patternsOutsideCurrentDirectory = utils2.pattern.getPatternsOutsideCurrentDirectory(positive);
          const patternsInsideCurrentDirectory = utils2.pattern.getPatternsInsideCurrentDirectory(positive);
          const outsideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsOutsideCurrentDirectory);
          const insideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsInsideCurrentDirectory);
          tasks.push(...convertPatternGroupsToTasks(outsideCurrentDirectoryGroup, negative, dynamic));
          if ("." in insideCurrentDirectoryGroup) {
            tasks.push(convertPatternGroupToTask(".", patternsInsideCurrentDirectory, negative, dynamic));
          } else {
            tasks.push(...convertPatternGroupsToTasks(insideCurrentDirectoryGroup, negative, dynamic));
          }
          return tasks;
        }
        exports2.convertPatternsToTasks = convertPatternsToTasks;
        function getPositivePatterns(patterns) {
          return utils2.pattern.getPositivePatterns(patterns);
        }
        exports2.getPositivePatterns = getPositivePatterns;
        function getNegativePatternsAsPositive(patterns, ignore) {
          const negative = utils2.pattern.getNegativePatterns(patterns).concat(ignore);
          const positive = negative.map(utils2.pattern.convertToPositivePattern);
          return positive;
        }
        exports2.getNegativePatternsAsPositive = getNegativePatternsAsPositive;
        function groupPatternsByBaseDirectory(patterns) {
          const group = {};
          return patterns.reduce((collection, pattern) => {
            const base = utils2.pattern.getBaseDirectory(pattern);
            if (base in collection) {
              collection[base].push(pattern);
            } else {
              collection[base] = [pattern];
            }
            return collection;
          }, group);
        }
        exports2.groupPatternsByBaseDirectory = groupPatternsByBaseDirectory;
        function convertPatternGroupsToTasks(positive, negative, dynamic) {
          return Object.keys(positive).map((base) => {
            return convertPatternGroupToTask(base, positive[base], negative, dynamic);
          });
        }
        exports2.convertPatternGroupsToTasks = convertPatternGroupsToTasks;
        function convertPatternGroupToTask(base, positive, negative, dynamic) {
          return {
            dynamic,
            positive,
            negative,
            base,
            patterns: [].concat(positive, negative.map(utils2.pattern.convertToNegativePattern))
          };
        }
        exports2.convertPatternGroupToTask = convertPatternGroupToTask;
      }
    });
    var require_patterns = __commonJS22({
      "node_modules/fast-glob/out/managers/patterns.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.removeDuplicateSlashes = exports2.transform = void 0;
        var DOUBLE_SLASH_RE = /(?!^)\/{2,}/g;
        function transform(patterns) {
          return patterns.map((pattern) => removeDuplicateSlashes(pattern));
        }
        exports2.transform = transform;
        function removeDuplicateSlashes(pattern) {
          return pattern.replace(DOUBLE_SLASH_RE, "/");
        }
        exports2.removeDuplicateSlashes = removeDuplicateSlashes;
      }
    });
    var require_async22 = __commonJS22({
      "node_modules/@nodelib/fs.stat/out/providers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.read = void 0;
        function read(path2, settings, callback) {
          settings.fs.lstat(path2, (lstatError, lstat) => {
            if (lstatError !== null) {
              callFailureCallback(callback, lstatError);
              return;
            }
            if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
              callSuccessCallback(callback, lstat);
              return;
            }
            settings.fs.stat(path2, (statError, stat) => {
              if (statError !== null) {
                if (settings.throwErrorOnBrokenSymbolicLink) {
                  callFailureCallback(callback, statError);
                  return;
                }
                callSuccessCallback(callback, lstat);
                return;
              }
              if (settings.markSymbolicLink) {
                stat.isSymbolicLink = () => true;
              }
              callSuccessCallback(callback, stat);
            });
          });
        }
        exports2.read = read;
        function callFailureCallback(callback, error) {
          callback(error);
        }
        function callSuccessCallback(callback, result) {
          callback(null, result);
        }
      }
    });
    var require_sync22 = __commonJS22({
      "node_modules/@nodelib/fs.stat/out/providers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.read = void 0;
        function read(path2, settings) {
          const lstat = settings.fs.lstatSync(path2);
          if (!lstat.isSymbolicLink() || !settings.followSymbolicLink) {
            return lstat;
          }
          try {
            const stat = settings.fs.statSync(path2);
            if (settings.markSymbolicLink) {
              stat.isSymbolicLink = () => true;
            }
            return stat;
          } catch (error) {
            if (!settings.throwErrorOnBrokenSymbolicLink) {
              return lstat;
            }
            throw error;
          }
        }
        exports2.read = read;
      }
    });
    var require_fs22 = __commonJS22({
      "node_modules/@nodelib/fs.stat/out/adapters/fs.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.createFileSystemAdapter = exports2.FILE_SYSTEM_ADAPTER = void 0;
        var fs2 = require("fs");
        exports2.FILE_SYSTEM_ADAPTER = {
          lstat: fs2.lstat,
          stat: fs2.stat,
          lstatSync: fs2.lstatSync,
          statSync: fs2.statSync
        };
        function createFileSystemAdapter(fsMethods) {
          if (fsMethods === void 0) {
            return exports2.FILE_SYSTEM_ADAPTER;
          }
          return Object.assign(Object.assign({}, exports2.FILE_SYSTEM_ADAPTER), fsMethods);
        }
        exports2.createFileSystemAdapter = createFileSystemAdapter;
      }
    });
    var require_settings4 = __commonJS22({
      "node_modules/@nodelib/fs.stat/out/settings.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fs2 = require_fs22();
        var Settings = class {
          constructor(_options = {}) {
            this._options = _options;
            this.followSymbolicLink = this._getValue(this._options.followSymbolicLink, true);
            this.fs = fs2.createFileSystemAdapter(this._options.fs);
            this.markSymbolicLink = this._getValue(this._options.markSymbolicLink, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
          }
          _getValue(option, value2) {
            return option !== null && option !== void 0 ? option : value2;
          }
        };
        exports2.default = Settings;
      }
    });
    var require_out4 = __commonJS22({
      "node_modules/@nodelib/fs.stat/out/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.statSync = exports2.stat = exports2.Settings = void 0;
        var async = require_async22();
        var sync = require_sync22();
        var settings_1 = require_settings4();
        exports2.Settings = settings_1.default;
        function stat(path2, optionsOrSettingsOrCallback, callback) {
          if (typeof optionsOrSettingsOrCallback === "function") {
            async.read(path2, getSettings(), optionsOrSettingsOrCallback);
            return;
          }
          async.read(path2, getSettings(optionsOrSettingsOrCallback), callback);
        }
        exports2.stat = stat;
        function statSync(path2, optionsOrSettings) {
          const settings = getSettings(optionsOrSettings);
          return sync.read(path2, settings);
        }
        exports2.statSync = statSync;
        function getSettings(settingsOrOptions = {}) {
          if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
          }
          return new settings_1.default(settingsOrOptions);
        }
      }
    });
    var require_queue_microtask2 = __commonJS22({
      "node_modules/queue-microtask/index.js"(exports2, module22) {
        var promise;
        module22.exports = typeof queueMicrotask === "function" ? queueMicrotask.bind(typeof window !== "undefined" ? window : global) : (cb) => (promise || (promise = Promise.resolve())).then(cb).catch((err) => setTimeout(() => {
          throw err;
        }, 0));
      }
    });
    var require_run_parallel2 = __commonJS22({
      "node_modules/run-parallel/index.js"(exports2, module22) {
        module22.exports = runParallel;
        var queueMicrotask2 = require_queue_microtask2();
        function runParallel(tasks, cb) {
          let results, pending, keys3;
          let isSync = true;
          if (Array.isArray(tasks)) {
            results = [];
            pending = tasks.length;
          } else {
            keys3 = Object.keys(tasks);
            results = {};
            pending = keys3.length;
          }
          function done(err) {
            function end() {
              if (cb)
                cb(err, results);
              cb = null;
            }
            if (isSync)
              queueMicrotask2(end);
            else
              end();
          }
          function each(i, err, result) {
            results[i] = result;
            if (--pending === 0 || err) {
              done(err);
            }
          }
          if (!pending) {
            done(null);
          } else if (keys3) {
            keys3.forEach(function(key) {
              tasks[key](function(err, result) {
                each(key, err, result);
              });
            });
          } else {
            tasks.forEach(function(task, i) {
              task(function(err, result) {
                each(i, err, result);
              });
            });
          }
          isSync = false;
        }
      }
    });
    var require_constants42 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/constants.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.IS_SUPPORT_READDIR_WITH_FILE_TYPES = void 0;
        var NODE_PROCESS_VERSION_PARTS = process.versions.node.split(".");
        if (NODE_PROCESS_VERSION_PARTS[0] === void 0 || NODE_PROCESS_VERSION_PARTS[1] === void 0) {
          throw new Error(`Unexpected behavior. The 'process.versions.node' variable has invalid value: ${process.versions.node}`);
        }
        var MAJOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[0], 10);
        var MINOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[1], 10);
        var SUPPORTED_MAJOR_VERSION = 10;
        var SUPPORTED_MINOR_VERSION = 10;
        var IS_MATCHED_BY_MAJOR = MAJOR_VERSION > SUPPORTED_MAJOR_VERSION;
        var IS_MATCHED_BY_MAJOR_AND_MINOR = MAJOR_VERSION === SUPPORTED_MAJOR_VERSION && MINOR_VERSION >= SUPPORTED_MINOR_VERSION;
        exports2.IS_SUPPORT_READDIR_WITH_FILE_TYPES = IS_MATCHED_BY_MAJOR || IS_MATCHED_BY_MAJOR_AND_MINOR;
      }
    });
    var require_fs32 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/utils/fs.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.createDirentFromStats = void 0;
        var DirentFromStats = class {
          constructor(name, stats) {
            this.name = name;
            this.isBlockDevice = stats.isBlockDevice.bind(stats);
            this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
            this.isDirectory = stats.isDirectory.bind(stats);
            this.isFIFO = stats.isFIFO.bind(stats);
            this.isFile = stats.isFile.bind(stats);
            this.isSocket = stats.isSocket.bind(stats);
            this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
          }
        };
        function createDirentFromStats(name, stats) {
          return new DirentFromStats(name, stats);
        }
        exports2.createDirentFromStats = createDirentFromStats;
      }
    });
    var require_utils52 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/utils/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.fs = void 0;
        var fs2 = require_fs32();
        exports2.fs = fs2;
      }
    });
    var require_common32 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/providers/common.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.joinPathSegments = void 0;
        function joinPathSegments(a, b, separator) {
          if (a.endsWith(separator)) {
            return a + b;
          }
          return a + separator + b;
        }
        exports2.joinPathSegments = joinPathSegments;
      }
    });
    var require_async32 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/providers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.readdir = exports2.readdirWithFileTypes = exports2.read = void 0;
        var fsStat = require_out4();
        var rpl = require_run_parallel2();
        var constants_1 = require_constants42();
        var utils2 = require_utils52();
        var common = require_common32();
        function read(directory, settings, callback) {
          if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
            readdirWithFileTypes(directory, settings, callback);
            return;
          }
          readdir(directory, settings, callback);
        }
        exports2.read = read;
        function readdirWithFileTypes(directory, settings, callback) {
          settings.fs.readdir(directory, {
            withFileTypes: true
          }, (readdirError, dirents) => {
            if (readdirError !== null) {
              callFailureCallback(callback, readdirError);
              return;
            }
            const entries = dirents.map((dirent) => ({
              dirent,
              name: dirent.name,
              path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
            }));
            if (!settings.followSymbolicLinks) {
              callSuccessCallback(callback, entries);
              return;
            }
            const tasks = entries.map((entry) => makeRplTaskEntry(entry, settings));
            rpl(tasks, (rplError, rplEntries) => {
              if (rplError !== null) {
                callFailureCallback(callback, rplError);
                return;
              }
              callSuccessCallback(callback, rplEntries);
            });
          });
        }
        exports2.readdirWithFileTypes = readdirWithFileTypes;
        function makeRplTaskEntry(entry, settings) {
          return (done) => {
            if (!entry.dirent.isSymbolicLink()) {
              done(null, entry);
              return;
            }
            settings.fs.stat(entry.path, (statError, stats) => {
              if (statError !== null) {
                if (settings.throwErrorOnBrokenSymbolicLink) {
                  done(statError);
                  return;
                }
                done(null, entry);
                return;
              }
              entry.dirent = utils2.fs.createDirentFromStats(entry.name, stats);
              done(null, entry);
            });
          };
        }
        function readdir(directory, settings, callback) {
          settings.fs.readdir(directory, (readdirError, names) => {
            if (readdirError !== null) {
              callFailureCallback(callback, readdirError);
              return;
            }
            const tasks = names.map((name) => {
              const path2 = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
              return (done) => {
                fsStat.stat(path2, settings.fsStatSettings, (error, stats) => {
                  if (error !== null) {
                    done(error);
                    return;
                  }
                  const entry = {
                    name,
                    path: path2,
                    dirent: utils2.fs.createDirentFromStats(name, stats)
                  };
                  if (settings.stats) {
                    entry.stats = stats;
                  }
                  done(null, entry);
                });
              };
            });
            rpl(tasks, (rplError, entries) => {
              if (rplError !== null) {
                callFailureCallback(callback, rplError);
                return;
              }
              callSuccessCallback(callback, entries);
            });
          });
        }
        exports2.readdir = readdir;
        function callFailureCallback(callback, error) {
          callback(error);
        }
        function callSuccessCallback(callback, result) {
          callback(null, result);
        }
      }
    });
    var require_sync32 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/providers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.readdir = exports2.readdirWithFileTypes = exports2.read = void 0;
        var fsStat = require_out4();
        var constants_1 = require_constants42();
        var utils2 = require_utils52();
        var common = require_common32();
        function read(directory, settings) {
          if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
            return readdirWithFileTypes(directory, settings);
          }
          return readdir(directory, settings);
        }
        exports2.read = read;
        function readdirWithFileTypes(directory, settings) {
          const dirents = settings.fs.readdirSync(directory, {
            withFileTypes: true
          });
          return dirents.map((dirent) => {
            const entry = {
              dirent,
              name: dirent.name,
              path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
            };
            if (entry.dirent.isSymbolicLink() && settings.followSymbolicLinks) {
              try {
                const stats = settings.fs.statSync(entry.path);
                entry.dirent = utils2.fs.createDirentFromStats(entry.name, stats);
              } catch (error) {
                if (settings.throwErrorOnBrokenSymbolicLink) {
                  throw error;
                }
              }
            }
            return entry;
          });
        }
        exports2.readdirWithFileTypes = readdirWithFileTypes;
        function readdir(directory, settings) {
          const names = settings.fs.readdirSync(directory);
          return names.map((name) => {
            const entryPath = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
            const stats = fsStat.statSync(entryPath, settings.fsStatSettings);
            const entry = {
              name,
              path: entryPath,
              dirent: utils2.fs.createDirentFromStats(name, stats)
            };
            if (settings.stats) {
              entry.stats = stats;
            }
            return entry;
          });
        }
        exports2.readdir = readdir;
      }
    });
    var require_fs42 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/adapters/fs.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.createFileSystemAdapter = exports2.FILE_SYSTEM_ADAPTER = void 0;
        var fs2 = require("fs");
        exports2.FILE_SYSTEM_ADAPTER = {
          lstat: fs2.lstat,
          stat: fs2.stat,
          lstatSync: fs2.lstatSync,
          statSync: fs2.statSync,
          readdir: fs2.readdir,
          readdirSync: fs2.readdirSync
        };
        function createFileSystemAdapter(fsMethods) {
          if (fsMethods === void 0) {
            return exports2.FILE_SYSTEM_ADAPTER;
          }
          return Object.assign(Object.assign({}, exports2.FILE_SYSTEM_ADAPTER), fsMethods);
        }
        exports2.createFileSystemAdapter = createFileSystemAdapter;
      }
    });
    var require_settings22 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/settings.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var path2 = require("path");
        var fsStat = require_out4();
        var fs2 = require_fs42();
        var Settings = class {
          constructor(_options = {}) {
            this._options = _options;
            this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, false);
            this.fs = fs2.createFileSystemAdapter(this._options.fs);
            this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path2.sep);
            this.stats = this._getValue(this._options.stats, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
            this.fsStatSettings = new fsStat.Settings({
              followSymbolicLink: this.followSymbolicLinks,
              fs: this.fs,
              throwErrorOnBrokenSymbolicLink: this.throwErrorOnBrokenSymbolicLink
            });
          }
          _getValue(option, value2) {
            return option !== null && option !== void 0 ? option : value2;
          }
        };
        exports2.default = Settings;
      }
    });
    var require_out22 = __commonJS22({
      "node_modules/@nodelib/fs.scandir/out/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.Settings = exports2.scandirSync = exports2.scandir = void 0;
        var async = require_async32();
        var sync = require_sync32();
        var settings_1 = require_settings22();
        exports2.Settings = settings_1.default;
        function scandir(path2, optionsOrSettingsOrCallback, callback) {
          if (typeof optionsOrSettingsOrCallback === "function") {
            async.read(path2, getSettings(), optionsOrSettingsOrCallback);
            return;
          }
          async.read(path2, getSettings(optionsOrSettingsOrCallback), callback);
        }
        exports2.scandir = scandir;
        function scandirSync(path2, optionsOrSettings) {
          const settings = getSettings(optionsOrSettings);
          return sync.read(path2, settings);
        }
        exports2.scandirSync = scandirSync;
        function getSettings(settingsOrOptions = {}) {
          if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
          }
          return new settings_1.default(settingsOrOptions);
        }
      }
    });
    var require_reusify2 = __commonJS22({
      "node_modules/reusify/reusify.js"(exports2, module22) {
        "use strict";
        function reusify(Constructor) {
          var head = new Constructor();
          var tail = head;
          function get() {
            var current = head;
            if (current.next) {
              head = current.next;
            } else {
              head = new Constructor();
              tail = head;
            }
            current.next = null;
            return current;
          }
          function release(obj) {
            tail.next = obj;
            tail = obj;
          }
          return {
            get,
            release
          };
        }
        module22.exports = reusify;
      }
    });
    var require_queue3 = __commonJS22({
      "node_modules/fastq/queue.js"(exports2, module22) {
        "use strict";
        var reusify = require_reusify2();
        function fastqueue(context, worker, concurrency) {
          if (typeof context === "function") {
            concurrency = worker;
            worker = context;
            context = null;
          }
          if (concurrency < 1) {
            throw new Error("fastqueue concurrency must be greater than 1");
          }
          var cache = reusify(Task);
          var queueHead = null;
          var queueTail = null;
          var _running = 0;
          var errorHandler = null;
          var self2 = {
            push,
            drain: noop,
            saturated: noop,
            pause,
            paused: false,
            concurrency,
            running,
            resume,
            idle,
            length,
            getQueue,
            unshift,
            empty: noop,
            kill,
            killAndDrain,
            error
          };
          return self2;
          function running() {
            return _running;
          }
          function pause() {
            self2.paused = true;
          }
          function length() {
            var current = queueHead;
            var counter = 0;
            while (current) {
              current = current.next;
              counter++;
            }
            return counter;
          }
          function getQueue() {
            var current = queueHead;
            var tasks = [];
            while (current) {
              tasks.push(current.value);
              current = current.next;
            }
            return tasks;
          }
          function resume() {
            if (!self2.paused)
              return;
            self2.paused = false;
            for (var i = 0; i < self2.concurrency; i++) {
              _running++;
              release();
            }
          }
          function idle() {
            return _running === 0 && self2.length() === 0;
          }
          function push(value2, done) {
            var current = cache.get();
            current.context = context;
            current.release = release;
            current.value = value2;
            current.callback = done || noop;
            current.errorHandler = errorHandler;
            if (_running === self2.concurrency || self2.paused) {
              if (queueTail) {
                queueTail.next = current;
                queueTail = current;
              } else {
                queueHead = current;
                queueTail = current;
                self2.saturated();
              }
            } else {
              _running++;
              worker.call(context, current.value, current.worked);
            }
          }
          function unshift(value2, done) {
            var current = cache.get();
            current.context = context;
            current.release = release;
            current.value = value2;
            current.callback = done || noop;
            if (_running === self2.concurrency || self2.paused) {
              if (queueHead) {
                current.next = queueHead;
                queueHead = current;
              } else {
                queueHead = current;
                queueTail = current;
                self2.saturated();
              }
            } else {
              _running++;
              worker.call(context, current.value, current.worked);
            }
          }
          function release(holder) {
            if (holder) {
              cache.release(holder);
            }
            var next = queueHead;
            if (next) {
              if (!self2.paused) {
                if (queueTail === queueHead) {
                  queueTail = null;
                }
                queueHead = next.next;
                next.next = null;
                worker.call(context, next.value, next.worked);
                if (queueTail === null) {
                  self2.empty();
                }
              } else {
                _running--;
              }
            } else if (--_running === 0) {
              self2.drain();
            }
          }
          function kill() {
            queueHead = null;
            queueTail = null;
            self2.drain = noop;
          }
          function killAndDrain() {
            queueHead = null;
            queueTail = null;
            self2.drain();
            self2.drain = noop;
          }
          function error(handler) {
            errorHandler = handler;
          }
        }
        function noop() {
        }
        function Task() {
          this.value = null;
          this.callback = noop;
          this.next = null;
          this.release = noop;
          this.context = null;
          this.errorHandler = null;
          var self2 = this;
          this.worked = function worked(err, result) {
            var callback = self2.callback;
            var errorHandler = self2.errorHandler;
            var val = self2.value;
            self2.value = null;
            self2.callback = noop;
            if (self2.errorHandler) {
              errorHandler(err, val);
            }
            callback.call(self2.context, err, result);
            self2.release(self2);
          };
        }
        function queueAsPromised(context, worker, concurrency) {
          if (typeof context === "function") {
            concurrency = worker;
            worker = context;
            context = null;
          }
          function asyncWrapper(arg, cb) {
            worker.call(this, arg).then(function(res) {
              cb(null, res);
            }, cb);
          }
          var queue = fastqueue(context, asyncWrapper, concurrency);
          var pushCb = queue.push;
          var unshiftCb = queue.unshift;
          queue.push = push;
          queue.unshift = unshift;
          queue.drained = drained;
          return queue;
          function push(value2) {
            var p = new Promise(function(resolve, reject) {
              pushCb(value2, function(err, result) {
                if (err) {
                  reject(err);
                  return;
                }
                resolve(result);
              });
            });
            p.catch(noop);
            return p;
          }
          function unshift(value2) {
            var p = new Promise(function(resolve, reject) {
              unshiftCb(value2, function(err, result) {
                if (err) {
                  reject(err);
                  return;
                }
                resolve(result);
              });
            });
            p.catch(noop);
            return p;
          }
          function drained() {
            var previousDrain = queue.drain;
            var p = new Promise(function(resolve) {
              queue.drain = function() {
                previousDrain();
                resolve();
              };
            });
            return p;
          }
        }
        module22.exports = fastqueue;
        module22.exports.promise = queueAsPromised;
      }
    });
    var require_common42 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/readers/common.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.joinPathSegments = exports2.replacePathSegmentSeparator = exports2.isAppliedFilter = exports2.isFatalError = void 0;
        function isFatalError(settings, error) {
          if (settings.errorFilter === null) {
            return true;
          }
          return !settings.errorFilter(error);
        }
        exports2.isFatalError = isFatalError;
        function isAppliedFilter(filter, value2) {
          return filter === null || filter(value2);
        }
        exports2.isAppliedFilter = isAppliedFilter;
        function replacePathSegmentSeparator(filepath, separator) {
          return filepath.split(/[/\\]/).join(separator);
        }
        exports2.replacePathSegmentSeparator = replacePathSegmentSeparator;
        function joinPathSegments(a, b, separator) {
          if (a === "") {
            return b;
          }
          if (a.endsWith(separator)) {
            return a + b;
          }
          return a + separator + b;
        }
        exports2.joinPathSegments = joinPathSegments;
      }
    });
    var require_reader2 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/readers/reader.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var common = require_common42();
        var Reader = class {
          constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._root = common.replacePathSegmentSeparator(_root, _settings.pathSegmentSeparator);
          }
        };
        exports2.default = Reader;
      }
    });
    var require_async42 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/readers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var events_1 = require("events");
        var fsScandir = require_out22();
        var fastq = require_queue3();
        var common = require_common42();
        var reader_1 = require_reader2();
        var AsyncReader = class extends reader_1.default {
          constructor(_root, _settings) {
            super(_root, _settings);
            this._settings = _settings;
            this._scandir = fsScandir.scandir;
            this._emitter = new events_1.EventEmitter();
            this._queue = fastq(this._worker.bind(this), this._settings.concurrency);
            this._isFatalError = false;
            this._isDestroyed = false;
            this._queue.drain = () => {
              if (!this._isFatalError) {
                this._emitter.emit("end");
              }
            };
          }
          read() {
            this._isFatalError = false;
            this._isDestroyed = false;
            setImmediate(() => {
              this._pushToQueue(this._root, this._settings.basePath);
            });
            return this._emitter;
          }
          get isDestroyed() {
            return this._isDestroyed;
          }
          destroy() {
            if (this._isDestroyed) {
              throw new Error("The reader is already destroyed");
            }
            this._isDestroyed = true;
            this._queue.killAndDrain();
          }
          onEntry(callback) {
            this._emitter.on("entry", callback);
          }
          onError(callback) {
            this._emitter.once("error", callback);
          }
          onEnd(callback) {
            this._emitter.once("end", callback);
          }
          _pushToQueue(directory, base) {
            const queueItem = {
              directory,
              base
            };
            this._queue.push(queueItem, (error) => {
              if (error !== null) {
                this._handleError(error);
              }
            });
          }
          _worker(item, done) {
            this._scandir(item.directory, this._settings.fsScandirSettings, (error, entries) => {
              if (error !== null) {
                done(error, void 0);
                return;
              }
              for (const entry of entries) {
                this._handleEntry(entry, item.base);
              }
              done(null, void 0);
            });
          }
          _handleError(error) {
            if (this._isDestroyed || !common.isFatalError(this._settings, error)) {
              return;
            }
            this._isFatalError = true;
            this._isDestroyed = true;
            this._emitter.emit("error", error);
          }
          _handleEntry(entry, base) {
            if (this._isDestroyed || this._isFatalError) {
              return;
            }
            const fullpath = entry.path;
            if (base !== void 0) {
              entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
            }
            if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
              this._emitEntry(entry);
            }
            if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
              this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
            }
          }
          _emitEntry(entry) {
            this._emitter.emit("entry", entry);
          }
        };
        exports2.default = AsyncReader;
      }
    });
    var require_async52 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/providers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var async_1 = require_async42();
        var AsyncProvider = class {
          constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new async_1.default(this._root, this._settings);
            this._storage = [];
          }
          read(callback) {
            this._reader.onError((error) => {
              callFailureCallback(callback, error);
            });
            this._reader.onEntry((entry) => {
              this._storage.push(entry);
            });
            this._reader.onEnd(() => {
              callSuccessCallback(callback, this._storage);
            });
            this._reader.read();
          }
        };
        exports2.default = AsyncProvider;
        function callFailureCallback(callback, error) {
          callback(error);
        }
        function callSuccessCallback(callback, entries) {
          callback(null, entries);
        }
      }
    });
    var require_stream22 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/providers/stream.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var stream_1 = require("stream");
        var async_1 = require_async42();
        var StreamProvider = class {
          constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new async_1.default(this._root, this._settings);
            this._stream = new stream_1.Readable({
              objectMode: true,
              read: () => {
              },
              destroy: () => {
                if (!this._reader.isDestroyed) {
                  this._reader.destroy();
                }
              }
            });
          }
          read() {
            this._reader.onError((error) => {
              this._stream.emit("error", error);
            });
            this._reader.onEntry((entry) => {
              this._stream.push(entry);
            });
            this._reader.onEnd(() => {
              this._stream.push(null);
            });
            this._reader.read();
            return this._stream;
          }
        };
        exports2.default = StreamProvider;
      }
    });
    var require_sync42 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/readers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fsScandir = require_out22();
        var common = require_common42();
        var reader_1 = require_reader2();
        var SyncReader = class extends reader_1.default {
          constructor() {
            super(...arguments);
            this._scandir = fsScandir.scandirSync;
            this._storage = [];
            this._queue = /* @__PURE__ */ new Set();
          }
          read() {
            this._pushToQueue(this._root, this._settings.basePath);
            this._handleQueue();
            return this._storage;
          }
          _pushToQueue(directory, base) {
            this._queue.add({
              directory,
              base
            });
          }
          _handleQueue() {
            for (const item of this._queue.values()) {
              this._handleDirectory(item.directory, item.base);
            }
          }
          _handleDirectory(directory, base) {
            try {
              const entries = this._scandir(directory, this._settings.fsScandirSettings);
              for (const entry of entries) {
                this._handleEntry(entry, base);
              }
            } catch (error) {
              this._handleError(error);
            }
          }
          _handleError(error) {
            if (!common.isFatalError(this._settings, error)) {
              return;
            }
            throw error;
          }
          _handleEntry(entry, base) {
            const fullpath = entry.path;
            if (base !== void 0) {
              entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
            }
            if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
              this._pushToStorage(entry);
            }
            if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
              this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
            }
          }
          _pushToStorage(entry) {
            this._storage.push(entry);
          }
        };
        exports2.default = SyncReader;
      }
    });
    var require_sync52 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/providers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var sync_1 = require_sync42();
        var SyncProvider = class {
          constructor(_root, _settings) {
            this._root = _root;
            this._settings = _settings;
            this._reader = new sync_1.default(this._root, this._settings);
          }
          read() {
            return this._reader.read();
          }
        };
        exports2.default = SyncProvider;
      }
    });
    var require_settings32 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/settings.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var path2 = require("path");
        var fsScandir = require_out22();
        var Settings = class {
          constructor(_options = {}) {
            this._options = _options;
            this.basePath = this._getValue(this._options.basePath, void 0);
            this.concurrency = this._getValue(this._options.concurrency, Number.POSITIVE_INFINITY);
            this.deepFilter = this._getValue(this._options.deepFilter, null);
            this.entryFilter = this._getValue(this._options.entryFilter, null);
            this.errorFilter = this._getValue(this._options.errorFilter, null);
            this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path2.sep);
            this.fsScandirSettings = new fsScandir.Settings({
              followSymbolicLinks: this._options.followSymbolicLinks,
              fs: this._options.fs,
              pathSegmentSeparator: this._options.pathSegmentSeparator,
              stats: this._options.stats,
              throwErrorOnBrokenSymbolicLink: this._options.throwErrorOnBrokenSymbolicLink
            });
          }
          _getValue(option, value2) {
            return option !== null && option !== void 0 ? option : value2;
          }
        };
        exports2.default = Settings;
      }
    });
    var require_out32 = __commonJS22({
      "node_modules/@nodelib/fs.walk/out/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.Settings = exports2.walkStream = exports2.walkSync = exports2.walk = void 0;
        var async_1 = require_async52();
        var stream_1 = require_stream22();
        var sync_1 = require_sync52();
        var settings_1 = require_settings32();
        exports2.Settings = settings_1.default;
        function walk(directory, optionsOrSettingsOrCallback, callback) {
          if (typeof optionsOrSettingsOrCallback === "function") {
            new async_1.default(directory, getSettings()).read(optionsOrSettingsOrCallback);
            return;
          }
          new async_1.default(directory, getSettings(optionsOrSettingsOrCallback)).read(callback);
        }
        exports2.walk = walk;
        function walkSync(directory, optionsOrSettings) {
          const settings = getSettings(optionsOrSettings);
          const provider = new sync_1.default(directory, settings);
          return provider.read();
        }
        exports2.walkSync = walkSync;
        function walkStream(directory, optionsOrSettings) {
          const settings = getSettings(optionsOrSettings);
          const provider = new stream_1.default(directory, settings);
          return provider.read();
        }
        exports2.walkStream = walkStream;
        function getSettings(settingsOrOptions = {}) {
          if (settingsOrOptions instanceof settings_1.default) {
            return settingsOrOptions;
          }
          return new settings_1.default(settingsOrOptions);
        }
      }
    });
    var require_reader22 = __commonJS22({
      "node_modules/fast-glob/out/readers/reader.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var path2 = require("path");
        var fsStat = require_out4();
        var utils2 = require_utils42();
        var Reader = class {
          constructor(_settings) {
            this._settings = _settings;
            this._fsStatSettings = new fsStat.Settings({
              followSymbolicLink: this._settings.followSymbolicLinks,
              fs: this._settings.fs,
              throwErrorOnBrokenSymbolicLink: this._settings.followSymbolicLinks
            });
          }
          _getFullEntryPath(filepath) {
            return path2.resolve(this._settings.cwd, filepath);
          }
          _makeEntry(stats, pattern) {
            const entry = {
              name: pattern,
              path: pattern,
              dirent: utils2.fs.createDirentFromStats(pattern, stats)
            };
            if (this._settings.stats) {
              entry.stats = stats;
            }
            return entry;
          }
          _isFatalError(error) {
            return !utils2.errno.isEnoentCodeError(error) && !this._settings.suppressErrors;
          }
        };
        exports2.default = Reader;
      }
    });
    var require_stream32 = __commonJS22({
      "node_modules/fast-glob/out/readers/stream.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var stream_1 = require("stream");
        var fsStat = require_out4();
        var fsWalk = require_out32();
        var reader_1 = require_reader22();
        var ReaderStream = class extends reader_1.default {
          constructor() {
            super(...arguments);
            this._walkStream = fsWalk.walkStream;
            this._stat = fsStat.stat;
          }
          dynamic(root2, options) {
            return this._walkStream(root2, options);
          }
          static(patterns, options) {
            const filepaths = patterns.map(this._getFullEntryPath, this);
            const stream = new stream_1.PassThrough({
              objectMode: true
            });
            stream._write = (index, _enc, done) => {
              return this._getEntry(filepaths[index], patterns[index], options).then((entry) => {
                if (entry !== null && options.entryFilter(entry)) {
                  stream.push(entry);
                }
                if (index === filepaths.length - 1) {
                  stream.end();
                }
                done();
              }).catch(done);
            };
            for (let i = 0; i < filepaths.length; i++) {
              stream.write(i);
            }
            return stream;
          }
          _getEntry(filepath, pattern, options) {
            return this._getStat(filepath).then((stats) => this._makeEntry(stats, pattern)).catch((error) => {
              if (options.errorFilter(error)) {
                return null;
              }
              throw error;
            });
          }
          _getStat(filepath) {
            return new Promise((resolve, reject) => {
              this._stat(filepath, this._fsStatSettings, (error, stats) => {
                return error === null ? resolve(stats) : reject(error);
              });
            });
          }
        };
        exports2.default = ReaderStream;
      }
    });
    var require_async62 = __commonJS22({
      "node_modules/fast-glob/out/readers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fsWalk = require_out32();
        var reader_1 = require_reader22();
        var stream_1 = require_stream32();
        var ReaderAsync = class extends reader_1.default {
          constructor() {
            super(...arguments);
            this._walkAsync = fsWalk.walk;
            this._readerStream = new stream_1.default(this._settings);
          }
          dynamic(root2, options) {
            return new Promise((resolve, reject) => {
              this._walkAsync(root2, options, (error, entries) => {
                if (error === null) {
                  resolve(entries);
                } else {
                  reject(error);
                }
              });
            });
          }
          async static(patterns, options) {
            const entries = [];
            const stream = this._readerStream.static(patterns, options);
            return new Promise((resolve, reject) => {
              stream.once("error", reject);
              stream.on("data", (entry) => entries.push(entry));
              stream.once("end", () => resolve(entries));
            });
          }
        };
        exports2.default = ReaderAsync;
      }
    });
    var require_matcher = __commonJS22({
      "node_modules/fast-glob/out/providers/matchers/matcher.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils2 = require_utils42();
        var Matcher = class {
          constructor(_patterns, _settings, _micromatchOptions) {
            this._patterns = _patterns;
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
            this._storage = [];
            this._fillStorage();
          }
          _fillStorage() {
            const patterns = utils2.pattern.expandPatternsWithBraceExpansion(this._patterns);
            for (const pattern of patterns) {
              const segments = this._getPatternSegments(pattern);
              const sections = this._splitSegmentsIntoSections(segments);
              this._storage.push({
                complete: sections.length <= 1,
                pattern,
                segments,
                sections
              });
            }
          }
          _getPatternSegments(pattern) {
            const parts = utils2.pattern.getPatternParts(pattern, this._micromatchOptions);
            return parts.map((part) => {
              const dynamic = utils2.pattern.isDynamicPattern(part, this._settings);
              if (!dynamic) {
                return {
                  dynamic: false,
                  pattern: part
                };
              }
              return {
                dynamic: true,
                pattern: part,
                patternRe: utils2.pattern.makeRe(part, this._micromatchOptions)
              };
            });
          }
          _splitSegmentsIntoSections(segments) {
            return utils2.array.splitWhen(segments, (segment) => segment.dynamic && utils2.pattern.hasGlobStar(segment.pattern));
          }
        };
        exports2.default = Matcher;
      }
    });
    var require_partial2 = __commonJS22({
      "node_modules/fast-glob/out/providers/matchers/partial.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var matcher_1 = require_matcher();
        var PartialMatcher = class extends matcher_1.default {
          match(filepath) {
            const parts = filepath.split("/");
            const levels = parts.length;
            const patterns = this._storage.filter((info) => !info.complete || info.segments.length > levels);
            for (const pattern of patterns) {
              const section = pattern.sections[0];
              if (!pattern.complete && levels > section.length) {
                return true;
              }
              const match = parts.every((part, index) => {
                const segment = pattern.segments[index];
                if (segment.dynamic && segment.patternRe.test(part)) {
                  return true;
                }
                if (!segment.dynamic && segment.pattern === part) {
                  return true;
                }
                return false;
              });
              if (match) {
                return true;
              }
            }
            return false;
          }
        };
        exports2.default = PartialMatcher;
      }
    });
    var require_deep = __commonJS22({
      "node_modules/fast-glob/out/providers/filters/deep.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils2 = require_utils42();
        var partial_1 = require_partial2();
        var DeepFilter = class {
          constructor(_settings, _micromatchOptions) {
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
          }
          getFilter(basePath, positive, negative) {
            const matcher = this._getMatcher(positive);
            const negativeRe = this._getNegativePatternsRe(negative);
            return (entry) => this._filter(basePath, entry, matcher, negativeRe);
          }
          _getMatcher(patterns) {
            return new partial_1.default(patterns, this._settings, this._micromatchOptions);
          }
          _getNegativePatternsRe(patterns) {
            const affectDepthOfReadingPatterns = patterns.filter(utils2.pattern.isAffectDepthOfReadingPattern);
            return utils2.pattern.convertPatternsToRe(affectDepthOfReadingPatterns, this._micromatchOptions);
          }
          _filter(basePath, entry, matcher, negativeRe) {
            if (this._isSkippedByDeep(basePath, entry.path)) {
              return false;
            }
            if (this._isSkippedSymbolicLink(entry)) {
              return false;
            }
            const filepath = utils2.path.removeLeadingDotSegment(entry.path);
            if (this._isSkippedByPositivePatterns(filepath, matcher)) {
              return false;
            }
            return this._isSkippedByNegativePatterns(filepath, negativeRe);
          }
          _isSkippedByDeep(basePath, entryPath) {
            if (this._settings.deep === Infinity) {
              return false;
            }
            return this._getEntryLevel(basePath, entryPath) >= this._settings.deep;
          }
          _getEntryLevel(basePath, entryPath) {
            const entryPathDepth = entryPath.split("/").length;
            if (basePath === "") {
              return entryPathDepth;
            }
            const basePathDepth = basePath.split("/").length;
            return entryPathDepth - basePathDepth;
          }
          _isSkippedSymbolicLink(entry) {
            return !this._settings.followSymbolicLinks && entry.dirent.isSymbolicLink();
          }
          _isSkippedByPositivePatterns(entryPath, matcher) {
            return !this._settings.baseNameMatch && !matcher.match(entryPath);
          }
          _isSkippedByNegativePatterns(entryPath, patternsRe) {
            return !utils2.pattern.matchAny(entryPath, patternsRe);
          }
        };
        exports2.default = DeepFilter;
      }
    });
    var require_entry = __commonJS22({
      "node_modules/fast-glob/out/providers/filters/entry.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils2 = require_utils42();
        var EntryFilter = class {
          constructor(_settings, _micromatchOptions) {
            this._settings = _settings;
            this._micromatchOptions = _micromatchOptions;
            this.index = /* @__PURE__ */ new Map();
          }
          getFilter(positive, negative) {
            const positiveRe = utils2.pattern.convertPatternsToRe(positive, this._micromatchOptions);
            const negativeRe = utils2.pattern.convertPatternsToRe(negative, this._micromatchOptions);
            return (entry) => this._filter(entry, positiveRe, negativeRe);
          }
          _filter(entry, positiveRe, negativeRe) {
            if (this._settings.unique && this._isDuplicateEntry(entry)) {
              return false;
            }
            if (this._onlyFileFilter(entry) || this._onlyDirectoryFilter(entry)) {
              return false;
            }
            if (this._isSkippedByAbsoluteNegativePatterns(entry.path, negativeRe)) {
              return false;
            }
            const filepath = this._settings.baseNameMatch ? entry.name : entry.path;
            const isDirectory = entry.dirent.isDirectory();
            const isMatched = this._isMatchToPatterns(filepath, positiveRe, isDirectory) && !this._isMatchToPatterns(entry.path, negativeRe, isDirectory);
            if (this._settings.unique && isMatched) {
              this._createIndexRecord(entry);
            }
            return isMatched;
          }
          _isDuplicateEntry(entry) {
            return this.index.has(entry.path);
          }
          _createIndexRecord(entry) {
            this.index.set(entry.path, void 0);
          }
          _onlyFileFilter(entry) {
            return this._settings.onlyFiles && !entry.dirent.isFile();
          }
          _onlyDirectoryFilter(entry) {
            return this._settings.onlyDirectories && !entry.dirent.isDirectory();
          }
          _isSkippedByAbsoluteNegativePatterns(entryPath, patternsRe) {
            if (!this._settings.absolute) {
              return false;
            }
            const fullpath = utils2.path.makeAbsolute(this._settings.cwd, entryPath);
            return utils2.pattern.matchAny(fullpath, patternsRe);
          }
          _isMatchToPatterns(entryPath, patternsRe, isDirectory) {
            const filepath = utils2.path.removeLeadingDotSegment(entryPath);
            const isMatched = utils2.pattern.matchAny(filepath, patternsRe);
            if (!isMatched && isDirectory) {
              return utils2.pattern.matchAny(filepath + "/", patternsRe);
            }
            return isMatched;
          }
        };
        exports2.default = EntryFilter;
      }
    });
    var require_error3 = __commonJS22({
      "node_modules/fast-glob/out/providers/filters/error.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils2 = require_utils42();
        var ErrorFilter = class {
          constructor(_settings) {
            this._settings = _settings;
          }
          getFilter() {
            return (error) => this._isNonFatalError(error);
          }
          _isNonFatalError(error) {
            return utils2.errno.isEnoentCodeError(error) || this._settings.suppressErrors;
          }
        };
        exports2.default = ErrorFilter;
      }
    });
    var require_entry2 = __commonJS22({
      "node_modules/fast-glob/out/providers/transformers/entry.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var utils2 = require_utils42();
        var EntryTransformer = class {
          constructor(_settings) {
            this._settings = _settings;
          }
          getTransformer() {
            return (entry) => this._transform(entry);
          }
          _transform(entry) {
            let filepath = entry.path;
            if (this._settings.absolute) {
              filepath = utils2.path.makeAbsolute(this._settings.cwd, filepath);
              filepath = utils2.path.unixify(filepath);
            }
            if (this._settings.markDirectories && entry.dirent.isDirectory()) {
              filepath += "/";
            }
            if (!this._settings.objectMode) {
              return filepath;
            }
            return Object.assign(Object.assign({}, entry), {
              path: filepath
            });
          }
        };
        exports2.default = EntryTransformer;
      }
    });
    var require_provider = __commonJS22({
      "node_modules/fast-glob/out/providers/provider.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var path2 = require("path");
        var deep_1 = require_deep();
        var entry_1 = require_entry();
        var error_1 = require_error3();
        var entry_2 = require_entry2();
        var Provider = class {
          constructor(_settings) {
            this._settings = _settings;
            this.errorFilter = new error_1.default(this._settings);
            this.entryFilter = new entry_1.default(this._settings, this._getMicromatchOptions());
            this.deepFilter = new deep_1.default(this._settings, this._getMicromatchOptions());
            this.entryTransformer = new entry_2.default(this._settings);
          }
          _getRootDirectory(task) {
            return path2.resolve(this._settings.cwd, task.base);
          }
          _getReaderOptions(task) {
            const basePath = task.base === "." ? "" : task.base;
            return {
              basePath,
              pathSegmentSeparator: "/",
              concurrency: this._settings.concurrency,
              deepFilter: this.deepFilter.getFilter(basePath, task.positive, task.negative),
              entryFilter: this.entryFilter.getFilter(task.positive, task.negative),
              errorFilter: this.errorFilter.getFilter(),
              followSymbolicLinks: this._settings.followSymbolicLinks,
              fs: this._settings.fs,
              stats: this._settings.stats,
              throwErrorOnBrokenSymbolicLink: this._settings.throwErrorOnBrokenSymbolicLink,
              transform: this.entryTransformer.getTransformer()
            };
          }
          _getMicromatchOptions() {
            return {
              dot: this._settings.dot,
              matchBase: this._settings.baseNameMatch,
              nobrace: !this._settings.braceExpansion,
              nocase: !this._settings.caseSensitiveMatch,
              noext: !this._settings.extglob,
              noglobstar: !this._settings.globstar,
              posix: true,
              strictSlashes: false
            };
          }
        };
        exports2.default = Provider;
      }
    });
    var require_async72 = __commonJS22({
      "node_modules/fast-glob/out/providers/async.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var async_1 = require_async62();
        var provider_1 = require_provider();
        var ProviderAsync = class extends provider_1.default {
          constructor() {
            super(...arguments);
            this._reader = new async_1.default(this._settings);
          }
          async read(task) {
            const root2 = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const entries = await this.api(root2, task, options);
            return entries.map((entry) => options.transform(entry));
          }
          api(root2, task, options) {
            if (task.dynamic) {
              return this._reader.dynamic(root2, options);
            }
            return this._reader.static(task.patterns, options);
          }
        };
        exports2.default = ProviderAsync;
      }
    });
    var require_stream4 = __commonJS22({
      "node_modules/fast-glob/out/providers/stream.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var stream_1 = require("stream");
        var stream_2 = require_stream32();
        var provider_1 = require_provider();
        var ProviderStream = class extends provider_1.default {
          constructor() {
            super(...arguments);
            this._reader = new stream_2.default(this._settings);
          }
          read(task) {
            const root2 = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const source = this.api(root2, task, options);
            const destination = new stream_1.Readable({
              objectMode: true,
              read: () => {
              }
            });
            source.once("error", (error) => destination.emit("error", error)).on("data", (entry) => destination.emit("data", options.transform(entry))).once("end", () => destination.emit("end"));
            destination.once("close", () => source.destroy());
            return destination;
          }
          api(root2, task, options) {
            if (task.dynamic) {
              return this._reader.dynamic(root2, options);
            }
            return this._reader.static(task.patterns, options);
          }
        };
        exports2.default = ProviderStream;
      }
    });
    var require_sync62 = __commonJS22({
      "node_modules/fast-glob/out/readers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var fsStat = require_out4();
        var fsWalk = require_out32();
        var reader_1 = require_reader22();
        var ReaderSync = class extends reader_1.default {
          constructor() {
            super(...arguments);
            this._walkSync = fsWalk.walkSync;
            this._statSync = fsStat.statSync;
          }
          dynamic(root2, options) {
            return this._walkSync(root2, options);
          }
          static(patterns, options) {
            const entries = [];
            for (const pattern of patterns) {
              const filepath = this._getFullEntryPath(pattern);
              const entry = this._getEntry(filepath, pattern, options);
              if (entry === null || !options.entryFilter(entry)) {
                continue;
              }
              entries.push(entry);
            }
            return entries;
          }
          _getEntry(filepath, pattern, options) {
            try {
              const stats = this._getStat(filepath);
              return this._makeEntry(stats, pattern);
            } catch (error) {
              if (options.errorFilter(error)) {
                return null;
              }
              throw error;
            }
          }
          _getStat(filepath) {
            return this._statSync(filepath, this._fsStatSettings);
          }
        };
        exports2.default = ReaderSync;
      }
    });
    var require_sync7 = __commonJS22({
      "node_modules/fast-glob/out/providers/sync.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var sync_1 = require_sync62();
        var provider_1 = require_provider();
        var ProviderSync = class extends provider_1.default {
          constructor() {
            super(...arguments);
            this._reader = new sync_1.default(this._settings);
          }
          read(task) {
            const root2 = this._getRootDirectory(task);
            const options = this._getReaderOptions(task);
            const entries = this.api(root2, task, options);
            return entries.map(options.transform);
          }
          api(root2, task, options) {
            if (task.dynamic) {
              return this._reader.dynamic(root2, options);
            }
            return this._reader.static(task.patterns, options);
          }
        };
        exports2.default = ProviderSync;
      }
    });
    var require_settings42 = __commonJS22({
      "node_modules/fast-glob/out/settings.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.DEFAULT_FILE_SYSTEM_ADAPTER = void 0;
        var fs2 = require("fs");
        var os = require("os");
        var CPU_COUNT = Math.max(os.cpus().length, 1);
        exports2.DEFAULT_FILE_SYSTEM_ADAPTER = {
          lstat: fs2.lstat,
          lstatSync: fs2.lstatSync,
          stat: fs2.stat,
          statSync: fs2.statSync,
          readdir: fs2.readdir,
          readdirSync: fs2.readdirSync
        };
        var Settings = class {
          constructor(_options = {}) {
            this._options = _options;
            this.absolute = this._getValue(this._options.absolute, false);
            this.baseNameMatch = this._getValue(this._options.baseNameMatch, false);
            this.braceExpansion = this._getValue(this._options.braceExpansion, true);
            this.caseSensitiveMatch = this._getValue(this._options.caseSensitiveMatch, true);
            this.concurrency = this._getValue(this._options.concurrency, CPU_COUNT);
            this.cwd = this._getValue(this._options.cwd, process.cwd());
            this.deep = this._getValue(this._options.deep, Infinity);
            this.dot = this._getValue(this._options.dot, false);
            this.extglob = this._getValue(this._options.extglob, true);
            this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, true);
            this.fs = this._getFileSystemMethods(this._options.fs);
            this.globstar = this._getValue(this._options.globstar, true);
            this.ignore = this._getValue(this._options.ignore, []);
            this.markDirectories = this._getValue(this._options.markDirectories, false);
            this.objectMode = this._getValue(this._options.objectMode, false);
            this.onlyDirectories = this._getValue(this._options.onlyDirectories, false);
            this.onlyFiles = this._getValue(this._options.onlyFiles, true);
            this.stats = this._getValue(this._options.stats, false);
            this.suppressErrors = this._getValue(this._options.suppressErrors, false);
            this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, false);
            this.unique = this._getValue(this._options.unique, true);
            if (this.onlyDirectories) {
              this.onlyFiles = false;
            }
            if (this.stats) {
              this.objectMode = true;
            }
          }
          _getValue(option, value2) {
            return option === void 0 ? value2 : option;
          }
          _getFileSystemMethods(methods = {}) {
            return Object.assign(Object.assign({}, exports2.DEFAULT_FILE_SYSTEM_ADAPTER), methods);
          }
        };
        exports2.default = Settings;
      }
    });
    var require_out42 = __commonJS22({
      "node_modules/fast-glob/out/index.js"(exports2, module22) {
        "use strict";
        var taskManager = require_tasks();
        var patternManager = require_patterns();
        var async_1 = require_async72();
        var stream_1 = require_stream4();
        var sync_1 = require_sync7();
        var settings_1 = require_settings42();
        var utils2 = require_utils42();
        async function FastGlob(source, options) {
          assertPatternsInput(source);
          const works = getWorks(source, async_1.default, options);
          const result = await Promise.all(works);
          return utils2.array.flatten(result);
        }
        (function(FastGlob2) {
          function sync(source, options) {
            assertPatternsInput(source);
            const works = getWorks(source, sync_1.default, options);
            return utils2.array.flatten(works);
          }
          FastGlob2.sync = sync;
          function stream(source, options) {
            assertPatternsInput(source);
            const works = getWorks(source, stream_1.default, options);
            return utils2.stream.merge(works);
          }
          FastGlob2.stream = stream;
          function generateTasks(source, options) {
            assertPatternsInput(source);
            const patterns = patternManager.transform([].concat(source));
            const settings = new settings_1.default(options);
            return taskManager.generate(patterns, settings);
          }
          FastGlob2.generateTasks = generateTasks;
          function isDynamicPattern(source, options) {
            assertPatternsInput(source);
            const settings = new settings_1.default(options);
            return utils2.pattern.isDynamicPattern(source, settings);
          }
          FastGlob2.isDynamicPattern = isDynamicPattern;
          function escapePath(source) {
            assertPatternsInput(source);
            return utils2.path.escape(source);
          }
          FastGlob2.escapePath = escapePath;
        })(FastGlob || (FastGlob = {}));
        function getWorks(source, _Provider, options) {
          const patterns = patternManager.transform([].concat(source));
          const settings = new settings_1.default(options);
          const tasks = taskManager.generate(patterns, settings);
          const provider = new _Provider(settings);
          return tasks.map(provider.read, provider);
        }
        function assertPatternsInput(input) {
          const source = [].concat(input);
          const isValidSource = source.every((item) => utils2.string.isString(item) && !utils2.string.isEmpty(item));
          if (!isValidSource) {
            throw new TypeError("Patterns must be a string (non empty) or an array of strings");
          }
        }
        module22.exports = FastGlob;
      }
    });
    var require_uniq_by_key = __commonJS22({
      "src/utils/uniq-by-key.js"(exports2, module22) {
        "use strict";
        function uniqByKey(array, key) {
          const result = [];
          const seen = /* @__PURE__ */ new Set();
          for (const element of array) {
            const value2 = element[key];
            if (!seen.has(value2)) {
              seen.add(value2);
              result.push(element);
            }
          }
          return result;
        }
        module22.exports = uniqByKey;
      }
    });
    var require_create_language = __commonJS22({
      "src/utils/create-language.js"(exports2, module22) {
        "use strict";
        module22.exports = function(linguistData, override) {
          const {
            languageId
          } = linguistData, rest = _objectWithoutProperties(linguistData, _excluded4);
          return Object.assign(Object.assign({
            linguistLanguageId: languageId
          }, rest), override(linguistData));
        };
      }
    });
    var require_ast2 = __commonJS22({
      "node_modules/esutils/lib/ast.js"(exports2, module22) {
        (function() {
          "use strict";
          function isExpression2(node) {
            if (node == null) {
              return false;
            }
            switch (node.type) {
              case "ArrayExpression":
              case "AssignmentExpression":
              case "BinaryExpression":
              case "CallExpression":
              case "ConditionalExpression":
              case "FunctionExpression":
              case "Identifier":
              case "Literal":
              case "LogicalExpression":
              case "MemberExpression":
              case "NewExpression":
              case "ObjectExpression":
              case "SequenceExpression":
              case "ThisExpression":
              case "UnaryExpression":
              case "UpdateExpression":
                return true;
            }
            return false;
          }
          function isIterationStatement(node) {
            if (node == null) {
              return false;
            }
            switch (node.type) {
              case "DoWhileStatement":
              case "ForInStatement":
              case "ForStatement":
              case "WhileStatement":
                return true;
            }
            return false;
          }
          function isStatement(node) {
            if (node == null) {
              return false;
            }
            switch (node.type) {
              case "BlockStatement":
              case "BreakStatement":
              case "ContinueStatement":
              case "DebuggerStatement":
              case "DoWhileStatement":
              case "EmptyStatement":
              case "ExpressionStatement":
              case "ForInStatement":
              case "ForStatement":
              case "IfStatement":
              case "LabeledStatement":
              case "ReturnStatement":
              case "SwitchStatement":
              case "ThrowStatement":
              case "TryStatement":
              case "VariableDeclaration":
              case "WhileStatement":
              case "WithStatement":
                return true;
            }
            return false;
          }
          function isSourceElement(node) {
            return isStatement(node) || node != null && node.type === "FunctionDeclaration";
          }
          function trailingStatement(node) {
            switch (node.type) {
              case "IfStatement":
                if (node.alternate != null) {
                  return node.alternate;
                }
                return node.consequent;
              case "LabeledStatement":
              case "ForStatement":
              case "ForInStatement":
              case "WhileStatement":
              case "WithStatement":
                return node.body;
            }
            return null;
          }
          function isProblematicIfStatement(node) {
            var current;
            if (node.type !== "IfStatement") {
              return false;
            }
            if (node.alternate == null) {
              return false;
            }
            current = node.consequent;
            do {
              if (current.type === "IfStatement") {
                if (current.alternate == null) {
                  return true;
                }
              }
              current = trailingStatement(current);
            } while (current);
            return false;
          }
          module22.exports = {
            isExpression: isExpression2,
            isStatement,
            isIterationStatement,
            isSourceElement,
            isProblematicIfStatement,
            trailingStatement
          };
        })();
      }
    });
    var require_code2 = __commonJS22({
      "node_modules/esutils/lib/code.js"(exports2, module22) {
        (function() {
          "use strict";
          var ES6Regex, ES5Regex, NON_ASCII_WHITESPACES, IDENTIFIER_START, IDENTIFIER_PART, ch;
          ES5Regex = {
            NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/,
            NonAsciiIdentifierPart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/
          };
          ES6Regex = {
            NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
            NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
          };
          function isDecimalDigit(ch2) {
            return 48 <= ch2 && ch2 <= 57;
          }
          function isHexDigit(ch2) {
            return 48 <= ch2 && ch2 <= 57 || 97 <= ch2 && ch2 <= 102 || 65 <= ch2 && ch2 <= 70;
          }
          function isOctalDigit(ch2) {
            return ch2 >= 48 && ch2 <= 55;
          }
          NON_ASCII_WHITESPACES = [5760, 8192, 8193, 8194, 8195, 8196, 8197, 8198, 8199, 8200, 8201, 8202, 8239, 8287, 12288, 65279];
          function isWhiteSpace(ch2) {
            return ch2 === 32 || ch2 === 9 || ch2 === 11 || ch2 === 12 || ch2 === 160 || ch2 >= 5760 && NON_ASCII_WHITESPACES.indexOf(ch2) >= 0;
          }
          function isLineTerminator(ch2) {
            return ch2 === 10 || ch2 === 13 || ch2 === 8232 || ch2 === 8233;
          }
          function fromCodePoint(cp) {
            if (cp <= 65535) {
              return String.fromCharCode(cp);
            }
            var cu1 = String.fromCharCode(Math.floor((cp - 65536) / 1024) + 55296);
            var cu2 = String.fromCharCode((cp - 65536) % 1024 + 56320);
            return cu1 + cu2;
          }
          IDENTIFIER_START = new Array(128);
          for (ch = 0; ch < 128; ++ch) {
            IDENTIFIER_START[ch] = ch >= 97 && ch <= 122 || ch >= 65 && ch <= 90 || ch === 36 || ch === 95;
          }
          IDENTIFIER_PART = new Array(128);
          for (ch = 0; ch < 128; ++ch) {
            IDENTIFIER_PART[ch] = ch >= 97 && ch <= 122 || ch >= 65 && ch <= 90 || ch >= 48 && ch <= 57 || ch === 36 || ch === 95;
          }
          function isIdentifierStartES5(ch2) {
            return ch2 < 128 ? IDENTIFIER_START[ch2] : ES5Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
          }
          function isIdentifierPartES5(ch2) {
            return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES5Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
          }
          function isIdentifierStartES6(ch2) {
            return ch2 < 128 ? IDENTIFIER_START[ch2] : ES6Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
          }
          function isIdentifierPartES6(ch2) {
            return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES6Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
          }
          module22.exports = {
            isDecimalDigit,
            isHexDigit,
            isOctalDigit,
            isWhiteSpace,
            isLineTerminator,
            isIdentifierStartES5,
            isIdentifierPartES5,
            isIdentifierStartES6,
            isIdentifierPartES6
          };
        })();
      }
    });
    var require_keyword22 = __commonJS22({
      "node_modules/esutils/lib/keyword.js"(exports2, module22) {
        (function() {
          "use strict";
          var code = require_code2();
          function isStrictModeReservedWordES6(id) {
            switch (id) {
              case "implements":
              case "interface":
              case "package":
              case "private":
              case "protected":
              case "public":
              case "static":
              case "let":
                return true;
              default:
                return false;
            }
          }
          function isKeywordES5(id, strict) {
            if (!strict && id === "yield") {
              return false;
            }
            return isKeywordES6(id, strict);
          }
          function isKeywordES6(id, strict) {
            if (strict && isStrictModeReservedWordES6(id)) {
              return true;
            }
            switch (id.length) {
              case 2:
                return id === "if" || id === "in" || id === "do";
              case 3:
                return id === "var" || id === "for" || id === "new" || id === "try";
              case 4:
                return id === "this" || id === "else" || id === "case" || id === "void" || id === "with" || id === "enum";
              case 5:
                return id === "while" || id === "break" || id === "catch" || id === "throw" || id === "const" || id === "yield" || id === "class" || id === "super";
              case 6:
                return id === "return" || id === "typeof" || id === "delete" || id === "switch" || id === "export" || id === "import";
              case 7:
                return id === "default" || id === "finally" || id === "extends";
              case 8:
                return id === "function" || id === "continue" || id === "debugger";
              case 10:
                return id === "instanceof";
              default:
                return false;
            }
          }
          function isReservedWordES5(id, strict) {
            return id === "null" || id === "true" || id === "false" || isKeywordES5(id, strict);
          }
          function isReservedWordES6(id, strict) {
            return id === "null" || id === "true" || id === "false" || isKeywordES6(id, strict);
          }
          function isRestrictedWord(id) {
            return id === "eval" || id === "arguments";
          }
          function isIdentifierNameES5(id) {
            var i, iz, ch;
            if (id.length === 0) {
              return false;
            }
            ch = id.charCodeAt(0);
            if (!code.isIdentifierStartES5(ch)) {
              return false;
            }
            for (i = 1, iz = id.length; i < iz; ++i) {
              ch = id.charCodeAt(i);
              if (!code.isIdentifierPartES5(ch)) {
                return false;
              }
            }
            return true;
          }
          function decodeUtf16(lead, trail) {
            return (lead - 55296) * 1024 + (trail - 56320) + 65536;
          }
          function isIdentifierNameES6(id) {
            var i, iz, ch, lowCh, check;
            if (id.length === 0) {
              return false;
            }
            check = code.isIdentifierStartES6;
            for (i = 0, iz = id.length; i < iz; ++i) {
              ch = id.charCodeAt(i);
              if (55296 <= ch && ch <= 56319) {
                ++i;
                if (i >= iz) {
                  return false;
                }
                lowCh = id.charCodeAt(i);
                if (!(56320 <= lowCh && lowCh <= 57343)) {
                  return false;
                }
                ch = decodeUtf16(ch, lowCh);
              }
              if (!check(ch)) {
                return false;
              }
              check = code.isIdentifierPartES6;
            }
            return true;
          }
          function isIdentifierES5(id, strict) {
            return isIdentifierNameES5(id) && !isReservedWordES5(id, strict);
          }
          function isIdentifierES6(id, strict) {
            return isIdentifierNameES6(id) && !isReservedWordES6(id, strict);
          }
          module22.exports = {
            isKeywordES5,
            isKeywordES6,
            isReservedWordES5,
            isReservedWordES6,
            isRestrictedWord,
            isIdentifierNameES5,
            isIdentifierNameES6,
            isIdentifierES5,
            isIdentifierES6
          };
        })();
      }
    });
    var require_utils62 = __commonJS22({
      "node_modules/esutils/lib/utils.js"(exports2) {
        (function() {
          "use strict";
          exports2.ast = require_ast2();
          exports2.code = require_code2();
          exports2.keyword = require_keyword22();
        })();
      }
    });
    var require_is_block_comment = __commonJS22({
      "src/language-js/utils/is-block-comment.js"(exports2, module22) {
        "use strict";
        var BLOCK_COMMENT_TYPES = /* @__PURE__ */ new Set(["Block", "CommentBlock", "MultiLine"]);
        var isBlockComment = (comment) => BLOCK_COMMENT_TYPES.has(comment === null || comment === void 0 ? void 0 : comment.type);
        module22.exports = isBlockComment;
      }
    });
    var require_is_node_matches = __commonJS22({
      "src/language-js/utils/is-node-matches.js"(exports2, module22) {
        "use strict";
        function isNodeMatchesNameOrPath(node, nameOrPath) {
          const names = nameOrPath.split(".");
          for (let index = names.length - 1; index >= 0; index--) {
            const name = names[index];
            if (index === 0) {
              return node.type === "Identifier" && node.name === name;
            }
            if (node.type !== "MemberExpression" || node.optional || node.computed || node.property.type !== "Identifier" || node.property.name !== name) {
              return false;
            }
            node = node.object;
          }
        }
        function isNodeMatches(node, nameOrPaths) {
          return nameOrPaths.some((nameOrPath) => isNodeMatchesNameOrPath(node, nameOrPath));
        }
        module22.exports = isNodeMatches;
      }
    });
    var require_utils72 = __commonJS22({
      "src/language-js/utils/index.js"(exports2, module22) {
        "use strict";
        var isIdentifierName = require_utils62().keyword.isIdentifierNameES5;
        var {
          getLast,
          hasNewline,
          skipWhitespace,
          isNonEmptyArray,
          isNextLineEmptyAfterIndex,
          getStringWidth
        } = require_util6();
        var {
          locStart,
          locEnd,
          hasSameLocStart
        } = require_loc();
        var isBlockComment = require_is_block_comment();
        var isNodeMatches = require_is_node_matches();
        var NON_LINE_TERMINATING_WHITE_SPACE = "(?:(?=.)\\s)";
        var FLOW_SHORTHAND_ANNOTATION = new RegExp(`^${NON_LINE_TERMINATING_WHITE_SPACE}*:`);
        var FLOW_ANNOTATION = new RegExp(`^${NON_LINE_TERMINATING_WHITE_SPACE}*::`);
        function hasFlowShorthandAnnotationComment(node) {
          var _node$extra, _node$trailingComment;
          return ((_node$extra = node.extra) === null || _node$extra === void 0 ? void 0 : _node$extra.parenthesized) && isBlockComment((_node$trailingComment = node.trailingComments) === null || _node$trailingComment === void 0 ? void 0 : _node$trailingComment[0]) && FLOW_SHORTHAND_ANNOTATION.test(node.trailingComments[0].value);
        }
        function hasFlowAnnotationComment(comments) {
          const firstComment = comments === null || comments === void 0 ? void 0 : comments[0];
          return isBlockComment(firstComment) && FLOW_ANNOTATION.test(firstComment.value);
        }
        function hasNode(node, fn) {
          if (!node || typeof node !== "object") {
            return false;
          }
          if (Array.isArray(node)) {
            return node.some((value2) => hasNode(value2, fn));
          }
          const result = fn(node);
          return typeof result === "boolean" ? result : Object.values(node).some((value2) => hasNode(value2, fn));
        }
        function hasNakedLeftSide(node) {
          return node.type === "AssignmentExpression" || node.type === "BinaryExpression" || node.type === "LogicalExpression" || node.type === "NGPipeExpression" || node.type === "ConditionalExpression" || isCallExpression2(node) || isMemberExpression(node) || node.type === "SequenceExpression" || node.type === "TaggedTemplateExpression" || node.type === "BindExpression" || node.type === "UpdateExpression" && !node.prefix || isTSTypeExpression(node) || node.type === "TSNonNullExpression";
        }
        function getLeftSide(node) {
          var _ref2, _ref3, _ref4, _ref5, _ref6, _node$left;
          if (node.expressions) {
            return node.expressions[0];
          }
          return (_ref2 = (_ref3 = (_ref4 = (_ref5 = (_ref6 = (_node$left = node.left) !== null && _node$left !== void 0 ? _node$left : node.test) !== null && _ref6 !== void 0 ? _ref6 : node.callee) !== null && _ref5 !== void 0 ? _ref5 : node.object) !== null && _ref4 !== void 0 ? _ref4 : node.tag) !== null && _ref3 !== void 0 ? _ref3 : node.argument) !== null && _ref2 !== void 0 ? _ref2 : node.expression;
        }
        function getLeftSidePathName(path2, node) {
          if (node.expressions) {
            return ["expressions", 0];
          }
          if (node.left) {
            return ["left"];
          }
          if (node.test) {
            return ["test"];
          }
          if (node.object) {
            return ["object"];
          }
          if (node.callee) {
            return ["callee"];
          }
          if (node.tag) {
            return ["tag"];
          }
          if (node.argument) {
            return ["argument"];
          }
          if (node.expression) {
            return ["expression"];
          }
          throw new Error("Unexpected node has no left side.");
        }
        function createTypeCheckFunction(types) {
          types = new Set(types);
          return (node) => types.has(node === null || node === void 0 ? void 0 : node.type);
        }
        var isLineComment = createTypeCheckFunction(["Line", "CommentLine", "SingleLine", "HashbangComment", "HTMLOpen", "HTMLClose"]);
        var isExportDeclaration = createTypeCheckFunction(["ExportDefaultDeclaration", "ExportDefaultSpecifier", "DeclareExportDeclaration", "ExportNamedDeclaration", "ExportAllDeclaration"]);
        function getParentExportDeclaration(path2) {
          const parentNode = path2.getParentNode();
          if (path2.getName() === "declaration" && isExportDeclaration(parentNode)) {
            return parentNode;
          }
          return null;
        }
        var isLiteral = createTypeCheckFunction(["BooleanLiteral", "DirectiveLiteral", "Literal", "NullLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "RegExpLiteral", "StringLiteral", "TemplateLiteral", "TSTypeLiteral", "JSXText"]);
        function isNumericLiteral(node) {
          return node.type === "NumericLiteral" || node.type === "Literal" && typeof node.value === "number";
        }
        function isSignedNumericLiteral(node) {
          return node.type === "UnaryExpression" && (node.operator === "+" || node.operator === "-") && isNumericLiteral(node.argument);
        }
        function isStringLiteral3(node) {
          return node.type === "StringLiteral" || node.type === "Literal" && typeof node.value === "string";
        }
        var isObjectType = createTypeCheckFunction(["ObjectTypeAnnotation", "TSTypeLiteral", "TSMappedType"]);
        var isFunctionOrArrowExpression = createTypeCheckFunction(["FunctionExpression", "ArrowFunctionExpression"]);
        function isFunctionOrArrowExpressionWithBody(node) {
          return node.type === "FunctionExpression" || node.type === "ArrowFunctionExpression" && node.body.type === "BlockStatement";
        }
        function isAngularTestWrapper(node) {
          return isCallExpression2(node) && node.callee.type === "Identifier" && ["async", "inject", "fakeAsync", "waitForAsync"].includes(node.callee.name);
        }
        var isJsxNode = createTypeCheckFunction(["JSXElement", "JSXFragment"]);
        function isTheOnlyJsxElementInMarkdown(options, path2) {
          if (options.parentParser !== "markdown" && options.parentParser !== "mdx") {
            return false;
          }
          const node = path2.getNode();
          if (!node.expression || !isJsxNode(node.expression)) {
            return false;
          }
          const parent = path2.getParentNode();
          return parent.type === "Program" && parent.body.length === 1;
        }
        function isGetterOrSetter(node) {
          return node.kind === "get" || node.kind === "set";
        }
        function isFunctionNotation(node) {
          return isGetterOrSetter(node) || hasSameLocStart(node, node.value);
        }
        function isObjectTypePropertyAFunction(node) {
          return (node.type === "ObjectTypeProperty" || node.type === "ObjectTypeInternalSlot") && node.value.type === "FunctionTypeAnnotation" && !node.static && !isFunctionNotation(node);
        }
        function isTypeAnnotationAFunction(node) {
          return (node.type === "TypeAnnotation" || node.type === "TSTypeAnnotation") && node.typeAnnotation.type === "FunctionTypeAnnotation" && !node.static && !hasSameLocStart(node, node.typeAnnotation);
        }
        var isBinaryish = createTypeCheckFunction(["BinaryExpression", "LogicalExpression", "NGPipeExpression"]);
        function isMemberish(node) {
          return isMemberExpression(node) || node.type === "BindExpression" && Boolean(node.object);
        }
        var simpleTypeAnnotations = /* @__PURE__ */ new Set(["AnyTypeAnnotation", "TSAnyKeyword", "NullLiteralTypeAnnotation", "TSNullKeyword", "ThisTypeAnnotation", "TSThisType", "NumberTypeAnnotation", "TSNumberKeyword", "VoidTypeAnnotation", "TSVoidKeyword", "BooleanTypeAnnotation", "TSBooleanKeyword", "BigIntTypeAnnotation", "TSBigIntKeyword", "SymbolTypeAnnotation", "TSSymbolKeyword", "StringTypeAnnotation", "TSStringKeyword", "BooleanLiteralTypeAnnotation", "StringLiteralTypeAnnotation", "BigIntLiteralTypeAnnotation", "NumberLiteralTypeAnnotation", "TSLiteralType", "TSTemplateLiteralType", "EmptyTypeAnnotation", "MixedTypeAnnotation", "TSNeverKeyword", "TSObjectKeyword", "TSUndefinedKeyword", "TSUnknownKeyword"]);
        function isSimpleType(node) {
          if (!node) {
            return false;
          }
          if ((node.type === "GenericTypeAnnotation" || node.type === "TSTypeReference") && !node.typeParameters) {
            return true;
          }
          if (simpleTypeAnnotations.has(node.type)) {
            return true;
          }
          return false;
        }
        function isUnitTestSetUp(node) {
          const unitTestSetUpRe = /^(?:before|after)(?:Each|All)$/;
          return node.callee.type === "Identifier" && unitTestSetUpRe.test(node.callee.name) && node.arguments.length === 1;
        }
        var testCallCalleePatterns = ["it", "it.only", "it.skip", "describe", "describe.only", "describe.skip", "test", "test.only", "test.skip", "test.step", "test.describe", "test.describe.only", "test.describe.parallel", "test.describe.parallel.only", "test.describe.serial", "test.describe.serial.only", "skip", "xit", "xdescribe", "xtest", "fit", "fdescribe", "ftest"];
        function isTestCallCallee(node) {
          return isNodeMatches(node, testCallCalleePatterns);
        }
        function isTestCall(node, parent) {
          if (node.type !== "CallExpression") {
            return false;
          }
          if (node.arguments.length === 1) {
            if (isAngularTestWrapper(node) && parent && isTestCall(parent)) {
              return isFunctionOrArrowExpression(node.arguments[0]);
            }
            if (isUnitTestSetUp(node)) {
              return isAngularTestWrapper(node.arguments[0]);
            }
          } else if (node.arguments.length === 2 || node.arguments.length === 3) {
            if ((node.arguments[0].type === "TemplateLiteral" || isStringLiteral3(node.arguments[0])) && isTestCallCallee(node.callee)) {
              if (node.arguments[2] && !isNumericLiteral(node.arguments[2])) {
                return false;
              }
              return (node.arguments.length === 2 ? isFunctionOrArrowExpression(node.arguments[1]) : isFunctionOrArrowExpressionWithBody(node.arguments[1]) && getFunctionParameters(node.arguments[1]).length <= 1) || isAngularTestWrapper(node.arguments[1]);
            }
          }
          return false;
        }
        var isCallExpression2 = createTypeCheckFunction(["CallExpression", "OptionalCallExpression"]);
        var isMemberExpression = createTypeCheckFunction(["MemberExpression", "OptionalMemberExpression"]);
        function isSimpleTemplateLiteral(node) {
          let expressionsKey = "expressions";
          if (node.type === "TSTemplateLiteralType") {
            expressionsKey = "types";
          }
          const expressions = node[expressionsKey];
          if (expressions.length === 0) {
            return false;
          }
          return expressions.every((expr) => {
            if (hasComment(expr)) {
              return false;
            }
            if (expr.type === "Identifier" || expr.type === "ThisExpression") {
              return true;
            }
            if (isMemberExpression(expr)) {
              let head = expr;
              while (isMemberExpression(head)) {
                if (head.property.type !== "Identifier" && head.property.type !== "Literal" && head.property.type !== "StringLiteral" && head.property.type !== "NumericLiteral") {
                  return false;
                }
                head = head.object;
                if (hasComment(head)) {
                  return false;
                }
              }
              if (head.type === "Identifier" || head.type === "ThisExpression") {
                return true;
              }
              return false;
            }
            return false;
          });
        }
        function getTypeScriptMappedTypeModifier(tokenNode, keyword) {
          if (tokenNode === "+" || tokenNode === "-") {
            return tokenNode + keyword;
          }
          return keyword;
        }
        function isFlowAnnotationComment(text, typeAnnotation) {
          const start = locStart(typeAnnotation);
          const end = skipWhitespace(text, locEnd(typeAnnotation));
          return end !== false && text.slice(start, start + 2) === "/*" && text.slice(end, end + 2) === "*/";
        }
        function hasLeadingOwnLineComment(text, node) {
          if (isJsxNode(node)) {
            return hasNodeIgnoreComment(node);
          }
          return hasComment(node, CommentCheckFlags.Leading, (comment) => hasNewline(text, locEnd(comment)));
        }
        function isStringPropSafeToUnquote(node, options) {
          return options.parser !== "json" && isStringLiteral3(node.key) && rawText(node.key).slice(1, -1) === node.key.value && (isIdentifierName(node.key.value) && !(options.parser === "babel-ts" && node.type === "ClassProperty" || options.parser === "typescript" && node.type === "PropertyDefinition") || isSimpleNumber(node.key.value) && String(Number(node.key.value)) === node.key.value && (options.parser === "babel" || options.parser === "acorn" || options.parser === "espree" || options.parser === "meriyah" || options.parser === "__babel_estree"));
        }
        function isSimpleNumber(numberString) {
          return /^(?:\d+|\d+\.\d+)$/.test(numberString);
        }
        function isJestEachTemplateLiteral(node, parentNode) {
          const jestEachTriggerRegex = /^[fx]?(?:describe|it|test)$/;
          return parentNode.type === "TaggedTemplateExpression" && parentNode.quasi === node && parentNode.tag.type === "MemberExpression" && parentNode.tag.property.type === "Identifier" && parentNode.tag.property.name === "each" && (parentNode.tag.object.type === "Identifier" && jestEachTriggerRegex.test(parentNode.tag.object.name) || parentNode.tag.object.type === "MemberExpression" && parentNode.tag.object.property.type === "Identifier" && (parentNode.tag.object.property.name === "only" || parentNode.tag.object.property.name === "skip") && parentNode.tag.object.object.type === "Identifier" && jestEachTriggerRegex.test(parentNode.tag.object.object.name));
        }
        function templateLiteralHasNewLines(template) {
          return template.quasis.some((quasi) => quasi.value.raw.includes("\n"));
        }
        function isTemplateOnItsOwnLine(node, text) {
          return (node.type === "TemplateLiteral" && templateLiteralHasNewLines(node) || node.type === "TaggedTemplateExpression" && templateLiteralHasNewLines(node.quasi)) && !hasNewline(text, locStart(node), {
            backwards: true
          });
        }
        function needsHardlineAfterDanglingComment(node) {
          if (!hasComment(node)) {
            return false;
          }
          const lastDanglingComment = getLast(getComments(node, CommentCheckFlags.Dangling));
          return lastDanglingComment && !isBlockComment(lastDanglingComment);
        }
        function isFunctionCompositionArgs(args) {
          if (args.length <= 1) {
            return false;
          }
          let count = 0;
          for (const arg of args) {
            if (isFunctionOrArrowExpression(arg)) {
              count += 1;
              if (count > 1) {
                return true;
              }
            } else if (isCallExpression2(arg)) {
              for (const childArg of arg.arguments) {
                if (isFunctionOrArrowExpression(childArg)) {
                  return true;
                }
              }
            }
          }
          return false;
        }
        function isLongCurriedCallExpression(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          return isCallExpression2(node) && isCallExpression2(parent) && parent.callee === node && node.arguments.length > parent.arguments.length && parent.arguments.length > 0;
        }
        function isSimpleCallArgument(node, depth) {
          if (depth >= 2) {
            return false;
          }
          const isChildSimple = (child) => isSimpleCallArgument(child, depth + 1);
          const regexpPattern = node.type === "Literal" && "regex" in node && node.regex.pattern || node.type === "RegExpLiteral" && node.pattern;
          if (regexpPattern && getStringWidth(regexpPattern) > 5) {
            return false;
          }
          if (node.type === "Literal" || node.type === "BigIntLiteral" || node.type === "DecimalLiteral" || node.type === "BooleanLiteral" || node.type === "NullLiteral" || node.type === "NumericLiteral" || node.type === "RegExpLiteral" || node.type === "StringLiteral" || node.type === "Identifier" || node.type === "ThisExpression" || node.type === "Super" || node.type === "PrivateName" || node.type === "PrivateIdentifier" || node.type === "ArgumentPlaceholder" || node.type === "Import") {
            return true;
          }
          if (node.type === "TemplateLiteral") {
            return node.quasis.every((element) => !element.value.raw.includes("\n")) && node.expressions.every(isChildSimple);
          }
          if (node.type === "ObjectExpression") {
            return node.properties.every((p) => !p.computed && (p.shorthand || p.value && isChildSimple(p.value)));
          }
          if (node.type === "ArrayExpression") {
            return node.elements.every((x) => x === null || isChildSimple(x));
          }
          if (isCallLikeExpression(node)) {
            return (node.type === "ImportExpression" || isSimpleCallArgument(node.callee, depth)) && getCallArguments(node).every(isChildSimple);
          }
          if (isMemberExpression(node)) {
            return isSimpleCallArgument(node.object, depth) && isSimpleCallArgument(node.property, depth);
          }
          const targetUnaryExpressionOperators = {
            "!": true,
            "-": true,
            "+": true,
            "~": true
          };
          if (node.type === "UnaryExpression" && targetUnaryExpressionOperators[node.operator]) {
            return isSimpleCallArgument(node.argument, depth);
          }
          const targetUpdateExpressionOperators = {
            "++": true,
            "--": true
          };
          if (node.type === "UpdateExpression" && targetUpdateExpressionOperators[node.operator]) {
            return isSimpleCallArgument(node.argument, depth);
          }
          if (node.type === "TSNonNullExpression") {
            return isSimpleCallArgument(node.expression, depth);
          }
          return false;
        }
        function rawText(node) {
          var _node$extra$raw, _node$extra2;
          return (_node$extra$raw = (_node$extra2 = node.extra) === null || _node$extra2 === void 0 ? void 0 : _node$extra2.raw) !== null && _node$extra$raw !== void 0 ? _node$extra$raw : node.raw;
        }
        function identity(x) {
          return x;
        }
        function isTSXFile(options) {
          return options.filepath && /\.tsx$/i.test(options.filepath);
        }
        function shouldPrintComma(options, level = "es5") {
          return options.trailingComma === "es5" && level === "es5" || options.trailingComma === "all" && (level === "all" || level === "es5");
        }
        function startsWithNoLookaheadToken(node, predicate) {
          switch (node.type) {
            case "BinaryExpression":
            case "LogicalExpression":
            case "AssignmentExpression":
            case "NGPipeExpression":
              return startsWithNoLookaheadToken(node.left, predicate);
            case "MemberExpression":
            case "OptionalMemberExpression":
              return startsWithNoLookaheadToken(node.object, predicate);
            case "TaggedTemplateExpression":
              if (node.tag.type === "FunctionExpression") {
                return false;
              }
              return startsWithNoLookaheadToken(node.tag, predicate);
            case "CallExpression":
            case "OptionalCallExpression":
              if (node.callee.type === "FunctionExpression") {
                return false;
              }
              return startsWithNoLookaheadToken(node.callee, predicate);
            case "ConditionalExpression":
              return startsWithNoLookaheadToken(node.test, predicate);
            case "UpdateExpression":
              return !node.prefix && startsWithNoLookaheadToken(node.argument, predicate);
            case "BindExpression":
              return node.object && startsWithNoLookaheadToken(node.object, predicate);
            case "SequenceExpression":
              return startsWithNoLookaheadToken(node.expressions[0], predicate);
            case "TSSatisfiesExpression":
            case "TSAsExpression":
            case "TSNonNullExpression":
              return startsWithNoLookaheadToken(node.expression, predicate);
            default:
              return predicate(node);
          }
        }
        var equalityOperators = {
          "==": true,
          "!=": true,
          "===": true,
          "!==": true
        };
        var multiplicativeOperators = {
          "*": true,
          "/": true,
          "%": true
        };
        var bitshiftOperators = {
          ">>": true,
          ">>>": true,
          "<<": true
        };
        function shouldFlatten(parentOp, nodeOp) {
          if (getPrecedence(nodeOp) !== getPrecedence(parentOp)) {
            return false;
          }
          if (parentOp === "**") {
            return false;
          }
          if (equalityOperators[parentOp] && equalityOperators[nodeOp]) {
            return false;
          }
          if (nodeOp === "%" && multiplicativeOperators[parentOp] || parentOp === "%" && multiplicativeOperators[nodeOp]) {
            return false;
          }
          if (nodeOp !== parentOp && multiplicativeOperators[nodeOp] && multiplicativeOperators[parentOp]) {
            return false;
          }
          if (bitshiftOperators[parentOp] && bitshiftOperators[nodeOp]) {
            return false;
          }
          return true;
        }
        var PRECEDENCE = new Map([["|>"], ["??"], ["||"], ["&&"], ["|"], ["^"], ["&"], ["==", "===", "!=", "!=="], ["<", ">", "<=", ">=", "in", "instanceof"], [">>", "<<", ">>>"], ["+", "-"], ["*", "/", "%"], ["**"]].flatMap((operators, index) => operators.map((operator) => [operator, index])));
        function getPrecedence(operator) {
          return PRECEDENCE.get(operator);
        }
        function isBitwiseOperator(operator) {
          return Boolean(bitshiftOperators[operator]) || operator === "|" || operator === "^" || operator === "&";
        }
        function hasRestParameter(node) {
          var _getLast;
          if (node.rest) {
            return true;
          }
          const parameters = getFunctionParameters(node);
          return ((_getLast = getLast(parameters)) === null || _getLast === void 0 ? void 0 : _getLast.type) === "RestElement";
        }
        var functionParametersCache = /* @__PURE__ */ new WeakMap();
        function getFunctionParameters(node) {
          if (functionParametersCache.has(node)) {
            return functionParametersCache.get(node);
          }
          const parameters = [];
          if (node.this) {
            parameters.push(node.this);
          }
          if (Array.isArray(node.parameters)) {
            parameters.push(...node.parameters);
          } else if (Array.isArray(node.params)) {
            parameters.push(...node.params);
          }
          if (node.rest) {
            parameters.push(node.rest);
          }
          functionParametersCache.set(node, parameters);
          return parameters;
        }
        function iterateFunctionParametersPath(path2, iteratee) {
          const node = path2.getValue();
          let index = 0;
          const callback = (childPath) => iteratee(childPath, index++);
          if (node.this) {
            path2.call(callback, "this");
          }
          if (Array.isArray(node.parameters)) {
            path2.each(callback, "parameters");
          } else if (Array.isArray(node.params)) {
            path2.each(callback, "params");
          }
          if (node.rest) {
            path2.call(callback, "rest");
          }
        }
        var callArgumentsCache = /* @__PURE__ */ new WeakMap();
        function getCallArguments(node) {
          if (callArgumentsCache.has(node)) {
            return callArgumentsCache.get(node);
          }
          let args = node.arguments;
          if (node.type === "ImportExpression") {
            args = [node.source];
            if (node.attributes) {
              args.push(node.attributes);
            }
          }
          callArgumentsCache.set(node, args);
          return args;
        }
        function iterateCallArgumentsPath(path2, iteratee) {
          const node = path2.getValue();
          if (node.type === "ImportExpression") {
            path2.call((sourcePath) => iteratee(sourcePath, 0), "source");
            if (node.attributes) {
              path2.call((sourcePath) => iteratee(sourcePath, 1), "attributes");
            }
          } else {
            path2.each(iteratee, "arguments");
          }
        }
        function isPrettierIgnoreComment(comment) {
          return comment.value.trim() === "prettier-ignore" && !comment.unignore;
        }
        function hasNodeIgnoreComment(node) {
          return node && (node.prettierIgnore || hasComment(node, CommentCheckFlags.PrettierIgnore));
        }
        function hasIgnoreComment(path2) {
          const node = path2.getValue();
          return hasNodeIgnoreComment(node);
        }
        var CommentCheckFlags = {
          Leading: 1 << 1,
          Trailing: 1 << 2,
          Dangling: 1 << 3,
          Block: 1 << 4,
          Line: 1 << 5,
          PrettierIgnore: 1 << 6,
          First: 1 << 7,
          Last: 1 << 8
        };
        var getCommentTestFunction = (flags, fn) => {
          if (typeof flags === "function") {
            fn = flags;
            flags = 0;
          }
          if (flags || fn) {
            return (comment, index, comments) => !(flags & CommentCheckFlags.Leading && !comment.leading || flags & CommentCheckFlags.Trailing && !comment.trailing || flags & CommentCheckFlags.Dangling && (comment.leading || comment.trailing) || flags & CommentCheckFlags.Block && !isBlockComment(comment) || flags & CommentCheckFlags.Line && !isLineComment(comment) || flags & CommentCheckFlags.First && index !== 0 || flags & CommentCheckFlags.Last && index !== comments.length - 1 || flags & CommentCheckFlags.PrettierIgnore && !isPrettierIgnoreComment(comment) || fn && !fn(comment));
          }
        };
        function hasComment(node, flags, fn) {
          if (!isNonEmptyArray(node === null || node === void 0 ? void 0 : node.comments)) {
            return false;
          }
          const test = getCommentTestFunction(flags, fn);
          return test ? node.comments.some(test) : true;
        }
        function getComments(node, flags, fn) {
          if (!Array.isArray(node === null || node === void 0 ? void 0 : node.comments)) {
            return [];
          }
          const test = getCommentTestFunction(flags, fn);
          return test ? node.comments.filter(test) : node.comments;
        }
        var isNextLineEmpty = (node, {
          originalText
        }) => isNextLineEmptyAfterIndex(originalText, locEnd(node));
        function isCallLikeExpression(node) {
          return isCallExpression2(node) || node.type === "NewExpression" || node.type === "ImportExpression";
        }
        function isObjectProperty(node) {
          return node && (node.type === "ObjectProperty" || node.type === "Property" && !node.method && node.kind === "init");
        }
        function isEnabledHackPipeline(options) {
          return Boolean(options.__isUsingHackPipeline);
        }
        var markerForIfWithoutBlockAndSameLineComment = Symbol("ifWithoutBlockAndSameLineComment");
        function isTSTypeExpression(node) {
          return node.type === "TSAsExpression" || node.type === "TSSatisfiesExpression";
        }
        module22.exports = {
          getFunctionParameters,
          iterateFunctionParametersPath,
          getCallArguments,
          iterateCallArgumentsPath,
          hasRestParameter,
          getLeftSide,
          getLeftSidePathName,
          getParentExportDeclaration,
          getTypeScriptMappedTypeModifier,
          hasFlowAnnotationComment,
          hasFlowShorthandAnnotationComment,
          hasLeadingOwnLineComment,
          hasNakedLeftSide,
          hasNode,
          hasIgnoreComment,
          hasNodeIgnoreComment,
          identity,
          isBinaryish,
          isCallLikeExpression,
          isEnabledHackPipeline,
          isLineComment,
          isPrettierIgnoreComment,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isExportDeclaration,
          isFlowAnnotationComment,
          isFunctionCompositionArgs,
          isFunctionNotation,
          isFunctionOrArrowExpression,
          isGetterOrSetter,
          isJestEachTemplateLiteral,
          isJsxNode,
          isLiteral,
          isLongCurriedCallExpression,
          isSimpleCallArgument,
          isMemberish,
          isNumericLiteral,
          isSignedNumericLiteral,
          isObjectProperty,
          isObjectType,
          isObjectTypePropertyAFunction,
          isSimpleType,
          isSimpleNumber,
          isSimpleTemplateLiteral,
          isStringLiteral: isStringLiteral3,
          isStringPropSafeToUnquote,
          isTemplateOnItsOwnLine,
          isTestCall,
          isTheOnlyJsxElementInMarkdown,
          isTSXFile,
          isTypeAnnotationAFunction,
          isNextLineEmpty,
          needsHardlineAfterDanglingComment,
          rawText,
          shouldPrintComma,
          isBitwiseOperator,
          shouldFlatten,
          startsWithNoLookaheadToken,
          getPrecedence,
          hasComment,
          getComments,
          CommentCheckFlags,
          markerForIfWithoutBlockAndSameLineComment,
          isTSTypeExpression
        };
      }
    });
    var require_template_literal = __commonJS22({
      "src/language-js/print/template-literal.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        var {
          getStringWidth,
          getIndentSize
        } = require_util6();
        var {
          builders: {
            join,
            hardline,
            softline,
            group,
            indent,
            align,
            lineSuffixBoundary,
            addAlignmentToDoc
          },
          printer: {
            printDocToString
          },
          utils: {
            mapDoc
          }
        } = require_doc();
        var {
          isBinaryish,
          isJestEachTemplateLiteral,
          isSimpleTemplateLiteral,
          hasComment,
          isMemberExpression,
          isTSTypeExpression
        } = require_utils72();
        function printTemplateLiteral(path2, print, options) {
          const node = path2.getValue();
          const isTemplateLiteral = node.type === "TemplateLiteral";
          if (isTemplateLiteral && isJestEachTemplateLiteral(node, path2.getParentNode())) {
            const printed = printJestEachTemplateLiteral(path2, options, print);
            if (printed) {
              return printed;
            }
          }
          let expressionsKey = "expressions";
          if (node.type === "TSTemplateLiteralType") {
            expressionsKey = "types";
          }
          const parts = [];
          let expressions = path2.map(print, expressionsKey);
          const isSimple = isSimpleTemplateLiteral(node);
          if (isSimple) {
            expressions = expressions.map((doc2) => printDocToString(doc2, Object.assign(Object.assign({}, options), {}, {
              printWidth: Number.POSITIVE_INFINITY
            })).formatted);
          }
          parts.push(lineSuffixBoundary, "`");
          path2.each((childPath) => {
            const i = childPath.getName();
            parts.push(print());
            if (i < expressions.length) {
              const {
                tabWidth
              } = options;
              const quasi = childPath.getValue();
              const indentSize = getIndentSize(quasi.value.raw, tabWidth);
              let printed = expressions[i];
              if (!isSimple) {
                const expression = node[expressionsKey][i];
                if (hasComment(expression) || isMemberExpression(expression) || expression.type === "ConditionalExpression" || expression.type === "SequenceExpression" || isTSTypeExpression(expression) || isBinaryish(expression)) {
                  printed = [indent([softline, printed]), softline];
                }
              }
              const aligned = indentSize === 0 && quasi.value.raw.endsWith("\n") ? align(Number.NEGATIVE_INFINITY, printed) : addAlignmentToDoc(printed, indentSize, tabWidth);
              parts.push(group(["${", aligned, lineSuffixBoundary, "}"]));
            }
          }, "quasis");
          parts.push("`");
          return parts;
        }
        function printJestEachTemplateLiteral(path2, options, print) {
          const node = path2.getNode();
          const headerNames = node.quasis[0].value.raw.trim().split(/\s*\|\s*/);
          if (headerNames.length > 1 || headerNames.some((headerName) => headerName.length > 0)) {
            options.__inJestEach = true;
            const expressions = path2.map(print, "expressions");
            options.__inJestEach = false;
            const parts = [];
            const stringifiedExpressions = expressions.map((doc2) => "${" + printDocToString(doc2, Object.assign(Object.assign({}, options), {}, {
              printWidth: Number.POSITIVE_INFINITY,
              endOfLine: "lf"
            })).formatted + "}");
            const tableBody = [{
              hasLineBreak: false,
              cells: []
            }];
            for (let i = 1; i < node.quasis.length; i++) {
              const row = getLast(tableBody);
              const correspondingExpression = stringifiedExpressions[i - 1];
              row.cells.push(correspondingExpression);
              if (correspondingExpression.includes("\n")) {
                row.hasLineBreak = true;
              }
              if (node.quasis[i].value.raw.includes("\n")) {
                tableBody.push({
                  hasLineBreak: false,
                  cells: []
                });
              }
            }
            const maxColumnCount = Math.max(headerNames.length, ...tableBody.map((row) => row.cells.length));
            const maxColumnWidths = Array.from({
              length: maxColumnCount
            }).fill(0);
            const table = [{
              cells: headerNames
            }, ...tableBody.filter((row) => row.cells.length > 0)];
            for (const {
              cells
            } of table.filter((row) => !row.hasLineBreak)) {
              for (const [index, cell] of cells.entries()) {
                maxColumnWidths[index] = Math.max(maxColumnWidths[index], getStringWidth(cell));
              }
            }
            parts.push(lineSuffixBoundary, "`", indent([hardline, join(hardline, table.map((row) => join(" | ", row.cells.map((cell, index) => row.hasLineBreak ? cell : cell + " ".repeat(maxColumnWidths[index] - getStringWidth(cell))))))]), hardline, "`");
            return parts;
          }
        }
        function printTemplateExpression(path2, print) {
          const node = path2.getValue();
          let printed = print();
          if (hasComment(node)) {
            printed = group([indent([softline, printed]), softline]);
          }
          return ["${", printed, lineSuffixBoundary, "}"];
        }
        function printTemplateExpressions(path2, print) {
          return path2.map((path22) => printTemplateExpression(path22, print), "expressions");
        }
        function escapeTemplateCharacters(doc2, raw) {
          return mapDoc(doc2, (currentDoc) => {
            if (typeof currentDoc === "string") {
              return raw ? currentDoc.replace(/(\\*)`/g, "$1$1\\`") : uncookTemplateElementValue(currentDoc);
            }
            return currentDoc;
          });
        }
        function uncookTemplateElementValue(cookedValue) {
          return cookedValue.replace(/([\\`]|\${)/g, "\\$1");
        }
        module22.exports = {
          printTemplateLiteral,
          printTemplateExpressions,
          escapeTemplateCharacters,
          uncookTemplateElementValue
        };
      }
    });
    var require_markdown = __commonJS22({
      "src/language-js/embed/markdown.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            indent,
            softline,
            literalline,
            dedentToRoot
          }
        } = require_doc();
        var {
          escapeTemplateCharacters
        } = require_template_literal();
        function format2(path2, print, textToDoc) {
          const node = path2.getValue();
          let text = node.quasis[0].value.raw.replace(/((?:\\\\)*)\\`/g, (_, backslashes) => "\\".repeat(backslashes.length / 2) + "`");
          const indentation = getIndentation(text);
          const hasIndent = indentation !== "";
          if (hasIndent) {
            text = text.replace(new RegExp(`^${indentation}`, "gm"), "");
          }
          const doc2 = escapeTemplateCharacters(textToDoc(text, {
            parser: "markdown",
            __inJsTemplate: true
          }, {
            stripTrailingHardline: true
          }), true);
          return ["`", hasIndent ? indent([softline, doc2]) : [literalline, dedentToRoot(doc2)], softline, "`"];
        }
        function getIndentation(str) {
          const firstMatchedIndent = str.match(/^([^\S\n]*)\S/m);
          return firstMatchedIndent === null ? "" : firstMatchedIndent[1];
        }
        module22.exports = format2;
      }
    });
    var require_css = __commonJS22({
      "src/language-js/embed/css.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            indent,
            hardline,
            softline
          },
          utils: {
            mapDoc,
            replaceEndOfLine,
            cleanDoc
          }
        } = require_doc();
        var {
          printTemplateExpressions
        } = require_template_literal();
        function format2(path2, print, textToDoc) {
          const node = path2.getValue();
          const rawQuasis = node.quasis.map((q) => q.value.raw);
          let placeholderID = 0;
          const text = rawQuasis.reduce((prevVal, currVal, idx) => idx === 0 ? currVal : prevVal + "@prettier-placeholder-" + placeholderID++ + "-id" + currVal, "");
          const doc2 = textToDoc(text, {
            parser: "scss"
          }, {
            stripTrailingHardline: true
          });
          const expressionDocs = printTemplateExpressions(path2, print);
          return transformCssDoc(doc2, node, expressionDocs);
        }
        function transformCssDoc(quasisDoc, parentNode, expressionDocs) {
          const isEmpty2 = parentNode.quasis.length === 1 && !parentNode.quasis[0].value.raw.trim();
          if (isEmpty2) {
            return "``";
          }
          const newDoc = replacePlaceholders(quasisDoc, expressionDocs);
          if (!newDoc) {
            throw new Error("Couldn't insert all the expressions");
          }
          return ["`", indent([hardline, newDoc]), softline, "`"];
        }
        function replacePlaceholders(quasisDoc, expressionDocs) {
          if (!isNonEmptyArray(expressionDocs)) {
            return quasisDoc;
          }
          let replaceCounter = 0;
          const newDoc = mapDoc(cleanDoc(quasisDoc), (doc2) => {
            if (typeof doc2 !== "string" || !doc2.includes("@prettier-placeholder")) {
              return doc2;
            }
            return doc2.split(/@prettier-placeholder-(\d+)-id/).map((component, idx) => {
              if (idx % 2 === 0) {
                return replaceEndOfLine(component);
              }
              replaceCounter++;
              return expressionDocs[component];
            });
          });
          return expressionDocs.length === replaceCounter ? newDoc : null;
        }
        module22.exports = format2;
      }
    });
    var require_graphql = __commonJS22({
      "src/language-js/embed/graphql.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            indent,
            join,
            hardline
          }
        } = require_doc();
        var {
          escapeTemplateCharacters,
          printTemplateExpressions
        } = require_template_literal();
        function format2(path2, print, textToDoc) {
          const node = path2.getValue();
          const numQuasis = node.quasis.length;
          if (numQuasis === 1 && node.quasis[0].value.raw.trim() === "") {
            return "``";
          }
          const expressionDocs = printTemplateExpressions(path2, print);
          const parts = [];
          for (let i = 0; i < numQuasis; i++) {
            const templateElement = node.quasis[i];
            const isFirst = i === 0;
            const isLast = i === numQuasis - 1;
            const text = templateElement.value.cooked;
            const lines = text.split("\n");
            const numLines = lines.length;
            const expressionDoc = expressionDocs[i];
            const startsWithBlankLine = numLines > 2 && lines[0].trim() === "" && lines[1].trim() === "";
            const endsWithBlankLine = numLines > 2 && lines[numLines - 1].trim() === "" && lines[numLines - 2].trim() === "";
            const commentsAndWhitespaceOnly = lines.every((line) => /^\s*(?:#[^\n\r]*)?$/.test(line));
            if (!isLast && /#[^\n\r]*$/.test(lines[numLines - 1])) {
              return null;
            }
            let doc2 = null;
            if (commentsAndWhitespaceOnly) {
              doc2 = printGraphqlComments(lines);
            } else {
              doc2 = textToDoc(text, {
                parser: "graphql"
              }, {
                stripTrailingHardline: true
              });
            }
            if (doc2) {
              doc2 = escapeTemplateCharacters(doc2, false);
              if (!isFirst && startsWithBlankLine) {
                parts.push("");
              }
              parts.push(doc2);
              if (!isLast && endsWithBlankLine) {
                parts.push("");
              }
            } else if (!isFirst && !isLast && startsWithBlankLine) {
              parts.push("");
            }
            if (expressionDoc) {
              parts.push(expressionDoc);
            }
          }
          return ["`", indent([hardline, join(hardline, parts)]), hardline, "`"];
        }
        function printGraphqlComments(lines) {
          const parts = [];
          let seenComment = false;
          const array = lines.map((textLine) => textLine.trim());
          for (const [i, textLine] of array.entries()) {
            if (textLine === "") {
              continue;
            }
            if (array[i - 1] === "" && seenComment) {
              parts.push([hardline, textLine]);
            } else {
              parts.push(textLine);
            }
            seenComment = true;
          }
          return parts.length === 0 ? null : join(hardline, parts);
        }
        module22.exports = format2;
      }
    });
    var require_html = __commonJS22({
      "src/language-js/embed/html.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            indent,
            line,
            hardline,
            group
          },
          utils: {
            mapDoc
          }
        } = require_doc();
        var {
          printTemplateExpressions,
          uncookTemplateElementValue
        } = require_template_literal();
        var htmlTemplateLiteralCounter = 0;
        function format2(path2, print, textToDoc, options, {
          parser
        }) {
          const node = path2.getValue();
          const counter = htmlTemplateLiteralCounter;
          htmlTemplateLiteralCounter = htmlTemplateLiteralCounter + 1 >>> 0;
          const composePlaceholder = (index) => `PRETTIER_HTML_PLACEHOLDER_${index}_${counter}_IN_JS`;
          const text = node.quasis.map((quasi, index, quasis) => index === quasis.length - 1 ? quasi.value.cooked : quasi.value.cooked + composePlaceholder(index)).join("");
          const expressionDocs = printTemplateExpressions(path2, print);
          if (expressionDocs.length === 0 && text.trim().length === 0) {
            return "``";
          }
          const placeholderRegex = new RegExp(composePlaceholder("(\\d+)"), "g");
          let topLevelCount = 0;
          const doc2 = textToDoc(text, {
            parser,
            __onHtmlRoot(root2) {
              topLevelCount = root2.children.length;
            }
          }, {
            stripTrailingHardline: true
          });
          const contentDoc = mapDoc(doc2, (doc3) => {
            if (typeof doc3 !== "string") {
              return doc3;
            }
            const parts = [];
            const components = doc3.split(placeholderRegex);
            for (let i = 0; i < components.length; i++) {
              let component = components[i];
              if (i % 2 === 0) {
                if (component) {
                  component = uncookTemplateElementValue(component);
                  if (options.__embeddedInHtml) {
                    component = component.replace(/<\/(script)\b/gi, "<\\/$1");
                  }
                  parts.push(component);
                }
                continue;
              }
              const placeholderIndex = Number(component);
              parts.push(expressionDocs[placeholderIndex]);
            }
            return parts;
          });
          const leadingWhitespace = /^\s/.test(text) ? " " : "";
          const trailingWhitespace = /\s$/.test(text) ? " " : "";
          const linebreak = options.htmlWhitespaceSensitivity === "ignore" ? hardline : leadingWhitespace && trailingWhitespace ? line : null;
          if (linebreak) {
            return group(["`", indent([linebreak, group(contentDoc)]), linebreak, "`"]);
          }
          return group(["`", leadingWhitespace, topLevelCount > 1 ? indent(group(contentDoc)) : group(contentDoc), trailingWhitespace, "`"]);
        }
        module22.exports = format2;
      }
    });
    var require_embed = __commonJS22({
      "src/language-js/embed.js"(exports2, module22) {
        "use strict";
        var {
          hasComment,
          CommentCheckFlags,
          isObjectProperty
        } = require_utils72();
        var formatMarkdown = require_markdown();
        var formatCss = require_css();
        var formatGraphql = require_graphql();
        var formatHtml = require_html();
        function getLanguage(path2) {
          if (isStyledJsx(path2) || isStyledComponents(path2) || isCssProp(path2) || isAngularComponentStyles(path2)) {
            return "css";
          }
          if (isGraphQL(path2)) {
            return "graphql";
          }
          if (isHtml(path2)) {
            return "html";
          }
          if (isAngularComponentTemplate(path2)) {
            return "angular";
          }
          if (isMarkdown(path2)) {
            return "markdown";
          }
        }
        function embed(path2, print, textToDoc, options) {
          const node = path2.getValue();
          if (node.type !== "TemplateLiteral" || hasInvalidCookedValue(node)) {
            return;
          }
          const language = getLanguage(path2);
          if (!language) {
            return;
          }
          if (language === "markdown") {
            return formatMarkdown(path2, print, textToDoc);
          }
          if (language === "css") {
            return formatCss(path2, print, textToDoc);
          }
          if (language === "graphql") {
            return formatGraphql(path2, print, textToDoc);
          }
          if (language === "html" || language === "angular") {
            return formatHtml(path2, print, textToDoc, options, {
              parser: language
            });
          }
        }
        function isMarkdown(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          return parent && parent.type === "TaggedTemplateExpression" && node.quasis.length === 1 && parent.tag.type === "Identifier" && (parent.tag.name === "md" || parent.tag.name === "markdown");
        }
        function isStyledJsx(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          const parentParent = path2.getParentNode(1);
          return parentParent && node.quasis && parent.type === "JSXExpressionContainer" && parentParent.type === "JSXElement" && parentParent.openingElement.name.name === "style" && parentParent.openingElement.attributes.some((attribute) => attribute.name.name === "jsx") || parent && parent.type === "TaggedTemplateExpression" && parent.tag.type === "Identifier" && parent.tag.name === "css" || parent && parent.type === "TaggedTemplateExpression" && parent.tag.type === "MemberExpression" && parent.tag.object.name === "css" && (parent.tag.property.name === "global" || parent.tag.property.name === "resolve");
        }
        function isAngularComponentStyles(path2) {
          return path2.match((node) => node.type === "TemplateLiteral", (node, name) => node.type === "ArrayExpression" && name === "elements", (node, name) => isObjectProperty(node) && node.key.type === "Identifier" && node.key.name === "styles" && name === "value", ...angularComponentObjectExpressionPredicates);
        }
        function isAngularComponentTemplate(path2) {
          return path2.match((node) => node.type === "TemplateLiteral", (node, name) => isObjectProperty(node) && node.key.type === "Identifier" && node.key.name === "template" && name === "value", ...angularComponentObjectExpressionPredicates);
        }
        var angularComponentObjectExpressionPredicates = [(node, name) => node.type === "ObjectExpression" && name === "properties", (node, name) => node.type === "CallExpression" && node.callee.type === "Identifier" && node.callee.name === "Component" && name === "arguments", (node, name) => node.type === "Decorator" && name === "expression"];
        function isStyledComponents(path2) {
          const parent = path2.getParentNode();
          if (!parent || parent.type !== "TaggedTemplateExpression") {
            return false;
          }
          const tag = parent.tag.type === "ParenthesizedExpression" ? parent.tag.expression : parent.tag;
          switch (tag.type) {
            case "MemberExpression":
              return isStyledIdentifier(tag.object) || isStyledExtend(tag);
            case "CallExpression":
              return isStyledIdentifier(tag.callee) || tag.callee.type === "MemberExpression" && (tag.callee.object.type === "MemberExpression" && (isStyledIdentifier(tag.callee.object.object) || isStyledExtend(tag.callee.object)) || tag.callee.object.type === "CallExpression" && isStyledIdentifier(tag.callee.object.callee));
            case "Identifier":
              return tag.name === "css";
            default:
              return false;
          }
        }
        function isCssProp(path2) {
          const parent = path2.getParentNode();
          const parentParent = path2.getParentNode(1);
          return parentParent && parent.type === "JSXExpressionContainer" && parentParent.type === "JSXAttribute" && parentParent.name.type === "JSXIdentifier" && parentParent.name.name === "css";
        }
        function isStyledIdentifier(node) {
          return node.type === "Identifier" && node.name === "styled";
        }
        function isStyledExtend(node) {
          return /^[A-Z]/.test(node.object.name) && node.property.name === "extend";
        }
        function isGraphQL(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          return hasLanguageComment(node, "GraphQL") || parent && (parent.type === "TaggedTemplateExpression" && (parent.tag.type === "MemberExpression" && parent.tag.object.name === "graphql" && parent.tag.property.name === "experimental" || parent.tag.type === "Identifier" && (parent.tag.name === "gql" || parent.tag.name === "graphql")) || parent.type === "CallExpression" && parent.callee.type === "Identifier" && parent.callee.name === "graphql");
        }
        function hasLanguageComment(node, languageName) {
          return hasComment(node, CommentCheckFlags.Block | CommentCheckFlags.Leading, ({
            value: value2
          }) => value2 === ` ${languageName} `);
        }
        function isHtml(path2) {
          return hasLanguageComment(path2.getValue(), "HTML") || path2.match((node) => node.type === "TemplateLiteral", (node, name) => node.type === "TaggedTemplateExpression" && node.tag.type === "Identifier" && node.tag.name === "html" && name === "quasi");
        }
        function hasInvalidCookedValue({
          quasis
        }) {
          return quasis.some(({
            value: {
              cooked
            }
          }) => cooked === null);
        }
        module22.exports = embed;
      }
    });
    var require_clean = __commonJS22({
      "src/language-js/clean.js"(exports2, module22) {
        "use strict";
        var isBlockComment = require_is_block_comment();
        var ignoredProperties = /* @__PURE__ */ new Set(["range", "raw", "comments", "leadingComments", "trailingComments", "innerComments", "extra", "start", "end", "loc", "flags", "errors", "tokens"]);
        var removeTemplateElementsValue = (node) => {
          for (const templateElement of node.quasis) {
            delete templateElement.value;
          }
        };
        function clean(ast, newObj, parent) {
          if (ast.type === "Program") {
            delete newObj.sourceType;
          }
          if (ast.type === "BigIntLiteral" || ast.type === "BigIntLiteralTypeAnnotation") {
            if (newObj.value) {
              newObj.value = newObj.value.toLowerCase();
            }
          }
          if (ast.type === "BigIntLiteral" || ast.type === "Literal") {
            if (newObj.bigint) {
              newObj.bigint = newObj.bigint.toLowerCase();
            }
          }
          if (ast.type === "DecimalLiteral") {
            newObj.value = Number(newObj.value);
          }
          if (ast.type === "Literal" && newObj.decimal) {
            newObj.decimal = Number(newObj.decimal);
          }
          if (ast.type === "EmptyStatement") {
            return null;
          }
          if (ast.type === "JSXText") {
            return null;
          }
          if (ast.type === "JSXExpressionContainer" && (ast.expression.type === "Literal" || ast.expression.type === "StringLiteral") && ast.expression.value === " ") {
            return null;
          }
          if ((ast.type === "Property" || ast.type === "ObjectProperty" || ast.type === "MethodDefinition" || ast.type === "ClassProperty" || ast.type === "ClassMethod" || ast.type === "PropertyDefinition" || ast.type === "TSDeclareMethod" || ast.type === "TSPropertySignature" || ast.type === "ObjectTypeProperty") && typeof ast.key === "object" && ast.key && (ast.key.type === "Literal" || ast.key.type === "NumericLiteral" || ast.key.type === "StringLiteral" || ast.key.type === "Identifier")) {
            delete newObj.key;
          }
          if (ast.type === "JSXElement" && ast.openingElement.name.name === "style" && ast.openingElement.attributes.some((attr) => attr.name.name === "jsx")) {
            for (const {
              type,
              expression: expression2
            } of newObj.children) {
              if (type === "JSXExpressionContainer" && expression2.type === "TemplateLiteral") {
                removeTemplateElementsValue(expression2);
              }
            }
          }
          if (ast.type === "JSXAttribute" && ast.name.name === "css" && ast.value.type === "JSXExpressionContainer" && ast.value.expression.type === "TemplateLiteral") {
            removeTemplateElementsValue(newObj.value.expression);
          }
          if (ast.type === "JSXAttribute" && ast.value && ast.value.type === "Literal" && /["']|&quot;|&apos;/.test(ast.value.value)) {
            newObj.value.value = newObj.value.value.replace(/["']|&quot;|&apos;/g, '"');
          }
          const expression = ast.expression || ast.callee;
          if (ast.type === "Decorator" && expression.type === "CallExpression" && expression.callee.name === "Component" && expression.arguments.length === 1) {
            const astProps = ast.expression.arguments[0].properties;
            for (const [index, prop] of newObj.expression.arguments[0].properties.entries()) {
              switch (astProps[index].key.name) {
                case "styles":
                  if (prop.value.type === "ArrayExpression") {
                    removeTemplateElementsValue(prop.value.elements[0]);
                  }
                  break;
                case "template":
                  if (prop.value.type === "TemplateLiteral") {
                    removeTemplateElementsValue(prop.value);
                  }
                  break;
              }
            }
          }
          if (ast.type === "TaggedTemplateExpression" && (ast.tag.type === "MemberExpression" || ast.tag.type === "Identifier" && (ast.tag.name === "gql" || ast.tag.name === "graphql" || ast.tag.name === "css" || ast.tag.name === "md" || ast.tag.name === "markdown" || ast.tag.name === "html") || ast.tag.type === "CallExpression")) {
            removeTemplateElementsValue(newObj.quasi);
          }
          if (ast.type === "TemplateLiteral") {
            var _ast$leadingComments;
            const hasLanguageComment = (_ast$leadingComments = ast.leadingComments) === null || _ast$leadingComments === void 0 ? void 0 : _ast$leadingComments.some((comment) => isBlockComment(comment) && ["GraphQL", "HTML"].some((languageName) => comment.value === ` ${languageName} `));
            if (hasLanguageComment || parent.type === "CallExpression" && parent.callee.name === "graphql" || !ast.leadingComments) {
              removeTemplateElementsValue(newObj);
            }
          }
          if (ast.type === "InterpreterDirective") {
            newObj.value = newObj.value.trimEnd();
          }
          if ((ast.type === "TSIntersectionType" || ast.type === "TSUnionType") && ast.types.length === 1) {
            return newObj.types[0];
          }
        }
        clean.ignoredProperties = ignoredProperties;
        module22.exports = clean;
      }
    });
    var require_detect_newline = __commonJS22({
      "node_modules/detect-newline/index.js"(exports2, module22) {
        "use strict";
        var detectNewline = (string) => {
          if (typeof string !== "string") {
            throw new TypeError("Expected a string");
          }
          const newlines = string.match(/(?:\r?\n)/g) || [];
          if (newlines.length === 0) {
            return;
          }
          const crlf = newlines.filter((newline) => newline === "\r\n").length;
          const lf = newlines.length - crlf;
          return crlf > lf ? "\r\n" : "\n";
        };
        module22.exports = detectNewline;
        module22.exports.graceful = (string) => typeof string === "string" && detectNewline(string) || "\n";
      }
    });
    var require_build = __commonJS22({
      "node_modules/jest-docblock/build/index.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.extract = extract;
        exports2.parse = parse3;
        exports2.parseWithComments = parseWithComments;
        exports2.print = print;
        exports2.strip = strip;
        function _os() {
          const data = require("os");
          _os = function() {
            return data;
          };
          return data;
        }
        function _detectNewline() {
          const data = _interopRequireDefault(require_detect_newline());
          _detectNewline = function() {
            return data;
          };
          return data;
        }
        function _interopRequireDefault(obj) {
          return obj && obj.__esModule ? obj : {
            default: obj
          };
        }
        var commentEndRe = /\*\/$/;
        var commentStartRe = /^\/\*\*?/;
        var docblockRe = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/;
        var lineCommentRe = /(^|\s+)\/\/([^\r\n]*)/g;
        var ltrimNewlineRe = /^(\r?\n)+/;
        var multilineRe = /(?:^|\r?\n) *(@[^\r\n]*?) *\r?\n *(?![^@\r\n]*\/\/[^]*)([^@\r\n\s][^@\r\n]+?) *\r?\n/g;
        var propertyRe = /(?:^|\r?\n) *@(\S+) *([^\r\n]*)/g;
        var stringStartRe = /(\r?\n|^) *\* ?/g;
        var STRING_ARRAY = [];
        function extract(contents) {
          const match = contents.match(docblockRe);
          return match ? match[0].trimLeft() : "";
        }
        function strip(contents) {
          const match = contents.match(docblockRe);
          return match && match[0] ? contents.substring(match[0].length) : contents;
        }
        function parse3(docblock) {
          return parseWithComments(docblock).pragmas;
        }
        function parseWithComments(docblock) {
          const line = (0, _detectNewline().default)(docblock) || _os().EOL;
          docblock = docblock.replace(commentStartRe, "").replace(commentEndRe, "").replace(stringStartRe, "$1");
          let prev = "";
          while (prev !== docblock) {
            prev = docblock;
            docblock = docblock.replace(multilineRe, `${line}$1 $2${line}`);
          }
          docblock = docblock.replace(ltrimNewlineRe, "").trimRight();
          const result = /* @__PURE__ */ Object.create(null);
          const comments = docblock.replace(propertyRe, "").replace(ltrimNewlineRe, "").trimRight();
          let match;
          while (match = propertyRe.exec(docblock)) {
            const nextPragma = match[2].replace(lineCommentRe, "");
            if (typeof result[match[1]] === "string" || Array.isArray(result[match[1]])) {
              result[match[1]] = STRING_ARRAY.concat(result[match[1]], nextPragma);
            } else {
              result[match[1]] = nextPragma;
            }
          }
          return {
            comments,
            pragmas: result
          };
        }
        function print({
          comments = "",
          pragmas = {}
        }) {
          const line = (0, _detectNewline().default)(comments) || _os().EOL;
          const head = "/**";
          const start = " *";
          const tail = " */";
          const keys3 = Object.keys(pragmas);
          const printedObject = keys3.map((key) => printKeyValues(key, pragmas[key])).reduce((arr, next) => arr.concat(next), []).map((keyValue) => `${start} ${keyValue}${line}`).join("");
          if (!comments) {
            if (keys3.length === 0) {
              return "";
            }
            if (keys3.length === 1 && !Array.isArray(pragmas[keys3[0]])) {
              const value2 = pragmas[keys3[0]];
              return `${head} ${printKeyValues(keys3[0], value2)[0]}${tail}`;
            }
          }
          const printedComments = comments.split(line).map((textLine) => `${start} ${textLine}`).join(line) + line;
          return head + line + (comments ? printedComments : "") + (comments && keys3.length ? start + line : "") + printedObject + tail;
        }
        function printKeyValues(key, valueOrArray) {
          return STRING_ARRAY.concat(valueOrArray).map((value2) => `@${key} ${value2}`.trim());
        }
      }
    });
    var require_get_shebang = __commonJS22({
      "src/language-js/utils/get-shebang.js"(exports2, module22) {
        "use strict";
        function getShebang(text) {
          if (!text.startsWith("#!")) {
            return "";
          }
          const index = text.indexOf("\n");
          if (index === -1) {
            return text;
          }
          return text.slice(0, index);
        }
        module22.exports = getShebang;
      }
    });
    var require_pragma = __commonJS22({
      "src/language-js/pragma.js"(exports2, module22) {
        "use strict";
        var {
          parseWithComments,
          strip,
          extract,
          print
        } = require_build();
        var {
          normalizeEndOfLine
        } = require_end_of_line();
        var getShebang = require_get_shebang();
        function parseDocBlock(text) {
          const shebang = getShebang(text);
          if (shebang) {
            text = text.slice(shebang.length + 1);
          }
          const docBlock = extract(text);
          const {
            pragmas,
            comments
          } = parseWithComments(docBlock);
          return {
            shebang,
            text,
            pragmas,
            comments
          };
        }
        function hasPragma(text) {
          const pragmas = Object.keys(parseDocBlock(text).pragmas);
          return pragmas.includes("prettier") || pragmas.includes("format");
        }
        function insertPragma(originalText) {
          const {
            shebang,
            text,
            pragmas,
            comments
          } = parseDocBlock(originalText);
          const strippedText = strip(text);
          const docBlock = print({
            pragmas: Object.assign({
              format: ""
            }, pragmas),
            comments: comments.trimStart()
          });
          return (shebang ? `${shebang}
` : "") + normalizeEndOfLine(docBlock) + (strippedText.startsWith("\n") ? "\n" : "\n\n") + strippedText;
        }
        module22.exports = {
          hasPragma,
          insertPragma
        };
      }
    });
    var require_comments22 = __commonJS22({
      "src/language-js/comments.js"(exports2, module22) {
        "use strict";
        var {
          getLast,
          hasNewline,
          getNextNonSpaceNonCommentCharacterIndexWithStartIndex,
          getNextNonSpaceNonCommentCharacter,
          hasNewlineInRange,
          addLeadingComment,
          addTrailingComment,
          addDanglingComment,
          getNextNonSpaceNonCommentCharacterIndex,
          isNonEmptyArray
        } = require_util6();
        var {
          getFunctionParameters,
          isPrettierIgnoreComment,
          isJsxNode,
          hasFlowShorthandAnnotationComment,
          hasFlowAnnotationComment,
          hasIgnoreComment,
          isCallLikeExpression,
          getCallArguments,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isObjectProperty,
          isLineComment,
          getComments,
          CommentCheckFlags,
          markerForIfWithoutBlockAndSameLineComment
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var isBlockComment = require_is_block_comment();
        function handleOwnLineComment(context) {
          return [handleIgnoreComments, handleLastFunctionArgComments, handleMemberExpressionComments, handleIfStatementComments, handleWhileComments, handleTryStatementComments, handleClassComments, handleForComments, handleUnionTypeComments, handleOnlyComments, handleModuleSpecifiersComments, handleAssignmentPatternComments, handleMethodNameComments, handleLabeledStatementComments, handleBreakAndContinueStatementComments].some((fn) => fn(context));
        }
        function handleEndOfLineComment(context) {
          return [handleClosureTypeCastComments, handleLastFunctionArgComments, handleConditionalExpressionComments, handleModuleSpecifiersComments, handleIfStatementComments, handleWhileComments, handleTryStatementComments, handleClassComments, handleLabeledStatementComments, handleCallExpressionComments, handlePropertyComments, handleOnlyComments, handleVariableDeclaratorComments, handleBreakAndContinueStatementComments, handleSwitchDefaultCaseComments].some((fn) => fn(context));
        }
        function handleRemainingComment(context) {
          return [handleIgnoreComments, handleIfStatementComments, handleWhileComments, handleObjectPropertyAssignment, handleCommentInEmptyParens, handleMethodNameComments, handleOnlyComments, handleCommentAfterArrowParams, handleFunctionNameComments, handleTSMappedTypeComments, handleBreakAndContinueStatementComments, handleTSFunctionTrailingComments].some((fn) => fn(context));
        }
        function addBlockStatementFirstComment(node, comment) {
          const firstNonEmptyNode = (node.body || node.properties).find(({
            type
          }) => type !== "EmptyStatement");
          if (firstNonEmptyNode) {
            addLeadingComment(firstNonEmptyNode, comment);
          } else {
            addDanglingComment(node, comment);
          }
        }
        function addBlockOrNotComment(node, comment) {
          if (node.type === "BlockStatement") {
            addBlockStatementFirstComment(node, comment);
          } else {
            addLeadingComment(node, comment);
          }
        }
        function handleClosureTypeCastComments({
          comment,
          followingNode
        }) {
          if (followingNode && isTypeCastComment(comment)) {
            addLeadingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleIfStatementComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode,
          text
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) !== "IfStatement" || !followingNode) {
            return false;
          }
          const nextCharacter = getNextNonSpaceNonCommentCharacter(text, comment, locEnd);
          if (nextCharacter === ")") {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if (precedingNode === enclosingNode.consequent && followingNode === enclosingNode.alternate) {
            if (precedingNode.type === "BlockStatement") {
              addTrailingComment(precedingNode, comment);
            } else {
              const isSingleLineComment = comment.type === "SingleLine" || comment.loc.start.line === comment.loc.end.line;
              const isSameLineComment = comment.loc.start.line === precedingNode.loc.start.line;
              if (isSingleLineComment && isSameLineComment) {
                addDanglingComment(precedingNode, comment, markerForIfWithoutBlockAndSameLineComment);
              } else {
                addDanglingComment(enclosingNode, comment);
              }
            }
            return true;
          }
          if (followingNode.type === "BlockStatement") {
            addBlockStatementFirstComment(followingNode, comment);
            return true;
          }
          if (followingNode.type === "IfStatement") {
            addBlockOrNotComment(followingNode.consequent, comment);
            return true;
          }
          if (enclosingNode.consequent === followingNode) {
            addLeadingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleWhileComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode,
          text
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) !== "WhileStatement" || !followingNode) {
            return false;
          }
          const nextCharacter = getNextNonSpaceNonCommentCharacter(text, comment, locEnd);
          if (nextCharacter === ")") {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if (followingNode.type === "BlockStatement") {
            addBlockStatementFirstComment(followingNode, comment);
            return true;
          }
          if (enclosingNode.body === followingNode) {
            addLeadingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleTryStatementComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) !== "TryStatement" && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) !== "CatchClause" || !followingNode) {
            return false;
          }
          if (enclosingNode.type === "CatchClause" && precedingNode) {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if (followingNode.type === "BlockStatement") {
            addBlockStatementFirstComment(followingNode, comment);
            return true;
          }
          if (followingNode.type === "TryStatement") {
            addBlockOrNotComment(followingNode.finalizer, comment);
            return true;
          }
          if (followingNode.type === "CatchClause") {
            addBlockOrNotComment(followingNode.body, comment);
            return true;
          }
          return false;
        }
        function handleMemberExpressionComments({
          comment,
          enclosingNode,
          followingNode
        }) {
          if (isMemberExpression(enclosingNode) && (followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "Identifier") {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleConditionalExpressionComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode,
          text
        }) {
          const isSameLineAsPrecedingNode = precedingNode && !hasNewlineInRange(text, locEnd(precedingNode), locStart(comment));
          if ((!precedingNode || !isSameLineAsPrecedingNode) && ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ConditionalExpression" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSConditionalType") && followingNode) {
            addLeadingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleObjectPropertyAssignment({
          comment,
          precedingNode,
          enclosingNode
        }) {
          if (isObjectProperty(enclosingNode) && enclosingNode.shorthand && enclosingNode.key === precedingNode && enclosingNode.value.type === "AssignmentPattern") {
            addTrailingComment(enclosingNode.value.left, comment);
            return true;
          }
          return false;
        }
        var classLikeNodeTypes = /* @__PURE__ */ new Set(["ClassDeclaration", "ClassExpression", "DeclareClass", "DeclareInterface", "InterfaceDeclaration", "TSInterfaceDeclaration"]);
        function handleClassComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode
        }) {
          if (classLikeNodeTypes.has(enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type)) {
            if (isNonEmptyArray(enclosingNode.decorators) && !(followingNode && followingNode.type === "Decorator")) {
              addTrailingComment(getLast(enclosingNode.decorators), comment);
              return true;
            }
            if (enclosingNode.body && followingNode === enclosingNode.body) {
              addBlockStatementFirstComment(enclosingNode.body, comment);
              return true;
            }
            if (followingNode) {
              if (enclosingNode.superClass && followingNode === enclosingNode.superClass && precedingNode && (precedingNode === enclosingNode.id || precedingNode === enclosingNode.typeParameters)) {
                addTrailingComment(precedingNode, comment);
                return true;
              }
              for (const prop of ["implements", "extends", "mixins"]) {
                if (enclosingNode[prop] && followingNode === enclosingNode[prop][0]) {
                  if (precedingNode && (precedingNode === enclosingNode.id || precedingNode === enclosingNode.typeParameters || precedingNode === enclosingNode.superClass)) {
                    addTrailingComment(precedingNode, comment);
                  } else {
                    addDanglingComment(enclosingNode, comment, prop);
                  }
                  return true;
                }
              }
            }
          }
          return false;
        }
        var propertyLikeNodeTypes = /* @__PURE__ */ new Set(["ClassMethod", "ClassProperty", "PropertyDefinition", "TSAbstractPropertyDefinition", "TSAbstractMethodDefinition", "TSDeclareMethod", "MethodDefinition", "ClassAccessorProperty", "AccessorProperty", "TSAbstractAccessorProperty"]);
        function handleMethodNameComments({
          comment,
          precedingNode,
          enclosingNode,
          text
        }) {
          if (enclosingNode && precedingNode && getNextNonSpaceNonCommentCharacter(text, comment, locEnd) === "(" && (enclosingNode.type === "Property" || enclosingNode.type === "TSDeclareMethod" || enclosingNode.type === "TSAbstractMethodDefinition") && precedingNode.type === "Identifier" && enclosingNode.key === precedingNode && getNextNonSpaceNonCommentCharacter(text, precedingNode, locEnd) !== ":") {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if ((precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "Decorator" && propertyLikeNodeTypes.has(enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type)) {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          return false;
        }
        var functionLikeNodeTypes = /* @__PURE__ */ new Set(["FunctionDeclaration", "FunctionExpression", "ClassMethod", "MethodDefinition", "ObjectMethod"]);
        function handleFunctionNameComments({
          comment,
          precedingNode,
          enclosingNode,
          text
        }) {
          if (getNextNonSpaceNonCommentCharacter(text, comment, locEnd) !== "(") {
            return false;
          }
          if (precedingNode && functionLikeNodeTypes.has(enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type)) {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          return false;
        }
        function handleCommentAfterArrowParams({
          comment,
          enclosingNode,
          text
        }) {
          if (!((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ArrowFunctionExpression")) {
            return false;
          }
          const index = getNextNonSpaceNonCommentCharacterIndex(text, comment, locEnd);
          if (index !== false && text.slice(index, index + 2) === "=>") {
            addDanglingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleCommentInEmptyParens({
          comment,
          enclosingNode,
          text
        }) {
          if (getNextNonSpaceNonCommentCharacter(text, comment, locEnd) !== ")") {
            return false;
          }
          if (enclosingNode && (isRealFunctionLikeNode(enclosingNode) && getFunctionParameters(enclosingNode).length === 0 || isCallLikeExpression(enclosingNode) && getCallArguments(enclosingNode).length === 0)) {
            addDanglingComment(enclosingNode, comment);
            return true;
          }
          if (((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "MethodDefinition" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSAbstractMethodDefinition") && getFunctionParameters(enclosingNode.value).length === 0) {
            addDanglingComment(enclosingNode.value, comment);
            return true;
          }
          return false;
        }
        function handleLastFunctionArgComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode,
          text
        }) {
          if ((precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "FunctionTypeParam" && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "FunctionTypeAnnotation" && (followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) !== "FunctionTypeParam") {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if (((precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "Identifier" || (precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "AssignmentPattern") && enclosingNode && isRealFunctionLikeNode(enclosingNode) && getNextNonSpaceNonCommentCharacter(text, comment, locEnd) === ")") {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "FunctionDeclaration" && (followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "BlockStatement") {
            const functionParamRightParenIndex = (() => {
              const parameters = getFunctionParameters(enclosingNode);
              if (parameters.length > 0) {
                return getNextNonSpaceNonCommentCharacterIndexWithStartIndex(text, locEnd(getLast(parameters)));
              }
              const functionParamLeftParenIndex = getNextNonSpaceNonCommentCharacterIndexWithStartIndex(text, locEnd(enclosingNode.id));
              return functionParamLeftParenIndex !== false && getNextNonSpaceNonCommentCharacterIndexWithStartIndex(text, functionParamLeftParenIndex + 1);
            })();
            if (locStart(comment) > functionParamRightParenIndex) {
              addBlockStatementFirstComment(followingNode, comment);
              return true;
            }
          }
          return false;
        }
        function handleLabeledStatementComments({
          comment,
          enclosingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "LabeledStatement") {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleBreakAndContinueStatementComments({
          comment,
          enclosingNode
        }) {
          if (((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ContinueStatement" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "BreakStatement") && !enclosingNode.label) {
            addTrailingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleCallExpressionComments({
          comment,
          precedingNode,
          enclosingNode
        }) {
          if (isCallExpression2(enclosingNode) && precedingNode && enclosingNode.callee === precedingNode && enclosingNode.arguments.length > 0) {
            addLeadingComment(enclosingNode.arguments[0], comment);
            return true;
          }
          return false;
        }
        function handleUnionTypeComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "UnionTypeAnnotation" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSUnionType") {
            if (isPrettierIgnoreComment(comment)) {
              followingNode.prettierIgnore = true;
              comment.unignore = true;
            }
            if (precedingNode) {
              addTrailingComment(precedingNode, comment);
              return true;
            }
            return false;
          }
          if (((followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "UnionTypeAnnotation" || (followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "TSUnionType") && isPrettierIgnoreComment(comment)) {
            followingNode.types[0].prettierIgnore = true;
            comment.unignore = true;
          }
          return false;
        }
        function handlePropertyComments({
          comment,
          enclosingNode
        }) {
          if (isObjectProperty(enclosingNode)) {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleOnlyComments({
          comment,
          enclosingNode,
          followingNode,
          ast,
          isLastComment
        }) {
          if (ast && ast.body && ast.body.length === 0) {
            if (isLastComment) {
              addDanglingComment(ast, comment);
            } else {
              addLeadingComment(ast, comment);
            }
            return true;
          }
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "Program" && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.body.length) === 0 && !isNonEmptyArray(enclosingNode.directives)) {
            if (isLastComment) {
              addDanglingComment(enclosingNode, comment);
            } else {
              addLeadingComment(enclosingNode, comment);
            }
            return true;
          }
          if ((followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "Program" && (followingNode === null || followingNode === void 0 ? void 0 : followingNode.body.length) === 0 && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ModuleExpression") {
            addDanglingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleForComments({
          comment,
          enclosingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ForInStatement" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ForOfStatement") {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleModuleSpecifiersComments({
          comment,
          precedingNode,
          enclosingNode,
          text
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ImportSpecifier" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ExportSpecifier") {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          const isImportDeclaration = (precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "ImportSpecifier" && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ImportDeclaration";
          const isExportDeclaration = (precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "ExportSpecifier" && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "ExportNamedDeclaration";
          if ((isImportDeclaration || isExportDeclaration) && hasNewline(text, locEnd(comment))) {
            addTrailingComment(precedingNode, comment);
            return true;
          }
          return false;
        }
        function handleAssignmentPatternComments({
          comment,
          enclosingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "AssignmentPattern") {
            addLeadingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        var assignmentLikeNodeTypes = /* @__PURE__ */ new Set(["VariableDeclarator", "AssignmentExpression", "TypeAlias", "TSTypeAliasDeclaration"]);
        var complexExprNodeTypes = /* @__PURE__ */ new Set(["ObjectExpression", "ArrayExpression", "TemplateLiteral", "TaggedTemplateExpression", "ObjectTypeAnnotation", "TSTypeLiteral"]);
        function handleVariableDeclaratorComments({
          comment,
          enclosingNode,
          followingNode
        }) {
          if (assignmentLikeNodeTypes.has(enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) && followingNode && (complexExprNodeTypes.has(followingNode.type) || isBlockComment(comment))) {
            addLeadingComment(followingNode, comment);
            return true;
          }
          return false;
        }
        function handleTSFunctionTrailingComments({
          comment,
          enclosingNode,
          followingNode,
          text
        }) {
          if (!followingNode && ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSMethodSignature" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSDeclareFunction" || (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSAbstractMethodDefinition") && getNextNonSpaceNonCommentCharacter(text, comment, locEnd) === ";") {
            addTrailingComment(enclosingNode, comment);
            return true;
          }
          return false;
        }
        function handleIgnoreComments({
          comment,
          enclosingNode,
          followingNode
        }) {
          if (isPrettierIgnoreComment(comment) && (enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) === "TSMappedType" && (followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "TSTypeParameter" && followingNode.constraint) {
            enclosingNode.prettierIgnore = true;
            comment.unignore = true;
            return true;
          }
        }
        function handleTSMappedTypeComments({
          comment,
          precedingNode,
          enclosingNode,
          followingNode
        }) {
          if ((enclosingNode === null || enclosingNode === void 0 ? void 0 : enclosingNode.type) !== "TSMappedType") {
            return false;
          }
          if ((followingNode === null || followingNode === void 0 ? void 0 : followingNode.type) === "TSTypeParameter" && followingNode.name) {
            addLeadingComment(followingNode.name, comment);
            return true;
          }
          if ((precedingNode === null || precedingNode === void 0 ? void 0 : precedingNode.type) === "TSTypeParameter" && precedingNode.constraint) {
            addTrailingComment(precedingNode.constraint, comment);
            return true;
          }
          return false;
        }
        function handleSwitchDefaultCaseComments({
          comment,
          enclosingNode,
          followingNode
        }) {
          if (!enclosingNode || enclosingNode.type !== "SwitchCase" || enclosingNode.test || !followingNode || followingNode !== enclosingNode.consequent[0]) {
            return false;
          }
          if (followingNode.type === "BlockStatement" && isLineComment(comment)) {
            addBlockStatementFirstComment(followingNode, comment);
          } else {
            addDanglingComment(enclosingNode, comment);
          }
          return true;
        }
        function isRealFunctionLikeNode(node) {
          return node.type === "ArrowFunctionExpression" || node.type === "FunctionExpression" || node.type === "FunctionDeclaration" || node.type === "ObjectMethod" || node.type === "ClassMethod" || node.type === "TSDeclareFunction" || node.type === "TSCallSignatureDeclaration" || node.type === "TSConstructSignatureDeclaration" || node.type === "TSMethodSignature" || node.type === "TSConstructorType" || node.type === "TSFunctionType" || node.type === "TSDeclareMethod";
        }
        function getCommentChildNodes(node, options) {
          if ((options.parser === "typescript" || options.parser === "flow" || options.parser === "acorn" || options.parser === "espree" || options.parser === "meriyah" || options.parser === "__babel_estree") && node.type === "MethodDefinition" && node.value && node.value.type === "FunctionExpression" && getFunctionParameters(node.value).length === 0 && !node.value.returnType && !isNonEmptyArray(node.value.typeParameters) && node.value.body) {
            return [...node.decorators || [], node.key, node.value.body];
          }
        }
        function isTypeCastComment(comment) {
          return isBlockComment(comment) && comment.value[0] === "*" && /@type\b/.test(comment.value);
        }
        function willPrintOwnComments(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          const hasFlowAnnotations = (node2) => hasFlowAnnotationComment(getComments(node2, CommentCheckFlags.Leading)) || hasFlowAnnotationComment(getComments(node2, CommentCheckFlags.Trailing));
          return (node && (isJsxNode(node) || hasFlowShorthandAnnotationComment(node) || isCallExpression2(parent) && hasFlowAnnotations(node)) || parent && (parent.type === "JSXSpreadAttribute" || parent.type === "JSXSpreadChild" || parent.type === "UnionTypeAnnotation" || parent.type === "TSUnionType" || (parent.type === "ClassDeclaration" || parent.type === "ClassExpression") && parent.superClass === node)) && (!hasIgnoreComment(path2) || parent.type === "UnionTypeAnnotation" || parent.type === "TSUnionType");
        }
        module22.exports = {
          handleOwnLineComment,
          handleEndOfLineComment,
          handleRemainingComment,
          isTypeCastComment,
          getCommentChildNodes,
          willPrintOwnComments
        };
      }
    });
    var require_needs_parens = __commonJS22({
      "src/language-js/needs-parens.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        var isNonEmptyArray = require_is_non_empty_array();
        var {
          getFunctionParameters,
          getLeftSidePathName,
          hasFlowShorthandAnnotationComment,
          hasNakedLeftSide,
          hasNode,
          isBitwiseOperator,
          startsWithNoLookaheadToken,
          shouldFlatten,
          getPrecedence,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isObjectProperty,
          isTSTypeExpression
        } = require_utils72();
        function needsParens(path2, options) {
          const parent = path2.getParentNode();
          if (!parent) {
            return false;
          }
          const name = path2.getName();
          const node = path2.getNode();
          if (options.__isInHtmlInterpolation && !options.bracketSpacing && endsWithRightBracket(node) && isFollowedByRightBracket(path2)) {
            return true;
          }
          if (isStatement(node)) {
            return false;
          }
          if (options.parser !== "flow" && hasFlowShorthandAnnotationComment(path2.getValue())) {
            return true;
          }
          if (node.type === "Identifier") {
            if (node.extra && node.extra.parenthesized && /^PRETTIER_HTML_PLACEHOLDER_\d+_\d+_IN_JS$/.test(node.name)) {
              return true;
            }
            if (name === "left" && (node.name === "async" && !parent.await || node.name === "let") && parent.type === "ForOfStatement") {
              return true;
            }
            if (node.name === "let") {
              var _path$findAncestor;
              const expression = (_path$findAncestor = path2.findAncestor((node2) => node2.type === "ForOfStatement")) === null || _path$findAncestor === void 0 ? void 0 : _path$findAncestor.left;
              if (expression && startsWithNoLookaheadToken(expression, (leftmostNode) => leftmostNode === node)) {
                return true;
              }
            }
            if (name === "object" && node.name === "let" && parent.type === "MemberExpression" && parent.computed && !parent.optional) {
              const statement = path2.findAncestor((node2) => node2.type === "ExpressionStatement" || node2.type === "ForStatement" || node2.type === "ForInStatement");
              const expression = !statement ? void 0 : statement.type === "ExpressionStatement" ? statement.expression : statement.type === "ForStatement" ? statement.init : statement.left;
              if (expression && startsWithNoLookaheadToken(expression, (leftmostNode) => leftmostNode === node)) {
                return true;
              }
            }
            return false;
          }
          if (node.type === "ObjectExpression" || node.type === "FunctionExpression" || node.type === "ClassExpression" || node.type === "DoExpression") {
            var _path$findAncestor2;
            const expression = (_path$findAncestor2 = path2.findAncestor((node2) => node2.type === "ExpressionStatement")) === null || _path$findAncestor2 === void 0 ? void 0 : _path$findAncestor2.expression;
            if (expression && startsWithNoLookaheadToken(expression, (leftmostNode) => leftmostNode === node)) {
              return true;
            }
          }
          switch (parent.type) {
            case "ParenthesizedExpression":
              return false;
            case "ClassDeclaration":
            case "ClassExpression": {
              if (name === "superClass" && (node.type === "ArrowFunctionExpression" || node.type === "AssignmentExpression" || node.type === "AwaitExpression" || node.type === "BinaryExpression" || node.type === "ConditionalExpression" || node.type === "LogicalExpression" || node.type === "NewExpression" || node.type === "ObjectExpression" || node.type === "SequenceExpression" || node.type === "TaggedTemplateExpression" || node.type === "UnaryExpression" || node.type === "UpdateExpression" || node.type === "YieldExpression" || node.type === "TSNonNullExpression")) {
                return true;
              }
              break;
            }
            case "ExportDefaultDeclaration": {
              return shouldWrapFunctionForExportDefault(path2, options) || node.type === "SequenceExpression";
            }
            case "Decorator": {
              if (name === "expression") {
                let hasCallExpression = false;
                let hasMemberExpression = false;
                let current = node;
                while (current) {
                  switch (current.type) {
                    case "MemberExpression":
                      hasMemberExpression = true;
                      current = current.object;
                      break;
                    case "CallExpression":
                      if (hasMemberExpression || hasCallExpression) {
                        return options.parser !== "typescript";
                      }
                      hasCallExpression = true;
                      current = current.callee;
                      break;
                    case "Identifier":
                      return false;
                    case "TaggedTemplateExpression":
                      return options.parser !== "typescript";
                    default:
                      return true;
                  }
                }
                return true;
              }
              break;
            }
            case "ArrowFunctionExpression": {
              if (name === "body" && node.type !== "SequenceExpression" && startsWithNoLookaheadToken(node, (node2) => node2.type === "ObjectExpression")) {
                return true;
              }
              break;
            }
          }
          switch (node.type) {
            case "UpdateExpression":
              if (parent.type === "UnaryExpression") {
                return node.prefix && (node.operator === "++" && parent.operator === "+" || node.operator === "--" && parent.operator === "-");
              }
            case "UnaryExpression":
              switch (parent.type) {
                case "UnaryExpression":
                  return node.operator === parent.operator && (node.operator === "+" || node.operator === "-");
                case "BindExpression":
                  return true;
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return name === "object";
                case "TaggedTemplateExpression":
                  return true;
                case "NewExpression":
                case "CallExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "BinaryExpression":
                  return name === "left" && parent.operator === "**";
                case "TSNonNullExpression":
                  return true;
                default:
                  return false;
              }
            case "BinaryExpression": {
              if (parent.type === "UpdateExpression") {
                return true;
              }
              if (node.operator === "in" && isPathInForStatementInitializer(path2)) {
                return true;
              }
              if (node.operator === "|>" && node.extra && node.extra.parenthesized) {
                const grandParent = path2.getParentNode(1);
                if (grandParent.type === "BinaryExpression" && grandParent.operator === "|>") {
                  return true;
                }
              }
            }
            case "TSTypeAssertion":
            case "TSAsExpression":
            case "TSSatisfiesExpression":
            case "LogicalExpression":
              switch (parent.type) {
                case "TSSatisfiesExpression":
                case "TSAsExpression":
                  return !isTSTypeExpression(node);
                case "ConditionalExpression":
                  return isTSTypeExpression(node);
                case "CallExpression":
                case "NewExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "ClassExpression":
                case "ClassDeclaration":
                  return name === "superClass";
                case "TSTypeAssertion":
                case "TaggedTemplateExpression":
                case "UnaryExpression":
                case "JSXSpreadAttribute":
                case "SpreadElement":
                case "SpreadProperty":
                case "BindExpression":
                case "AwaitExpression":
                case "TSNonNullExpression":
                case "UpdateExpression":
                  return true;
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return name === "object";
                case "AssignmentExpression":
                case "AssignmentPattern":
                  return name === "left" && (node.type === "TSTypeAssertion" || isTSTypeExpression(node));
                case "LogicalExpression":
                  if (node.type === "LogicalExpression") {
                    return parent.operator !== node.operator;
                  }
                case "BinaryExpression": {
                  const {
                    operator,
                    type
                  } = node;
                  if (!operator && type !== "TSTypeAssertion") {
                    return true;
                  }
                  const precedence = getPrecedence(operator);
                  const parentOperator = parent.operator;
                  const parentPrecedence = getPrecedence(parentOperator);
                  if (parentPrecedence > precedence) {
                    return true;
                  }
                  if (name === "right" && parentPrecedence === precedence) {
                    return true;
                  }
                  if (parentPrecedence === precedence && !shouldFlatten(parentOperator, operator)) {
                    return true;
                  }
                  if (parentPrecedence < precedence && operator === "%") {
                    return parentOperator === "+" || parentOperator === "-";
                  }
                  if (isBitwiseOperator(parentOperator)) {
                    return true;
                  }
                  return false;
                }
                default:
                  return false;
              }
            case "SequenceExpression":
              switch (parent.type) {
                case "ReturnStatement":
                  return false;
                case "ForStatement":
                  return false;
                case "ExpressionStatement":
                  return name !== "expression";
                case "ArrowFunctionExpression":
                  return name !== "body";
                default:
                  return true;
              }
            case "YieldExpression":
              if (parent.type === "UnaryExpression" || parent.type === "AwaitExpression" || isTSTypeExpression(parent) || parent.type === "TSNonNullExpression") {
                return true;
              }
            case "AwaitExpression":
              switch (parent.type) {
                case "TaggedTemplateExpression":
                case "UnaryExpression":
                case "LogicalExpression":
                case "SpreadElement":
                case "SpreadProperty":
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSNonNullExpression":
                case "BindExpression":
                  return true;
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return name === "object";
                case "NewExpression":
                case "CallExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "ConditionalExpression":
                  return name === "test";
                case "BinaryExpression": {
                  if (!node.argument && parent.operator === "|>") {
                    return false;
                  }
                  return true;
                }
                default:
                  return false;
              }
            case "TSConditionalType":
              if (name === "extendsType" && parent.type === "TSConditionalType") {
                return true;
              }
            case "TSFunctionType":
            case "TSConstructorType":
              if (name === "extendsType" && parent.type === "TSConditionalType") {
                const returnTypeAnnotation = (node.returnType || node.typeAnnotation).typeAnnotation;
                if (returnTypeAnnotation.type === "TSInferType" && returnTypeAnnotation.typeParameter.constraint) {
                  return true;
                }
              }
              if (name === "checkType" && parent.type === "TSConditionalType") {
                return true;
              }
            case "TSUnionType":
            case "TSIntersectionType":
              if ((parent.type === "TSUnionType" || parent.type === "TSIntersectionType") && parent.types.length > 1 && (!node.types || node.types.length > 1)) {
                return true;
              }
            case "TSInferType":
              if (node.type === "TSInferType" && parent.type === "TSRestType") {
                return false;
              }
            case "TSTypeOperator":
              return parent.type === "TSArrayType" || parent.type === "TSOptionalType" || parent.type === "TSRestType" || name === "objectType" && parent.type === "TSIndexedAccessType" || parent.type === "TSTypeOperator" || parent.type === "TSTypeAnnotation" && path2.getParentNode(1).type.startsWith("TSJSDoc");
            case "TSTypeQuery":
              return name === "objectType" && parent.type === "TSIndexedAccessType" || name === "elementType" && parent.type === "TSArrayType";
            case "ArrayTypeAnnotation":
              return parent.type === "NullableTypeAnnotation";
            case "IntersectionTypeAnnotation":
            case "UnionTypeAnnotation":
              return parent.type === "ArrayTypeAnnotation" || parent.type === "NullableTypeAnnotation" || parent.type === "IntersectionTypeAnnotation" || parent.type === "UnionTypeAnnotation" || name === "objectType" && (parent.type === "IndexedAccessType" || parent.type === "OptionalIndexedAccessType");
            case "NullableTypeAnnotation":
              return parent.type === "ArrayTypeAnnotation" || name === "objectType" && (parent.type === "IndexedAccessType" || parent.type === "OptionalIndexedAccessType");
            case "FunctionTypeAnnotation": {
              const ancestor = parent.type === "NullableTypeAnnotation" ? path2.getParentNode(1) : parent;
              return ancestor.type === "UnionTypeAnnotation" || ancestor.type === "IntersectionTypeAnnotation" || ancestor.type === "ArrayTypeAnnotation" || name === "objectType" && (ancestor.type === "IndexedAccessType" || ancestor.type === "OptionalIndexedAccessType") || ancestor.type === "NullableTypeAnnotation" || parent.type === "FunctionTypeParam" && parent.name === null && getFunctionParameters(node).some((param) => param.typeAnnotation && param.typeAnnotation.type === "NullableTypeAnnotation");
            }
            case "OptionalIndexedAccessType":
              return name === "objectType" && parent.type === "IndexedAccessType";
            case "TypeofTypeAnnotation":
              return name === "objectType" && (parent.type === "IndexedAccessType" || parent.type === "OptionalIndexedAccessType");
            case "StringLiteral":
            case "NumericLiteral":
            case "Literal":
              if (typeof node.value === "string" && parent.type === "ExpressionStatement" && !parent.directive) {
                const grandParent = path2.getParentNode(1);
                return grandParent.type === "Program" || grandParent.type === "BlockStatement";
              }
              return name === "object" && parent.type === "MemberExpression" && typeof node.value === "number";
            case "AssignmentExpression": {
              const grandParent = path2.getParentNode(1);
              if (name === "body" && parent.type === "ArrowFunctionExpression") {
                return true;
              }
              if (name === "key" && (parent.type === "ClassProperty" || parent.type === "PropertyDefinition") && parent.computed) {
                return false;
              }
              if ((name === "init" || name === "update") && parent.type === "ForStatement") {
                return false;
              }
              if (parent.type === "ExpressionStatement") {
                return node.left.type === "ObjectPattern";
              }
              if (name === "key" && parent.type === "TSPropertySignature") {
                return false;
              }
              if (parent.type === "AssignmentExpression") {
                return false;
              }
              if (parent.type === "SequenceExpression" && grandParent && grandParent.type === "ForStatement" && (grandParent.init === parent || grandParent.update === parent)) {
                return false;
              }
              if (name === "value" && parent.type === "Property" && grandParent && grandParent.type === "ObjectPattern" && grandParent.properties.includes(parent)) {
                return false;
              }
              if (parent.type === "NGChainedExpression") {
                return false;
              }
              return true;
            }
            case "ConditionalExpression":
              switch (parent.type) {
                case "TaggedTemplateExpression":
                case "UnaryExpression":
                case "SpreadElement":
                case "SpreadProperty":
                case "BinaryExpression":
                case "LogicalExpression":
                case "NGPipeExpression":
                case "ExportDefaultDeclaration":
                case "AwaitExpression":
                case "JSXSpreadAttribute":
                case "TSTypeAssertion":
                case "TypeCastExpression":
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSNonNullExpression":
                  return true;
                case "NewExpression":
                case "CallExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "ConditionalExpression":
                  return name === "test";
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return name === "object";
                default:
                  return false;
              }
            case "FunctionExpression":
              switch (parent.type) {
                case "NewExpression":
                case "CallExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "TaggedTemplateExpression":
                  return true;
                default:
                  return false;
              }
            case "ArrowFunctionExpression":
              switch (parent.type) {
                case "BinaryExpression":
                  return parent.operator !== "|>" || node.extra && node.extra.parenthesized;
                case "NewExpression":
                case "CallExpression":
                case "OptionalCallExpression":
                  return name === "callee";
                case "MemberExpression":
                case "OptionalMemberExpression":
                  return name === "object";
                case "TSAsExpression":
                case "TSSatisfiesExpression":
                case "TSNonNullExpression":
                case "BindExpression":
                case "TaggedTemplateExpression":
                case "UnaryExpression":
                case "LogicalExpression":
                case "AwaitExpression":
                case "TSTypeAssertion":
                  return true;
                case "ConditionalExpression":
                  return name === "test";
                default:
                  return false;
              }
            case "ClassExpression":
              if (isNonEmptyArray(node.decorators)) {
                return true;
              }
              switch (parent.type) {
                case "NewExpression":
                  return name === "callee";
                default:
                  return false;
              }
            case "OptionalMemberExpression":
            case "OptionalCallExpression": {
              const parentParent = path2.getParentNode(1);
              if (name === "object" && parent.type === "MemberExpression" || name === "callee" && (parent.type === "CallExpression" || parent.type === "NewExpression") || parent.type === "TSNonNullExpression" && parentParent.type === "MemberExpression" && parentParent.object === parent) {
                return true;
              }
            }
            case "CallExpression":
            case "MemberExpression":
            case "TaggedTemplateExpression":
            case "TSNonNullExpression":
              if (name === "callee" && (parent.type === "BindExpression" || parent.type === "NewExpression")) {
                let object = node;
                while (object) {
                  switch (object.type) {
                    case "CallExpression":
                    case "OptionalCallExpression":
                      return true;
                    case "MemberExpression":
                    case "OptionalMemberExpression":
                    case "BindExpression":
                      object = object.object;
                      break;
                    case "TaggedTemplateExpression":
                      object = object.tag;
                      break;
                    case "TSNonNullExpression":
                      object = object.expression;
                      break;
                    default:
                      return false;
                  }
                }
              }
              return false;
            case "BindExpression":
              return name === "callee" && (parent.type === "BindExpression" || parent.type === "NewExpression") || name === "object" && isMemberExpression(parent);
            case "NGPipeExpression":
              if (parent.type === "NGRoot" || parent.type === "NGMicrosyntaxExpression" || parent.type === "ObjectProperty" && !(node.extra && node.extra.parenthesized) || parent.type === "ArrayExpression" || isCallExpression2(parent) && parent.arguments[name] === node || name === "right" && parent.type === "NGPipeExpression" || name === "property" && parent.type === "MemberExpression" || parent.type === "AssignmentExpression") {
                return false;
              }
              return true;
            case "JSXFragment":
            case "JSXElement":
              return name === "callee" || name === "left" && parent.type === "BinaryExpression" && parent.operator === "<" || parent.type !== "ArrayExpression" && parent.type !== "ArrowFunctionExpression" && parent.type !== "AssignmentExpression" && parent.type !== "AssignmentPattern" && parent.type !== "BinaryExpression" && parent.type !== "NewExpression" && parent.type !== "ConditionalExpression" && parent.type !== "ExpressionStatement" && parent.type !== "JsExpressionRoot" && parent.type !== "JSXAttribute" && parent.type !== "JSXElement" && parent.type !== "JSXExpressionContainer" && parent.type !== "JSXFragment" && parent.type !== "LogicalExpression" && !isCallExpression2(parent) && !isObjectProperty(parent) && parent.type !== "ReturnStatement" && parent.type !== "ThrowStatement" && parent.type !== "TypeCastExpression" && parent.type !== "VariableDeclarator" && parent.type !== "YieldExpression";
            case "TypeAnnotation":
              return name === "returnType" && parent.type === "ArrowFunctionExpression" && includesFunctionTypeInObjectType(node);
          }
          return false;
        }
        function isStatement(node) {
          return node.type === "BlockStatement" || node.type === "BreakStatement" || node.type === "ClassBody" || node.type === "ClassDeclaration" || node.type === "ClassMethod" || node.type === "ClassProperty" || node.type === "PropertyDefinition" || node.type === "ClassPrivateProperty" || node.type === "ContinueStatement" || node.type === "DebuggerStatement" || node.type === "DeclareClass" || node.type === "DeclareExportAllDeclaration" || node.type === "DeclareExportDeclaration" || node.type === "DeclareFunction" || node.type === "DeclareInterface" || node.type === "DeclareModule" || node.type === "DeclareModuleExports" || node.type === "DeclareVariable" || node.type === "DoWhileStatement" || node.type === "EnumDeclaration" || node.type === "ExportAllDeclaration" || node.type === "ExportDefaultDeclaration" || node.type === "ExportNamedDeclaration" || node.type === "ExpressionStatement" || node.type === "ForInStatement" || node.type === "ForOfStatement" || node.type === "ForStatement" || node.type === "FunctionDeclaration" || node.type === "IfStatement" || node.type === "ImportDeclaration" || node.type === "InterfaceDeclaration" || node.type === "LabeledStatement" || node.type === "MethodDefinition" || node.type === "ReturnStatement" || node.type === "SwitchStatement" || node.type === "ThrowStatement" || node.type === "TryStatement" || node.type === "TSDeclareFunction" || node.type === "TSEnumDeclaration" || node.type === "TSImportEqualsDeclaration" || node.type === "TSInterfaceDeclaration" || node.type === "TSModuleDeclaration" || node.type === "TSNamespaceExportDeclaration" || node.type === "TypeAlias" || node.type === "VariableDeclaration" || node.type === "WhileStatement" || node.type === "WithStatement";
        }
        function isPathInForStatementInitializer(path2) {
          let i = 0;
          let node = path2.getValue();
          while (node) {
            const parent = path2.getParentNode(i++);
            if (parent && parent.type === "ForStatement" && parent.init === node) {
              return true;
            }
            node = parent;
          }
          return false;
        }
        function includesFunctionTypeInObjectType(node) {
          return hasNode(node, (n1) => n1.type === "ObjectTypeAnnotation" && hasNode(n1, (n2) => n2.type === "FunctionTypeAnnotation" || void 0) || void 0);
        }
        function endsWithRightBracket(node) {
          switch (node.type) {
            case "ObjectExpression":
              return true;
            default:
              return false;
          }
        }
        function isFollowedByRightBracket(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          const name = path2.getName();
          switch (parent.type) {
            case "NGPipeExpression":
              if (typeof name === "number" && parent.arguments[name] === node && parent.arguments.length - 1 === name) {
                return path2.callParent(isFollowedByRightBracket);
              }
              break;
            case "ObjectProperty":
              if (name === "value") {
                const parentParent = path2.getParentNode(1);
                return getLast(parentParent.properties) === parent;
              }
              break;
            case "BinaryExpression":
            case "LogicalExpression":
              if (name === "right") {
                return path2.callParent(isFollowedByRightBracket);
              }
              break;
            case "ConditionalExpression":
              if (name === "alternate") {
                return path2.callParent(isFollowedByRightBracket);
              }
              break;
            case "UnaryExpression":
              if (parent.prefix) {
                return path2.callParent(isFollowedByRightBracket);
              }
              break;
          }
          return false;
        }
        function shouldWrapFunctionForExportDefault(path2, options) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          if (node.type === "FunctionExpression" || node.type === "ClassExpression") {
            return parent.type === "ExportDefaultDeclaration" || !needsParens(path2, options);
          }
          if (!hasNakedLeftSide(node) || parent.type !== "ExportDefaultDeclaration" && needsParens(path2, options)) {
            return false;
          }
          return path2.call((childPath) => shouldWrapFunctionForExportDefault(childPath, options), ...getLeftSidePathName(path2, node));
        }
        module22.exports = needsParens;
      }
    });
    var require_print_preprocess = __commonJS22({
      "src/language-js/print-preprocess.js"(exports2, module22) {
        "use strict";
        function preprocess(ast, options) {
          switch (options.parser) {
            case "json":
            case "json5":
            case "json-stringify":
            case "__js_expression":
            case "__vue_expression":
            case "__vue_ts_expression":
              return Object.assign(Object.assign({}, ast), {}, {
                type: options.parser.startsWith("__") ? "JsExpressionRoot" : "JsonRoot",
                node: ast,
                comments: [],
                rootMarker: options.rootMarker
              });
            default:
              return ast;
          }
        }
        module22.exports = preprocess;
      }
    });
    var require_html_binding = __commonJS22({
      "src/language-js/print/html-binding.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            join,
            line,
            group,
            softline,
            indent
          }
        } = require_doc();
        function printHtmlBinding(path2, options, print) {
          const node = path2.getValue();
          if (options.__onHtmlBindingRoot && path2.getName() === null) {
            options.__onHtmlBindingRoot(node, options);
          }
          if (node.type !== "File") {
            return;
          }
          if (options.__isVueForBindingLeft) {
            return path2.call((functionDeclarationPath) => {
              const printed = join([",", line], functionDeclarationPath.map(print, "params"));
              const {
                params
              } = functionDeclarationPath.getValue();
              if (params.length === 1) {
                return printed;
              }
              return ["(", indent([softline, group(printed)]), softline, ")"];
            }, "program", "body", 0);
          }
          if (options.__isVueBindings) {
            return path2.call((functionDeclarationPath) => join([",", line], functionDeclarationPath.map(print, "params")), "program", "body", 0);
          }
        }
        function isVueEventBindingExpression(node) {
          switch (node.type) {
            case "MemberExpression":
              switch (node.property.type) {
                case "Identifier":
                case "NumericLiteral":
                case "StringLiteral":
                  return isVueEventBindingExpression(node.object);
              }
              return false;
            case "Identifier":
              return true;
            default:
              return false;
          }
        }
        module22.exports = {
          isVueEventBindingExpression,
          printHtmlBinding
        };
      }
    });
    var require_binaryish = __commonJS22({
      "src/language-js/print/binaryish.js"(exports2, module22) {
        "use strict";
        var {
          printComments
        } = require_comments2();
        var {
          getLast
        } = require_util6();
        var {
          builders: {
            join,
            line,
            softline,
            group,
            indent,
            align,
            indentIfBreak
          },
          utils: {
            cleanDoc,
            getDocParts,
            isConcat
          }
        } = require_doc();
        var {
          hasLeadingOwnLineComment,
          isBinaryish,
          isJsxNode,
          shouldFlatten,
          hasComment,
          CommentCheckFlags,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isObjectProperty,
          isEnabledHackPipeline
        } = require_utils72();
        var uid = 0;
        function printBinaryishExpression(path2, options, print) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          const parentParent = path2.getParentNode(1);
          const isInsideParenthesis = node !== parent.body && (parent.type === "IfStatement" || parent.type === "WhileStatement" || parent.type === "SwitchStatement" || parent.type === "DoWhileStatement");
          const isHackPipeline = isEnabledHackPipeline(options) && node.operator === "|>";
          const parts = printBinaryishExpressions(path2, print, options, false, isInsideParenthesis);
          if (isInsideParenthesis) {
            return parts;
          }
          if (isHackPipeline) {
            return group(parts);
          }
          if (isCallExpression2(parent) && parent.callee === node || parent.type === "UnaryExpression" || isMemberExpression(parent) && !parent.computed) {
            return group([indent([softline, ...parts]), softline]);
          }
          const shouldNotIndent = parent.type === "ReturnStatement" || parent.type === "ThrowStatement" || parent.type === "JSXExpressionContainer" && parentParent.type === "JSXAttribute" || node.operator !== "|" && parent.type === "JsExpressionRoot" || node.type !== "NGPipeExpression" && (parent.type === "NGRoot" && options.parser === "__ng_binding" || parent.type === "NGMicrosyntaxExpression" && parentParent.type === "NGMicrosyntax" && parentParent.body.length === 1) || node === parent.body && parent.type === "ArrowFunctionExpression" || node !== parent.body && parent.type === "ForStatement" || parent.type === "ConditionalExpression" && parentParent.type !== "ReturnStatement" && parentParent.type !== "ThrowStatement" && !isCallExpression2(parentParent) || parent.type === "TemplateLiteral";
          const shouldIndentIfInlining = parent.type === "AssignmentExpression" || parent.type === "VariableDeclarator" || parent.type === "ClassProperty" || parent.type === "PropertyDefinition" || parent.type === "TSAbstractPropertyDefinition" || parent.type === "ClassPrivateProperty" || isObjectProperty(parent);
          const samePrecedenceSubExpression = isBinaryish(node.left) && shouldFlatten(node.operator, node.left.operator);
          if (shouldNotIndent || shouldInlineLogicalExpression(node) && !samePrecedenceSubExpression || !shouldInlineLogicalExpression(node) && shouldIndentIfInlining) {
            return group(parts);
          }
          if (parts.length === 0) {
            return "";
          }
          const hasJsx = isJsxNode(node.right);
          const firstGroupIndex = parts.findIndex((part) => typeof part !== "string" && !Array.isArray(part) && part.type === "group");
          const headParts = parts.slice(0, firstGroupIndex === -1 ? 1 : firstGroupIndex + 1);
          const rest = parts.slice(headParts.length, hasJsx ? -1 : void 0);
          const groupId = Symbol("logicalChain-" + ++uid);
          const chain = group([...headParts, indent(rest)], {
            id: groupId
          });
          if (!hasJsx) {
            return chain;
          }
          const jsxPart = getLast(parts);
          return group([chain, indentIfBreak(jsxPart, {
            groupId
          })]);
        }
        function printBinaryishExpressions(path2, print, options, isNested, isInsideParenthesis) {
          const node = path2.getValue();
          if (!isBinaryish(node)) {
            return [group(print())];
          }
          let parts = [];
          if (shouldFlatten(node.operator, node.left.operator)) {
            parts = path2.call((left) => printBinaryishExpressions(left, print, options, true, isInsideParenthesis), "left");
          } else {
            parts.push(group(print("left")));
          }
          const shouldInline = shouldInlineLogicalExpression(node);
          const lineBeforeOperator = (node.operator === "|>" || node.type === "NGPipeExpression" || node.operator === "|" && options.parser === "__vue_expression") && !hasLeadingOwnLineComment(options.originalText, node.right);
          const operator = node.type === "NGPipeExpression" ? "|" : node.operator;
          const rightSuffix = node.type === "NGPipeExpression" && node.arguments.length > 0 ? group(indent([line, ": ", join([line, ": "], path2.map(print, "arguments").map((arg) => align(2, group(arg))))])) : "";
          let right;
          if (shouldInline) {
            right = [operator, " ", print("right"), rightSuffix];
          } else {
            const isHackPipeline = isEnabledHackPipeline(options) && operator === "|>";
            const rightContent = isHackPipeline ? path2.call((left) => printBinaryishExpressions(left, print, options, true, isInsideParenthesis), "right") : print("right");
            right = [lineBeforeOperator ? line : "", operator, lineBeforeOperator ? " " : line, rightContent, rightSuffix];
          }
          const parent = path2.getParentNode();
          const shouldBreak = hasComment(node.left, CommentCheckFlags.Trailing | CommentCheckFlags.Line);
          const shouldGroup = shouldBreak || !(isInsideParenthesis && node.type === "LogicalExpression") && parent.type !== node.type && node.left.type !== node.type && node.right.type !== node.type;
          parts.push(lineBeforeOperator ? "" : " ", shouldGroup ? group(right, {
            shouldBreak
          }) : right);
          if (isNested && hasComment(node)) {
            const printed = cleanDoc(printComments(path2, parts, options));
            if (isConcat(printed) || printed.type === "fill") {
              return getDocParts(printed);
            }
            return [printed];
          }
          return parts;
        }
        function shouldInlineLogicalExpression(node) {
          if (node.type !== "LogicalExpression") {
            return false;
          }
          if (node.right.type === "ObjectExpression" && node.right.properties.length > 0) {
            return true;
          }
          if (node.right.type === "ArrayExpression" && node.right.elements.length > 0) {
            return true;
          }
          if (isJsxNode(node.right)) {
            return true;
          }
          return false;
        }
        module22.exports = {
          printBinaryishExpression,
          shouldInlineLogicalExpression
        };
      }
    });
    var require_angular = __commonJS22({
      "src/language-js/print/angular.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            join,
            line,
            group
          }
        } = require_doc();
        var {
          hasNode,
          hasComment,
          getComments
        } = require_utils72();
        var {
          printBinaryishExpression
        } = require_binaryish();
        function printAngular(path2, options, print) {
          const node = path2.getValue();
          if (!node.type.startsWith("NG")) {
            return;
          }
          switch (node.type) {
            case "NGRoot":
              return [print("node"), !hasComment(node.node) ? "" : " //" + getComments(node.node)[0].value.trimEnd()];
            case "NGPipeExpression":
              return printBinaryishExpression(path2, options, print);
            case "NGChainedExpression":
              return group(join([";", line], path2.map((childPath) => hasNgSideEffect(childPath) ? print() : ["(", print(), ")"], "expressions")));
            case "NGEmptyExpression":
              return "";
            case "NGQuotedExpression":
              return [node.prefix, ": ", node.value.trim()];
            case "NGMicrosyntax":
              return path2.map((childPath, index) => [index === 0 ? "" : isNgForOf(childPath.getValue(), index, node) ? " " : [";", line], print()], "body");
            case "NGMicrosyntaxKey":
              return /^[$_a-z][\w$]*(?:-[$_a-z][\w$])*$/i.test(node.name) ? node.name : JSON.stringify(node.name);
            case "NGMicrosyntaxExpression":
              return [print("expression"), node.alias === null ? "" : [" as ", print("alias")]];
            case "NGMicrosyntaxKeyedExpression": {
              const index = path2.getName();
              const parentNode = path2.getParentNode();
              const shouldNotPrintColon = isNgForOf(node, index, parentNode) || (index === 1 && (node.key.name === "then" || node.key.name === "else") || index === 2 && node.key.name === "else" && parentNode.body[index - 1].type === "NGMicrosyntaxKeyedExpression" && parentNode.body[index - 1].key.name === "then") && parentNode.body[0].type === "NGMicrosyntaxExpression";
              return [print("key"), shouldNotPrintColon ? " " : ": ", print("expression")];
            }
            case "NGMicrosyntaxLet":
              return ["let ", print("key"), node.value === null ? "" : [" = ", print("value")]];
            case "NGMicrosyntaxAs":
              return [print("key"), " as ", print("alias")];
            default:
              throw new Error(`Unknown Angular node type: ${JSON.stringify(node.type)}.`);
          }
        }
        function isNgForOf(node, index, parentNode) {
          return node.type === "NGMicrosyntaxKeyedExpression" && node.key.name === "of" && index === 1 && parentNode.body[0].type === "NGMicrosyntaxLet" && parentNode.body[0].value === null;
        }
        function hasNgSideEffect(path2) {
          return hasNode(path2.getValue(), (node) => {
            switch (node.type) {
              case void 0:
                return false;
              case "CallExpression":
              case "OptionalCallExpression":
              case "AssignmentExpression":
                return true;
            }
          });
        }
        module22.exports = {
          printAngular
        };
      }
    });
    var require_jsx4 = __commonJS22({
      "src/language-js/print/jsx.js"(exports2, module22) {
        "use strict";
        var {
          printComments,
          printDanglingComments,
          printCommentsSeparately
        } = require_comments2();
        var {
          builders: {
            line,
            hardline,
            softline,
            group,
            indent,
            conditionalGroup,
            fill,
            ifBreak,
            lineSuffixBoundary,
            join
          },
          utils: {
            willBreak
          }
        } = require_doc();
        var {
          getLast,
          getPreferredQuote
        } = require_util6();
        var {
          isJsxNode,
          rawText,
          isLiteral,
          isCallExpression: isCallExpression2,
          isStringLiteral: isStringLiteral3,
          isBinaryish,
          hasComment,
          CommentCheckFlags,
          hasNodeIgnoreComment
        } = require_utils72();
        var pathNeedsParens = require_needs_parens();
        var {
          willPrintOwnComments
        } = require_comments22();
        var isEmptyStringOrAnyLine = (doc2) => doc2 === "" || doc2 === line || doc2 === hardline || doc2 === softline;
        function printJsxElementInternal(path2, options, print) {
          const node = path2.getValue();
          if (node.type === "JSXElement" && isEmptyJsxElement(node)) {
            return [print("openingElement"), print("closingElement")];
          }
          const openingLines = node.type === "JSXElement" ? print("openingElement") : print("openingFragment");
          const closingLines = node.type === "JSXElement" ? print("closingElement") : print("closingFragment");
          if (node.children.length === 1 && node.children[0].type === "JSXExpressionContainer" && (node.children[0].expression.type === "TemplateLiteral" || node.children[0].expression.type === "TaggedTemplateExpression")) {
            return [openingLines, ...path2.map(print, "children"), closingLines];
          }
          node.children = node.children.map((child) => {
            if (isJsxWhitespaceExpression(child)) {
              return {
                type: "JSXText",
                value: " ",
                raw: " "
              };
            }
            return child;
          });
          const containsTag = node.children.some(isJsxNode);
          const containsMultipleExpressions = node.children.filter((child) => child.type === "JSXExpressionContainer").length > 1;
          const containsMultipleAttributes = node.type === "JSXElement" && node.openingElement.attributes.length > 1;
          let forcedBreak = willBreak(openingLines) || containsTag || containsMultipleAttributes || containsMultipleExpressions;
          const isMdxBlock = path2.getParentNode().rootMarker === "mdx";
          const rawJsxWhitespace = options.singleQuote ? "{' '}" : '{" "}';
          const jsxWhitespace = isMdxBlock ? " " : ifBreak([rawJsxWhitespace, softline], " ");
          const isFacebookTranslationTag = node.openingElement && node.openingElement.name && node.openingElement.name.name === "fbt";
          const children = printJsxChildren(path2, options, print, jsxWhitespace, isFacebookTranslationTag);
          const containsText = node.children.some((child) => isMeaningfulJsxText(child));
          for (let i = children.length - 2; i >= 0; i--) {
            const isPairOfEmptyStrings = children[i] === "" && children[i + 1] === "";
            const isPairOfHardlines = children[i] === hardline && children[i + 1] === "" && children[i + 2] === hardline;
            const isLineFollowedByJsxWhitespace = (children[i] === softline || children[i] === hardline) && children[i + 1] === "" && children[i + 2] === jsxWhitespace;
            const isJsxWhitespaceFollowedByLine = children[i] === jsxWhitespace && children[i + 1] === "" && (children[i + 2] === softline || children[i + 2] === hardline);
            const isDoubleJsxWhitespace = children[i] === jsxWhitespace && children[i + 1] === "" && children[i + 2] === jsxWhitespace;
            const isPairOfHardOrSoftLines = children[i] === softline && children[i + 1] === "" && children[i + 2] === hardline || children[i] === hardline && children[i + 1] === "" && children[i + 2] === softline;
            if (isPairOfHardlines && containsText || isPairOfEmptyStrings || isLineFollowedByJsxWhitespace || isDoubleJsxWhitespace || isPairOfHardOrSoftLines) {
              children.splice(i, 2);
            } else if (isJsxWhitespaceFollowedByLine) {
              children.splice(i + 1, 2);
            }
          }
          while (children.length > 0 && isEmptyStringOrAnyLine(getLast(children))) {
            children.pop();
          }
          while (children.length > 1 && isEmptyStringOrAnyLine(children[0]) && isEmptyStringOrAnyLine(children[1])) {
            children.shift();
            children.shift();
          }
          const multilineChildren = [];
          for (const [i, child] of children.entries()) {
            if (child === jsxWhitespace) {
              if (i === 1 && children[i - 1] === "") {
                if (children.length === 2) {
                  multilineChildren.push(rawJsxWhitespace);
                  continue;
                }
                multilineChildren.push([rawJsxWhitespace, hardline]);
                continue;
              } else if (i === children.length - 1) {
                multilineChildren.push(rawJsxWhitespace);
                continue;
              } else if (children[i - 1] === "" && children[i - 2] === hardline) {
                multilineChildren.push(rawJsxWhitespace);
                continue;
              }
            }
            multilineChildren.push(child);
            if (willBreak(child)) {
              forcedBreak = true;
            }
          }
          const content = containsText ? fill(multilineChildren) : group(multilineChildren, {
            shouldBreak: true
          });
          if (isMdxBlock) {
            return content;
          }
          const multiLineElem = group([openingLines, indent([hardline, content]), hardline, closingLines]);
          if (forcedBreak) {
            return multiLineElem;
          }
          return conditionalGroup([group([openingLines, ...children, closingLines]), multiLineElem]);
        }
        function printJsxChildren(path2, options, print, jsxWhitespace, isFacebookTranslationTag) {
          const parts = [];
          path2.each((childPath, i, children) => {
            const child = childPath.getValue();
            if (isLiteral(child)) {
              const text = rawText(child);
              if (isMeaningfulJsxText(child)) {
                const words = text.split(matchJsxWhitespaceRegex);
                if (words[0] === "") {
                  parts.push("");
                  words.shift();
                  if (/\n/.test(words[0])) {
                    const next = children[i + 1];
                    parts.push(separatorWithWhitespace(isFacebookTranslationTag, words[1], child, next));
                  } else {
                    parts.push(jsxWhitespace);
                  }
                  words.shift();
                }
                let endWhitespace;
                if (getLast(words) === "") {
                  words.pop();
                  endWhitespace = words.pop();
                }
                if (words.length === 0) {
                  return;
                }
                for (const [i2, word] of words.entries()) {
                  if (i2 % 2 === 1) {
                    parts.push(line);
                  } else {
                    parts.push(word);
                  }
                }
                if (endWhitespace !== void 0) {
                  if (/\n/.test(endWhitespace)) {
                    const next = children[i + 1];
                    parts.push(separatorWithWhitespace(isFacebookTranslationTag, getLast(parts), child, next));
                  } else {
                    parts.push(jsxWhitespace);
                  }
                } else {
                  const next = children[i + 1];
                  parts.push(separatorNoWhitespace(isFacebookTranslationTag, getLast(parts), child, next));
                }
              } else if (/\n/.test(text)) {
                if (text.match(/\n/g).length > 1) {
                  parts.push("", hardline);
                }
              } else {
                parts.push("", jsxWhitespace);
              }
            } else {
              const printedChild = print();
              parts.push(printedChild);
              const next = children[i + 1];
              const directlyFollowedByMeaningfulText = next && isMeaningfulJsxText(next);
              if (directlyFollowedByMeaningfulText) {
                const firstWord = trimJsxWhitespace(rawText(next)).split(matchJsxWhitespaceRegex)[0];
                parts.push(separatorNoWhitespace(isFacebookTranslationTag, firstWord, child, next));
              } else {
                parts.push(hardline);
              }
            }
          }, "children");
          return parts;
        }
        function separatorNoWhitespace(isFacebookTranslationTag, child, childNode, nextNode) {
          if (isFacebookTranslationTag) {
            return "";
          }
          if (childNode.type === "JSXElement" && !childNode.closingElement || nextNode && nextNode.type === "JSXElement" && !nextNode.closingElement) {
            return child.length === 1 ? softline : hardline;
          }
          return softline;
        }
        function separatorWithWhitespace(isFacebookTranslationTag, child, childNode, nextNode) {
          if (isFacebookTranslationTag) {
            return hardline;
          }
          if (child.length === 1) {
            return childNode.type === "JSXElement" && !childNode.closingElement || nextNode && nextNode.type === "JSXElement" && !nextNode.closingElement ? hardline : softline;
          }
          return hardline;
        }
        function maybeWrapJsxElementInParens(path2, elem, options) {
          const parent = path2.getParentNode();
          if (!parent) {
            return elem;
          }
          const NO_WRAP_PARENTS = {
            ArrayExpression: true,
            JSXAttribute: true,
            JSXElement: true,
            JSXExpressionContainer: true,
            JSXFragment: true,
            ExpressionStatement: true,
            CallExpression: true,
            OptionalCallExpression: true,
            ConditionalExpression: true,
            JsExpressionRoot: true
          };
          if (NO_WRAP_PARENTS[parent.type]) {
            return elem;
          }
          const shouldBreak = path2.match(void 0, (node) => node.type === "ArrowFunctionExpression", isCallExpression2, (node) => node.type === "JSXExpressionContainer");
          const needsParens = pathNeedsParens(path2, options);
          return group([needsParens ? "" : ifBreak("("), indent([softline, elem]), softline, needsParens ? "" : ifBreak(")")], {
            shouldBreak
          });
        }
        function printJsxAttribute(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          parts.push(print("name"));
          if (node.value) {
            let res;
            if (isStringLiteral3(node.value)) {
              const raw = rawText(node.value);
              let final = raw.slice(1, -1).replace(/&apos;/g, "'").replace(/&quot;/g, '"');
              const {
                escaped,
                quote,
                regex
              } = getPreferredQuote(final, options.jsxSingleQuote ? "'" : '"');
              final = final.replace(regex, escaped);
              const {
                leading,
                trailing
              } = path2.call(() => printCommentsSeparately(path2, options), "value");
              res = [leading, quote, final, quote, trailing];
            } else {
              res = print("value");
            }
            parts.push("=", res);
          }
          return parts;
        }
        function printJsxExpressionContainer(path2, options, print) {
          const node = path2.getValue();
          const shouldInline = (node2, parent) => node2.type === "JSXEmptyExpression" || !hasComment(node2) && (node2.type === "ArrayExpression" || node2.type === "ObjectExpression" || node2.type === "ArrowFunctionExpression" || node2.type === "AwaitExpression" && (shouldInline(node2.argument, node2) || node2.argument.type === "JSXElement") || isCallExpression2(node2) || node2.type === "FunctionExpression" || node2.type === "TemplateLiteral" || node2.type === "TaggedTemplateExpression" || node2.type === "DoExpression" || isJsxNode(parent) && (node2.type === "ConditionalExpression" || isBinaryish(node2)));
          if (shouldInline(node.expression, path2.getParentNode(0))) {
            return group(["{", print("expression"), lineSuffixBoundary, "}"]);
          }
          return group(["{", indent([softline, print("expression")]), softline, lineSuffixBoundary, "}"]);
        }
        function printJsxOpeningElement(path2, options, print) {
          const node = path2.getValue();
          const nameHasComments = node.name && hasComment(node.name) || node.typeParameters && hasComment(node.typeParameters);
          if (node.selfClosing && node.attributes.length === 0 && !nameHasComments) {
            return ["<", print("name"), print("typeParameters"), " />"];
          }
          if (node.attributes && node.attributes.length === 1 && node.attributes[0].value && isStringLiteral3(node.attributes[0].value) && !node.attributes[0].value.value.includes("\n") && !nameHasComments && !hasComment(node.attributes[0])) {
            return group(["<", print("name"), print("typeParameters"), " ", ...path2.map(print, "attributes"), node.selfClosing ? " />" : ">"]);
          }
          const shouldBreak = node.attributes && node.attributes.some((attr) => attr.value && isStringLiteral3(attr.value) && attr.value.value.includes("\n"));
          const attributeLine = options.singleAttributePerLine && node.attributes.length > 1 ? hardline : line;
          return group(["<", print("name"), print("typeParameters"), indent(path2.map(() => [attributeLine, print()], "attributes")), ...printEndOfOpeningTag(node, options, nameHasComments)], {
            shouldBreak
          });
        }
        function printEndOfOpeningTag(node, options, nameHasComments) {
          if (node.selfClosing) {
            return [line, "/>"];
          }
          const bracketSameLine = shouldPrintBracketSameLine(node, options, nameHasComments);
          if (bracketSameLine) {
            return [">"];
          }
          return [softline, ">"];
        }
        function shouldPrintBracketSameLine(node, options, nameHasComments) {
          const lastAttrHasTrailingComments = node.attributes.length > 0 && hasComment(getLast(node.attributes), CommentCheckFlags.Trailing);
          return node.attributes.length === 0 && !nameHasComments || (options.bracketSameLine || options.jsxBracketSameLine) && (!nameHasComments || node.attributes.length > 0) && !lastAttrHasTrailingComments;
        }
        function printJsxClosingElement(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          parts.push("</");
          const printed = print("name");
          if (hasComment(node.name, CommentCheckFlags.Leading | CommentCheckFlags.Line)) {
            parts.push(indent([hardline, printed]), hardline);
          } else if (hasComment(node.name, CommentCheckFlags.Leading | CommentCheckFlags.Block)) {
            parts.push(" ", printed);
          } else {
            parts.push(printed);
          }
          parts.push(">");
          return parts;
        }
        function printJsxOpeningClosingFragment(path2, options) {
          const node = path2.getValue();
          const nodeHasComment = hasComment(node);
          const hasOwnLineComment = hasComment(node, CommentCheckFlags.Line);
          const isOpeningFragment = node.type === "JSXOpeningFragment";
          return [isOpeningFragment ? "<" : "</", indent([hasOwnLineComment ? hardline : nodeHasComment && !isOpeningFragment ? " " : "", printDanglingComments(path2, options, true)]), hasOwnLineComment ? hardline : "", ">"];
        }
        function printJsxElement(path2, options, print) {
          const elem = printComments(path2, printJsxElementInternal(path2, options, print), options);
          return maybeWrapJsxElementInParens(path2, elem, options);
        }
        function printJsxEmptyExpression(path2, options) {
          const node = path2.getValue();
          const requiresHardline = hasComment(node, CommentCheckFlags.Line);
          return [printDanglingComments(path2, options, !requiresHardline), requiresHardline ? hardline : ""];
        }
        function printJsxSpreadAttribute(path2, options, print) {
          const node = path2.getValue();
          return ["{", path2.call((p) => {
            const printed = ["...", print()];
            const node2 = p.getValue();
            if (!hasComment(node2) || !willPrintOwnComments(p)) {
              return printed;
            }
            return [indent([softline, printComments(p, printed, options)]), softline];
          }, node.type === "JSXSpreadAttribute" ? "argument" : "expression"), "}"];
        }
        function printJsx(path2, options, print) {
          const node = path2.getValue();
          if (!node.type.startsWith("JSX")) {
            return;
          }
          switch (node.type) {
            case "JSXAttribute":
              return printJsxAttribute(path2, options, print);
            case "JSXIdentifier":
              return String(node.name);
            case "JSXNamespacedName":
              return join(":", [print("namespace"), print("name")]);
            case "JSXMemberExpression":
              return join(".", [print("object"), print("property")]);
            case "JSXSpreadAttribute":
              return printJsxSpreadAttribute(path2, options, print);
            case "JSXSpreadChild": {
              const printJsxSpreadChild = printJsxSpreadAttribute;
              return printJsxSpreadChild(path2, options, print);
            }
            case "JSXExpressionContainer":
              return printJsxExpressionContainer(path2, options, print);
            case "JSXFragment":
            case "JSXElement":
              return printJsxElement(path2, options, print);
            case "JSXOpeningElement":
              return printJsxOpeningElement(path2, options, print);
            case "JSXClosingElement":
              return printJsxClosingElement(path2, options, print);
            case "JSXOpeningFragment":
            case "JSXClosingFragment":
              return printJsxOpeningClosingFragment(path2, options);
            case "JSXEmptyExpression":
              return printJsxEmptyExpression(path2, options);
            case "JSXText":
              throw new Error("JSXText should be handled by JSXElement");
            default:
              throw new Error(`Unknown JSX node type: ${JSON.stringify(node.type)}.`);
          }
        }
        var jsxWhitespaceChars = " \n\r	";
        var matchJsxWhitespaceRegex = new RegExp("([" + jsxWhitespaceChars + "]+)");
        var containsNonJsxWhitespaceRegex = new RegExp("[^" + jsxWhitespaceChars + "]");
        var trimJsxWhitespace = (text) => text.replace(new RegExp("(?:^" + matchJsxWhitespaceRegex.source + "|" + matchJsxWhitespaceRegex.source + "$)"), "");
        function isEmptyJsxElement(node) {
          if (node.children.length === 0) {
            return true;
          }
          if (node.children.length > 1) {
            return false;
          }
          const child = node.children[0];
          return isLiteral(child) && !isMeaningfulJsxText(child);
        }
        function isMeaningfulJsxText(node) {
          return isLiteral(node) && (containsNonJsxWhitespaceRegex.test(rawText(node)) || !/\n/.test(rawText(node)));
        }
        function isJsxWhitespaceExpression(node) {
          return node.type === "JSXExpressionContainer" && isLiteral(node.expression) && node.expression.value === " " && !hasComment(node.expression);
        }
        function hasJsxIgnoreComment(path2) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          if (!parent || !node || !isJsxNode(node) || !isJsxNode(parent)) {
            return false;
          }
          const index = parent.children.indexOf(node);
          let prevSibling = null;
          for (let i = index; i > 0; i--) {
            const candidate = parent.children[i - 1];
            if (candidate.type === "JSXText" && !isMeaningfulJsxText(candidate)) {
              continue;
            }
            prevSibling = candidate;
            break;
          }
          return prevSibling && prevSibling.type === "JSXExpressionContainer" && prevSibling.expression.type === "JSXEmptyExpression" && hasNodeIgnoreComment(prevSibling.expression);
        }
        module22.exports = {
          hasJsxIgnoreComment,
          printJsx
        };
      }
    });
    var require_doc_builders = __commonJS22({
      "src/document/doc-builders.js"(exports2, module22) {
        "use strict";
        function concat(parts) {
          if (false) {
            for (const part of parts) {
              assertDoc(part);
            }
          }
          return {
            type: "concat",
            parts
          };
        }
        function indent(contents) {
          if (false) {
            assertDoc(contents);
          }
          return {
            type: "indent",
            contents
          };
        }
        function align(widthOrString, contents) {
          if (false) {
            assertDoc(contents);
          }
          return {
            type: "align",
            contents,
            n: widthOrString
          };
        }
        function group(contents, opts = {}) {
          if (false) {
            assertDoc(contents);
          }
          return {
            type: "group",
            id: opts.id,
            contents,
            break: Boolean(opts.shouldBreak),
            expandedStates: opts.expandedStates
          };
        }
        function dedentToRoot(contents) {
          return align(Number.NEGATIVE_INFINITY, contents);
        }
        function markAsRoot(contents) {
          return align({
            type: "root"
          }, contents);
        }
        function dedent(contents) {
          return align(-1, contents);
        }
        function conditionalGroup(states, opts) {
          return group(states[0], Object.assign(Object.assign({}, opts), {}, {
            expandedStates: states
          }));
        }
        function fill(parts) {
          if (false) {
            for (const part of parts) {
              assertDoc(part);
            }
          }
          return {
            type: "fill",
            parts
          };
        }
        function ifBreak(breakContents, flatContents, opts = {}) {
          if (false) {
            if (breakContents) {
              assertDoc(breakContents);
            }
            if (flatContents) {
              assertDoc(flatContents);
            }
          }
          return {
            type: "if-break",
            breakContents,
            flatContents,
            groupId: opts.groupId
          };
        }
        function indentIfBreak(contents, opts) {
          return {
            type: "indent-if-break",
            contents,
            groupId: opts.groupId,
            negate: opts.negate
          };
        }
        function lineSuffix(contents) {
          if (false) {
            assertDoc(contents);
          }
          return {
            type: "line-suffix",
            contents
          };
        }
        var lineSuffixBoundary = {
          type: "line-suffix-boundary"
        };
        var breakParent = {
          type: "break-parent"
        };
        var trim = {
          type: "trim"
        };
        var hardlineWithoutBreakParent = {
          type: "line",
          hard: true
        };
        var literallineWithoutBreakParent = {
          type: "line",
          hard: true,
          literal: true
        };
        var line = {
          type: "line"
        };
        var softline = {
          type: "line",
          soft: true
        };
        var hardline = concat([hardlineWithoutBreakParent, breakParent]);
        var literalline = concat([literallineWithoutBreakParent, breakParent]);
        var cursor = {
          type: "cursor",
          placeholder: Symbol("cursor")
        };
        function join(sep, arr) {
          const res = [];
          for (let i = 0; i < arr.length; i++) {
            if (i !== 0) {
              res.push(sep);
            }
            res.push(arr[i]);
          }
          return concat(res);
        }
        function addAlignmentToDoc(doc2, size, tabWidth) {
          let aligned = doc2;
          if (size > 0) {
            for (let i = 0; i < Math.floor(size / tabWidth); ++i) {
              aligned = indent(aligned);
            }
            aligned = align(size % tabWidth, aligned);
            aligned = align(Number.NEGATIVE_INFINITY, aligned);
          }
          return aligned;
        }
        function label(label2, contents) {
          return {
            type: "label",
            label: label2,
            contents
          };
        }
        module22.exports = {
          concat,
          join,
          line,
          softline,
          hardline,
          literalline,
          group,
          conditionalGroup,
          fill,
          lineSuffix,
          lineSuffixBoundary,
          cursor,
          breakParent,
          ifBreak,
          trim,
          indent,
          indentIfBreak,
          align,
          addAlignmentToDoc,
          markAsRoot,
          dedentToRoot,
          dedent,
          hardlineWithoutBreakParent,
          literallineWithoutBreakParent,
          label
        };
      }
    });
    var require_doc_utils = __commonJS22({
      "src/document/doc-utils.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        var {
          literalline,
          join
        } = require_doc_builders();
        var isConcat = (doc2) => Array.isArray(doc2) || doc2 && doc2.type === "concat";
        var getDocParts = (doc2) => {
          if (Array.isArray(doc2)) {
            return doc2;
          }
          if (doc2.type !== "concat" && doc2.type !== "fill") {
            throw new Error("Expect doc type to be `concat` or `fill`.");
          }
          return doc2.parts;
        };
        var traverseDocOnExitStackMarker = {};
        function traverseDoc(doc2, onEnter, onExit, shouldTraverseConditionalGroups) {
          const docsStack = [doc2];
          while (docsStack.length > 0) {
            const doc3 = docsStack.pop();
            if (doc3 === traverseDocOnExitStackMarker) {
              onExit(docsStack.pop());
              continue;
            }
            if (onExit) {
              docsStack.push(doc3, traverseDocOnExitStackMarker);
            }
            if (!onEnter || onEnter(doc3) !== false) {
              if (isConcat(doc3) || doc3.type === "fill") {
                const parts = getDocParts(doc3);
                for (let ic = parts.length, i = ic - 1; i >= 0; --i) {
                  docsStack.push(parts[i]);
                }
              } else if (doc3.type === "if-break") {
                if (doc3.flatContents) {
                  docsStack.push(doc3.flatContents);
                }
                if (doc3.breakContents) {
                  docsStack.push(doc3.breakContents);
                }
              } else if (doc3.type === "group" && doc3.expandedStates) {
                if (shouldTraverseConditionalGroups) {
                  for (let ic = doc3.expandedStates.length, i = ic - 1; i >= 0; --i) {
                    docsStack.push(doc3.expandedStates[i]);
                  }
                } else {
                  docsStack.push(doc3.contents);
                }
              } else if (doc3.contents) {
                docsStack.push(doc3.contents);
              }
            }
          }
        }
        function mapDoc(doc2, cb) {
          const mapped = /* @__PURE__ */ new Map();
          return rec(doc2);
          function rec(doc3) {
            if (mapped.has(doc3)) {
              return mapped.get(doc3);
            }
            const result = process2(doc3);
            mapped.set(doc3, result);
            return result;
          }
          function process2(doc3) {
            if (Array.isArray(doc3)) {
              return cb(doc3.map(rec));
            }
            if (doc3.type === "concat" || doc3.type === "fill") {
              const parts = doc3.parts.map(rec);
              return cb(Object.assign(Object.assign({}, doc3), {}, {
                parts
              }));
            }
            if (doc3.type === "if-break") {
              const breakContents = doc3.breakContents && rec(doc3.breakContents);
              const flatContents = doc3.flatContents && rec(doc3.flatContents);
              return cb(Object.assign(Object.assign({}, doc3), {}, {
                breakContents,
                flatContents
              }));
            }
            if (doc3.type === "group" && doc3.expandedStates) {
              const expandedStates = doc3.expandedStates.map(rec);
              const contents = expandedStates[0];
              return cb(Object.assign(Object.assign({}, doc3), {}, {
                contents,
                expandedStates
              }));
            }
            if (doc3.contents) {
              const contents = rec(doc3.contents);
              return cb(Object.assign(Object.assign({}, doc3), {}, {
                contents
              }));
            }
            return cb(doc3);
          }
        }
        function findInDoc(doc2, fn, defaultValue) {
          let result = defaultValue;
          let hasStopped = false;
          function findInDocOnEnterFn(doc3) {
            const maybeResult = fn(doc3);
            if (maybeResult !== void 0) {
              hasStopped = true;
              result = maybeResult;
            }
            if (hasStopped) {
              return false;
            }
          }
          traverseDoc(doc2, findInDocOnEnterFn);
          return result;
        }
        function willBreakFn(doc2) {
          if (doc2.type === "group" && doc2.break) {
            return true;
          }
          if (doc2.type === "line" && doc2.hard) {
            return true;
          }
          if (doc2.type === "break-parent") {
            return true;
          }
        }
        function willBreak(doc2) {
          return findInDoc(doc2, willBreakFn, false);
        }
        function breakParentGroup(groupStack) {
          if (groupStack.length > 0) {
            const parentGroup = getLast(groupStack);
            if (!parentGroup.expandedStates && !parentGroup.break) {
              parentGroup.break = "propagated";
            }
          }
          return null;
        }
        function propagateBreaks(doc2) {
          const alreadyVisitedSet = /* @__PURE__ */ new Set();
          const groupStack = [];
          function propagateBreaksOnEnterFn(doc3) {
            if (doc3.type === "break-parent") {
              breakParentGroup(groupStack);
            }
            if (doc3.type === "group") {
              groupStack.push(doc3);
              if (alreadyVisitedSet.has(doc3)) {
                return false;
              }
              alreadyVisitedSet.add(doc3);
            }
          }
          function propagateBreaksOnExitFn(doc3) {
            if (doc3.type === "group") {
              const group = groupStack.pop();
              if (group.break) {
                breakParentGroup(groupStack);
              }
            }
          }
          traverseDoc(doc2, propagateBreaksOnEnterFn, propagateBreaksOnExitFn, true);
        }
        function removeLinesFn(doc2) {
          if (doc2.type === "line" && !doc2.hard) {
            return doc2.soft ? "" : " ";
          }
          if (doc2.type === "if-break") {
            return doc2.flatContents || "";
          }
          return doc2;
        }
        function removeLines(doc2) {
          return mapDoc(doc2, removeLinesFn);
        }
        var isHardline = (doc2, nextDoc) => doc2 && doc2.type === "line" && doc2.hard && nextDoc && nextDoc.type === "break-parent";
        function stripDocTrailingHardlineFromDoc(doc2) {
          if (!doc2) {
            return doc2;
          }
          if (isConcat(doc2) || doc2.type === "fill") {
            const parts = getDocParts(doc2);
            while (parts.length > 1 && isHardline(...parts.slice(-2))) {
              parts.length -= 2;
            }
            if (parts.length > 0) {
              const lastPart = stripDocTrailingHardlineFromDoc(getLast(parts));
              parts[parts.length - 1] = lastPart;
            }
            return Array.isArray(doc2) ? parts : Object.assign(Object.assign({}, doc2), {}, {
              parts
            });
          }
          switch (doc2.type) {
            case "align":
            case "indent":
            case "indent-if-break":
            case "group":
            case "line-suffix":
            case "label": {
              const contents = stripDocTrailingHardlineFromDoc(doc2.contents);
              return Object.assign(Object.assign({}, doc2), {}, {
                contents
              });
            }
            case "if-break": {
              const breakContents = stripDocTrailingHardlineFromDoc(doc2.breakContents);
              const flatContents = stripDocTrailingHardlineFromDoc(doc2.flatContents);
              return Object.assign(Object.assign({}, doc2), {}, {
                breakContents,
                flatContents
              });
            }
          }
          return doc2;
        }
        function stripTrailingHardline(doc2) {
          return stripDocTrailingHardlineFromDoc(cleanDoc(doc2));
        }
        function cleanDocFn(doc2) {
          switch (doc2.type) {
            case "fill":
              if (doc2.parts.every((part) => part === "")) {
                return "";
              }
              break;
            case "group":
              if (!doc2.contents && !doc2.id && !doc2.break && !doc2.expandedStates) {
                return "";
              }
              if (doc2.contents.type === "group" && doc2.contents.id === doc2.id && doc2.contents.break === doc2.break && doc2.contents.expandedStates === doc2.expandedStates) {
                return doc2.contents;
              }
              break;
            case "align":
            case "indent":
            case "indent-if-break":
            case "line-suffix":
              if (!doc2.contents) {
                return "";
              }
              break;
            case "if-break":
              if (!doc2.flatContents && !doc2.breakContents) {
                return "";
              }
              break;
          }
          if (!isConcat(doc2)) {
            return doc2;
          }
          const parts = [];
          for (const part of getDocParts(doc2)) {
            if (!part) {
              continue;
            }
            const [currentPart, ...restParts] = isConcat(part) ? getDocParts(part) : [part];
            if (typeof currentPart === "string" && typeof getLast(parts) === "string") {
              parts[parts.length - 1] += currentPart;
            } else {
              parts.push(currentPart);
            }
            parts.push(...restParts);
          }
          if (parts.length === 0) {
            return "";
          }
          if (parts.length === 1) {
            return parts[0];
          }
          return Array.isArray(doc2) ? parts : Object.assign(Object.assign({}, doc2), {}, {
            parts
          });
        }
        function cleanDoc(doc2) {
          return mapDoc(doc2, (currentDoc) => cleanDocFn(currentDoc));
        }
        function normalizeParts(parts) {
          const newParts = [];
          const restParts = parts.filter(Boolean);
          while (restParts.length > 0) {
            const part = restParts.shift();
            if (!part) {
              continue;
            }
            if (isConcat(part)) {
              restParts.unshift(...getDocParts(part));
              continue;
            }
            if (newParts.length > 0 && typeof getLast(newParts) === "string" && typeof part === "string") {
              newParts[newParts.length - 1] += part;
              continue;
            }
            newParts.push(part);
          }
          return newParts;
        }
        function normalizeDoc(doc2) {
          return mapDoc(doc2, (currentDoc) => {
            if (Array.isArray(currentDoc)) {
              return normalizeParts(currentDoc);
            }
            if (!currentDoc.parts) {
              return currentDoc;
            }
            return Object.assign(Object.assign({}, currentDoc), {}, {
              parts: normalizeParts(currentDoc.parts)
            });
          });
        }
        function replaceEndOfLine(doc2) {
          return mapDoc(doc2, (currentDoc) => typeof currentDoc === "string" && currentDoc.includes("\n") ? replaceTextEndOfLine(currentDoc) : currentDoc);
        }
        function replaceTextEndOfLine(text, replacement = literalline) {
          return join(replacement, text.split("\n")).parts;
        }
        function canBreakFn(doc2) {
          if (doc2.type === "line") {
            return true;
          }
        }
        function canBreak(doc2) {
          return findInDoc(doc2, canBreakFn, false);
        }
        module22.exports = {
          isConcat,
          getDocParts,
          willBreak,
          traverseDoc,
          findInDoc,
          mapDoc,
          propagateBreaks,
          removeLines,
          stripTrailingHardline,
          normalizeParts,
          normalizeDoc,
          cleanDoc,
          replaceTextEndOfLine,
          replaceEndOfLine,
          canBreak
        };
      }
    });
    var require_misc3 = __commonJS22({
      "src/language-js/print/misc.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            indent,
            join,
            line
          }
        } = require_doc();
        var {
          isFlowAnnotationComment
        } = require_utils72();
        function printOptionalToken(path2) {
          const node = path2.getValue();
          if (!node.optional || node.type === "Identifier" && node === path2.getParentNode().key) {
            return "";
          }
          if (node.type === "OptionalCallExpression" || node.type === "OptionalMemberExpression" && node.computed) {
            return "?.";
          }
          return "?";
        }
        function printDefiniteToken(path2) {
          return path2.getValue().definite || path2.match(void 0, (node, name) => name === "id" && node.type === "VariableDeclarator" && node.definite) ? "!" : "";
        }
        function printFunctionTypeParameters(path2, options, print) {
          const fun = path2.getValue();
          if (fun.typeArguments) {
            return print("typeArguments");
          }
          if (fun.typeParameters) {
            return print("typeParameters");
          }
          return "";
        }
        function printTypeAnnotation(path2, options, print) {
          const node = path2.getValue();
          if (!node.typeAnnotation) {
            return "";
          }
          const parentNode = path2.getParentNode();
          const isFunctionDeclarationIdentifier = parentNode.type === "DeclareFunction" && parentNode.id === node;
          if (isFlowAnnotationComment(options.originalText, node.typeAnnotation)) {
            return [" /*: ", print("typeAnnotation"), " */"];
          }
          return [isFunctionDeclarationIdentifier ? "" : ": ", print("typeAnnotation")];
        }
        function printBindExpressionCallee(path2, options, print) {
          return ["::", print("callee")];
        }
        function printTypeScriptModifiers(path2, options, print) {
          const node = path2.getValue();
          if (!isNonEmptyArray(node.modifiers)) {
            return "";
          }
          return [join(" ", path2.map(print, "modifiers")), " "];
        }
        function adjustClause(node, clause, forceSpace) {
          if (node.type === "EmptyStatement") {
            return ";";
          }
          if (node.type === "BlockStatement" || forceSpace) {
            return [" ", clause];
          }
          return indent([line, clause]);
        }
        function printRestSpread(path2, options, print) {
          return ["...", print("argument"), printTypeAnnotation(path2, options, print)];
        }
        function printDirective(rawText, options) {
          const rawContent = rawText.slice(1, -1);
          if (rawContent.includes('"') || rawContent.includes("'")) {
            return rawText;
          }
          const enclosingQuote = options.singleQuote ? "'" : '"';
          return enclosingQuote + rawContent + enclosingQuote;
        }
        module22.exports = {
          printOptionalToken,
          printDefiniteToken,
          printFunctionTypeParameters,
          printBindExpressionCallee,
          printTypeScriptModifiers,
          printTypeAnnotation,
          printRestSpread,
          adjustClause,
          printDirective
        };
      }
    });
    var require_array4 = __commonJS22({
      "src/language-js/print/array.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          builders: {
            line,
            softline,
            hardline,
            group,
            indent,
            ifBreak,
            fill
          }
        } = require_doc();
        var {
          getLast,
          hasNewline
        } = require_util6();
        var {
          shouldPrintComma,
          hasComment,
          CommentCheckFlags,
          isNextLineEmpty,
          isNumericLiteral,
          isSignedNumericLiteral
        } = require_utils72();
        var {
          locStart
        } = require_loc();
        var {
          printOptionalToken,
          printTypeAnnotation
        } = require_misc3();
        function printArray(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          const openBracket = node.type === "TupleExpression" ? "#[" : "[";
          const closeBracket = "]";
          if (node.elements.length === 0) {
            if (!hasComment(node, CommentCheckFlags.Dangling)) {
              parts.push(openBracket, closeBracket);
            } else {
              parts.push(group([openBracket, printDanglingComments(path2, options), softline, closeBracket]));
            }
          } else {
            const lastElem = getLast(node.elements);
            const canHaveTrailingComma = !(lastElem && lastElem.type === "RestElement");
            const needsForcedTrailingComma = lastElem === null;
            const groupId = Symbol("array");
            const shouldBreak = !options.__inJestEach && node.elements.length > 1 && node.elements.every((element, i, elements) => {
              const elementType = element && element.type;
              if (elementType !== "ArrayExpression" && elementType !== "ObjectExpression") {
                return false;
              }
              const nextElement = elements[i + 1];
              if (nextElement && elementType !== nextElement.type) {
                return false;
              }
              const itemsKey = elementType === "ArrayExpression" ? "elements" : "properties";
              return element[itemsKey] && element[itemsKey].length > 1;
            });
            const shouldUseConciseFormatting = isConciselyPrintedArray(node, options);
            const trailingComma = !canHaveTrailingComma ? "" : needsForcedTrailingComma ? "," : !shouldPrintComma(options) ? "" : shouldUseConciseFormatting ? ifBreak(",", "", {
              groupId
            }) : ifBreak(",");
            parts.push(group([openBracket, indent([softline, shouldUseConciseFormatting ? printArrayItemsConcisely(path2, options, print, trailingComma) : [printArrayItems(path2, options, "elements", print), trailingComma], printDanglingComments(path2, options, true)]), softline, closeBracket], {
              shouldBreak,
              id: groupId
            }));
          }
          parts.push(printOptionalToken(path2), printTypeAnnotation(path2, options, print));
          return parts;
        }
        function isConciselyPrintedArray(node, options) {
          return node.elements.length > 1 && node.elements.every((element) => element && (isNumericLiteral(element) || isSignedNumericLiteral(element) && !hasComment(element.argument)) && !hasComment(element, CommentCheckFlags.Trailing | CommentCheckFlags.Line, (comment) => !hasNewline(options.originalText, locStart(comment), {
            backwards: true
          })));
        }
        function printArrayItems(path2, options, printPath, print) {
          const printedElements = [];
          let separatorParts = [];
          path2.each((childPath) => {
            printedElements.push(separatorParts, group(print()));
            separatorParts = [",", line];
            if (childPath.getValue() && isNextLineEmpty(childPath.getValue(), options)) {
              separatorParts.push(softline);
            }
          }, printPath);
          return printedElements;
        }
        function printArrayItemsConcisely(path2, options, print, trailingComma) {
          const parts = [];
          path2.each((childPath, i, elements) => {
            const isLast = i === elements.length - 1;
            parts.push([print(), isLast ? trailingComma : ","]);
            if (!isLast) {
              parts.push(isNextLineEmpty(childPath.getValue(), options) ? [hardline, hardline] : hasComment(elements[i + 1], CommentCheckFlags.Leading | CommentCheckFlags.Line) ? hardline : line);
            }
          }, "elements");
          return fill(parts);
        }
        module22.exports = {
          printArray,
          printArrayItems,
          isConciselyPrintedArray
        };
      }
    });
    var require_call_arguments = __commonJS22({
      "src/language-js/print/call-arguments.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          getLast,
          getPenultimate
        } = require_util6();
        var {
          getFunctionParameters,
          hasComment,
          CommentCheckFlags,
          isFunctionCompositionArgs,
          isJsxNode,
          isLongCurriedCallExpression,
          shouldPrintComma,
          getCallArguments,
          iterateCallArgumentsPath,
          isNextLineEmpty,
          isCallExpression: isCallExpression2,
          isStringLiteral: isStringLiteral3,
          isObjectProperty,
          isTSTypeExpression
        } = require_utils72();
        var {
          builders: {
            line,
            hardline,
            softline,
            group,
            indent,
            conditionalGroup,
            ifBreak,
            breakParent
          },
          utils: {
            willBreak
          }
        } = require_doc();
        var {
          ArgExpansionBailout
        } = require_errors2();
        var {
          isConciselyPrintedArray
        } = require_array4();
        function printCallArguments(path2, options, print) {
          const node = path2.getValue();
          const isDynamicImport = node.type === "ImportExpression";
          const args = getCallArguments(node);
          if (args.length === 0) {
            return ["(", printDanglingComments(path2, options, true), ")"];
          }
          if (isReactHookCallWithDepsArray(args)) {
            return ["(", print(["arguments", 0]), ", ", print(["arguments", 1]), ")"];
          }
          let anyArgEmptyLine = false;
          let hasEmptyLineFollowingFirstArg = false;
          const lastArgIndex = args.length - 1;
          const printedArguments = [];
          iterateCallArgumentsPath(path2, (argPath, index) => {
            const arg = argPath.getNode();
            const parts = [print()];
            if (index === lastArgIndex) {
            } else if (isNextLineEmpty(arg, options)) {
              if (index === 0) {
                hasEmptyLineFollowingFirstArg = true;
              }
              anyArgEmptyLine = true;
              parts.push(",", hardline, hardline);
            } else {
              parts.push(",", line);
            }
            printedArguments.push(parts);
          });
          const maybeTrailingComma = !(isDynamicImport || node.callee && node.callee.type === "Import") && shouldPrintComma(options, "all") ? "," : "";
          function allArgsBrokenOut() {
            return group(["(", indent([line, ...printedArguments]), maybeTrailingComma, line, ")"], {
              shouldBreak: true
            });
          }
          if (anyArgEmptyLine || path2.getParentNode().type !== "Decorator" && isFunctionCompositionArgs(args)) {
            return allArgsBrokenOut();
          }
          const shouldGroupFirst = shouldGroupFirstArg(args);
          const shouldGroupLast = shouldGroupLastArg(args, options);
          if (shouldGroupFirst || shouldGroupLast) {
            if (shouldGroupFirst ? printedArguments.slice(1).some(willBreak) : printedArguments.slice(0, -1).some(willBreak)) {
              return allArgsBrokenOut();
            }
            let printedExpanded = [];
            try {
              path2.try(() => {
                iterateCallArgumentsPath(path2, (argPath, i) => {
                  if (shouldGroupFirst && i === 0) {
                    printedExpanded = [[print([], {
                      expandFirstArg: true
                    }), printedArguments.length > 1 ? "," : "", hasEmptyLineFollowingFirstArg ? hardline : line, hasEmptyLineFollowingFirstArg ? hardline : ""], ...printedArguments.slice(1)];
                  }
                  if (shouldGroupLast && i === lastArgIndex) {
                    printedExpanded = [...printedArguments.slice(0, -1), print([], {
                      expandLastArg: true
                    })];
                  }
                });
              });
            } catch (caught) {
              if (caught instanceof ArgExpansionBailout) {
                return allArgsBrokenOut();
              }
              throw caught;
            }
            return [printedArguments.some(willBreak) ? breakParent : "", conditionalGroup([["(", ...printedExpanded, ")"], shouldGroupFirst ? ["(", group(printedExpanded[0], {
              shouldBreak: true
            }), ...printedExpanded.slice(1), ")"] : ["(", ...printedArguments.slice(0, -1), group(getLast(printedExpanded), {
              shouldBreak: true
            }), ")"], allArgsBrokenOut()])];
          }
          const contents = ["(", indent([softline, ...printedArguments]), ifBreak(maybeTrailingComma), softline, ")"];
          if (isLongCurriedCallExpression(path2)) {
            return contents;
          }
          return group(contents, {
            shouldBreak: printedArguments.some(willBreak) || anyArgEmptyLine
          });
        }
        function couldGroupArg(arg, arrowChainRecursion = false) {
          return arg.type === "ObjectExpression" && (arg.properties.length > 0 || hasComment(arg)) || arg.type === "ArrayExpression" && (arg.elements.length > 0 || hasComment(arg)) || arg.type === "TSTypeAssertion" && couldGroupArg(arg.expression) || isTSTypeExpression(arg) && couldGroupArg(arg.expression) || arg.type === "FunctionExpression" || arg.type === "ArrowFunctionExpression" && (!arg.returnType || !arg.returnType.typeAnnotation || arg.returnType.typeAnnotation.type !== "TSTypeReference" || isNonEmptyBlockStatement(arg.body)) && (arg.body.type === "BlockStatement" || arg.body.type === "ArrowFunctionExpression" && couldGroupArg(arg.body, true) || arg.body.type === "ObjectExpression" || arg.body.type === "ArrayExpression" || !arrowChainRecursion && (isCallExpression2(arg.body) || arg.body.type === "ConditionalExpression") || isJsxNode(arg.body)) || arg.type === "DoExpression" || arg.type === "ModuleExpression";
        }
        function shouldGroupLastArg(args, options) {
          const lastArg = getLast(args);
          const penultimateArg = getPenultimate(args);
          return !hasComment(lastArg, CommentCheckFlags.Leading) && !hasComment(lastArg, CommentCheckFlags.Trailing) && couldGroupArg(lastArg) && (!penultimateArg || penultimateArg.type !== lastArg.type) && (args.length !== 2 || penultimateArg.type !== "ArrowFunctionExpression" || lastArg.type !== "ArrayExpression") && !(args.length > 1 && lastArg.type === "ArrayExpression" && isConciselyPrintedArray(lastArg, options));
        }
        function shouldGroupFirstArg(args) {
          if (args.length !== 2) {
            return false;
          }
          const [firstArg, secondArg] = args;
          if (firstArg.type === "ModuleExpression" && isTypeModuleObjectExpression(secondArg)) {
            return true;
          }
          return !hasComment(firstArg) && (firstArg.type === "FunctionExpression" || firstArg.type === "ArrowFunctionExpression" && firstArg.body.type === "BlockStatement") && secondArg.type !== "FunctionExpression" && secondArg.type !== "ArrowFunctionExpression" && secondArg.type !== "ConditionalExpression" && !couldGroupArg(secondArg);
        }
        function isReactHookCallWithDepsArray(args) {
          return args.length === 2 && args[0].type === "ArrowFunctionExpression" && getFunctionParameters(args[0]).length === 0 && args[0].body.type === "BlockStatement" && args[1].type === "ArrayExpression" && !args.some((arg) => hasComment(arg));
        }
        function isNonEmptyBlockStatement(node) {
          return node.type === "BlockStatement" && (node.body.some((node2) => node2.type !== "EmptyStatement") || hasComment(node, CommentCheckFlags.Dangling));
        }
        function isTypeModuleObjectExpression(node) {
          return node.type === "ObjectExpression" && node.properties.length === 1 && isObjectProperty(node.properties[0]) && node.properties[0].key.type === "Identifier" && node.properties[0].key.name === "type" && isStringLiteral3(node.properties[0].value) && node.properties[0].value.value === "module";
        }
        module22.exports = printCallArguments;
      }
    });
    var require_member = __commonJS22({
      "src/language-js/print/member.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            softline,
            group,
            indent,
            label
          }
        } = require_doc();
        var {
          isNumericLiteral,
          isMemberExpression,
          isCallExpression: isCallExpression2
        } = require_utils72();
        var {
          printOptionalToken
        } = require_misc3();
        function printMemberExpression(path2, options, print) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          let firstNonMemberParent;
          let i = 0;
          do {
            firstNonMemberParent = path2.getParentNode(i);
            i++;
          } while (firstNonMemberParent && (isMemberExpression(firstNonMemberParent) || firstNonMemberParent.type === "TSNonNullExpression"));
          const objectDoc = print("object");
          const lookupDoc = printMemberLookup(path2, options, print);
          const shouldInline = firstNonMemberParent && (firstNonMemberParent.type === "NewExpression" || firstNonMemberParent.type === "BindExpression" || firstNonMemberParent.type === "AssignmentExpression" && firstNonMemberParent.left.type !== "Identifier") || node.computed || node.object.type === "Identifier" && node.property.type === "Identifier" && !isMemberExpression(parent) || (parent.type === "AssignmentExpression" || parent.type === "VariableDeclarator") && (isCallExpression2(node.object) && node.object.arguments.length > 0 || node.object.type === "TSNonNullExpression" && isCallExpression2(node.object.expression) && node.object.expression.arguments.length > 0 || objectDoc.label === "member-chain");
          return label(objectDoc.label === "member-chain" ? "member-chain" : "member", [objectDoc, shouldInline ? lookupDoc : group(indent([softline, lookupDoc]))]);
        }
        function printMemberLookup(path2, options, print) {
          const property = print("property");
          const node = path2.getValue();
          const optional = printOptionalToken(path2);
          if (!node.computed) {
            return [optional, ".", property];
          }
          if (!node.property || isNumericLiteral(node.property)) {
            return [optional, "[", property, "]"];
          }
          return group([optional, "[", indent([softline, property]), softline, "]"]);
        }
        module22.exports = {
          printMemberExpression,
          printMemberLookup
        };
      }
    });
    var require_member_chain = __commonJS22({
      "src/language-js/print/member-chain.js"(exports2, module22) {
        "use strict";
        var {
          printComments
        } = require_comments2();
        var {
          getLast,
          isNextLineEmptyAfterIndex,
          getNextNonSpaceNonCommentCharacterIndex
        } = require_util6();
        var pathNeedsParens = require_needs_parens();
        var {
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isFunctionOrArrowExpression,
          isLongCurriedCallExpression,
          isMemberish,
          isNumericLiteral,
          isSimpleCallArgument,
          hasComment,
          CommentCheckFlags,
          isNextLineEmpty
        } = require_utils72();
        var {
          locEnd
        } = require_loc();
        var {
          builders: {
            join,
            hardline,
            group,
            indent,
            conditionalGroup,
            breakParent,
            label
          },
          utils: {
            willBreak
          }
        } = require_doc();
        var printCallArguments = require_call_arguments();
        var {
          printMemberLookup
        } = require_member();
        var {
          printOptionalToken,
          printFunctionTypeParameters,
          printBindExpressionCallee
        } = require_misc3();
        function printMemberChain(path2, options, print) {
          const parent = path2.getParentNode();
          const isExpressionStatement = !parent || parent.type === "ExpressionStatement";
          const printedNodes = [];
          function shouldInsertEmptyLineAfter(node2) {
            const {
              originalText
            } = options;
            const nextCharIndex = getNextNonSpaceNonCommentCharacterIndex(originalText, node2, locEnd);
            const nextChar = originalText.charAt(nextCharIndex);
            if (nextChar === ")") {
              return nextCharIndex !== false && isNextLineEmptyAfterIndex(originalText, nextCharIndex + 1);
            }
            return isNextLineEmpty(node2, options);
          }
          function rec(path22) {
            const node2 = path22.getValue();
            if (isCallExpression2(node2) && (isMemberish(node2.callee) || isCallExpression2(node2.callee))) {
              printedNodes.unshift({
                node: node2,
                printed: [printComments(path22, [printOptionalToken(path22), printFunctionTypeParameters(path22, options, print), printCallArguments(path22, options, print)], options), shouldInsertEmptyLineAfter(node2) ? hardline : ""]
              });
              path22.call((callee) => rec(callee), "callee");
            } else if (isMemberish(node2)) {
              printedNodes.unshift({
                node: node2,
                needsParens: pathNeedsParens(path22, options),
                printed: printComments(path22, isMemberExpression(node2) ? printMemberLookup(path22, options, print) : printBindExpressionCallee(path22, options, print), options)
              });
              path22.call((object) => rec(object), "object");
            } else if (node2.type === "TSNonNullExpression") {
              printedNodes.unshift({
                node: node2,
                printed: printComments(path22, "!", options)
              });
              path22.call((expression) => rec(expression), "expression");
            } else {
              printedNodes.unshift({
                node: node2,
                printed: print()
              });
            }
          }
          const node = path2.getValue();
          printedNodes.unshift({
            node,
            printed: [printOptionalToken(path2), printFunctionTypeParameters(path2, options, print), printCallArguments(path2, options, print)]
          });
          if (node.callee) {
            path2.call((callee) => rec(callee), "callee");
          }
          const groups = [];
          let currentGroup = [printedNodes[0]];
          let i = 1;
          for (; i < printedNodes.length; ++i) {
            if (printedNodes[i].node.type === "TSNonNullExpression" || isCallExpression2(printedNodes[i].node) || isMemberExpression(printedNodes[i].node) && printedNodes[i].node.computed && isNumericLiteral(printedNodes[i].node.property)) {
              currentGroup.push(printedNodes[i]);
            } else {
              break;
            }
          }
          if (!isCallExpression2(printedNodes[0].node)) {
            for (; i + 1 < printedNodes.length; ++i) {
              if (isMemberish(printedNodes[i].node) && isMemberish(printedNodes[i + 1].node)) {
                currentGroup.push(printedNodes[i]);
              } else {
                break;
              }
            }
          }
          groups.push(currentGroup);
          currentGroup = [];
          let hasSeenCallExpression = false;
          for (; i < printedNodes.length; ++i) {
            if (hasSeenCallExpression && isMemberish(printedNodes[i].node)) {
              if (printedNodes[i].node.computed && isNumericLiteral(printedNodes[i].node.property)) {
                currentGroup.push(printedNodes[i]);
                continue;
              }
              groups.push(currentGroup);
              currentGroup = [];
              hasSeenCallExpression = false;
            }
            if (isCallExpression2(printedNodes[i].node) || printedNodes[i].node.type === "ImportExpression") {
              hasSeenCallExpression = true;
            }
            currentGroup.push(printedNodes[i]);
            if (hasComment(printedNodes[i].node, CommentCheckFlags.Trailing)) {
              groups.push(currentGroup);
              currentGroup = [];
              hasSeenCallExpression = false;
            }
          }
          if (currentGroup.length > 0) {
            groups.push(currentGroup);
          }
          function isFactory(name) {
            return /^[A-Z]|^[$_]+$/.test(name);
          }
          function isShort(name) {
            return name.length <= options.tabWidth;
          }
          function shouldNotWrap(groups2) {
            const hasComputed = groups2[1].length > 0 && groups2[1][0].node.computed;
            if (groups2[0].length === 1) {
              const firstNode = groups2[0][0].node;
              return firstNode.type === "ThisExpression" || firstNode.type === "Identifier" && (isFactory(firstNode.name) || isExpressionStatement && isShort(firstNode.name) || hasComputed);
            }
            const lastNode = getLast(groups2[0]).node;
            return isMemberExpression(lastNode) && lastNode.property.type === "Identifier" && (isFactory(lastNode.property.name) || hasComputed);
          }
          const shouldMerge = groups.length >= 2 && !hasComment(groups[1][0].node) && shouldNotWrap(groups);
          function printGroup(printedGroup) {
            const printed = printedGroup.map((tuple) => tuple.printed);
            if (printedGroup.length > 0 && getLast(printedGroup).needsParens) {
              return ["(", ...printed, ")"];
            }
            return printed;
          }
          function printIndentedGroup(groups2) {
            if (groups2.length === 0) {
              return "";
            }
            return indent(group([hardline, join(hardline, groups2.map(printGroup))]));
          }
          const printedGroups = groups.map(printGroup);
          const oneLine = printedGroups;
          const cutoff = shouldMerge ? 3 : 2;
          const flatGroups = groups.flat();
          const nodeHasComment = flatGroups.slice(1, -1).some((node2) => hasComment(node2.node, CommentCheckFlags.Leading)) || flatGroups.slice(0, -1).some((node2) => hasComment(node2.node, CommentCheckFlags.Trailing)) || groups[cutoff] && hasComment(groups[cutoff][0].node, CommentCheckFlags.Leading);
          if (groups.length <= cutoff && !nodeHasComment) {
            if (isLongCurriedCallExpression(path2)) {
              return oneLine;
            }
            return group(oneLine);
          }
          const lastNodeBeforeIndent = getLast(groups[shouldMerge ? 1 : 0]).node;
          const shouldHaveEmptyLineBeforeIndent = !isCallExpression2(lastNodeBeforeIndent) && shouldInsertEmptyLineAfter(lastNodeBeforeIndent);
          const expanded = [printGroup(groups[0]), shouldMerge ? groups.slice(1, 2).map(printGroup) : "", shouldHaveEmptyLineBeforeIndent ? hardline : "", printIndentedGroup(groups.slice(shouldMerge ? 2 : 1))];
          const callExpressions = printedNodes.map(({
            node: node2
          }) => node2).filter(isCallExpression2);
          function lastGroupWillBreakAndOtherCallsHaveFunctionArguments() {
            const lastGroupNode = getLast(getLast(groups)).node;
            const lastGroupDoc = getLast(printedGroups);
            return isCallExpression2(lastGroupNode) && willBreak(lastGroupDoc) && callExpressions.slice(0, -1).some((node2) => node2.arguments.some(isFunctionOrArrowExpression));
          }
          let result;
          if (nodeHasComment || callExpressions.length > 2 && callExpressions.some((expr) => !expr.arguments.every((arg) => isSimpleCallArgument(arg, 0))) || printedGroups.slice(0, -1).some(willBreak) || lastGroupWillBreakAndOtherCallsHaveFunctionArguments()) {
            result = group(expanded);
          } else {
            result = [willBreak(oneLine) || shouldHaveEmptyLineBeforeIndent ? breakParent : "", conditionalGroup([oneLine, expanded])];
          }
          return label("member-chain", result);
        }
        module22.exports = printMemberChain;
      }
    });
    var require_call_expression = __commonJS22({
      "src/language-js/print/call-expression.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            join,
            group
          }
        } = require_doc();
        var pathNeedsParens = require_needs_parens();
        var {
          getCallArguments,
          hasFlowAnnotationComment,
          isCallExpression: isCallExpression2,
          isMemberish,
          isStringLiteral: isStringLiteral3,
          isTemplateOnItsOwnLine,
          isTestCall,
          iterateCallArgumentsPath
        } = require_utils72();
        var printMemberChain = require_member_chain();
        var printCallArguments = require_call_arguments();
        var {
          printOptionalToken,
          printFunctionTypeParameters
        } = require_misc3();
        function printCallExpression(path2, options, print) {
          const node = path2.getValue();
          const parentNode = path2.getParentNode();
          const isNew = node.type === "NewExpression";
          const isDynamicImport = node.type === "ImportExpression";
          const optional = printOptionalToken(path2);
          const args = getCallArguments(node);
          if (args.length > 0 && (!isDynamicImport && !isNew && isCommonsJsOrAmdCall(node, parentNode) || args.length === 1 && isTemplateOnItsOwnLine(args[0], options.originalText) || !isNew && isTestCall(node, parentNode))) {
            const printed = [];
            iterateCallArgumentsPath(path2, () => {
              printed.push(print());
            });
            return [isNew ? "new " : "", print("callee"), optional, printFunctionTypeParameters(path2, options, print), "(", join(", ", printed), ")"];
          }
          const isIdentifierWithFlowAnnotation = (options.parser === "babel" || options.parser === "babel-flow") && node.callee && node.callee.type === "Identifier" && hasFlowAnnotationComment(node.callee.trailingComments);
          if (isIdentifierWithFlowAnnotation) {
            node.callee.trailingComments[0].printed = true;
          }
          if (!isDynamicImport && !isNew && isMemberish(node.callee) && !path2.call((path22) => pathNeedsParens(path22, options), "callee")) {
            return printMemberChain(path2, options, print);
          }
          const contents = [isNew ? "new " : "", isDynamicImport ? "import" : print("callee"), optional, isIdentifierWithFlowAnnotation ? `/*:: ${node.callee.trailingComments[0].value.slice(2).trim()} */` : "", printFunctionTypeParameters(path2, options, print), printCallArguments(path2, options, print)];
          if (isDynamicImport || isCallExpression2(node.callee)) {
            return group(contents);
          }
          return contents;
        }
        function isCommonsJsOrAmdCall(node, parentNode) {
          if (node.callee.type !== "Identifier") {
            return false;
          }
          if (node.callee.name === "require") {
            return true;
          }
          if (node.callee.name === "define") {
            const args = getCallArguments(node);
            return parentNode.type === "ExpressionStatement" && (args.length === 1 || args.length === 2 && args[0].type === "ArrayExpression" || args.length === 3 && isStringLiteral3(args[0]) && args[1].type === "ArrayExpression");
          }
          return false;
        }
        module22.exports = {
          printCallExpression
        };
      }
    });
    var require_assignment = __commonJS22({
      "src/language-js/print/assignment.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray,
          getStringWidth
        } = require_util6();
        var {
          builders: {
            line,
            group,
            indent,
            indentIfBreak,
            lineSuffixBoundary
          },
          utils: {
            cleanDoc,
            willBreak,
            canBreak
          }
        } = require_doc();
        var {
          hasLeadingOwnLineComment,
          isBinaryish,
          isStringLiteral: isStringLiteral3,
          isLiteral,
          isNumericLiteral,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          getCallArguments,
          rawText,
          hasComment,
          isSignedNumericLiteral,
          isObjectProperty
        } = require_utils72();
        var {
          shouldInlineLogicalExpression
        } = require_binaryish();
        var {
          printCallExpression
        } = require_call_expression();
        function printAssignment(path2, options, print, leftDoc, operator, rightPropertyName) {
          const layout = chooseLayout(path2, options, print, leftDoc, rightPropertyName);
          const rightDoc = print(rightPropertyName, {
            assignmentLayout: layout
          });
          switch (layout) {
            case "break-after-operator":
              return group([group(leftDoc), operator, group(indent([line, rightDoc]))]);
            case "never-break-after-operator":
              return group([group(leftDoc), operator, " ", rightDoc]);
            case "fluid": {
              const groupId = Symbol("assignment");
              return group([group(leftDoc), operator, group(indent(line), {
                id: groupId
              }), lineSuffixBoundary, indentIfBreak(rightDoc, {
                groupId
              })]);
            }
            case "break-lhs":
              return group([leftDoc, operator, " ", group(rightDoc)]);
            case "chain":
              return [group(leftDoc), operator, line, rightDoc];
            case "chain-tail":
              return [group(leftDoc), operator, indent([line, rightDoc])];
            case "chain-tail-arrow-chain":
              return [group(leftDoc), operator, rightDoc];
            case "only-left":
              return leftDoc;
          }
        }
        function printAssignmentExpression(path2, options, print) {
          const node = path2.getValue();
          return printAssignment(path2, options, print, print("left"), [" ", node.operator], "right");
        }
        function printVariableDeclarator(path2, options, print) {
          return printAssignment(path2, options, print, print("id"), " =", "init");
        }
        function chooseLayout(path2, options, print, leftDoc, rightPropertyName) {
          const node = path2.getValue();
          const rightNode = node[rightPropertyName];
          if (!rightNode) {
            return "only-left";
          }
          const isTail = !isAssignment(rightNode);
          const shouldUseChainFormatting = path2.match(isAssignment, isAssignmentOrVariableDeclarator, (node2) => !isTail || node2.type !== "ExpressionStatement" && node2.type !== "VariableDeclaration");
          if (shouldUseChainFormatting) {
            return !isTail ? "chain" : rightNode.type === "ArrowFunctionExpression" && rightNode.body.type === "ArrowFunctionExpression" ? "chain-tail-arrow-chain" : "chain-tail";
          }
          const isHeadOfLongChain = !isTail && isAssignment(rightNode.right);
          if (isHeadOfLongChain || hasLeadingOwnLineComment(options.originalText, rightNode)) {
            return "break-after-operator";
          }
          if (rightNode.type === "CallExpression" && rightNode.callee.name === "require" || options.parser === "json5" || options.parser === "json") {
            return "never-break-after-operator";
          }
          if (isComplexDestructuring(node) || isComplexTypeAliasParams(node) || hasComplexTypeAnnotation(node) || isArrowFunctionVariableDeclarator(node) && canBreak(leftDoc)) {
            return "break-lhs";
          }
          const hasShortKey = isObjectPropertyWithShortKey(node, leftDoc, options);
          if (path2.call(() => shouldBreakAfterOperator(path2, options, print, hasShortKey), rightPropertyName)) {
            return "break-after-operator";
          }
          if (hasShortKey || rightNode.type === "TemplateLiteral" || rightNode.type === "TaggedTemplateExpression" || rightNode.type === "BooleanLiteral" || isNumericLiteral(rightNode) || rightNode.type === "ClassExpression") {
            return "never-break-after-operator";
          }
          return "fluid";
        }
        function shouldBreakAfterOperator(path2, options, print, hasShortKey) {
          const rightNode = path2.getValue();
          if (isBinaryish(rightNode) && !shouldInlineLogicalExpression(rightNode)) {
            return true;
          }
          switch (rightNode.type) {
            case "StringLiteralTypeAnnotation":
            case "SequenceExpression":
              return true;
            case "ConditionalExpression": {
              const {
                test
              } = rightNode;
              return isBinaryish(test) && !shouldInlineLogicalExpression(test);
            }
            case "ClassExpression":
              return isNonEmptyArray(rightNode.decorators);
          }
          if (hasShortKey) {
            return false;
          }
          let node = rightNode;
          const propertiesForPath = [];
          for (; ; ) {
            if (node.type === "UnaryExpression") {
              node = node.argument;
              propertiesForPath.push("argument");
            } else if (node.type === "TSNonNullExpression") {
              node = node.expression;
              propertiesForPath.push("expression");
            } else {
              break;
            }
          }
          if (isStringLiteral3(node) || path2.call(() => isPoorlyBreakableMemberOrCallChain(path2, options, print), ...propertiesForPath)) {
            return true;
          }
          return false;
        }
        function isComplexDestructuring(node) {
          if (isAssignmentOrVariableDeclarator(node)) {
            const leftNode = node.left || node.id;
            return leftNode.type === "ObjectPattern" && leftNode.properties.length > 2 && leftNode.properties.some((property) => isObjectProperty(property) && (!property.shorthand || property.value && property.value.type === "AssignmentPattern"));
          }
          return false;
        }
        function isAssignment(node) {
          return node.type === "AssignmentExpression";
        }
        function isAssignmentOrVariableDeclarator(node) {
          return isAssignment(node) || node.type === "VariableDeclarator";
        }
        function isComplexTypeAliasParams(node) {
          const typeParams = getTypeParametersFromTypeAlias(node);
          if (isNonEmptyArray(typeParams)) {
            const constraintPropertyName = node.type === "TSTypeAliasDeclaration" ? "constraint" : "bound";
            if (typeParams.length > 1 && typeParams.some((param) => param[constraintPropertyName] || param.default)) {
              return true;
            }
          }
          return false;
        }
        function getTypeParametersFromTypeAlias(node) {
          if (isTypeAlias(node) && node.typeParameters && node.typeParameters.params) {
            return node.typeParameters.params;
          }
          return null;
        }
        function isTypeAlias(node) {
          return node.type === "TSTypeAliasDeclaration" || node.type === "TypeAlias";
        }
        function hasComplexTypeAnnotation(node) {
          if (node.type !== "VariableDeclarator") {
            return false;
          }
          const {
            typeAnnotation
          } = node.id;
          if (!typeAnnotation || !typeAnnotation.typeAnnotation) {
            return false;
          }
          const typeParams = getTypeParametersFromTypeReference(typeAnnotation.typeAnnotation);
          return isNonEmptyArray(typeParams) && typeParams.length > 1 && typeParams.some((param) => isNonEmptyArray(getTypeParametersFromTypeReference(param)) || param.type === "TSConditionalType");
        }
        function isArrowFunctionVariableDeclarator(node) {
          return node.type === "VariableDeclarator" && node.init && node.init.type === "ArrowFunctionExpression";
        }
        function getTypeParametersFromTypeReference(node) {
          if (isTypeReference(node) && node.typeParameters && node.typeParameters.params) {
            return node.typeParameters.params;
          }
          return null;
        }
        function isTypeReference(node) {
          return node.type === "TSTypeReference" || node.type === "GenericTypeAnnotation";
        }
        function isPoorlyBreakableMemberOrCallChain(path2, options, print, deep = false) {
          const node = path2.getValue();
          const goDeeper = () => isPoorlyBreakableMemberOrCallChain(path2, options, print, true);
          if (node.type === "TSNonNullExpression") {
            return path2.call(goDeeper, "expression");
          }
          if (isCallExpression2(node)) {
            const doc2 = printCallExpression(path2, options, print);
            if (doc2.label === "member-chain") {
              return false;
            }
            const args = getCallArguments(node);
            const isPoorlyBreakableCall = args.length === 0 || args.length === 1 && isLoneShortArgument(args[0], options);
            if (!isPoorlyBreakableCall) {
              return false;
            }
            if (isCallExpressionWithComplexTypeArguments(node, print)) {
              return false;
            }
            return path2.call(goDeeper, "callee");
          }
          if (isMemberExpression(node)) {
            return path2.call(goDeeper, "object");
          }
          return deep && (node.type === "Identifier" || node.type === "ThisExpression");
        }
        var LONE_SHORT_ARGUMENT_THRESHOLD_RATE = 0.25;
        function isLoneShortArgument(node, {
          printWidth
        }) {
          if (hasComment(node)) {
            return false;
          }
          const threshold = printWidth * LONE_SHORT_ARGUMENT_THRESHOLD_RATE;
          if (node.type === "ThisExpression" || node.type === "Identifier" && node.name.length <= threshold || isSignedNumericLiteral(node) && !hasComment(node.argument)) {
            return true;
          }
          const regexpPattern = node.type === "Literal" && "regex" in node && node.regex.pattern || node.type === "RegExpLiteral" && node.pattern;
          if (regexpPattern) {
            return regexpPattern.length <= threshold;
          }
          if (isStringLiteral3(node)) {
            return rawText(node).length <= threshold;
          }
          if (node.type === "TemplateLiteral") {
            return node.expressions.length === 0 && node.quasis[0].value.raw.length <= threshold && !node.quasis[0].value.raw.includes("\n");
          }
          return isLiteral(node);
        }
        function isObjectPropertyWithShortKey(node, keyDoc, options) {
          if (!isObjectProperty(node)) {
            return false;
          }
          keyDoc = cleanDoc(keyDoc);
          const MIN_OVERLAP_FOR_BREAK = 3;
          return typeof keyDoc === "string" && getStringWidth(keyDoc) < options.tabWidth + MIN_OVERLAP_FOR_BREAK;
        }
        function isCallExpressionWithComplexTypeArguments(node, print) {
          const typeArgs = getTypeArgumentsFromCallExpression(node);
          if (isNonEmptyArray(typeArgs)) {
            if (typeArgs.length > 1) {
              return true;
            }
            if (typeArgs.length === 1) {
              const firstArg = typeArgs[0];
              if (firstArg.type === "TSUnionType" || firstArg.type === "UnionTypeAnnotation" || firstArg.type === "TSIntersectionType" || firstArg.type === "IntersectionTypeAnnotation" || firstArg.type === "TSTypeLiteral" || firstArg.type === "ObjectTypeAnnotation") {
                return true;
              }
            }
            const typeArgsKeyName = node.typeParameters ? "typeParameters" : "typeArguments";
            if (willBreak(print(typeArgsKeyName))) {
              return true;
            }
          }
          return false;
        }
        function getTypeArgumentsFromCallExpression(node) {
          return node.typeParameters && node.typeParameters.params || node.typeArguments && node.typeArguments.params;
        }
        module22.exports = {
          printVariableDeclarator,
          printAssignmentExpression,
          printAssignment,
          isArrowFunctionVariableDeclarator
        };
      }
    });
    var require_function_parameters = __commonJS22({
      "src/language-js/print/function-parameters.js"(exports2, module22) {
        "use strict";
        var {
          getNextNonSpaceNonCommentCharacter
        } = require_util6();
        var {
          printDanglingComments
        } = require_comments2();
        var {
          builders: {
            line,
            hardline,
            softline,
            group,
            indent,
            ifBreak
          },
          utils: {
            removeLines,
            willBreak
          }
        } = require_doc();
        var {
          getFunctionParameters,
          iterateFunctionParametersPath,
          isSimpleType,
          isTestCall,
          isTypeAnnotationAFunction,
          isObjectType,
          isObjectTypePropertyAFunction,
          hasRestParameter,
          shouldPrintComma,
          hasComment,
          isNextLineEmpty
        } = require_utils72();
        var {
          locEnd
        } = require_loc();
        var {
          ArgExpansionBailout
        } = require_errors2();
        var {
          printFunctionTypeParameters
        } = require_misc3();
        function printFunctionParameters(path2, print, options, expandArg, printTypeParams) {
          const functionNode = path2.getValue();
          const parameters = getFunctionParameters(functionNode);
          const typeParams = printTypeParams ? printFunctionTypeParameters(path2, options, print) : "";
          if (parameters.length === 0) {
            return [typeParams, "(", printDanglingComments(path2, options, true, (comment) => getNextNonSpaceNonCommentCharacter(options.originalText, comment, locEnd) === ")"), ")"];
          }
          const parent = path2.getParentNode();
          const isParametersInTestCall = isTestCall(parent);
          const shouldHugParameters = shouldHugFunctionParameters(functionNode);
          const printed = [];
          iterateFunctionParametersPath(path2, (parameterPath, index) => {
            const isLastParameter = index === parameters.length - 1;
            if (isLastParameter && functionNode.rest) {
              printed.push("...");
            }
            printed.push(print());
            if (isLastParameter) {
              return;
            }
            printed.push(",");
            if (isParametersInTestCall || shouldHugParameters) {
              printed.push(" ");
            } else if (isNextLineEmpty(parameters[index], options)) {
              printed.push(hardline, hardline);
            } else {
              printed.push(line);
            }
          });
          if (expandArg) {
            if (willBreak(typeParams) || willBreak(printed)) {
              throw new ArgExpansionBailout();
            }
            return group([removeLines(typeParams), "(", removeLines(printed), ")"]);
          }
          const hasNotParameterDecorator = parameters.every((node) => !node.decorators);
          if (shouldHugParameters && hasNotParameterDecorator) {
            return [typeParams, "(", ...printed, ")"];
          }
          if (isParametersInTestCall) {
            return [typeParams, "(", ...printed, ")"];
          }
          const isFlowShorthandWithOneArg = (isObjectTypePropertyAFunction(parent) || isTypeAnnotationAFunction(parent) || parent.type === "TypeAlias" || parent.type === "UnionTypeAnnotation" || parent.type === "TSUnionType" || parent.type === "IntersectionTypeAnnotation" || parent.type === "FunctionTypeAnnotation" && parent.returnType === functionNode) && parameters.length === 1 && parameters[0].name === null && functionNode.this !== parameters[0] && parameters[0].typeAnnotation && functionNode.typeParameters === null && isSimpleType(parameters[0].typeAnnotation) && !functionNode.rest;
          if (isFlowShorthandWithOneArg) {
            if (options.arrowParens === "always") {
              return ["(", ...printed, ")"];
            }
            return printed;
          }
          return [typeParams, "(", indent([softline, ...printed]), ifBreak(!hasRestParameter(functionNode) && shouldPrintComma(options, "all") ? "," : ""), softline, ")"];
        }
        function shouldHugFunctionParameters(node) {
          if (!node) {
            return false;
          }
          const parameters = getFunctionParameters(node);
          if (parameters.length !== 1) {
            return false;
          }
          const [parameter] = parameters;
          return !hasComment(parameter) && (parameter.type === "ObjectPattern" || parameter.type === "ArrayPattern" || parameter.type === "Identifier" && parameter.typeAnnotation && (parameter.typeAnnotation.type === "TypeAnnotation" || parameter.typeAnnotation.type === "TSTypeAnnotation") && isObjectType(parameter.typeAnnotation.typeAnnotation) || parameter.type === "FunctionTypeParam" && isObjectType(parameter.typeAnnotation) || parameter.type === "AssignmentPattern" && (parameter.left.type === "ObjectPattern" || parameter.left.type === "ArrayPattern") && (parameter.right.type === "Identifier" || parameter.right.type === "ObjectExpression" && parameter.right.properties.length === 0 || parameter.right.type === "ArrayExpression" && parameter.right.elements.length === 0));
        }
        function getReturnTypeNode(functionNode) {
          let returnTypeNode;
          if (functionNode.returnType) {
            returnTypeNode = functionNode.returnType;
            if (returnTypeNode.typeAnnotation) {
              returnTypeNode = returnTypeNode.typeAnnotation;
            }
          } else if (functionNode.typeAnnotation) {
            returnTypeNode = functionNode.typeAnnotation;
          }
          return returnTypeNode;
        }
        function shouldGroupFunctionParameters(functionNode, returnTypeDoc) {
          const returnTypeNode = getReturnTypeNode(functionNode);
          if (!returnTypeNode) {
            return false;
          }
          const typeParameters = functionNode.typeParameters && functionNode.typeParameters.params;
          if (typeParameters) {
            if (typeParameters.length > 1) {
              return false;
            }
            if (typeParameters.length === 1) {
              const typeParameter = typeParameters[0];
              if (typeParameter.constraint || typeParameter.default) {
                return false;
              }
            }
          }
          return getFunctionParameters(functionNode).length === 1 && (isObjectType(returnTypeNode) || willBreak(returnTypeDoc));
        }
        module22.exports = {
          printFunctionParameters,
          shouldHugFunctionParameters,
          shouldGroupFunctionParameters
        };
      }
    });
    var require_type_annotation = __commonJS22({
      "src/language-js/print/type-annotation.js"(exports2, module22) {
        "use strict";
        var {
          printComments,
          printDanglingComments
        } = require_comments2();
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            group,
            join,
            line,
            softline,
            indent,
            align,
            ifBreak
          }
        } = require_doc();
        var pathNeedsParens = require_needs_parens();
        var {
          locStart
        } = require_loc();
        var {
          isSimpleType,
          isObjectType,
          hasLeadingOwnLineComment,
          isObjectTypePropertyAFunction,
          shouldPrintComma
        } = require_utils72();
        var {
          printAssignment
        } = require_assignment();
        var {
          printFunctionParameters,
          shouldGroupFunctionParameters
        } = require_function_parameters();
        var {
          printArrayItems
        } = require_array4();
        function shouldHugType(node) {
          if (isSimpleType(node) || isObjectType(node)) {
            return true;
          }
          if (node.type === "UnionTypeAnnotation" || node.type === "TSUnionType") {
            const voidCount = node.types.filter((node2) => node2.type === "VoidTypeAnnotation" || node2.type === "TSVoidKeyword" || node2.type === "NullLiteralTypeAnnotation" || node2.type === "TSNullKeyword").length;
            const hasObject = node.types.some((node2) => node2.type === "ObjectTypeAnnotation" || node2.type === "TSTypeLiteral" || node2.type === "GenericTypeAnnotation" || node2.type === "TSTypeReference");
            if (node.types.length - 1 === voidCount && hasObject) {
              return true;
            }
          }
          return false;
        }
        function printOpaqueType(path2, options, print) {
          const semi = options.semi ? ";" : "";
          const node = path2.getValue();
          const parts = [];
          parts.push("opaque type ", print("id"), print("typeParameters"));
          if (node.supertype) {
            parts.push(": ", print("supertype"));
          }
          if (node.impltype) {
            parts.push(" = ", print("impltype"));
          }
          parts.push(semi);
          return parts;
        }
        function printTypeAlias(path2, options, print) {
          const semi = options.semi ? ";" : "";
          const node = path2.getValue();
          const parts = [];
          if (node.declare) {
            parts.push("declare ");
          }
          parts.push("type ", print("id"), print("typeParameters"));
          const rightPropertyName = node.type === "TSTypeAliasDeclaration" ? "typeAnnotation" : "right";
          return [printAssignment(path2, options, print, parts, " =", rightPropertyName), semi];
        }
        function printIntersectionType(path2, options, print) {
          const node = path2.getValue();
          const types = path2.map(print, "types");
          const result = [];
          let wasIndented = false;
          for (let i = 0; i < types.length; ++i) {
            if (i === 0) {
              result.push(types[i]);
            } else if (isObjectType(node.types[i - 1]) && isObjectType(node.types[i])) {
              result.push([" & ", wasIndented ? indent(types[i]) : types[i]]);
            } else if (!isObjectType(node.types[i - 1]) && !isObjectType(node.types[i])) {
              result.push(indent([" &", line, types[i]]));
            } else {
              if (i > 1) {
                wasIndented = true;
              }
              result.push(" & ", i > 1 ? indent(types[i]) : types[i]);
            }
          }
          return group(result);
        }
        function printUnionType(path2, options, print) {
          const node = path2.getValue();
          const parent = path2.getParentNode();
          const shouldIndent = parent.type !== "TypeParameterInstantiation" && parent.type !== "TSTypeParameterInstantiation" && parent.type !== "GenericTypeAnnotation" && parent.type !== "TSTypeReference" && parent.type !== "TSTypeAssertion" && parent.type !== "TupleTypeAnnotation" && parent.type !== "TSTupleType" && !(parent.type === "FunctionTypeParam" && !parent.name && path2.getParentNode(1).this !== parent) && !((parent.type === "TypeAlias" || parent.type === "VariableDeclarator" || parent.type === "TSTypeAliasDeclaration") && hasLeadingOwnLineComment(options.originalText, node));
          const shouldHug = shouldHugType(node);
          const printed = path2.map((typePath) => {
            let printedType = print();
            if (!shouldHug) {
              printedType = align(2, printedType);
            }
            return printComments(typePath, printedType, options);
          }, "types");
          if (shouldHug) {
            return join(" | ", printed);
          }
          const shouldAddStartLine = shouldIndent && !hasLeadingOwnLineComment(options.originalText, node);
          const code = [ifBreak([shouldAddStartLine ? line : "", "| "]), join([line, "| "], printed)];
          if (pathNeedsParens(path2, options)) {
            return group([indent(code), softline]);
          }
          if (parent.type === "TupleTypeAnnotation" && parent.types.length > 1 || parent.type === "TSTupleType" && parent.elementTypes.length > 1) {
            return group([indent([ifBreak(["(", softline]), code]), softline, ifBreak(")")]);
          }
          return group(shouldIndent ? indent(code) : code);
        }
        function printFunctionType(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          const parent = path2.getParentNode(0);
          const parentParent = path2.getParentNode(1);
          const parentParentParent = path2.getParentNode(2);
          let isArrowFunctionTypeAnnotation = node.type === "TSFunctionType" || !((parent.type === "ObjectTypeProperty" || parent.type === "ObjectTypeInternalSlot") && !parent.variance && !parent.optional && locStart(parent) === locStart(node) || parent.type === "ObjectTypeCallProperty" || parentParentParent && parentParentParent.type === "DeclareFunction");
          let needsColon = isArrowFunctionTypeAnnotation && (parent.type === "TypeAnnotation" || parent.type === "TSTypeAnnotation");
          const needsParens = needsColon && isArrowFunctionTypeAnnotation && (parent.type === "TypeAnnotation" || parent.type === "TSTypeAnnotation") && parentParent.type === "ArrowFunctionExpression";
          if (isObjectTypePropertyAFunction(parent)) {
            isArrowFunctionTypeAnnotation = true;
            needsColon = true;
          }
          if (needsParens) {
            parts.push("(");
          }
          const parametersDoc = printFunctionParameters(path2, print, options, false, true);
          const returnTypeDoc = node.returnType || node.predicate || node.typeAnnotation ? [isArrowFunctionTypeAnnotation ? " => " : ": ", print("returnType"), print("predicate"), print("typeAnnotation")] : "";
          const shouldGroupParameters = shouldGroupFunctionParameters(node, returnTypeDoc);
          parts.push(shouldGroupParameters ? group(parametersDoc) : parametersDoc);
          if (returnTypeDoc) {
            parts.push(returnTypeDoc);
          }
          if (needsParens) {
            parts.push(")");
          }
          return group(parts);
        }
        function printTupleType(path2, options, print) {
          const node = path2.getValue();
          const typesField = node.type === "TSTupleType" ? "elementTypes" : "types";
          const types = node[typesField];
          const isNonEmptyTuple = isNonEmptyArray(types);
          const bracketsDelimiterLine = isNonEmptyTuple ? softline : "";
          return group(["[", indent([bracketsDelimiterLine, printArrayItems(path2, options, typesField, print)]), ifBreak(isNonEmptyTuple && shouldPrintComma(options, "all") ? "," : ""), printDanglingComments(path2, options, true), bracketsDelimiterLine, "]"]);
        }
        function printIndexedAccessType(path2, options, print) {
          const node = path2.getValue();
          const leftDelimiter = node.type === "OptionalIndexedAccessType" && node.optional ? "?.[" : "[";
          return [print("objectType"), leftDelimiter, print("indexType"), "]"];
        }
        function printJSDocType(path2, print, token) {
          const node = path2.getValue();
          return [node.postfix ? "" : token, print("typeAnnotation"), node.postfix ? token : ""];
        }
        module22.exports = {
          printOpaqueType,
          printTypeAlias,
          printIntersectionType,
          printUnionType,
          printFunctionType,
          printTupleType,
          printIndexedAccessType,
          shouldHugType,
          printJSDocType
        };
      }
    });
    var require_type_parameters = __commonJS22({
      "src/language-js/print/type-parameters.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          builders: {
            join,
            line,
            hardline,
            softline,
            group,
            indent,
            ifBreak
          }
        } = require_doc();
        var {
          isTestCall,
          hasComment,
          CommentCheckFlags,
          isTSXFile,
          shouldPrintComma,
          getFunctionParameters,
          isObjectType
        } = require_utils72();
        var {
          createGroupIdMapper
        } = require_util6();
        var {
          shouldHugType
        } = require_type_annotation();
        var {
          isArrowFunctionVariableDeclarator
        } = require_assignment();
        var getTypeParametersGroupId = createGroupIdMapper("typeParameters");
        function printTypeParameters(path2, options, print, paramsKey) {
          const node = path2.getValue();
          if (!node[paramsKey]) {
            return "";
          }
          if (!Array.isArray(node[paramsKey])) {
            return print(paramsKey);
          }
          const grandparent = path2.getNode(2);
          const isParameterInTestCall = grandparent && isTestCall(grandparent);
          const isArrowFunctionVariable = path2.match((node2) => !(node2[paramsKey].length === 1 && isObjectType(node2[paramsKey][0])), void 0, (node2, name) => name === "typeAnnotation", (node2) => node2.type === "Identifier", isArrowFunctionVariableDeclarator);
          const shouldInline = node[paramsKey].length === 0 || !isArrowFunctionVariable && (isParameterInTestCall || node[paramsKey].length === 1 && (node[paramsKey][0].type === "NullableTypeAnnotation" || shouldHugType(node[paramsKey][0])));
          if (shouldInline) {
            return ["<", join(", ", path2.map(print, paramsKey)), printDanglingCommentsForInline(path2, options), ">"];
          }
          const trailingComma = node.type === "TSTypeParameterInstantiation" ? "" : getFunctionParameters(node).length === 1 && isTSXFile(options) && !node[paramsKey][0].constraint && path2.getParentNode().type === "ArrowFunctionExpression" ? "," : shouldPrintComma(options, "all") ? ifBreak(",") : "";
          return group(["<", indent([softline, join([",", line], path2.map(print, paramsKey))]), trailingComma, softline, ">"], {
            id: getTypeParametersGroupId(node)
          });
        }
        function printDanglingCommentsForInline(path2, options) {
          const node = path2.getValue();
          if (!hasComment(node, CommentCheckFlags.Dangling)) {
            return "";
          }
          const hasOnlyBlockComments = !hasComment(node, CommentCheckFlags.Line);
          const printed = printDanglingComments(path2, options, hasOnlyBlockComments);
          if (hasOnlyBlockComments) {
            return printed;
          }
          return [printed, hardline];
        }
        function printTypeParameter(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          const parent = path2.getParentNode();
          if (parent.type === "TSMappedType") {
            parts.push("[", print("name"));
            if (node.constraint) {
              parts.push(" in ", print("constraint"));
            }
            if (parent.nameType) {
              parts.push(" as ", path2.callParent(() => print("nameType")));
            }
            parts.push("]");
            return parts;
          }
          if (node.variance) {
            parts.push(print("variance"));
          }
          if (node.in) {
            parts.push("in ");
          }
          if (node.out) {
            parts.push("out ");
          }
          parts.push(print("name"));
          if (node.bound) {
            parts.push(": ", print("bound"));
          }
          if (node.constraint) {
            parts.push(" extends ", print("constraint"));
          }
          if (node.default) {
            parts.push(" = ", print("default"));
          }
          return parts;
        }
        module22.exports = {
          printTypeParameter,
          printTypeParameters,
          getTypeParametersGroupId
        };
      }
    });
    var require_property2 = __commonJS22({
      "src/language-js/print/property.js"(exports2, module22) {
        "use strict";
        var {
          printComments
        } = require_comments2();
        var {
          printString,
          printNumber
        } = require_util6();
        var {
          isNumericLiteral,
          isSimpleNumber,
          isStringLiteral: isStringLiteral3,
          isStringPropSafeToUnquote,
          rawText
        } = require_utils72();
        var {
          printAssignment
        } = require_assignment();
        var needsQuoteProps = /* @__PURE__ */ new WeakMap();
        function printPropertyKey(path2, options, print) {
          const node = path2.getNode();
          if (node.computed) {
            return ["[", print("key"), "]"];
          }
          const parent = path2.getParentNode();
          const {
            key
          } = node;
          if (options.quoteProps === "consistent" && !needsQuoteProps.has(parent)) {
            const objectHasStringProp = (parent.properties || parent.body || parent.members).some((prop) => !prop.computed && prop.key && isStringLiteral3(prop.key) && !isStringPropSafeToUnquote(prop, options));
            needsQuoteProps.set(parent, objectHasStringProp);
          }
          if ((key.type === "Identifier" || isNumericLiteral(key) && isSimpleNumber(printNumber(rawText(key))) && String(key.value) === printNumber(rawText(key)) && !(options.parser === "typescript" || options.parser === "babel-ts")) && (options.parser === "json" || options.quoteProps === "consistent" && needsQuoteProps.get(parent))) {
            const prop = printString(JSON.stringify(key.type === "Identifier" ? key.name : key.value.toString()), options);
            return path2.call((keyPath) => printComments(keyPath, prop, options), "key");
          }
          if (isStringPropSafeToUnquote(node, options) && (options.quoteProps === "as-needed" || options.quoteProps === "consistent" && !needsQuoteProps.get(parent))) {
            return path2.call((keyPath) => printComments(keyPath, /^\d/.test(key.value) ? printNumber(key.value) : key.value, options), "key");
          }
          return print("key");
        }
        function printProperty(path2, options, print) {
          const node = path2.getValue();
          if (node.shorthand) {
            return print("value");
          }
          return printAssignment(path2, options, print, printPropertyKey(path2, options, print), ":", "value");
        }
        module22.exports = {
          printProperty,
          printPropertyKey
        };
      }
    });
    var require_function = __commonJS22({
      "src/language-js/print/function.js"(exports2, module22) {
        "use strict";
        var assert = require("assert");
        var {
          printDanglingComments,
          printCommentsSeparately
        } = require_comments2();
        var getLast = require_get_last();
        var {
          getNextNonSpaceNonCommentCharacterIndex
        } = require_util6();
        var {
          builders: {
            line,
            softline,
            group,
            indent,
            ifBreak,
            hardline,
            join,
            indentIfBreak
          },
          utils: {
            removeLines,
            willBreak
          }
        } = require_doc();
        var {
          ArgExpansionBailout
        } = require_errors2();
        var {
          getFunctionParameters,
          hasLeadingOwnLineComment,
          isFlowAnnotationComment,
          isJsxNode,
          isTemplateOnItsOwnLine,
          shouldPrintComma,
          startsWithNoLookaheadToken,
          isBinaryish,
          isLineComment,
          hasComment,
          getComments,
          CommentCheckFlags,
          isCallLikeExpression,
          isCallExpression: isCallExpression2,
          getCallArguments,
          hasNakedLeftSide,
          getLeftSide
        } = require_utils72();
        var {
          locEnd
        } = require_loc();
        var {
          printFunctionParameters,
          shouldGroupFunctionParameters
        } = require_function_parameters();
        var {
          printPropertyKey
        } = require_property2();
        var {
          printFunctionTypeParameters
        } = require_misc3();
        function printFunction(path2, print, options, args) {
          const node = path2.getValue();
          let expandArg = false;
          if ((node.type === "FunctionDeclaration" || node.type === "FunctionExpression") && args && args.expandLastArg) {
            const parent = path2.getParentNode();
            if (isCallExpression2(parent) && getCallArguments(parent).length > 1) {
              expandArg = true;
            }
          }
          const parts = [];
          if (node.type === "TSDeclareFunction" && node.declare) {
            parts.push("declare ");
          }
          if (node.async) {
            parts.push("async ");
          }
          if (node.generator) {
            parts.push("function* ");
          } else {
            parts.push("function ");
          }
          if (node.id) {
            parts.push(print("id"));
          }
          const parametersDoc = printFunctionParameters(path2, print, options, expandArg);
          const returnTypeDoc = printReturnType(path2, print, options);
          const shouldGroupParameters = shouldGroupFunctionParameters(node, returnTypeDoc);
          parts.push(printFunctionTypeParameters(path2, options, print), group([shouldGroupParameters ? group(parametersDoc) : parametersDoc, returnTypeDoc]), node.body ? " " : "", print("body"));
          if (options.semi && (node.declare || !node.body)) {
            parts.push(";");
          }
          return parts;
        }
        function printMethod(path2, options, print) {
          const node = path2.getNode();
          const {
            kind
          } = node;
          const value2 = node.value || node;
          const parts = [];
          if (!kind || kind === "init" || kind === "method" || kind === "constructor") {
            if (value2.async) {
              parts.push("async ");
            }
          } else {
            assert.ok(kind === "get" || kind === "set");
            parts.push(kind, " ");
          }
          if (value2.generator) {
            parts.push("*");
          }
          parts.push(printPropertyKey(path2, options, print), node.optional || node.key.optional ? "?" : "");
          if (node === value2) {
            parts.push(printMethodInternal(path2, options, print));
          } else if (value2.type === "FunctionExpression") {
            parts.push(path2.call((path22) => printMethodInternal(path22, options, print), "value"));
          } else {
            parts.push(print("value"));
          }
          return parts;
        }
        function printMethodInternal(path2, options, print) {
          const node = path2.getNode();
          const parametersDoc = printFunctionParameters(path2, print, options);
          const returnTypeDoc = printReturnType(path2, print, options);
          const shouldGroupParameters = shouldGroupFunctionParameters(node, returnTypeDoc);
          const parts = [printFunctionTypeParameters(path2, options, print), group([shouldGroupParameters ? group(parametersDoc) : parametersDoc, returnTypeDoc])];
          if (node.body) {
            parts.push(" ", print("body"));
          } else {
            parts.push(options.semi ? ";" : "");
          }
          return parts;
        }
        function printArrowFunctionSignature(path2, options, print, args) {
          const node = path2.getValue();
          const parts = [];
          if (node.async) {
            parts.push("async ");
          }
          if (shouldPrintParamsWithoutParens(path2, options)) {
            parts.push(print(["params", 0]));
          } else {
            const expandArg = args && (args.expandLastArg || args.expandFirstArg);
            let returnTypeDoc = printReturnType(path2, print, options);
            if (expandArg) {
              if (willBreak(returnTypeDoc)) {
                throw new ArgExpansionBailout();
              }
              returnTypeDoc = group(removeLines(returnTypeDoc));
            }
            parts.push(group([printFunctionParameters(path2, print, options, expandArg, true), returnTypeDoc]));
          }
          const dangling = printDanglingComments(path2, options, true, (comment) => {
            const nextCharacter = getNextNonSpaceNonCommentCharacterIndex(options.originalText, comment, locEnd);
            return nextCharacter !== false && options.originalText.slice(nextCharacter, nextCharacter + 2) === "=>";
          });
          if (dangling) {
            parts.push(" ", dangling);
          }
          return parts;
        }
        function printArrowChain(path2, args, signatures, shouldBreak, bodyDoc, tailNode) {
          const name = path2.getName();
          const parent = path2.getParentNode();
          const isCallee = isCallLikeExpression(parent) && name === "callee";
          const isAssignmentRhs = Boolean(args && args.assignmentLayout);
          const shouldPutBodyOnSeparateLine = tailNode.body.type !== "BlockStatement" && tailNode.body.type !== "ObjectExpression" && tailNode.body.type !== "SequenceExpression";
          const shouldBreakBeforeChain = isCallee && shouldPutBodyOnSeparateLine || args && args.assignmentLayout === "chain-tail-arrow-chain";
          const groupId = Symbol("arrow-chain");
          if (tailNode.body.type === "SequenceExpression") {
            bodyDoc = group(["(", indent([softline, bodyDoc]), softline, ")"]);
          }
          return group([group(indent([isCallee || isAssignmentRhs ? softline : "", group(join([" =>", line], signatures), {
            shouldBreak
          })]), {
            id: groupId,
            shouldBreak: shouldBreakBeforeChain
          }), " =>", indentIfBreak(shouldPutBodyOnSeparateLine ? indent([line, bodyDoc]) : [" ", bodyDoc], {
            groupId
          }), isCallee ? ifBreak(softline, "", {
            groupId
          }) : ""]);
        }
        function printArrowFunction(path2, options, print, args) {
          let node = path2.getValue();
          const signatures = [];
          const body = [];
          let chainShouldBreak = false;
          (function rec() {
            const doc2 = printArrowFunctionSignature(path2, options, print, args);
            if (signatures.length === 0) {
              signatures.push(doc2);
            } else {
              const {
                leading,
                trailing
              } = printCommentsSeparately(path2, options);
              signatures.push([leading, doc2]);
              body.unshift(trailing);
            }
            chainShouldBreak = chainShouldBreak || node.returnType && getFunctionParameters(node).length > 0 || node.typeParameters || getFunctionParameters(node).some((param) => param.type !== "Identifier");
            if (node.body.type !== "ArrowFunctionExpression" || args && args.expandLastArg) {
              body.unshift(print("body", args));
            } else {
              node = node.body;
              path2.call(rec, "body");
            }
          })();
          if (signatures.length > 1) {
            return printArrowChain(path2, args, signatures, chainShouldBreak, body, node);
          }
          const parts = signatures;
          parts.push(" =>");
          if (!hasLeadingOwnLineComment(options.originalText, node.body) && (node.body.type === "ArrayExpression" || node.body.type === "ObjectExpression" || node.body.type === "BlockStatement" || isJsxNode(node.body) || isTemplateOnItsOwnLine(node.body, options.originalText) || node.body.type === "ArrowFunctionExpression" || node.body.type === "DoExpression")) {
            return group([...parts, " ", body]);
          }
          if (node.body.type === "SequenceExpression") {
            return group([...parts, group([" (", indent([softline, body]), softline, ")"])]);
          }
          const shouldAddSoftLine = (args && args.expandLastArg || path2.getParentNode().type === "JSXExpressionContainer") && !hasComment(node);
          const printTrailingComma = args && args.expandLastArg && shouldPrintComma(options, "all");
          const shouldAddParens = node.body.type === "ConditionalExpression" && !startsWithNoLookaheadToken(node.body, (node2) => node2.type === "ObjectExpression");
          return group([...parts, group([indent([line, shouldAddParens ? ifBreak("", "(") : "", body, shouldAddParens ? ifBreak("", ")") : ""]), shouldAddSoftLine ? [ifBreak(printTrailingComma ? "," : ""), softline] : ""])]);
        }
        function canPrintParamsWithoutParens(node) {
          const parameters = getFunctionParameters(node);
          return parameters.length === 1 && !node.typeParameters && !hasComment(node, CommentCheckFlags.Dangling) && parameters[0].type === "Identifier" && !parameters[0].typeAnnotation && !hasComment(parameters[0]) && !parameters[0].optional && !node.predicate && !node.returnType;
        }
        function shouldPrintParamsWithoutParens(path2, options) {
          if (options.arrowParens === "always") {
            return false;
          }
          if (options.arrowParens === "avoid") {
            const node = path2.getValue();
            return canPrintParamsWithoutParens(node);
          }
          return false;
        }
        function printReturnType(path2, print, options) {
          const node = path2.getValue();
          const returnType = print("returnType");
          if (node.returnType && isFlowAnnotationComment(options.originalText, node.returnType)) {
            return [" /*: ", returnType, " */"];
          }
          const parts = [returnType];
          if (node.returnType && node.returnType.typeAnnotation) {
            parts.unshift(": ");
          }
          if (node.predicate) {
            parts.push(node.returnType ? " " : ": ", print("predicate"));
          }
          return parts;
        }
        function printReturnOrThrowArgument(path2, options, print) {
          const node = path2.getValue();
          const semi = options.semi ? ";" : "";
          const parts = [];
          if (node.argument) {
            if (returnArgumentHasLeadingComment(options, node.argument)) {
              parts.push([" (", indent([hardline, print("argument")]), hardline, ")"]);
            } else if (isBinaryish(node.argument) || node.argument.type === "SequenceExpression") {
              parts.push(group([ifBreak(" (", " "), indent([softline, print("argument")]), softline, ifBreak(")")]));
            } else {
              parts.push(" ", print("argument"));
            }
          }
          const comments = getComments(node);
          const lastComment = getLast(comments);
          const isLastCommentLine = lastComment && isLineComment(lastComment);
          if (isLastCommentLine) {
            parts.push(semi);
          }
          if (hasComment(node, CommentCheckFlags.Dangling)) {
            parts.push(" ", printDanglingComments(path2, options, true));
          }
          if (!isLastCommentLine) {
            parts.push(semi);
          }
          return parts;
        }
        function printReturnStatement(path2, options, print) {
          return ["return", printReturnOrThrowArgument(path2, options, print)];
        }
        function printThrowStatement(path2, options, print) {
          return ["throw", printReturnOrThrowArgument(path2, options, print)];
        }
        function returnArgumentHasLeadingComment(options, argument) {
          if (hasLeadingOwnLineComment(options.originalText, argument)) {
            return true;
          }
          if (hasNakedLeftSide(argument)) {
            let leftMost = argument;
            let newLeftMost;
            while (newLeftMost = getLeftSide(leftMost)) {
              leftMost = newLeftMost;
              if (hasLeadingOwnLineComment(options.originalText, leftMost)) {
                return true;
              }
            }
          }
          return false;
        }
        module22.exports = {
          printFunction,
          printArrowFunction,
          printMethod,
          printReturnStatement,
          printThrowStatement,
          printMethodInternal,
          shouldPrintParamsWithoutParens
        };
      }
    });
    var require_decorators = __commonJS22({
      "src/language-js/print/decorators.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray,
          hasNewline
        } = require_util6();
        var {
          builders: {
            line,
            hardline,
            join,
            breakParent,
            group
          }
        } = require_doc();
        var {
          locStart,
          locEnd
        } = require_loc();
        var {
          getParentExportDeclaration
        } = require_utils72();
        function printClassMemberDecorators(path2, options, print) {
          const node = path2.getValue();
          return group([join(line, path2.map(print, "decorators")), hasNewlineBetweenOrAfterDecorators(node, options) ? hardline : line]);
        }
        function printDecoratorsBeforeExport(path2, options, print) {
          return [join(hardline, path2.map(print, "declaration", "decorators")), hardline];
        }
        function printDecorators(path2, options, print) {
          const node = path2.getValue();
          const {
            decorators
          } = node;
          if (!isNonEmptyArray(decorators) || hasDecoratorsBeforeExport(path2.getParentNode())) {
            return;
          }
          const shouldBreak = node.type === "ClassExpression" || node.type === "ClassDeclaration" || hasNewlineBetweenOrAfterDecorators(node, options);
          return [getParentExportDeclaration(path2) ? hardline : shouldBreak ? breakParent : "", join(line, path2.map(print, "decorators")), line];
        }
        function hasNewlineBetweenOrAfterDecorators(node, options) {
          return node.decorators.some((decorator) => hasNewline(options.originalText, locEnd(decorator)));
        }
        function hasDecoratorsBeforeExport(node) {
          if (node.type !== "ExportDefaultDeclaration" && node.type !== "ExportNamedDeclaration" && node.type !== "DeclareExportDeclaration") {
            return false;
          }
          const decorators = node.declaration && node.declaration.decorators;
          return isNonEmptyArray(decorators) && locStart(node) === locStart(decorators[0]);
        }
        module22.exports = {
          printDecorators,
          printClassMemberDecorators,
          printDecoratorsBeforeExport,
          hasDecoratorsBeforeExport
        };
      }
    });
    var require_class = __commonJS22({
      "src/language-js/print/class.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray,
          createGroupIdMapper
        } = require_util6();
        var {
          printComments,
          printDanglingComments
        } = require_comments2();
        var {
          builders: {
            join,
            line,
            hardline,
            softline,
            group,
            indent,
            ifBreak
          }
        } = require_doc();
        var {
          hasComment,
          CommentCheckFlags
        } = require_utils72();
        var {
          getTypeParametersGroupId
        } = require_type_parameters();
        var {
          printMethod
        } = require_function();
        var {
          printOptionalToken,
          printTypeAnnotation,
          printDefiniteToken
        } = require_misc3();
        var {
          printPropertyKey
        } = require_property2();
        var {
          printAssignment
        } = require_assignment();
        var {
          printClassMemberDecorators
        } = require_decorators();
        function printClass(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (node.declare) {
            parts.push("declare ");
          }
          if (node.abstract) {
            parts.push("abstract ");
          }
          parts.push("class");
          const groupMode = node.id && hasComment(node.id, CommentCheckFlags.Trailing) || node.typeParameters && hasComment(node.typeParameters, CommentCheckFlags.Trailing) || node.superClass && hasComment(node.superClass) || isNonEmptyArray(node.extends) || isNonEmptyArray(node.mixins) || isNonEmptyArray(node.implements);
          const partsGroup = [];
          const extendsParts = [];
          if (node.id) {
            partsGroup.push(" ", print("id"));
          }
          partsGroup.push(print("typeParameters"));
          if (node.superClass) {
            const printed = [printSuperClass(path2, options, print), print("superTypeParameters")];
            const printedWithComments = path2.call((superClass) => ["extends ", printComments(superClass, printed, options)], "superClass");
            if (groupMode) {
              extendsParts.push(line, group(printedWithComments));
            } else {
              extendsParts.push(" ", printedWithComments);
            }
          } else {
            extendsParts.push(printList(path2, options, print, "extends"));
          }
          extendsParts.push(printList(path2, options, print, "mixins"), printList(path2, options, print, "implements"));
          if (groupMode) {
            let printedPartsGroup;
            if (shouldIndentOnlyHeritageClauses(node)) {
              printedPartsGroup = [...partsGroup, indent(extendsParts)];
            } else {
              printedPartsGroup = indent([...partsGroup, extendsParts]);
            }
            parts.push(group(printedPartsGroup, {
              id: getHeritageGroupId(node)
            }));
          } else {
            parts.push(...partsGroup, ...extendsParts);
          }
          parts.push(" ", print("body"));
          return parts;
        }
        var getHeritageGroupId = createGroupIdMapper("heritageGroup");
        function printHardlineAfterHeritage(node) {
          return ifBreak(hardline, "", {
            groupId: getHeritageGroupId(node)
          });
        }
        function hasMultipleHeritage(node) {
          return ["superClass", "extends", "mixins", "implements"].filter((key) => Boolean(node[key])).length > 1;
        }
        function shouldIndentOnlyHeritageClauses(node) {
          return node.typeParameters && !hasComment(node.typeParameters, CommentCheckFlags.Trailing | CommentCheckFlags.Line) && !hasMultipleHeritage(node);
        }
        function printList(path2, options, print, listName) {
          const node = path2.getValue();
          if (!isNonEmptyArray(node[listName])) {
            return "";
          }
          const printedLeadingComments = printDanglingComments(path2, options, true, ({
            marker
          }) => marker === listName);
          return [shouldIndentOnlyHeritageClauses(node) ? ifBreak(" ", line, {
            groupId: getTypeParametersGroupId(node.typeParameters)
          }) : line, printedLeadingComments, printedLeadingComments && hardline, listName, group(indent([line, join([",", line], path2.map(print, listName))]))];
        }
        function printSuperClass(path2, options, print) {
          const printed = print("superClass");
          const parent = path2.getParentNode();
          if (parent.type === "AssignmentExpression") {
            return group(ifBreak(["(", indent([softline, printed]), softline, ")"], printed));
          }
          return printed;
        }
        function printClassMethod(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (isNonEmptyArray(node.decorators)) {
            parts.push(printClassMemberDecorators(path2, options, print));
          }
          if (node.accessibility) {
            parts.push(node.accessibility + " ");
          }
          if (node.readonly) {
            parts.push("readonly ");
          }
          if (node.declare) {
            parts.push("declare ");
          }
          if (node.static) {
            parts.push("static ");
          }
          if (node.type === "TSAbstractMethodDefinition" || node.abstract) {
            parts.push("abstract ");
          }
          if (node.override) {
            parts.push("override ");
          }
          parts.push(printMethod(path2, options, print));
          return parts;
        }
        function printClassProperty(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          const semi = options.semi ? ";" : "";
          if (isNonEmptyArray(node.decorators)) {
            parts.push(printClassMemberDecorators(path2, options, print));
          }
          if (node.accessibility) {
            parts.push(node.accessibility + " ");
          }
          if (node.declare) {
            parts.push("declare ");
          }
          if (node.static) {
            parts.push("static ");
          }
          if (node.type === "TSAbstractPropertyDefinition" || node.type === "TSAbstractAccessorProperty" || node.abstract) {
            parts.push("abstract ");
          }
          if (node.override) {
            parts.push("override ");
          }
          if (node.readonly) {
            parts.push("readonly ");
          }
          if (node.variance) {
            parts.push(print("variance"));
          }
          if (node.type === "ClassAccessorProperty" || node.type === "AccessorProperty" || node.type === "TSAbstractAccessorProperty") {
            parts.push("accessor ");
          }
          parts.push(printPropertyKey(path2, options, print), printOptionalToken(path2), printDefiniteToken(path2), printTypeAnnotation(path2, options, print));
          return [printAssignment(path2, options, print, parts, " =", "value"), semi];
        }
        module22.exports = {
          printClass,
          printClassMethod,
          printClassProperty,
          printHardlineAfterHeritage
        };
      }
    });
    var require_interface = __commonJS22({
      "src/language-js/print/interface.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            join,
            line,
            group,
            indent,
            ifBreak
          }
        } = require_doc();
        var {
          hasComment,
          identity,
          CommentCheckFlags
        } = require_utils72();
        var {
          getTypeParametersGroupId
        } = require_type_parameters();
        var {
          printTypeScriptModifiers
        } = require_misc3();
        function printInterface(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (node.declare) {
            parts.push("declare ");
          }
          if (node.type === "TSInterfaceDeclaration") {
            parts.push(node.abstract ? "abstract " : "", printTypeScriptModifiers(path2, options, print));
          }
          parts.push("interface");
          const partsGroup = [];
          const extendsParts = [];
          if (node.type !== "InterfaceTypeAnnotation") {
            partsGroup.push(" ", print("id"), print("typeParameters"));
          }
          const shouldIndentOnlyHeritageClauses = node.typeParameters && !hasComment(node.typeParameters, CommentCheckFlags.Trailing | CommentCheckFlags.Line);
          if (isNonEmptyArray(node.extends)) {
            extendsParts.push(shouldIndentOnlyHeritageClauses ? ifBreak(" ", line, {
              groupId: getTypeParametersGroupId(node.typeParameters)
            }) : line, "extends ", (node.extends.length === 1 ? identity : indent)(join([",", line], path2.map(print, "extends"))));
          }
          if (node.id && hasComment(node.id, CommentCheckFlags.Trailing) || isNonEmptyArray(node.extends)) {
            if (shouldIndentOnlyHeritageClauses) {
              parts.push(group([...partsGroup, indent(extendsParts)]));
            } else {
              parts.push(group(indent([...partsGroup, ...extendsParts])));
            }
          } else {
            parts.push(...partsGroup, ...extendsParts);
          }
          parts.push(" ", print("body"));
          return group(parts);
        }
        module22.exports = {
          printInterface
        };
      }
    });
    var require_module = __commonJS22({
      "src/language-js/print/module.js"(exports2, module22) {
        "use strict";
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            softline,
            group,
            indent,
            join,
            line,
            ifBreak,
            hardline
          }
        } = require_doc();
        var {
          printDanglingComments
        } = require_comments2();
        var {
          hasComment,
          CommentCheckFlags,
          shouldPrintComma,
          needsHardlineAfterDanglingComment,
          isStringLiteral: isStringLiteral3,
          rawText
        } = require_utils72();
        var {
          locStart,
          hasSameLoc
        } = require_loc();
        var {
          hasDecoratorsBeforeExport,
          printDecoratorsBeforeExport
        } = require_decorators();
        function printImportDeclaration(path2, options, print) {
          const node = path2.getValue();
          const semi = options.semi ? ";" : "";
          const parts = [];
          const {
            importKind
          } = node;
          parts.push("import");
          if (importKind && importKind !== "value") {
            parts.push(" ", importKind);
          }
          parts.push(printModuleSpecifiers(path2, options, print), printModuleSource(path2, options, print), printImportAssertions(path2, options, print), semi);
          return parts;
        }
        function printExportDeclaration(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (hasDecoratorsBeforeExport(node)) {
            parts.push(printDecoratorsBeforeExport(path2, options, print));
          }
          const {
            type,
            exportKind,
            declaration
          } = node;
          parts.push("export");
          const isDefaultExport = node.default || type === "ExportDefaultDeclaration";
          if (isDefaultExport) {
            parts.push(" default");
          }
          if (hasComment(node, CommentCheckFlags.Dangling)) {
            parts.push(" ", printDanglingComments(path2, options, true));
            if (needsHardlineAfterDanglingComment(node)) {
              parts.push(hardline);
            }
          }
          if (declaration) {
            parts.push(" ", print("declaration"));
          } else {
            parts.push(exportKind === "type" ? " type" : "", printModuleSpecifiers(path2, options, print), printModuleSource(path2, options, print), printImportAssertions(path2, options, print));
          }
          if (shouldExportDeclarationPrintSemi(node, options)) {
            parts.push(";");
          }
          return parts;
        }
        function printExportAllDeclaration(path2, options, print) {
          const node = path2.getValue();
          const semi = options.semi ? ";" : "";
          const parts = [];
          const {
            exportKind,
            exported
          } = node;
          parts.push("export");
          if (exportKind === "type") {
            parts.push(" type");
          }
          parts.push(" *");
          if (exported) {
            parts.push(" as ", print("exported"));
          }
          parts.push(printModuleSource(path2, options, print), printImportAssertions(path2, options, print), semi);
          return parts;
        }
        function shouldExportDeclarationPrintSemi(node, options) {
          if (!options.semi) {
            return false;
          }
          const {
            type,
            declaration
          } = node;
          const isDefaultExport = node.default || type === "ExportDefaultDeclaration";
          if (!declaration) {
            return true;
          }
          const {
            type: declarationType
          } = declaration;
          if (isDefaultExport && declarationType !== "ClassDeclaration" && declarationType !== "FunctionDeclaration" && declarationType !== "TSInterfaceDeclaration" && declarationType !== "DeclareClass" && declarationType !== "DeclareFunction" && declarationType !== "TSDeclareFunction" && declarationType !== "EnumDeclaration") {
            return true;
          }
          return false;
        }
        function printModuleSource(path2, options, print) {
          const node = path2.getValue();
          if (!node.source) {
            return "";
          }
          const parts = [];
          if (!shouldNotPrintSpecifiers(node, options)) {
            parts.push(" from");
          }
          parts.push(" ", print("source"));
          return parts;
        }
        function printModuleSpecifiers(path2, options, print) {
          const node = path2.getValue();
          if (shouldNotPrintSpecifiers(node, options)) {
            return "";
          }
          const parts = [" "];
          if (isNonEmptyArray(node.specifiers)) {
            const standaloneSpecifiers = [];
            const groupedSpecifiers = [];
            path2.each(() => {
              const specifierType = path2.getValue().type;
              if (specifierType === "ExportNamespaceSpecifier" || specifierType === "ExportDefaultSpecifier" || specifierType === "ImportNamespaceSpecifier" || specifierType === "ImportDefaultSpecifier") {
                standaloneSpecifiers.push(print());
              } else if (specifierType === "ExportSpecifier" || specifierType === "ImportSpecifier") {
                groupedSpecifiers.push(print());
              } else {
                throw new Error(`Unknown specifier type ${JSON.stringify(specifierType)}`);
              }
            }, "specifiers");
            parts.push(join(", ", standaloneSpecifiers));
            if (groupedSpecifiers.length > 0) {
              if (standaloneSpecifiers.length > 0) {
                parts.push(", ");
              }
              const canBreak = groupedSpecifiers.length > 1 || standaloneSpecifiers.length > 0 || node.specifiers.some((node2) => hasComment(node2));
              if (canBreak) {
                parts.push(group(["{", indent([options.bracketSpacing ? line : softline, join([",", line], groupedSpecifiers)]), ifBreak(shouldPrintComma(options) ? "," : ""), options.bracketSpacing ? line : softline, "}"]));
              } else {
                parts.push(["{", options.bracketSpacing ? " " : "", ...groupedSpecifiers, options.bracketSpacing ? " " : "", "}"]);
              }
            }
          } else {
            parts.push("{}");
          }
          return parts;
        }
        function shouldNotPrintSpecifiers(node, options) {
          const {
            type,
            importKind,
            source,
            specifiers
          } = node;
          if (type !== "ImportDeclaration" || isNonEmptyArray(specifiers) || importKind === "type") {
            return false;
          }
          return !/{\s*}/.test(options.originalText.slice(locStart(node), locStart(source)));
        }
        function printImportAssertions(path2, options, print) {
          const node = path2.getNode();
          if (isNonEmptyArray(node.assertions)) {
            return [" assert {", options.bracketSpacing ? " " : "", join(", ", path2.map(print, "assertions")), options.bracketSpacing ? " " : "", "}"];
          }
          return "";
        }
        function printModuleSpecifier(path2, options, print) {
          const node = path2.getNode();
          const {
            type
          } = node;
          const parts = [];
          const kind = type === "ImportSpecifier" ? node.importKind : node.exportKind;
          if (kind && kind !== "value") {
            parts.push(kind, " ");
          }
          const isImport = type.startsWith("Import");
          const leftSideProperty = isImport ? "imported" : "local";
          const rightSideProperty = isImport ? "local" : "exported";
          const leftSideNode = node[leftSideProperty];
          const rightSideNode = node[rightSideProperty];
          let left = "";
          let right = "";
          if (type === "ExportNamespaceSpecifier" || type === "ImportNamespaceSpecifier") {
            left = "*";
          } else if (leftSideNode) {
            left = print(leftSideProperty);
          }
          if (rightSideNode && !isShorthandSpecifier(node)) {
            right = print(rightSideProperty);
          }
          parts.push(left, left && right ? " as " : "", right);
          return parts;
        }
        function isShorthandSpecifier(specifier) {
          if (specifier.type !== "ImportSpecifier" && specifier.type !== "ExportSpecifier") {
            return false;
          }
          const {
            local,
            [specifier.type === "ImportSpecifier" ? "imported" : "exported"]: importedOrExported
          } = specifier;
          if (local.type !== importedOrExported.type || !hasSameLoc(local, importedOrExported)) {
            return false;
          }
          if (isStringLiteral3(local)) {
            return local.value === importedOrExported.value && rawText(local) === rawText(importedOrExported);
          }
          switch (local.type) {
            case "Identifier":
              return local.name === importedOrExported.name;
            default:
              return false;
          }
        }
        module22.exports = {
          printImportDeclaration,
          printExportDeclaration,
          printExportAllDeclaration,
          printModuleSpecifier
        };
      }
    });
    var require_object = __commonJS22({
      "src/language-js/print/object.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          builders: {
            line,
            softline,
            group,
            indent,
            ifBreak,
            hardline
          }
        } = require_doc();
        var {
          getLast,
          hasNewlineInRange,
          hasNewline,
          isNonEmptyArray
        } = require_util6();
        var {
          shouldPrintComma,
          hasComment,
          getComments,
          CommentCheckFlags,
          isNextLineEmpty
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var {
          printOptionalToken,
          printTypeAnnotation
        } = require_misc3();
        var {
          shouldHugFunctionParameters
        } = require_function_parameters();
        var {
          shouldHugType
        } = require_type_annotation();
        var {
          printHardlineAfterHeritage
        } = require_class();
        function printObject(path2, options, print) {
          const semi = options.semi ? ";" : "";
          const node = path2.getValue();
          let propertiesField;
          if (node.type === "TSTypeLiteral") {
            propertiesField = "members";
          } else if (node.type === "TSInterfaceBody") {
            propertiesField = "body";
          } else {
            propertiesField = "properties";
          }
          const isTypeAnnotation = node.type === "ObjectTypeAnnotation";
          const fields = [propertiesField];
          if (isTypeAnnotation) {
            fields.push("indexers", "callProperties", "internalSlots");
          }
          const firstProperty = fields.map((field) => node[field][0]).sort((a, b) => locStart(a) - locStart(b))[0];
          const parent = path2.getParentNode(0);
          const isFlowInterfaceLikeBody = isTypeAnnotation && parent && (parent.type === "InterfaceDeclaration" || parent.type === "DeclareInterface" || parent.type === "DeclareClass") && path2.getName() === "body";
          const shouldBreak = node.type === "TSInterfaceBody" || isFlowInterfaceLikeBody || node.type === "ObjectPattern" && parent.type !== "FunctionDeclaration" && parent.type !== "FunctionExpression" && parent.type !== "ArrowFunctionExpression" && parent.type !== "ObjectMethod" && parent.type !== "ClassMethod" && parent.type !== "ClassPrivateMethod" && parent.type !== "AssignmentPattern" && parent.type !== "CatchClause" && node.properties.some((property) => property.value && (property.value.type === "ObjectPattern" || property.value.type === "ArrayPattern")) || node.type !== "ObjectPattern" && firstProperty && hasNewlineInRange(options.originalText, locStart(node), locStart(firstProperty));
          const separator = isFlowInterfaceLikeBody ? ";" : node.type === "TSInterfaceBody" || node.type === "TSTypeLiteral" ? ifBreak(semi, ";") : ",";
          const leftBrace = node.type === "RecordExpression" ? "#{" : node.exact ? "{|" : "{";
          const rightBrace = node.exact ? "|}" : "}";
          const propsAndLoc = [];
          for (const field of fields) {
            path2.each((childPath) => {
              const node2 = childPath.getValue();
              propsAndLoc.push({
                node: node2,
                printed: print(),
                loc: locStart(node2)
              });
            }, field);
          }
          if (fields.length > 1) {
            propsAndLoc.sort((a, b) => a.loc - b.loc);
          }
          let separatorParts = [];
          const props = propsAndLoc.map((prop) => {
            const result = [...separatorParts, group(prop.printed)];
            separatorParts = [separator, line];
            if ((prop.node.type === "TSPropertySignature" || prop.node.type === "TSMethodSignature" || prop.node.type === "TSConstructSignatureDeclaration") && hasComment(prop.node, CommentCheckFlags.PrettierIgnore)) {
              separatorParts.shift();
            }
            if (isNextLineEmpty(prop.node, options)) {
              separatorParts.push(hardline);
            }
            return result;
          });
          if (node.inexact) {
            let printed;
            if (hasComment(node, CommentCheckFlags.Dangling)) {
              const hasLineComments = hasComment(node, CommentCheckFlags.Line);
              const printedDanglingComments = printDanglingComments(path2, options, true);
              printed = [printedDanglingComments, hasLineComments || hasNewline(options.originalText, locEnd(getLast(getComments(node)))) ? hardline : line, "..."];
            } else {
              printed = ["..."];
            }
            props.push([...separatorParts, ...printed]);
          }
          const lastElem = getLast(node[propertiesField]);
          const canHaveTrailingSeparator = !(node.inexact || lastElem && lastElem.type === "RestElement" || lastElem && (lastElem.type === "TSPropertySignature" || lastElem.type === "TSCallSignatureDeclaration" || lastElem.type === "TSMethodSignature" || lastElem.type === "TSConstructSignatureDeclaration") && hasComment(lastElem, CommentCheckFlags.PrettierIgnore));
          let content;
          if (props.length === 0) {
            if (!hasComment(node, CommentCheckFlags.Dangling)) {
              return [leftBrace, rightBrace, printTypeAnnotation(path2, options, print)];
            }
            content = group([leftBrace, printDanglingComments(path2, options), softline, rightBrace, printOptionalToken(path2), printTypeAnnotation(path2, options, print)]);
          } else {
            content = [isFlowInterfaceLikeBody && isNonEmptyArray(node.properties) ? printHardlineAfterHeritage(parent) : "", leftBrace, indent([options.bracketSpacing ? line : softline, ...props]), ifBreak(canHaveTrailingSeparator && (separator !== "," || shouldPrintComma(options)) ? separator : ""), options.bracketSpacing ? line : softline, rightBrace, printOptionalToken(path2), printTypeAnnotation(path2, options, print)];
          }
          if (path2.match((node2) => node2.type === "ObjectPattern" && !node2.decorators, (node2, name, number) => shouldHugFunctionParameters(node2) && (name === "params" || name === "parameters" || name === "this" || name === "rest") && number === 0) || path2.match(shouldHugType, (node2, name) => name === "typeAnnotation", (node2, name) => name === "typeAnnotation", (node2, name, number) => shouldHugFunctionParameters(node2) && (name === "params" || name === "parameters" || name === "this" || name === "rest") && number === 0) || !shouldBreak && path2.match((node2) => node2.type === "ObjectPattern", (node2) => node2.type === "AssignmentExpression" || node2.type === "VariableDeclarator")) {
            return content;
          }
          return group(content, {
            shouldBreak
          });
        }
        module22.exports = {
          printObject
        };
      }
    });
    var require_flow4 = __commonJS22({
      "src/language-js/print/flow.js"(exports2, module22) {
        "use strict";
        var assert = require("assert");
        var {
          printDanglingComments
        } = require_comments2();
        var {
          printString,
          printNumber
        } = require_util6();
        var {
          builders: {
            hardline,
            softline,
            group,
            indent
          }
        } = require_doc();
        var {
          getParentExportDeclaration,
          isFunctionNotation,
          isGetterOrSetter,
          rawText,
          shouldPrintComma
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var {
          replaceTextEndOfLine
        } = require_doc_utils();
        var {
          printClass
        } = require_class();
        var {
          printOpaqueType,
          printTypeAlias,
          printIntersectionType,
          printUnionType,
          printFunctionType,
          printTupleType,
          printIndexedAccessType
        } = require_type_annotation();
        var {
          printInterface
        } = require_interface();
        var {
          printTypeParameter,
          printTypeParameters
        } = require_type_parameters();
        var {
          printExportDeclaration,
          printExportAllDeclaration
        } = require_module();
        var {
          printArrayItems
        } = require_array4();
        var {
          printObject
        } = require_object();
        var {
          printPropertyKey
        } = require_property2();
        var {
          printOptionalToken,
          printTypeAnnotation,
          printRestSpread
        } = require_misc3();
        function printFlow(path2, options, print) {
          const node = path2.getValue();
          const semi = options.semi ? ";" : "";
          const parts = [];
          switch (node.type) {
            case "DeclareClass":
              return printFlowDeclaration(path2, printClass(path2, options, print));
            case "DeclareFunction":
              return printFlowDeclaration(path2, ["function ", print("id"), node.predicate ? " " : "", print("predicate"), semi]);
            case "DeclareModule":
              return printFlowDeclaration(path2, ["module ", print("id"), " ", print("body")]);
            case "DeclareModuleExports":
              return printFlowDeclaration(path2, ["module.exports", ": ", print("typeAnnotation"), semi]);
            case "DeclareVariable":
              return printFlowDeclaration(path2, ["var ", print("id"), semi]);
            case "DeclareOpaqueType":
              return printFlowDeclaration(path2, printOpaqueType(path2, options, print));
            case "DeclareInterface":
              return printFlowDeclaration(path2, printInterface(path2, options, print));
            case "DeclareTypeAlias":
              return printFlowDeclaration(path2, printTypeAlias(path2, options, print));
            case "DeclareExportDeclaration":
              return printFlowDeclaration(path2, printExportDeclaration(path2, options, print));
            case "DeclareExportAllDeclaration":
              return printFlowDeclaration(path2, printExportAllDeclaration(path2, options, print));
            case "OpaqueType":
              return printOpaqueType(path2, options, print);
            case "TypeAlias":
              return printTypeAlias(path2, options, print);
            case "IntersectionTypeAnnotation":
              return printIntersectionType(path2, options, print);
            case "UnionTypeAnnotation":
              return printUnionType(path2, options, print);
            case "FunctionTypeAnnotation":
              return printFunctionType(path2, options, print);
            case "TupleTypeAnnotation":
              return printTupleType(path2, options, print);
            case "GenericTypeAnnotation":
              return [print("id"), printTypeParameters(path2, options, print, "typeParameters")];
            case "IndexedAccessType":
            case "OptionalIndexedAccessType":
              return printIndexedAccessType(path2, options, print);
            case "TypeAnnotation":
              return print("typeAnnotation");
            case "TypeParameter":
              return printTypeParameter(path2, options, print);
            case "TypeofTypeAnnotation":
              return ["typeof ", print("argument")];
            case "ExistsTypeAnnotation":
              return "*";
            case "EmptyTypeAnnotation":
              return "empty";
            case "MixedTypeAnnotation":
              return "mixed";
            case "ArrayTypeAnnotation":
              return [print("elementType"), "[]"];
            case "BooleanLiteralTypeAnnotation":
              return String(node.value);
            case "EnumDeclaration":
              return ["enum ", print("id"), " ", print("body")];
            case "EnumBooleanBody":
            case "EnumNumberBody":
            case "EnumStringBody":
            case "EnumSymbolBody": {
              if (node.type === "EnumSymbolBody" || node.explicitType) {
                let type = null;
                switch (node.type) {
                  case "EnumBooleanBody":
                    type = "boolean";
                    break;
                  case "EnumNumberBody":
                    type = "number";
                    break;
                  case "EnumStringBody":
                    type = "string";
                    break;
                  case "EnumSymbolBody":
                    type = "symbol";
                    break;
                }
                parts.push("of ", type, " ");
              }
              if (node.members.length === 0 && !node.hasUnknownMembers) {
                parts.push(group(["{", printDanglingComments(path2, options), softline, "}"]));
              } else {
                const members = node.members.length > 0 ? [hardline, printArrayItems(path2, options, "members", print), node.hasUnknownMembers || shouldPrintComma(options) ? "," : ""] : [];
                parts.push(group(["{", indent([...members, ...node.hasUnknownMembers ? [hardline, "..."] : []]), printDanglingComments(path2, options, true), hardline, "}"]));
              }
              return parts;
            }
            case "EnumBooleanMember":
            case "EnumNumberMember":
            case "EnumStringMember":
              return [print("id"), " = ", typeof node.init === "object" ? print("init") : String(node.init)];
            case "EnumDefaultedMember":
              return print("id");
            case "FunctionTypeParam": {
              const name = node.name ? print("name") : path2.getParentNode().this === node ? "this" : "";
              return [name, printOptionalToken(path2), name ? ": " : "", print("typeAnnotation")];
            }
            case "InterfaceDeclaration":
            case "InterfaceTypeAnnotation":
              return printInterface(path2, options, print);
            case "ClassImplements":
            case "InterfaceExtends":
              return [print("id"), print("typeParameters")];
            case "NullableTypeAnnotation":
              return ["?", print("typeAnnotation")];
            case "Variance": {
              const {
                kind
              } = node;
              assert.ok(kind === "plus" || kind === "minus");
              return kind === "plus" ? "+" : "-";
            }
            case "ObjectTypeCallProperty":
              if (node.static) {
                parts.push("static ");
              }
              parts.push(print("value"));
              return parts;
            case "ObjectTypeIndexer": {
              return [node.static ? "static " : "", node.variance ? print("variance") : "", "[", print("id"), node.id ? ": " : "", print("key"), "]: ", print("value")];
            }
            case "ObjectTypeProperty": {
              let modifier = "";
              if (node.proto) {
                modifier = "proto ";
              } else if (node.static) {
                modifier = "static ";
              }
              return [modifier, isGetterOrSetter(node) ? node.kind + " " : "", node.variance ? print("variance") : "", printPropertyKey(path2, options, print), printOptionalToken(path2), isFunctionNotation(node) ? "" : ": ", print("value")];
            }
            case "ObjectTypeAnnotation":
              return printObject(path2, options, print);
            case "ObjectTypeInternalSlot":
              return [node.static ? "static " : "", "[[", print("id"), "]]", printOptionalToken(path2), node.method ? "" : ": ", print("value")];
            case "ObjectTypeSpreadProperty":
              return printRestSpread(path2, options, print);
            case "QualifiedTypeofIdentifier":
            case "QualifiedTypeIdentifier":
              return [print("qualification"), ".", print("id")];
            case "StringLiteralTypeAnnotation":
              return replaceTextEndOfLine(printString(rawText(node), options));
            case "NumberLiteralTypeAnnotation":
              assert.strictEqual(typeof node.value, "number");
            case "BigIntLiteralTypeAnnotation":
              if (node.extra) {
                return printNumber(node.extra.raw);
              }
              return printNumber(node.raw);
            case "TypeCastExpression": {
              return ["(", print("expression"), printTypeAnnotation(path2, options, print), ")"];
            }
            case "TypeParameterDeclaration":
            case "TypeParameterInstantiation": {
              const printed = printTypeParameters(path2, options, print, "params");
              if (options.parser === "flow") {
                const start = locStart(node);
                const end = locEnd(node);
                const commentStartIndex = options.originalText.lastIndexOf("/*", start);
                const commentEndIndex = options.originalText.indexOf("*/", end);
                if (commentStartIndex !== -1 && commentEndIndex !== -1) {
                  const comment = options.originalText.slice(commentStartIndex + 2, commentEndIndex).trim();
                  if (comment.startsWith("::") && !comment.includes("/*") && !comment.includes("*/")) {
                    return ["/*:: ", printed, " */"];
                  }
                }
              }
              return printed;
            }
            case "InferredPredicate":
              return "%checks";
            case "DeclaredPredicate":
              return ["%checks(", print("value"), ")"];
            case "AnyTypeAnnotation":
              return "any";
            case "BooleanTypeAnnotation":
              return "boolean";
            case "BigIntTypeAnnotation":
              return "bigint";
            case "NullLiteralTypeAnnotation":
              return "null";
            case "NumberTypeAnnotation":
              return "number";
            case "SymbolTypeAnnotation":
              return "symbol";
            case "StringTypeAnnotation":
              return "string";
            case "VoidTypeAnnotation":
              return "void";
            case "ThisTypeAnnotation":
              return "this";
            case "Node":
            case "Printable":
            case "SourceLocation":
            case "Position":
            case "Statement":
            case "Function":
            case "Pattern":
            case "Expression":
            case "Declaration":
            case "Specifier":
            case "NamedSpecifier":
            case "Comment":
            case "MemberTypeAnnotation":
            case "Type":
              throw new Error("unprintable type: " + JSON.stringify(node.type));
          }
        }
        function printFlowDeclaration(path2, printed) {
          const parentExportDecl = getParentExportDeclaration(path2);
          if (parentExportDecl) {
            assert.strictEqual(parentExportDecl.type, "DeclareExportDeclaration");
            return printed;
          }
          return ["declare ", printed];
        }
        module22.exports = {
          printFlow
        };
      }
    });
    var require_is_ts_keyword_type = __commonJS22({
      "src/language-js/utils/is-ts-keyword-type.js"(exports2, module22) {
        "use strict";
        function isTsKeywordType({
          type
        }) {
          return type.startsWith("TS") && type.endsWith("Keyword");
        }
        module22.exports = isTsKeywordType;
      }
    });
    var require_ternary = __commonJS22({
      "src/language-js/print/ternary.js"(exports2, module22) {
        "use strict";
        var {
          hasNewlineInRange
        } = require_util6();
        var {
          isJsxNode,
          getComments,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          isTSTypeExpression
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var isBlockComment = require_is_block_comment();
        var {
          builders: {
            line,
            softline,
            group,
            indent,
            align,
            ifBreak,
            dedent,
            breakParent
          }
        } = require_doc();
        function conditionalExpressionChainContainsJsx(node) {
          const conditionalExpressions = [node];
          for (let index = 0; index < conditionalExpressions.length; index++) {
            const conditionalExpression = conditionalExpressions[index];
            for (const property of ["test", "consequent", "alternate"]) {
              const node2 = conditionalExpression[property];
              if (isJsxNode(node2)) {
                return true;
              }
              if (node2.type === "ConditionalExpression") {
                conditionalExpressions.push(node2);
              }
            }
          }
          return false;
        }
        function printTernaryTest(path2, options, print) {
          const node = path2.getValue();
          const isConditionalExpression = node.type === "ConditionalExpression";
          const alternateNodePropertyName = isConditionalExpression ? "alternate" : "falseType";
          const parent = path2.getParentNode();
          const printed = isConditionalExpression ? print("test") : [print("checkType"), " ", "extends", " ", print("extendsType")];
          if (parent.type === node.type && parent[alternateNodePropertyName] === node) {
            return align(2, printed);
          }
          return printed;
        }
        var ancestorNameMap = /* @__PURE__ */ new Map([["AssignmentExpression", "right"], ["VariableDeclarator", "init"], ["ReturnStatement", "argument"], ["ThrowStatement", "argument"], ["UnaryExpression", "argument"], ["YieldExpression", "argument"]]);
        function shouldExtraIndentForConditionalExpression(path2) {
          const node = path2.getValue();
          if (node.type !== "ConditionalExpression") {
            return false;
          }
          let parent;
          let child = node;
          for (let ancestorCount = 0; !parent; ancestorCount++) {
            const node2 = path2.getParentNode(ancestorCount);
            if (isCallExpression2(node2) && node2.callee === child || isMemberExpression(node2) && node2.object === child || node2.type === "TSNonNullExpression" && node2.expression === child) {
              child = node2;
              continue;
            }
            if (node2.type === "NewExpression" && node2.callee === child || isTSTypeExpression(node2) && node2.expression === child) {
              parent = path2.getParentNode(ancestorCount + 1);
              child = node2;
            } else {
              parent = node2;
            }
          }
          if (child === node) {
            return false;
          }
          return parent[ancestorNameMap.get(parent.type)] === child;
        }
        function printTernary(path2, options, print) {
          const node = path2.getValue();
          const isConditionalExpression = node.type === "ConditionalExpression";
          const consequentNodePropertyName = isConditionalExpression ? "consequent" : "trueType";
          const alternateNodePropertyName = isConditionalExpression ? "alternate" : "falseType";
          const testNodePropertyNames = isConditionalExpression ? ["test"] : ["checkType", "extendsType"];
          const consequentNode = node[consequentNodePropertyName];
          const alternateNode = node[alternateNodePropertyName];
          const parts = [];
          let jsxMode = false;
          const parent = path2.getParentNode();
          const isParentTest = parent.type === node.type && testNodePropertyNames.some((prop) => parent[prop] === node);
          let forceNoIndent = parent.type === node.type && !isParentTest;
          let currentParent;
          let previousParent;
          let i = 0;
          do {
            previousParent = currentParent || node;
            currentParent = path2.getParentNode(i);
            i++;
          } while (currentParent && currentParent.type === node.type && testNodePropertyNames.every((prop) => currentParent[prop] !== previousParent));
          const firstNonConditionalParent = currentParent || parent;
          const lastConditionalParent = previousParent;
          if (isConditionalExpression && (isJsxNode(node[testNodePropertyNames[0]]) || isJsxNode(consequentNode) || isJsxNode(alternateNode) || conditionalExpressionChainContainsJsx(lastConditionalParent))) {
            jsxMode = true;
            forceNoIndent = true;
            const wrap = (doc2) => [ifBreak("("), indent([softline, doc2]), softline, ifBreak(")")];
            const isNil = (node2) => node2.type === "NullLiteral" || node2.type === "Literal" && node2.value === null || node2.type === "Identifier" && node2.name === "undefined";
            parts.push(" ? ", isNil(consequentNode) ? print(consequentNodePropertyName) : wrap(print(consequentNodePropertyName)), " : ", alternateNode.type === node.type || isNil(alternateNode) ? print(alternateNodePropertyName) : wrap(print(alternateNodePropertyName)));
          } else {
            const part = [line, "? ", consequentNode.type === node.type ? ifBreak("", "(") : "", align(2, print(consequentNodePropertyName)), consequentNode.type === node.type ? ifBreak("", ")") : "", line, ": ", alternateNode.type === node.type ? print(alternateNodePropertyName) : align(2, print(alternateNodePropertyName))];
            parts.push(parent.type !== node.type || parent[alternateNodePropertyName] === node || isParentTest ? part : options.useTabs ? dedent(indent(part)) : align(Math.max(0, options.tabWidth - 2), part));
          }
          const comments = [...testNodePropertyNames.map((propertyName) => getComments(node[propertyName])), getComments(consequentNode), getComments(alternateNode)].flat();
          const shouldBreak = comments.some((comment) => isBlockComment(comment) && hasNewlineInRange(options.originalText, locStart(comment), locEnd(comment)));
          const maybeGroup = (doc2) => parent === firstNonConditionalParent ? group(doc2, {
            shouldBreak
          }) : shouldBreak ? [doc2, breakParent] : doc2;
          const breakClosingParen = !jsxMode && (isMemberExpression(parent) || parent.type === "NGPipeExpression" && parent.left === node) && !parent.computed;
          const shouldExtraIndent = shouldExtraIndentForConditionalExpression(path2);
          const result = maybeGroup([printTernaryTest(path2, options, print), forceNoIndent ? parts : indent(parts), isConditionalExpression && breakClosingParen && !shouldExtraIndent ? softline : ""]);
          return isParentTest || shouldExtraIndent ? group([indent([softline, result]), softline]) : result;
        }
        module22.exports = {
          printTernary
        };
      }
    });
    var require_statement = __commonJS22({
      "src/language-js/print/statement.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            hardline
          }
        } = require_doc();
        var pathNeedsParens = require_needs_parens();
        var {
          getLeftSidePathName,
          hasNakedLeftSide,
          isJsxNode,
          isTheOnlyJsxElementInMarkdown,
          hasComment,
          CommentCheckFlags,
          isNextLineEmpty
        } = require_utils72();
        var {
          shouldPrintParamsWithoutParens
        } = require_function();
        function printStatementSequence(path2, options, print, property) {
          const node = path2.getValue();
          const parts = [];
          const isClassBody = node.type === "ClassBody";
          const lastStatement = getLastStatement(node[property]);
          path2.each((path22, index, statements) => {
            const node2 = path22.getValue();
            if (node2.type === "EmptyStatement") {
              return;
            }
            const printed = print();
            if (!options.semi && !isClassBody && !isTheOnlyJsxElementInMarkdown(options, path22) && statementNeedsASIProtection(path22, options)) {
              if (hasComment(node2, CommentCheckFlags.Leading)) {
                parts.push(print([], {
                  needsSemi: true
                }));
              } else {
                parts.push(";", printed);
              }
            } else {
              parts.push(printed);
            }
            if (!options.semi && isClassBody && isClassProperty(node2) && shouldPrintSemicolonAfterClassProperty(node2, statements[index + 1])) {
              parts.push(";");
            }
            if (node2 !== lastStatement) {
              parts.push(hardline);
              if (isNextLineEmpty(node2, options)) {
                parts.push(hardline);
              }
            }
          }, property);
          return parts;
        }
        function getLastStatement(statements) {
          for (let i = statements.length - 1; i >= 0; i--) {
            const statement = statements[i];
            if (statement.type !== "EmptyStatement") {
              return statement;
            }
          }
        }
        function statementNeedsASIProtection(path2, options) {
          const node = path2.getNode();
          if (node.type !== "ExpressionStatement") {
            return false;
          }
          return path2.call((childPath) => expressionNeedsASIProtection(childPath, options), "expression");
        }
        function expressionNeedsASIProtection(path2, options) {
          const node = path2.getValue();
          switch (node.type) {
            case "ParenthesizedExpression":
            case "TypeCastExpression":
            case "ArrayExpression":
            case "ArrayPattern":
            case "TemplateLiteral":
            case "TemplateElement":
            case "RegExpLiteral":
              return true;
            case "ArrowFunctionExpression": {
              if (!shouldPrintParamsWithoutParens(path2, options)) {
                return true;
              }
              break;
            }
            case "UnaryExpression": {
              const {
                prefix,
                operator
              } = node;
              if (prefix && (operator === "+" || operator === "-")) {
                return true;
              }
              break;
            }
            case "BindExpression": {
              if (!node.object) {
                return true;
              }
              break;
            }
            case "Literal": {
              if (node.regex) {
                return true;
              }
              break;
            }
            default: {
              if (isJsxNode(node)) {
                return true;
              }
            }
          }
          if (pathNeedsParens(path2, options)) {
            return true;
          }
          if (!hasNakedLeftSide(node)) {
            return false;
          }
          return path2.call((childPath) => expressionNeedsASIProtection(childPath, options), ...getLeftSidePathName(path2, node));
        }
        function printBody(path2, options, print) {
          return printStatementSequence(path2, options, print, "body");
        }
        function printSwitchCaseConsequent(path2, options, print) {
          return printStatementSequence(path2, options, print, "consequent");
        }
        var isClassProperty = ({
          type
        }) => type === "ClassProperty" || type === "PropertyDefinition" || type === "ClassPrivateProperty" || type === "ClassAccessorProperty" || type === "AccessorProperty" || type === "TSAbstractPropertyDefinition" || type === "TSAbstractAccessorProperty";
        function shouldPrintSemicolonAfterClassProperty(node, nextNode) {
          const {
            type,
            name
          } = node.key;
          if (!node.computed && type === "Identifier" && (name === "static" || name === "get" || name === "set" || name === "accessor") && !node.value && !node.typeAnnotation) {
            return true;
          }
          if (!nextNode) {
            return false;
          }
          if (nextNode.static || nextNode.accessibility) {
            return false;
          }
          if (!nextNode.computed) {
            const name2 = nextNode.key && nextNode.key.name;
            if (name2 === "in" || name2 === "instanceof") {
              return true;
            }
          }
          if (isClassProperty(nextNode) && nextNode.variance && !nextNode.static && !nextNode.declare) {
            return true;
          }
          switch (nextNode.type) {
            case "ClassProperty":
            case "PropertyDefinition":
            case "TSAbstractPropertyDefinition":
              return nextNode.computed;
            case "MethodDefinition":
            case "TSAbstractMethodDefinition":
            case "ClassMethod":
            case "ClassPrivateMethod": {
              const isAsync = nextNode.value ? nextNode.value.async : nextNode.async;
              if (isAsync || nextNode.kind === "get" || nextNode.kind === "set") {
                return false;
              }
              const isGenerator = nextNode.value ? nextNode.value.generator : nextNode.generator;
              if (nextNode.computed || isGenerator) {
                return true;
              }
              return false;
            }
            case "TSIndexSignature":
              return true;
          }
          return false;
        }
        module22.exports = {
          printBody,
          printSwitchCaseConsequent
        };
      }
    });
    var require_block = __commonJS22({
      "src/language-js/print/block.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            hardline,
            indent
          }
        } = require_doc();
        var {
          hasComment,
          CommentCheckFlags,
          isNextLineEmpty
        } = require_utils72();
        var {
          printHardlineAfterHeritage
        } = require_class();
        var {
          printBody
        } = require_statement();
        function printBlock(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (node.type === "StaticBlock") {
            parts.push("static ");
          }
          if (node.type === "ClassBody" && isNonEmptyArray(node.body)) {
            const parent = path2.getParentNode();
            parts.push(printHardlineAfterHeritage(parent));
          }
          parts.push("{");
          const printed = printBlockBody(path2, options, print);
          if (printed) {
            parts.push(indent([hardline, printed]), hardline);
          } else {
            const parent = path2.getParentNode();
            const parentParent = path2.getParentNode(1);
            if (!(parent.type === "ArrowFunctionExpression" || parent.type === "FunctionExpression" || parent.type === "FunctionDeclaration" || parent.type === "ObjectMethod" || parent.type === "ClassMethod" || parent.type === "ClassPrivateMethod" || parent.type === "ForStatement" || parent.type === "WhileStatement" || parent.type === "DoWhileStatement" || parent.type === "DoExpression" || parent.type === "CatchClause" && !parentParent.finalizer || parent.type === "TSModuleDeclaration" || parent.type === "TSDeclareFunction" || node.type === "StaticBlock" || node.type === "ClassBody")) {
              parts.push(hardline);
            }
          }
          parts.push("}");
          return parts;
        }
        function printBlockBody(path2, options, print) {
          const node = path2.getValue();
          const nodeHasDirectives = isNonEmptyArray(node.directives);
          const nodeHasBody = node.body.some((node2) => node2.type !== "EmptyStatement");
          const nodeHasComment = hasComment(node, CommentCheckFlags.Dangling);
          if (!nodeHasDirectives && !nodeHasBody && !nodeHasComment) {
            return "";
          }
          const parts = [];
          if (nodeHasDirectives) {
            path2.each((childPath, index, directives) => {
              parts.push(print());
              if (index < directives.length - 1 || nodeHasBody || nodeHasComment) {
                parts.push(hardline);
                if (isNextLineEmpty(childPath.getValue(), options)) {
                  parts.push(hardline);
                }
              }
            }, "directives");
          }
          if (nodeHasBody) {
            parts.push(printBody(path2, options, print));
          }
          if (nodeHasComment) {
            parts.push(printDanglingComments(path2, options, true));
          }
          if (node.type === "Program") {
            const parent = path2.getParentNode();
            if (!parent || parent.type !== "ModuleExpression") {
              parts.push(hardline);
            }
          }
          return parts;
        }
        module22.exports = {
          printBlock,
          printBlockBody
        };
      }
    });
    var require_typescript4 = __commonJS22({
      "src/language-js/print/typescript.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          hasNewlineInRange
        } = require_util6();
        var {
          builders: {
            join,
            line,
            hardline,
            softline,
            group,
            indent,
            conditionalGroup,
            ifBreak
          }
        } = require_doc();
        var {
          isLiteral,
          getTypeScriptMappedTypeModifier,
          shouldPrintComma,
          isCallExpression: isCallExpression2,
          isMemberExpression
        } = require_utils72();
        var isTsKeywordType = require_is_ts_keyword_type();
        var {
          locStart,
          locEnd
        } = require_loc();
        var {
          printOptionalToken,
          printTypeScriptModifiers
        } = require_misc3();
        var {
          printTernary
        } = require_ternary();
        var {
          printFunctionParameters,
          shouldGroupFunctionParameters
        } = require_function_parameters();
        var {
          printTemplateLiteral
        } = require_template_literal();
        var {
          printArrayItems
        } = require_array4();
        var {
          printObject
        } = require_object();
        var {
          printClassProperty,
          printClassMethod
        } = require_class();
        var {
          printTypeParameter,
          printTypeParameters
        } = require_type_parameters();
        var {
          printPropertyKey
        } = require_property2();
        var {
          printFunction,
          printMethodInternal
        } = require_function();
        var {
          printInterface
        } = require_interface();
        var {
          printBlock
        } = require_block();
        var {
          printTypeAlias,
          printIntersectionType,
          printUnionType,
          printFunctionType,
          printTupleType,
          printIndexedAccessType,
          printJSDocType
        } = require_type_annotation();
        function printTypescript(path2, options, print) {
          const node = path2.getValue();
          if (!node.type.startsWith("TS")) {
            return;
          }
          if (isTsKeywordType(node)) {
            return node.type.slice(2, -7).toLowerCase();
          }
          const semi = options.semi ? ";" : "";
          const parts = [];
          switch (node.type) {
            case "TSThisType":
              return "this";
            case "TSTypeAssertion": {
              const shouldBreakAfterCast = !(node.expression.type === "ArrayExpression" || node.expression.type === "ObjectExpression");
              const castGroup = group(["<", indent([softline, print("typeAnnotation")]), softline, ">"]);
              const exprContents = [ifBreak("("), indent([softline, print("expression")]), softline, ifBreak(")")];
              if (shouldBreakAfterCast) {
                return conditionalGroup([[castGroup, print("expression")], [castGroup, group(exprContents, {
                  shouldBreak: true
                })], [castGroup, print("expression")]]);
              }
              return group([castGroup, print("expression")]);
            }
            case "TSDeclareFunction":
              return printFunction(path2, print, options);
            case "TSExportAssignment":
              return ["export = ", print("expression"), semi];
            case "TSModuleBlock":
              return printBlock(path2, options, print);
            case "TSInterfaceBody":
            case "TSTypeLiteral":
              return printObject(path2, options, print);
            case "TSTypeAliasDeclaration":
              return printTypeAlias(path2, options, print);
            case "TSQualifiedName":
              return join(".", [print("left"), print("right")]);
            case "TSAbstractMethodDefinition":
            case "TSDeclareMethod":
              return printClassMethod(path2, options, print);
            case "TSAbstractAccessorProperty":
            case "TSAbstractPropertyDefinition":
              return printClassProperty(path2, options, print);
            case "TSInterfaceHeritage":
            case "TSExpressionWithTypeArguments":
              parts.push(print("expression"));
              if (node.typeParameters) {
                parts.push(print("typeParameters"));
              }
              return parts;
            case "TSTemplateLiteralType":
              return printTemplateLiteral(path2, print, options);
            case "TSNamedTupleMember":
              return [print("label"), node.optional ? "?" : "", ": ", print("elementType")];
            case "TSRestType":
              return ["...", print("typeAnnotation")];
            case "TSOptionalType":
              return [print("typeAnnotation"), "?"];
            case "TSInterfaceDeclaration":
              return printInterface(path2, options, print);
            case "TSClassImplements":
              return [print("expression"), print("typeParameters")];
            case "TSTypeParameterDeclaration":
            case "TSTypeParameterInstantiation":
              return printTypeParameters(path2, options, print, "params");
            case "TSTypeParameter":
              return printTypeParameter(path2, options, print);
            case "TSSatisfiesExpression":
            case "TSAsExpression": {
              const operator = node.type === "TSAsExpression" ? "as" : "satisfies";
              parts.push(print("expression"), ` ${operator} `, print("typeAnnotation"));
              const parent = path2.getParentNode();
              if (isCallExpression2(parent) && parent.callee === node || isMemberExpression(parent) && parent.object === node) {
                return group([indent([softline, ...parts]), softline]);
              }
              return parts;
            }
            case "TSArrayType":
              return [print("elementType"), "[]"];
            case "TSPropertySignature": {
              if (node.readonly) {
                parts.push("readonly ");
              }
              parts.push(printPropertyKey(path2, options, print), printOptionalToken(path2));
              if (node.typeAnnotation) {
                parts.push(": ", print("typeAnnotation"));
              }
              if (node.initializer) {
                parts.push(" = ", print("initializer"));
              }
              return parts;
            }
            case "TSParameterProperty":
              if (node.accessibility) {
                parts.push(node.accessibility + " ");
              }
              if (node.export) {
                parts.push("export ");
              }
              if (node.static) {
                parts.push("static ");
              }
              if (node.override) {
                parts.push("override ");
              }
              if (node.readonly) {
                parts.push("readonly ");
              }
              parts.push(print("parameter"));
              return parts;
            case "TSTypeQuery":
              return ["typeof ", print("exprName"), print("typeParameters")];
            case "TSIndexSignature": {
              const parent = path2.getParentNode();
              const trailingComma = node.parameters.length > 1 ? ifBreak(shouldPrintComma(options) ? "," : "") : "";
              const parametersGroup = group([indent([softline, join([", ", softline], path2.map(print, "parameters"))]), trailingComma, softline]);
              return [node.export ? "export " : "", node.accessibility ? [node.accessibility, " "] : "", node.static ? "static " : "", node.readonly ? "readonly " : "", node.declare ? "declare " : "", "[", node.parameters ? parametersGroup : "", node.typeAnnotation ? "]: " : "]", node.typeAnnotation ? print("typeAnnotation") : "", parent.type === "ClassBody" ? semi : ""];
            }
            case "TSTypePredicate":
              return [node.asserts ? "asserts " : "", print("parameterName"), node.typeAnnotation ? [" is ", print("typeAnnotation")] : ""];
            case "TSNonNullExpression":
              return [print("expression"), "!"];
            case "TSImportType":
              return [!node.isTypeOf ? "" : "typeof ", "import(", print(node.parameter ? "parameter" : "argument"), ")", !node.qualifier ? "" : [".", print("qualifier")], printTypeParameters(path2, options, print, "typeParameters")];
            case "TSLiteralType":
              return print("literal");
            case "TSIndexedAccessType":
              return printIndexedAccessType(path2, options, print);
            case "TSConstructSignatureDeclaration":
            case "TSCallSignatureDeclaration":
            case "TSConstructorType": {
              if (node.type === "TSConstructorType" && node.abstract) {
                parts.push("abstract ");
              }
              if (node.type !== "TSCallSignatureDeclaration") {
                parts.push("new ");
              }
              parts.push(group(printFunctionParameters(path2, print, options, false, true)));
              if (node.returnType || node.typeAnnotation) {
                const isType = node.type === "TSConstructorType";
                parts.push(isType ? " => " : ": ", print("returnType"), print("typeAnnotation"));
              }
              return parts;
            }
            case "TSTypeOperator":
              return [node.operator, " ", print("typeAnnotation")];
            case "TSMappedType": {
              const shouldBreak = hasNewlineInRange(options.originalText, locStart(node), locEnd(node));
              return group(["{", indent([options.bracketSpacing ? line : softline, node.readonly ? [getTypeScriptMappedTypeModifier(node.readonly, "readonly"), " "] : "", printTypeScriptModifiers(path2, options, print), print("typeParameter"), node.optional ? getTypeScriptMappedTypeModifier(node.optional, "?") : "", node.typeAnnotation ? ": " : "", print("typeAnnotation"), ifBreak(semi)]), printDanglingComments(path2, options, true), options.bracketSpacing ? line : softline, "}"], {
                shouldBreak
              });
            }
            case "TSMethodSignature": {
              const kind = node.kind && node.kind !== "method" ? `${node.kind} ` : "";
              parts.push(node.accessibility ? [node.accessibility, " "] : "", kind, node.export ? "export " : "", node.static ? "static " : "", node.readonly ? "readonly " : "", node.abstract ? "abstract " : "", node.declare ? "declare " : "", node.computed ? "[" : "", print("key"), node.computed ? "]" : "", printOptionalToken(path2));
              const parametersDoc = printFunctionParameters(path2, print, options, false, true);
              const returnTypePropertyName = node.returnType ? "returnType" : "typeAnnotation";
              const returnTypeNode = node[returnTypePropertyName];
              const returnTypeDoc = returnTypeNode ? print(returnTypePropertyName) : "";
              const shouldGroupParameters = shouldGroupFunctionParameters(node, returnTypeDoc);
              parts.push(shouldGroupParameters ? group(parametersDoc) : parametersDoc);
              if (returnTypeNode) {
                parts.push(": ", group(returnTypeDoc));
              }
              return group(parts);
            }
            case "TSNamespaceExportDeclaration":
              parts.push("export as namespace ", print("id"));
              if (options.semi) {
                parts.push(";");
              }
              return group(parts);
            case "TSEnumDeclaration":
              if (node.declare) {
                parts.push("declare ");
              }
              if (node.modifiers) {
                parts.push(printTypeScriptModifiers(path2, options, print));
              }
              if (node.const) {
                parts.push("const ");
              }
              parts.push("enum ", print("id"), " ");
              if (node.members.length === 0) {
                parts.push(group(["{", printDanglingComments(path2, options), softline, "}"]));
              } else {
                parts.push(group(["{", indent([hardline, printArrayItems(path2, options, "members", print), shouldPrintComma(options, "es5") ? "," : ""]), printDanglingComments(path2, options, true), hardline, "}"]));
              }
              return parts;
            case "TSEnumMember":
              if (node.computed) {
                parts.push("[", print("id"), "]");
              } else {
                parts.push(print("id"));
              }
              if (node.initializer) {
                parts.push(" = ", print("initializer"));
              }
              return parts;
            case "TSImportEqualsDeclaration":
              if (node.isExport) {
                parts.push("export ");
              }
              parts.push("import ");
              if (node.importKind && node.importKind !== "value") {
                parts.push(node.importKind, " ");
              }
              parts.push(print("id"), " = ", print("moduleReference"));
              if (options.semi) {
                parts.push(";");
              }
              return group(parts);
            case "TSExternalModuleReference":
              return ["require(", print("expression"), ")"];
            case "TSModuleDeclaration": {
              const parent = path2.getParentNode();
              const isExternalModule = isLiteral(node.id);
              const parentIsDeclaration = parent.type === "TSModuleDeclaration";
              const bodyIsDeclaration = node.body && node.body.type === "TSModuleDeclaration";
              if (parentIsDeclaration) {
                parts.push(".");
              } else {
                if (node.declare) {
                  parts.push("declare ");
                }
                parts.push(printTypeScriptModifiers(path2, options, print));
                const textBetweenNodeAndItsId = options.originalText.slice(locStart(node), locStart(node.id));
                const isGlobalDeclaration = node.id.type === "Identifier" && node.id.name === "global" && !/namespace|module/.test(textBetweenNodeAndItsId);
                if (!isGlobalDeclaration) {
                  parts.push(isExternalModule || /(?:^|\s)module(?:\s|$)/.test(textBetweenNodeAndItsId) ? "module " : "namespace ");
                }
              }
              parts.push(print("id"));
              if (bodyIsDeclaration) {
                parts.push(print("body"));
              } else if (node.body) {
                parts.push(" ", group(print("body")));
              } else {
                parts.push(semi);
              }
              return parts;
            }
            case "TSConditionalType":
              return printTernary(path2, options, print);
            case "TSInferType":
              return ["infer", " ", print("typeParameter")];
            case "TSIntersectionType":
              return printIntersectionType(path2, options, print);
            case "TSUnionType":
              return printUnionType(path2, options, print);
            case "TSFunctionType":
              return printFunctionType(path2, options, print);
            case "TSTupleType":
              return printTupleType(path2, options, print);
            case "TSTypeReference":
              return [print("typeName"), printTypeParameters(path2, options, print, "typeParameters")];
            case "TSTypeAnnotation":
              return print("typeAnnotation");
            case "TSEmptyBodyFunctionExpression":
              return printMethodInternal(path2, options, print);
            case "TSJSDocAllType":
              return "*";
            case "TSJSDocUnknownType":
              return "?";
            case "TSJSDocNullableType":
              return printJSDocType(path2, print, "?");
            case "TSJSDocNonNullableType":
              return printJSDocType(path2, print, "!");
            case "TSInstantiationExpression":
              return [print("expression"), print("typeParameters")];
            default:
              throw new Error(`Unknown TypeScript node type: ${JSON.stringify(node.type)}.`);
          }
        }
        module22.exports = {
          printTypescript
        };
      }
    });
    var require_comment2 = __commonJS22({
      "src/language-js/print/comment.js"(exports2, module22) {
        "use strict";
        var {
          hasNewline
        } = require_util6();
        var {
          builders: {
            join,
            hardline
          },
          utils: {
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          isLineComment
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var isBlockComment = require_is_block_comment();
        function printComment(commentPath, options) {
          const comment = commentPath.getValue();
          if (isLineComment(comment)) {
            return options.originalText.slice(locStart(comment), locEnd(comment)).trimEnd();
          }
          if (isBlockComment(comment)) {
            if (isIndentableBlockComment(comment)) {
              const printed = printIndentableBlockComment(comment);
              if (comment.trailing && !hasNewline(options.originalText, locStart(comment), {
                backwards: true
              })) {
                return [hardline, printed];
              }
              return printed;
            }
            const commentEnd = locEnd(comment);
            const isInsideFlowComment = options.originalText.slice(commentEnd - 3, commentEnd) === "*-/";
            return ["/*", replaceTextEndOfLine(comment.value), isInsideFlowComment ? "*-/" : "*/"];
          }
          throw new Error("Not a comment: " + JSON.stringify(comment));
        }
        function isIndentableBlockComment(comment) {
          const lines = `*${comment.value}*`.split("\n");
          return lines.length > 1 && lines.every((line) => line.trim()[0] === "*");
        }
        function printIndentableBlockComment(comment) {
          const lines = comment.value.split("\n");
          return ["/*", join(hardline, lines.map((line, index) => index === 0 ? line.trimEnd() : " " + (index < lines.length - 1 ? line.trim() : line.trimStart()))), "*/"];
        }
        module22.exports = {
          printComment
        };
      }
    });
    var require_literal2 = __commonJS22({
      "src/language-js/print/literal.js"(exports2, module22) {
        "use strict";
        var {
          printString,
          printNumber
        } = require_util6();
        var {
          replaceTextEndOfLine
        } = require_doc_utils();
        var {
          printDirective
        } = require_misc3();
        function printLiteral(path2, options) {
          const node = path2.getNode();
          switch (node.type) {
            case "RegExpLiteral":
              return printRegex(node);
            case "BigIntLiteral":
              return printBigInt(node.bigint || node.extra.raw);
            case "NumericLiteral":
              return printNumber(node.extra.raw);
            case "StringLiteral":
              return replaceTextEndOfLine(printString(node.extra.raw, options));
            case "NullLiteral":
              return "null";
            case "BooleanLiteral":
              return String(node.value);
            case "DecimalLiteral":
              return printNumber(node.value) + "m";
            case "Literal": {
              if (node.regex) {
                return printRegex(node.regex);
              }
              if (node.bigint) {
                return printBigInt(node.raw);
              }
              if (node.decimal) {
                return printNumber(node.decimal) + "m";
              }
              const {
                value: value2
              } = node;
              if (typeof value2 === "number") {
                return printNumber(node.raw);
              }
              if (typeof value2 === "string") {
                return isDirective(path2) ? printDirective(node.raw, options) : replaceTextEndOfLine(printString(node.raw, options));
              }
              return String(value2);
            }
          }
        }
        function isDirective(path2) {
          if (path2.getName() !== "expression") {
            return;
          }
          const parent = path2.getParentNode();
          return parent.type === "ExpressionStatement" && parent.directive;
        }
        function printBigInt(raw) {
          return raw.toLowerCase();
        }
        function printRegex({
          pattern,
          flags
        }) {
          flags = [...flags].sort().join("");
          return `/${pattern}/${flags}`;
        }
        module22.exports = {
          printLiteral
        };
      }
    });
    var require_printer_estree = __commonJS22({
      "src/language-js/printer-estree.js"(exports2, module22) {
        "use strict";
        var {
          printDanglingComments
        } = require_comments2();
        var {
          hasNewline
        } = require_util6();
        var {
          builders: {
            join,
            line,
            hardline,
            softline,
            group,
            indent
          },
          utils: {
            replaceTextEndOfLine
          }
        } = require_doc();
        var embed = require_embed();
        var clean = require_clean();
        var {
          insertPragma
        } = require_pragma();
        var handleComments = require_comments22();
        var pathNeedsParens = require_needs_parens();
        var preprocess = require_print_preprocess();
        var {
          hasFlowShorthandAnnotationComment,
          hasComment,
          CommentCheckFlags,
          isTheOnlyJsxElementInMarkdown,
          isLineComment,
          isNextLineEmpty,
          needsHardlineAfterDanglingComment,
          hasIgnoreComment,
          isCallExpression: isCallExpression2,
          isMemberExpression,
          markerForIfWithoutBlockAndSameLineComment
        } = require_utils72();
        var {
          locStart,
          locEnd
        } = require_loc();
        var isBlockComment = require_is_block_comment();
        var {
          printHtmlBinding,
          isVueEventBindingExpression
        } = require_html_binding();
        var {
          printAngular
        } = require_angular();
        var {
          printJsx,
          hasJsxIgnoreComment
        } = require_jsx4();
        var {
          printFlow
        } = require_flow4();
        var {
          printTypescript
        } = require_typescript4();
        var {
          printOptionalToken,
          printBindExpressionCallee,
          printTypeAnnotation,
          adjustClause,
          printRestSpread,
          printDefiniteToken,
          printDirective
        } = require_misc3();
        var {
          printImportDeclaration,
          printExportDeclaration,
          printExportAllDeclaration,
          printModuleSpecifier
        } = require_module();
        var {
          printTernary
        } = require_ternary();
        var {
          printTemplateLiteral
        } = require_template_literal();
        var {
          printArray
        } = require_array4();
        var {
          printObject
        } = require_object();
        var {
          printClass,
          printClassMethod,
          printClassProperty
        } = require_class();
        var {
          printProperty
        } = require_property2();
        var {
          printFunction,
          printArrowFunction,
          printMethod,
          printReturnStatement,
          printThrowStatement
        } = require_function();
        var {
          printCallExpression
        } = require_call_expression();
        var {
          printVariableDeclarator,
          printAssignmentExpression
        } = require_assignment();
        var {
          printBinaryishExpression
        } = require_binaryish();
        var {
          printSwitchCaseConsequent
        } = require_statement();
        var {
          printMemberExpression
        } = require_member();
        var {
          printBlock,
          printBlockBody
        } = require_block();
        var {
          printComment
        } = require_comment2();
        var {
          printLiteral
        } = require_literal2();
        var {
          printDecorators
        } = require_decorators();
        function genericPrint(path2, options, print, args) {
          const printed = printPathNoParens(path2, options, print, args);
          if (!printed) {
            return "";
          }
          const node = path2.getValue();
          const {
            type
          } = node;
          if (type === "ClassMethod" || type === "ClassPrivateMethod" || type === "ClassProperty" || type === "ClassAccessorProperty" || type === "AccessorProperty" || type === "TSAbstractAccessorProperty" || type === "PropertyDefinition" || type === "TSAbstractPropertyDefinition" || type === "ClassPrivateProperty" || type === "MethodDefinition" || type === "TSAbstractMethodDefinition" || type === "TSDeclareMethod") {
            return printed;
          }
          let parts = [printed];
          const printedDecorators = printDecorators(path2, options, print);
          const isClassExpressionWithDecorators = node.type === "ClassExpression" && printedDecorators;
          if (printedDecorators) {
            parts = [...printedDecorators, printed];
            if (!isClassExpressionWithDecorators) {
              return group(parts);
            }
          }
          const needsParens = pathNeedsParens(path2, options);
          if (!needsParens) {
            if (args && args.needsSemi) {
              parts.unshift(";");
            }
            if (parts.length === 1 && parts[0] === printed) {
              return printed;
            }
            return parts;
          }
          if (isClassExpressionWithDecorators) {
            parts = [indent([line, ...parts])];
          }
          parts.unshift("(");
          if (args && args.needsSemi) {
            parts.unshift(";");
          }
          if (hasFlowShorthandAnnotationComment(node)) {
            const [comment] = node.trailingComments;
            parts.push(" /*", comment.value.trimStart(), "*/");
            comment.printed = true;
          }
          if (isClassExpressionWithDecorators) {
            parts.push(line);
          }
          parts.push(")");
          return parts;
        }
        function printPathNoParens(path2, options, print, args) {
          const node = path2.getValue();
          const semi = options.semi ? ";" : "";
          if (!node) {
            return "";
          }
          if (typeof node === "string") {
            return node;
          }
          for (const printer of [printLiteral, printHtmlBinding, printAngular, printJsx, printFlow, printTypescript]) {
            const printed = printer(path2, options, print);
            if (typeof printed !== "undefined") {
              return printed;
            }
          }
          let parts = [];
          switch (node.type) {
            case "JsExpressionRoot":
              return print("node");
            case "JsonRoot":
              return [print("node"), hardline];
            case "File":
              if (node.program && node.program.interpreter) {
                parts.push(print(["program", "interpreter"]));
              }
              parts.push(print("program"));
              return parts;
            case "Program":
              return printBlockBody(path2, options, print);
            case "EmptyStatement":
              return "";
            case "ExpressionStatement": {
              if (options.parser === "__vue_event_binding" || options.parser === "__vue_ts_event_binding") {
                const parent = path2.getParentNode();
                if (parent.type === "Program" && parent.body.length === 1 && parent.body[0] === node) {
                  return [print("expression"), isVueEventBindingExpression(node.expression) ? ";" : ""];
                }
              }
              const danglingComment = printDanglingComments(path2, options, true, ({
                marker
              }) => marker === markerForIfWithoutBlockAndSameLineComment);
              return [print("expression"), isTheOnlyJsxElementInMarkdown(options, path2) ? "" : semi, danglingComment ? [" ", danglingComment] : ""];
            }
            case "ParenthesizedExpression": {
              const shouldHug = !hasComment(node.expression) && (node.expression.type === "ObjectExpression" || node.expression.type === "ArrayExpression");
              if (shouldHug) {
                return ["(", print("expression"), ")"];
              }
              return group(["(", indent([softline, print("expression")]), softline, ")"]);
            }
            case "AssignmentExpression":
              return printAssignmentExpression(path2, options, print);
            case "VariableDeclarator":
              return printVariableDeclarator(path2, options, print);
            case "BinaryExpression":
            case "LogicalExpression":
              return printBinaryishExpression(path2, options, print);
            case "AssignmentPattern":
              return [print("left"), " = ", print("right")];
            case "OptionalMemberExpression":
            case "MemberExpression": {
              return printMemberExpression(path2, options, print);
            }
            case "MetaProperty":
              return [print("meta"), ".", print("property")];
            case "BindExpression":
              if (node.object) {
                parts.push(print("object"));
              }
              parts.push(group(indent([softline, printBindExpressionCallee(path2, options, print)])));
              return parts;
            case "Identifier": {
              return [node.name, printOptionalToken(path2), printDefiniteToken(path2), printTypeAnnotation(path2, options, print)];
            }
            case "V8IntrinsicIdentifier":
              return ["%", node.name];
            case "SpreadElement":
            case "SpreadElementPattern":
            case "SpreadProperty":
            case "SpreadPropertyPattern":
            case "RestElement":
              return printRestSpread(path2, options, print);
            case "FunctionDeclaration":
            case "FunctionExpression":
              return printFunction(path2, print, options, args);
            case "ArrowFunctionExpression":
              return printArrowFunction(path2, options, print, args);
            case "YieldExpression":
              parts.push("yield");
              if (node.delegate) {
                parts.push("*");
              }
              if (node.argument) {
                parts.push(" ", print("argument"));
              }
              return parts;
            case "AwaitExpression": {
              parts.push("await");
              if (node.argument) {
                parts.push(" ", print("argument"));
                const parent = path2.getParentNode();
                if (isCallExpression2(parent) && parent.callee === node || isMemberExpression(parent) && parent.object === node) {
                  parts = [indent([softline, ...parts]), softline];
                  const parentAwaitOrBlock = path2.findAncestor((node2) => node2.type === "AwaitExpression" || node2.type === "BlockStatement");
                  if (!parentAwaitOrBlock || parentAwaitOrBlock.type !== "AwaitExpression") {
                    return group(parts);
                  }
                }
              }
              return parts;
            }
            case "ExportDefaultDeclaration":
            case "ExportNamedDeclaration":
              return printExportDeclaration(path2, options, print);
            case "ExportAllDeclaration":
              return printExportAllDeclaration(path2, options, print);
            case "ImportDeclaration":
              return printImportDeclaration(path2, options, print);
            case "ImportSpecifier":
            case "ExportSpecifier":
            case "ImportNamespaceSpecifier":
            case "ExportNamespaceSpecifier":
            case "ImportDefaultSpecifier":
            case "ExportDefaultSpecifier":
              return printModuleSpecifier(path2, options, print);
            case "ImportAttribute":
              return [print("key"), ": ", print("value")];
            case "Import":
              return "import";
            case "BlockStatement":
            case "StaticBlock":
            case "ClassBody":
              return printBlock(path2, options, print);
            case "ThrowStatement":
              return printThrowStatement(path2, options, print);
            case "ReturnStatement":
              return printReturnStatement(path2, options, print);
            case "NewExpression":
            case "ImportExpression":
            case "OptionalCallExpression":
            case "CallExpression":
              return printCallExpression(path2, options, print);
            case "ObjectExpression":
            case "ObjectPattern":
            case "RecordExpression":
              return printObject(path2, options, print);
            case "ObjectProperty":
            case "Property":
              if (node.method || node.kind === "get" || node.kind === "set") {
                return printMethod(path2, options, print);
              }
              return printProperty(path2, options, print);
            case "ObjectMethod":
              return printMethod(path2, options, print);
            case "Decorator":
              return ["@", print("expression")];
            case "ArrayExpression":
            case "ArrayPattern":
            case "TupleExpression":
              return printArray(path2, options, print);
            case "SequenceExpression": {
              const parent = path2.getParentNode(0);
              if (parent.type === "ExpressionStatement" || parent.type === "ForStatement") {
                const parts2 = [];
                path2.each((expressionPath, index) => {
                  if (index === 0) {
                    parts2.push(print());
                  } else {
                    parts2.push(",", indent([line, print()]));
                  }
                }, "expressions");
                return group(parts2);
              }
              return group(join([",", line], path2.map(print, "expressions")));
            }
            case "ThisExpression":
              return "this";
            case "Super":
              return "super";
            case "Directive":
              return [print("value"), semi];
            case "DirectiveLiteral":
              return printDirective(node.extra.raw, options);
            case "UnaryExpression":
              parts.push(node.operator);
              if (/[a-z]$/.test(node.operator)) {
                parts.push(" ");
              }
              if (hasComment(node.argument)) {
                parts.push(group(["(", indent([softline, print("argument")]), softline, ")"]));
              } else {
                parts.push(print("argument"));
              }
              return parts;
            case "UpdateExpression":
              parts.push(print("argument"), node.operator);
              if (node.prefix) {
                parts.reverse();
              }
              return parts;
            case "ConditionalExpression":
              return printTernary(path2, options, print);
            case "VariableDeclaration": {
              const printed = path2.map(print, "declarations");
              const parentNode = path2.getParentNode();
              const isParentForLoop = parentNode.type === "ForStatement" || parentNode.type === "ForInStatement" || parentNode.type === "ForOfStatement";
              const hasValue = node.declarations.some((decl) => decl.init);
              let firstVariable;
              if (printed.length === 1 && !hasComment(node.declarations[0])) {
                firstVariable = printed[0];
              } else if (printed.length > 0) {
                firstVariable = indent(printed[0]);
              }
              parts = [node.declare ? "declare " : "", node.kind, firstVariable ? [" ", firstVariable] : "", indent(printed.slice(1).map((p) => [",", hasValue && !isParentForLoop ? hardline : line, p]))];
              if (!(isParentForLoop && parentNode.body !== node)) {
                parts.push(semi);
              }
              return group(parts);
            }
            case "WithStatement":
              return group(["with (", print("object"), ")", adjustClause(node.body, print("body"))]);
            case "IfStatement": {
              const con = adjustClause(node.consequent, print("consequent"));
              const opening = group(["if (", group([indent([softline, print("test")]), softline]), ")", con]);
              parts.push(opening);
              if (node.alternate) {
                const commentOnOwnLine = hasComment(node.consequent, CommentCheckFlags.Trailing | CommentCheckFlags.Line) || needsHardlineAfterDanglingComment(node);
                const elseOnSameLine = node.consequent.type === "BlockStatement" && !commentOnOwnLine;
                parts.push(elseOnSameLine ? " " : hardline);
                if (hasComment(node, CommentCheckFlags.Dangling)) {
                  parts.push(printDanglingComments(path2, options, true), commentOnOwnLine ? hardline : " ");
                }
                parts.push("else", group(adjustClause(node.alternate, print("alternate"), node.alternate.type === "IfStatement")));
              }
              return parts;
            }
            case "ForStatement": {
              const body = adjustClause(node.body, print("body"));
              const dangling = printDanglingComments(path2, options, true);
              const printedComments = dangling ? [dangling, softline] : "";
              if (!node.init && !node.test && !node.update) {
                return [printedComments, group(["for (;;)", body])];
              }
              return [printedComments, group(["for (", group([indent([softline, print("init"), ";", line, print("test"), ";", line, print("update")]), softline]), ")", body])];
            }
            case "WhileStatement":
              return group(["while (", group([indent([softline, print("test")]), softline]), ")", adjustClause(node.body, print("body"))]);
            case "ForInStatement":
              return group(["for (", print("left"), " in ", print("right"), ")", adjustClause(node.body, print("body"))]);
            case "ForOfStatement":
              return group(["for", node.await ? " await" : "", " (", print("left"), " of ", print("right"), ")", adjustClause(node.body, print("body"))]);
            case "DoWhileStatement": {
              const clause = adjustClause(node.body, print("body"));
              const doBody = group(["do", clause]);
              parts = [doBody];
              if (node.body.type === "BlockStatement") {
                parts.push(" ");
              } else {
                parts.push(hardline);
              }
              parts.push("while (", group([indent([softline, print("test")]), softline]), ")", semi);
              return parts;
            }
            case "DoExpression":
              return [node.async ? "async " : "", "do ", print("body")];
            case "BreakStatement":
              parts.push("break");
              if (node.label) {
                parts.push(" ", print("label"));
              }
              parts.push(semi);
              return parts;
            case "ContinueStatement":
              parts.push("continue");
              if (node.label) {
                parts.push(" ", print("label"));
              }
              parts.push(semi);
              return parts;
            case "LabeledStatement":
              if (node.body.type === "EmptyStatement") {
                return [print("label"), ":;"];
              }
              return [print("label"), ": ", print("body")];
            case "TryStatement":
              return ["try ", print("block"), node.handler ? [" ", print("handler")] : "", node.finalizer ? [" finally ", print("finalizer")] : ""];
            case "CatchClause":
              if (node.param) {
                const parameterHasComments = hasComment(node.param, (comment) => !isBlockComment(comment) || comment.leading && hasNewline(options.originalText, locEnd(comment)) || comment.trailing && hasNewline(options.originalText, locStart(comment), {
                  backwards: true
                }));
                const param = print("param");
                return ["catch ", parameterHasComments ? ["(", indent([softline, param]), softline, ") "] : ["(", param, ") "], print("body")];
              }
              return ["catch ", print("body")];
            case "SwitchStatement":
              return [group(["switch (", indent([softline, print("discriminant")]), softline, ")"]), " {", node.cases.length > 0 ? indent([hardline, join(hardline, path2.map((casePath, index, cases) => {
                const caseNode = casePath.getValue();
                return [print(), index !== cases.length - 1 && isNextLineEmpty(caseNode, options) ? hardline : ""];
              }, "cases"))]) : "", hardline, "}"];
            case "SwitchCase": {
              if (node.test) {
                parts.push("case ", print("test"), ":");
              } else {
                parts.push("default:");
              }
              if (hasComment(node, CommentCheckFlags.Dangling)) {
                parts.push(" ", printDanglingComments(path2, options, true));
              }
              const consequent = node.consequent.filter((node2) => node2.type !== "EmptyStatement");
              if (consequent.length > 0) {
                const cons = printSwitchCaseConsequent(path2, options, print);
                parts.push(consequent.length === 1 && consequent[0].type === "BlockStatement" ? [" ", cons] : indent([hardline, cons]));
              }
              return parts;
            }
            case "DebuggerStatement":
              return ["debugger", semi];
            case "ClassDeclaration":
            case "ClassExpression":
              return printClass(path2, options, print);
            case "ClassMethod":
            case "ClassPrivateMethod":
            case "MethodDefinition":
              return printClassMethod(path2, options, print);
            case "ClassProperty":
            case "PropertyDefinition":
            case "ClassPrivateProperty":
            case "ClassAccessorProperty":
            case "AccessorProperty":
              return printClassProperty(path2, options, print);
            case "TemplateElement":
              return replaceTextEndOfLine(node.value.raw);
            case "TemplateLiteral":
              return printTemplateLiteral(path2, print, options);
            case "TaggedTemplateExpression":
              return [print("tag"), print("typeParameters"), print("quasi")];
            case "PrivateIdentifier":
              return ["#", print("name")];
            case "PrivateName":
              return ["#", print("id")];
            case "InterpreterDirective":
              parts.push("#!", node.value, hardline);
              if (isNextLineEmpty(node, options)) {
                parts.push(hardline);
              }
              return parts;
            case "TopicReference":
              return "%";
            case "ArgumentPlaceholder":
              return "?";
            case "ModuleExpression": {
              parts.push("module {");
              const printed = print("body");
              if (printed) {
                parts.push(indent([hardline, printed]), hardline);
              }
              parts.push("}");
              return parts;
            }
            default:
              throw new Error("unknown type: " + JSON.stringify(node.type));
          }
        }
        function canAttachComment(node) {
          return node.type && !isBlockComment(node) && !isLineComment(node) && node.type !== "EmptyStatement" && node.type !== "TemplateElement" && node.type !== "Import" && node.type !== "TSEmptyBodyFunctionExpression";
        }
        module22.exports = {
          preprocess,
          print: genericPrint,
          embed,
          insertPragma,
          massageAstNode: clean,
          hasPrettierIgnore(path2) {
            return hasIgnoreComment(path2) || hasJsxIgnoreComment(path2);
          },
          willPrintOwnComments: handleComments.willPrintOwnComments,
          canAttachComment,
          printComment,
          isBlockComment,
          handleComments: {
            avoidAstMutation: true,
            ownLine: handleComments.handleOwnLineComment,
            endOfLine: handleComments.handleEndOfLineComment,
            remaining: handleComments.handleRemainingComment
          },
          getCommentChildNodes: handleComments.getCommentChildNodes
        };
      }
    });
    var require_printer_estree_json = __commonJS22({
      "src/language-js/printer-estree-json.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            hardline,
            indent,
            join
          }
        } = require_doc();
        var preprocess = require_print_preprocess();
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          switch (node.type) {
            case "JsonRoot":
              return [print("node"), hardline];
            case "ArrayExpression": {
              if (node.elements.length === 0) {
                return "[]";
              }
              const printed = path2.map(() => path2.getValue() === null ? "null" : print(), "elements");
              return ["[", indent([hardline, join([",", hardline], printed)]), hardline, "]"];
            }
            case "ObjectExpression":
              return node.properties.length === 0 ? "{}" : ["{", indent([hardline, join([",", hardline], path2.map(print, "properties"))]), hardline, "}"];
            case "ObjectProperty":
              return [print("key"), ": ", print("value")];
            case "UnaryExpression":
              return [node.operator === "+" ? "" : node.operator, print("argument")];
            case "NullLiteral":
              return "null";
            case "BooleanLiteral":
              return node.value ? "true" : "false";
            case "StringLiteral":
              return JSON.stringify(node.value);
            case "NumericLiteral":
              return isObjectKey2(path2) ? JSON.stringify(String(node.value)) : JSON.stringify(node.value);
            case "Identifier":
              return isObjectKey2(path2) ? JSON.stringify(node.name) : node.name;
            case "TemplateLiteral":
              return print(["quasis", 0]);
            case "TemplateElement":
              return JSON.stringify(node.value.cooked);
            default:
              throw new Error("unknown type: " + JSON.stringify(node.type));
          }
        }
        function isObjectKey2(path2) {
          return path2.getName() === "key" && path2.getParentNode().type === "ObjectProperty";
        }
        var ignoredProperties = /* @__PURE__ */ new Set(["start", "end", "extra", "loc", "comments", "leadingComments", "trailingComments", "innerComments", "errors", "range", "tokens"]);
        function clean(node, newNode) {
          const {
            type
          } = node;
          if (type === "ObjectProperty") {
            const {
              key
            } = node;
            if (key.type === "Identifier") {
              newNode.key = {
                type: "StringLiteral",
                value: key.name
              };
            } else if (key.type === "NumericLiteral") {
              newNode.key = {
                type: "StringLiteral",
                value: String(key.value)
              };
            }
            return;
          }
          if (type === "UnaryExpression" && node.operator === "+") {
            return newNode.argument;
          }
          if (type === "ArrayExpression") {
            for (const [index, element] of node.elements.entries()) {
              if (element === null) {
                newNode.elements.splice(index, 0, {
                  type: "NullLiteral"
                });
              }
            }
            return;
          }
          if (type === "TemplateLiteral") {
            return {
              type: "StringLiteral",
              value: node.quasis[0].value.cooked
            };
          }
        }
        clean.ignoredProperties = ignoredProperties;
        module22.exports = {
          preprocess,
          print: genericPrint,
          massageAstNode: clean
        };
      }
    });
    var require_common_options = __commonJS22({
      "src/common/common-options.js"(exports2, module22) {
        "use strict";
        var CATEGORY_COMMON = "Common";
        module22.exports = {
          bracketSpacing: {
            since: "0.0.0",
            category: CATEGORY_COMMON,
            type: "boolean",
            default: true,
            description: "Print spaces between brackets.",
            oppositeDescription: "Do not print spaces between brackets."
          },
          singleQuote: {
            since: "0.0.0",
            category: CATEGORY_COMMON,
            type: "boolean",
            default: false,
            description: "Use single quotes instead of double quotes."
          },
          proseWrap: {
            since: "1.8.2",
            category: CATEGORY_COMMON,
            type: "choice",
            default: [{
              since: "1.8.2",
              value: true
            }, {
              since: "1.9.0",
              value: "preserve"
            }],
            description: "How to wrap prose.",
            choices: [{
              since: "1.9.0",
              value: "always",
              description: "Wrap prose if it exceeds the print width."
            }, {
              since: "1.9.0",
              value: "never",
              description: "Do not wrap prose."
            }, {
              since: "1.9.0",
              value: "preserve",
              description: "Wrap prose as-is."
            }]
          },
          bracketSameLine: {
            since: "2.4.0",
            category: CATEGORY_COMMON,
            type: "boolean",
            default: false,
            description: "Put > of opening tags on the last line instead of on a new line."
          },
          singleAttributePerLine: {
            since: "2.6.0",
            category: CATEGORY_COMMON,
            type: "boolean",
            default: false,
            description: "Enforce single attribute per line in HTML, Vue and JSX."
          }
        };
      }
    });
    var require_options22 = __commonJS22({
      "src/language-js/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        var CATEGORY_JAVASCRIPT = "JavaScript";
        module22.exports = {
          arrowParens: {
            since: "1.9.0",
            category: CATEGORY_JAVASCRIPT,
            type: "choice",
            default: [{
              since: "1.9.0",
              value: "avoid"
            }, {
              since: "2.0.0",
              value: "always"
            }],
            description: "Include parentheses around a sole arrow function parameter.",
            choices: [{
              value: "always",
              description: "Always include parens. Example: `(x) => x`"
            }, {
              value: "avoid",
              description: "Omit parens when possible. Example: `x => x`"
            }]
          },
          bracketSameLine: commonOptions.bracketSameLine,
          bracketSpacing: commonOptions.bracketSpacing,
          jsxBracketSameLine: {
            since: "0.17.0",
            category: CATEGORY_JAVASCRIPT,
            type: "boolean",
            description: "Put > on the last line instead of at a new line.",
            deprecated: "2.4.0"
          },
          semi: {
            since: "1.0.0",
            category: CATEGORY_JAVASCRIPT,
            type: "boolean",
            default: true,
            description: "Print semicolons.",
            oppositeDescription: "Do not print semicolons, except at the beginning of lines which may need them."
          },
          singleQuote: commonOptions.singleQuote,
          jsxSingleQuote: {
            since: "1.15.0",
            category: CATEGORY_JAVASCRIPT,
            type: "boolean",
            default: false,
            description: "Use single quotes in JSX."
          },
          quoteProps: {
            since: "1.17.0",
            category: CATEGORY_JAVASCRIPT,
            type: "choice",
            default: "as-needed",
            description: "Change when properties in objects are quoted.",
            choices: [{
              value: "as-needed",
              description: "Only add quotes around object properties where required."
            }, {
              value: "consistent",
              description: "If at least one property in an object requires quotes, quote all properties."
            }, {
              value: "preserve",
              description: "Respect the input use of quotes in object properties."
            }]
          },
          trailingComma: {
            since: "0.0.0",
            category: CATEGORY_JAVASCRIPT,
            type: "choice",
            default: [{
              since: "0.0.0",
              value: false
            }, {
              since: "0.19.0",
              value: "none"
            }, {
              since: "2.0.0",
              value: "es5"
            }],
            description: "Print trailing commas wherever possible when multi-line.",
            choices: [{
              value: "es5",
              description: "Trailing commas where valid in ES5 (objects, arrays, etc.)"
            }, {
              value: "none",
              description: "No trailing commas."
            }, {
              value: "all",
              description: "Trailing commas wherever possible (including function arguments)."
            }]
          },
          singleAttributePerLine: commonOptions.singleAttributePerLine
        };
      }
    });
    var require_parsers = __commonJS22({
      "src/language-js/parse/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get babel() {
            return require_parser_babel().parsers.babel;
          },
          get "babel-flow"() {
            return require_parser_babel().parsers["babel-flow"];
          },
          get "babel-ts"() {
            return require_parser_babel().parsers["babel-ts"];
          },
          get json() {
            return require_parser_babel().parsers.json;
          },
          get json5() {
            return require_parser_babel().parsers.json5;
          },
          get "json-stringify"() {
            return require_parser_babel().parsers["json-stringify"];
          },
          get __js_expression() {
            return require_parser_babel().parsers.__js_expression;
          },
          get __vue_expression() {
            return require_parser_babel().parsers.__vue_expression;
          },
          get __vue_ts_expression() {
            return require_parser_babel().parsers.__vue_ts_expression;
          },
          get __vue_event_binding() {
            return require_parser_babel().parsers.__vue_event_binding;
          },
          get __vue_ts_event_binding() {
            return require_parser_babel().parsers.__vue_ts_event_binding;
          },
          get flow() {
            return require_parser_flow().parsers.flow;
          },
          get typescript() {
            return require_parser_typescript().parsers.typescript;
          },
          get __ng_action() {
            return require_parser_angular().parsers.__ng_action;
          },
          get __ng_binding() {
            return require_parser_angular().parsers.__ng_binding;
          },
          get __ng_interpolation() {
            return require_parser_angular().parsers.__ng_interpolation;
          },
          get __ng_directive() {
            return require_parser_angular().parsers.__ng_directive;
          },
          get acorn() {
            return require_parser_espree().parsers.acorn;
          },
          get espree() {
            return require_parser_espree().parsers.espree;
          },
          get meriyah() {
            return require_parser_meriyah().parsers.meriyah;
          },
          get __babel_estree() {
            return require_parser_babel().parsers.__babel_estree;
          }
        };
      }
    });
    var require_JavaScript = __commonJS22({
      "node_modules/linguist-languages/data/JavaScript.json"(exports2, module22) {
        module22.exports = {
          name: "JavaScript",
          type: "programming",
          tmScope: "source.js",
          aceMode: "javascript",
          codemirrorMode: "javascript",
          codemirrorMimeType: "text/javascript",
          color: "#f1e05a",
          aliases: ["js", "node"],
          extensions: [".js", "._js", ".bones", ".cjs", ".es", ".es6", ".frag", ".gs", ".jake", ".javascript", ".jsb", ".jscad", ".jsfl", ".jslib", ".jsm", ".jspre", ".jss", ".jsx", ".mjs", ".njs", ".pac", ".sjs", ".ssjs", ".xsjs", ".xsjslib"],
          filenames: ["Jakefile"],
          interpreters: ["chakra", "d8", "gjs", "js", "node", "nodejs", "qjs", "rhino", "v8", "v8-shell"],
          languageId: 183
        };
      }
    });
    var require_TypeScript = __commonJS22({
      "node_modules/linguist-languages/data/TypeScript.json"(exports2, module22) {
        module22.exports = {
          name: "TypeScript",
          type: "programming",
          color: "#3178c6",
          aliases: ["ts"],
          interpreters: ["deno", "ts-node"],
          extensions: [".ts", ".cts", ".mts"],
          tmScope: "source.ts",
          aceMode: "typescript",
          codemirrorMode: "javascript",
          codemirrorMimeType: "application/typescript",
          languageId: 378
        };
      }
    });
    var require_TSX = __commonJS22({
      "node_modules/linguist-languages/data/TSX.json"(exports2, module22) {
        module22.exports = {
          name: "TSX",
          type: "programming",
          color: "#3178c6",
          group: "TypeScript",
          extensions: [".tsx"],
          tmScope: "source.tsx",
          aceMode: "javascript",
          codemirrorMode: "jsx",
          codemirrorMimeType: "text/jsx",
          languageId: 94901924
        };
      }
    });
    var require_JSON = __commonJS22({
      "node_modules/linguist-languages/data/JSON.json"(exports2, module22) {
        module22.exports = {
          name: "JSON",
          type: "data",
          color: "#292929",
          tmScope: "source.json",
          aceMode: "json",
          codemirrorMode: "javascript",
          codemirrorMimeType: "application/json",
          aliases: ["geojson", "jsonl", "topojson"],
          extensions: [".json", ".4DForm", ".4DProject", ".avsc", ".geojson", ".gltf", ".har", ".ice", ".JSON-tmLanguage", ".jsonl", ".mcmeta", ".tfstate", ".tfstate.backup", ".topojson", ".webapp", ".webmanifest", ".yy", ".yyp"],
          filenames: [".arcconfig", ".auto-changelog", ".c8rc", ".htmlhintrc", ".imgbotconfig", ".nycrc", ".tern-config", ".tern-project", ".watchmanconfig", "Pipfile.lock", "composer.lock", "mcmod.info"],
          languageId: 174
        };
      }
    });
    var require_JSON_with_Comments = __commonJS22({
      "node_modules/linguist-languages/data/JSON with Comments.json"(exports2, module22) {
        module22.exports = {
          name: "JSON with Comments",
          type: "data",
          color: "#292929",
          group: "JSON",
          tmScope: "source.js",
          aceMode: "javascript",
          codemirrorMode: "javascript",
          codemirrorMimeType: "text/javascript",
          aliases: ["jsonc"],
          extensions: [".jsonc", ".code-snippets", ".sublime-build", ".sublime-commands", ".sublime-completions", ".sublime-keymap", ".sublime-macro", ".sublime-menu", ".sublime-mousemap", ".sublime-project", ".sublime-settings", ".sublime-theme", ".sublime-workspace", ".sublime_metrics", ".sublime_session"],
          filenames: [".babelrc", ".devcontainer.json", ".eslintrc.json", ".jscsrc", ".jshintrc", ".jslintrc", "api-extractor.json", "devcontainer.json", "jsconfig.json", "language-configuration.json", "tsconfig.json", "tslint.json"],
          languageId: 423
        };
      }
    });
    var require_JSON5 = __commonJS22({
      "node_modules/linguist-languages/data/JSON5.json"(exports2, module22) {
        module22.exports = {
          name: "JSON5",
          type: "data",
          color: "#267CB9",
          extensions: [".json5"],
          tmScope: "source.js",
          aceMode: "javascript",
          codemirrorMode: "javascript",
          codemirrorMimeType: "application/json",
          languageId: 175
        };
      }
    });
    var require_language_js = __commonJS22({
      "src/language-js/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var estreePrinter = require_printer_estree();
        var estreeJsonPrinter = require_printer_estree_json();
        var options = require_options22();
        var parsers = require_parsers();
        var languages = [createLanguage(require_JavaScript(), (data) => ({
          since: "0.0.0",
          parsers: ["babel", "acorn", "espree", "meriyah", "babel-flow", "babel-ts", "flow", "typescript"],
          vscodeLanguageIds: ["javascript", "mongo"],
          interpreters: [...data.interpreters, "zx"],
          extensions: [...data.extensions.filter((extension) => extension !== ".jsx"), ".wxs"]
        })), createLanguage(require_JavaScript(), () => ({
          name: "Flow",
          since: "0.0.0",
          parsers: ["flow", "babel-flow"],
          vscodeLanguageIds: ["javascript"],
          aliases: [],
          filenames: [],
          extensions: [".js.flow"]
        })), createLanguage(require_JavaScript(), () => ({
          name: "JSX",
          since: "0.0.0",
          parsers: ["babel", "babel-flow", "babel-ts", "flow", "typescript", "espree", "meriyah"],
          vscodeLanguageIds: ["javascriptreact"],
          aliases: void 0,
          filenames: void 0,
          extensions: [".jsx"],
          group: "JavaScript",
          interpreters: void 0,
          tmScope: "source.js.jsx",
          aceMode: "javascript",
          codemirrorMode: "jsx",
          codemirrorMimeType: "text/jsx",
          color: void 0
        })), createLanguage(require_TypeScript(), () => ({
          since: "1.4.0",
          parsers: ["typescript", "babel-ts"],
          vscodeLanguageIds: ["typescript"]
        })), createLanguage(require_TSX(), () => ({
          since: "1.4.0",
          parsers: ["typescript", "babel-ts"],
          vscodeLanguageIds: ["typescriptreact"]
        })), createLanguage(require_JSON(), () => ({
          name: "JSON.stringify",
          since: "1.13.0",
          parsers: ["json-stringify"],
          vscodeLanguageIds: ["json"],
          extensions: [".importmap"],
          filenames: ["package.json", "package-lock.json", "composer.json"]
        })), createLanguage(require_JSON(), (data) => ({
          since: "1.5.0",
          parsers: ["json"],
          vscodeLanguageIds: ["json"],
          extensions: data.extensions.filter((extension) => extension !== ".jsonl")
        })), createLanguage(require_JSON_with_Comments(), (data) => ({
          since: "1.5.0",
          parsers: ["json"],
          vscodeLanguageIds: ["jsonc"],
          filenames: [...data.filenames, ".eslintrc", ".swcrc"]
        })), createLanguage(require_JSON5(), () => ({
          since: "1.13.0",
          parsers: ["json5"],
          vscodeLanguageIds: ["json5"]
        }))];
        var printers = {
          estree: estreePrinter,
          "estree-json": estreeJsonPrinter
        };
        module22.exports = {
          languages,
          options,
          printers,
          parsers
        };
      }
    });
    var require_clean2 = __commonJS22({
      "src/language-css/clean.js"(exports2, module22) {
        "use strict";
        var {
          isFrontMatterNode
        } = require_util6();
        var getLast = require_get_last();
        var ignoredProperties = /* @__PURE__ */ new Set(["raw", "raws", "sourceIndex", "source", "before", "after", "trailingComma"]);
        function clean(ast, newObj, parent) {
          if (isFrontMatterNode(ast) && ast.lang === "yaml") {
            delete newObj.value;
          }
          if (ast.type === "css-comment" && parent.type === "css-root" && parent.nodes.length > 0) {
            if (parent.nodes[0] === ast || isFrontMatterNode(parent.nodes[0]) && parent.nodes[1] === ast) {
              delete newObj.text;
              if (/^\*\s*@(?:format|prettier)\s*$/.test(ast.text)) {
                return null;
              }
            }
            if (parent.type === "css-root" && getLast(parent.nodes) === ast) {
              return null;
            }
          }
          if (ast.type === "value-root") {
            delete newObj.text;
          }
          if (ast.type === "media-query" || ast.type === "media-query-list" || ast.type === "media-feature-expression") {
            delete newObj.value;
          }
          if (ast.type === "css-rule") {
            delete newObj.params;
          }
          if (ast.type === "selector-combinator") {
            newObj.value = newObj.value.replace(/\s+/g, " ");
          }
          if (ast.type === "media-feature") {
            newObj.value = newObj.value.replace(/ /g, "");
          }
          if (ast.type === "value-word" && (ast.isColor && ast.isHex || ["initial", "inherit", "unset", "revert"].includes(newObj.value.replace().toLowerCase())) || ast.type === "media-feature" || ast.type === "selector-root-invalid" || ast.type === "selector-pseudo") {
            newObj.value = newObj.value.toLowerCase();
          }
          if (ast.type === "css-decl") {
            newObj.prop = newObj.prop.toLowerCase();
          }
          if (ast.type === "css-atrule" || ast.type === "css-import") {
            newObj.name = newObj.name.toLowerCase();
          }
          if (ast.type === "value-number") {
            newObj.unit = newObj.unit.toLowerCase();
          }
          if ((ast.type === "media-feature" || ast.type === "media-keyword" || ast.type === "media-type" || ast.type === "media-unknown" || ast.type === "media-url" || ast.type === "media-value" || ast.type === "selector-attribute" || ast.type === "selector-string" || ast.type === "selector-class" || ast.type === "selector-combinator" || ast.type === "value-string") && newObj.value) {
            newObj.value = cleanCSSStrings(newObj.value);
          }
          if (ast.type === "selector-attribute") {
            newObj.attribute = newObj.attribute.trim();
            if (newObj.namespace) {
              if (typeof newObj.namespace === "string") {
                newObj.namespace = newObj.namespace.trim();
                if (newObj.namespace.length === 0) {
                  newObj.namespace = true;
                }
              }
            }
            if (newObj.value) {
              newObj.value = newObj.value.trim().replace(/^["']|["']$/g, "");
              delete newObj.quoted;
            }
          }
          if ((ast.type === "media-value" || ast.type === "media-type" || ast.type === "value-number" || ast.type === "selector-root-invalid" || ast.type === "selector-class" || ast.type === "selector-combinator" || ast.type === "selector-tag") && newObj.value) {
            newObj.value = newObj.value.replace(/([\d+.Ee-]+)([A-Za-z]*)/g, (match, numStr, unit) => {
              const num = Number(numStr);
              return Number.isNaN(num) ? match : num + unit.toLowerCase();
            });
          }
          if (ast.type === "selector-tag") {
            const lowercasedValue = ast.value.toLowerCase();
            if (["from", "to"].includes(lowercasedValue)) {
              newObj.value = lowercasedValue;
            }
          }
          if (ast.type === "css-atrule" && ast.name.toLowerCase() === "supports") {
            delete newObj.value;
          }
          if (ast.type === "selector-unknown") {
            delete newObj.value;
          }
          if (ast.type === "value-comma_group") {
            const index = ast.groups.findIndex((node) => node.type === "value-number" && node.unit === "...");
            if (index !== -1) {
              newObj.groups[index].unit = "";
              newObj.groups.splice(index + 1, 0, {
                type: "value-word",
                value: "...",
                isColor: false,
                isHex: false
              });
            }
          }
          if (ast.type === "value-comma_group" && ast.groups.some((node) => node.type === "value-atword" && node.value.endsWith("[") || node.type === "value-word" && node.value.startsWith("]"))) {
            return {
              type: "value-atword",
              value: ast.groups.map((node) => node.value).join(""),
              group: {
                open: null,
                close: null,
                groups: [],
                type: "value-paren_group"
              }
            };
          }
        }
        clean.ignoredProperties = ignoredProperties;
        function cleanCSSStrings(value2) {
          return value2.replace(/'/g, '"').replace(/\\([^\dA-Fa-f])/g, "$1");
        }
        module22.exports = clean;
      }
    });
    var require_print = __commonJS22({
      "src/utils/front-matter/print.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            hardline,
            markAsRoot
          }
        } = require_doc();
        function print(node, textToDoc) {
          if (node.lang === "yaml") {
            const value2 = node.value.trim();
            const doc2 = value2 ? textToDoc(value2, {
              parser: "yaml"
            }, {
              stripTrailingHardline: true
            }) : "";
            return markAsRoot([node.startDelimiter, hardline, doc2, doc2 ? hardline : "", node.endDelimiter]);
          }
        }
        module22.exports = print;
      }
    });
    var require_embed2 = __commonJS22({
      "src/language-css/embed.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            hardline
          }
        } = require_doc();
        var printFrontMatter = require_print();
        function embed(path2, print, textToDoc) {
          const node = path2.getValue();
          if (node.type === "front-matter") {
            const doc2 = printFrontMatter(node, textToDoc);
            return doc2 ? [doc2, hardline] : "";
          }
        }
        module22.exports = embed;
      }
    });
    var require_parse42 = __commonJS22({
      "src/utils/front-matter/parse.js"(exports2, module22) {
        "use strict";
        var frontMatterRegex = new RegExp("^(?<startDelimiter>-{3}|\\+{3})(?<language>[^\\n]*)\\n(?:|(?<value>.*?)\\n)(?<endDelimiter>\\k<startDelimiter>|\\.{3})[^\\S\\n]*(?:\\n|$)", "s");
        function parse3(text) {
          const match = text.match(frontMatterRegex);
          if (!match) {
            return {
              content: text
            };
          }
          const {
            startDelimiter,
            language,
            value: value2 = "",
            endDelimiter
          } = match.groups;
          let lang = language.trim() || "yaml";
          if (startDelimiter === "+++") {
            lang = "toml";
          }
          if (lang !== "yaml" && startDelimiter !== endDelimiter) {
            return {
              content: text
            };
          }
          const [raw] = match;
          const frontMatter = {
            type: "front-matter",
            lang,
            value: value2,
            startDelimiter,
            endDelimiter,
            raw: raw.replace(/\n$/, "")
          };
          return {
            frontMatter,
            content: raw.replace(/[^\n]/g, " ") + text.slice(raw.length)
          };
        }
        module22.exports = parse3;
      }
    });
    var require_pragma2 = __commonJS22({
      "src/language-css/pragma.js"(exports2, module22) {
        "use strict";
        var jsPragma = require_pragma();
        var parseFrontMatter = require_parse42();
        function hasPragma(text) {
          return jsPragma.hasPragma(parseFrontMatter(text).content);
        }
        function insertPragma(text) {
          const {
            frontMatter,
            content
          } = parseFrontMatter(text);
          return (frontMatter ? frontMatter.raw + "\n\n" : "") + jsPragma.insertPragma(content);
        }
        module22.exports = {
          hasPragma,
          insertPragma
        };
      }
    });
    var require_utils82 = __commonJS22({
      "src/language-css/utils/index.js"(exports2, module22) {
        "use strict";
        var colorAdjusterFunctions = /* @__PURE__ */ new Set(["red", "green", "blue", "alpha", "a", "rgb", "hue", "h", "saturation", "s", "lightness", "l", "whiteness", "w", "blackness", "b", "tint", "shade", "blend", "blenda", "contrast", "hsl", "hsla", "hwb", "hwba"]);
        function getAncestorCounter(path2, typeOrTypes) {
          const types = Array.isArray(typeOrTypes) ? typeOrTypes : [typeOrTypes];
          let counter = -1;
          let ancestorNode;
          while (ancestorNode = path2.getParentNode(++counter)) {
            if (types.includes(ancestorNode.type)) {
              return counter;
            }
          }
          return -1;
        }
        function getAncestorNode(path2, typeOrTypes) {
          const counter = getAncestorCounter(path2, typeOrTypes);
          return counter === -1 ? null : path2.getParentNode(counter);
        }
        function getPropOfDeclNode(path2) {
          var _declAncestorNode$pro;
          const declAncestorNode = getAncestorNode(path2, "css-decl");
          return declAncestorNode === null || declAncestorNode === void 0 ? void 0 : (_declAncestorNode$pro = declAncestorNode.prop) === null || _declAncestorNode$pro === void 0 ? void 0 : _declAncestorNode$pro.toLowerCase();
        }
        var wideKeywords = /* @__PURE__ */ new Set(["initial", "inherit", "unset", "revert"]);
        function isWideKeywords(value2) {
          return wideKeywords.has(value2.toLowerCase());
        }
        function isKeyframeAtRuleKeywords(path2, value2) {
          const atRuleAncestorNode = getAncestorNode(path2, "css-atrule");
          return (atRuleAncestorNode === null || atRuleAncestorNode === void 0 ? void 0 : atRuleAncestorNode.name) && atRuleAncestorNode.name.toLowerCase().endsWith("keyframes") && ["from", "to"].includes(value2.toLowerCase());
        }
        function maybeToLowerCase(value2) {
          return value2.includes("$") || value2.includes("@") || value2.includes("#") || value2.startsWith("%") || value2.startsWith("--") || value2.startsWith(":--") || value2.includes("(") && value2.includes(")") ? value2 : value2.toLowerCase();
        }
        function insideValueFunctionNode(path2, functionName) {
          var _funcAncestorNode$val;
          const funcAncestorNode = getAncestorNode(path2, "value-func");
          return (funcAncestorNode === null || funcAncestorNode === void 0 ? void 0 : (_funcAncestorNode$val = funcAncestorNode.value) === null || _funcAncestorNode$val === void 0 ? void 0 : _funcAncestorNode$val.toLowerCase()) === functionName;
        }
        function insideICSSRuleNode(path2) {
          var _ruleAncestorNode$raw;
          const ruleAncestorNode = getAncestorNode(path2, "css-rule");
          const selector = ruleAncestorNode === null || ruleAncestorNode === void 0 ? void 0 : (_ruleAncestorNode$raw = ruleAncestorNode.raws) === null || _ruleAncestorNode$raw === void 0 ? void 0 : _ruleAncestorNode$raw.selector;
          return selector && (selector.startsWith(":import") || selector.startsWith(":export"));
        }
        function insideAtRuleNode(path2, atRuleNameOrAtRuleNames) {
          const atRuleNames = Array.isArray(atRuleNameOrAtRuleNames) ? atRuleNameOrAtRuleNames : [atRuleNameOrAtRuleNames];
          const atRuleAncestorNode = getAncestorNode(path2, "css-atrule");
          return atRuleAncestorNode && atRuleNames.includes(atRuleAncestorNode.name.toLowerCase());
        }
        function insideURLFunctionInImportAtRuleNode(path2) {
          const node = path2.getValue();
          const atRuleAncestorNode = getAncestorNode(path2, "css-atrule");
          return (atRuleAncestorNode === null || atRuleAncestorNode === void 0 ? void 0 : atRuleAncestorNode.name) === "import" && node.groups[0].value === "url" && node.groups.length === 2;
        }
        function isURLFunctionNode(node) {
          return node.type === "value-func" && node.value.toLowerCase() === "url";
        }
        function isLastNode(path2, node) {
          var _path$getParentNode;
          const nodes = (_path$getParentNode = path2.getParentNode()) === null || _path$getParentNode === void 0 ? void 0 : _path$getParentNode.nodes;
          return nodes && nodes.indexOf(node) === nodes.length - 1;
        }
        function isDetachedRulesetDeclarationNode(node) {
          const {
            selector
          } = node;
          if (!selector) {
            return false;
          }
          return typeof selector === "string" && /^@.+:.*$/.test(selector) || selector.value && /^@.+:.*$/.test(selector.value);
        }
        function isForKeywordNode(node) {
          return node.type === "value-word" && ["from", "through", "end"].includes(node.value);
        }
        function isIfElseKeywordNode(node) {
          return node.type === "value-word" && ["and", "or", "not"].includes(node.value);
        }
        function isEachKeywordNode(node) {
          return node.type === "value-word" && node.value === "in";
        }
        function isMultiplicationNode(node) {
          return node.type === "value-operator" && node.value === "*";
        }
        function isDivisionNode(node) {
          return node.type === "value-operator" && node.value === "/";
        }
        function isAdditionNode(node) {
          return node.type === "value-operator" && node.value === "+";
        }
        function isSubtractionNode(node) {
          return node.type === "value-operator" && node.value === "-";
        }
        function isModuloNode(node) {
          return node.type === "value-operator" && node.value === "%";
        }
        function isMathOperatorNode(node) {
          return isMultiplicationNode(node) || isDivisionNode(node) || isAdditionNode(node) || isSubtractionNode(node) || isModuloNode(node);
        }
        function isEqualityOperatorNode(node) {
          return node.type === "value-word" && ["==", "!="].includes(node.value);
        }
        function isRelationalOperatorNode(node) {
          return node.type === "value-word" && ["<", ">", "<=", ">="].includes(node.value);
        }
        function isSCSSControlDirectiveNode(node) {
          return node.type === "css-atrule" && ["if", "else", "for", "each", "while"].includes(node.name);
        }
        function isDetachedRulesetCallNode(node) {
          var _node$raws;
          return ((_node$raws = node.raws) === null || _node$raws === void 0 ? void 0 : _node$raws.params) && /^\(\s*\)$/.test(node.raws.params);
        }
        function isTemplatePlaceholderNode(node) {
          return node.name.startsWith("prettier-placeholder");
        }
        function isTemplatePropNode(node) {
          return node.prop.startsWith("@prettier-placeholder");
        }
        function isPostcssSimpleVarNode(currentNode, nextNode) {
          return currentNode.value === "$$" && currentNode.type === "value-func" && (nextNode === null || nextNode === void 0 ? void 0 : nextNode.type) === "value-word" && !nextNode.raws.before;
        }
        function hasComposesNode(node) {
          var _node$value, _node$value$group;
          return ((_node$value = node.value) === null || _node$value === void 0 ? void 0 : _node$value.type) === "value-root" && ((_node$value$group = node.value.group) === null || _node$value$group === void 0 ? void 0 : _node$value$group.type) === "value-value" && node.prop.toLowerCase() === "composes";
        }
        function hasParensAroundNode(node) {
          var _node$value2, _node$value2$group, _node$value2$group$gr;
          return ((_node$value2 = node.value) === null || _node$value2 === void 0 ? void 0 : (_node$value2$group = _node$value2.group) === null || _node$value2$group === void 0 ? void 0 : (_node$value2$group$gr = _node$value2$group.group) === null || _node$value2$group$gr === void 0 ? void 0 : _node$value2$group$gr.type) === "value-paren_group" && node.value.group.group.open !== null && node.value.group.group.close !== null;
        }
        function hasEmptyRawBefore(node) {
          var _node$raws2;
          return ((_node$raws2 = node.raws) === null || _node$raws2 === void 0 ? void 0 : _node$raws2.before) === "";
        }
        function isKeyValuePairNode(node) {
          var _node$groups, _node$groups$;
          return node.type === "value-comma_group" && ((_node$groups = node.groups) === null || _node$groups === void 0 ? void 0 : (_node$groups$ = _node$groups[1]) === null || _node$groups$ === void 0 ? void 0 : _node$groups$.type) === "value-colon";
        }
        function isKeyValuePairInParenGroupNode(node) {
          var _node$groups2;
          return node.type === "value-paren_group" && ((_node$groups2 = node.groups) === null || _node$groups2 === void 0 ? void 0 : _node$groups2[0]) && isKeyValuePairNode(node.groups[0]);
        }
        function isSCSSMapItemNode(path2) {
          var _declNode$prop;
          const node = path2.getValue();
          if (node.groups.length === 0) {
            return false;
          }
          const parentParentNode = path2.getParentNode(1);
          if (!isKeyValuePairInParenGroupNode(node) && !(parentParentNode && isKeyValuePairInParenGroupNode(parentParentNode))) {
            return false;
          }
          const declNode = getAncestorNode(path2, "css-decl");
          if (declNode !== null && declNode !== void 0 && (_declNode$prop = declNode.prop) !== null && _declNode$prop !== void 0 && _declNode$prop.startsWith("$")) {
            return true;
          }
          if (isKeyValuePairInParenGroupNode(parentParentNode)) {
            return true;
          }
          if (parentParentNode.type === "value-func") {
            return true;
          }
          return false;
        }
        function isInlineValueCommentNode(node) {
          return node.type === "value-comment" && node.inline;
        }
        function isHashNode(node) {
          return node.type === "value-word" && node.value === "#";
        }
        function isLeftCurlyBraceNode(node) {
          return node.type === "value-word" && node.value === "{";
        }
        function isRightCurlyBraceNode(node) {
          return node.type === "value-word" && node.value === "}";
        }
        function isWordNode(node) {
          return ["value-word", "value-atword"].includes(node.type);
        }
        function isColonNode(node) {
          return (node === null || node === void 0 ? void 0 : node.type) === "value-colon";
        }
        function isKeyInValuePairNode(node, parentNode) {
          if (!isKeyValuePairNode(parentNode)) {
            return false;
          }
          const {
            groups
          } = parentNode;
          const index = groups.indexOf(node);
          if (index === -1) {
            return false;
          }
          return isColonNode(groups[index + 1]);
        }
        function isMediaAndSupportsKeywords(node) {
          return node.value && ["not", "and", "or"].includes(node.value.toLowerCase());
        }
        function isColorAdjusterFuncNode(node) {
          if (node.type !== "value-func") {
            return false;
          }
          return colorAdjusterFunctions.has(node.value.toLowerCase());
        }
        function lastLineHasInlineComment(text) {
          return /\/\//.test(text.split(/[\n\r]/).pop());
        }
        function isAtWordPlaceholderNode(node) {
          return (node === null || node === void 0 ? void 0 : node.type) === "value-atword" && node.value.startsWith("prettier-placeholder-");
        }
        function isConfigurationNode(node, parentNode) {
          var _node$open, _node$close;
          if (((_node$open = node.open) === null || _node$open === void 0 ? void 0 : _node$open.value) !== "(" || ((_node$close = node.close) === null || _node$close === void 0 ? void 0 : _node$close.value) !== ")" || node.groups.some((group) => group.type !== "value-comma_group")) {
            return false;
          }
          if (parentNode.type === "value-comma_group") {
            const prevIdx = parentNode.groups.indexOf(node) - 1;
            const maybeWithNode = parentNode.groups[prevIdx];
            if ((maybeWithNode === null || maybeWithNode === void 0 ? void 0 : maybeWithNode.type) === "value-word" && maybeWithNode.value === "with") {
              return true;
            }
          }
          return false;
        }
        function isParenGroupNode(node) {
          var _node$open2, _node$close2;
          return node.type === "value-paren_group" && ((_node$open2 = node.open) === null || _node$open2 === void 0 ? void 0 : _node$open2.value) === "(" && ((_node$close2 = node.close) === null || _node$close2 === void 0 ? void 0 : _node$close2.value) === ")";
        }
        module22.exports = {
          getAncestorCounter,
          getAncestorNode,
          getPropOfDeclNode,
          maybeToLowerCase,
          insideValueFunctionNode,
          insideICSSRuleNode,
          insideAtRuleNode,
          insideURLFunctionInImportAtRuleNode,
          isKeyframeAtRuleKeywords,
          isWideKeywords,
          isLastNode,
          isSCSSControlDirectiveNode,
          isDetachedRulesetDeclarationNode,
          isRelationalOperatorNode,
          isEqualityOperatorNode,
          isMultiplicationNode,
          isDivisionNode,
          isAdditionNode,
          isSubtractionNode,
          isModuloNode,
          isMathOperatorNode,
          isEachKeywordNode,
          isForKeywordNode,
          isURLFunctionNode,
          isIfElseKeywordNode,
          hasComposesNode,
          hasParensAroundNode,
          hasEmptyRawBefore,
          isDetachedRulesetCallNode,
          isTemplatePlaceholderNode,
          isTemplatePropNode,
          isPostcssSimpleVarNode,
          isKeyValuePairNode,
          isKeyValuePairInParenGroupNode,
          isKeyInValuePairNode,
          isSCSSMapItemNode,
          isInlineValueCommentNode,
          isHashNode,
          isLeftCurlyBraceNode,
          isRightCurlyBraceNode,
          isWordNode,
          isColonNode,
          isMediaAndSupportsKeywords,
          isColorAdjusterFuncNode,
          lastLineHasInlineComment,
          isAtWordPlaceholderNode,
          isConfigurationNode,
          isParenGroupNode
        };
      }
    });
    var require_line_column_to_index = __commonJS22({
      "src/utils/line-column-to-index.js"(exports2, module22) {
        "use strict";
        module22.exports = function(lineColumn, text) {
          let index = 0;
          for (let i = 0; i < lineColumn.line - 1; ++i) {
            index = text.indexOf("\n", index) + 1;
          }
          return index + lineColumn.column;
        };
      }
    });
    var require_loc2 = __commonJS22({
      "src/language-css/loc.js"(exports2, module22) {
        "use strict";
        var {
          skipEverythingButNewLine
        } = require_skip2();
        var getLast = require_get_last();
        var lineColumnToIndex = require_line_column_to_index();
        function calculateLocStart(node, text) {
          if (typeof node.sourceIndex === "number") {
            return node.sourceIndex;
          }
          return node.source ? lineColumnToIndex(node.source.start, text) - 1 : null;
        }
        function calculateLocEnd(node, text) {
          if (node.type === "css-comment" && node.inline) {
            return skipEverythingButNewLine(text, node.source.startOffset);
          }
          const endNode = node.nodes && getLast(node.nodes);
          if (endNode && node.source && !node.source.end) {
            node = endNode;
          }
          if (node.source && node.source.end) {
            return lineColumnToIndex(node.source.end, text);
          }
          return null;
        }
        function calculateLoc(node, text) {
          if (node.source) {
            node.source.startOffset = calculateLocStart(node, text);
            node.source.endOffset = calculateLocEnd(node, text);
          }
          for (const key in node) {
            const child = node[key];
            if (key === "source" || !child || typeof child !== "object") {
              continue;
            }
            if (child.type === "value-root" || child.type === "value-unknown") {
              calculateValueNodeLoc(child, getValueRootOffset(node), child.text || child.value);
            } else {
              calculateLoc(child, text);
            }
          }
        }
        function calculateValueNodeLoc(node, rootOffset, text) {
          if (node.source) {
            node.source.startOffset = calculateLocStart(node, text) + rootOffset;
            node.source.endOffset = calculateLocEnd(node, text) + rootOffset;
          }
          for (const key in node) {
            const child = node[key];
            if (key === "source" || !child || typeof child !== "object") {
              continue;
            }
            calculateValueNodeLoc(child, rootOffset, text);
          }
        }
        function getValueRootOffset(node) {
          let result = node.source.startOffset;
          if (typeof node.prop === "string") {
            result += node.prop.length;
          }
          if (node.type === "css-atrule" && typeof node.name === "string") {
            result += 1 + node.name.length + node.raws.afterName.match(/^\s*:?\s*/)[0].length;
          }
          if (node.type !== "css-atrule" && node.raws && typeof node.raws.between === "string") {
            result += node.raws.between.length;
          }
          return result;
        }
        function replaceQuotesInInlineComments(text) {
          let state = "initial";
          let stateToReturnFromQuotes = "initial";
          let inlineCommentStartIndex;
          let inlineCommentContainsQuotes = false;
          const inlineCommentsToReplace = [];
          for (let i = 0; i < text.length; i++) {
            const c = text[i];
            switch (state) {
              case "initial":
                if (c === "'") {
                  state = "single-quotes";
                  continue;
                }
                if (c === '"') {
                  state = "double-quotes";
                  continue;
                }
                if ((c === "u" || c === "U") && text.slice(i, i + 4).toLowerCase() === "url(") {
                  state = "url";
                  i += 3;
                  continue;
                }
                if (c === "*" && text[i - 1] === "/") {
                  state = "comment-block";
                  continue;
                }
                if (c === "/" && text[i - 1] === "/") {
                  state = "comment-inline";
                  inlineCommentStartIndex = i - 1;
                  continue;
                }
                continue;
              case "single-quotes":
                if (c === "'" && text[i - 1] !== "\\") {
                  state = stateToReturnFromQuotes;
                  stateToReturnFromQuotes = "initial";
                }
                if (c === "\n" || c === "\r") {
                  return text;
                }
                continue;
              case "double-quotes":
                if (c === '"' && text[i - 1] !== "\\") {
                  state = stateToReturnFromQuotes;
                  stateToReturnFromQuotes = "initial";
                }
                if (c === "\n" || c === "\r") {
                  return text;
                }
                continue;
              case "url":
                if (c === ")") {
                  state = "initial";
                }
                if (c === "\n" || c === "\r") {
                  return text;
                }
                if (c === "'") {
                  state = "single-quotes";
                  stateToReturnFromQuotes = "url";
                  continue;
                }
                if (c === '"') {
                  state = "double-quotes";
                  stateToReturnFromQuotes = "url";
                  continue;
                }
                continue;
              case "comment-block":
                if (c === "/" && text[i - 1] === "*") {
                  state = "initial";
                }
                continue;
              case "comment-inline":
                if (c === '"' || c === "'" || c === "*") {
                  inlineCommentContainsQuotes = true;
                }
                if (c === "\n" || c === "\r") {
                  if (inlineCommentContainsQuotes) {
                    inlineCommentsToReplace.push([inlineCommentStartIndex, i]);
                  }
                  state = "initial";
                  inlineCommentContainsQuotes = false;
                }
                continue;
            }
          }
          for (const [start, end] of inlineCommentsToReplace) {
            text = text.slice(0, start) + text.slice(start, end).replace(/["'*]/g, " ") + text.slice(end);
          }
          return text;
        }
        function locStart(node) {
          return node.source.startOffset;
        }
        function locEnd(node) {
          return node.source.endOffset;
        }
        module22.exports = {
          locStart,
          locEnd,
          calculateLoc,
          replaceQuotesInInlineComments
        };
      }
    });
    var require_is_less_parser = __commonJS22({
      "src/language-css/utils/is-less-parser.js"(exports2, module22) {
        "use strict";
        function isLessParser(options) {
          return options.parser === "css" || options.parser === "less";
        }
        module22.exports = isLessParser;
      }
    });
    var require_is_scss = __commonJS22({
      "src/language-css/utils/is-scss.js"(exports2, module22) {
        "use strict";
        function isSCSS(parser, text) {
          const hasExplicitParserChoice = parser === "less" || parser === "scss";
          const IS_POSSIBLY_SCSS = /(?:\w\s*:\s*[^:}]+|#){|@import[^\n]+(?:url|,)/;
          return hasExplicitParserChoice ? parser === "scss" : IS_POSSIBLY_SCSS.test(text);
        }
        module22.exports = isSCSS;
      }
    });
    var require_css_units_evaluate = __commonJS22({
      "src/language-css/utils/css-units.evaluate.js"(exports2, module22) {
        module22.exports = {
          em: "em",
          rem: "rem",
          ex: "ex",
          rex: "rex",
          cap: "cap",
          rcap: "rcap",
          ch: "ch",
          rch: "rch",
          ic: "ic",
          ric: "ric",
          lh: "lh",
          rlh: "rlh",
          vw: "vw",
          svw: "svw",
          lvw: "lvw",
          dvw: "dvw",
          vh: "vh",
          svh: "svh",
          lvh: "lvh",
          dvh: "dvh",
          vi: "vi",
          svi: "svi",
          lvi: "lvi",
          dvi: "dvi",
          vb: "vb",
          svb: "svb",
          lvb: "lvb",
          dvb: "dvb",
          vmin: "vmin",
          svmin: "svmin",
          lvmin: "lvmin",
          dvmin: "dvmin",
          vmax: "vmax",
          svmax: "svmax",
          lvmax: "lvmax",
          dvmax: "dvmax",
          cm: "cm",
          mm: "mm",
          q: "Q",
          in: "in",
          pt: "pt",
          pc: "pc",
          px: "px",
          deg: "deg",
          grad: "grad",
          rad: "rad",
          turn: "turn",
          s: "s",
          ms: "ms",
          hz: "Hz",
          khz: "kHz",
          dpi: "dpi",
          dpcm: "dpcm",
          dppx: "dppx",
          x: "x"
        };
      }
    });
    var require_print_unit = __commonJS22({
      "src/language-css/utils/print-unit.js"(exports2, module22) {
        "use strict";
        var CSS_UNITS = require_css_units_evaluate();
        function printUnit(unit) {
          const lowercased = unit.toLowerCase();
          return Object.prototype.hasOwnProperty.call(CSS_UNITS, lowercased) ? CSS_UNITS[lowercased] : unit;
        }
        module22.exports = printUnit;
      }
    });
    var require_printer_postcss = __commonJS22({
      "src/language-css/printer-postcss.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        var {
          printNumber,
          printString,
          hasNewline,
          isFrontMatterNode,
          isNextLineEmpty,
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            join,
            line,
            hardline,
            softline,
            group,
            fill,
            indent,
            dedent,
            ifBreak,
            breakParent
          },
          utils: {
            removeLines,
            getDocParts
          }
        } = require_doc();
        var clean = require_clean2();
        var embed = require_embed2();
        var {
          insertPragma
        } = require_pragma2();
        var {
          getAncestorNode,
          getPropOfDeclNode,
          maybeToLowerCase,
          insideValueFunctionNode,
          insideICSSRuleNode,
          insideAtRuleNode,
          insideURLFunctionInImportAtRuleNode,
          isKeyframeAtRuleKeywords,
          isWideKeywords,
          isLastNode,
          isSCSSControlDirectiveNode,
          isDetachedRulesetDeclarationNode,
          isRelationalOperatorNode,
          isEqualityOperatorNode,
          isMultiplicationNode,
          isDivisionNode,
          isAdditionNode,
          isSubtractionNode,
          isMathOperatorNode,
          isEachKeywordNode,
          isForKeywordNode,
          isURLFunctionNode,
          isIfElseKeywordNode,
          hasComposesNode,
          hasParensAroundNode,
          hasEmptyRawBefore,
          isKeyValuePairNode,
          isKeyInValuePairNode,
          isDetachedRulesetCallNode,
          isTemplatePlaceholderNode,
          isTemplatePropNode,
          isPostcssSimpleVarNode,
          isSCSSMapItemNode,
          isInlineValueCommentNode,
          isHashNode,
          isLeftCurlyBraceNode,
          isRightCurlyBraceNode,
          isWordNode,
          isColonNode,
          isMediaAndSupportsKeywords,
          isColorAdjusterFuncNode,
          lastLineHasInlineComment,
          isAtWordPlaceholderNode,
          isConfigurationNode,
          isParenGroupNode
        } = require_utils82();
        var {
          locStart,
          locEnd
        } = require_loc2();
        var isLessParser = require_is_less_parser();
        var isSCSS = require_is_scss();
        var printUnit = require_print_unit();
        function shouldPrintComma(options) {
          return options.trailingComma === "es5" || options.trailingComma === "all";
        }
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          if (!node) {
            return "";
          }
          if (typeof node === "string") {
            return node;
          }
          switch (node.type) {
            case "front-matter":
              return [node.raw, hardline];
            case "css-root": {
              const nodes = printNodeSequence(path2, options, print);
              let after = node.raws.after.trim();
              if (after.startsWith(";")) {
                after = after.slice(1).trim();
              }
              return [nodes, after ? ` ${after}` : "", getDocParts(nodes).length > 0 ? hardline : ""];
            }
            case "css-comment": {
              const isInlineComment = node.inline || node.raws.inline;
              const text = options.originalText.slice(locStart(node), locEnd(node));
              return isInlineComment ? text.trimEnd() : text;
            }
            case "css-rule": {
              return [print("selector"), node.important ? " !important" : "", node.nodes ? [node.selector && node.selector.type === "selector-unknown" && lastLineHasInlineComment(node.selector.value) ? line : " ", "{", node.nodes.length > 0 ? indent([hardline, printNodeSequence(path2, options, print)]) : "", hardline, "}", isDetachedRulesetDeclarationNode(node) ? ";" : ""] : ";"];
            }
            case "css-decl": {
              const parentNode = path2.getParentNode();
              const {
                between: rawBetween
              } = node.raws;
              const trimmedBetween = rawBetween.trim();
              const isColon = trimmedBetween === ":";
              let value2 = hasComposesNode(node) ? removeLines(print("value")) : print("value");
              if (!isColon && lastLineHasInlineComment(trimmedBetween)) {
                value2 = indent([hardline, dedent(value2)]);
              }
              return [node.raws.before.replace(/[\s;]/g, ""), parentNode.type === "css-atrule" && parentNode.variable || insideICSSRuleNode(path2) ? node.prop : maybeToLowerCase(node.prop), trimmedBetween.startsWith("//") ? " " : "", trimmedBetween, node.extend ? "" : " ", isLessParser(options) && node.extend && node.selector ? ["extend(", print("selector"), ")"] : "", value2, node.raws.important ? node.raws.important.replace(/\s*!\s*important/i, " !important") : node.important ? " !important" : "", node.raws.scssDefault ? node.raws.scssDefault.replace(/\s*!default/i, " !default") : node.scssDefault ? " !default" : "", node.raws.scssGlobal ? node.raws.scssGlobal.replace(/\s*!global/i, " !global") : node.scssGlobal ? " !global" : "", node.nodes ? [" {", indent([softline, printNodeSequence(path2, options, print)]), softline, "}"] : isTemplatePropNode(node) && !parentNode.raws.semicolon && options.originalText[locEnd(node) - 1] !== ";" ? "" : options.__isHTMLStyleAttribute && isLastNode(path2, node) ? ifBreak(";") : ";"];
            }
            case "css-atrule": {
              const parentNode = path2.getParentNode();
              const isTemplatePlaceholderNodeWithoutSemiColon = isTemplatePlaceholderNode(node) && !parentNode.raws.semicolon && options.originalText[locEnd(node) - 1] !== ";";
              if (isLessParser(options)) {
                if (node.mixin) {
                  return [print("selector"), node.important ? " !important" : "", isTemplatePlaceholderNodeWithoutSemiColon ? "" : ";"];
                }
                if (node.function) {
                  return [node.name, print("params"), isTemplatePlaceholderNodeWithoutSemiColon ? "" : ";"];
                }
                if (node.variable) {
                  return ["@", node.name, ": ", node.value ? print("value") : "", node.raws.between.trim() ? node.raws.between.trim() + " " : "", node.nodes ? ["{", indent([node.nodes.length > 0 ? softline : "", printNodeSequence(path2, options, print)]), softline, "}"] : "", isTemplatePlaceholderNodeWithoutSemiColon ? "" : ";"];
                }
              }
              return ["@", isDetachedRulesetCallNode(node) || node.name.endsWith(":") ? node.name : maybeToLowerCase(node.name), node.params ? [isDetachedRulesetCallNode(node) ? "" : isTemplatePlaceholderNode(node) ? node.raws.afterName === "" ? "" : node.name.endsWith(":") ? " " : /^\s*\n\s*\n/.test(node.raws.afterName) ? [hardline, hardline] : /^\s*\n/.test(node.raws.afterName) ? hardline : " " : " ", print("params")] : "", node.selector ? indent([" ", print("selector")]) : "", node.value ? group([" ", print("value"), isSCSSControlDirectiveNode(node) ? hasParensAroundNode(node) ? " " : line : ""]) : node.name === "else" ? " " : "", node.nodes ? [isSCSSControlDirectiveNode(node) ? "" : node.selector && !node.selector.nodes && typeof node.selector.value === "string" && lastLineHasInlineComment(node.selector.value) || !node.selector && typeof node.params === "string" && lastLineHasInlineComment(node.params) ? line : " ", "{", indent([node.nodes.length > 0 ? softline : "", printNodeSequence(path2, options, print)]), softline, "}"] : isTemplatePlaceholderNodeWithoutSemiColon ? "" : ";"];
            }
            case "media-query-list": {
              const parts = [];
              path2.each((childPath) => {
                const node2 = childPath.getValue();
                if (node2.type === "media-query" && node2.value === "") {
                  return;
                }
                parts.push(print());
              }, "nodes");
              return group(indent(join(line, parts)));
            }
            case "media-query": {
              return [join(" ", path2.map(print, "nodes")), isLastNode(path2, node) ? "" : ","];
            }
            case "media-type": {
              return adjustNumbers(adjustStrings(node.value, options));
            }
            case "media-feature-expression": {
              if (!node.nodes) {
                return node.value;
              }
              return ["(", ...path2.map(print, "nodes"), ")"];
            }
            case "media-feature": {
              return maybeToLowerCase(adjustStrings(node.value.replace(/ +/g, " "), options));
            }
            case "media-colon": {
              return [node.value, " "];
            }
            case "media-value": {
              return adjustNumbers(adjustStrings(node.value, options));
            }
            case "media-keyword": {
              return adjustStrings(node.value, options);
            }
            case "media-url": {
              return adjustStrings(node.value.replace(/^url\(\s+/gi, "url(").replace(/\s+\)$/g, ")"), options);
            }
            case "media-unknown": {
              return node.value;
            }
            case "selector-root": {
              return group([insideAtRuleNode(path2, "custom-selector") ? [getAncestorNode(path2, "css-atrule").customSelector, line] : "", join([",", insideAtRuleNode(path2, ["extend", "custom-selector", "nest"]) ? line : hardline], path2.map(print, "nodes"))]);
            }
            case "selector-selector": {
              return group(indent(path2.map(print, "nodes")));
            }
            case "selector-comment": {
              return node.value;
            }
            case "selector-string": {
              return adjustStrings(node.value, options);
            }
            case "selector-tag": {
              const parentNode = path2.getParentNode();
              const index = parentNode && parentNode.nodes.indexOf(node);
              const prevNode = index && parentNode.nodes[index - 1];
              return [node.namespace ? [node.namespace === true ? "" : node.namespace.trim(), "|"] : "", prevNode.type === "selector-nesting" ? node.value : adjustNumbers(isKeyframeAtRuleKeywords(path2, node.value) ? node.value.toLowerCase() : node.value)];
            }
            case "selector-id": {
              return ["#", node.value];
            }
            case "selector-class": {
              return [".", adjustNumbers(adjustStrings(node.value, options))];
            }
            case "selector-attribute": {
              var _node$operator;
              return ["[", node.namespace ? [node.namespace === true ? "" : node.namespace.trim(), "|"] : "", node.attribute.trim(), (_node$operator = node.operator) !== null && _node$operator !== void 0 ? _node$operator : "", node.value ? quoteAttributeValue(adjustStrings(node.value.trim(), options), options) : "", node.insensitive ? " i" : "", "]"];
            }
            case "selector-combinator": {
              if (node.value === "+" || node.value === ">" || node.value === "~" || node.value === ">>>") {
                const parentNode = path2.getParentNode();
                const leading2 = parentNode.type === "selector-selector" && parentNode.nodes[0] === node ? "" : line;
                return [leading2, node.value, isLastNode(path2, node) ? "" : " "];
              }
              const leading = node.value.trim().startsWith("(") ? line : "";
              const value2 = adjustNumbers(adjustStrings(node.value.trim(), options)) || line;
              return [leading, value2];
            }
            case "selector-universal": {
              return [node.namespace ? [node.namespace === true ? "" : node.namespace.trim(), "|"] : "", node.value];
            }
            case "selector-pseudo": {
              return [maybeToLowerCase(node.value), isNonEmptyArray(node.nodes) ? group(["(", indent([softline, join([",", line], path2.map(print, "nodes"))]), softline, ")"]) : ""];
            }
            case "selector-nesting": {
              return node.value;
            }
            case "selector-unknown": {
              const ruleAncestorNode = getAncestorNode(path2, "css-rule");
              if (ruleAncestorNode && ruleAncestorNode.isSCSSNesterProperty) {
                return adjustNumbers(adjustStrings(maybeToLowerCase(node.value), options));
              }
              const parentNode = path2.getParentNode();
              if (parentNode.raws && parentNode.raws.selector) {
                const start = locStart(parentNode);
                const end = start + parentNode.raws.selector.length;
                return options.originalText.slice(start, end).trim();
              }
              const grandParent = path2.getParentNode(1);
              if (parentNode.type === "value-paren_group" && grandParent && grandParent.type === "value-func" && grandParent.value === "selector") {
                const start = locEnd(parentNode.open) + 1;
                const end = locStart(parentNode.close);
                const selector = options.originalText.slice(start, end).trim();
                return lastLineHasInlineComment(selector) ? [breakParent, selector] : selector;
              }
              return node.value;
            }
            case "value-value":
            case "value-root": {
              return print("group");
            }
            case "value-comment": {
              return options.originalText.slice(locStart(node), locEnd(node));
            }
            case "value-comma_group": {
              const parentNode = path2.getParentNode();
              const parentParentNode = path2.getParentNode(1);
              const declAncestorProp = getPropOfDeclNode(path2);
              const isGridValue = declAncestorProp && parentNode.type === "value-value" && (declAncestorProp === "grid" || declAncestorProp.startsWith("grid-template"));
              const atRuleAncestorNode = getAncestorNode(path2, "css-atrule");
              const isControlDirective = atRuleAncestorNode && isSCSSControlDirectiveNode(atRuleAncestorNode);
              const hasInlineComment = node.groups.some((node2) => isInlineValueCommentNode(node2));
              const printed = path2.map(print, "groups");
              const parts = [];
              const insideURLFunction = insideValueFunctionNode(path2, "url");
              let insideSCSSInterpolationInString = false;
              let didBreak = false;
              for (let i = 0; i < node.groups.length; ++i) {
                var _iNode$value;
                parts.push(printed[i]);
                const iPrevNode = node.groups[i - 1];
                const iNode = node.groups[i];
                const iNextNode = node.groups[i + 1];
                const iNextNextNode = node.groups[i + 2];
                if (insideURLFunction) {
                  if (iNextNode && isAdditionNode(iNextNode) || isAdditionNode(iNode)) {
                    parts.push(" ");
                  }
                  continue;
                }
                if (insideAtRuleNode(path2, "forward") && iNode.type === "value-word" && iNode.value && iPrevNode !== void 0 && iPrevNode.type === "value-word" && iPrevNode.value === "as" && iNextNode.type === "value-operator" && iNextNode.value === "*") {
                  continue;
                }
                if (!iNextNode) {
                  continue;
                }
                if (iNode.type === "value-word" && iNode.value.endsWith("-") && isAtWordPlaceholderNode(iNextNode)) {
                  continue;
                }
                if (iNode.type === "value-string" && iNode.quoted) {
                  const positionOfOpeningInterpolation = iNode.value.lastIndexOf("#{");
                  const positionOfClosingInterpolation = iNode.value.lastIndexOf("}");
                  if (positionOfOpeningInterpolation !== -1 && positionOfClosingInterpolation !== -1) {
                    insideSCSSInterpolationInString = positionOfOpeningInterpolation > positionOfClosingInterpolation;
                  } else if (positionOfOpeningInterpolation !== -1) {
                    insideSCSSInterpolationInString = true;
                  } else if (positionOfClosingInterpolation !== -1) {
                    insideSCSSInterpolationInString = false;
                  }
                }
                if (insideSCSSInterpolationInString) {
                  continue;
                }
                if (isColonNode(iNode) || isColonNode(iNextNode)) {
                  continue;
                }
                if (iNode.type === "value-atword" && (iNode.value === "" || iNode.value.endsWith("["))) {
                  continue;
                }
                if (iNextNode.type === "value-word" && iNextNode.value.startsWith("]")) {
                  continue;
                }
                if (iNode.value === "~") {
                  continue;
                }
                if (iNode.value && iNode.value.includes("\\") && iNextNode && iNextNode.type !== "value-comment") {
                  continue;
                }
                if (iPrevNode && iPrevNode.value && iPrevNode.value.indexOf("\\") === iPrevNode.value.length - 1 && iNode.type === "value-operator" && iNode.value === "/") {
                  continue;
                }
                if (iNode.value === "\\") {
                  continue;
                }
                if (isPostcssSimpleVarNode(iNode, iNextNode)) {
                  continue;
                }
                if (isHashNode(iNode) || isLeftCurlyBraceNode(iNode) || isRightCurlyBraceNode(iNextNode) || isLeftCurlyBraceNode(iNextNode) && hasEmptyRawBefore(iNextNode) || isRightCurlyBraceNode(iNode) && hasEmptyRawBefore(iNextNode)) {
                  continue;
                }
                if (iNode.value === "--" && isHashNode(iNextNode)) {
                  continue;
                }
                const isMathOperator = isMathOperatorNode(iNode);
                const isNextMathOperator = isMathOperatorNode(iNextNode);
                if ((isMathOperator && isHashNode(iNextNode) || isNextMathOperator && isRightCurlyBraceNode(iNode)) && hasEmptyRawBefore(iNextNode)) {
                  continue;
                }
                if (!iPrevNode && isDivisionNode(iNode)) {
                  continue;
                }
                if (insideValueFunctionNode(path2, "calc") && (isAdditionNode(iNode) || isAdditionNode(iNextNode) || isSubtractionNode(iNode) || isSubtractionNode(iNextNode)) && hasEmptyRawBefore(iNextNode)) {
                  continue;
                }
                const isColorAdjusterNode = (isAdditionNode(iNode) || isSubtractionNode(iNode)) && i === 0 && (iNextNode.type === "value-number" || iNextNode.isHex) && parentParentNode && isColorAdjusterFuncNode(parentParentNode) && !hasEmptyRawBefore(iNextNode);
                const requireSpaceBeforeOperator = iNextNextNode && iNextNextNode.type === "value-func" || iNextNextNode && isWordNode(iNextNextNode) || iNode.type === "value-func" || isWordNode(iNode);
                const requireSpaceAfterOperator = iNextNode.type === "value-func" || isWordNode(iNextNode) || iPrevNode && iPrevNode.type === "value-func" || iPrevNode && isWordNode(iPrevNode);
                if (!(isMultiplicationNode(iNextNode) || isMultiplicationNode(iNode)) && !insideValueFunctionNode(path2, "calc") && !isColorAdjusterNode && (isDivisionNode(iNextNode) && !requireSpaceBeforeOperator || isDivisionNode(iNode) && !requireSpaceAfterOperator || isAdditionNode(iNextNode) && !requireSpaceBeforeOperator || isAdditionNode(iNode) && !requireSpaceAfterOperator || isSubtractionNode(iNextNode) || isSubtractionNode(iNode)) && (hasEmptyRawBefore(iNextNode) || isMathOperator && (!iPrevNode || iPrevNode && isMathOperatorNode(iPrevNode)))) {
                  continue;
                }
                if ((options.parser === "scss" || options.parser === "less") && isMathOperator && iNode.value === "-" && isParenGroupNode(iNextNode) && locEnd(iNode) === locStart(iNextNode.open) && iNextNode.open.value === "(") {
                  continue;
                }
                if (isInlineValueCommentNode(iNode)) {
                  if (parentNode.type === "value-paren_group") {
                    parts.push(dedent(hardline));
                    continue;
                  }
                  parts.push(hardline);
                  continue;
                }
                if (isControlDirective && (isEqualityOperatorNode(iNextNode) || isRelationalOperatorNode(iNextNode) || isIfElseKeywordNode(iNextNode) || isEachKeywordNode(iNode) || isForKeywordNode(iNode))) {
                  parts.push(" ");
                  continue;
                }
                if (atRuleAncestorNode && atRuleAncestorNode.name.toLowerCase() === "namespace") {
                  parts.push(" ");
                  continue;
                }
                if (isGridValue) {
                  if (iNode.source && iNextNode.source && iNode.source.start.line !== iNextNode.source.start.line) {
                    parts.push(hardline);
                    didBreak = true;
                  } else {
                    parts.push(" ");
                  }
                  continue;
                }
                if (isNextMathOperator) {
                  parts.push(" ");
                  continue;
                }
                if (iNextNode && iNextNode.value === "...") {
                  continue;
                }
                if (isAtWordPlaceholderNode(iNode) && isAtWordPlaceholderNode(iNextNode) && locEnd(iNode) === locStart(iNextNode)) {
                  continue;
                }
                if (isAtWordPlaceholderNode(iNode) && isParenGroupNode(iNextNode) && locEnd(iNode) === locStart(iNextNode.open)) {
                  parts.push(softline);
                  continue;
                }
                if (iNode.value === "with" && isParenGroupNode(iNextNode)) {
                  parts.push(" ");
                  continue;
                }
                if ((_iNode$value = iNode.value) !== null && _iNode$value !== void 0 && _iNode$value.endsWith("#") && iNextNode.value === "{" && isParenGroupNode(iNextNode.group)) {
                  continue;
                }
                parts.push(line);
              }
              if (hasInlineComment) {
                parts.push(breakParent);
              }
              if (didBreak) {
                parts.unshift(hardline);
              }
              if (isControlDirective) {
                return group(indent(parts));
              }
              if (insideURLFunctionInImportAtRuleNode(path2)) {
                return group(fill(parts));
              }
              return group(indent(fill(parts)));
            }
            case "value-paren_group": {
              const parentNode = path2.getParentNode();
              if (parentNode && isURLFunctionNode(parentNode) && (node.groups.length === 1 || node.groups.length > 0 && node.groups[0].type === "value-comma_group" && node.groups[0].groups.length > 0 && node.groups[0].groups[0].type === "value-word" && node.groups[0].groups[0].value.startsWith("data:"))) {
                return [node.open ? print("open") : "", join(",", path2.map(print, "groups")), node.close ? print("close") : ""];
              }
              if (!node.open) {
                const printed2 = path2.map(print, "groups");
                const res = [];
                for (let i = 0; i < printed2.length; i++) {
                  if (i !== 0) {
                    res.push([",", line]);
                  }
                  res.push(printed2[i]);
                }
                return group(indent(fill(res)));
              }
              const isSCSSMapItem = isSCSSMapItemNode(path2);
              const lastItem = getLast(node.groups);
              const isLastItemComment = lastItem && lastItem.type === "value-comment";
              const isKey = isKeyInValuePairNode(node, parentNode);
              const isConfiguration = isConfigurationNode(node, parentNode);
              const shouldBreak = isConfiguration || isSCSSMapItem && !isKey;
              const shouldDedent = isConfiguration || isKey;
              const printed = group([node.open ? print("open") : "", indent([softline, join([line], path2.map((childPath, index) => {
                const child = childPath.getValue();
                const isLast = index === node.groups.length - 1;
                let printed2 = [print(), isLast ? "" : ","];
                if (isKeyValuePairNode(child) && child.type === "value-comma_group" && child.groups && child.groups[0].type !== "value-paren_group" && child.groups[2] && child.groups[2].type === "value-paren_group") {
                  const parts = getDocParts(printed2[0].contents.contents);
                  parts[1] = group(parts[1]);
                  printed2 = [group(dedent(printed2))];
                }
                if (!isLast && child.type === "value-comma_group" && isNonEmptyArray(child.groups)) {
                  let last2 = getLast(child.groups);
                  if (!last2.source && last2.close) {
                    last2 = last2.close;
                  }
                  if (last2.source && isNextLineEmpty(options.originalText, last2, locEnd)) {
                    printed2.push(hardline);
                  }
                }
                return printed2;
              }, "groups"))]), ifBreak(!isLastItemComment && isSCSS(options.parser, options.originalText) && isSCSSMapItem && shouldPrintComma(options) ? "," : ""), softline, node.close ? print("close") : ""], {
                shouldBreak
              });
              return shouldDedent ? dedent(printed) : printed;
            }
            case "value-func": {
              return [node.value, insideAtRuleNode(path2, "supports") && isMediaAndSupportsKeywords(node) ? " " : "", print("group")];
            }
            case "value-paren": {
              return node.value;
            }
            case "value-number": {
              return [printCssNumber(node.value), printUnit(node.unit)];
            }
            case "value-operator": {
              return node.value;
            }
            case "value-word": {
              if (node.isColor && node.isHex || isWideKeywords(node.value)) {
                return node.value.toLowerCase();
              }
              return node.value;
            }
            case "value-colon": {
              const parentNode = path2.getParentNode();
              const index = parentNode && parentNode.groups.indexOf(node);
              const prevNode = index && parentNode.groups[index - 1];
              return [node.value, prevNode && typeof prevNode.value === "string" && getLast(prevNode.value) === "\\" || insideValueFunctionNode(path2, "url") ? "" : line];
            }
            case "value-comma": {
              return [node.value, " "];
            }
            case "value-string": {
              return printString(node.raws.quote + node.value + node.raws.quote, options);
            }
            case "value-atword": {
              return ["@", node.value];
            }
            case "value-unicode-range": {
              return node.value;
            }
            case "value-unknown": {
              return node.value;
            }
            default:
              throw new Error(`Unknown postcss type ${JSON.stringify(node.type)}`);
          }
        }
        function printNodeSequence(path2, options, print) {
          const parts = [];
          path2.each((pathChild, i, nodes) => {
            const prevNode = nodes[i - 1];
            if (prevNode && prevNode.type === "css-comment" && prevNode.text.trim() === "prettier-ignore") {
              const childNode = pathChild.getValue();
              parts.push(options.originalText.slice(locStart(childNode), locEnd(childNode)));
            } else {
              parts.push(print());
            }
            if (i !== nodes.length - 1) {
              if (nodes[i + 1].type === "css-comment" && !hasNewline(options.originalText, locStart(nodes[i + 1]), {
                backwards: true
              }) && !isFrontMatterNode(nodes[i]) || nodes[i + 1].type === "css-atrule" && nodes[i + 1].name === "else" && nodes[i].type !== "css-comment") {
                parts.push(" ");
              } else {
                parts.push(options.__isHTMLStyleAttribute ? line : hardline);
                if (isNextLineEmpty(options.originalText, pathChild.getValue(), locEnd) && !isFrontMatterNode(nodes[i])) {
                  parts.push(hardline);
                }
              }
            }
          }, "nodes");
          return parts;
        }
        var STRING_REGEX = /(["'])(?:(?!\1)[^\\]|\\.)*\1/gs;
        var NUMBER_REGEX = /(?:\d*\.\d+|\d+\.?)(?:[Ee][+-]?\d+)?/g;
        var STANDARD_UNIT_REGEX = /[A-Za-z]+/g;
        var WORD_PART_REGEX = /[$@]?[A-Z_a-z\u0080-\uFFFF][\w\u0080-\uFFFF-]*/g;
        var ADJUST_NUMBERS_REGEX = new RegExp(STRING_REGEX.source + `|(${WORD_PART_REGEX.source})?(${NUMBER_REGEX.source})(${STANDARD_UNIT_REGEX.source})?`, "g");
        function adjustStrings(value2, options) {
          return value2.replace(STRING_REGEX, (match) => printString(match, options));
        }
        function quoteAttributeValue(value2, options) {
          const quote = options.singleQuote ? "'" : '"';
          return value2.includes('"') || value2.includes("'") ? value2 : quote + value2 + quote;
        }
        function adjustNumbers(value2) {
          return value2.replace(ADJUST_NUMBERS_REGEX, (match, quote, wordPart, number, unit) => !wordPart && number ? printCssNumber(number) + maybeToLowerCase(unit || "") : match);
        }
        function printCssNumber(rawNumber) {
          return printNumber(rawNumber).replace(/\.0(?=$|e)/, "");
        }
        module22.exports = {
          print: genericPrint,
          embed,
          insertPragma,
          massageAstNode: clean
        };
      }
    });
    var require_options32 = __commonJS22({
      "src/language-css/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        module22.exports = {
          singleQuote: commonOptions.singleQuote
        };
      }
    });
    var require_parsers2 = __commonJS22({
      "src/language-css/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get css() {
            return require_parser_postcss().parsers.css;
          },
          get less() {
            return require_parser_postcss().parsers.less;
          },
          get scss() {
            return require_parser_postcss().parsers.scss;
          }
        };
      }
    });
    var require_CSS = __commonJS22({
      "node_modules/linguist-languages/data/CSS.json"(exports2, module22) {
        module22.exports = {
          name: "CSS",
          type: "markup",
          tmScope: "source.css",
          aceMode: "css",
          codemirrorMode: "css",
          codemirrorMimeType: "text/css",
          color: "#563d7c",
          extensions: [".css"],
          languageId: 50
        };
      }
    });
    var require_PostCSS = __commonJS22({
      "node_modules/linguist-languages/data/PostCSS.json"(exports2, module22) {
        module22.exports = {
          name: "PostCSS",
          type: "markup",
          color: "#dc3a0c",
          tmScope: "source.postcss",
          group: "CSS",
          extensions: [".pcss", ".postcss"],
          aceMode: "text",
          languageId: 262764437
        };
      }
    });
    var require_Less = __commonJS22({
      "node_modules/linguist-languages/data/Less.json"(exports2, module22) {
        module22.exports = {
          name: "Less",
          type: "markup",
          color: "#1d365d",
          aliases: ["less-css"],
          extensions: [".less"],
          tmScope: "source.css.less",
          aceMode: "less",
          codemirrorMode: "css",
          codemirrorMimeType: "text/css",
          languageId: 198
        };
      }
    });
    var require_SCSS = __commonJS22({
      "node_modules/linguist-languages/data/SCSS.json"(exports2, module22) {
        module22.exports = {
          name: "SCSS",
          type: "markup",
          color: "#c6538c",
          tmScope: "source.css.scss",
          aceMode: "scss",
          codemirrorMode: "css",
          codemirrorMimeType: "text/x-scss",
          extensions: [".scss"],
          languageId: 329
        };
      }
    });
    var require_language_css = __commonJS22({
      "src/language-css/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_postcss();
        var options = require_options32();
        var parsers = require_parsers2();
        var languages = [createLanguage(require_CSS(), (data) => ({
          since: "1.4.0",
          parsers: ["css"],
          vscodeLanguageIds: ["css"],
          extensions: [...data.extensions, ".wxss"]
        })), createLanguage(require_PostCSS(), () => ({
          since: "1.4.0",
          parsers: ["css"],
          vscodeLanguageIds: ["postcss"]
        })), createLanguage(require_Less(), () => ({
          since: "1.4.0",
          parsers: ["less"],
          vscodeLanguageIds: ["less"]
        })), createLanguage(require_SCSS(), () => ({
          since: "1.4.0",
          parsers: ["scss"],
          vscodeLanguageIds: ["scss"]
        }))];
        var printers = {
          postcss: printer
        };
        module22.exports = {
          languages,
          options,
          printers,
          parsers
        };
      }
    });
    var require_loc3 = __commonJS22({
      "src/language-handlebars/loc.js"(exports2, module22) {
        "use strict";
        function locStart(node) {
          return node.loc.start.offset;
        }
        function locEnd(node) {
          return node.loc.end.offset;
        }
        module22.exports = {
          locStart,
          locEnd
        };
      }
    });
    var require_clean3 = __commonJS22({
      "src/language-handlebars/clean.js"(exports2, module22) {
        "use strict";
        function clean(ast, newNode) {
          if (ast.type === "TextNode") {
            const trimmed = ast.chars.trim();
            if (!trimmed) {
              return null;
            }
            newNode.chars = trimmed.replace(/[\t\n\f\r ]+/g, " ");
          }
          if (ast.type === "AttrNode" && ast.name.toLowerCase() === "class") {
            delete newNode.value;
          }
        }
        clean.ignoredProperties = /* @__PURE__ */ new Set(["loc", "selfClosing"]);
        module22.exports = clean;
      }
    });
    var require_html_void_elements = __commonJS22({
      "vendors/html-void-elements.json"(exports2, module22) {
        module22.exports = {
          htmlVoidElements: ["area", "base", "basefont", "bgsound", "br", "col", "command", "embed", "frame", "hr", "image", "img", "input", "isindex", "keygen", "link", "menuitem", "meta", "nextid", "param", "source", "track", "wbr"]
        };
      }
    });
    var require_utils92 = __commonJS22({
      "src/language-handlebars/utils.js"(exports2, module22) {
        "use strict";
        var {
          htmlVoidElements
        } = require_html_void_elements();
        var getLast = require_get_last();
        function isLastNodeOfSiblings(path2) {
          const node = path2.getValue();
          const parentNode = path2.getParentNode(0);
          if (isParentOfSomeType(path2, ["ElementNode"]) && getLast(parentNode.children) === node) {
            return true;
          }
          if (isParentOfSomeType(path2, ["Block"]) && getLast(parentNode.body) === node) {
            return true;
          }
          return false;
        }
        function isUppercase(string) {
          return string.toUpperCase() === string;
        }
        function isGlimmerComponent(node) {
          return isNodeOfSomeType(node, ["ElementNode"]) && typeof node.tag === "string" && !node.tag.startsWith(":") && (isUppercase(node.tag[0]) || node.tag.includes("."));
        }
        var voidTags = new Set(htmlVoidElements);
        function isVoid(node) {
          return voidTags.has(node.tag) || node.selfClosing === true || isGlimmerComponent(node) && node.children.every((node2) => isWhitespaceNode(node2));
        }
        function isWhitespaceNode(node) {
          return isNodeOfSomeType(node, ["TextNode"]) && !/\S/.test(node.chars);
        }
        function isNodeOfSomeType(node, types) {
          return node && types.includes(node.type);
        }
        function isParentOfSomeType(path2, types) {
          const parentNode = path2.getParentNode(0);
          return isNodeOfSomeType(parentNode, types);
        }
        function isPreviousNodeOfSomeType(path2, types) {
          const previousNode = getPreviousNode(path2);
          return isNodeOfSomeType(previousNode, types);
        }
        function isNextNodeOfSomeType(path2, types) {
          const nextNode = getNextNode(path2);
          return isNodeOfSomeType(nextNode, types);
        }
        function getSiblingNode(path2, offset) {
          var _path$getParentNode2, _ref7, _ref8, _parentNode$children;
          const node = path2.getValue();
          const parentNode = (_path$getParentNode2 = path2.getParentNode(0)) !== null && _path$getParentNode2 !== void 0 ? _path$getParentNode2 : {};
          const children = (_ref7 = (_ref8 = (_parentNode$children = parentNode.children) !== null && _parentNode$children !== void 0 ? _parentNode$children : parentNode.body) !== null && _ref8 !== void 0 ? _ref8 : parentNode.parts) !== null && _ref7 !== void 0 ? _ref7 : [];
          const index = children.indexOf(node);
          return index !== -1 && children[index + offset];
        }
        function getPreviousNode(path2, lookBack = 1) {
          return getSiblingNode(path2, -lookBack);
        }
        function getNextNode(path2) {
          return getSiblingNode(path2, 1);
        }
        function isPrettierIgnoreNode(node) {
          return isNodeOfSomeType(node, ["MustacheCommentStatement"]) && typeof node.value === "string" && node.value.trim() === "prettier-ignore";
        }
        function hasPrettierIgnore(path2) {
          const node = path2.getValue();
          const previousPreviousNode = getPreviousNode(path2, 2);
          return isPrettierIgnoreNode(node) || isPrettierIgnoreNode(previousPreviousNode);
        }
        module22.exports = {
          getNextNode,
          getPreviousNode,
          hasPrettierIgnore,
          isLastNodeOfSiblings,
          isNextNodeOfSomeType,
          isNodeOfSomeType,
          isParentOfSomeType,
          isPreviousNodeOfSomeType,
          isVoid,
          isWhitespaceNode
        };
      }
    });
    var require_printer_glimmer = __commonJS22({
      "src/language-handlebars/printer-glimmer.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            dedent,
            fill,
            group,
            hardline,
            ifBreak,
            indent,
            join,
            line,
            softline
          },
          utils: {
            getDocParts,
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          getPreferredQuote,
          isNonEmptyArray
        } = require_util6();
        var {
          locStart,
          locEnd
        } = require_loc3();
        var clean = require_clean3();
        var {
          getNextNode,
          getPreviousNode,
          hasPrettierIgnore,
          isLastNodeOfSiblings,
          isNextNodeOfSomeType,
          isNodeOfSomeType,
          isParentOfSomeType,
          isPreviousNodeOfSomeType,
          isVoid,
          isWhitespaceNode
        } = require_utils92();
        var NEWLINES_TO_PRESERVE_MAX = 2;
        function print(path2, options, print2) {
          const node = path2.getValue();
          if (!node) {
            return "";
          }
          if (hasPrettierIgnore(path2)) {
            return options.originalText.slice(locStart(node), locEnd(node));
          }
          const favoriteQuote = options.singleQuote ? "'" : '"';
          switch (node.type) {
            case "Block":
            case "Program":
            case "Template": {
              return group(path2.map(print2, "body"));
            }
            case "ElementNode": {
              const startingTag = group(printStartingTag(path2, print2));
              const escapeNextElementNode = options.htmlWhitespaceSensitivity === "ignore" && isNextNodeOfSomeType(path2, ["ElementNode"]) ? softline : "";
              if (isVoid(node)) {
                return [startingTag, escapeNextElementNode];
              }
              const endingTag = ["</", node.tag, ">"];
              if (node.children.length === 0) {
                return [startingTag, indent(endingTag), escapeNextElementNode];
              }
              if (options.htmlWhitespaceSensitivity === "ignore") {
                return [startingTag, indent(printChildren(path2, options, print2)), hardline, indent(endingTag), escapeNextElementNode];
              }
              return [startingTag, indent(group(printChildren(path2, options, print2))), indent(endingTag), escapeNextElementNode];
            }
            case "BlockStatement": {
              const pp = path2.getParentNode(1);
              const isElseIfLike = pp && pp.inverse && pp.inverse.body.length === 1 && pp.inverse.body[0] === node && pp.inverse.body[0].path.parts[0] === pp.path.parts[0];
              if (isElseIfLike) {
                return [printElseIfLikeBlock(path2, print2, pp.inverse.body[0].path.parts[0]), printProgram(path2, print2, options), printInverse(path2, print2, options)];
              }
              return [printOpenBlock(path2, print2), group([printProgram(path2, print2, options), printInverse(path2, print2, options), printCloseBlock(path2, print2, options)])];
            }
            case "ElementModifierStatement": {
              return group(["{{", printPathAndParams(path2, print2), "}}"]);
            }
            case "MustacheStatement": {
              return group([printOpeningMustache(node), printPathAndParams(path2, print2), printClosingMustache(node)]);
            }
            case "SubExpression": {
              return group(["(", printSubExpressionPathAndParams(path2, print2), softline, ")"]);
            }
            case "AttrNode": {
              const isText = node.value.type === "TextNode";
              const isEmptyText = isText && node.value.chars === "";
              if (isEmptyText && locStart(node.value) === locEnd(node.value)) {
                return node.name;
              }
              const quote = isText ? getPreferredQuote(node.value.chars, favoriteQuote).quote : node.value.type === "ConcatStatement" ? getPreferredQuote(node.value.parts.filter((part) => part.type === "TextNode").map((part) => part.chars).join(""), favoriteQuote).quote : "";
              const valueDoc = print2("value");
              return [node.name, "=", quote, node.name === "class" && quote ? group(indent(valueDoc)) : valueDoc, quote];
            }
            case "ConcatStatement": {
              return path2.map(print2, "parts");
            }
            case "Hash": {
              return join(line, path2.map(print2, "pairs"));
            }
            case "HashPair": {
              return [node.key, "=", print2("value")];
            }
            case "TextNode": {
              let text = node.chars.replace(/{{/g, "\\{{");
              const attrName = getCurrentAttributeName(path2);
              if (attrName) {
                if (attrName === "class") {
                  const formattedClasses = text.trim().split(/\s+/).join(" ");
                  let leadingSpace2 = false;
                  let trailingSpace2 = false;
                  if (isParentOfSomeType(path2, ["ConcatStatement"])) {
                    if (isPreviousNodeOfSomeType(path2, ["MustacheStatement"]) && /^\s/.test(text)) {
                      leadingSpace2 = true;
                    }
                    if (isNextNodeOfSomeType(path2, ["MustacheStatement"]) && /\s$/.test(text) && formattedClasses !== "") {
                      trailingSpace2 = true;
                    }
                  }
                  return [leadingSpace2 ? line : "", formattedClasses, trailingSpace2 ? line : ""];
                }
                return replaceTextEndOfLine(text);
              }
              const whitespacesOnlyRE = /^[\t\n\f\r ]*$/;
              const isWhitespaceOnly = whitespacesOnlyRE.test(text);
              const isFirstElement = !getPreviousNode(path2);
              const isLastElement = !getNextNode(path2);
              if (options.htmlWhitespaceSensitivity !== "ignore") {
                const leadingWhitespacesRE = /^[\t\n\f\r ]*/;
                const trailingWhitespacesRE = /[\t\n\f\r ]*$/;
                const shouldTrimTrailingNewlines = isLastElement && isParentOfSomeType(path2, ["Template"]);
                const shouldTrimLeadingNewlines = isFirstElement && isParentOfSomeType(path2, ["Template"]);
                if (isWhitespaceOnly) {
                  if (shouldTrimLeadingNewlines || shouldTrimTrailingNewlines) {
                    return "";
                  }
                  let breaks = [line];
                  const newlines = countNewLines(text);
                  if (newlines) {
                    breaks = generateHardlines(newlines);
                  }
                  if (isLastNodeOfSiblings(path2)) {
                    breaks = breaks.map((newline) => dedent(newline));
                  }
                  return breaks;
                }
                const [lead] = text.match(leadingWhitespacesRE);
                const [tail] = text.match(trailingWhitespacesRE);
                let leadBreaks = [];
                if (lead) {
                  leadBreaks = [line];
                  const leadingNewlines = countNewLines(lead);
                  if (leadingNewlines) {
                    leadBreaks = generateHardlines(leadingNewlines);
                  }
                  text = text.replace(leadingWhitespacesRE, "");
                }
                let trailBreaks = [];
                if (tail) {
                  if (!shouldTrimTrailingNewlines) {
                    trailBreaks = [line];
                    const trailingNewlines = countNewLines(tail);
                    if (trailingNewlines) {
                      trailBreaks = generateHardlines(trailingNewlines);
                    }
                    if (isLastNodeOfSiblings(path2)) {
                      trailBreaks = trailBreaks.map((hardline2) => dedent(hardline2));
                    }
                  }
                  text = text.replace(trailingWhitespacesRE, "");
                }
                return [...leadBreaks, fill(getTextValueParts(text)), ...trailBreaks];
              }
              const lineBreaksCount = countNewLines(text);
              let leadingLineBreaksCount = countLeadingNewLines(text);
              let trailingLineBreaksCount = countTrailingNewLines(text);
              if ((isFirstElement || isLastElement) && isWhitespaceOnly && isParentOfSomeType(path2, ["Block", "ElementNode", "Template"])) {
                return "";
              }
              if (isWhitespaceOnly && lineBreaksCount) {
                leadingLineBreaksCount = Math.min(lineBreaksCount, NEWLINES_TO_PRESERVE_MAX);
                trailingLineBreaksCount = 0;
              } else {
                if (isNextNodeOfSomeType(path2, ["BlockStatement", "ElementNode"])) {
                  trailingLineBreaksCount = Math.max(trailingLineBreaksCount, 1);
                }
                if (isPreviousNodeOfSomeType(path2, ["BlockStatement", "ElementNode"])) {
                  leadingLineBreaksCount = Math.max(leadingLineBreaksCount, 1);
                }
              }
              let leadingSpace = "";
              let trailingSpace = "";
              if (trailingLineBreaksCount === 0 && isNextNodeOfSomeType(path2, ["MustacheStatement"])) {
                trailingSpace = " ";
              }
              if (leadingLineBreaksCount === 0 && isPreviousNodeOfSomeType(path2, ["MustacheStatement"])) {
                leadingSpace = " ";
              }
              if (isFirstElement) {
                leadingLineBreaksCount = 0;
                leadingSpace = "";
              }
              if (isLastElement) {
                trailingLineBreaksCount = 0;
                trailingSpace = "";
              }
              text = text.replace(/^[\t\n\f\r ]+/g, leadingSpace).replace(/[\t\n\f\r ]+$/, trailingSpace);
              return [...generateHardlines(leadingLineBreaksCount), fill(getTextValueParts(text)), ...generateHardlines(trailingLineBreaksCount)];
            }
            case "MustacheCommentStatement": {
              const start = locStart(node);
              const end = locEnd(node);
              const isLeftWhiteSpaceSensitive = options.originalText.charAt(start + 2) === "~";
              const isRightWhitespaceSensitive = options.originalText.charAt(end - 3) === "~";
              const dashes = node.value.includes("}}") ? "--" : "";
              return ["{{", isLeftWhiteSpaceSensitive ? "~" : "", "!", dashes, node.value, dashes, isRightWhitespaceSensitive ? "~" : "", "}}"];
            }
            case "PathExpression": {
              return node.original;
            }
            case "BooleanLiteral": {
              return String(node.value);
            }
            case "CommentStatement": {
              return ["<!--", node.value, "-->"];
            }
            case "StringLiteral": {
              if (needsOppositeQuote(path2)) {
                const printFavoriteQuote = !options.singleQuote ? "'" : '"';
                return printStringLiteral(node.value, printFavoriteQuote);
              }
              return printStringLiteral(node.value, favoriteQuote);
            }
            case "NumberLiteral": {
              return String(node.value);
            }
            case "UndefinedLiteral": {
              return "undefined";
            }
            case "NullLiteral": {
              return "null";
            }
            default:
              throw new Error("unknown glimmer type: " + JSON.stringify(node.type));
          }
        }
        function sortByLoc(a, b) {
          return locStart(a) - locStart(b);
        }
        function printStartingTag(path2, print2) {
          const node = path2.getValue();
          const types = ["attributes", "modifiers", "comments"].filter((property) => isNonEmptyArray(node[property]));
          const attributes = types.flatMap((type) => node[type]).sort(sortByLoc);
          for (const attributeType of types) {
            path2.each((attributePath) => {
              const index = attributes.indexOf(attributePath.getValue());
              attributes.splice(index, 1, [line, print2()]);
            }, attributeType);
          }
          if (isNonEmptyArray(node.blockParams)) {
            attributes.push(line, printBlockParams(node));
          }
          return ["<", node.tag, indent(attributes), printStartingTagEndMarker(node)];
        }
        function printChildren(path2, options, print2) {
          const node = path2.getValue();
          const isEmpty2 = node.children.every((node2) => isWhitespaceNode(node2));
          if (options.htmlWhitespaceSensitivity === "ignore" && isEmpty2) {
            return "";
          }
          return path2.map((childPath, childIndex) => {
            const printedChild = print2();
            if (childIndex === 0 && options.htmlWhitespaceSensitivity === "ignore") {
              return [softline, printedChild];
            }
            return printedChild;
          }, "children");
        }
        function printStartingTagEndMarker(node) {
          if (isVoid(node)) {
            return ifBreak([softline, "/>"], [" />", softline]);
          }
          return ifBreak([softline, ">"], ">");
        }
        function printOpeningMustache(node) {
          const mustache = node.escaped === false ? "{{{" : "{{";
          const strip = node.strip && node.strip.open ? "~" : "";
          return [mustache, strip];
        }
        function printClosingMustache(node) {
          const mustache = node.escaped === false ? "}}}" : "}}";
          const strip = node.strip && node.strip.close ? "~" : "";
          return [strip, mustache];
        }
        function printOpeningBlockOpeningMustache(node) {
          const opening = printOpeningMustache(node);
          const strip = node.openStrip.open ? "~" : "";
          return [opening, strip, "#"];
        }
        function printOpeningBlockClosingMustache(node) {
          const closing = printClosingMustache(node);
          const strip = node.openStrip.close ? "~" : "";
          return [strip, closing];
        }
        function printClosingBlockOpeningMustache(node) {
          const opening = printOpeningMustache(node);
          const strip = node.closeStrip.open ? "~" : "";
          return [opening, strip, "/"];
        }
        function printClosingBlockClosingMustache(node) {
          const closing = printClosingMustache(node);
          const strip = node.closeStrip.close ? "~" : "";
          return [strip, closing];
        }
        function printInverseBlockOpeningMustache(node) {
          const opening = printOpeningMustache(node);
          const strip = node.inverseStrip.open ? "~" : "";
          return [opening, strip];
        }
        function printInverseBlockClosingMustache(node) {
          const closing = printClosingMustache(node);
          const strip = node.inverseStrip.close ? "~" : "";
          return [strip, closing];
        }
        function printOpenBlock(path2, print2) {
          const node = path2.getValue();
          const openingMustache = printOpeningBlockOpeningMustache(node);
          const closingMustache = printOpeningBlockClosingMustache(node);
          const attributes = [printPath(path2, print2)];
          const params = printParams(path2, print2);
          if (params) {
            attributes.push(line, params);
          }
          if (isNonEmptyArray(node.program.blockParams)) {
            const block = printBlockParams(node.program);
            attributes.push(line, block);
          }
          return group([openingMustache, indent(attributes), softline, closingMustache]);
        }
        function printElseBlock(node, options) {
          return [options.htmlWhitespaceSensitivity === "ignore" ? hardline : "", printInverseBlockOpeningMustache(node), "else", printInverseBlockClosingMustache(node)];
        }
        function printElseIfLikeBlock(path2, print2, ifLikeKeyword) {
          const node = path2.getValue();
          let blockParams = [];
          if (isNonEmptyArray(node.program.blockParams)) {
            blockParams = [line, printBlockParams(node.program)];
          }
          const parentNode = path2.getParentNode(1);
          return group([printInverseBlockOpeningMustache(parentNode), indent(group([group(["else", line, ifLikeKeyword]), line, printParams(path2, print2)])), indent(blockParams), softline, printInverseBlockClosingMustache(parentNode)]);
        }
        function printCloseBlock(path2, print2, options) {
          const node = path2.getValue();
          if (options.htmlWhitespaceSensitivity === "ignore") {
            const escape2 = blockStatementHasOnlyWhitespaceInProgram(node) ? softline : hardline;
            return [escape2, printClosingBlockOpeningMustache(node), print2("path"), printClosingBlockClosingMustache(node)];
          }
          return [printClosingBlockOpeningMustache(node), print2("path"), printClosingBlockClosingMustache(node)];
        }
        function blockStatementHasOnlyWhitespaceInProgram(node) {
          return isNodeOfSomeType(node, ["BlockStatement"]) && node.program.body.every((node2) => isWhitespaceNode(node2));
        }
        function blockStatementHasElseIfLike(node) {
          return blockStatementHasElse(node) && node.inverse.body.length === 1 && isNodeOfSomeType(node.inverse.body[0], ["BlockStatement"]) && node.inverse.body[0].path.parts[0] === node.path.parts[0];
        }
        function blockStatementHasElse(node) {
          return isNodeOfSomeType(node, ["BlockStatement"]) && node.inverse;
        }
        function printProgram(path2, print2, options) {
          const node = path2.getValue();
          if (blockStatementHasOnlyWhitespaceInProgram(node)) {
            return "";
          }
          const program2 = print2("program");
          if (options.htmlWhitespaceSensitivity === "ignore") {
            return indent([hardline, program2]);
          }
          return indent(program2);
        }
        function printInverse(path2, print2, options) {
          const node = path2.getValue();
          const inverse = print2("inverse");
          const printed = options.htmlWhitespaceSensitivity === "ignore" ? [hardline, inverse] : inverse;
          if (blockStatementHasElseIfLike(node)) {
            return printed;
          }
          if (blockStatementHasElse(node)) {
            return [printElseBlock(node, options), indent(printed)];
          }
          return "";
        }
        function getTextValueParts(value2) {
          return getDocParts(join(line, splitByHtmlWhitespace(value2)));
        }
        function splitByHtmlWhitespace(string) {
          return string.split(/[\t\n\f\r ]+/);
        }
        function getCurrentAttributeName(path2) {
          for (let depth = 0; depth < 2; depth++) {
            const parentNode = path2.getParentNode(depth);
            if (parentNode && parentNode.type === "AttrNode") {
              return parentNode.name.toLowerCase();
            }
          }
        }
        function countNewLines(string) {
          string = typeof string === "string" ? string : "";
          return string.split("\n").length - 1;
        }
        function countLeadingNewLines(string) {
          string = typeof string === "string" ? string : "";
          const newLines = (string.match(/^([^\S\n\r]*[\n\r])+/g) || [])[0] || "";
          return countNewLines(newLines);
        }
        function countTrailingNewLines(string) {
          string = typeof string === "string" ? string : "";
          const newLines = (string.match(/([\n\r][^\S\n\r]*)+$/g) || [])[0] || "";
          return countNewLines(newLines);
        }
        function generateHardlines(number = 0) {
          return Array.from({
            length: Math.min(number, NEWLINES_TO_PRESERVE_MAX)
          }).fill(hardline);
        }
        function printStringLiteral(stringLiteral2, favoriteQuote) {
          const {
            quote,
            regex
          } = getPreferredQuote(stringLiteral2, favoriteQuote);
          return [quote, stringLiteral2.replace(regex, `\\${quote}`), quote];
        }
        function needsOppositeQuote(path2) {
          let index = 0;
          let parentNode = path2.getParentNode(index);
          while (parentNode && isNodeOfSomeType(parentNode, ["SubExpression"])) {
            index++;
            parentNode = path2.getParentNode(index);
          }
          if (parentNode && isNodeOfSomeType(path2.getParentNode(index + 1), ["ConcatStatement"]) && isNodeOfSomeType(path2.getParentNode(index + 2), ["AttrNode"])) {
            return true;
          }
          return false;
        }
        function printSubExpressionPathAndParams(path2, print2) {
          const printed = printPath(path2, print2);
          const params = printParams(path2, print2);
          if (!params) {
            return printed;
          }
          return indent([printed, line, group(params)]);
        }
        function printPathAndParams(path2, print2) {
          const p = printPath(path2, print2);
          const params = printParams(path2, print2);
          if (!params) {
            return p;
          }
          return [indent([p, line, params]), softline];
        }
        function printPath(path2, print2) {
          return print2("path");
        }
        function printParams(path2, print2) {
          const node = path2.getValue();
          const parts = [];
          if (node.params.length > 0) {
            const params = path2.map(print2, "params");
            parts.push(...params);
          }
          if (node.hash && node.hash.pairs.length > 0) {
            const hash = print2("hash");
            parts.push(hash);
          }
          if (parts.length === 0) {
            return "";
          }
          return join(line, parts);
        }
        function printBlockParams(node) {
          return ["as |", node.blockParams.join(" "), "|"];
        }
        module22.exports = {
          print,
          massageAstNode: clean
        };
      }
    });
    var require_parsers3 = __commonJS22({
      "src/language-handlebars/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get glimmer() {
            return require_parser_glimmer().parsers.glimmer;
          }
        };
      }
    });
    var require_Handlebars = __commonJS22({
      "node_modules/linguist-languages/data/Handlebars.json"(exports2, module22) {
        module22.exports = {
          name: "Handlebars",
          type: "markup",
          color: "#f7931e",
          aliases: ["hbs", "htmlbars"],
          extensions: [".handlebars", ".hbs"],
          tmScope: "text.html.handlebars",
          aceMode: "handlebars",
          languageId: 155
        };
      }
    });
    var require_language_handlebars = __commonJS22({
      "src/language-handlebars/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_glimmer();
        var parsers = require_parsers3();
        var languages = [createLanguage(require_Handlebars(), () => ({
          since: "2.3.0",
          parsers: ["glimmer"],
          vscodeLanguageIds: ["handlebars"]
        }))];
        var printers = {
          glimmer: printer
        };
        module22.exports = {
          languages,
          printers,
          parsers
        };
      }
    });
    var require_pragma3 = __commonJS22({
      "src/language-graphql/pragma.js"(exports2, module22) {
        "use strict";
        function hasPragma(text) {
          return /^\s*#[^\S\n]*@(?:format|prettier)\s*(?:\n|$)/.test(text);
        }
        function insertPragma(text) {
          return "# @format\n\n" + text;
        }
        module22.exports = {
          hasPragma,
          insertPragma
        };
      }
    });
    var require_loc4 = __commonJS22({
      "src/language-graphql/loc.js"(exports2, module22) {
        "use strict";
        function locStart(node) {
          if (typeof node.start === "number") {
            return node.start;
          }
          return node.loc && node.loc.start;
        }
        function locEnd(node) {
          if (typeof node.end === "number") {
            return node.end;
          }
          return node.loc && node.loc.end;
        }
        module22.exports = {
          locStart,
          locEnd
        };
      }
    });
    var require_printer_graphql = __commonJS22({
      "src/language-graphql/printer-graphql.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            join,
            hardline,
            line,
            softline,
            group,
            indent,
            ifBreak
          }
        } = require_doc();
        var {
          isNextLineEmpty,
          isNonEmptyArray
        } = require_util6();
        var {
          insertPragma
        } = require_pragma3();
        var {
          locStart,
          locEnd
        } = require_loc4();
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          if (!node) {
            return "";
          }
          if (typeof node === "string") {
            return node;
          }
          switch (node.kind) {
            case "Document": {
              const parts = [];
              path2.each((pathChild, index, definitions) => {
                parts.push(print());
                if (index !== definitions.length - 1) {
                  parts.push(hardline);
                  if (isNextLineEmpty(options.originalText, pathChild.getValue(), locEnd)) {
                    parts.push(hardline);
                  }
                }
              }, "definitions");
              return [...parts, hardline];
            }
            case "OperationDefinition": {
              const hasOperation = options.originalText[locStart(node)] !== "{";
              const hasName = Boolean(node.name);
              return [hasOperation ? node.operation : "", hasOperation && hasName ? [" ", print("name")] : "", hasOperation && !hasName && isNonEmptyArray(node.variableDefinitions) ? " " : "", isNonEmptyArray(node.variableDefinitions) ? group(["(", indent([softline, join([ifBreak("", ", "), softline], path2.map(print, "variableDefinitions"))]), softline, ")"]) : "", printDirectives(path2, print, node), node.selectionSet ? !hasOperation && !hasName ? "" : " " : "", print("selectionSet")];
            }
            case "FragmentDefinition": {
              return ["fragment ", print("name"), isNonEmptyArray(node.variableDefinitions) ? group(["(", indent([softline, join([ifBreak("", ", "), softline], path2.map(print, "variableDefinitions"))]), softline, ")"]) : "", " on ", print("typeCondition"), printDirectives(path2, print, node), " ", print("selectionSet")];
            }
            case "SelectionSet": {
              return ["{", indent([hardline, join(hardline, printSequence(path2, options, print, "selections"))]), hardline, "}"];
            }
            case "Field": {
              return group([node.alias ? [print("alias"), ": "] : "", print("name"), node.arguments.length > 0 ? group(["(", indent([softline, join([ifBreak("", ", "), softline], printSequence(path2, options, print, "arguments"))]), softline, ")"]) : "", printDirectives(path2, print, node), node.selectionSet ? " " : "", print("selectionSet")]);
            }
            case "Name": {
              return node.value;
            }
            case "StringValue": {
              if (node.block) {
                const lines = node.value.replace(/"""/g, "\\$&").split("\n");
                if (lines.length === 1) {
                  lines[0] = lines[0].trim();
                }
                if (lines.every((line2) => line2 === "")) {
                  lines.length = 0;
                }
                return join(hardline, ['"""', ...lines, '"""']);
              }
              return ['"', node.value.replace(/["\\]/g, "\\$&").replace(/\n/g, "\\n"), '"'];
            }
            case "IntValue":
            case "FloatValue":
            case "EnumValue": {
              return node.value;
            }
            case "BooleanValue": {
              return node.value ? "true" : "false";
            }
            case "NullValue": {
              return "null";
            }
            case "Variable": {
              return ["$", print("name")];
            }
            case "ListValue": {
              return group(["[", indent([softline, join([ifBreak("", ", "), softline], path2.map(print, "values"))]), softline, "]"]);
            }
            case "ObjectValue": {
              return group(["{", options.bracketSpacing && node.fields.length > 0 ? " " : "", indent([softline, join([ifBreak("", ", "), softline], path2.map(print, "fields"))]), softline, ifBreak("", options.bracketSpacing && node.fields.length > 0 ? " " : ""), "}"]);
            }
            case "ObjectField":
            case "Argument": {
              return [print("name"), ": ", print("value")];
            }
            case "Directive": {
              return ["@", print("name"), node.arguments.length > 0 ? group(["(", indent([softline, join([ifBreak("", ", "), softline], printSequence(path2, options, print, "arguments"))]), softline, ")"]) : ""];
            }
            case "NamedType": {
              return print("name");
            }
            case "VariableDefinition": {
              return [print("variable"), ": ", print("type"), node.defaultValue ? [" = ", print("defaultValue")] : "", printDirectives(path2, print, node)];
            }
            case "ObjectTypeExtension":
            case "ObjectTypeDefinition": {
              return [print("description"), node.description ? hardline : "", node.kind === "ObjectTypeExtension" ? "extend " : "", "type ", print("name"), node.interfaces.length > 0 ? [" implements ", ...printInterfaces(path2, options, print)] : "", printDirectives(path2, print, node), node.fields.length > 0 ? [" {", indent([hardline, join(hardline, printSequence(path2, options, print, "fields"))]), hardline, "}"] : ""];
            }
            case "FieldDefinition": {
              return [print("description"), node.description ? hardline : "", print("name"), node.arguments.length > 0 ? group(["(", indent([softline, join([ifBreak("", ", "), softline], printSequence(path2, options, print, "arguments"))]), softline, ")"]) : "", ": ", print("type"), printDirectives(path2, print, node)];
            }
            case "DirectiveDefinition": {
              return [print("description"), node.description ? hardline : "", "directive ", "@", print("name"), node.arguments.length > 0 ? group(["(", indent([softline, join([ifBreak("", ", "), softline], printSequence(path2, options, print, "arguments"))]), softline, ")"]) : "", node.repeatable ? " repeatable" : "", " on ", join(" | ", path2.map(print, "locations"))];
            }
            case "EnumTypeExtension":
            case "EnumTypeDefinition": {
              return [print("description"), node.description ? hardline : "", node.kind === "EnumTypeExtension" ? "extend " : "", "enum ", print("name"), printDirectives(path2, print, node), node.values.length > 0 ? [" {", indent([hardline, join(hardline, printSequence(path2, options, print, "values"))]), hardline, "}"] : ""];
            }
            case "EnumValueDefinition": {
              return [print("description"), node.description ? hardline : "", print("name"), printDirectives(path2, print, node)];
            }
            case "InputValueDefinition": {
              return [print("description"), node.description ? node.description.block ? hardline : line : "", print("name"), ": ", print("type"), node.defaultValue ? [" = ", print("defaultValue")] : "", printDirectives(path2, print, node)];
            }
            case "InputObjectTypeExtension":
            case "InputObjectTypeDefinition": {
              return [print("description"), node.description ? hardline : "", node.kind === "InputObjectTypeExtension" ? "extend " : "", "input ", print("name"), printDirectives(path2, print, node), node.fields.length > 0 ? [" {", indent([hardline, join(hardline, printSequence(path2, options, print, "fields"))]), hardline, "}"] : ""];
            }
            case "SchemaExtension": {
              return ["extend schema", printDirectives(path2, print, node), ...node.operationTypes.length > 0 ? [" {", indent([hardline, join(hardline, printSequence(path2, options, print, "operationTypes"))]), hardline, "}"] : []];
            }
            case "SchemaDefinition": {
              return [print("description"), node.description ? hardline : "", "schema", printDirectives(path2, print, node), " {", node.operationTypes.length > 0 ? indent([hardline, join(hardline, printSequence(path2, options, print, "operationTypes"))]) : "", hardline, "}"];
            }
            case "OperationTypeDefinition": {
              return [print("operation"), ": ", print("type")];
            }
            case "InterfaceTypeExtension":
            case "InterfaceTypeDefinition": {
              return [print("description"), node.description ? hardline : "", node.kind === "InterfaceTypeExtension" ? "extend " : "", "interface ", print("name"), node.interfaces.length > 0 ? [" implements ", ...printInterfaces(path2, options, print)] : "", printDirectives(path2, print, node), node.fields.length > 0 ? [" {", indent([hardline, join(hardline, printSequence(path2, options, print, "fields"))]), hardline, "}"] : ""];
            }
            case "FragmentSpread": {
              return ["...", print("name"), printDirectives(path2, print, node)];
            }
            case "InlineFragment": {
              return ["...", node.typeCondition ? [" on ", print("typeCondition")] : "", printDirectives(path2, print, node), " ", print("selectionSet")];
            }
            case "UnionTypeExtension":
            case "UnionTypeDefinition": {
              return group([print("description"), node.description ? hardline : "", group([node.kind === "UnionTypeExtension" ? "extend " : "", "union ", print("name"), printDirectives(path2, print, node), node.types.length > 0 ? [" =", ifBreak("", " "), indent([ifBreak([line, "  "]), join([line, "| "], path2.map(print, "types"))])] : ""])]);
            }
            case "ScalarTypeExtension":
            case "ScalarTypeDefinition": {
              return [print("description"), node.description ? hardline : "", node.kind === "ScalarTypeExtension" ? "extend " : "", "scalar ", print("name"), printDirectives(path2, print, node)];
            }
            case "NonNullType": {
              return [print("type"), "!"];
            }
            case "ListType": {
              return ["[", print("type"), "]"];
            }
            default:
              throw new Error("unknown graphql type: " + JSON.stringify(node.kind));
          }
        }
        function printDirectives(path2, print, node) {
          if (node.directives.length === 0) {
            return "";
          }
          const printed = join(line, path2.map(print, "directives"));
          if (node.kind === "FragmentDefinition" || node.kind === "OperationDefinition") {
            return group([line, printed]);
          }
          return [" ", group(indent([softline, printed]))];
        }
        function printSequence(path2, options, print, property) {
          return path2.map((path22, index, sequence) => {
            const printed = print();
            if (index < sequence.length - 1 && isNextLineEmpty(options.originalText, path22.getValue(), locEnd)) {
              return [printed, hardline];
            }
            return printed;
          }, property);
        }
        function canAttachComment(node) {
          return node.kind && node.kind !== "Comment";
        }
        function printComment(commentPath) {
          const comment = commentPath.getValue();
          if (comment.kind === "Comment") {
            return "#" + comment.value.trimEnd();
          }
          throw new Error("Not a comment: " + JSON.stringify(comment));
        }
        function printInterfaces(path2, options, print) {
          const node = path2.getNode();
          const parts = [];
          const {
            interfaces
          } = node;
          const printed = path2.map((node2) => print(node2), "interfaces");
          for (let index = 0; index < interfaces.length; index++) {
            const interfaceNode = interfaces[index];
            parts.push(printed[index]);
            const nextInterfaceNode = interfaces[index + 1];
            if (nextInterfaceNode) {
              const textBetween = options.originalText.slice(interfaceNode.loc.end, nextInterfaceNode.loc.start);
              const hasComment = textBetween.includes("#");
              const separator = textBetween.replace(/#.*/g, "").trim();
              parts.push(separator === "," ? "," : " &", hasComment ? line : " ");
            }
          }
          return parts;
        }
        function clean(node, newNode) {
          if (node.kind === "StringValue" && node.block && !node.value.includes("\n")) {
            newNode.value = newNode.value.trim();
          }
        }
        clean.ignoredProperties = /* @__PURE__ */ new Set(["loc", "comments"]);
        function hasPrettierIgnore(path2) {
          var _node$comments;
          const node = path2.getValue();
          return node === null || node === void 0 ? void 0 : (_node$comments = node.comments) === null || _node$comments === void 0 ? void 0 : _node$comments.some((comment) => comment.value.trim() === "prettier-ignore");
        }
        module22.exports = {
          print: genericPrint,
          massageAstNode: clean,
          hasPrettierIgnore,
          insertPragma,
          printComment,
          canAttachComment
        };
      }
    });
    var require_options42 = __commonJS22({
      "src/language-graphql/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        module22.exports = {
          bracketSpacing: commonOptions.bracketSpacing
        };
      }
    });
    var require_parsers4 = __commonJS22({
      "src/language-graphql/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get graphql() {
            return require_parser_graphql().parsers.graphql;
          }
        };
      }
    });
    var require_GraphQL = __commonJS22({
      "node_modules/linguist-languages/data/GraphQL.json"(exports2, module22) {
        module22.exports = {
          name: "GraphQL",
          type: "data",
          color: "#e10098",
          extensions: [".graphql", ".gql", ".graphqls"],
          tmScope: "source.graphql",
          aceMode: "text",
          languageId: 139
        };
      }
    });
    var require_language_graphql = __commonJS22({
      "src/language-graphql/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_graphql();
        var options = require_options42();
        var parsers = require_parsers4();
        var languages = [createLanguage(require_GraphQL(), () => ({
          since: "1.5.0",
          parsers: ["graphql"],
          vscodeLanguageIds: ["graphql"]
        }))];
        var printers = {
          graphql: printer
        };
        module22.exports = {
          languages,
          options,
          printers,
          parsers
        };
      }
    });
    var require_collapse_white_space = __commonJS22({
      "node_modules/collapse-white-space/index.js"(exports2, module22) {
        "use strict";
        module22.exports = collapse;
        function collapse(value2) {
          return String(value2).replace(/\s+/g, " ");
        }
      }
    });
    var require_loc5 = __commonJS22({
      "src/language-markdown/loc.js"(exports2, module22) {
        "use strict";
        function locStart(node) {
          return node.position.start.offset;
        }
        function locEnd(node) {
          return node.position.end.offset;
        }
        module22.exports = {
          locStart,
          locEnd
        };
      }
    });
    var require_constants_evaluate = __commonJS22({
      "src/language-markdown/constants.evaluate.js"(exports2, module22) {
        module22.exports = {
          cjkPattern: "(?:[\\u02ea-\\u02eb\\u1100-\\u11ff\\u2e80-\\u2e99\\u2e9b-\\u2ef3\\u2f00-\\u2fd5\\u2ff0-\\u303f\\u3041-\\u3096\\u3099-\\u309f\\u30a1-\\u30fa\\u30fc-\\u30ff\\u3105-\\u312f\\u3131-\\u318e\\u3190-\\u3191\\u3196-\\u31ba\\u31c0-\\u31e3\\u31f0-\\u321e\\u322a-\\u3247\\u3260-\\u327e\\u328a-\\u32b0\\u32c0-\\u32cb\\u32d0-\\u3370\\u337b-\\u337f\\u33e0-\\u33fe\\u3400-\\u4db5\\u4e00-\\u9fef\\ua960-\\ua97c\\uac00-\\ud7a3\\ud7b0-\\ud7c6\\ud7cb-\\ud7fb\\uf900-\\ufa6d\\ufa70-\\ufad9\\ufe10-\\ufe1f\\ufe30-\\ufe6f\\uff00-\\uffef]|[\\ud840-\\ud868\\ud86a-\\ud86c\\ud86f-\\ud872\\ud874-\\ud879][\\udc00-\\udfff]|\\ud82c[\\udc00-\\udd1e\\udd50-\\udd52\\udd64-\\udd67]|\\ud83c[\\ude00\\ude50-\\ude51]|\\ud869[\\udc00-\\uded6\\udf00-\\udfff]|\\ud86d[\\udc00-\\udf34\\udf40-\\udfff]|\\ud86e[\\udc00-\\udc1d\\udc20-\\udfff]|\\ud873[\\udc00-\\udea1\\udeb0-\\udfff]|\\ud87a[\\udc00-\\udfe0]|\\ud87e[\\udc00-\\ude1d])(?:[\\ufe00-\\ufe0f]|\\udb40[\\udd00-\\uddef])?",
          kPattern: "[\\u1100-\\u11ff\\u3001-\\u3003\\u3008-\\u3011\\u3013-\\u301f\\u302e-\\u3030\\u3037\\u30fb\\u3131-\\u318e\\u3200-\\u321e\\u3260-\\u327e\\ua960-\\ua97c\\uac00-\\ud7a3\\ud7b0-\\ud7c6\\ud7cb-\\ud7fb\\ufe45-\\ufe46\\uff61-\\uff65\\uffa0-\\uffbe\\uffc2-\\uffc7\\uffca-\\uffcf\\uffd2-\\uffd7\\uffda-\\uffdc]",
          punctuationPattern: "[\\u0021-\\u002f\\u003a-\\u0040\\u005b-\\u0060\\u007b-\\u007e\\u00a1\\u00a7\\u00ab\\u00b6-\\u00b7\\u00bb\\u00bf\\u037e\\u0387\\u055a-\\u055f\\u0589-\\u058a\\u05be\\u05c0\\u05c3\\u05c6\\u05f3-\\u05f4\\u0609-\\u060a\\u060c-\\u060d\\u061b\\u061e-\\u061f\\u066a-\\u066d\\u06d4\\u0700-\\u070d\\u07f7-\\u07f9\\u0830-\\u083e\\u085e\\u0964-\\u0965\\u0970\\u09fd\\u0a76\\u0af0\\u0c77\\u0c84\\u0df4\\u0e4f\\u0e5a-\\u0e5b\\u0f04-\\u0f12\\u0f14\\u0f3a-\\u0f3d\\u0f85\\u0fd0-\\u0fd4\\u0fd9-\\u0fda\\u104a-\\u104f\\u10fb\\u1360-\\u1368\\u1400\\u166e\\u169b-\\u169c\\u16eb-\\u16ed\\u1735-\\u1736\\u17d4-\\u17d6\\u17d8-\\u17da\\u1800-\\u180a\\u1944-\\u1945\\u1a1e-\\u1a1f\\u1aa0-\\u1aa6\\u1aa8-\\u1aad\\u1b5a-\\u1b60\\u1bfc-\\u1bff\\u1c3b-\\u1c3f\\u1c7e-\\u1c7f\\u1cc0-\\u1cc7\\u1cd3\\u2010-\\u2027\\u2030-\\u2043\\u2045-\\u2051\\u2053-\\u205e\\u207d-\\u207e\\u208d-\\u208e\\u2308-\\u230b\\u2329-\\u232a\\u2768-\\u2775\\u27c5-\\u27c6\\u27e6-\\u27ef\\u2983-\\u2998\\u29d8-\\u29db\\u29fc-\\u29fd\\u2cf9-\\u2cfc\\u2cfe-\\u2cff\\u2d70\\u2e00-\\u2e2e\\u2e30-\\u2e4f\\u3001-\\u3003\\u3008-\\u3011\\u3014-\\u301f\\u3030\\u303d\\u30a0\\u30fb\\ua4fe-\\ua4ff\\ua60d-\\ua60f\\ua673\\ua67e\\ua6f2-\\ua6f7\\ua874-\\ua877\\ua8ce-\\ua8cf\\ua8f8-\\ua8fa\\ua8fc\\ua92e-\\ua92f\\ua95f\\ua9c1-\\ua9cd\\ua9de-\\ua9df\\uaa5c-\\uaa5f\\uaade-\\uaadf\\uaaf0-\\uaaf1\\uabeb\\ufd3e-\\ufd3f\\ufe10-\\ufe19\\ufe30-\\ufe52\\ufe54-\\ufe61\\ufe63\\ufe68\\ufe6a-\\ufe6b\\uff01-\\uff03\\uff05-\\uff0a\\uff0c-\\uff0f\\uff1a-\\uff1b\\uff1f-\\uff20\\uff3b-\\uff3d\\uff3f\\uff5b\\uff5d\\uff5f-\\uff65]|\\ud800[\\udd00-\\udd02\\udf9f\\udfd0]|\\ud801[\\udd6f]|\\ud802[\\udc57\\udd1f\\udd3f\\ude50-\\ude58\\ude7f\\udef0-\\udef6\\udf39-\\udf3f\\udf99-\\udf9c]|\\ud803[\\udf55-\\udf59]|\\ud804[\\udc47-\\udc4d\\udcbb-\\udcbc\\udcbe-\\udcc1\\udd40-\\udd43\\udd74-\\udd75\\uddc5-\\uddc8\\uddcd\\udddb\\udddd-\\udddf\\ude38-\\ude3d\\udea9]|\\ud805[\\udc4b-\\udc4f\\udc5b\\udc5d\\udcc6\\uddc1-\\uddd7\\ude41-\\ude43\\ude60-\\ude6c\\udf3c-\\udf3e]|\\ud806[\\udc3b\\udde2\\ude3f-\\ude46\\ude9a-\\ude9c\\ude9e-\\udea2]|\\ud807[\\udc41-\\udc45\\udc70-\\udc71\\udef7-\\udef8\\udfff]|\\ud809[\\udc70-\\udc74]|\\ud81a[\\ude6e-\\ude6f\\udef5\\udf37-\\udf3b\\udf44]|\\ud81b[\\ude97-\\ude9a\\udfe2]|\\ud82f[\\udc9f]|\\ud836[\\ude87-\\ude8b]|\\ud83a[\\udd5e-\\udd5f]"
        };
      }
    });
    var require_utils102 = __commonJS22({
      "src/language-markdown/utils.js"(exports2, module22) {
        "use strict";
        var {
          getLast
        } = require_util6();
        var {
          locStart,
          locEnd
        } = require_loc5();
        var {
          cjkPattern,
          kPattern,
          punctuationPattern
        } = require_constants_evaluate();
        var INLINE_NODE_TYPES = ["liquidNode", "inlineCode", "emphasis", "esComment", "strong", "delete", "wikiLink", "link", "linkReference", "image", "imageReference", "footnote", "footnoteReference", "sentence", "whitespace", "word", "break", "inlineMath"];
        var INLINE_NODE_WRAPPER_TYPES = [...INLINE_NODE_TYPES, "tableCell", "paragraph", "heading"];
        var kRegex = new RegExp(kPattern);
        var punctuationRegex = new RegExp(punctuationPattern);
        function splitText(text, options) {
          const KIND_NON_CJK = "non-cjk";
          const KIND_CJ_LETTER = "cj-letter";
          const KIND_K_LETTER = "k-letter";
          const KIND_CJK_PUNCTUATION = "cjk-punctuation";
          const nodes = [];
          const tokens = (options.proseWrap === "preserve" ? text : text.replace(new RegExp(`(${cjkPattern})
(${cjkPattern})`, "g"), "$1$2")).split(/([\t\n ]+)/);
          for (const [index, token] of tokens.entries()) {
            if (index % 2 === 1) {
              nodes.push({
                type: "whitespace",
                value: /\n/.test(token) ? "\n" : " "
              });
              continue;
            }
            if ((index === 0 || index === tokens.length - 1) && token === "") {
              continue;
            }
            const innerTokens = token.split(new RegExp(`(${cjkPattern})`));
            for (const [innerIndex, innerToken] of innerTokens.entries()) {
              if ((innerIndex === 0 || innerIndex === innerTokens.length - 1) && innerToken === "") {
                continue;
              }
              if (innerIndex % 2 === 0) {
                if (innerToken !== "") {
                  appendNode({
                    type: "word",
                    value: innerToken,
                    kind: KIND_NON_CJK,
                    hasLeadingPunctuation: punctuationRegex.test(innerToken[0]),
                    hasTrailingPunctuation: punctuationRegex.test(getLast(innerToken))
                  });
                }
                continue;
              }
              appendNode(punctuationRegex.test(innerToken) ? {
                type: "word",
                value: innerToken,
                kind: KIND_CJK_PUNCTUATION,
                hasLeadingPunctuation: true,
                hasTrailingPunctuation: true
              } : {
                type: "word",
                value: innerToken,
                kind: kRegex.test(innerToken) ? KIND_K_LETTER : KIND_CJ_LETTER,
                hasLeadingPunctuation: false,
                hasTrailingPunctuation: false
              });
            }
          }
          return nodes;
          function appendNode(node) {
            const lastNode = getLast(nodes);
            if (lastNode && lastNode.type === "word") {
              if (lastNode.kind === KIND_NON_CJK && node.kind === KIND_CJ_LETTER && !lastNode.hasTrailingPunctuation || lastNode.kind === KIND_CJ_LETTER && node.kind === KIND_NON_CJK && !node.hasLeadingPunctuation) {
                nodes.push({
                  type: "whitespace",
                  value: " "
                });
              } else if (!isBetween(KIND_NON_CJK, KIND_CJK_PUNCTUATION) && ![lastNode.value, node.value].some((value2) => /\u3000/.test(value2))) {
                nodes.push({
                  type: "whitespace",
                  value: ""
                });
              }
            }
            nodes.push(node);
            function isBetween(kind1, kind2) {
              return lastNode.kind === kind1 && node.kind === kind2 || lastNode.kind === kind2 && node.kind === kind1;
            }
          }
        }
        function getOrderedListItemInfo(orderListItem, originalText) {
          const [, numberText, marker, leadingSpaces] = originalText.slice(orderListItem.position.start.offset, orderListItem.position.end.offset).match(/^\s*(\d+)(\.|\))(\s*)/);
          return {
            numberText,
            marker,
            leadingSpaces
          };
        }
        function hasGitDiffFriendlyOrderedList(node, options) {
          if (!node.ordered) {
            return false;
          }
          if (node.children.length < 2) {
            return false;
          }
          const firstNumber = Number(getOrderedListItemInfo(node.children[0], options.originalText).numberText);
          const secondNumber = Number(getOrderedListItemInfo(node.children[1], options.originalText).numberText);
          if (firstNumber === 0 && node.children.length > 2) {
            const thirdNumber = Number(getOrderedListItemInfo(node.children[2], options.originalText).numberText);
            return secondNumber === 1 && thirdNumber === 1;
          }
          return secondNumber === 1;
        }
        function getFencedCodeBlockValue(node, originalText) {
          const {
            value: value2
          } = node;
          if (node.position.end.offset === originalText.length && value2.endsWith("\n") && originalText.endsWith("\n")) {
            return value2.slice(0, -1);
          }
          return value2;
        }
        function mapAst(ast, handler) {
          return function preorder(node, index, parentStack) {
            const newNode = Object.assign({}, handler(node, index, parentStack));
            if (newNode.children) {
              newNode.children = newNode.children.map((child, index2) => preorder(child, index2, [newNode, ...parentStack]));
            }
            return newNode;
          }(ast, null, []);
        }
        function isAutolink(node) {
          if ((node === null || node === void 0 ? void 0 : node.type) !== "link" || node.children.length !== 1) {
            return false;
          }
          const [child] = node.children;
          return locStart(node) === locStart(child) && locEnd(node) === locEnd(child);
        }
        module22.exports = {
          mapAst,
          splitText,
          punctuationPattern,
          getFencedCodeBlockValue,
          getOrderedListItemInfo,
          hasGitDiffFriendlyOrderedList,
          INLINE_NODE_TYPES,
          INLINE_NODE_WRAPPER_TYPES,
          isAutolink
        };
      }
    });
    var require_embed3 = __commonJS22({
      "src/language-markdown/embed.js"(exports2, module22) {
        "use strict";
        var {
          inferParserByLanguage,
          getMaxContinuousCount
        } = require_util6();
        var {
          builders: {
            hardline,
            markAsRoot
          },
          utils: {
            replaceEndOfLine
          }
        } = require_doc();
        var printFrontMatter = require_print();
        var {
          getFencedCodeBlockValue
        } = require_utils102();
        function embed(path2, print, textToDoc, options) {
          const node = path2.getValue();
          if (node.type === "code" && node.lang !== null) {
            const parser = inferParserByLanguage(node.lang, options);
            if (parser) {
              const styleUnit = options.__inJsTemplate ? "~" : "`";
              const style = styleUnit.repeat(Math.max(3, getMaxContinuousCount(node.value, styleUnit) + 1));
              const newOptions = {
                parser
              };
              if (node.lang === "tsx") {
                newOptions.filepath = "dummy.tsx";
              }
              const doc2 = textToDoc(getFencedCodeBlockValue(node, options.originalText), newOptions, {
                stripTrailingHardline: true
              });
              return markAsRoot([style, node.lang, node.meta ? " " + node.meta : "", hardline, replaceEndOfLine(doc2), hardline, style]);
            }
          }
          switch (node.type) {
            case "front-matter":
              return printFrontMatter(node, textToDoc);
            case "importExport":
              return [textToDoc(node.value, {
                parser: "babel"
              }, {
                stripTrailingHardline: true
              }), hardline];
            case "jsx":
              return textToDoc(`<$>${node.value}</$>`, {
                parser: "__js_expression",
                rootMarker: "mdx"
              }, {
                stripTrailingHardline: true
              });
          }
          return null;
        }
        module22.exports = embed;
      }
    });
    var require_pragma4 = __commonJS22({
      "src/language-markdown/pragma.js"(exports2, module22) {
        "use strict";
        var parseFrontMatter = require_parse42();
        var pragmas = ["format", "prettier"];
        function startWithPragma(text) {
          const pragma = `@(${pragmas.join("|")})`;
          const regex = new RegExp([`<!--\\s*${pragma}\\s*-->`, `{\\s*\\/\\*\\s*${pragma}\\s*\\*\\/\\s*}`, `<!--.*\r?
[\\s\\S]*(^|
)[^\\S
]*${pragma}[^\\S
]*($|
)[\\s\\S]*
.*-->`].join("|"), "m");
          const matched = text.match(regex);
          return (matched === null || matched === void 0 ? void 0 : matched.index) === 0;
        }
        module22.exports = {
          startWithPragma,
          hasPragma: (text) => startWithPragma(parseFrontMatter(text).content.trimStart()),
          insertPragma: (text) => {
            const extracted = parseFrontMatter(text);
            const pragma = `<!-- @${pragmas[0]} -->`;
            return extracted.frontMatter ? `${extracted.frontMatter.raw}

${pragma}

${extracted.content}` : `${pragma}

${extracted.content}`;
          }
        };
      }
    });
    var require_print_preprocess2 = __commonJS22({
      "src/language-markdown/print-preprocess.js"(exports2, module22) {
        "use strict";
        var getLast = require_get_last();
        var {
          getOrderedListItemInfo,
          mapAst,
          splitText
        } = require_utils102();
        var isSingleCharRegex = /^.$/su;
        function preprocess(ast, options) {
          ast = restoreUnescapedCharacter(ast, options);
          ast = mergeContinuousTexts(ast);
          ast = transformInlineCode(ast, options);
          ast = transformIndentedCodeblockAndMarkItsParentList(ast, options);
          ast = markAlignedList(ast, options);
          ast = splitTextIntoSentences(ast, options);
          ast = transformImportExport(ast);
          ast = mergeContinuousImportExport(ast);
          return ast;
        }
        function transformImportExport(ast) {
          return mapAst(ast, (node) => {
            if (node.type !== "import" && node.type !== "export") {
              return node;
            }
            return Object.assign(Object.assign({}, node), {}, {
              type: "importExport"
            });
          });
        }
        function transformInlineCode(ast, options) {
          return mapAst(ast, (node) => {
            if (node.type !== "inlineCode" || options.proseWrap === "preserve") {
              return node;
            }
            return Object.assign(Object.assign({}, node), {}, {
              value: node.value.replace(/\s+/g, " ")
            });
          });
        }
        function restoreUnescapedCharacter(ast, options) {
          return mapAst(ast, (node) => node.type !== "text" || node.value === "*" || node.value === "_" || !isSingleCharRegex.test(node.value) || node.position.end.offset - node.position.start.offset === node.value.length ? node : Object.assign(Object.assign({}, node), {}, {
            value: options.originalText.slice(node.position.start.offset, node.position.end.offset)
          }));
        }
        function mergeContinuousImportExport(ast) {
          return mergeChildren(ast, (prevNode, node) => prevNode.type === "importExport" && node.type === "importExport", (prevNode, node) => ({
            type: "importExport",
            value: prevNode.value + "\n\n" + node.value,
            position: {
              start: prevNode.position.start,
              end: node.position.end
            }
          }));
        }
        function mergeChildren(ast, shouldMerge, mergeNode) {
          return mapAst(ast, (node) => {
            if (!node.children) {
              return node;
            }
            const children = node.children.reduce((current, child) => {
              const lastChild = getLast(current);
              if (lastChild && shouldMerge(lastChild, child)) {
                current.splice(-1, 1, mergeNode(lastChild, child));
              } else {
                current.push(child);
              }
              return current;
            }, []);
            return Object.assign(Object.assign({}, node), {}, {
              children
            });
          });
        }
        function mergeContinuousTexts(ast) {
          return mergeChildren(ast, (prevNode, node) => prevNode.type === "text" && node.type === "text", (prevNode, node) => ({
            type: "text",
            value: prevNode.value + node.value,
            position: {
              start: prevNode.position.start,
              end: node.position.end
            }
          }));
        }
        function splitTextIntoSentences(ast, options) {
          return mapAst(ast, (node, index, [parentNode]) => {
            if (node.type !== "text") {
              return node;
            }
            let {
              value: value2
            } = node;
            if (parentNode.type === "paragraph") {
              if (index === 0) {
                value2 = value2.trimStart();
              }
              if (index === parentNode.children.length - 1) {
                value2 = value2.trimEnd();
              }
            }
            return {
              type: "sentence",
              position: node.position,
              children: splitText(value2, options)
            };
          });
        }
        function transformIndentedCodeblockAndMarkItsParentList(ast, options) {
          return mapAst(ast, (node, index, parentStack) => {
            if (node.type === "code") {
              const isIndented = /^\n?(?: {4,}|\t)/.test(options.originalText.slice(node.position.start.offset, node.position.end.offset));
              node.isIndented = isIndented;
              if (isIndented) {
                for (let i = 0; i < parentStack.length; i++) {
                  const parent = parentStack[i];
                  if (parent.hasIndentedCodeblock) {
                    break;
                  }
                  if (parent.type === "list") {
                    parent.hasIndentedCodeblock = true;
                  }
                }
              }
            }
            return node;
          });
        }
        function markAlignedList(ast, options) {
          return mapAst(ast, (node, index, parentStack) => {
            if (node.type === "list" && node.children.length > 0) {
              for (let i = 0; i < parentStack.length; i++) {
                const parent = parentStack[i];
                if (parent.type === "list" && !parent.isAligned) {
                  node.isAligned = false;
                  return node;
                }
              }
              node.isAligned = isAligned(node);
            }
            return node;
          });
          function getListItemStart(listItem) {
            return listItem.children.length === 0 ? -1 : listItem.children[0].position.start.column - 1;
          }
          function isAligned(list) {
            if (!list.ordered) {
              return true;
            }
            const [firstItem, secondItem] = list.children;
            const firstInfo = getOrderedListItemInfo(firstItem, options.originalText);
            if (firstInfo.leadingSpaces.length > 1) {
              return true;
            }
            const firstStart = getListItemStart(firstItem);
            if (firstStart === -1) {
              return false;
            }
            if (list.children.length === 1) {
              return firstStart % options.tabWidth === 0;
            }
            const secondStart = getListItemStart(secondItem);
            if (firstStart !== secondStart) {
              return false;
            }
            if (firstStart % options.tabWidth === 0) {
              return true;
            }
            const secondInfo = getOrderedListItemInfo(secondItem, options.originalText);
            return secondInfo.leadingSpaces.length > 1;
          }
        }
        module22.exports = preprocess;
      }
    });
    var require_clean4 = __commonJS22({
      "src/language-markdown/clean.js"(exports2, module22) {
        "use strict";
        var collapseWhiteSpace = require_collapse_white_space();
        var {
          isFrontMatterNode
        } = require_util6();
        var {
          startWithPragma
        } = require_pragma4();
        var ignoredProperties = /* @__PURE__ */ new Set(["position", "raw"]);
        function clean(ast, newObj, parent) {
          if (ast.type === "front-matter" || ast.type === "code" || ast.type === "yaml" || ast.type === "import" || ast.type === "export" || ast.type === "jsx") {
            delete newObj.value;
          }
          if (ast.type === "list") {
            delete newObj.isAligned;
          }
          if (ast.type === "list" || ast.type === "listItem") {
            delete newObj.spread;
            delete newObj.loose;
          }
          if (ast.type === "text") {
            return null;
          }
          if (ast.type === "inlineCode") {
            newObj.value = ast.value.replace(/[\t\n ]+/g, " ");
          }
          if (ast.type === "wikiLink") {
            newObj.value = ast.value.trim().replace(/[\t\n]+/g, " ");
          }
          if (ast.type === "definition" || ast.type === "linkReference" || ast.type === "imageReference") {
            newObj.label = collapseWhiteSpace(ast.label);
          }
          if ((ast.type === "definition" || ast.type === "link" || ast.type === "image") && ast.title) {
            newObj.title = ast.title.replace(/\\(["')])/g, "$1");
          }
          if (parent && parent.type === "root" && parent.children.length > 0 && (parent.children[0] === ast || isFrontMatterNode(parent.children[0]) && parent.children[1] === ast) && ast.type === "html" && startWithPragma(ast.value)) {
            return null;
          }
        }
        clean.ignoredProperties = ignoredProperties;
        module22.exports = clean;
      }
    });
    var require_printer_markdown = __commonJS22({
      "src/language-markdown/printer-markdown.js"(exports2, module22) {
        "use strict";
        var collapseWhiteSpace = require_collapse_white_space();
        var {
          getLast,
          getMinNotPresentContinuousCount,
          getMaxContinuousCount,
          getStringWidth,
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            breakParent,
            join,
            line,
            literalline,
            markAsRoot,
            hardline,
            softline,
            ifBreak,
            fill,
            align,
            indent,
            group,
            hardlineWithoutBreakParent
          },
          utils: {
            normalizeDoc,
            replaceTextEndOfLine
          },
          printer: {
            printDocToString
          }
        } = require_doc();
        var embed = require_embed3();
        var {
          insertPragma
        } = require_pragma4();
        var {
          locStart,
          locEnd
        } = require_loc5();
        var preprocess = require_print_preprocess2();
        var clean = require_clean4();
        var {
          getFencedCodeBlockValue,
          hasGitDiffFriendlyOrderedList,
          splitText,
          punctuationPattern,
          INLINE_NODE_TYPES,
          INLINE_NODE_WRAPPER_TYPES,
          isAutolink
        } = require_utils102();
        var TRAILING_HARDLINE_NODES = /* @__PURE__ */ new Set(["importExport"]);
        var SINGLE_LINE_NODE_TYPES = ["heading", "tableCell", "link", "wikiLink"];
        var SIBLING_NODE_TYPES = /* @__PURE__ */ new Set(["listItem", "definition", "footnoteDefinition"]);
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          if (shouldRemainTheSameContent(path2)) {
            return splitText(options.originalText.slice(node.position.start.offset, node.position.end.offset), options).map((node2) => node2.type === "word" ? node2.value : node2.value === "" ? "" : printLine(path2, node2.value, options));
          }
          switch (node.type) {
            case "front-matter":
              return options.originalText.slice(node.position.start.offset, node.position.end.offset);
            case "root":
              if (node.children.length === 0) {
                return "";
              }
              return [normalizeDoc(printRoot(path2, options, print)), !TRAILING_HARDLINE_NODES.has(getLastDescendantNode(node).type) ? hardline : ""];
            case "paragraph":
              return printChildren(path2, options, print, {
                postprocessor: fill
              });
            case "sentence":
              return printChildren(path2, options, print);
            case "word": {
              let escapedValue = node.value.replace(/\*/g, "\\$&").replace(new RegExp([`(^|${punctuationPattern})(_+)`, `(_+)(${punctuationPattern}|$)`].join("|"), "g"), (_, text1, underscore1, underscore2, text2) => (underscore1 ? `${text1}${underscore1}` : `${underscore2}${text2}`).replace(/_/g, "\\_"));
              const isFirstSentence = (node2, name, index) => node2.type === "sentence" && index === 0;
              const isLastChildAutolink = (node2, name, index) => isAutolink(node2.children[index - 1]);
              if (escapedValue !== node.value && (path2.match(void 0, isFirstSentence, isLastChildAutolink) || path2.match(void 0, isFirstSentence, (node2, name, index) => node2.type === "emphasis" && index === 0, isLastChildAutolink))) {
                escapedValue = escapedValue.replace(/^(\\?[*_])+/, (prefix) => prefix.replace(/\\/g, ""));
              }
              return escapedValue;
            }
            case "whitespace": {
              const parentNode = path2.getParentNode();
              const index = parentNode.children.indexOf(node);
              const nextNode = parentNode.children[index + 1];
              const proseWrap = nextNode && /^>|^(?:[*+-]|#{1,6}|\d+[).])$/.test(nextNode.value) ? "never" : options.proseWrap;
              return printLine(path2, node.value, {
                proseWrap
              });
            }
            case "emphasis": {
              let style;
              if (isAutolink(node.children[0])) {
                style = options.originalText[node.position.start.offset];
              } else {
                const parentNode = path2.getParentNode();
                const index = parentNode.children.indexOf(node);
                const prevNode = parentNode.children[index - 1];
                const nextNode = parentNode.children[index + 1];
                const hasPrevOrNextWord = prevNode && prevNode.type === "sentence" && prevNode.children.length > 0 && getLast(prevNode.children).type === "word" && !getLast(prevNode.children).hasTrailingPunctuation || nextNode && nextNode.type === "sentence" && nextNode.children.length > 0 && nextNode.children[0].type === "word" && !nextNode.children[0].hasLeadingPunctuation;
                style = hasPrevOrNextWord || getAncestorNode(path2, "emphasis") ? "*" : "_";
              }
              return [style, printChildren(path2, options, print), style];
            }
            case "strong":
              return ["**", printChildren(path2, options, print), "**"];
            case "delete":
              return ["~~", printChildren(path2, options, print), "~~"];
            case "inlineCode": {
              const backtickCount = getMinNotPresentContinuousCount(node.value, "`");
              const style = "`".repeat(backtickCount || 1);
              const gap = backtickCount && !/^\s/.test(node.value) ? " " : "";
              return [style, gap, node.value, gap, style];
            }
            case "wikiLink": {
              let contents = "";
              if (options.proseWrap === "preserve") {
                contents = node.value;
              } else {
                contents = node.value.replace(/[\t\n]+/g, " ");
              }
              return ["[[", contents, "]]"];
            }
            case "link":
              switch (options.originalText[node.position.start.offset]) {
                case "<": {
                  const mailto = "mailto:";
                  const url = node.url.startsWith(mailto) && options.originalText.slice(node.position.start.offset + 1, node.position.start.offset + 1 + mailto.length) !== mailto ? node.url.slice(mailto.length) : node.url;
                  return ["<", url, ">"];
                }
                case "[":
                  return ["[", printChildren(path2, options, print), "](", printUrl(node.url, ")"), printTitle(node.title, options), ")"];
                default:
                  return options.originalText.slice(node.position.start.offset, node.position.end.offset);
              }
            case "image":
              return ["![", node.alt || "", "](", printUrl(node.url, ")"), printTitle(node.title, options), ")"];
            case "blockquote":
              return ["> ", align("> ", printChildren(path2, options, print))];
            case "heading":
              return ["#".repeat(node.depth) + " ", printChildren(path2, options, print)];
            case "code": {
              if (node.isIndented) {
                const alignment = " ".repeat(4);
                return align(alignment, [alignment, ...replaceTextEndOfLine(node.value, hardline)]);
              }
              const styleUnit = options.__inJsTemplate ? "~" : "`";
              const style = styleUnit.repeat(Math.max(3, getMaxContinuousCount(node.value, styleUnit) + 1));
              return [style, node.lang || "", node.meta ? " " + node.meta : "", hardline, ...replaceTextEndOfLine(getFencedCodeBlockValue(node, options.originalText), hardline), hardline, style];
            }
            case "html": {
              const parentNode = path2.getParentNode();
              const value2 = parentNode.type === "root" && getLast(parentNode.children) === node ? node.value.trimEnd() : node.value;
              const isHtmlComment = /^<!--.*-->$/s.test(value2);
              return replaceTextEndOfLine(value2, isHtmlComment ? hardline : markAsRoot(literalline));
            }
            case "list": {
              const nthSiblingIndex = getNthListSiblingIndex(node, path2.getParentNode());
              const isGitDiffFriendlyOrderedList = hasGitDiffFriendlyOrderedList(node, options);
              return printChildren(path2, options, print, {
                processor: (childPath, index) => {
                  const prefix = getPrefix();
                  const childNode = childPath.getValue();
                  if (childNode.children.length === 2 && childNode.children[1].type === "html" && childNode.children[0].position.start.column !== childNode.children[1].position.start.column) {
                    return [prefix, printListItem(childPath, options, print, prefix)];
                  }
                  return [prefix, align(" ".repeat(prefix.length), printListItem(childPath, options, print, prefix))];
                  function getPrefix() {
                    const rawPrefix = node.ordered ? (index === 0 ? node.start : isGitDiffFriendlyOrderedList ? 1 : node.start + index) + (nthSiblingIndex % 2 === 0 ? ". " : ") ") : nthSiblingIndex % 2 === 0 ? "- " : "* ";
                    return node.isAligned || node.hasIndentedCodeblock ? alignListPrefix(rawPrefix, options) : rawPrefix;
                  }
                }
              });
            }
            case "thematicBreak": {
              const counter = getAncestorCounter(path2, "list");
              if (counter === -1) {
                return "---";
              }
              const nthSiblingIndex = getNthListSiblingIndex(path2.getParentNode(counter), path2.getParentNode(counter + 1));
              return nthSiblingIndex % 2 === 0 ? "***" : "---";
            }
            case "linkReference":
              return ["[", printChildren(path2, options, print), "]", node.referenceType === "full" ? printLinkReference(node) : node.referenceType === "collapsed" ? "[]" : ""];
            case "imageReference":
              switch (node.referenceType) {
                case "full":
                  return ["![", node.alt || "", "]", printLinkReference(node)];
                default:
                  return ["![", node.alt, "]", node.referenceType === "collapsed" ? "[]" : ""];
              }
            case "definition": {
              const lineOrSpace = options.proseWrap === "always" ? line : " ";
              return group([printLinkReference(node), ":", indent([lineOrSpace, printUrl(node.url), node.title === null ? "" : [lineOrSpace, printTitle(node.title, options, false)]])]);
            }
            case "footnote":
              return ["[^", printChildren(path2, options, print), "]"];
            case "footnoteReference":
              return printFootnoteReference(node);
            case "footnoteDefinition": {
              const nextNode = path2.getParentNode().children[path2.getName() + 1];
              const shouldInlineFootnote = node.children.length === 1 && node.children[0].type === "paragraph" && (options.proseWrap === "never" || options.proseWrap === "preserve" && node.children[0].position.start.line === node.children[0].position.end.line);
              return [printFootnoteReference(node), ": ", shouldInlineFootnote ? printChildren(path2, options, print) : group([align(" ".repeat(4), printChildren(path2, options, print, {
                processor: (childPath, index) => index === 0 ? group([softline, print()]) : print()
              })), nextNode && nextNode.type === "footnoteDefinition" ? softline : ""])];
            }
            case "table":
              return printTable(path2, options, print);
            case "tableCell":
              return printChildren(path2, options, print);
            case "break":
              return /\s/.test(options.originalText[node.position.start.offset]) ? ["  ", markAsRoot(literalline)] : ["\\", hardline];
            case "liquidNode":
              return replaceTextEndOfLine(node.value, hardline);
            case "importExport":
              return [node.value, hardline];
            case "esComment":
              return ["{/* ", node.value, " */}"];
            case "jsx":
              return node.value;
            case "math":
              return ["$$", hardline, node.value ? [...replaceTextEndOfLine(node.value, hardline), hardline] : "", "$$"];
            case "inlineMath": {
              return options.originalText.slice(locStart(node), locEnd(node));
            }
            case "tableRow":
            case "listItem":
            default:
              throw new Error(`Unknown markdown type ${JSON.stringify(node.type)}`);
          }
        }
        function printListItem(path2, options, print, listPrefix) {
          const node = path2.getValue();
          const prefix = node.checked === null ? "" : node.checked ? "[x] " : "[ ] ";
          return [prefix, printChildren(path2, options, print, {
            processor: (childPath, index) => {
              if (index === 0 && childPath.getValue().type !== "list") {
                return align(" ".repeat(prefix.length), print());
              }
              const alignment = " ".repeat(clamp(options.tabWidth - listPrefix.length, 0, 3));
              return [alignment, align(alignment, print())];
            }
          })];
        }
        function alignListPrefix(prefix, options) {
          const additionalSpaces = getAdditionalSpaces();
          return prefix + " ".repeat(additionalSpaces >= 4 ? 0 : additionalSpaces);
          function getAdditionalSpaces() {
            const restSpaces = prefix.length % options.tabWidth;
            return restSpaces === 0 ? 0 : options.tabWidth - restSpaces;
          }
        }
        function getNthListSiblingIndex(node, parentNode) {
          return getNthSiblingIndex(node, parentNode, (siblingNode) => siblingNode.ordered === node.ordered);
        }
        function getNthSiblingIndex(node, parentNode, condition) {
          let index = -1;
          for (const childNode of parentNode.children) {
            if (childNode.type === node.type && condition(childNode)) {
              index++;
            } else {
              index = -1;
            }
            if (childNode === node) {
              return index;
            }
          }
        }
        function getAncestorCounter(path2, typeOrTypes) {
          const types = Array.isArray(typeOrTypes) ? typeOrTypes : [typeOrTypes];
          let counter = -1;
          let ancestorNode;
          while (ancestorNode = path2.getParentNode(++counter)) {
            if (types.includes(ancestorNode.type)) {
              return counter;
            }
          }
          return -1;
        }
        function getAncestorNode(path2, typeOrTypes) {
          const counter = getAncestorCounter(path2, typeOrTypes);
          return counter === -1 ? null : path2.getParentNode(counter);
        }
        function printLine(path2, value2, options) {
          if (options.proseWrap === "preserve" && value2 === "\n") {
            return hardline;
          }
          const isBreakable = options.proseWrap === "always" && !getAncestorNode(path2, SINGLE_LINE_NODE_TYPES);
          return value2 !== "" ? isBreakable ? line : " " : isBreakable ? softline : "";
        }
        function printTable(path2, options, print) {
          const node = path2.getValue();
          const columnMaxWidths = [];
          const contents = path2.map((rowPath) => rowPath.map((cellPath, columnIndex) => {
            const text = printDocToString(print(), options).formatted;
            const width = getStringWidth(text);
            columnMaxWidths[columnIndex] = Math.max(columnMaxWidths[columnIndex] || 3, width);
            return {
              text,
              width
            };
          }, "children"), "children");
          const alignedTable = printTableContents(false);
          if (options.proseWrap !== "never") {
            return [breakParent, alignedTable];
          }
          const compactTable = printTableContents(true);
          return [breakParent, group(ifBreak(compactTable, alignedTable))];
          function printTableContents(isCompact) {
            const parts = [printRow(contents[0], isCompact), printAlign(isCompact)];
            if (contents.length > 1) {
              parts.push(join(hardlineWithoutBreakParent, contents.slice(1).map((rowContents) => printRow(rowContents, isCompact))));
            }
            return join(hardlineWithoutBreakParent, parts);
          }
          function printAlign(isCompact) {
            const align2 = columnMaxWidths.map((width, index) => {
              const align3 = node.align[index];
              const first2 = align3 === "center" || align3 === "left" ? ":" : "-";
              const last2 = align3 === "center" || align3 === "right" ? ":" : "-";
              const middle = isCompact ? "-" : "-".repeat(width - 2);
              return `${first2}${middle}${last2}`;
            });
            return `| ${align2.join(" | ")} |`;
          }
          function printRow(rowContents, isCompact) {
            const columns = rowContents.map(({
              text,
              width
            }, columnIndex) => {
              if (isCompact) {
                return text;
              }
              const spaces = columnMaxWidths[columnIndex] - width;
              const align2 = node.align[columnIndex];
              let before = 0;
              if (align2 === "right") {
                before = spaces;
              } else if (align2 === "center") {
                before = Math.floor(spaces / 2);
              }
              const after = spaces - before;
              return `${" ".repeat(before)}${text}${" ".repeat(after)}`;
            });
            return `| ${columns.join(" | ")} |`;
          }
        }
        function printRoot(path2, options, print) {
          const ignoreRanges = [];
          let ignoreStart = null;
          const {
            children
          } = path2.getValue();
          for (const [index, childNode] of children.entries()) {
            switch (isPrettierIgnore(childNode)) {
              case "start":
                if (ignoreStart === null) {
                  ignoreStart = {
                    index,
                    offset: childNode.position.end.offset
                  };
                }
                break;
              case "end":
                if (ignoreStart !== null) {
                  ignoreRanges.push({
                    start: ignoreStart,
                    end: {
                      index,
                      offset: childNode.position.start.offset
                    }
                  });
                  ignoreStart = null;
                }
                break;
              default:
                break;
            }
          }
          return printChildren(path2, options, print, {
            processor: (childPath, index) => {
              if (ignoreRanges.length > 0) {
                const ignoreRange = ignoreRanges[0];
                if (index === ignoreRange.start.index) {
                  return [printIgnoreComment(children[ignoreRange.start.index]), options.originalText.slice(ignoreRange.start.offset, ignoreRange.end.offset), printIgnoreComment(children[ignoreRange.end.index])];
                }
                if (ignoreRange.start.index < index && index < ignoreRange.end.index) {
                  return false;
                }
                if (index === ignoreRange.end.index) {
                  ignoreRanges.shift();
                  return false;
                }
              }
              return print();
            }
          });
        }
        function printChildren(path2, options, print, events = {}) {
          const {
            postprocessor
          } = events;
          const processor = events.processor || (() => print());
          const node = path2.getValue();
          const parts = [];
          let lastChildNode;
          path2.each((childPath, index) => {
            const childNode = childPath.getValue();
            const result = processor(childPath, index);
            if (result !== false) {
              const data = {
                parts,
                prevNode: lastChildNode,
                parentNode: node,
                options
              };
              if (shouldPrePrintHardline(childNode, data)) {
                parts.push(hardline);
                if (lastChildNode && TRAILING_HARDLINE_NODES.has(lastChildNode.type)) {
                  if (shouldPrePrintTripleHardline(childNode, data)) {
                    parts.push(hardline);
                  }
                } else {
                  if (shouldPrePrintDoubleHardline(childNode, data) || shouldPrePrintTripleHardline(childNode, data)) {
                    parts.push(hardline);
                  }
                  if (shouldPrePrintTripleHardline(childNode, data)) {
                    parts.push(hardline);
                  }
                }
              }
              parts.push(result);
              lastChildNode = childNode;
            }
          }, "children");
          return postprocessor ? postprocessor(parts) : parts;
        }
        function printIgnoreComment(node) {
          if (node.type === "html") {
            return node.value;
          }
          if (node.type === "paragraph" && Array.isArray(node.children) && node.children.length === 1 && node.children[0].type === "esComment") {
            return ["{/* ", node.children[0].value, " */}"];
          }
        }
        function getLastDescendantNode(node) {
          let current = node;
          while (isNonEmptyArray(current.children)) {
            current = getLast(current.children);
          }
          return current;
        }
        function isPrettierIgnore(node) {
          let match;
          if (node.type === "html") {
            match = node.value.match(/^<!--\s*prettier-ignore(?:-(start|end))?\s*-->$/);
          } else {
            let comment;
            if (node.type === "esComment") {
              comment = node;
            } else if (node.type === "paragraph" && node.children.length === 1 && node.children[0].type === "esComment") {
              comment = node.children[0];
            }
            if (comment) {
              match = comment.value.match(/^prettier-ignore(?:-(start|end))?$/);
            }
          }
          return match ? match[1] || "next" : false;
        }
        function shouldPrePrintHardline(node, data) {
          const isFirstNode = data.parts.length === 0;
          const isInlineNode = INLINE_NODE_TYPES.includes(node.type);
          const isInlineHTML = node.type === "html" && INLINE_NODE_WRAPPER_TYPES.includes(data.parentNode.type);
          return !isFirstNode && !isInlineNode && !isInlineHTML;
        }
        function shouldPrePrintDoubleHardline(node, data) {
          var _data$prevNode, _data$prevNode2, _data$prevNode3;
          const isSequence = (data.prevNode && data.prevNode.type) === node.type;
          const isSiblingNode = isSequence && SIBLING_NODE_TYPES.has(node.type);
          const isInTightListItem = data.parentNode.type === "listItem" && !data.parentNode.loose;
          const isPrevNodeLooseListItem = ((_data$prevNode = data.prevNode) === null || _data$prevNode === void 0 ? void 0 : _data$prevNode.type) === "listItem" && data.prevNode.loose;
          const isPrevNodePrettierIgnore = isPrettierIgnore(data.prevNode) === "next";
          const isBlockHtmlWithoutBlankLineBetweenPrevHtml = node.type === "html" && ((_data$prevNode2 = data.prevNode) === null || _data$prevNode2 === void 0 ? void 0 : _data$prevNode2.type) === "html" && data.prevNode.position.end.line + 1 === node.position.start.line;
          const isHtmlDirectAfterListItem = node.type === "html" && data.parentNode.type === "listItem" && ((_data$prevNode3 = data.prevNode) === null || _data$prevNode3 === void 0 ? void 0 : _data$prevNode3.type) === "paragraph" && data.prevNode.position.end.line + 1 === node.position.start.line;
          return isPrevNodeLooseListItem || !(isSiblingNode || isInTightListItem || isPrevNodePrettierIgnore || isBlockHtmlWithoutBlankLineBetweenPrevHtml || isHtmlDirectAfterListItem);
        }
        function shouldPrePrintTripleHardline(node, data) {
          const isPrevNodeList = data.prevNode && data.prevNode.type === "list";
          const isIndentedCode = node.type === "code" && node.isIndented;
          return isPrevNodeList && isIndentedCode;
        }
        function shouldRemainTheSameContent(path2) {
          const ancestorNode = getAncestorNode(path2, ["linkReference", "imageReference"]);
          return ancestorNode && (ancestorNode.type !== "linkReference" || ancestorNode.referenceType !== "full");
        }
        function printUrl(url, dangerousCharOrChars = []) {
          const dangerousChars = [" ", ...Array.isArray(dangerousCharOrChars) ? dangerousCharOrChars : [dangerousCharOrChars]];
          return new RegExp(dangerousChars.map((x) => `\\${x}`).join("|")).test(url) ? `<${url}>` : url;
        }
        function printTitle(title, options, printSpace = true) {
          if (!title) {
            return "";
          }
          if (printSpace) {
            return " " + printTitle(title, options, false);
          }
          title = title.replace(/\\(["')])/g, "$1");
          if (title.includes('"') && title.includes("'") && !title.includes(")")) {
            return `(${title})`;
          }
          const singleCount = title.split("'").length - 1;
          const doubleCount = title.split('"').length - 1;
          const quote = singleCount > doubleCount ? '"' : doubleCount > singleCount ? "'" : options.singleQuote ? "'" : '"';
          title = title.replace(/\\/, "\\\\");
          title = title.replace(new RegExp(`(${quote})`, "g"), "\\$1");
          return `${quote}${title}${quote}`;
        }
        function clamp(value2, min2, max2) {
          return value2 < min2 ? min2 : value2 > max2 ? max2 : value2;
        }
        function hasPrettierIgnore(path2) {
          const index = Number(path2.getName());
          if (index === 0) {
            return false;
          }
          const prevNode = path2.getParentNode().children[index - 1];
          return isPrettierIgnore(prevNode) === "next";
        }
        function printLinkReference(node) {
          return `[${collapseWhiteSpace(node.label)}]`;
        }
        function printFootnoteReference(node) {
          return `[^${node.label}]`;
        }
        module22.exports = {
          preprocess,
          print: genericPrint,
          embed,
          massageAstNode: clean,
          hasPrettierIgnore,
          insertPragma
        };
      }
    });
    var require_options5 = __commonJS22({
      "src/language-markdown/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        module22.exports = {
          proseWrap: commonOptions.proseWrap,
          singleQuote: commonOptions.singleQuote
        };
      }
    });
    var require_parsers5 = __commonJS22({
      "src/language-markdown/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get remark() {
            return require_parser_markdown().parsers.remark;
          },
          get markdown() {
            return require_parser_markdown().parsers.remark;
          },
          get mdx() {
            return require_parser_markdown().parsers.mdx;
          }
        };
      }
    });
    var require_Markdown = __commonJS22({
      "node_modules/linguist-languages/data/Markdown.json"(exports2, module22) {
        module22.exports = {
          name: "Markdown",
          type: "prose",
          color: "#083fa1",
          aliases: ["pandoc"],
          aceMode: "markdown",
          codemirrorMode: "gfm",
          codemirrorMimeType: "text/x-gfm",
          wrap: true,
          extensions: [".md", ".livemd", ".markdown", ".mdown", ".mdwn", ".mdx", ".mkd", ".mkdn", ".mkdown", ".ronn", ".scd", ".workbook"],
          filenames: ["contents.lr"],
          tmScope: "source.gfm",
          languageId: 222
        };
      }
    });
    var require_language_markdown = __commonJS22({
      "src/language-markdown/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_markdown();
        var options = require_options5();
        var parsers = require_parsers5();
        var languages = [createLanguage(require_Markdown(), (data) => ({
          since: "1.8.0",
          parsers: ["markdown"],
          vscodeLanguageIds: ["markdown"],
          filenames: [...data.filenames, "README"],
          extensions: data.extensions.filter((extension) => extension !== ".mdx")
        })), createLanguage(require_Markdown(), () => ({
          name: "MDX",
          since: "1.15.0",
          parsers: ["mdx"],
          vscodeLanguageIds: ["mdx"],
          filenames: [],
          extensions: [".mdx"]
        }))];
        var printers = {
          mdast: printer
        };
        module22.exports = {
          languages,
          options,
          printers,
          parsers
        };
      }
    });
    var require_clean5 = __commonJS22({
      "src/language-html/clean.js"(exports2, module22) {
        "use strict";
        var {
          isFrontMatterNode
        } = require_util6();
        var ignoredProperties = /* @__PURE__ */ new Set(["sourceSpan", "startSourceSpan", "endSourceSpan", "nameSpan", "valueSpan"]);
        function clean(ast, newNode) {
          if (ast.type === "text" || ast.type === "comment") {
            return null;
          }
          if (isFrontMatterNode(ast) || ast.type === "yaml" || ast.type === "toml") {
            return null;
          }
          if (ast.type === "attribute") {
            delete newNode.value;
          }
          if (ast.type === "docType") {
            delete newNode.value;
          }
        }
        clean.ignoredProperties = ignoredProperties;
        module22.exports = clean;
      }
    });
    var require_constants_evaluate2 = __commonJS22({
      "src/language-html/constants.evaluate.js"(exports2, module22) {
        module22.exports = {
          CSS_DISPLAY_TAGS: {
            area: "none",
            base: "none",
            basefont: "none",
            datalist: "none",
            head: "none",
            link: "none",
            meta: "none",
            noembed: "none",
            noframes: "none",
            param: "block",
            rp: "none",
            script: "block",
            source: "block",
            style: "none",
            template: "inline",
            track: "block",
            title: "none",
            html: "block",
            body: "block",
            address: "block",
            blockquote: "block",
            center: "block",
            div: "block",
            figure: "block",
            figcaption: "block",
            footer: "block",
            form: "block",
            header: "block",
            hr: "block",
            legend: "block",
            listing: "block",
            main: "block",
            p: "block",
            plaintext: "block",
            pre: "block",
            xmp: "block",
            slot: "contents",
            ruby: "ruby",
            rt: "ruby-text",
            article: "block",
            aside: "block",
            h1: "block",
            h2: "block",
            h3: "block",
            h4: "block",
            h5: "block",
            h6: "block",
            hgroup: "block",
            nav: "block",
            section: "block",
            dir: "block",
            dd: "block",
            dl: "block",
            dt: "block",
            ol: "block",
            ul: "block",
            li: "list-item",
            table: "table",
            caption: "table-caption",
            colgroup: "table-column-group",
            col: "table-column",
            thead: "table-header-group",
            tbody: "table-row-group",
            tfoot: "table-footer-group",
            tr: "table-row",
            td: "table-cell",
            th: "table-cell",
            fieldset: "block",
            button: "inline-block",
            details: "block",
            summary: "block",
            dialog: "block",
            meter: "inline-block",
            progress: "inline-block",
            object: "inline-block",
            video: "inline-block",
            audio: "inline-block",
            select: "inline-block",
            option: "block",
            optgroup: "block"
          },
          CSS_DISPLAY_DEFAULT: "inline",
          CSS_WHITE_SPACE_TAGS: {
            listing: "pre",
            plaintext: "pre",
            pre: "pre",
            xmp: "pre",
            nobr: "nowrap",
            table: "initial",
            textarea: "pre-wrap"
          },
          CSS_WHITE_SPACE_DEFAULT: "normal"
        };
      }
    });
    var require_is_unknown_namespace = __commonJS22({
      "src/language-html/utils/is-unknown-namespace.js"(exports2, module22) {
        "use strict";
        function isUnknownNamespace(node) {
          return node.type === "element" && !node.hasExplicitNamespace && !["html", "svg"].includes(node.namespace);
        }
        module22.exports = isUnknownNamespace;
      }
    });
    var require_utils11 = __commonJS22({
      "src/language-html/utils/index.js"(exports2, module22) {
        "use strict";
        var {
          inferParserByLanguage,
          isFrontMatterNode
        } = require_util6();
        var {
          builders: {
            line,
            hardline,
            join
          },
          utils: {
            getDocParts,
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          CSS_DISPLAY_TAGS,
          CSS_DISPLAY_DEFAULT,
          CSS_WHITE_SPACE_TAGS,
          CSS_WHITE_SPACE_DEFAULT
        } = require_constants_evaluate2();
        var isUnknownNamespace = require_is_unknown_namespace();
        var HTML_WHITESPACE = /* @__PURE__ */ new Set(["	", "\n", "\f", "\r", " "]);
        var htmlTrimStart = (string) => string.replace(/^[\t\n\f\r ]+/, "");
        var htmlTrimEnd = (string) => string.replace(/[\t\n\f\r ]+$/, "");
        var htmlTrim = (string) => htmlTrimStart(htmlTrimEnd(string));
        var htmlTrimLeadingBlankLines = (string) => string.replace(/^[\t\f\r ]*\n/g, "");
        var htmlTrimPreserveIndentation = (string) => htmlTrimLeadingBlankLines(htmlTrimEnd(string));
        var splitByHtmlWhitespace = (string) => string.split(/[\t\n\f\r ]+/);
        var getLeadingHtmlWhitespace = (string) => string.match(/^[\t\n\f\r ]*/)[0];
        var getLeadingAndTrailingHtmlWhitespace = (string) => {
          const [, leadingWhitespace, text, trailingWhitespace] = string.match(/^([\t\n\f\r ]*)(.*?)([\t\n\f\r ]*)$/s);
          return {
            leadingWhitespace,
            trailingWhitespace,
            text
          };
        };
        var hasHtmlWhitespace = (string) => /[\t\n\f\r ]/.test(string);
        function shouldPreserveContent(node, options) {
          if (node.type === "ieConditionalComment" && node.lastChild && !node.lastChild.isSelfClosing && !node.lastChild.endSourceSpan) {
            return true;
          }
          if (node.type === "ieConditionalComment" && !node.complete) {
            return true;
          }
          if (isPreLikeNode(node) && node.children.some((child) => child.type !== "text" && child.type !== "interpolation")) {
            return true;
          }
          if (isVueNonHtmlBlock(node, options) && !isScriptLikeTag(node) && node.type !== "interpolation") {
            return true;
          }
          return false;
        }
        function hasPrettierIgnore(node) {
          if (node.type === "attribute") {
            return false;
          }
          if (!node.parent) {
            return false;
          }
          if (!node.prev) {
            return false;
          }
          return isPrettierIgnore(node.prev);
        }
        function isPrettierIgnore(node) {
          return node.type === "comment" && node.value.trim() === "prettier-ignore";
        }
        function isTextLikeNode(node) {
          return node.type === "text" || node.type === "comment";
        }
        function isScriptLikeTag(node) {
          return node.type === "element" && (node.fullName === "script" || node.fullName === "style" || node.fullName === "svg:style" || isUnknownNamespace(node) && (node.name === "script" || node.name === "style"));
        }
        function canHaveInterpolation(node) {
          return node.children && !isScriptLikeTag(node);
        }
        function isWhitespaceSensitiveNode(node) {
          return isScriptLikeTag(node) || node.type === "interpolation" || isIndentationSensitiveNode(node);
        }
        function isIndentationSensitiveNode(node) {
          return getNodeCssStyleWhiteSpace(node).startsWith("pre");
        }
        function isLeadingSpaceSensitiveNode(node, options) {
          const isLeadingSpaceSensitive = _isLeadingSpaceSensitiveNode();
          if (isLeadingSpaceSensitive && !node.prev && node.parent && node.parent.tagDefinition && node.parent.tagDefinition.ignoreFirstLf) {
            return node.type === "interpolation";
          }
          return isLeadingSpaceSensitive;
          function _isLeadingSpaceSensitiveNode() {
            if (isFrontMatterNode(node)) {
              return false;
            }
            if ((node.type === "text" || node.type === "interpolation") && node.prev && (node.prev.type === "text" || node.prev.type === "interpolation")) {
              return true;
            }
            if (!node.parent || node.parent.cssDisplay === "none") {
              return false;
            }
            if (isPreLikeNode(node.parent)) {
              return true;
            }
            if (!node.prev && (node.parent.type === "root" || isPreLikeNode(node) && node.parent || isScriptLikeTag(node.parent) || isVueCustomBlock(node.parent, options) || !isFirstChildLeadingSpaceSensitiveCssDisplay(node.parent.cssDisplay))) {
              return false;
            }
            if (node.prev && !isNextLeadingSpaceSensitiveCssDisplay(node.prev.cssDisplay)) {
              return false;
            }
            return true;
          }
        }
        function isTrailingSpaceSensitiveNode(node, options) {
          if (isFrontMatterNode(node)) {
            return false;
          }
          if ((node.type === "text" || node.type === "interpolation") && node.next && (node.next.type === "text" || node.next.type === "interpolation")) {
            return true;
          }
          if (!node.parent || node.parent.cssDisplay === "none") {
            return false;
          }
          if (isPreLikeNode(node.parent)) {
            return true;
          }
          if (!node.next && (node.parent.type === "root" || isPreLikeNode(node) && node.parent || isScriptLikeTag(node.parent) || isVueCustomBlock(node.parent, options) || !isLastChildTrailingSpaceSensitiveCssDisplay(node.parent.cssDisplay))) {
            return false;
          }
          if (node.next && !isPrevTrailingSpaceSensitiveCssDisplay(node.next.cssDisplay)) {
            return false;
          }
          return true;
        }
        function isDanglingSpaceSensitiveNode(node) {
          return isDanglingSpaceSensitiveCssDisplay(node.cssDisplay) && !isScriptLikeTag(node);
        }
        function forceNextEmptyLine(node) {
          return isFrontMatterNode(node) || node.next && node.sourceSpan.end && node.sourceSpan.end.line + 1 < node.next.sourceSpan.start.line;
        }
        function forceBreakContent(node) {
          return forceBreakChildren(node) || node.type === "element" && node.children.length > 0 && (["body", "script", "style"].includes(node.name) || node.children.some((child) => hasNonTextChild(child))) || node.firstChild && node.firstChild === node.lastChild && node.firstChild.type !== "text" && hasLeadingLineBreak(node.firstChild) && (!node.lastChild.isTrailingSpaceSensitive || hasTrailingLineBreak(node.lastChild));
        }
        function forceBreakChildren(node) {
          return node.type === "element" && node.children.length > 0 && (["html", "head", "ul", "ol", "select"].includes(node.name) || node.cssDisplay.startsWith("table") && node.cssDisplay !== "table-cell");
        }
        function preferHardlineAsLeadingSpaces(node) {
          return preferHardlineAsSurroundingSpaces(node) || node.prev && preferHardlineAsTrailingSpaces(node.prev) || hasSurroundingLineBreak(node);
        }
        function preferHardlineAsTrailingSpaces(node) {
          return preferHardlineAsSurroundingSpaces(node) || node.type === "element" && node.fullName === "br" || hasSurroundingLineBreak(node);
        }
        function hasSurroundingLineBreak(node) {
          return hasLeadingLineBreak(node) && hasTrailingLineBreak(node);
        }
        function hasLeadingLineBreak(node) {
          return node.hasLeadingSpaces && (node.prev ? node.prev.sourceSpan.end.line < node.sourceSpan.start.line : node.parent.type === "root" || node.parent.startSourceSpan.end.line < node.sourceSpan.start.line);
        }
        function hasTrailingLineBreak(node) {
          return node.hasTrailingSpaces && (node.next ? node.next.sourceSpan.start.line > node.sourceSpan.end.line : node.parent.type === "root" || node.parent.endSourceSpan && node.parent.endSourceSpan.start.line > node.sourceSpan.end.line);
        }
        function preferHardlineAsSurroundingSpaces(node) {
          switch (node.type) {
            case "ieConditionalComment":
            case "comment":
            case "directive":
              return true;
            case "element":
              return ["script", "select"].includes(node.name);
          }
          return false;
        }
        function getLastDescendant(node) {
          return node.lastChild ? getLastDescendant(node.lastChild) : node;
        }
        function hasNonTextChild(node) {
          return node.children && node.children.some((child) => child.type !== "text");
        }
        function _inferScriptParser(node) {
          const {
            type,
            lang
          } = node.attrMap;
          if (type === "module" || type === "text/javascript" || type === "text/babel" || type === "application/javascript" || lang === "jsx") {
            return "babel";
          }
          if (type === "application/x-typescript" || lang === "ts" || lang === "tsx") {
            return "typescript";
          }
          if (type === "text/markdown") {
            return "markdown";
          }
          if (type === "text/html") {
            return "html";
          }
          if (type && (type.endsWith("json") || type.endsWith("importmap")) || type === "speculationrules") {
            return "json";
          }
          if (type === "text/x-handlebars-template") {
            return "glimmer";
          }
        }
        function inferStyleParser(node, options) {
          const {
            lang
          } = node.attrMap;
          if (!lang || lang === "postcss" || lang === "css") {
            return "css";
          }
          if (lang === "scss") {
            return "scss";
          }
          if (lang === "less") {
            return "less";
          }
          if (lang === "stylus") {
            return inferParserByLanguage("stylus", options);
          }
        }
        function inferScriptParser(node, options) {
          if (node.name === "script" && !node.attrMap.src) {
            if (!node.attrMap.lang && !node.attrMap.type) {
              return "babel";
            }
            return _inferScriptParser(node);
          }
          if (node.name === "style") {
            return inferStyleParser(node, options);
          }
          if (options && isVueNonHtmlBlock(node, options)) {
            return _inferScriptParser(node) || !("src" in node.attrMap) && inferParserByLanguage(node.attrMap.lang, options);
          }
        }
        function isBlockLikeCssDisplay(cssDisplay) {
          return cssDisplay === "block" || cssDisplay === "list-item" || cssDisplay.startsWith("table");
        }
        function isFirstChildLeadingSpaceSensitiveCssDisplay(cssDisplay) {
          return !isBlockLikeCssDisplay(cssDisplay) && cssDisplay !== "inline-block";
        }
        function isLastChildTrailingSpaceSensitiveCssDisplay(cssDisplay) {
          return !isBlockLikeCssDisplay(cssDisplay) && cssDisplay !== "inline-block";
        }
        function isPrevTrailingSpaceSensitiveCssDisplay(cssDisplay) {
          return !isBlockLikeCssDisplay(cssDisplay);
        }
        function isNextLeadingSpaceSensitiveCssDisplay(cssDisplay) {
          return !isBlockLikeCssDisplay(cssDisplay);
        }
        function isDanglingSpaceSensitiveCssDisplay(cssDisplay) {
          return !isBlockLikeCssDisplay(cssDisplay) && cssDisplay !== "inline-block";
        }
        function isPreLikeNode(node) {
          return getNodeCssStyleWhiteSpace(node).startsWith("pre");
        }
        function countParents(path2, predicate) {
          let counter = 0;
          for (let i = path2.stack.length - 1; i >= 0; i--) {
            const value2 = path2.stack[i];
            if (value2 && typeof value2 === "object" && !Array.isArray(value2) && predicate(value2)) {
              counter++;
            }
          }
          return counter;
        }
        function hasParent(node, fn) {
          let current = node;
          while (current) {
            if (fn(current)) {
              return true;
            }
            current = current.parent;
          }
          return false;
        }
        function getNodeCssStyleDisplay(node, options) {
          if (node.prev && node.prev.type === "comment") {
            const match = node.prev.value.match(/^\s*display:\s*([a-z]+)\s*$/);
            if (match) {
              return match[1];
            }
          }
          let isInSvgForeignObject = false;
          if (node.type === "element" && node.namespace === "svg") {
            if (hasParent(node, (parent) => parent.fullName === "svg:foreignObject")) {
              isInSvgForeignObject = true;
            } else {
              return node.name === "svg" ? "inline-block" : "block";
            }
          }
          switch (options.htmlWhitespaceSensitivity) {
            case "strict":
              return "inline";
            case "ignore":
              return "block";
            default: {
              if (options.parser === "vue" && node.parent && node.parent.type === "root") {
                return "block";
              }
              return node.type === "element" && (!node.namespace || isInSvgForeignObject || isUnknownNamespace(node)) && CSS_DISPLAY_TAGS[node.name] || CSS_DISPLAY_DEFAULT;
            }
          }
        }
        function getNodeCssStyleWhiteSpace(node) {
          return node.type === "element" && (!node.namespace || isUnknownNamespace(node)) && CSS_WHITE_SPACE_TAGS[node.name] || CSS_WHITE_SPACE_DEFAULT;
        }
        function getMinIndentation(text) {
          let minIndentation = Number.POSITIVE_INFINITY;
          for (const lineText of text.split("\n")) {
            if (lineText.length === 0) {
              continue;
            }
            if (!HTML_WHITESPACE.has(lineText[0])) {
              return 0;
            }
            const indentation = getLeadingHtmlWhitespace(lineText).length;
            if (lineText.length === indentation) {
              continue;
            }
            if (indentation < minIndentation) {
              minIndentation = indentation;
            }
          }
          return minIndentation === Number.POSITIVE_INFINITY ? 0 : minIndentation;
        }
        function dedentString(text, minIndent = getMinIndentation(text)) {
          return minIndent === 0 ? text : text.split("\n").map((lineText) => lineText.slice(minIndent)).join("\n");
        }
        function countChars(text, char) {
          let counter = 0;
          for (let i = 0; i < text.length; i++) {
            if (text[i] === char) {
              counter++;
            }
          }
          return counter;
        }
        function unescapeQuoteEntities(text) {
          return text.replace(/&apos;/g, "'").replace(/&quot;/g, '"');
        }
        var vueRootElementsSet = /* @__PURE__ */ new Set(["template", "style", "script"]);
        function isVueCustomBlock(node, options) {
          return isVueSfcBlock(node, options) && !vueRootElementsSet.has(node.fullName);
        }
        function isVueSfcBlock(node, options) {
          return options.parser === "vue" && node.type === "element" && node.parent.type === "root" && node.fullName.toLowerCase() !== "html";
        }
        function isVueNonHtmlBlock(node, options) {
          return isVueSfcBlock(node, options) && (isVueCustomBlock(node, options) || node.attrMap.lang && node.attrMap.lang !== "html");
        }
        function isVueSlotAttribute(attribute) {
          const attributeName = attribute.fullName;
          return attributeName.charAt(0) === "#" || attributeName === "slot-scope" || attributeName === "v-slot" || attributeName.startsWith("v-slot:");
        }
        function isVueSfcBindingsAttribute(attribute, options) {
          const element = attribute.parent;
          if (!isVueSfcBlock(element, options)) {
            return false;
          }
          const tagName = element.fullName;
          const attributeName = attribute.fullName;
          return tagName === "script" && attributeName === "setup" || tagName === "style" && attributeName === "vars";
        }
        function getTextValueParts(node, value2 = node.value) {
          return node.parent.isWhitespaceSensitive ? node.parent.isIndentationSensitive ? replaceTextEndOfLine(value2) : replaceTextEndOfLine(dedentString(htmlTrimPreserveIndentation(value2)), hardline) : getDocParts(join(line, splitByHtmlWhitespace(value2)));
        }
        function isVueScriptTag(node, options) {
          return isVueSfcBlock(node, options) && node.name === "script";
        }
        module22.exports = {
          htmlTrim,
          htmlTrimPreserveIndentation,
          hasHtmlWhitespace,
          getLeadingAndTrailingHtmlWhitespace,
          canHaveInterpolation,
          countChars,
          countParents,
          dedentString,
          forceBreakChildren,
          forceBreakContent,
          forceNextEmptyLine,
          getLastDescendant,
          getNodeCssStyleDisplay,
          getNodeCssStyleWhiteSpace,
          hasPrettierIgnore,
          inferScriptParser,
          isVueCustomBlock,
          isVueNonHtmlBlock,
          isVueScriptTag,
          isVueSlotAttribute,
          isVueSfcBindingsAttribute,
          isVueSfcBlock,
          isDanglingSpaceSensitiveNode,
          isIndentationSensitiveNode,
          isLeadingSpaceSensitiveNode,
          isPreLikeNode,
          isScriptLikeTag,
          isTextLikeNode,
          isTrailingSpaceSensitiveNode,
          isWhitespaceSensitiveNode,
          isUnknownNamespace,
          preferHardlineAsLeadingSpaces,
          preferHardlineAsTrailingSpaces,
          shouldPreserveContent,
          unescapeQuoteEntities,
          getTextValueParts
        };
      }
    });
    var require_chars = __commonJS22({
      "node_modules/angular-html-parser/lib/compiler/src/chars.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        exports2.$EOF = 0;
        exports2.$BSPACE = 8;
        exports2.$TAB = 9;
        exports2.$LF = 10;
        exports2.$VTAB = 11;
        exports2.$FF = 12;
        exports2.$CR = 13;
        exports2.$SPACE = 32;
        exports2.$BANG = 33;
        exports2.$DQ = 34;
        exports2.$HASH = 35;
        exports2.$$ = 36;
        exports2.$PERCENT = 37;
        exports2.$AMPERSAND = 38;
        exports2.$SQ = 39;
        exports2.$LPAREN = 40;
        exports2.$RPAREN = 41;
        exports2.$STAR = 42;
        exports2.$PLUS = 43;
        exports2.$COMMA = 44;
        exports2.$MINUS = 45;
        exports2.$PERIOD = 46;
        exports2.$SLASH = 47;
        exports2.$COLON = 58;
        exports2.$SEMICOLON = 59;
        exports2.$LT = 60;
        exports2.$EQ = 61;
        exports2.$GT = 62;
        exports2.$QUESTION = 63;
        exports2.$0 = 48;
        exports2.$7 = 55;
        exports2.$9 = 57;
        exports2.$A = 65;
        exports2.$E = 69;
        exports2.$F = 70;
        exports2.$X = 88;
        exports2.$Z = 90;
        exports2.$LBRACKET = 91;
        exports2.$BACKSLASH = 92;
        exports2.$RBRACKET = 93;
        exports2.$CARET = 94;
        exports2.$_ = 95;
        exports2.$a = 97;
        exports2.$b = 98;
        exports2.$e = 101;
        exports2.$f = 102;
        exports2.$n = 110;
        exports2.$r = 114;
        exports2.$t = 116;
        exports2.$u = 117;
        exports2.$v = 118;
        exports2.$x = 120;
        exports2.$z = 122;
        exports2.$LBRACE = 123;
        exports2.$BAR = 124;
        exports2.$RBRACE = 125;
        exports2.$NBSP = 160;
        exports2.$PIPE = 124;
        exports2.$TILDA = 126;
        exports2.$AT = 64;
        exports2.$BT = 96;
        function isWhitespace(code) {
          return code >= exports2.$TAB && code <= exports2.$SPACE || code == exports2.$NBSP;
        }
        exports2.isWhitespace = isWhitespace;
        function isDigit(code) {
          return exports2.$0 <= code && code <= exports2.$9;
        }
        exports2.isDigit = isDigit;
        function isAsciiLetter(code) {
          return code >= exports2.$a && code <= exports2.$z || code >= exports2.$A && code <= exports2.$Z;
        }
        exports2.isAsciiLetter = isAsciiLetter;
        function isAsciiHexDigit(code) {
          return code >= exports2.$a && code <= exports2.$f || code >= exports2.$A && code <= exports2.$F || isDigit(code);
        }
        exports2.isAsciiHexDigit = isAsciiHexDigit;
        function isNewLine(code) {
          return code === exports2.$LF || code === exports2.$CR;
        }
        exports2.isNewLine = isNewLine;
        function isOctalDigit(code) {
          return exports2.$0 <= code && code <= exports2.$7;
        }
        exports2.isOctalDigit = isOctalDigit;
      }
    });
    var require_static_symbol = __commonJS22({
      "node_modules/angular-html-parser/lib/compiler/src/aot/static_symbol.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var StaticSymbol = class {
          constructor(filePath, name, members) {
            this.filePath = filePath;
            this.name = name;
            this.members = members;
          }
          assertNoMembers() {
            if (this.members.length) {
              throw new Error(`Illegal state: symbol without members expected, but got ${JSON.stringify(this)}.`);
            }
          }
        };
        exports2.StaticSymbol = StaticSymbol;
        var StaticSymbolCache = class {
          constructor() {
            this.cache = /* @__PURE__ */ new Map();
          }
          get(declarationFile, name, members) {
            members = members || [];
            const memberSuffix = members.length ? `.${members.join(".")}` : "";
            const key = `"${declarationFile}".${name}${memberSuffix}`;
            let result = this.cache.get(key);
            if (!result) {
              result = new StaticSymbol(declarationFile, name, members);
              this.cache.set(key, result);
            }
            return result;
          }
        };
        exports2.StaticSymbolCache = StaticSymbolCache;
      }
    });
    var require_util32 = __commonJS22({
      "node_modules/angular-html-parser/lib/compiler/src/util.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var DASH_CASE_REGEXP = /-+([a-z0-9])/g;
        function dashCaseToCamelCase(input) {
          return input.replace(DASH_CASE_REGEXP, (...m) => m[1].toUpperCase());
        }
        exports2.dashCaseToCamelCase = dashCaseToCamelCase;
        function splitAtColon(input, defaultValues) {
          return _splitAt(input, ":", defaultValues);
        }
        exports2.splitAtColon = splitAtColon;
        function splitAtPeriod(input, defaultValues) {
          return _splitAt(input, ".", defaultValues);
        }
        exports2.splitAtPeriod = splitAtPeriod;
        function _splitAt(input, character, defaultValues) {
          const characterIndex = input.indexOf(character);
          if (characterIndex == -1)
            return defaultValues;
          return [input.slice(0, characterIndex).trim(), input.slice(characterIndex + 1).trim()];
        }
        function visitValue(value2, visitor, context) {
          if (Array.isArray(value2)) {
            return visitor.visitArray(value2, context);
          }
          if (isStrictStringMap(value2)) {
            return visitor.visitStringMap(value2, context);
          }
          if (value2 == null || typeof value2 == "string" || typeof value2 == "number" || typeof value2 == "boolean") {
            return visitor.visitPrimitive(value2, context);
          }
          return visitor.visitOther(value2, context);
        }
        exports2.visitValue = visitValue;
        function isDefined(val) {
          return val !== null && val !== void 0;
        }
        exports2.isDefined = isDefined;
        function noUndefined(val) {
          return val === void 0 ? null : val;
        }
        exports2.noUndefined = noUndefined;
        var ValueTransformer = class {
          visitArray(arr, context) {
            return arr.map((value2) => visitValue(value2, this, context));
          }
          visitStringMap(map, context) {
            const result = {};
            Object.keys(map).forEach((key) => {
              result[key] = visitValue(map[key], this, context);
            });
            return result;
          }
          visitPrimitive(value2, context) {
            return value2;
          }
          visitOther(value2, context) {
            return value2;
          }
        };
        exports2.ValueTransformer = ValueTransformer;
        exports2.SyncAsync = {
          assertSync: (value2) => {
            if (isPromise(value2)) {
              throw new Error(`Illegal state: value cannot be a promise`);
            }
            return value2;
          },
          then: (value2, cb) => {
            return isPromise(value2) ? value2.then(cb) : cb(value2);
          },
          all: (syncAsyncValues) => {
            return syncAsyncValues.some(isPromise) ? Promise.all(syncAsyncValues) : syncAsyncValues;
          }
        };
        function error(msg) {
          throw new Error(`Internal Error: ${msg}`);
        }
        exports2.error = error;
        function syntaxError(msg, parseErrors) {
          const error2 = Error(msg);
          error2[ERROR_SYNTAX_ERROR] = true;
          if (parseErrors)
            error2[ERROR_PARSE_ERRORS] = parseErrors;
          return error2;
        }
        exports2.syntaxError = syntaxError;
        var ERROR_SYNTAX_ERROR = "ngSyntaxError";
        var ERROR_PARSE_ERRORS = "ngParseErrors";
        function isSyntaxError(error2) {
          return error2[ERROR_SYNTAX_ERROR];
        }
        exports2.isSyntaxError = isSyntaxError;
        function getParseErrors(error2) {
          return error2[ERROR_PARSE_ERRORS] || [];
        }
        exports2.getParseErrors = getParseErrors;
        function escapeRegExp(s) {
          return s.replace(/([.*+?^=!:${}()|[\]\/\\])/g, "\\$1");
        }
        exports2.escapeRegExp = escapeRegExp;
        var STRING_MAP_PROTO = Object.getPrototypeOf({});
        function isStrictStringMap(obj) {
          return typeof obj === "object" && obj !== null && Object.getPrototypeOf(obj) === STRING_MAP_PROTO;
        }
        function utf8Encode(str) {
          let encoded = "";
          for (let index = 0; index < str.length; index++) {
            let codePoint = str.charCodeAt(index);
            if (codePoint >= 55296 && codePoint <= 56319 && str.length > index + 1) {
              const low = str.charCodeAt(index + 1);
              if (low >= 56320 && low <= 57343) {
                index++;
                codePoint = (codePoint - 55296 << 10) + low - 56320 + 65536;
              }
            }
            if (codePoint <= 127) {
              encoded += String.fromCharCode(codePoint);
            } else if (codePoint <= 2047) {
              encoded += String.fromCharCode(codePoint >> 6 & 31 | 192, codePoint & 63 | 128);
            } else if (codePoint <= 65535) {
              encoded += String.fromCharCode(codePoint >> 12 | 224, codePoint >> 6 & 63 | 128, codePoint & 63 | 128);
            } else if (codePoint <= 2097151) {
              encoded += String.fromCharCode(codePoint >> 18 & 7 | 240, codePoint >> 12 & 63 | 128, codePoint >> 6 & 63 | 128, codePoint & 63 | 128);
            }
          }
          return encoded;
        }
        exports2.utf8Encode = utf8Encode;
        function stringify(token) {
          if (typeof token === "string") {
            return token;
          }
          if (token instanceof Array) {
            return "[" + token.map(stringify).join(", ") + "]";
          }
          if (token == null) {
            return "" + token;
          }
          if (token.overriddenName) {
            return `${token.overriddenName}`;
          }
          if (token.name) {
            return `${token.name}`;
          }
          if (!token.toString) {
            return "object";
          }
          const res = token.toString();
          if (res == null) {
            return "" + res;
          }
          const newLineIndex = res.indexOf("\n");
          return newLineIndex === -1 ? res : res.substring(0, newLineIndex);
        }
        exports2.stringify = stringify;
        function resolveForwardRef(type) {
          if (typeof type === "function" && type.hasOwnProperty("__forward_ref__")) {
            return type();
          } else {
            return type;
          }
        }
        exports2.resolveForwardRef = resolveForwardRef;
        function isPromise(obj) {
          return !!obj && typeof obj.then === "function";
        }
        exports2.isPromise = isPromise;
        var Version = class {
          constructor(full) {
            this.full = full;
            const splits = full.split(".");
            this.major = splits[0];
            this.minor = splits[1];
            this.patch = splits.slice(2).join(".");
          }
        };
        exports2.Version = Version;
        var __window = typeof window !== "undefined" && window;
        var __self = typeof self !== "undefined" && typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope && self;
        var __global = typeof global !== "undefined" && global;
        var _global = __global || __window || __self;
        exports2.global = _global;
      }
    });
    var require_compile_metadata = __commonJS22({
      "node_modules/angular-html-parser/lib/compiler/src/compile_metadata.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var static_symbol_1 = require_static_symbol();
        var util_1 = require_util32();
        var HOST_REG_EXP = /^(?:(?:\[([^\]]+)\])|(?:\(([^\)]+)\)))|(\@[-\w]+)$/;
        function sanitizeIdentifier(name) {
          return name.replace(/\W/g, "_");
        }
        exports2.sanitizeIdentifier = sanitizeIdentifier;
        var _anonymousTypeIndex = 0;
        function identifierName(compileIdentifier) {
          if (!compileIdentifier || !compileIdentifier.reference) {
            return null;
          }
          const ref = compileIdentifier.reference;
          if (ref instanceof static_symbol_1.StaticSymbol) {
            return ref.name;
          }
          if (ref["__anonymousType"]) {
            return ref["__anonymousType"];
          }
          let identifier3 = util_1.stringify(ref);
          if (identifier3.indexOf("(") >= 0) {
            identifier3 = `anonymous_${_anonymousTypeIndex++}`;
            ref["__anonymousType"] = identifier3;
          } else {
            identifier3 = sanitizeIdentifier(identifier3);
          }
          return identifier3;
        }
        exports2.identifierName = identifierName;
        function identifierModuleUrl(compileIdentifier) {
          const ref = compileIdentifier.reference;
          if (ref instanceof static_symbol_1.StaticSymbol) {
            return ref.filePath;
          }
          return `./${util_1.stringify(ref)}`;
        }
        exports2.identifierModuleUrl = identifierModuleUrl;
        function viewClassName(compType, embeddedTemplateIndex) {
          return `View_${identifierName({
            reference: compType
          })}_${embeddedTemplateIndex}`;
        }
        exports2.viewClassName = viewClassName;
        function rendererTypeName(compType) {
          return `RenderType_${identifierName({
            reference: compType
          })}`;
        }
        exports2.rendererTypeName = rendererTypeName;
        function hostViewClassName(compType) {
          return `HostView_${identifierName({
            reference: compType
          })}`;
        }
        exports2.hostViewClassName = hostViewClassName;
        function componentFactoryName(compType) {
          return `${identifierName({
            reference: compType
          })}NgFactory`;
        }
        exports2.componentFactoryName = componentFactoryName;
        var CompileSummaryKind;
        (function(CompileSummaryKind2) {
          CompileSummaryKind2[CompileSummaryKind2["Pipe"] = 0] = "Pipe";
          CompileSummaryKind2[CompileSummaryKind2["Directive"] = 1] = "Directive";
          CompileSummaryKind2[CompileSummaryKind2["NgModule"] = 2] = "NgModule";
          CompileSummaryKind2[CompileSummaryKind2["Injectable"] = 3] = "Injectable";
        })(CompileSummaryKind = exports2.CompileSummaryKind || (exports2.CompileSummaryKind = {}));
        function tokenName(token) {
          return token.value != null ? sanitizeIdentifier(token.value) : identifierName(token.identifier);
        }
        exports2.tokenName = tokenName;
        function tokenReference(token) {
          if (token.identifier != null) {
            return token.identifier.reference;
          } else {
            return token.value;
          }
        }
        exports2.tokenReference = tokenReference;
        var CompileStylesheetMetadata = class {
          constructor({
            moduleUrl,
            styles,
            styleUrls
          } = {}) {
            this.moduleUrl = moduleUrl || null;
            this.styles = _normalizeArray(styles);
            this.styleUrls = _normalizeArray(styleUrls);
          }
        };
        exports2.CompileStylesheetMetadata = CompileStylesheetMetadata;
        var CompileTemplateMetadata = class {
          constructor({
            encapsulation,
            template,
            templateUrl,
            htmlAst,
            styles,
            styleUrls,
            externalStylesheets,
            animations,
            ngContentSelectors,
            interpolation,
            isInline,
            preserveWhitespaces
          }) {
            this.encapsulation = encapsulation;
            this.template = template;
            this.templateUrl = templateUrl;
            this.htmlAst = htmlAst;
            this.styles = _normalizeArray(styles);
            this.styleUrls = _normalizeArray(styleUrls);
            this.externalStylesheets = _normalizeArray(externalStylesheets);
            this.animations = animations ? flatten(animations) : [];
            this.ngContentSelectors = ngContentSelectors || [];
            if (interpolation && interpolation.length != 2) {
              throw new Error(`'interpolation' should have a start and an end symbol.`);
            }
            this.interpolation = interpolation;
            this.isInline = isInline;
            this.preserveWhitespaces = preserveWhitespaces;
          }
          toSummary() {
            return {
              ngContentSelectors: this.ngContentSelectors,
              encapsulation: this.encapsulation,
              styles: this.styles,
              animations: this.animations
            };
          }
        };
        exports2.CompileTemplateMetadata = CompileTemplateMetadata;
        var CompileDirectiveMetadata = class {
          static create({
            isHost,
            type,
            isComponent,
            selector,
            exportAs,
            changeDetection,
            inputs,
            outputs,
            host,
            providers,
            viewProviders,
            queries,
            guards,
            viewQueries,
            entryComponents,
            template,
            componentViewType,
            rendererType,
            componentFactory
          }) {
            const hostListeners = {};
            const hostProperties = {};
            const hostAttributes = {};
            if (host != null) {
              Object.keys(host).forEach((key) => {
                const value2 = host[key];
                const matches = key.match(HOST_REG_EXP);
                if (matches === null) {
                  hostAttributes[key] = value2;
                } else if (matches[1] != null) {
                  hostProperties[matches[1]] = value2;
                } else if (matches[2] != null) {
                  hostListeners[matches[2]] = value2;
                }
              });
            }
            const inputsMap = {};
            if (inputs != null) {
              inputs.forEach((bindConfig) => {
                const parts = util_1.splitAtColon(bindConfig, [bindConfig, bindConfig]);
                inputsMap[parts[0]] = parts[1];
              });
            }
            const outputsMap = {};
            if (outputs != null) {
              outputs.forEach((bindConfig) => {
                const parts = util_1.splitAtColon(bindConfig, [bindConfig, bindConfig]);
                outputsMap[parts[0]] = parts[1];
              });
            }
            return new CompileDirectiveMetadata({
              isHost,
              type,
              isComponent: !!isComponent,
              selector,
              exportAs,
              changeDetection,
              inputs: inputsMap,
              outputs: outputsMap,
              hostListeners,
              hostProperties,
              hostAttributes,
              providers,
              viewProviders,
              queries,
              guards,
              viewQueries,
              entryComponents,
              template,
              componentViewType,
              rendererType,
              componentFactory
            });
          }
          constructor({
            isHost,
            type,
            isComponent,
            selector,
            exportAs,
            changeDetection,
            inputs,
            outputs,
            hostListeners,
            hostProperties,
            hostAttributes,
            providers,
            viewProviders,
            queries,
            guards,
            viewQueries,
            entryComponents,
            template,
            componentViewType,
            rendererType,
            componentFactory
          }) {
            this.isHost = !!isHost;
            this.type = type;
            this.isComponent = isComponent;
            this.selector = selector;
            this.exportAs = exportAs;
            this.changeDetection = changeDetection;
            this.inputs = inputs;
            this.outputs = outputs;
            this.hostListeners = hostListeners;
            this.hostProperties = hostProperties;
            this.hostAttributes = hostAttributes;
            this.providers = _normalizeArray(providers);
            this.viewProviders = _normalizeArray(viewProviders);
            this.queries = _normalizeArray(queries);
            this.guards = guards;
            this.viewQueries = _normalizeArray(viewQueries);
            this.entryComponents = _normalizeArray(entryComponents);
            this.template = template;
            this.componentViewType = componentViewType;
            this.rendererType = rendererType;
            this.componentFactory = componentFactory;
          }
          toSummary() {
            return {
              summaryKind: CompileSummaryKind.Directive,
              type: this.type,
              isComponent: this.isComponent,
              selector: this.selector,
              exportAs: this.exportAs,
              inputs: this.inputs,
              outputs: this.outputs,
              hostListeners: this.hostListeners,
              hostProperties: this.hostProperties,
              hostAttributes: this.hostAttributes,
              providers: this.providers,
              viewProviders: this.viewProviders,
              queries: this.queries,
              guards: this.guards,
              viewQueries: this.viewQueries,
              entryComponents: this.entryComponents,
              changeDetection: this.changeDetection,
              template: this.template && this.template.toSummary(),
              componentViewType: this.componentViewType,
              rendererType: this.rendererType,
              componentFactory: this.componentFactory
            };
          }
        };
        exports2.CompileDirectiveMetadata = CompileDirectiveMetadata;
        var CompilePipeMetadata = class {
          constructor({
            type,
            name,
            pure
          }) {
            this.type = type;
            this.name = name;
            this.pure = !!pure;
          }
          toSummary() {
            return {
              summaryKind: CompileSummaryKind.Pipe,
              type: this.type,
              name: this.name,
              pure: this.pure
            };
          }
        };
        exports2.CompilePipeMetadata = CompilePipeMetadata;
        var CompileShallowModuleMetadata = class {
        };
        exports2.CompileShallowModuleMetadata = CompileShallowModuleMetadata;
        var CompileNgModuleMetadata = class {
          constructor({
            type,
            providers,
            declaredDirectives,
            exportedDirectives,
            declaredPipes,
            exportedPipes,
            entryComponents,
            bootstrapComponents,
            importedModules,
            exportedModules,
            schemas,
            transitiveModule,
            id
          }) {
            this.type = type || null;
            this.declaredDirectives = _normalizeArray(declaredDirectives);
            this.exportedDirectives = _normalizeArray(exportedDirectives);
            this.declaredPipes = _normalizeArray(declaredPipes);
            this.exportedPipes = _normalizeArray(exportedPipes);
            this.providers = _normalizeArray(providers);
            this.entryComponents = _normalizeArray(entryComponents);
            this.bootstrapComponents = _normalizeArray(bootstrapComponents);
            this.importedModules = _normalizeArray(importedModules);
            this.exportedModules = _normalizeArray(exportedModules);
            this.schemas = _normalizeArray(schemas);
            this.id = id || null;
            this.transitiveModule = transitiveModule || null;
          }
          toSummary() {
            const module3 = this.transitiveModule;
            return {
              summaryKind: CompileSummaryKind.NgModule,
              type: this.type,
              entryComponents: module3.entryComponents,
              providers: module3.providers,
              modules: module3.modules,
              exportedDirectives: module3.exportedDirectives,
              exportedPipes: module3.exportedPipes
            };
          }
        };
        exports2.CompileNgModuleMetadata = CompileNgModuleMetadata;
        var TransitiveCompileNgModuleMetadata = class {
          constructor() {
            this.directivesSet = /* @__PURE__ */ new Set();
            this.directives = [];
            this.exportedDirectivesSet = /* @__PURE__ */ new Set();
            this.exportedDirectives = [];
            this.pipesSet = /* @__PURE__ */ new Set();
            this.pipes = [];
            this.exportedPipesSet = /* @__PURE__ */ new Set();
            this.exportedPipes = [];
            this.modulesSet = /* @__PURE__ */ new Set();
            this.modules = [];
            this.entryComponentsSet = /* @__PURE__ */ new Set();
            this.entryComponents = [];
            this.providers = [];
          }
          addProvider(provider, module3) {
            this.providers.push({
              provider,
              module: module3
            });
          }
          addDirective(id) {
            if (!this.directivesSet.has(id.reference)) {
              this.directivesSet.add(id.reference);
              this.directives.push(id);
            }
          }
          addExportedDirective(id) {
            if (!this.exportedDirectivesSet.has(id.reference)) {
              this.exportedDirectivesSet.add(id.reference);
              this.exportedDirectives.push(id);
            }
          }
          addPipe(id) {
            if (!this.pipesSet.has(id.reference)) {
              this.pipesSet.add(id.reference);
              this.pipes.push(id);
            }
          }
          addExportedPipe(id) {
            if (!this.exportedPipesSet.has(id.reference)) {
              this.exportedPipesSet.add(id.reference);
              this.exportedPipes.push(id);
            }
          }
          addModule(id) {
            if (!this.modulesSet.has(id.reference)) {
              this.modulesSet.add(id.reference);
              this.modules.push(id);
            }
          }
          addEntryComponent(ec) {
            if (!this.entryComponentsSet.has(ec.componentType)) {
              this.entryComponentsSet.add(ec.componentType);
              this.entryComponents.push(ec);
            }
          }
        };
        exports2.TransitiveCompileNgModuleMetadata = TransitiveCompileNgModuleMetadata;
        function _normalizeArray(obj) {
          return obj || [];
        }
        var ProviderMeta = class {
          constructor(token, {
            useClass,
            useValue,
            useExisting,
            useFactory,
            deps,
            multi
          }) {
            this.token = token;
            this.useClass = useClass || null;
            this.useValue = useValue;
            this.useExisting = useExisting;
            this.useFactory = useFactory || null;
            this.dependencies = deps || null;
            this.multi = !!multi;
          }
        };
        exports2.ProviderMeta = ProviderMeta;
        function flatten(list) {
          return list.reduce((flat, item) => {
            const flatItem = Array.isArray(item) ? flatten(item) : item;
            return flat.concat(flatItem);
          }, []);
        }
        exports2.flatten = flatten;
        function jitSourceUrl(url) {
          return url.replace(/(\w+:\/\/[\w:-]+)?(\/+)?/, "ng:///");
        }
        function templateSourceUrl(ngModuleType, compMeta, templateMeta) {
          let url;
          if (templateMeta.isInline) {
            if (compMeta.type.reference instanceof static_symbol_1.StaticSymbol) {
              url = `${compMeta.type.reference.filePath}.${compMeta.type.reference.name}.html`;
            } else {
              url = `${identifierName(ngModuleType)}/${identifierName(compMeta.type)}.html`;
            }
          } else {
            url = templateMeta.templateUrl;
          }
          return compMeta.type.reference instanceof static_symbol_1.StaticSymbol ? url : jitSourceUrl(url);
        }
        exports2.templateSourceUrl = templateSourceUrl;
        function sharedStylesheetJitUrl(meta, id) {
          const pathParts = meta.moduleUrl.split(/\/\\/g);
          const baseName = pathParts[pathParts.length - 1];
          return jitSourceUrl(`css/${id}${baseName}.ngstyle.js`);
        }
        exports2.sharedStylesheetJitUrl = sharedStylesheetJitUrl;
        function ngModuleJitUrl(moduleMeta) {
          return jitSourceUrl(`${identifierName(moduleMeta.type)}/module.ngfactory.js`);
        }
        exports2.ngModuleJitUrl = ngModuleJitUrl;
        function templateJitUrl(ngModuleType, compMeta) {
          return jitSourceUrl(`${identifierName(ngModuleType)}/${identifierName(compMeta.type)}.ngfactory.js`);
        }
        exports2.templateJitUrl = templateJitUrl;
      }
    });
    var require_parse_util = __commonJS22({
      "node_modules/angular-html-parser/lib/compiler/src/parse_util.js"(exports2) {
        "use strict";
        Object.defineProperty(exports2, "__esModule", {
          value: true
        });
        var chars = require_chars();
        var compile_metadata_1 = require_compile_metadata();
        var ParseLocation = class {
          constructor(file, offset, line, col) {
            this.file = file;
            this.offset = offset;
            this.line = line;
            this.col = col;
          }
          toString() {
            return this.offset != null ? `${this.file.url}@${this.line}:${this.col}` : this.file.url;
          }
          moveBy(delta) {
            const source = this.file.content;
            const len = source.length;
            let offset = this.offset;
            let line = this.line;
            let col = this.col;
            while (offset > 0 && delta < 0) {
              offset--;
              delta++;
              const ch = source.charCodeAt(offset);
              if (ch == chars.$LF) {
                line--;
                const priorLine = source.substr(0, offset - 1).lastIndexOf(String.fromCharCode(chars.$LF));
                col = priorLine > 0 ? offset - priorLine : offset;
              } else {
                col--;
              }
            }
            while (offset < len && delta > 0) {
              const ch = source.charCodeAt(offset);
              offset++;
              delta--;
              if (ch == chars.$LF) {
                line++;
                col = 0;
              } else {
                col++;
              }
            }
            return new ParseLocation(this.file, offset, line, col);
          }
          getContext(maxChars, maxLines) {
            const content = this.file.content;
            let startOffset = this.offset;
            if (startOffset != null) {
              if (startOffset > content.length - 1) {
                startOffset = content.length - 1;
              }
              let endOffset = startOffset;
              let ctxChars = 0;
              let ctxLines = 0;
              while (ctxChars < maxChars && startOffset > 0) {
                startOffset--;
                ctxChars++;
                if (content[startOffset] == "\n") {
                  if (++ctxLines == maxLines) {
                    break;
                  }
                }
              }
              ctxChars = 0;
              ctxLines = 0;
              while (ctxChars < maxChars && endOffset < content.length - 1) {
                endOffset++;
                ctxChars++;
                if (content[endOffset] == "\n") {
                  if (++ctxLines == maxLines) {
                    break;
                  }
                }
              }
              return {
                before: content.substring(startOffset, this.offset),
                after: content.substring(this.offset, endOffset + 1)
              };
            }
            return null;
          }
        };
        exports2.ParseLocation = ParseLocation;
        var ParseSourceFile = class {
          constructor(content, url) {
            this.content = content;
            this.url = url;
          }
        };
        exports2.ParseSourceFile = ParseSourceFile;
        var ParseSourceSpan = class {
          constructor(start, end, details = null) {
            this.start = start;
            this.end = end;
            this.details = details;
          }
          toString() {
            return this.start.file.content.substring(this.start.offset, this.end.offset);
          }
        };
        exports2.ParseSourceSpan = ParseSourceSpan;
        exports2.EMPTY_PARSE_LOCATION = new ParseLocation(new ParseSourceFile("", ""), 0, 0, 0);
        exports2.EMPTY_SOURCE_SPAN = new ParseSourceSpan(exports2.EMPTY_PARSE_LOCATION, exports2.EMPTY_PARSE_LOCATION);
        var ParseErrorLevel;
        (function(ParseErrorLevel2) {
          ParseErrorLevel2[ParseErrorLevel2["WARNING"] = 0] = "WARNING";
          ParseErrorLevel2[ParseErrorLevel2["ERROR"] = 1] = "ERROR";
        })(ParseErrorLevel = exports2.ParseErrorLevel || (exports2.ParseErrorLevel = {}));
        var ParseError = class {
          constructor(span, msg, level = ParseErrorLevel.ERROR) {
            this.span = span;
            this.msg = msg;
            this.level = level;
          }
          contextualMessage() {
            const ctx = this.span.start.getContext(100, 3);
            return ctx ? `${this.msg} ("${ctx.before}[${ParseErrorLevel[this.level]} ->]${ctx.after}")` : this.msg;
          }
          toString() {
            const details = this.span.details ? `, ${this.span.details}` : "";
            return `${this.contextualMessage()}: ${this.span.start}${details}`;
          }
        };
        exports2.ParseError = ParseError;
        function typeSourceSpan(kind, type) {
          const moduleUrl = compile_metadata_1.identifierModuleUrl(type);
          const sourceFileName = moduleUrl != null ? `in ${kind} ${compile_metadata_1.identifierName(type)} in ${moduleUrl}` : `in ${kind} ${compile_metadata_1.identifierName(type)}`;
          const sourceFile = new ParseSourceFile("", sourceFileName);
          return new ParseSourceSpan(new ParseLocation(sourceFile, -1, -1, -1), new ParseLocation(sourceFile, -1, -1, -1));
        }
        exports2.typeSourceSpan = typeSourceSpan;
        function r3JitTypeSourceSpan(kind, typeName, sourceUrl) {
          const sourceFileName = `in ${kind} ${typeName} in ${sourceUrl}`;
          const sourceFile = new ParseSourceFile("", sourceFileName);
          return new ParseSourceSpan(new ParseLocation(sourceFile, -1, -1, -1), new ParseLocation(sourceFile, -1, -1, -1));
        }
        exports2.r3JitTypeSourceSpan = r3JitTypeSourceSpan;
      }
    });
    var require_print_preprocess3 = __commonJS22({
      "src/language-html/print-preprocess.js"(exports2, module22) {
        "use strict";
        var {
          ParseSourceSpan
        } = require_parse_util();
        var {
          htmlTrim,
          getLeadingAndTrailingHtmlWhitespace,
          hasHtmlWhitespace,
          canHaveInterpolation,
          getNodeCssStyleDisplay,
          isDanglingSpaceSensitiveNode,
          isIndentationSensitiveNode,
          isLeadingSpaceSensitiveNode,
          isTrailingSpaceSensitiveNode,
          isWhitespaceSensitiveNode,
          isVueScriptTag
        } = require_utils11();
        var PREPROCESS_PIPELINE = [removeIgnorableFirstLf, mergeIfConditionalStartEndCommentIntoElementOpeningTag, mergeCdataIntoText, extractInterpolation, extractWhitespaces, addCssDisplay, addIsSelfClosing, addHasHtmComponentClosingTag, addIsSpaceSensitive, mergeSimpleElementIntoText, markTsScript];
        function preprocess(ast, options) {
          for (const fn of PREPROCESS_PIPELINE) {
            fn(ast, options);
          }
          return ast;
        }
        function removeIgnorableFirstLf(ast) {
          ast.walk((node) => {
            if (node.type === "element" && node.tagDefinition.ignoreFirstLf && node.children.length > 0 && node.children[0].type === "text" && node.children[0].value[0] === "\n") {
              const text = node.children[0];
              if (text.value.length === 1) {
                node.removeChild(text);
              } else {
                text.value = text.value.slice(1);
              }
            }
          });
        }
        function mergeIfConditionalStartEndCommentIntoElementOpeningTag(ast) {
          const isTarget = (node) => node.type === "element" && node.prev && node.prev.type === "ieConditionalStartComment" && node.prev.sourceSpan.end.offset === node.startSourceSpan.start.offset && node.firstChild && node.firstChild.type === "ieConditionalEndComment" && node.firstChild.sourceSpan.start.offset === node.startSourceSpan.end.offset;
          ast.walk((node) => {
            if (node.children) {
              for (let i = 0; i < node.children.length; i++) {
                const child = node.children[i];
                if (!isTarget(child)) {
                  continue;
                }
                const ieConditionalStartComment = child.prev;
                const ieConditionalEndComment = child.firstChild;
                node.removeChild(ieConditionalStartComment);
                i--;
                const startSourceSpan = new ParseSourceSpan(ieConditionalStartComment.sourceSpan.start, ieConditionalEndComment.sourceSpan.end);
                const sourceSpan = new ParseSourceSpan(startSourceSpan.start, child.sourceSpan.end);
                child.condition = ieConditionalStartComment.condition;
                child.sourceSpan = sourceSpan;
                child.startSourceSpan = startSourceSpan;
                child.removeChild(ieConditionalEndComment);
              }
            }
          });
        }
        function mergeNodeIntoText(ast, shouldMerge, getValue) {
          ast.walk((node) => {
            if (node.children) {
              for (let i = 0; i < node.children.length; i++) {
                const child = node.children[i];
                if (child.type !== "text" && !shouldMerge(child)) {
                  continue;
                }
                if (child.type !== "text") {
                  child.type = "text";
                  child.value = getValue(child);
                }
                const prevChild = child.prev;
                if (!prevChild || prevChild.type !== "text") {
                  continue;
                }
                prevChild.value += child.value;
                prevChild.sourceSpan = new ParseSourceSpan(prevChild.sourceSpan.start, child.sourceSpan.end);
                node.removeChild(child);
                i--;
              }
            }
          });
        }
        function mergeCdataIntoText(ast) {
          return mergeNodeIntoText(ast, (node) => node.type === "cdata", (node) => `<![CDATA[${node.value}]]>`);
        }
        function mergeSimpleElementIntoText(ast) {
          const isSimpleElement = (node) => node.type === "element" && node.attrs.length === 0 && node.children.length === 1 && node.firstChild.type === "text" && !hasHtmlWhitespace(node.children[0].value) && !node.firstChild.hasLeadingSpaces && !node.firstChild.hasTrailingSpaces && node.isLeadingSpaceSensitive && !node.hasLeadingSpaces && node.isTrailingSpaceSensitive && !node.hasTrailingSpaces && node.prev && node.prev.type === "text" && node.next && node.next.type === "text";
          ast.walk((node) => {
            if (node.children) {
              for (let i = 0; i < node.children.length; i++) {
                const child = node.children[i];
                if (!isSimpleElement(child)) {
                  continue;
                }
                const prevChild = child.prev;
                const nextChild = child.next;
                prevChild.value += `<${child.rawName}>` + child.firstChild.value + `</${child.rawName}>` + nextChild.value;
                prevChild.sourceSpan = new ParseSourceSpan(prevChild.sourceSpan.start, nextChild.sourceSpan.end);
                prevChild.isTrailingSpaceSensitive = nextChild.isTrailingSpaceSensitive;
                prevChild.hasTrailingSpaces = nextChild.hasTrailingSpaces;
                node.removeChild(child);
                i--;
                node.removeChild(nextChild);
              }
            }
          });
        }
        function extractInterpolation(ast, options) {
          if (options.parser === "html") {
            return;
          }
          const interpolationRegex = /{{(.+?)}}/s;
          ast.walk((node) => {
            if (!canHaveInterpolation(node)) {
              return;
            }
            for (const child of node.children) {
              if (child.type !== "text") {
                continue;
              }
              let startSourceSpan = child.sourceSpan.start;
              let endSourceSpan = null;
              const components = child.value.split(interpolationRegex);
              for (let i = 0; i < components.length; i++, startSourceSpan = endSourceSpan) {
                const value2 = components[i];
                if (i % 2 === 0) {
                  endSourceSpan = startSourceSpan.moveBy(value2.length);
                  if (value2.length > 0) {
                    node.insertChildBefore(child, {
                      type: "text",
                      value: value2,
                      sourceSpan: new ParseSourceSpan(startSourceSpan, endSourceSpan)
                    });
                  }
                  continue;
                }
                endSourceSpan = startSourceSpan.moveBy(value2.length + 4);
                node.insertChildBefore(child, {
                  type: "interpolation",
                  sourceSpan: new ParseSourceSpan(startSourceSpan, endSourceSpan),
                  children: value2.length === 0 ? [] : [{
                    type: "text",
                    value: value2,
                    sourceSpan: new ParseSourceSpan(startSourceSpan.moveBy(2), endSourceSpan.moveBy(-2))
                  }]
                });
              }
              node.removeChild(child);
            }
          });
        }
        function extractWhitespaces(ast) {
          ast.walk((node) => {
            if (!node.children) {
              return;
            }
            if (node.children.length === 0 || node.children.length === 1 && node.children[0].type === "text" && htmlTrim(node.children[0].value).length === 0) {
              node.hasDanglingSpaces = node.children.length > 0;
              node.children = [];
              return;
            }
            const isWhitespaceSensitive = isWhitespaceSensitiveNode(node);
            const isIndentationSensitive = isIndentationSensitiveNode(node);
            if (!isWhitespaceSensitive) {
              for (let i = 0; i < node.children.length; i++) {
                const child = node.children[i];
                if (child.type !== "text") {
                  continue;
                }
                const {
                  leadingWhitespace,
                  text,
                  trailingWhitespace
                } = getLeadingAndTrailingHtmlWhitespace(child.value);
                const prevChild = child.prev;
                const nextChild = child.next;
                if (!text) {
                  node.removeChild(child);
                  i--;
                  if (leadingWhitespace || trailingWhitespace) {
                    if (prevChild) {
                      prevChild.hasTrailingSpaces = true;
                    }
                    if (nextChild) {
                      nextChild.hasLeadingSpaces = true;
                    }
                  }
                } else {
                  child.value = text;
                  child.sourceSpan = new ParseSourceSpan(child.sourceSpan.start.moveBy(leadingWhitespace.length), child.sourceSpan.end.moveBy(-trailingWhitespace.length));
                  if (leadingWhitespace) {
                    if (prevChild) {
                      prevChild.hasTrailingSpaces = true;
                    }
                    child.hasLeadingSpaces = true;
                  }
                  if (trailingWhitespace) {
                    child.hasTrailingSpaces = true;
                    if (nextChild) {
                      nextChild.hasLeadingSpaces = true;
                    }
                  }
                }
              }
            }
            node.isWhitespaceSensitive = isWhitespaceSensitive;
            node.isIndentationSensitive = isIndentationSensitive;
          });
        }
        function addIsSelfClosing(ast) {
          ast.walk((node) => {
            node.isSelfClosing = !node.children || node.type === "element" && (node.tagDefinition.isVoid || node.startSourceSpan === node.endSourceSpan);
          });
        }
        function addHasHtmComponentClosingTag(ast, options) {
          ast.walk((node) => {
            if (node.type !== "element") {
              return;
            }
            node.hasHtmComponentClosingTag = node.endSourceSpan && /^<\s*\/\s*\/\s*>$/.test(options.originalText.slice(node.endSourceSpan.start.offset, node.endSourceSpan.end.offset));
          });
        }
        function addCssDisplay(ast, options) {
          ast.walk((node) => {
            node.cssDisplay = getNodeCssStyleDisplay(node, options);
          });
        }
        function addIsSpaceSensitive(ast, options) {
          ast.walk((node) => {
            const {
              children
            } = node;
            if (!children) {
              return;
            }
            if (children.length === 0) {
              node.isDanglingSpaceSensitive = isDanglingSpaceSensitiveNode(node);
              return;
            }
            for (const child of children) {
              child.isLeadingSpaceSensitive = isLeadingSpaceSensitiveNode(child, options);
              child.isTrailingSpaceSensitive = isTrailingSpaceSensitiveNode(child, options);
            }
            for (let index = 0; index < children.length; index++) {
              const child = children[index];
              child.isLeadingSpaceSensitive = index === 0 ? child.isLeadingSpaceSensitive : child.prev.isTrailingSpaceSensitive && child.isLeadingSpaceSensitive;
              child.isTrailingSpaceSensitive = index === children.length - 1 ? child.isTrailingSpaceSensitive : child.next.isLeadingSpaceSensitive && child.isTrailingSpaceSensitive;
            }
          });
        }
        function markTsScript(ast, options) {
          if (options.parser === "vue") {
            const vueScriptTag = ast.children.find((child) => isVueScriptTag(child, options));
            if (!vueScriptTag) {
              return;
            }
            const {
              lang
            } = vueScriptTag.attrMap;
            if (lang === "ts" || lang === "typescript") {
              options.__should_parse_vue_template_with_ts = true;
            }
          }
        }
        module22.exports = preprocess;
      }
    });
    var require_pragma5 = __commonJS22({
      "src/language-html/pragma.js"(exports2, module22) {
        "use strict";
        function hasPragma(text) {
          return /^\s*<!--\s*@(?:format|prettier)\s*-->/.test(text);
        }
        function insertPragma(text) {
          return "<!-- @format -->\n\n" + text.replace(/^\s*\n/, "");
        }
        module22.exports = {
          hasPragma,
          insertPragma
        };
      }
    });
    var require_loc6 = __commonJS22({
      "src/language-html/loc.js"(exports2, module22) {
        "use strict";
        function locStart(node) {
          return node.sourceSpan.start.offset;
        }
        function locEnd(node) {
          return node.sourceSpan.end.offset;
        }
        module22.exports = {
          locStart,
          locEnd
        };
      }
    });
    var require_tag = __commonJS22({
      "src/language-html/print/tag.js"(exports2, module22) {
        "use strict";
        var assert = require("assert");
        var {
          isNonEmptyArray
        } = require_util6();
        var {
          builders: {
            indent,
            join,
            line,
            softline,
            hardline
          },
          utils: {
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          locStart,
          locEnd
        } = require_loc6();
        var {
          isTextLikeNode,
          getLastDescendant,
          isPreLikeNode,
          hasPrettierIgnore,
          shouldPreserveContent,
          isVueSfcBlock
        } = require_utils11();
        function printClosingTag(node, options) {
          return [node.isSelfClosing ? "" : printClosingTagStart(node, options), printClosingTagEnd(node, options)];
        }
        function printClosingTagStart(node, options) {
          return node.lastChild && needsToBorrowParentClosingTagStartMarker(node.lastChild) ? "" : [printClosingTagPrefix(node, options), printClosingTagStartMarker(node, options)];
        }
        function printClosingTagEnd(node, options) {
          return (node.next ? needsToBorrowPrevClosingTagEndMarker(node.next) : needsToBorrowLastChildClosingTagEndMarker(node.parent)) ? "" : [printClosingTagEndMarker(node, options), printClosingTagSuffix(node, options)];
        }
        function printClosingTagPrefix(node, options) {
          return needsToBorrowLastChildClosingTagEndMarker(node) ? printClosingTagEndMarker(node.lastChild, options) : "";
        }
        function printClosingTagSuffix(node, options) {
          return needsToBorrowParentClosingTagStartMarker(node) ? printClosingTagStartMarker(node.parent, options) : needsToBorrowNextOpeningTagStartMarker(node) ? printOpeningTagStartMarker(node.next) : "";
        }
        function printClosingTagStartMarker(node, options) {
          assert(!node.isSelfClosing);
          if (shouldNotPrintClosingTag(node, options)) {
            return "";
          }
          switch (node.type) {
            case "ieConditionalComment":
              return "<!";
            case "element":
              if (node.hasHtmComponentClosingTag) {
                return "<//";
              }
            default:
              return `</${node.rawName}`;
          }
        }
        function printClosingTagEndMarker(node, options) {
          if (shouldNotPrintClosingTag(node, options)) {
            return "";
          }
          switch (node.type) {
            case "ieConditionalComment":
            case "ieConditionalEndComment":
              return "[endif]-->";
            case "ieConditionalStartComment":
              return "]><!-->";
            case "interpolation":
              return "}}";
            case "element":
              if (node.isSelfClosing) {
                return "/>";
              }
            default:
              return ">";
          }
        }
        function shouldNotPrintClosingTag(node, options) {
          return !node.isSelfClosing && !node.endSourceSpan && (hasPrettierIgnore(node) || shouldPreserveContent(node.parent, options));
        }
        function needsToBorrowPrevClosingTagEndMarker(node) {
          return node.prev && node.prev.type !== "docType" && !isTextLikeNode(node.prev) && node.isLeadingSpaceSensitive && !node.hasLeadingSpaces;
        }
        function needsToBorrowLastChildClosingTagEndMarker(node) {
          return node.lastChild && node.lastChild.isTrailingSpaceSensitive && !node.lastChild.hasTrailingSpaces && !isTextLikeNode(getLastDescendant(node.lastChild)) && !isPreLikeNode(node);
        }
        function needsToBorrowParentClosingTagStartMarker(node) {
          return !node.next && !node.hasTrailingSpaces && node.isTrailingSpaceSensitive && isTextLikeNode(getLastDescendant(node));
        }
        function needsToBorrowNextOpeningTagStartMarker(node) {
          return node.next && !isTextLikeNode(node.next) && isTextLikeNode(node) && node.isTrailingSpaceSensitive && !node.hasTrailingSpaces;
        }
        function getPrettierIgnoreAttributeCommentData(value2) {
          const match = value2.trim().match(/^prettier-ignore-attribute(?:\s+(.+))?$/s);
          if (!match) {
            return false;
          }
          if (!match[1]) {
            return true;
          }
          return match[1].split(/\s+/);
        }
        function needsToBorrowParentOpeningTagEndMarker(node) {
          return !node.prev && node.isLeadingSpaceSensitive && !node.hasLeadingSpaces;
        }
        function printAttributes(path2, options, print) {
          const node = path2.getValue();
          if (!isNonEmptyArray(node.attrs)) {
            return node.isSelfClosing ? " " : "";
          }
          const ignoreAttributeData = node.prev && node.prev.type === "comment" && getPrettierIgnoreAttributeCommentData(node.prev.value);
          const hasPrettierIgnoreAttribute = typeof ignoreAttributeData === "boolean" ? () => ignoreAttributeData : Array.isArray(ignoreAttributeData) ? (attribute) => ignoreAttributeData.includes(attribute.rawName) : () => false;
          const printedAttributes = path2.map((attributePath) => {
            const attribute = attributePath.getValue();
            return hasPrettierIgnoreAttribute(attribute) ? replaceTextEndOfLine(options.originalText.slice(locStart(attribute), locEnd(attribute))) : print();
          }, "attrs");
          const forceNotToBreakAttrContent = node.type === "element" && node.fullName === "script" && node.attrs.length === 1 && node.attrs[0].fullName === "src" && node.children.length === 0;
          const shouldPrintAttributePerLine = options.singleAttributePerLine && node.attrs.length > 1 && !isVueSfcBlock(node, options);
          const attributeLine = shouldPrintAttributePerLine ? hardline : line;
          const parts = [indent([forceNotToBreakAttrContent ? " " : line, join(attributeLine, printedAttributes)])];
          if (node.firstChild && needsToBorrowParentOpeningTagEndMarker(node.firstChild) || node.isSelfClosing && needsToBorrowLastChildClosingTagEndMarker(node.parent) || forceNotToBreakAttrContent) {
            parts.push(node.isSelfClosing ? " " : "");
          } else {
            parts.push(options.bracketSameLine ? node.isSelfClosing ? " " : "" : node.isSelfClosing ? line : softline);
          }
          return parts;
        }
        function printOpeningTagEnd(node) {
          return node.firstChild && needsToBorrowParentOpeningTagEndMarker(node.firstChild) ? "" : printOpeningTagEndMarker(node);
        }
        function printOpeningTag(path2, options, print) {
          const node = path2.getValue();
          return [printOpeningTagStart(node, options), printAttributes(path2, options, print), node.isSelfClosing ? "" : printOpeningTagEnd(node)];
        }
        function printOpeningTagStart(node, options) {
          return node.prev && needsToBorrowNextOpeningTagStartMarker(node.prev) ? "" : [printOpeningTagPrefix(node, options), printOpeningTagStartMarker(node)];
        }
        function printOpeningTagPrefix(node, options) {
          return needsToBorrowParentOpeningTagEndMarker(node) ? printOpeningTagEndMarker(node.parent) : needsToBorrowPrevClosingTagEndMarker(node) ? printClosingTagEndMarker(node.prev, options) : "";
        }
        function printOpeningTagStartMarker(node) {
          switch (node.type) {
            case "ieConditionalComment":
            case "ieConditionalStartComment":
              return `<!--[if ${node.condition}`;
            case "ieConditionalEndComment":
              return "<!--<!";
            case "interpolation":
              return "{{";
            case "docType":
              return "<!DOCTYPE";
            case "element":
              if (node.condition) {
                return `<!--[if ${node.condition}]><!--><${node.rawName}`;
              }
            default:
              return `<${node.rawName}`;
          }
        }
        function printOpeningTagEndMarker(node) {
          assert(!node.isSelfClosing);
          switch (node.type) {
            case "ieConditionalComment":
              return "]>";
            case "element":
              if (node.condition) {
                return "><!--<![endif]-->";
              }
            default:
              return ">";
          }
        }
        module22.exports = {
          printClosingTag,
          printClosingTagStart,
          printClosingTagStartMarker,
          printClosingTagEndMarker,
          printClosingTagSuffix,
          printClosingTagEnd,
          needsToBorrowLastChildClosingTagEndMarker,
          needsToBorrowParentClosingTagStartMarker,
          needsToBorrowPrevClosingTagEndMarker,
          printOpeningTag,
          printOpeningTagStart,
          printOpeningTagPrefix,
          printOpeningTagStartMarker,
          printOpeningTagEndMarker,
          needsToBorrowNextOpeningTagStartMarker,
          needsToBorrowParentOpeningTagEndMarker
        };
      }
    });
    var require_parse_srcset = __commonJS22({
      "node_modules/parse-srcset/src/parse-srcset.js"(exports2, module22) {
        (function(root2, factory) {
          if (typeof define === "function" && define.amd) {
            define([], factory);
          } else if (typeof module22 === "object" && module22.exports) {
            module22.exports = factory();
          } else {
            root2.parseSrcset = factory();
          }
        })(exports2, function() {
          return function(input, options) {
            var logger = options && options.logger || console;
            function isSpace(c2) {
              return c2 === " " || c2 === "	" || c2 === "\n" || c2 === "\f" || c2 === "\r";
            }
            function collectCharacters(regEx) {
              var chars, match = regEx.exec(input.substring(pos));
              if (match) {
                chars = match[0];
                pos += chars.length;
                return chars;
              }
            }
            var inputLength = input.length, regexLeadingSpaces = /^[ \t\n\r\u000c]+/, regexLeadingCommasOrSpaces = /^[, \t\n\r\u000c]+/, regexLeadingNotSpaces = /^[^ \t\n\r\u000c]+/, regexTrailingCommas = /[,]+$/, regexNonNegativeInteger = /^\d+$/, regexFloatingPoint = /^-?(?:[0-9]+|[0-9]*\.[0-9]+)(?:[eE][+-]?[0-9]+)?$/, url, descriptors, currentDescriptor, state, c, pos = 0, candidates = [];
            while (true) {
              collectCharacters(regexLeadingCommasOrSpaces);
              if (pos >= inputLength) {
                return candidates;
              }
              url = collectCharacters(regexLeadingNotSpaces);
              descriptors = [];
              if (url.slice(-1) === ",") {
                url = url.replace(regexTrailingCommas, "");
                parseDescriptors();
              } else {
                tokenize();
              }
            }
            function tokenize() {
              collectCharacters(regexLeadingSpaces);
              currentDescriptor = "";
              state = "in descriptor";
              while (true) {
                c = input.charAt(pos);
                if (state === "in descriptor") {
                  if (isSpace(c)) {
                    if (currentDescriptor) {
                      descriptors.push(currentDescriptor);
                      currentDescriptor = "";
                      state = "after descriptor";
                    }
                  } else if (c === ",") {
                    pos += 1;
                    if (currentDescriptor) {
                      descriptors.push(currentDescriptor);
                    }
                    parseDescriptors();
                    return;
                  } else if (c === "(") {
                    currentDescriptor = currentDescriptor + c;
                    state = "in parens";
                  } else if (c === "") {
                    if (currentDescriptor) {
                      descriptors.push(currentDescriptor);
                    }
                    parseDescriptors();
                    return;
                  } else {
                    currentDescriptor = currentDescriptor + c;
                  }
                } else if (state === "in parens") {
                  if (c === ")") {
                    currentDescriptor = currentDescriptor + c;
                    state = "in descriptor";
                  } else if (c === "") {
                    descriptors.push(currentDescriptor);
                    parseDescriptors();
                    return;
                  } else {
                    currentDescriptor = currentDescriptor + c;
                  }
                } else if (state === "after descriptor") {
                  if (isSpace(c)) {
                  } else if (c === "") {
                    parseDescriptors();
                    return;
                  } else {
                    state = "in descriptor";
                    pos -= 1;
                  }
                }
                pos += 1;
              }
            }
            function parseDescriptors() {
              var pError = false, w, d, h, i, candidate = {}, desc, lastChar, value2, intVal, floatVal;
              for (i = 0; i < descriptors.length; i++) {
                desc = descriptors[i];
                lastChar = desc[desc.length - 1];
                value2 = desc.substring(0, desc.length - 1);
                intVal = parseInt(value2, 10);
                floatVal = parseFloat(value2);
                if (regexNonNegativeInteger.test(value2) && lastChar === "w") {
                  if (w || d) {
                    pError = true;
                  }
                  if (intVal === 0) {
                    pError = true;
                  } else {
                    w = intVal;
                  }
                } else if (regexFloatingPoint.test(value2) && lastChar === "x") {
                  if (w || d || h) {
                    pError = true;
                  }
                  if (floatVal < 0) {
                    pError = true;
                  } else {
                    d = floatVal;
                  }
                } else if (regexNonNegativeInteger.test(value2) && lastChar === "h") {
                  if (h || d) {
                    pError = true;
                  }
                  if (intVal === 0) {
                    pError = true;
                  } else {
                    h = intVal;
                  }
                } else {
                  pError = true;
                }
              }
              if (!pError) {
                candidate.url = url;
                if (w) {
                  candidate.w = w;
                }
                if (d) {
                  candidate.d = d;
                }
                if (h) {
                  candidate.h = h;
                }
                candidates.push(candidate);
              } else if (logger && logger.error) {
                logger.error("Invalid srcset descriptor found in '" + input + "' at '" + desc + "'.");
              }
            }
          };
        });
      }
    });
    var require_syntax_attribute = __commonJS22({
      "src/language-html/syntax-attribute.js"(exports2, module22) {
        "use strict";
        var parseSrcset = require_parse_srcset();
        var {
          builders: {
            ifBreak,
            join,
            line
          }
        } = require_doc();
        function printImgSrcset(value2) {
          const srcset = parseSrcset(value2, {
            logger: {
              error(message) {
                throw new Error(message);
              }
            }
          });
          const hasW = srcset.some(({
            w
          }) => w);
          const hasH = srcset.some(({
            h
          }) => h);
          const hasX = srcset.some(({
            d
          }) => d);
          if (hasW + hasH + hasX > 1) {
            throw new Error("Mixed descriptor in srcset is not supported");
          }
          const key = hasW ? "w" : hasH ? "h" : "d";
          const unit = hasW ? "w" : hasH ? "h" : "x";
          const getMax = (values2) => Math.max(...values2);
          const urls = srcset.map((src) => src.url);
          const maxUrlLength = getMax(urls.map((url) => url.length));
          const descriptors = srcset.map((src) => src[key]).map((descriptor) => descriptor ? descriptor.toString() : "");
          const descriptorLeftLengths = descriptors.map((descriptor) => {
            const index = descriptor.indexOf(".");
            return index === -1 ? descriptor.length : index;
          });
          const maxDescriptorLeftLength = getMax(descriptorLeftLengths);
          return join([",", line], urls.map((url, index) => {
            const parts = [url];
            const descriptor = descriptors[index];
            if (descriptor) {
              const urlPadding = maxUrlLength - url.length + 1;
              const descriptorPadding = maxDescriptorLeftLength - descriptorLeftLengths[index];
              const alignment = " ".repeat(urlPadding + descriptorPadding);
              parts.push(ifBreak(alignment, " "), descriptor + unit);
            }
            return parts;
          }));
        }
        function printClassNames(value2) {
          return value2.trim().split(/\s+/).join(" ");
        }
        module22.exports = {
          printImgSrcset,
          printClassNames
        };
      }
    });
    var require_syntax_vue = __commonJS22({
      "src/language-html/syntax-vue.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            group
          }
        } = require_doc();
        function printVueFor(value2, textToDoc) {
          const {
            left,
            operator,
            right
          } = parseVueFor(value2);
          return [group(textToDoc(`function _(${left}) {}`, {
            parser: "babel",
            __isVueForBindingLeft: true
          })), " ", operator, " ", textToDoc(right, {
            parser: "__js_expression"
          }, {
            stripTrailingHardline: true
          })];
        }
        function parseVueFor(value2) {
          const forAliasRE = /(.*?)\s+(in|of)\s+(.*)/s;
          const forIteratorRE = /,([^,\]}]*)(?:,([^,\]}]*))?$/;
          const stripParensRE = /^\(|\)$/g;
          const inMatch = value2.match(forAliasRE);
          if (!inMatch) {
            return;
          }
          const res = {};
          res.for = inMatch[3].trim();
          if (!res.for) {
            return;
          }
          const alias = inMatch[1].trim().replace(stripParensRE, "");
          const iteratorMatch = alias.match(forIteratorRE);
          if (iteratorMatch) {
            res.alias = alias.replace(forIteratorRE, "");
            res.iterator1 = iteratorMatch[1].trim();
            if (iteratorMatch[2]) {
              res.iterator2 = iteratorMatch[2].trim();
            }
          } else {
            res.alias = alias;
          }
          const left = [res.alias, res.iterator1, res.iterator2];
          if (left.some((part, index) => !part && (index === 0 || left.slice(index + 1).some(Boolean)))) {
            return;
          }
          return {
            left: left.filter(Boolean).join(","),
            operator: inMatch[2],
            right: res.for
          };
        }
        function printVueBindings(value2, textToDoc) {
          return textToDoc(`function _(${value2}) {}`, {
            parser: "babel",
            __isVueBindings: true
          });
        }
        function isVueEventBindingExpression(eventBindingValue) {
          const fnExpRE = /^(?:[\w$]+|\([^)]*\))\s*=>|^function\s*\(/;
          const simplePathRE = /^[$A-Z_a-z][\w$]*(?:\.[$A-Z_a-z][\w$]*|\['[^']*']|\["[^"]*"]|\[\d+]|\[[$A-Z_a-z][\w$]*])*$/;
          const value2 = eventBindingValue.trim();
          return fnExpRE.test(value2) || simplePathRE.test(value2);
        }
        module22.exports = {
          isVueEventBindingExpression,
          printVueFor,
          printVueBindings
        };
      }
    });
    var require_get_node_content = __commonJS22({
      "src/language-html/get-node-content.js"(exports2, module22) {
        "use strict";
        var {
          needsToBorrowParentClosingTagStartMarker,
          printClosingTagStartMarker,
          needsToBorrowLastChildClosingTagEndMarker,
          printClosingTagEndMarker,
          needsToBorrowParentOpeningTagEndMarker,
          printOpeningTagEndMarker
        } = require_tag();
        function getNodeContent(node, options) {
          let start = node.startSourceSpan.end.offset;
          if (node.firstChild && needsToBorrowParentOpeningTagEndMarker(node.firstChild)) {
            start -= printOpeningTagEndMarker(node).length;
          }
          let end = node.endSourceSpan.start.offset;
          if (node.lastChild && needsToBorrowParentClosingTagStartMarker(node.lastChild)) {
            end += printClosingTagStartMarker(node, options).length;
          } else if (needsToBorrowLastChildClosingTagEndMarker(node)) {
            end -= printClosingTagEndMarker(node.lastChild, options).length;
          }
          return options.originalText.slice(start, end);
        }
        module22.exports = getNodeContent;
      }
    });
    var require_embed4 = __commonJS22({
      "src/language-html/embed.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            breakParent,
            group,
            hardline,
            indent,
            line,
            fill,
            softline
          },
          utils: {
            mapDoc,
            replaceTextEndOfLine
          }
        } = require_doc();
        var printFrontMatter = require_print();
        var {
          printClosingTag,
          printClosingTagSuffix,
          needsToBorrowPrevClosingTagEndMarker,
          printOpeningTagPrefix,
          printOpeningTag
        } = require_tag();
        var {
          printImgSrcset,
          printClassNames
        } = require_syntax_attribute();
        var {
          printVueFor,
          printVueBindings,
          isVueEventBindingExpression
        } = require_syntax_vue();
        var {
          isScriptLikeTag,
          isVueNonHtmlBlock,
          inferScriptParser,
          htmlTrimPreserveIndentation,
          dedentString,
          unescapeQuoteEntities,
          isVueSlotAttribute,
          isVueSfcBindingsAttribute,
          getTextValueParts
        } = require_utils11();
        var getNodeContent = require_get_node_content();
        function printEmbeddedAttributeValue(node, htmlTextToDoc, options) {
          const isKeyMatched = (patterns) => new RegExp(patterns.join("|")).test(node.fullName);
          const getValue = () => unescapeQuoteEntities(node.value);
          let shouldHug = false;
          const __onHtmlBindingRoot = (root2, options2) => {
            const rootNode = root2.type === "NGRoot" ? root2.node.type === "NGMicrosyntax" && root2.node.body.length === 1 && root2.node.body[0].type === "NGMicrosyntaxExpression" ? root2.node.body[0].expression : root2.node : root2.type === "JsExpressionRoot" ? root2.node : root2;
            if (rootNode && (rootNode.type === "ObjectExpression" || rootNode.type === "ArrayExpression" || options2.parser === "__vue_expression" && (rootNode.type === "TemplateLiteral" || rootNode.type === "StringLiteral"))) {
              shouldHug = true;
            }
          };
          const printHug = (doc2) => group(doc2);
          const printExpand = (doc2, canHaveTrailingWhitespace = true) => group([indent([softline, doc2]), canHaveTrailingWhitespace ? softline : ""]);
          const printMaybeHug = (doc2) => shouldHug ? printHug(doc2) : printExpand(doc2);
          const attributeTextToDoc = (code, opts) => htmlTextToDoc(code, Object.assign({
            __onHtmlBindingRoot,
            __embeddedInHtml: true
          }, opts));
          if (node.fullName === "srcset" && (node.parent.fullName === "img" || node.parent.fullName === "source")) {
            return printExpand(printImgSrcset(getValue()));
          }
          if (node.fullName === "class" && !options.parentParser) {
            const value2 = getValue();
            if (!value2.includes("{{")) {
              return printClassNames(value2);
            }
          }
          if (node.fullName === "style" && !options.parentParser) {
            const value2 = getValue();
            if (!value2.includes("{{")) {
              return printExpand(attributeTextToDoc(value2, {
                parser: "css",
                __isHTMLStyleAttribute: true
              }));
            }
          }
          if (options.parser === "vue") {
            if (node.fullName === "v-for") {
              return printVueFor(getValue(), attributeTextToDoc);
            }
            if (isVueSlotAttribute(node) || isVueSfcBindingsAttribute(node, options)) {
              return printVueBindings(getValue(), attributeTextToDoc);
            }
            const vueEventBindingPatterns = ["^@", "^v-on:"];
            const vueExpressionBindingPatterns = ["^:", "^v-bind:"];
            const jsExpressionBindingPatterns = ["^v-"];
            if (isKeyMatched(vueEventBindingPatterns)) {
              const value2 = getValue();
              const parser = isVueEventBindingExpression(value2) ? "__js_expression" : options.__should_parse_vue_template_with_ts ? "__vue_ts_event_binding" : "__vue_event_binding";
              return printMaybeHug(attributeTextToDoc(value2, {
                parser
              }));
            }
            if (isKeyMatched(vueExpressionBindingPatterns)) {
              return printMaybeHug(attributeTextToDoc(getValue(), {
                parser: "__vue_expression"
              }));
            }
            if (isKeyMatched(jsExpressionBindingPatterns)) {
              return printMaybeHug(attributeTextToDoc(getValue(), {
                parser: "__js_expression"
              }));
            }
          }
          if (options.parser === "angular") {
            const ngTextToDoc = (code, opts) => attributeTextToDoc(code, Object.assign(Object.assign({}, opts), {}, {
              trailingComma: "none"
            }));
            const ngDirectiveBindingPatterns = ["^\\*"];
            const ngStatementBindingPatterns = ["^\\(.+\\)$", "^on-"];
            const ngExpressionBindingPatterns = ["^\\[.+\\]$", "^bind(on)?-", "^ng-(if|show|hide|class|style)$"];
            const ngI18nPatterns = ["^i18n(-.+)?$"];
            if (isKeyMatched(ngStatementBindingPatterns)) {
              return printMaybeHug(ngTextToDoc(getValue(), {
                parser: "__ng_action"
              }));
            }
            if (isKeyMatched(ngExpressionBindingPatterns)) {
              return printMaybeHug(ngTextToDoc(getValue(), {
                parser: "__ng_binding"
              }));
            }
            if (isKeyMatched(ngI18nPatterns)) {
              const value22 = getValue().trim();
              return printExpand(fill(getTextValueParts(node, value22)), !value22.includes("@@"));
            }
            if (isKeyMatched(ngDirectiveBindingPatterns)) {
              return printMaybeHug(ngTextToDoc(getValue(), {
                parser: "__ng_directive"
              }));
            }
            const interpolationRegex = /{{(.+?)}}/s;
            const value2 = getValue();
            if (interpolationRegex.test(value2)) {
              const parts = [];
              for (const [index, part] of value2.split(interpolationRegex).entries()) {
                if (index % 2 === 0) {
                  parts.push(replaceTextEndOfLine(part));
                } else {
                  try {
                    parts.push(group(["{{", indent([line, ngTextToDoc(part, {
                      parser: "__ng_interpolation",
                      __isInHtmlInterpolation: true
                    })]), line, "}}"]));
                  } catch {
                    parts.push("{{", replaceTextEndOfLine(part), "}}");
                  }
                }
              }
              return group(parts);
            }
          }
          return null;
        }
        function embed(path2, print, textToDoc, options) {
          const node = path2.getValue();
          switch (node.type) {
            case "element": {
              if (isScriptLikeTag(node) || node.type === "interpolation") {
                return;
              }
              if (!node.isSelfClosing && isVueNonHtmlBlock(node, options)) {
                const parser = inferScriptParser(node, options);
                if (!parser) {
                  return;
                }
                const content = getNodeContent(node, options);
                let isEmpty2 = /^\s*$/.test(content);
                let doc2 = "";
                if (!isEmpty2) {
                  doc2 = textToDoc(htmlTrimPreserveIndentation(content), {
                    parser,
                    __embeddedInHtml: true
                  }, {
                    stripTrailingHardline: true
                  });
                  isEmpty2 = doc2 === "";
                }
                return [printOpeningTagPrefix(node, options), group(printOpeningTag(path2, options, print)), isEmpty2 ? "" : hardline, doc2, isEmpty2 ? "" : hardline, printClosingTag(node, options), printClosingTagSuffix(node, options)];
              }
              break;
            }
            case "text": {
              if (isScriptLikeTag(node.parent)) {
                const parser = inferScriptParser(node.parent, options);
                if (parser) {
                  const value2 = parser === "markdown" ? dedentString(node.value.replace(/^[^\S\n]*\n/, "")) : node.value;
                  const textToDocOptions = {
                    parser,
                    __embeddedInHtml: true
                  };
                  if (options.parser === "html" && parser === "babel") {
                    let sourceType = "script";
                    const {
                      attrMap
                    } = node.parent;
                    if (attrMap && (attrMap.type === "module" || attrMap.type === "text/babel" && attrMap["data-type"] === "module")) {
                      sourceType = "module";
                    }
                    textToDocOptions.__babelSourceType = sourceType;
                  }
                  return [breakParent, printOpeningTagPrefix(node, options), textToDoc(value2, textToDocOptions, {
                    stripTrailingHardline: true
                  }), printClosingTagSuffix(node, options)];
                }
              } else if (node.parent.type === "interpolation") {
                const textToDocOptions = {
                  __isInHtmlInterpolation: true,
                  __embeddedInHtml: true
                };
                if (options.parser === "angular") {
                  textToDocOptions.parser = "__ng_interpolation";
                  textToDocOptions.trailingComma = "none";
                } else if (options.parser === "vue") {
                  textToDocOptions.parser = options.__should_parse_vue_template_with_ts ? "__vue_ts_expression" : "__vue_expression";
                } else {
                  textToDocOptions.parser = "__js_expression";
                }
                return [indent([line, textToDoc(node.value, textToDocOptions, {
                  stripTrailingHardline: true
                })]), node.parent.next && needsToBorrowPrevClosingTagEndMarker(node.parent.next) ? " " : line];
              }
              break;
            }
            case "attribute": {
              if (!node.value) {
                break;
              }
              if (/^PRETTIER_HTML_PLACEHOLDER_\d+_\d+_IN_JS$/.test(options.originalText.slice(node.valueSpan.start.offset, node.valueSpan.end.offset))) {
                return [node.rawName, "=", node.value];
              }
              if (options.parser === "lwc") {
                const interpolationRegex = /^{.*}$/s;
                if (interpolationRegex.test(options.originalText.slice(node.valueSpan.start.offset, node.valueSpan.end.offset))) {
                  return [node.rawName, "=", node.value];
                }
              }
              const embeddedAttributeValueDoc = printEmbeddedAttributeValue(node, (code, opts) => textToDoc(code, Object.assign({
                __isInHtmlAttribute: true,
                __embeddedInHtml: true
              }, opts), {
                stripTrailingHardline: true
              }), options);
              if (embeddedAttributeValueDoc) {
                return [node.rawName, '="', group(mapDoc(embeddedAttributeValueDoc, (doc2) => typeof doc2 === "string" ? doc2.replace(/"/g, "&quot;") : doc2)), '"'];
              }
              break;
            }
            case "front-matter":
              return printFrontMatter(node, textToDoc);
          }
        }
        module22.exports = embed;
      }
    });
    var require_children = __commonJS22({
      "src/language-html/print/children.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            breakParent,
            group,
            ifBreak,
            line,
            softline,
            hardline
          },
          utils: {
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          locStart,
          locEnd
        } = require_loc6();
        var {
          forceBreakChildren,
          forceNextEmptyLine,
          isTextLikeNode,
          hasPrettierIgnore,
          preferHardlineAsLeadingSpaces
        } = require_utils11();
        var {
          printOpeningTagPrefix,
          needsToBorrowNextOpeningTagStartMarker,
          printOpeningTagStartMarker,
          needsToBorrowPrevClosingTagEndMarker,
          printClosingTagEndMarker,
          printClosingTagSuffix,
          needsToBorrowParentClosingTagStartMarker
        } = require_tag();
        function printChild(childPath, options, print) {
          const child = childPath.getValue();
          if (hasPrettierIgnore(child)) {
            return [printOpeningTagPrefix(child, options), ...replaceTextEndOfLine(options.originalText.slice(locStart(child) + (child.prev && needsToBorrowNextOpeningTagStartMarker(child.prev) ? printOpeningTagStartMarker(child).length : 0), locEnd(child) - (child.next && needsToBorrowPrevClosingTagEndMarker(child.next) ? printClosingTagEndMarker(child, options).length : 0))), printClosingTagSuffix(child, options)];
          }
          return print();
        }
        function printBetweenLine(prevNode, nextNode) {
          return isTextLikeNode(prevNode) && isTextLikeNode(nextNode) ? prevNode.isTrailingSpaceSensitive ? prevNode.hasTrailingSpaces ? preferHardlineAsLeadingSpaces(nextNode) ? hardline : line : "" : preferHardlineAsLeadingSpaces(nextNode) ? hardline : softline : needsToBorrowNextOpeningTagStartMarker(prevNode) && (hasPrettierIgnore(nextNode) || nextNode.firstChild || nextNode.isSelfClosing || nextNode.type === "element" && nextNode.attrs.length > 0) || prevNode.type === "element" && prevNode.isSelfClosing && needsToBorrowPrevClosingTagEndMarker(nextNode) ? "" : !nextNode.isLeadingSpaceSensitive || preferHardlineAsLeadingSpaces(nextNode) || needsToBorrowPrevClosingTagEndMarker(nextNode) && prevNode.lastChild && needsToBorrowParentClosingTagStartMarker(prevNode.lastChild) && prevNode.lastChild.lastChild && needsToBorrowParentClosingTagStartMarker(prevNode.lastChild.lastChild) ? hardline : nextNode.hasLeadingSpaces ? line : softline;
        }
        function printChildren(path2, options, print) {
          const node = path2.getValue();
          if (forceBreakChildren(node)) {
            return [breakParent, ...path2.map((childPath) => {
              const childNode = childPath.getValue();
              const prevBetweenLine = !childNode.prev ? "" : printBetweenLine(childNode.prev, childNode);
              return [!prevBetweenLine ? "" : [prevBetweenLine, forceNextEmptyLine(childNode.prev) ? hardline : ""], printChild(childPath, options, print)];
            }, "children")];
          }
          const groupIds = node.children.map(() => Symbol(""));
          return path2.map((childPath, childIndex) => {
            const childNode = childPath.getValue();
            if (isTextLikeNode(childNode)) {
              if (childNode.prev && isTextLikeNode(childNode.prev)) {
                const prevBetweenLine2 = printBetweenLine(childNode.prev, childNode);
                if (prevBetweenLine2) {
                  if (forceNextEmptyLine(childNode.prev)) {
                    return [hardline, hardline, printChild(childPath, options, print)];
                  }
                  return [prevBetweenLine2, printChild(childPath, options, print)];
                }
              }
              return printChild(childPath, options, print);
            }
            const prevParts = [];
            const leadingParts = [];
            const trailingParts = [];
            const nextParts = [];
            const prevBetweenLine = childNode.prev ? printBetweenLine(childNode.prev, childNode) : "";
            const nextBetweenLine = childNode.next ? printBetweenLine(childNode, childNode.next) : "";
            if (prevBetweenLine) {
              if (forceNextEmptyLine(childNode.prev)) {
                prevParts.push(hardline, hardline);
              } else if (prevBetweenLine === hardline) {
                prevParts.push(hardline);
              } else {
                if (isTextLikeNode(childNode.prev)) {
                  leadingParts.push(prevBetweenLine);
                } else {
                  leadingParts.push(ifBreak("", softline, {
                    groupId: groupIds[childIndex - 1]
                  }));
                }
              }
            }
            if (nextBetweenLine) {
              if (forceNextEmptyLine(childNode)) {
                if (isTextLikeNode(childNode.next)) {
                  nextParts.push(hardline, hardline);
                }
              } else if (nextBetweenLine === hardline) {
                if (isTextLikeNode(childNode.next)) {
                  nextParts.push(hardline);
                }
              } else {
                trailingParts.push(nextBetweenLine);
              }
            }
            return [...prevParts, group([...leadingParts, group([printChild(childPath, options, print), ...trailingParts], {
              id: groupIds[childIndex]
            })]), ...nextParts];
          }, "children");
        }
        module22.exports = {
          printChildren
        };
      }
    });
    var require_element = __commonJS22({
      "src/language-html/print/element.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            breakParent,
            dedentToRoot,
            group,
            ifBreak,
            indentIfBreak,
            indent,
            line,
            softline
          },
          utils: {
            replaceTextEndOfLine
          }
        } = require_doc();
        var getNodeContent = require_get_node_content();
        var {
          shouldPreserveContent,
          isScriptLikeTag,
          isVueCustomBlock,
          countParents,
          forceBreakContent
        } = require_utils11();
        var {
          printOpeningTagPrefix,
          printOpeningTag,
          printClosingTagSuffix,
          printClosingTag,
          needsToBorrowPrevClosingTagEndMarker,
          needsToBorrowLastChildClosingTagEndMarker
        } = require_tag();
        var {
          printChildren
        } = require_children();
        function printElement(path2, options, print) {
          const node = path2.getValue();
          if (shouldPreserveContent(node, options)) {
            return [printOpeningTagPrefix(node, options), group(printOpeningTag(path2, options, print)), ...replaceTextEndOfLine(getNodeContent(node, options)), ...printClosingTag(node, options), printClosingTagSuffix(node, options)];
          }
          const shouldHugContent = node.children.length === 1 && node.firstChild.type === "interpolation" && node.firstChild.isLeadingSpaceSensitive && !node.firstChild.hasLeadingSpaces && node.lastChild.isTrailingSpaceSensitive && !node.lastChild.hasTrailingSpaces;
          const attrGroupId = Symbol("element-attr-group-id");
          const printTag = (doc2) => group([group(printOpeningTag(path2, options, print), {
            id: attrGroupId
          }), doc2, printClosingTag(node, options)]);
          const printChildrenDoc = (childrenDoc) => {
            if (shouldHugContent) {
              return indentIfBreak(childrenDoc, {
                groupId: attrGroupId
              });
            }
            if ((isScriptLikeTag(node) || isVueCustomBlock(node, options)) && node.parent.type === "root" && options.parser === "vue" && !options.vueIndentScriptAndStyle) {
              return childrenDoc;
            }
            return indent(childrenDoc);
          };
          const printLineBeforeChildren = () => {
            if (shouldHugContent) {
              return ifBreak(softline, "", {
                groupId: attrGroupId
              });
            }
            if (node.firstChild.hasLeadingSpaces && node.firstChild.isLeadingSpaceSensitive) {
              return line;
            }
            if (node.firstChild.type === "text" && node.isWhitespaceSensitive && node.isIndentationSensitive) {
              return dedentToRoot(softline);
            }
            return softline;
          };
          const printLineAfterChildren = () => {
            const needsToBorrow = node.next ? needsToBorrowPrevClosingTagEndMarker(node.next) : needsToBorrowLastChildClosingTagEndMarker(node.parent);
            if (needsToBorrow) {
              if (node.lastChild.hasTrailingSpaces && node.lastChild.isTrailingSpaceSensitive) {
                return " ";
              }
              return "";
            }
            if (shouldHugContent) {
              return ifBreak(softline, "", {
                groupId: attrGroupId
              });
            }
            if (node.lastChild.hasTrailingSpaces && node.lastChild.isTrailingSpaceSensitive) {
              return line;
            }
            if ((node.lastChild.type === "comment" || node.lastChild.type === "text" && node.isWhitespaceSensitive && node.isIndentationSensitive) && new RegExp(`\\n[\\t ]{${options.tabWidth * countParents(path2, (node2) => node2.parent && node2.parent.type !== "root")}}$`).test(node.lastChild.value)) {
              return "";
            }
            return softline;
          };
          if (node.children.length === 0) {
            return printTag(node.hasDanglingSpaces && node.isDanglingSpaceSensitive ? line : "");
          }
          return printTag([forceBreakContent(node) ? breakParent : "", printChildrenDoc([printLineBeforeChildren(), printChildren(path2, options, print)]), printLineAfterChildren()]);
        }
        module22.exports = {
          printElement
        };
      }
    });
    var require_printer_html = __commonJS22({
      "src/language-html/printer-html.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            fill,
            group,
            hardline,
            literalline
          },
          utils: {
            cleanDoc,
            getDocParts,
            isConcat,
            replaceTextEndOfLine
          }
        } = require_doc();
        var clean = require_clean5();
        var {
          countChars,
          unescapeQuoteEntities,
          getTextValueParts
        } = require_utils11();
        var preprocess = require_print_preprocess3();
        var {
          insertPragma
        } = require_pragma5();
        var {
          locStart,
          locEnd
        } = require_loc6();
        var embed = require_embed4();
        var {
          printClosingTagSuffix,
          printClosingTagEnd,
          printOpeningTagPrefix,
          printOpeningTagStart
        } = require_tag();
        var {
          printElement
        } = require_element();
        var {
          printChildren
        } = require_children();
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          switch (node.type) {
            case "front-matter":
              return replaceTextEndOfLine(node.raw);
            case "root":
              if (options.__onHtmlRoot) {
                options.__onHtmlRoot(node);
              }
              return [group(printChildren(path2, options, print)), hardline];
            case "element":
            case "ieConditionalComment": {
              return printElement(path2, options, print);
            }
            case "ieConditionalStartComment":
            case "ieConditionalEndComment":
              return [printOpeningTagStart(node), printClosingTagEnd(node)];
            case "interpolation":
              return [printOpeningTagStart(node, options), ...path2.map(print, "children"), printClosingTagEnd(node, options)];
            case "text": {
              if (node.parent.type === "interpolation") {
                const trailingNewlineRegex = /\n[^\S\n]*$/;
                const hasTrailingNewline = trailingNewlineRegex.test(node.value);
                const value2 = hasTrailingNewline ? node.value.replace(trailingNewlineRegex, "") : node.value;
                return [...replaceTextEndOfLine(value2), hasTrailingNewline ? hardline : ""];
              }
              const printed = cleanDoc([printOpeningTagPrefix(node, options), ...getTextValueParts(node), printClosingTagSuffix(node, options)]);
              if (isConcat(printed) || printed.type === "fill") {
                return fill(getDocParts(printed));
              }
              return printed;
            }
            case "docType":
              return [group([printOpeningTagStart(node, options), " ", node.value.replace(/^html\b/i, "html").replace(/\s+/g, " ")]), printClosingTagEnd(node, options)];
            case "comment": {
              return [printOpeningTagPrefix(node, options), ...replaceTextEndOfLine(options.originalText.slice(locStart(node), locEnd(node)), literalline), printClosingTagSuffix(node, options)];
            }
            case "attribute": {
              if (node.value === null) {
                return node.rawName;
              }
              const value2 = unescapeQuoteEntities(node.value);
              const singleQuoteCount = countChars(value2, "'");
              const doubleQuoteCount = countChars(value2, '"');
              const quote = singleQuoteCount < doubleQuoteCount ? "'" : '"';
              return [node.rawName, "=", quote, ...replaceTextEndOfLine(quote === '"' ? value2.replace(/"/g, "&quot;") : value2.replace(/'/g, "&apos;")), quote];
            }
            default:
              throw new Error(`Unexpected node type ${node.type}`);
          }
        }
        module22.exports = {
          preprocess,
          print: genericPrint,
          insertPragma,
          massageAstNode: clean,
          embed
        };
      }
    });
    var require_options6 = __commonJS22({
      "src/language-html/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        var CATEGORY_HTML = "HTML";
        module22.exports = {
          bracketSameLine: commonOptions.bracketSameLine,
          htmlWhitespaceSensitivity: {
            since: "1.15.0",
            category: CATEGORY_HTML,
            type: "choice",
            default: "css",
            description: "How to handle whitespaces in HTML.",
            choices: [{
              value: "css",
              description: "Respect the default value of CSS display property."
            }, {
              value: "strict",
              description: "Whitespaces are considered sensitive."
            }, {
              value: "ignore",
              description: "Whitespaces are considered insensitive."
            }]
          },
          singleAttributePerLine: commonOptions.singleAttributePerLine,
          vueIndentScriptAndStyle: {
            since: "1.19.0",
            category: CATEGORY_HTML,
            type: "boolean",
            default: false,
            description: "Indent script and style tags in Vue files."
          }
        };
      }
    });
    var require_parsers6 = __commonJS22({
      "src/language-html/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get html() {
            return require_parser_html().parsers.html;
          },
          get vue() {
            return require_parser_html().parsers.vue;
          },
          get angular() {
            return require_parser_html().parsers.angular;
          },
          get lwc() {
            return require_parser_html().parsers.lwc;
          }
        };
      }
    });
    var require_HTML = __commonJS22({
      "node_modules/linguist-languages/data/HTML.json"(exports2, module22) {
        module22.exports = {
          name: "HTML",
          type: "markup",
          tmScope: "text.html.basic",
          aceMode: "html",
          codemirrorMode: "htmlmixed",
          codemirrorMimeType: "text/html",
          color: "#e34c26",
          aliases: ["xhtml"],
          extensions: [".html", ".hta", ".htm", ".html.hl", ".inc", ".xht", ".xhtml"],
          languageId: 146
        };
      }
    });
    var require_Vue = __commonJS22({
      "node_modules/linguist-languages/data/Vue.json"(exports2, module22) {
        module22.exports = {
          name: "Vue",
          type: "markup",
          color: "#41b883",
          extensions: [".vue"],
          tmScope: "text.html.vue",
          aceMode: "html",
          languageId: 391
        };
      }
    });
    var require_language_html = __commonJS22({
      "src/language-html/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_html();
        var options = require_options6();
        var parsers = require_parsers6();
        var languages = [createLanguage(require_HTML(), () => ({
          name: "Angular",
          since: "1.15.0",
          parsers: ["angular"],
          vscodeLanguageIds: ["html"],
          extensions: [".component.html"],
          filenames: []
        })), createLanguage(require_HTML(), (data) => ({
          since: "1.15.0",
          parsers: ["html"],
          vscodeLanguageIds: ["html"],
          extensions: [...data.extensions, ".mjml"]
        })), createLanguage(require_HTML(), () => ({
          name: "Lightning Web Components",
          since: "1.17.0",
          parsers: ["lwc"],
          vscodeLanguageIds: ["html"],
          extensions: [],
          filenames: []
        })), createLanguage(require_Vue(), () => ({
          since: "1.10.0",
          parsers: ["vue"],
          vscodeLanguageIds: ["vue"]
        }))];
        var printers = {
          html: printer
        };
        module22.exports = {
          languages,
          printers,
          options,
          parsers
        };
      }
    });
    var require_pragma6 = __commonJS22({
      "src/language-yaml/pragma.js"(exports2, module22) {
        "use strict";
        function isPragma(text) {
          return /^\s*@(?:prettier|format)\s*$/.test(text);
        }
        function hasPragma(text) {
          return /^\s*#[^\S\n]*@(?:prettier|format)\s*?(?:\n|$)/.test(text);
        }
        function insertPragma(text) {
          return `# @format

${text}`;
        }
        module22.exports = {
          isPragma,
          hasPragma,
          insertPragma
        };
      }
    });
    var require_loc7 = __commonJS22({
      "src/language-yaml/loc.js"(exports2, module22) {
        "use strict";
        function locStart(node) {
          return node.position.start.offset;
        }
        function locEnd(node) {
          return node.position.end.offset;
        }
        module22.exports = {
          locStart,
          locEnd
        };
      }
    });
    var require_embed5 = __commonJS22({
      "src/language-yaml/embed.js"(exports2, module22) {
        "use strict";
        function embed(path2, print, textToDoc, options) {
          const node = path2.getValue();
          if (node.type === "root" && options.filepath && /(?:[/\\]|^)\.(?:prettier|stylelint|lintstaged)rc$/.test(options.filepath)) {
            return textToDoc(options.originalText, Object.assign(Object.assign({}, options), {}, {
              parser: "json"
            }));
          }
        }
        module22.exports = embed;
      }
    });
    var require_utils12 = __commonJS22({
      "src/language-yaml/utils.js"(exports2, module22) {
        "use strict";
        var {
          getLast,
          isNonEmptyArray
        } = require_util6();
        function getAncestorCount(path2, filter) {
          let counter = 0;
          const pathStackLength = path2.stack.length - 1;
          for (let i = 0; i < pathStackLength; i++) {
            const value2 = path2.stack[i];
            if (isNode(value2) && filter(value2)) {
              counter++;
            }
          }
          return counter;
        }
        function isNode(value2, types) {
          return value2 && typeof value2.type === "string" && (!types || types.includes(value2.type));
        }
        function mapNode(node, callback, parent) {
          return callback("children" in node ? Object.assign(Object.assign({}, node), {}, {
            children: node.children.map((childNode) => mapNode(childNode, callback, node))
          }) : node, parent);
        }
        function defineShortcut(x, key, getter) {
          Object.defineProperty(x, key, {
            get: getter,
            enumerable: false
          });
        }
        function isNextLineEmpty(node, text) {
          let newlineCount = 0;
          const textLength = text.length;
          for (let i = node.position.end.offset - 1; i < textLength; i++) {
            const char = text[i];
            if (char === "\n") {
              newlineCount++;
            }
            if (newlineCount === 1 && /\S/.test(char)) {
              return false;
            }
            if (newlineCount === 2) {
              return true;
            }
          }
          return false;
        }
        function isLastDescendantNode(path2) {
          const node = path2.getValue();
          switch (node.type) {
            case "tag":
            case "anchor":
            case "comment":
              return false;
          }
          const pathStackLength = path2.stack.length;
          for (let i = 1; i < pathStackLength; i++) {
            const item = path2.stack[i];
            const parentItem = path2.stack[i - 1];
            if (Array.isArray(parentItem) && typeof item === "number" && item !== parentItem.length - 1) {
              return false;
            }
          }
          return true;
        }
        function getLastDescendantNode(node) {
          return isNonEmptyArray(node.children) ? getLastDescendantNode(getLast(node.children)) : node;
        }
        function isPrettierIgnore(comment) {
          return comment.value.trim() === "prettier-ignore";
        }
        function hasPrettierIgnore(path2) {
          const node = path2.getValue();
          if (node.type === "documentBody") {
            const document2 = path2.getParentNode();
            return hasEndComments(document2.head) && isPrettierIgnore(getLast(document2.head.endComments));
          }
          return hasLeadingComments(node) && isPrettierIgnore(getLast(node.leadingComments));
        }
        function isEmptyNode(node) {
          return !isNonEmptyArray(node.children) && !hasComments(node);
        }
        function hasComments(node) {
          return hasLeadingComments(node) || hasMiddleComments(node) || hasIndicatorComment(node) || hasTrailingComment(node) || hasEndComments(node);
        }
        function hasLeadingComments(node) {
          return isNonEmptyArray(node === null || node === void 0 ? void 0 : node.leadingComments);
        }
        function hasMiddleComments(node) {
          return isNonEmptyArray(node === null || node === void 0 ? void 0 : node.middleComments);
        }
        function hasIndicatorComment(node) {
          return node === null || node === void 0 ? void 0 : node.indicatorComment;
        }
        function hasTrailingComment(node) {
          return node === null || node === void 0 ? void 0 : node.trailingComment;
        }
        function hasEndComments(node) {
          return isNonEmptyArray(node === null || node === void 0 ? void 0 : node.endComments);
        }
        function splitWithSingleSpace(text) {
          const parts = [];
          let lastPart;
          for (const part of text.split(/( +)/)) {
            if (part !== " ") {
              if (lastPart === " ") {
                parts.push(part);
              } else {
                parts.push((parts.pop() || "") + part);
              }
            } else if (lastPart === void 0) {
              parts.unshift("");
            }
            lastPart = part;
          }
          if (lastPart === " ") {
            parts.push((parts.pop() || "") + " ");
          }
          if (parts[0] === "") {
            parts.shift();
            parts.unshift(" " + (parts.shift() || ""));
          }
          return parts;
        }
        function getFlowScalarLineContents(nodeType, content, options) {
          const rawLineContents = content.split("\n").map((lineContent, index, lineContents) => index === 0 && index === lineContents.length - 1 ? lineContent : index !== 0 && index !== lineContents.length - 1 ? lineContent.trim() : index === 0 ? lineContent.trimEnd() : lineContent.trimStart());
          if (options.proseWrap === "preserve") {
            return rawLineContents.map((lineContent) => lineContent.length === 0 ? [] : [lineContent]);
          }
          return rawLineContents.map((lineContent) => lineContent.length === 0 ? [] : splitWithSingleSpace(lineContent)).reduce((reduced, lineContentWords, index) => index !== 0 && rawLineContents[index - 1].length > 0 && lineContentWords.length > 0 && !(nodeType === "quoteDouble" && getLast(getLast(reduced)).endsWith("\\")) ? [...reduced.slice(0, -1), [...getLast(reduced), ...lineContentWords]] : [...reduced, lineContentWords], []).map((lineContentWords) => options.proseWrap === "never" ? [lineContentWords.join(" ")] : lineContentWords);
        }
        function getBlockValueLineContents(node, {
          parentIndent,
          isLastDescendant,
          options
        }) {
          const content = node.position.start.line === node.position.end.line ? "" : options.originalText.slice(node.position.start.offset, node.position.end.offset).match(/^[^\n]*\n(.*)$/s)[1];
          let leadingSpaceCount;
          if (node.indent === null) {
            const matches = content.match(/^(?<leadingSpace> *)[^\n\r ]/m);
            leadingSpaceCount = matches ? matches.groups.leadingSpace.length : Number.POSITIVE_INFINITY;
          } else {
            leadingSpaceCount = node.indent - 1 + parentIndent;
          }
          const rawLineContents = content.split("\n").map((lineContent) => lineContent.slice(leadingSpaceCount));
          if (options.proseWrap === "preserve" || node.type === "blockLiteral") {
            return removeUnnecessaryTrailingNewlines(rawLineContents.map((lineContent) => lineContent.length === 0 ? [] : [lineContent]));
          }
          return removeUnnecessaryTrailingNewlines(rawLineContents.map((lineContent) => lineContent.length === 0 ? [] : splitWithSingleSpace(lineContent)).reduce((reduced, lineContentWords, index) => index !== 0 && rawLineContents[index - 1].length > 0 && lineContentWords.length > 0 && !/^\s/.test(lineContentWords[0]) && !/^\s|\s$/.test(getLast(reduced)) ? [...reduced.slice(0, -1), [...getLast(reduced), ...lineContentWords]] : [...reduced, lineContentWords], []).map((lineContentWords) => lineContentWords.reduce((reduced, word) => reduced.length > 0 && /\s$/.test(getLast(reduced)) ? [...reduced.slice(0, -1), getLast(reduced) + " " + word] : [...reduced, word], [])).map((lineContentWords) => options.proseWrap === "never" ? [lineContentWords.join(" ")] : lineContentWords));
          function removeUnnecessaryTrailingNewlines(lineContents) {
            if (node.chomping === "keep") {
              return getLast(lineContents).length === 0 ? lineContents.slice(0, -1) : lineContents;
            }
            let trailingNewlineCount = 0;
            for (let i = lineContents.length - 1; i >= 0; i--) {
              if (lineContents[i].length === 0) {
                trailingNewlineCount++;
              } else {
                break;
              }
            }
            return trailingNewlineCount === 0 ? lineContents : trailingNewlineCount >= 2 && !isLastDescendant ? lineContents.slice(0, -(trailingNewlineCount - 1)) : lineContents.slice(0, -trailingNewlineCount);
          }
        }
        function isInlineNode(node) {
          if (!node) {
            return true;
          }
          switch (node.type) {
            case "plain":
            case "quoteDouble":
            case "quoteSingle":
            case "alias":
            case "flowMapping":
            case "flowSequence":
              return true;
            default:
              return false;
          }
        }
        module22.exports = {
          getLast,
          getAncestorCount,
          isNode,
          isEmptyNode,
          isInlineNode,
          mapNode,
          defineShortcut,
          isNextLineEmpty,
          isLastDescendantNode,
          getBlockValueLineContents,
          getFlowScalarLineContents,
          getLastDescendantNode,
          hasPrettierIgnore,
          hasLeadingComments,
          hasMiddleComments,
          hasIndicatorComment,
          hasTrailingComment,
          hasEndComments
        };
      }
    });
    var require_print_preprocess4 = __commonJS22({
      "src/language-yaml/print-preprocess.js"(exports2, module22) {
        "use strict";
        var {
          defineShortcut,
          mapNode
        } = require_utils12();
        function preprocess(ast) {
          return mapNode(ast, defineShortcuts);
        }
        function defineShortcuts(node) {
          switch (node.type) {
            case "document":
              defineShortcut(node, "head", () => node.children[0]);
              defineShortcut(node, "body", () => node.children[1]);
              break;
            case "documentBody":
            case "sequenceItem":
            case "flowSequenceItem":
            case "mappingKey":
            case "mappingValue":
              defineShortcut(node, "content", () => node.children[0]);
              break;
            case "mappingItem":
            case "flowMappingItem":
              defineShortcut(node, "key", () => node.children[0]);
              defineShortcut(node, "value", () => node.children[1]);
              break;
          }
          return node;
        }
        module22.exports = preprocess;
      }
    });
    var require_misc22 = __commonJS22({
      "src/language-yaml/print/misc.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            softline,
            align
          }
        } = require_doc();
        var {
          hasEndComments,
          isNextLineEmpty,
          isNode
        } = require_utils12();
        var printedEmptyLineCache = /* @__PURE__ */ new WeakMap();
        function printNextEmptyLine(path2, originalText) {
          const node = path2.getValue();
          const root2 = path2.stack[0];
          let isNextEmptyLinePrintedSet;
          if (printedEmptyLineCache.has(root2)) {
            isNextEmptyLinePrintedSet = printedEmptyLineCache.get(root2);
          } else {
            isNextEmptyLinePrintedSet = /* @__PURE__ */ new Set();
            printedEmptyLineCache.set(root2, isNextEmptyLinePrintedSet);
          }
          if (!isNextEmptyLinePrintedSet.has(node.position.end.line)) {
            isNextEmptyLinePrintedSet.add(node.position.end.line);
            if (isNextLineEmpty(node, originalText) && !shouldPrintEndComments(path2.getParentNode())) {
              return softline;
            }
          }
          return "";
        }
        function shouldPrintEndComments(node) {
          return hasEndComments(node) && !isNode(node, ["documentHead", "documentBody", "flowMapping", "flowSequence"]);
        }
        function alignWithSpaces(width, doc2) {
          return align(" ".repeat(width), doc2);
        }
        module22.exports = {
          alignWithSpaces,
          shouldPrintEndComments,
          printNextEmptyLine
        };
      }
    });
    var require_flow_mapping_sequence = __commonJS22({
      "src/language-yaml/print/flow-mapping-sequence.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            ifBreak,
            line,
            softline,
            hardline,
            join
          }
        } = require_doc();
        var {
          isEmptyNode,
          getLast,
          hasEndComments
        } = require_utils12();
        var {
          printNextEmptyLine,
          alignWithSpaces
        } = require_misc22();
        function printFlowMapping(path2, print, options) {
          const node = path2.getValue();
          const isMapping = node.type === "flowMapping";
          const openMarker = isMapping ? "{" : "[";
          const closeMarker = isMapping ? "}" : "]";
          let bracketSpacing = softline;
          if (isMapping && node.children.length > 0 && options.bracketSpacing) {
            bracketSpacing = line;
          }
          const lastItem = getLast(node.children);
          const isLastItemEmptyMappingItem = lastItem && lastItem.type === "flowMappingItem" && isEmptyNode(lastItem.key) && isEmptyNode(lastItem.value);
          return [openMarker, alignWithSpaces(options.tabWidth, [bracketSpacing, printChildren(path2, print, options), options.trailingComma === "none" ? "" : ifBreak(","), hasEndComments(node) ? [hardline, join(hardline, path2.map(print, "endComments"))] : ""]), isLastItemEmptyMappingItem ? "" : bracketSpacing, closeMarker];
        }
        function printChildren(path2, print, options) {
          const node = path2.getValue();
          const parts = path2.map((childPath, index) => [print(), index === node.children.length - 1 ? "" : [",", line, node.children[index].position.start.line !== node.children[index + 1].position.start.line ? printNextEmptyLine(childPath, options.originalText) : ""]], "children");
          return parts;
        }
        module22.exports = {
          printFlowMapping,
          printFlowSequence: printFlowMapping
        };
      }
    });
    var require_mapping_item = __commonJS22({
      "src/language-yaml/print/mapping-item.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            conditionalGroup,
            group,
            hardline,
            ifBreak,
            join,
            line
          }
        } = require_doc();
        var {
          hasLeadingComments,
          hasMiddleComments,
          hasTrailingComment,
          hasEndComments,
          isNode,
          isEmptyNode,
          isInlineNode
        } = require_utils12();
        var {
          alignWithSpaces
        } = require_misc22();
        function printMappingItem(node, parentNode, path2, print, options) {
          const {
            key,
            value: value2
          } = node;
          const isEmptyMappingKey = isEmptyNode(key);
          const isEmptyMappingValue = isEmptyNode(value2);
          if (isEmptyMappingKey && isEmptyMappingValue) {
            return ": ";
          }
          const printedKey = print("key");
          const spaceBeforeColon = needsSpaceInFrontOfMappingValue(node) ? " " : "";
          if (isEmptyMappingValue) {
            if (node.type === "flowMappingItem" && parentNode.type === "flowMapping") {
              return printedKey;
            }
            if (node.type === "mappingItem" && isAbsolutelyPrintedAsSingleLineNode(key.content, options) && !hasTrailingComment(key.content) && (!parentNode.tag || parentNode.tag.value !== "tag:yaml.org,2002:set")) {
              return [printedKey, spaceBeforeColon, ":"];
            }
            return ["? ", alignWithSpaces(2, printedKey)];
          }
          const printedValue = print("value");
          if (isEmptyMappingKey) {
            return [": ", alignWithSpaces(2, printedValue)];
          }
          if (hasLeadingComments(value2) || !isInlineNode(key.content)) {
            return ["? ", alignWithSpaces(2, printedKey), hardline, join("", path2.map(print, "value", "leadingComments").map((comment) => [comment, hardline])), ": ", alignWithSpaces(2, printedValue)];
          }
          if (isSingleLineNode(key.content) && !hasLeadingComments(key.content) && !hasMiddleComments(key.content) && !hasTrailingComment(key.content) && !hasEndComments(key) && !hasLeadingComments(value2.content) && !hasMiddleComments(value2.content) && !hasEndComments(value2) && isAbsolutelyPrintedAsSingleLineNode(value2.content, options)) {
            return [printedKey, spaceBeforeColon, ": ", printedValue];
          }
          const groupId = Symbol("mappingKey");
          const groupedKey = group([ifBreak("? "), group(alignWithSpaces(2, printedKey), {
            id: groupId
          })]);
          const explicitMappingValue = [hardline, ": ", alignWithSpaces(2, printedValue)];
          const implicitMappingValueParts = [spaceBeforeColon, ":"];
          if (hasLeadingComments(value2.content) || hasEndComments(value2) && value2.content && !isNode(value2.content, ["mapping", "sequence"]) || parentNode.type === "mapping" && hasTrailingComment(key.content) && isInlineNode(value2.content) || isNode(value2.content, ["mapping", "sequence"]) && value2.content.tag === null && value2.content.anchor === null) {
            implicitMappingValueParts.push(hardline);
          } else if (value2.content) {
            implicitMappingValueParts.push(line);
          }
          implicitMappingValueParts.push(printedValue);
          const implicitMappingValue = alignWithSpaces(options.tabWidth, implicitMappingValueParts);
          if (isAbsolutelyPrintedAsSingleLineNode(key.content, options) && !hasLeadingComments(key.content) && !hasMiddleComments(key.content) && !hasEndComments(key)) {
            return conditionalGroup([[printedKey, implicitMappingValue]]);
          }
          return conditionalGroup([[groupedKey, ifBreak(explicitMappingValue, implicitMappingValue, {
            groupId
          })]]);
        }
        function isAbsolutelyPrintedAsSingleLineNode(node, options) {
          if (!node) {
            return true;
          }
          switch (node.type) {
            case "plain":
            case "quoteSingle":
            case "quoteDouble":
              break;
            case "alias":
              return true;
            default:
              return false;
          }
          if (options.proseWrap === "preserve") {
            return node.position.start.line === node.position.end.line;
          }
          if (/\\$/m.test(options.originalText.slice(node.position.start.offset, node.position.end.offset))) {
            return false;
          }
          switch (options.proseWrap) {
            case "never":
              return !node.value.includes("\n");
            case "always":
              return !/[\n ]/.test(node.value);
            default:
              return false;
          }
        }
        function needsSpaceInFrontOfMappingValue(node) {
          return node.key.content && node.key.content.type === "alias";
        }
        function isSingleLineNode(node) {
          if (!node) {
            return true;
          }
          switch (node.type) {
            case "plain":
            case "quoteDouble":
            case "quoteSingle":
              return node.position.start.line === node.position.end.line;
            case "alias":
              return true;
            default:
              return false;
          }
        }
        module22.exports = printMappingItem;
      }
    });
    var require_block2 = __commonJS22({
      "src/language-yaml/print/block.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            dedent,
            dedentToRoot,
            fill,
            hardline,
            join,
            line,
            literalline,
            markAsRoot
          },
          utils: {
            getDocParts
          }
        } = require_doc();
        var {
          getAncestorCount,
          getBlockValueLineContents,
          hasIndicatorComment,
          isLastDescendantNode,
          isNode
        } = require_utils12();
        var {
          alignWithSpaces
        } = require_misc22();
        function printBlock(path2, print, options) {
          const node = path2.getValue();
          const parentIndent = getAncestorCount(path2, (ancestorNode) => isNode(ancestorNode, ["sequence", "mapping"]));
          const isLastDescendant = isLastDescendantNode(path2);
          const parts = [node.type === "blockFolded" ? ">" : "|"];
          if (node.indent !== null) {
            parts.push(node.indent.toString());
          }
          if (node.chomping !== "clip") {
            parts.push(node.chomping === "keep" ? "+" : "-");
          }
          if (hasIndicatorComment(node)) {
            parts.push(" ", print("indicatorComment"));
          }
          const lineContents = getBlockValueLineContents(node, {
            parentIndent,
            isLastDescendant,
            options
          });
          const contentsParts = [];
          for (const [index, lineWords] of lineContents.entries()) {
            if (index === 0) {
              contentsParts.push(hardline);
            }
            contentsParts.push(fill(getDocParts(join(line, lineWords))));
            if (index !== lineContents.length - 1) {
              contentsParts.push(lineWords.length === 0 ? hardline : markAsRoot(literalline));
            } else if (node.chomping === "keep" && isLastDescendant) {
              contentsParts.push(dedentToRoot(lineWords.length === 0 ? hardline : literalline));
            }
          }
          if (node.indent === null) {
            parts.push(dedent(alignWithSpaces(options.tabWidth, contentsParts)));
          } else {
            parts.push(dedentToRoot(alignWithSpaces(node.indent - 1 + parentIndent, contentsParts)));
          }
          return parts;
        }
        module22.exports = printBlock;
      }
    });
    var require_printer_yaml = __commonJS22({
      "src/language-yaml/printer-yaml.js"(exports2, module22) {
        "use strict";
        var {
          builders: {
            breakParent,
            fill,
            group,
            hardline,
            join,
            line,
            lineSuffix,
            literalline
          },
          utils: {
            getDocParts,
            replaceTextEndOfLine
          }
        } = require_doc();
        var {
          isPreviousLineEmpty
        } = require_util6();
        var {
          insertPragma,
          isPragma
        } = require_pragma6();
        var {
          locStart
        } = require_loc7();
        var embed = require_embed5();
        var {
          getFlowScalarLineContents,
          getLastDescendantNode,
          hasLeadingComments,
          hasMiddleComments,
          hasTrailingComment,
          hasEndComments,
          hasPrettierIgnore,
          isLastDescendantNode,
          isNode,
          isInlineNode
        } = require_utils12();
        var preprocess = require_print_preprocess4();
        var {
          alignWithSpaces,
          printNextEmptyLine,
          shouldPrintEndComments
        } = require_misc22();
        var {
          printFlowMapping,
          printFlowSequence
        } = require_flow_mapping_sequence();
        var printMappingItem = require_mapping_item();
        var printBlock = require_block2();
        function genericPrint(path2, options, print) {
          const node = path2.getValue();
          const parts = [];
          if (node.type !== "mappingValue" && hasLeadingComments(node)) {
            parts.push([join(hardline, path2.map(print, "leadingComments")), hardline]);
          }
          const {
            tag,
            anchor
          } = node;
          if (tag) {
            parts.push(print("tag"));
          }
          if (tag && anchor) {
            parts.push(" ");
          }
          if (anchor) {
            parts.push(print("anchor"));
          }
          let nextEmptyLine = "";
          if (isNode(node, ["mapping", "sequence", "comment", "directive", "mappingItem", "sequenceItem"]) && !isLastDescendantNode(path2)) {
            nextEmptyLine = printNextEmptyLine(path2, options.originalText);
          }
          if (tag || anchor) {
            if (isNode(node, ["sequence", "mapping"]) && !hasMiddleComments(node)) {
              parts.push(hardline);
            } else {
              parts.push(" ");
            }
          }
          if (hasMiddleComments(node)) {
            parts.push([node.middleComments.length === 1 ? "" : hardline, join(hardline, path2.map(print, "middleComments")), hardline]);
          }
          const parentNode = path2.getParentNode();
          if (hasPrettierIgnore(path2)) {
            parts.push(replaceTextEndOfLine(options.originalText.slice(node.position.start.offset, node.position.end.offset).trimEnd(), literalline));
          } else {
            parts.push(group(printNode(node, parentNode, path2, options, print)));
          }
          if (hasTrailingComment(node) && !isNode(node, ["document", "documentHead"])) {
            parts.push(lineSuffix([node.type === "mappingValue" && !node.content ? "" : " ", parentNode.type === "mappingKey" && path2.getParentNode(2).type === "mapping" && isInlineNode(node) ? "" : breakParent, print("trailingComment")]));
          }
          if (shouldPrintEndComments(node)) {
            parts.push(alignWithSpaces(node.type === "sequenceItem" ? 2 : 0, [hardline, join(hardline, path2.map((path22) => [isPreviousLineEmpty(options.originalText, path22.getValue(), locStart) ? hardline : "", print()], "endComments"))]));
          }
          parts.push(nextEmptyLine);
          return parts;
        }
        function printNode(node, parentNode, path2, options, print) {
          switch (node.type) {
            case "root": {
              const {
                children
              } = node;
              const parts = [];
              path2.each((childPath, index) => {
                const document2 = children[index];
                const nextDocument = children[index + 1];
                if (index !== 0) {
                  parts.push(hardline);
                }
                parts.push(print());
                if (shouldPrintDocumentEndMarker(document2, nextDocument)) {
                  parts.push(hardline, "...");
                  if (hasTrailingComment(document2)) {
                    parts.push(" ", print("trailingComment"));
                  }
                } else if (nextDocument && !hasTrailingComment(nextDocument.head)) {
                  parts.push(hardline, "---");
                }
              }, "children");
              const lastDescendantNode = getLastDescendantNode(node);
              if (!isNode(lastDescendantNode, ["blockLiteral", "blockFolded"]) || lastDescendantNode.chomping !== "keep") {
                parts.push(hardline);
              }
              return parts;
            }
            case "document": {
              const nextDocument = parentNode.children[path2.getName() + 1];
              const parts = [];
              if (shouldPrintDocumentHeadEndMarker(node, nextDocument, parentNode, options) === "head") {
                if (node.head.children.length > 0 || node.head.endComments.length > 0) {
                  parts.push(print("head"));
                }
                if (hasTrailingComment(node.head)) {
                  parts.push(["---", " ", print(["head", "trailingComment"])]);
                } else {
                  parts.push("---");
                }
              }
              if (shouldPrintDocumentBody(node)) {
                parts.push(print("body"));
              }
              return join(hardline, parts);
            }
            case "documentHead":
              return join(hardline, [...path2.map(print, "children"), ...path2.map(print, "endComments")]);
            case "documentBody": {
              const {
                children,
                endComments
              } = node;
              let separator = "";
              if (children.length > 0 && endComments.length > 0) {
                const lastDescendantNode = getLastDescendantNode(node);
                if (isNode(lastDescendantNode, ["blockFolded", "blockLiteral"])) {
                  if (lastDescendantNode.chomping !== "keep") {
                    separator = [hardline, hardline];
                  }
                } else {
                  separator = hardline;
                }
              }
              return [join(hardline, path2.map(print, "children")), separator, join(hardline, path2.map(print, "endComments"))];
            }
            case "directive":
              return ["%", join(" ", [node.name, ...node.parameters])];
            case "comment":
              return ["#", node.value];
            case "alias":
              return ["*", node.value];
            case "tag":
              return options.originalText.slice(node.position.start.offset, node.position.end.offset);
            case "anchor":
              return ["&", node.value];
            case "plain":
              return printFlowScalarContent(node.type, options.originalText.slice(node.position.start.offset, node.position.end.offset), options);
            case "quoteDouble":
            case "quoteSingle": {
              const singleQuote = "'";
              const doubleQuote = '"';
              const raw = options.originalText.slice(node.position.start.offset + 1, node.position.end.offset - 1);
              if (node.type === "quoteSingle" && raw.includes("\\") || node.type === "quoteDouble" && /\\[^"]/.test(raw)) {
                const originalQuote = node.type === "quoteDouble" ? doubleQuote : singleQuote;
                return [originalQuote, printFlowScalarContent(node.type, raw, options), originalQuote];
              }
              if (raw.includes(doubleQuote)) {
                return [singleQuote, printFlowScalarContent(node.type, node.type === "quoteDouble" ? raw.replace(/\\"/g, doubleQuote).replace(/'/g, singleQuote.repeat(2)) : raw, options), singleQuote];
              }
              if (raw.includes(singleQuote)) {
                return [doubleQuote, printFlowScalarContent(node.type, node.type === "quoteSingle" ? raw.replace(/''/g, singleQuote) : raw, options), doubleQuote];
              }
              const quote = options.singleQuote ? singleQuote : doubleQuote;
              return [quote, printFlowScalarContent(node.type, raw, options), quote];
            }
            case "blockFolded":
            case "blockLiteral": {
              return printBlock(path2, print, options);
            }
            case "mapping":
            case "sequence":
              return join(hardline, path2.map(print, "children"));
            case "sequenceItem":
              return ["- ", alignWithSpaces(2, node.content ? print("content") : "")];
            case "mappingKey":
            case "mappingValue":
              return !node.content ? "" : print("content");
            case "mappingItem":
            case "flowMappingItem": {
              return printMappingItem(node, parentNode, path2, print, options);
            }
            case "flowMapping":
              return printFlowMapping(path2, print, options);
            case "flowSequence":
              return printFlowSequence(path2, print, options);
            case "flowSequenceItem":
              return print("content");
            default:
              throw new Error(`Unexpected node type ${node.type}`);
          }
        }
        function shouldPrintDocumentBody(document2) {
          return document2.body.children.length > 0 || hasEndComments(document2.body);
        }
        function shouldPrintDocumentEndMarker(document2, nextDocument) {
          return hasTrailingComment(document2) || nextDocument && (nextDocument.head.children.length > 0 || hasEndComments(nextDocument.head));
        }
        function shouldPrintDocumentHeadEndMarker(document2, nextDocument, root2, options) {
          if (root2.children[0] === document2 && /---(?:\s|$)/.test(options.originalText.slice(locStart(document2), locStart(document2) + 4)) || document2.head.children.length > 0 || hasEndComments(document2.head) || hasTrailingComment(document2.head)) {
            return "head";
          }
          if (shouldPrintDocumentEndMarker(document2, nextDocument)) {
            return false;
          }
          return nextDocument ? "root" : false;
        }
        function printFlowScalarContent(nodeType, content, options) {
          const lineContents = getFlowScalarLineContents(nodeType, content, options);
          return join(hardline, lineContents.map((lineContentWords) => fill(getDocParts(join(line, lineContentWords)))));
        }
        function clean(node, newNode) {
          if (isNode(newNode)) {
            delete newNode.position;
            switch (newNode.type) {
              case "comment":
                if (isPragma(newNode.value)) {
                  return null;
                }
                break;
              case "quoteDouble":
              case "quoteSingle":
                newNode.type = "quote";
                break;
            }
          }
        }
        module22.exports = {
          preprocess,
          embed,
          print: genericPrint,
          massageAstNode: clean,
          insertPragma
        };
      }
    });
    var require_options7 = __commonJS22({
      "src/language-yaml/options.js"(exports2, module22) {
        "use strict";
        var commonOptions = require_common_options();
        module22.exports = {
          bracketSpacing: commonOptions.bracketSpacing,
          singleQuote: commonOptions.singleQuote,
          proseWrap: commonOptions.proseWrap
        };
      }
    });
    var require_parsers7 = __commonJS22({
      "src/language-yaml/parsers.js"(exports2, module22) {
        "use strict";
        module22.exports = {
          get yaml() {
            return require_parser_yaml().parsers.yaml;
          }
        };
      }
    });
    var require_YAML = __commonJS22({
      "node_modules/linguist-languages/data/YAML.json"(exports2, module22) {
        module22.exports = {
          name: "YAML",
          type: "data",
          color: "#cb171e",
          tmScope: "source.yaml",
          aliases: ["yml"],
          extensions: [".yml", ".mir", ".reek", ".rviz", ".sublime-syntax", ".syntax", ".yaml", ".yaml-tmlanguage", ".yaml.sed", ".yml.mysql"],
          filenames: [".clang-format", ".clang-tidy", ".gemrc", "CITATION.cff", "glide.lock", "yarn.lock"],
          aceMode: "yaml",
          codemirrorMode: "yaml",
          codemirrorMimeType: "text/x-yaml",
          languageId: 407
        };
      }
    });
    var require_language_yaml = __commonJS22({
      "src/language-yaml/index.js"(exports2, module22) {
        "use strict";
        var createLanguage = require_create_language();
        var printer = require_printer_yaml();
        var options = require_options7();
        var parsers = require_parsers7();
        var languages = [createLanguage(require_YAML(), (data) => ({
          since: "1.14.0",
          parsers: ["yaml"],
          vscodeLanguageIds: ["yaml", "ansible", "home-assistant"],
          filenames: [...data.filenames.filter((filename) => filename !== "yarn.lock"), ".prettierrc", ".stylelintrc", ".lintstagedrc"]
        }))];
        module22.exports = {
          languages,
          printers: {
            yaml: printer
          },
          options,
          parsers
        };
      }
    });
    var require_languages = __commonJS22({
      "src/languages.js"(exports2, module22) {
        "use strict";
        module22.exports = [require_language_js(), require_language_css(), require_language_handlebars(), require_language_graphql(), require_language_markdown(), require_language_html(), require_language_yaml()];
      }
    });
    var require_load_plugins = __commonJS22({
      "src/common/load-plugins.js"(exports2, module22) {
        "use strict";
        var fs2 = require("fs");
        var path2 = require("path");
        var fastGlob = require_out42();
        var partition = require_partition3();
        var uniqByKey = require_uniq_by_key();
        var internalPlugins = require_languages();
        var {
          default: mem2,
          memClear: memClear2
        } = (init_dist(), __toCommonJS(dist_exports));
        var thirdParty = require_third_party();
        var resolve = require_resolve22();
        var memoizedLoad = mem2(load, {
          cacheKey: JSON.stringify
        });
        var memoizedSearch = mem2(findPluginsInNodeModules);
        var clearCache = () => {
          memClear2(memoizedLoad);
          memClear2(memoizedSearch);
        };
        function load(plugins2, pluginSearchDirs) {
          if (!plugins2) {
            plugins2 = [];
          }
          if (pluginSearchDirs === false) {
            pluginSearchDirs = [];
          } else {
            pluginSearchDirs = pluginSearchDirs || [];
            if (pluginSearchDirs.length === 0) {
              const autoLoadDir = thirdParty.findParentDir(__dirname, "node_modules");
              if (autoLoadDir) {
                pluginSearchDirs = [autoLoadDir];
              }
            }
          }
          const [externalPluginNames, externalPluginInstances] = partition(plugins2, (plugin) => typeof plugin === "string");
          const externalManualLoadPluginInfos = externalPluginNames.map((pluginName) => {
            let requirePath;
            try {
              requirePath = resolve(path2.resolve(process.cwd(), pluginName));
            } catch {
              requirePath = resolve(pluginName, {
                paths: [process.cwd()]
              });
            }
            return {
              name: pluginName,
              requirePath
            };
          });
          const externalAutoLoadPluginInfos = pluginSearchDirs.flatMap((pluginSearchDir) => {
            const resolvedPluginSearchDir = path2.resolve(process.cwd(), pluginSearchDir);
            const nodeModulesDir = path2.resolve(resolvedPluginSearchDir, "node_modules");
            if (!isDirectory(nodeModulesDir) && !isDirectory(resolvedPluginSearchDir)) {
              throw new Error(`${pluginSearchDir} does not exist or is not a directory`);
            }
            return memoizedSearch(nodeModulesDir).map((pluginName) => ({
              name: pluginName,
              requirePath: resolve(pluginName, {
                paths: [resolvedPluginSearchDir]
              })
            }));
          });
          const externalPlugins = [...uniqByKey([...externalManualLoadPluginInfos, ...externalAutoLoadPluginInfos], "requirePath").map((externalPluginInfo) => Object.assign({
            name: externalPluginInfo.name
          }, require(externalPluginInfo.requirePath))), ...externalPluginInstances];
          return [...internalPlugins, ...externalPlugins];
        }
        function findPluginsInNodeModules(nodeModulesDir) {
          const pluginPackageJsonPaths = fastGlob.sync(["prettier-plugin-*/package.json", "@*/prettier-plugin-*/package.json", "@prettier/plugin-*/package.json"], {
            cwd: nodeModulesDir
          });
          return pluginPackageJsonPaths.map(path2.dirname);
        }
        function isDirectory(dir) {
          try {
            return fs2.statSync(dir).isDirectory();
          } catch {
            return false;
          }
        }
        module22.exports = {
          loadPlugins: memoizedLoad,
          clearCache
        };
      }
    });
    var {
      version: version2
    } = require_package7();
    var core = require_core3();
    var {
      getSupportInfo
    } = require_support();
    var getFileInfo = require_get_file_info();
    var sharedUtil = require_util_shared();
    var plugins = require_load_plugins();
    var config = require_resolve_config();
    var doc = require_doc();
    function _withPlugins(fn, optsArgIdx = 1) {
      return (...args) => {
        const opts = args[optsArgIdx] || {};
        args[optsArgIdx] = Object.assign(Object.assign({}, opts), {}, {
          plugins: plugins.loadPlugins(opts.plugins, opts.pluginSearchDirs)
        });
        return fn(...args);
      };
    }
    function withPlugins(fn, optsArgIdx) {
      const resultingFn = _withPlugins(fn, optsArgIdx);
      if (fn.sync) {
        resultingFn.sync = _withPlugins(fn.sync, optsArgIdx);
      }
      return resultingFn;
    }
    var formatWithCursor = withPlugins(core.formatWithCursor);
    module2.exports = {
      formatWithCursor,
      format(text, opts) {
        return formatWithCursor(text, opts).formatted;
      },
      check(text, opts) {
        const {
          formatted
        } = formatWithCursor(text, opts);
        return formatted === text;
      },
      doc,
      resolveConfig: config.resolveConfig,
      resolveConfigFile: config.resolveConfigFile,
      clearConfigCache() {
        config.clearCache();
        plugins.clearCache();
      },
      getFileInfo: withPlugins(getFileInfo),
      getSupportInfo: withPlugins(getSupportInfo, 0),
      version: version2,
      util: sharedUtil,
      __internal: {
        errors: require_errors2(),
        coreOptions: require_core_options(),
        createIgnorer: require_create_ignorer(),
        optionsModule: require_options4(),
        optionsNormalizer: require_options_normalizer(),
        utils: {
          arrayify: require_arrayify(),
          getLast: require_get_last(),
          partition: require_partition3(),
          isNonEmptyArray: require_util6().isNonEmptyArray
        }
      },
      __debug: {
        parse: withPlugins(core.parse),
        formatAST: withPlugins(core.formatAST),
        formatDoc: withPlugins(core.formatDoc),
        printToDoc: withPlugins(core.printToDoc),
        printDocToString: withPlugins(core.printDocToString)
      }
    };
  }
});

// node_modules/xlsx/dist/cpexcel.js
var require_cpexcel = __commonJS({
  "node_modules/xlsx/dist/cpexcel.js"(exports, module2) {
    var cptable2 = { version: "1.15.0" };
    cptable2[437] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xA2\xA3\xA5\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[620] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\u0105\xE7\xEA\xEB\xE8\xEF\xEE\u0107\xC4\u0104\u0118\u0119\u0142\xF4\xF6\u0106\xFB\xF9\u015A\xD6\xDC\xA2\u0141\xA5\u015B\u0192\u0179\u017B\xF3\xD3\u0144\u0143\u017A\u017C\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[737] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C2\u03C4\u03C5\u03C6\u03C7\u03C8\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03C9\u03AC\u03AD\u03AE\u03CA\u03AF\u03CC\u03CD\u03CB\u03CE\u0386\u0388\u0389\u038A\u038C\u038E\u038F\xB1\u2265\u2264\u03AA\u03AB\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[850] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xF8\xA3\xD8\xD7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\xAE\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\xC0\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\xE3\xC3\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\xF0\xD0\xCA\xCB\xC8\u0131\xCD\xCE\xCF\u2518\u250C\u2588\u2584\xA6\xCC\u2580\xD3\xDF\xD4\xD2\xF5\xD5\xB5\xFE\xDE\xDA\xDB\xD9\xFD\xDD\xAF\xB4\xAD\xB1\u2017\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[852] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\u016F\u0107\xE7\u0142\xEB\u0150\u0151\xEE\u0179\xC4\u0106\xC9\u0139\u013A\xF4\xF6\u013D\u013E\u015A\u015B\xD6\xDC\u0164\u0165\u0141\xD7\u010D\xE1\xED\xF3\xFA\u0104\u0105\u017D\u017E\u0118\u0119\xAC\u017A\u010C\u015F\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\u011A\u015E\u2563\u2551\u2557\u255D\u017B\u017C\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u0102\u0103\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\u0111\u0110\u010E\xCB\u010F\u0147\xCD\xCE\u011B\u2518\u250C\u2588\u2584\u0162\u016E\u2580\xD3\xDF\xD4\u0143\u0144\u0148\u0160\u0161\u0154\xDA\u0155\u0170\xFD\xDD\u0163\xB4\xAD\u02DD\u02DB\u02C7\u02D8\xA7\xF7\xB8\xB0\xA8\u02D9\u0171\u0158\u0159\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[857] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\u0131\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\u0130\xD6\xDC\xF8\xA3\xD8\u015E\u015F\xE1\xED\xF3\xFA\xF1\xD1\u011E\u011F\xBF\xAE\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\xC1\xC2\xC0\xA9\u2563\u2551\u2557\u255D\xA2\xA5\u2510\u2514\u2534\u252C\u251C\u2500\u253C\xE3\xC3\u255A\u2554\u2569\u2566\u2560\u2550\u256C\xA4\xBA\xAA\xCA\xCB\xC8\uFFFD\xCD\xCE\xCF\u2518\u250C\u2588\u2584\xA6\xCC\u2580\xD3\xDF\xD4\xD2\xF5\xD5\xB5\uFFFD\xD7\xDA\xDB\xD9\xEC\xFF\xAF\xB4\xAD\xB1\uFFFD\xBE\xB6\xA7\xF7\xB8\xB0\xA8\xB7\xB9\xB3\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[861] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xD0\xF0\xDE\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xFE\xFB\xDD\xFD\xD6\xDC\xF8\xA3\xD8\u20A7\u0192\xE1\xED\xF3\xFA\xC1\xCD\xD3\xDA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[865] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xF8\xA3\xD8\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xA4\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[866] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\u0401\u0451\u0404\u0454\u0407\u0457\u040E\u045E\xB0\u2219\xB7\u221A\u2116\xA4\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[874] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\uFFFD\uFFFD\uFFFD\u2026\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\xA0\u0E01\u0E02\u0E03\u0E04\u0E05\u0E06\u0E07\u0E08\u0E09\u0E0A\u0E0B\u0E0C\u0E0D\u0E0E\u0E0F\u0E10\u0E11\u0E12\u0E13\u0E14\u0E15\u0E16\u0E17\u0E18\u0E19\u0E1A\u0E1B\u0E1C\u0E1D\u0E1E\u0E1F\u0E20\u0E21\u0E22\u0E23\u0E24\u0E25\u0E26\u0E27\u0E28\u0E29\u0E2A\u0E2B\u0E2C\u0E2D\u0E2E\u0E2F\u0E30\u0E31\u0E32\u0E33\u0E34\u0E35\u0E36\u0E37\u0E38\u0E39\u0E3A\uFFFD\uFFFD\uFFFD\uFFFD\u0E3F\u0E40\u0E41\u0E42\u0E43\u0E44\u0E45\u0E46\u0E47\u0E48\u0E49\u0E4A\u0E4B\u0E4C\u0E4D\u0E4E\u0E4F\u0E50\u0E51\u0E52\u0E53\u0E54\u0E55\u0E56\u0E57\u0E58\u0E59\u0E5A\u0E5B\uFFFD\uFFFD\uFFFD\uFFFD", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[895] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u010C\xFC\xE9\u010F\xE4\u010E\u0164\u010D\u011B\u011A\u0139\xCD\u013E\u01EA\xC4\xC1\xC9\u017E\u017D\xF4\xF6\xD3\u016F\xDA\xFD\xD6\xDC\u0160\u013D\xDD\u0158\u0165\xE1\xED\xF3\xFA\u0148\u0147\u016E\xD4\u0161\u0159\u0155\u0154\xBC\xA7\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[932] = function() {
      var d = [], e = {}, D = [], j;
      D[0] = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF61\uFF62\uFF63\uFF64\uFF65\uFF66\uFF67\uFF68\uFF69\uFF6A\uFF6B\uFF6C\uFF6D\uFF6E\uFF6F\uFF70\uFF71\uFF72\uFF73\uFF74\uFF75\uFF76\uFF77\uFF78\uFF79\uFF7A\uFF7B\uFF7C\uFF7D\uFF7E\uFF7F\uFF80\uFF81\uFF82\uFF83\uFF84\uFF85\uFF86\uFF87\uFF88\uFF89\uFF8A\uFF8B\uFF8C\uFF8D\uFF8E\uFF8F\uFF90\uFF91\uFF92\uFF93\uFF94\uFF95\uFF96\uFF97\uFF98\uFF99\uFF9A\uFF9B\uFF9C\uFF9D\uFF9E\uFF9F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[0].length; ++j)
        if (D[0][j].charCodeAt(0) !== 65533) {
          e[D[0][j]] = 0 + j;
          d[0 + j] = D[0][j];
        }
      D[129] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3000\u3001\u3002\uFF0C\uFF0E\u30FB\uFF1A\uFF1B\uFF1F\uFF01\u309B\u309C\xB4\uFF40\xA8\uFF3E\uFFE3\uFF3F\u30FD\u30FE\u309D\u309E\u3003\u4EDD\u3005\u3006\u3007\u30FC\u2015\u2010\uFF0F\uFF3C\uFF5E\u2225\uFF5C\u2026\u2025\u2018\u2019\u201C\u201D\uFF08\uFF09\u3014\u3015\uFF3B\uFF3D\uFF5B\uFF5D\u3008\u3009\u300A\u300B\u300C\u300D\u300E\u300F\u3010\u3011\uFF0B\uFF0D\xB1\xD7\uFFFD\xF7\uFF1D\u2260\uFF1C\uFF1E\u2266\u2267\u221E\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFFE5\uFF04\uFFE0\uFFE1\uFF05\uFF03\uFF06\uFF0A\uFF20\xA7\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u25BD\u25BC\u203B\u3012\u2192\u2190\u2191\u2193\u3013\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2208\u220B\u2286\u2287\u2282\u2283\u222A\u2229\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2227\u2228\uFFE2\u21D2\u21D4\u2200\u2203\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2220\u22A5\u2312\u2202\u2207\u2261\u2252\u226A\u226B\u221A\u223D\u221D\u2235\u222B\u222C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u212B\u2030\u266F\u266D\u266A\u2020\u2021\xB6\uFFFD\uFFFD\uFFFD\uFFFD\u25EF\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[129].length; ++j)
        if (D[129][j].charCodeAt(0) !== 65533) {
          e[D[129][j]] = 33024 + j;
          d[33024 + j] = D[129][j];
        }
      D[130] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF10\uFF11\uFF12\uFF13\uFF14\uFF15\uFF16\uFF17\uFF18\uFF19\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF21\uFF22\uFF23\uFF24\uFF25\uFF26\uFF27\uFF28\uFF29\uFF2A\uFF2B\uFF2C\uFF2D\uFF2E\uFF2F\uFF30\uFF31\uFF32\uFF33\uFF34\uFF35\uFF36\uFF37\uFF38\uFF39\uFF3A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF41\uFF42\uFF43\uFF44\uFF45\uFF46\uFF47\uFF48\uFF49\uFF4A\uFF4B\uFF4C\uFF4D\uFF4E\uFF4F\uFF50\uFF51\uFF52\uFF53\uFF54\uFF55\uFF56\uFF57\uFF58\uFF59\uFF5A\uFFFD\uFFFD\uFFFD\uFFFD\u3041\u3042\u3043\u3044\u3045\u3046\u3047\u3048\u3049\u304A\u304B\u304C\u304D\u304E\u304F\u3050\u3051\u3052\u3053\u3054\u3055\u3056\u3057\u3058\u3059\u305A\u305B\u305C\u305D\u305E\u305F\u3060\u3061\u3062\u3063\u3064\u3065\u3066\u3067\u3068\u3069\u306A\u306B\u306C\u306D\u306E\u306F\u3070\u3071\u3072\u3073\u3074\u3075\u3076\u3077\u3078\u3079\u307A\u307B\u307C\u307D\u307E\u307F\u3080\u3081\u3082\u3083\u3084\u3085\u3086\u3087\u3088\u3089\u308A\u308B\u308C\u308D\u308E\u308F\u3090\u3091\u3092\u3093\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[130].length; ++j)
        if (D[130][j].charCodeAt(0) !== 65533) {
          e[D[130][j]] = 33280 + j;
          d[33280 + j] = D[130][j];
        }
      D[131] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u30A1\u30A2\u30A3\u30A4\u30A5\u30A6\u30A7\u30A8\u30A9\u30AA\u30AB\u30AC\u30AD\u30AE\u30AF\u30B0\u30B1\u30B2\u30B3\u30B4\u30B5\u30B6\u30B7\u30B8\u30B9\u30BA\u30BB\u30BC\u30BD\u30BE\u30BF\u30C0\u30C1\u30C2\u30C3\u30C4\u30C5\u30C6\u30C7\u30C8\u30C9\u30CA\u30CB\u30CC\u30CD\u30CE\u30CF\u30D0\u30D1\u30D2\u30D3\u30D4\u30D5\u30D6\u30D7\u30D8\u30D9\u30DA\u30DB\u30DC\u30DD\u30DE\u30DF\uFFFD\u30E0\u30E1\u30E2\u30E3\u30E4\u30E5\u30E6\u30E7\u30E8\u30E9\u30EA\u30EB\u30EC\u30ED\u30EE\u30EF\u30F0\u30F1\u30F2\u30F3\u30F4\u30F5\u30F6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[131].length; ++j)
        if (D[131][j].charCodeAt(0) !== 65533) {
          e[D[131][j]] = 33536 + j;
          d[33536 + j] = D[131][j];
        }
      D[132] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0410\u0411\u0412\u0413\u0414\u0415\u0401\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0430\u0431\u0432\u0433\u0434\u0435\u0451\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\uFFFD\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2500\u2502\u250C\u2510\u2518\u2514\u251C\u252C\u2524\u2534\u253C\u2501\u2503\u250F\u2513\u251B\u2517\u2523\u2533\u252B\u253B\u254B\u2520\u252F\u2528\u2537\u253F\u251D\u2530\u2525\u2538\u2542\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[132].length; ++j)
        if (D[132][j].charCodeAt(0) !== 65533) {
          e[D[132][j]] = 33792 + j;
          d[33792 + j] = D[132][j];
        }
      D[135] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2460\u2461\u2462\u2463\u2464\u2465\u2466\u2467\u2468\u2469\u246A\u246B\u246C\u246D\u246E\u246F\u2470\u2471\u2472\u2473\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\uFFFD\u3349\u3314\u3322\u334D\u3318\u3327\u3303\u3336\u3351\u3357\u330D\u3326\u3323\u332B\u334A\u333B\u339C\u339D\u339E\u338E\u338F\u33C4\u33A1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u337B\uFFFD\u301D\u301F\u2116\u33CD\u2121\u32A4\u32A5\u32A6\u32A7\u32A8\u3231\u3232\u3239\u337E\u337D\u337C\u2252\u2261\u222B\u222E\u2211\u221A\u22A5\u2220\u221F\u22BF\u2235\u2229\u222A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[135].length; ++j)
        if (D[135][j].charCodeAt(0) !== 65533) {
          e[D[135][j]] = 34560 + j;
          d[34560 + j] = D[135][j];
        }
      D[136] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E9C\u5516\u5A03\u963F\u54C0\u611B\u6328\u59F6\u9022\u8475\u831C\u7A50\u60AA\u63E1\u6E25\u65ED\u8466\u82A6\u9BF5\u6893\u5727\u65A1\u6271\u5B9B\u59D0\u867B\u98F4\u7D62\u7DBE\u9B8E\u6216\u7C9F\u88B7\u5B89\u5EB5\u6309\u6697\u6848\u95C7\u978D\u674F\u4EE5\u4F0A\u4F4D\u4F9D\u5049\u56F2\u5937\u59D4\u5A01\u5C09\u60DF\u610F\u6170\u6613\u6905\u70BA\u754F\u7570\u79FB\u7DAD\u7DEF\u80C3\u840E\u8863\u8B02\u9055\u907A\u533B\u4E95\u4EA5\u57DF\u80B2\u90C1\u78EF\u4E00\u58F1\u6EA2\u9038\u7A32\u8328\u828B\u9C2F\u5141\u5370\u54BD\u54E1\u56E0\u59FB\u5F15\u98F2\u6DEB\u80E4\u852D\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[136].length; ++j)
        if (D[136][j].charCodeAt(0) !== 65533) {
          e[D[136][j]] = 34816 + j;
          d[34816 + j] = D[136][j];
        }
      D[137] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9662\u9670\u96A0\u97FB\u540B\u53F3\u5B87\u70CF\u7FBD\u8FC2\u96E8\u536F\u9D5C\u7ABA\u4E11\u7893\u81FC\u6E26\u5618\u5504\u6B1D\u851A\u9C3B\u59E5\u53A9\u6D66\u74DC\u958F\u5642\u4E91\u904B\u96F2\u834F\u990C\u53E1\u55B6\u5B30\u5F71\u6620\u66F3\u6804\u6C38\u6CF3\u6D29\u745B\u76C8\u7A4E\u9834\u82F1\u885B\u8A60\u92ED\u6DB2\u75AB\u76CA\u99C5\u60A6\u8B01\u8D8A\u95B2\u698E\u53AD\u5186\uFFFD\u5712\u5830\u5944\u5BB4\u5EF6\u6028\u63A9\u63F4\u6CBF\u6F14\u708E\u7114\u7159\u71D5\u733F\u7E01\u8276\u82D1\u8597\u9060\u925B\u9D1B\u5869\u65BC\u6C5A\u7525\u51F9\u592E\u5965\u5F80\u5FDC\u62BC\u65FA\u6A2A\u6B27\u6BB4\u738B\u7FC1\u8956\u9D2C\u9D0E\u9EC4\u5CA1\u6C96\u837B\u5104\u5C4B\u61B6\u81C6\u6876\u7261\u4E59\u4FFA\u5378\u6069\u6E29\u7A4F\u97F3\u4E0B\u5316\u4EEE\u4F55\u4F3D\u4FA1\u4F73\u52A0\u53EF\u5609\u590F\u5AC1\u5BB6\u5BE1\u79D1\u6687\u679C\u67B6\u6B4C\u6CB3\u706B\u73C2\u798D\u79BE\u7A3C\u7B87\u82B1\u82DB\u8304\u8377\u83EF\u83D3\u8766\u8AB2\u5629\u8CA8\u8FE6\u904E\u971E\u868A\u4FC4\u5CE8\u6211\u7259\u753B\u81E5\u82BD\u86FE\u8CC0\u96C5\u9913\u99D5\u4ECB\u4F1A\u89E3\u56DE\u584A\u58CA\u5EFB\u5FEB\u602A\u6094\u6062\u61D0\u6212\u62D0\u6539\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[137].length; ++j)
        if (D[137][j].charCodeAt(0) !== 65533) {
          e[D[137][j]] = 35072 + j;
          d[35072 + j] = D[137][j];
        }
      D[138] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9B41\u6666\u68B0\u6D77\u7070\u754C\u7686\u7D75\u82A5\u87F9\u958B\u968E\u8C9D\u51F1\u52BE\u5916\u54B3\u5BB3\u5D16\u6168\u6982\u6DAF\u788D\u84CB\u8857\u8A72\u93A7\u9AB8\u6D6C\u99A8\u86D9\u57A3\u67FF\u86CE\u920E\u5283\u5687\u5404\u5ED3\u62E1\u64B9\u683C\u6838\u6BBB\u7372\u78BA\u7A6B\u899A\u89D2\u8D6B\u8F03\u90ED\u95A3\u9694\u9769\u5B66\u5CB3\u697D\u984D\u984E\u639B\u7B20\u6A2B\uFFFD\u6A7F\u68B6\u9C0D\u6F5F\u5272\u559D\u6070\u62EC\u6D3B\u6E07\u6ED1\u845B\u8910\u8F44\u4E14\u9C39\u53F6\u691B\u6A3A\u9784\u682A\u515C\u7AC3\u84B2\u91DC\u938C\u565B\u9D28\u6822\u8305\u8431\u7CA5\u5208\u82C5\u74E6\u4E7E\u4F83\u51A0\u5BD2\u520A\u52D8\u52E7\u5DFB\u559A\u582A\u59E6\u5B8C\u5B98\u5BDB\u5E72\u5E79\u60A3\u611F\u6163\u61BE\u63DB\u6562\u67D1\u6853\u68FA\u6B3E\u6B53\u6C57\u6F22\u6F97\u6F45\u74B0\u7518\u76E3\u770B\u7AFF\u7BA1\u7C21\u7DE9\u7F36\u7FF0\u809D\u8266\u839E\u89B3\u8ACC\u8CAB\u9084\u9451\u9593\u9591\u95A2\u9665\u97D3\u9928\u8218\u4E38\u542B\u5CB8\u5DCC\u73A9\u764C\u773C\u5CA9\u7FEB\u8D0B\u96C1\u9811\u9854\u9858\u4F01\u4F0E\u5371\u559C\u5668\u57FA\u5947\u5B09\u5BC4\u5C90\u5E0C\u5E7E\u5FCC\u63EE\u673A\u65D7\u65E2\u671F\u68CB\u68C4\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[138].length; ++j)
        if (D[138][j].charCodeAt(0) !== 65533) {
          e[D[138][j]] = 35328 + j;
          d[35328 + j] = D[138][j];
        }
      D[139] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6A5F\u5E30\u6BC5\u6C17\u6C7D\u757F\u7948\u5B63\u7A00\u7D00\u5FBD\u898F\u8A18\u8CB4\u8D77\u8ECC\u8F1D\u98E2\u9A0E\u9B3C\u4E80\u507D\u5100\u5993\u5B9C\u622F\u6280\u64EC\u6B3A\u72A0\u7591\u7947\u7FA9\u87FB\u8ABC\u8B70\u63AC\u83CA\u97A0\u5409\u5403\u55AB\u6854\u6A58\u8A70\u7827\u6775\u9ECD\u5374\u5BA2\u811A\u8650\u9006\u4E18\u4E45\u4EC7\u4F11\u53CA\u5438\u5BAE\u5F13\u6025\u6551\uFFFD\u673D\u6C42\u6C72\u6CE3\u7078\u7403\u7A76\u7AAE\u7B08\u7D1A\u7CFE\u7D66\u65E7\u725B\u53BB\u5C45\u5DE8\u62D2\u62E0\u6319\u6E20\u865A\u8A31\u8DDD\u92F8\u6F01\u79A6\u9B5A\u4EA8\u4EAB\u4EAC\u4F9B\u4FA0\u50D1\u5147\u7AF6\u5171\u51F6\u5354\u5321\u537F\u53EB\u55AC\u5883\u5CE1\u5F37\u5F4A\u602F\u6050\u606D\u631F\u6559\u6A4B\u6CC1\u72C2\u72ED\u77EF\u80F8\u8105\u8208\u854E\u90F7\u93E1\u97FF\u9957\u9A5A\u4EF0\u51DD\u5C2D\u6681\u696D\u5C40\u66F2\u6975\u7389\u6850\u7C81\u50C5\u52E4\u5747\u5DFE\u9326\u65A4\u6B23\u6B3D\u7434\u7981\u79BD\u7B4B\u7DCA\u82B9\u83CC\u887F\u895F\u8B39\u8FD1\u91D1\u541F\u9280\u4E5D\u5036\u53E5\u533A\u72D7\u7396\u77E9\u82E6\u8EAF\u99C6\u99C8\u99D2\u5177\u611A\u865E\u55B0\u7A7A\u5076\u5BD3\u9047\u9685\u4E32\u6ADB\u91E7\u5C51\u5C48\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[139].length; ++j)
        if (D[139][j].charCodeAt(0) !== 65533) {
          e[D[139][j]] = 35584 + j;
          d[35584 + j] = D[139][j];
        }
      D[140] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6398\u7A9F\u6C93\u9774\u8F61\u7AAA\u718A\u9688\u7C82\u6817\u7E70\u6851\u936C\u52F2\u541B\u85AB\u8A13\u7FA4\u8ECD\u90E1\u5366\u8888\u7941\u4FC2\u50BE\u5211\u5144\u5553\u572D\u73EA\u578B\u5951\u5F62\u5F84\u6075\u6176\u6167\u61A9\u63B2\u643A\u656C\u666F\u6842\u6E13\u7566\u7A3D\u7CFB\u7D4C\u7D99\u7E4B\u7F6B\u830E\u834A\u86CD\u8A08\u8A63\u8B66\u8EFD\u981A\u9D8F\u82B8\u8FCE\u9BE8\uFFFD\u5287\u621F\u6483\u6FC0\u9699\u6841\u5091\u6B20\u6C7A\u6F54\u7A74\u7D50\u8840\u8A23\u6708\u4EF6\u5039\u5026\u5065\u517C\u5238\u5263\u55A7\u570F\u5805\u5ACC\u5EFA\u61B2\u61F8\u62F3\u6372\u691C\u6A29\u727D\u72AC\u732E\u7814\u786F\u7D79\u770C\u80A9\u898B\u8B19\u8CE2\u8ED2\u9063\u9375\u967A\u9855\u9A13\u9E78\u5143\u539F\u53B3\u5E7B\u5F26\u6E1B\u6E90\u7384\u73FE\u7D43\u8237\u8A00\u8AFA\u9650\u4E4E\u500B\u53E4\u547C\u56FA\u59D1\u5B64\u5DF1\u5EAB\u5F27\u6238\u6545\u67AF\u6E56\u72D0\u7CCA\u88B4\u80A1\u80E1\u83F0\u864E\u8A87\u8DE8\u9237\u96C7\u9867\u9F13\u4E94\u4E92\u4F0D\u5348\u5449\u543E\u5A2F\u5F8C\u5FA1\u609F\u68A7\u6A8E\u745A\u7881\u8A9E\u8AA4\u8B77\u9190\u4E5E\u9BC9\u4EA4\u4F7C\u4FAF\u5019\u5016\u5149\u516C\u529F\u52B9\u52FE\u539A\u53E3\u5411\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[140].length; ++j)
        if (D[140][j].charCodeAt(0) !== 65533) {
          e[D[140][j]] = 35840 + j;
          d[35840 + j] = D[140][j];
        }
      D[141] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u540E\u5589\u5751\u57A2\u597D\u5B54\u5B5D\u5B8F\u5DE5\u5DE7\u5DF7\u5E78\u5E83\u5E9A\u5EB7\u5F18\u6052\u614C\u6297\u62D8\u63A7\u653B\u6602\u6643\u66F4\u676D\u6821\u6897\u69CB\u6C5F\u6D2A\u6D69\u6E2F\u6E9D\u7532\u7687\u786C\u7A3F\u7CE0\u7D05\u7D18\u7D5E\u7DB1\u8015\u8003\u80AF\u80B1\u8154\u818F\u822A\u8352\u884C\u8861\u8B1B\u8CA2\u8CFC\u90CA\u9175\u9271\u783F\u92FC\u95A4\u964D\uFFFD\u9805\u9999\u9AD8\u9D3B\u525B\u52AB\u53F7\u5408\u58D5\u62F7\u6FE0\u8C6A\u8F5F\u9EB9\u514B\u523B\u544A\u56FD\u7A40\u9177\u9D60\u9ED2\u7344\u6F09\u8170\u7511\u5FFD\u60DA\u9AA8\u72DB\u8FBC\u6B64\u9803\u4ECA\u56F0\u5764\u58BE\u5A5A\u6068\u61C7\u660F\u6606\u6839\u68B1\u6DF7\u75D5\u7D3A\u826E\u9B42\u4E9B\u4F50\u53C9\u5506\u5D6F\u5DE6\u5DEE\u67FB\u6C99\u7473\u7802\u8A50\u9396\u88DF\u5750\u5EA7\u632B\u50B5\u50AC\u518D\u6700\u54C9\u585E\u59BB\u5BB0\u5F69\u624D\u63A1\u683D\u6B73\u6E08\u707D\u91C7\u7280\u7815\u7826\u796D\u658E\u7D30\u83DC\u88C1\u8F09\u969B\u5264\u5728\u6750\u7F6A\u8CA1\u51B4\u5742\u962A\u583A\u698A\u80B4\u54B2\u5D0E\u57FC\u7895\u9DFA\u4F5C\u524A\u548B\u643E\u6628\u6714\u67F5\u7A84\u7B56\u7D22\u932F\u685C\u9BAD\u7B39\u5319\u518A\u5237\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[141].length; ++j)
        if (D[141][j].charCodeAt(0) !== 65533) {
          e[D[141][j]] = 36096 + j;
          d[36096 + j] = D[141][j];
        }
      D[142] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5BDF\u62F6\u64AE\u64E6\u672D\u6BBA\u85A9\u96D1\u7690\u9BD6\u634C\u9306\u9BAB\u76BF\u6652\u4E09\u5098\u53C2\u5C71\u60E8\u6492\u6563\u685F\u71E6\u73CA\u7523\u7B97\u7E82\u8695\u8B83\u8CDB\u9178\u9910\u65AC\u66AB\u6B8B\u4ED5\u4ED4\u4F3A\u4F7F\u523A\u53F8\u53F2\u55E3\u56DB\u58EB\u59CB\u59C9\u59FF\u5B50\u5C4D\u5E02\u5E2B\u5FD7\u601D\u6307\u652F\u5B5C\u65AF\u65BD\u65E8\u679D\u6B62\uFFFD\u6B7B\u6C0F\u7345\u7949\u79C1\u7CF8\u7D19\u7D2B\u80A2\u8102\u81F3\u8996\u8A5E\u8A69\u8A66\u8A8C\u8AEE\u8CC7\u8CDC\u96CC\u98FC\u6B6F\u4E8B\u4F3C\u4F8D\u5150\u5B57\u5BFA\u6148\u6301\u6642\u6B21\u6ECB\u6CBB\u723E\u74BD\u75D4\u78C1\u793A\u800C\u8033\u81EA\u8494\u8F9E\u6C50\u9E7F\u5F0F\u8B58\u9D2B\u7AFA\u8EF8\u5B8D\u96EB\u4E03\u53F1\u57F7\u5931\u5AC9\u5BA4\u6089\u6E7F\u6F06\u75BE\u8CEA\u5B9F\u8500\u7BE0\u5072\u67F4\u829D\u5C61\u854A\u7E1E\u820E\u5199\u5C04\u6368\u8D66\u659C\u716E\u793E\u7D17\u8005\u8B1D\u8ECA\u906E\u86C7\u90AA\u501F\u52FA\u5C3A\u6753\u707C\u7235\u914C\u91C8\u932B\u82E5\u5BC2\u5F31\u60F9\u4E3B\u53D6\u5B88\u624B\u6731\u6B8A\u72E9\u73E0\u7A2E\u816B\u8DA3\u9152\u9996\u5112\u53D7\u546A\u5BFF\u6388\u6A39\u7DAC\u9700\u56DA\u53CE\u5468\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[142].length; ++j)
        if (D[142][j].charCodeAt(0) !== 65533) {
          e[D[142][j]] = 36352 + j;
          d[36352 + j] = D[142][j];
        }
      D[143] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5B97\u5C31\u5DDE\u4FEE\u6101\u62FE\u6D32\u79C0\u79CB\u7D42\u7E4D\u7FD2\u81ED\u821F\u8490\u8846\u8972\u8B90\u8E74\u8F2F\u9031\u914B\u916C\u96C6\u919C\u4EC0\u4F4F\u5145\u5341\u5F93\u620E\u67D4\u6C41\u6E0B\u7363\u7E26\u91CD\u9283\u53D4\u5919\u5BBF\u6DD1\u795D\u7E2E\u7C9B\u587E\u719F\u51FA\u8853\u8FF0\u4FCA\u5CFB\u6625\u77AC\u7AE3\u821C\u99FF\u51C6\u5FAA\u65EC\u696F\u6B89\u6DF3\uFFFD\u6E96\u6F64\u76FE\u7D14\u5DE1\u9075\u9187\u9806\u51E6\u521D\u6240\u6691\u66D9\u6E1A\u5EB6\u7DD2\u7F72\u66F8\u85AF\u85F7\u8AF8\u52A9\u53D9\u5973\u5E8F\u5F90\u6055\u92E4\u9664\u50B7\u511F\u52DD\u5320\u5347\u53EC\u54E8\u5546\u5531\u5617\u5968\u59BE\u5A3C\u5BB5\u5C06\u5C0F\u5C11\u5C1A\u5E84\u5E8A\u5EE0\u5F70\u627F\u6284\u62DB\u638C\u6377\u6607\u660C\u662D\u6676\u677E\u68A2\u6A1F\u6A35\u6CBC\u6D88\u6E09\u6E58\u713C\u7126\u7167\u75C7\u7701\u785D\u7901\u7965\u79F0\u7AE0\u7B11\u7CA7\u7D39\u8096\u83D6\u848B\u8549\u885D\u88F3\u8A1F\u8A3C\u8A54\u8A73\u8C61\u8CDE\u91A4\u9266\u937E\u9418\u969C\u9798\u4E0A\u4E08\u4E1E\u4E57\u5197\u5270\u57CE\u5834\u58CC\u5B22\u5E38\u60C5\u64FE\u6761\u6756\u6D44\u72B6\u7573\u7A63\u84B8\u8B72\u91B8\u9320\u5631\u57F4\u98FE\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[143].length; ++j)
        if (D[143][j].charCodeAt(0) !== 65533) {
          e[D[143][j]] = 36608 + j;
          d[36608 + j] = D[143][j];
        }
      D[144] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u62ED\u690D\u6B96\u71ED\u7E54\u8077\u8272\u89E6\u98DF\u8755\u8FB1\u5C3B\u4F38\u4FE1\u4FB5\u5507\u5A20\u5BDD\u5BE9\u5FC3\u614E\u632F\u65B0\u664B\u68EE\u699B\u6D78\u6DF1\u7533\u75B9\u771F\u795E\u79E6\u7D33\u81E3\u82AF\u85AA\u89AA\u8A3A\u8EAB\u8F9B\u9032\u91DD\u9707\u4EBA\u4EC1\u5203\u5875\u58EC\u5C0B\u751A\u5C3D\u814E\u8A0A\u8FC5\u9663\u976D\u7B25\u8ACF\u9808\u9162\u56F3\u53A8\uFFFD\u9017\u5439\u5782\u5E25\u63A8\u6C34\u708A\u7761\u7C8B\u7FE0\u8870\u9042\u9154\u9310\u9318\u968F\u745E\u9AC4\u5D07\u5D69\u6570\u67A2\u8DA8\u96DB\u636E\u6749\u6919\u83C5\u9817\u96C0\u88FE\u6F84\u647A\u5BF8\u4E16\u702C\u755D\u662F\u51C4\u5236\u52E2\u59D3\u5F81\u6027\u6210\u653F\u6574\u661F\u6674\u68F2\u6816\u6B63\u6E05\u7272\u751F\u76DB\u7CBE\u8056\u58F0\u88FD\u897F\u8AA0\u8A93\u8ACB\u901D\u9192\u9752\u9759\u6589\u7A0E\u8106\u96BB\u5E2D\u60DC\u621A\u65A5\u6614\u6790\u77F3\u7A4D\u7C4D\u7E3E\u810A\u8CAC\u8D64\u8DE1\u8E5F\u78A9\u5207\u62D9\u63A5\u6442\u6298\u8A2D\u7A83\u7BC0\u8AAC\u96EA\u7D76\u820C\u8749\u4ED9\u5148\u5343\u5360\u5BA3\u5C02\u5C16\u5DDD\u6226\u6247\u64B0\u6813\u6834\u6CC9\u6D45\u6D17\u67D3\u6F5C\u714E\u717D\u65CB\u7A7F\u7BAD\u7DDA\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[144].length; ++j)
        if (D[144][j].charCodeAt(0) !== 65533) {
          e[D[144][j]] = 36864 + j;
          d[36864 + j] = D[144][j];
        }
      D[145] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E4A\u7FA8\u817A\u821B\u8239\u85A6\u8A6E\u8CCE\u8DF5\u9078\u9077\u92AD\u9291\u9583\u9BAE\u524D\u5584\u6F38\u7136\u5168\u7985\u7E55\u81B3\u7CCE\u564C\u5851\u5CA8\u63AA\u66FE\u66FD\u695A\u72D9\u758F\u758E\u790E\u7956\u79DF\u7C97\u7D20\u7D44\u8607\u8A34\u963B\u9061\u9F20\u50E7\u5275\u53CC\u53E2\u5009\u55AA\u58EE\u594F\u723D\u5B8B\u5C64\u531D\u60E3\u60F3\u635C\u6383\u633F\u63BB\uFFFD\u64CD\u65E9\u66F9\u5DE3\u69CD\u69FD\u6F15\u71E5\u4E89\u75E9\u76F8\u7A93\u7CDF\u7DCF\u7D9C\u8061\u8349\u8358\u846C\u84BC\u85FB\u88C5\u8D70\u9001\u906D\u9397\u971C\u9A12\u50CF\u5897\u618E\u81D3\u8535\u8D08\u9020\u4FC3\u5074\u5247\u5373\u606F\u6349\u675F\u6E2C\u8DB3\u901F\u4FD7\u5C5E\u8CCA\u65CF\u7D9A\u5352\u8896\u5176\u63C3\u5B58\u5B6B\u5C0A\u640D\u6751\u905C\u4ED6\u591A\u592A\u6C70\u8A51\u553E\u5815\u59A5\u60F0\u6253\u67C1\u8235\u6955\u9640\u99C4\u9A28\u4F53\u5806\u5BFE\u8010\u5CB1\u5E2F\u5F85\u6020\u614B\u6234\u66FF\u6CF0\u6EDE\u80CE\u817F\u82D4\u888B\u8CB8\u9000\u902E\u968A\u9EDB\u9BDB\u4EE3\u53F0\u5927\u7B2C\u918D\u984C\u9DF9\u6EDD\u7027\u5353\u5544\u5B85\u6258\u629E\u62D3\u6CA2\u6FEF\u7422\u8A17\u9438\u6FC1\u8AFE\u8338\u51E7\u86F8\u53EA\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[145].length; ++j)
        if (D[145][j].charCodeAt(0) !== 65533) {
          e[D[145][j]] = 37120 + j;
          d[37120 + j] = D[145][j];
        }
      D[146] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u53E9\u4F46\u9054\u8FB0\u596A\u8131\u5DFD\u7AEA\u8FBF\u68DA\u8C37\u72F8\u9C48\u6A3D\u8AB0\u4E39\u5358\u5606\u5766\u62C5\u63A2\u65E6\u6B4E\u6DE1\u6E5B\u70AD\u77ED\u7AEF\u7BAA\u7DBB\u803D\u80C6\u86CB\u8A95\u935B\u56E3\u58C7\u5F3E\u65AD\u6696\u6A80\u6BB5\u7537\u8AC7\u5024\u77E5\u5730\u5F1B\u6065\u667A\u6C60\u75F4\u7A1A\u7F6E\u81F4\u8718\u9045\u99B3\u7BC9\u755C\u7AF9\u7B51\u84C4\uFFFD\u9010\u79E9\u7A92\u8336\u5AE1\u7740\u4E2D\u4EF2\u5B99\u5FE0\u62BD\u663C\u67F1\u6CE8\u866B\u8877\u8A3B\u914E\u92F3\u99D0\u6A17\u7026\u732A\u82E7\u8457\u8CAF\u4E01\u5146\u51CB\u558B\u5BF5\u5E16\u5E33\u5E81\u5F14\u5F35\u5F6B\u5FB4\u61F2\u6311\u66A2\u671D\u6F6E\u7252\u753A\u773A\u8074\u8139\u8178\u8776\u8ABF\u8ADC\u8D85\u8DF3\u929A\u9577\u9802\u9CE5\u52C5\u6357\u76F4\u6715\u6C88\u73CD\u8CC3\u93AE\u9673\u6D25\u589C\u690E\u69CC\u8FFD\u939A\u75DB\u901A\u585A\u6802\u63B4\u69FB\u4F43\u6F2C\u67D8\u8FBB\u8526\u7DB4\u9354\u693F\u6F70\u576A\u58F7\u5B2C\u7D2C\u722A\u540A\u91E3\u9DB4\u4EAD\u4F4E\u505C\u5075\u5243\u8C9E\u5448\u5824\u5B9A\u5E1D\u5E95\u5EAD\u5EF7\u5F1F\u608C\u62B5\u633A\u63D0\u68AF\u6C40\u7887\u798E\u7A0B\u7DE0\u8247\u8A02\u8AE6\u8E44\u9013\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[146].length; ++j)
        if (D[146][j].charCodeAt(0) !== 65533) {
          e[D[146][j]] = 37376 + j;
          d[37376 + j] = D[146][j];
        }
      D[147] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u90B8\u912D\u91D8\u9F0E\u6CE5\u6458\u64E2\u6575\u6EF4\u7684\u7B1B\u9069\u93D1\u6EBA\u54F2\u5FB9\u64A4\u8F4D\u8FED\u9244\u5178\u586B\u5929\u5C55\u5E97\u6DFB\u7E8F\u751C\u8CBC\u8EE2\u985B\u70B9\u4F1D\u6BBF\u6FB1\u7530\u96FB\u514E\u5410\u5835\u5857\u59AC\u5C60\u5F92\u6597\u675C\u6E21\u767B\u83DF\u8CED\u9014\u90FD\u934D\u7825\u783A\u52AA\u5EA6\u571F\u5974\u6012\u5012\u515A\u51AC\uFFFD\u51CD\u5200\u5510\u5854\u5858\u5957\u5B95\u5CF6\u5D8B\u60BC\u6295\u642D\u6771\u6843\u68BC\u68DF\u76D7\u6DD8\u6E6F\u6D9B\u706F\u71C8\u5F53\u75D8\u7977\u7B49\u7B54\u7B52\u7CD6\u7D71\u5230\u8463\u8569\u85E4\u8A0E\u8B04\u8C46\u8E0F\u9003\u900F\u9419\u9676\u982D\u9A30\u95D8\u50CD\u52D5\u540C\u5802\u5C0E\u61A7\u649E\u6D1E\u77B3\u7AE5\u80F4\u8404\u9053\u9285\u5CE0\u9D07\u533F\u5F97\u5FB3\u6D9C\u7279\u7763\u79BF\u7BE4\u6BD2\u72EC\u8AAD\u6803\u6A61\u51F8\u7A81\u6934\u5C4A\u9CF6\u82EB\u5BC5\u9149\u701E\u5678\u5C6F\u60C7\u6566\u6C8C\u8C5A\u9041\u9813\u5451\u66C7\u920D\u5948\u90A3\u5185\u4E4D\u51EA\u8599\u8B0E\u7058\u637A\u934B\u6962\u99B4\u7E04\u7577\u5357\u6960\u8EDF\u96E3\u6C5D\u4E8C\u5C3C\u5F10\u8FE9\u5302\u8CD1\u8089\u8679\u5EFF\u65E5\u4E73\u5165\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[147].length; ++j)
        if (D[147][j].charCodeAt(0) !== 65533) {
          e[D[147][j]] = 37632 + j;
          d[37632 + j] = D[147][j];
        }
      D[148] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5982\u5C3F\u97EE\u4EFB\u598A\u5FCD\u8A8D\u6FE1\u79B0\u7962\u5BE7\u8471\u732B\u71B1\u5E74\u5FF5\u637B\u649A\u71C3\u7C98\u4E43\u5EFC\u4E4B\u57DC\u56A2\u60A9\u6FC3\u7D0D\u80FD\u8133\u81BF\u8FB2\u8997\u86A4\u5DF4\u628A\u64AD\u8987\u6777\u6CE2\u6D3E\u7436\u7834\u5A46\u7F75\u82AD\u99AC\u4FF3\u5EC3\u62DD\u6392\u6557\u676F\u76C3\u724C\u80CC\u80BA\u8F29\u914D\u500D\u57F9\u5A92\u6885\uFFFD\u6973\u7164\u72FD\u8CB7\u58F2\u8CE0\u966A\u9019\u877F\u79E4\u77E7\u8429\u4F2F\u5265\u535A\u62CD\u67CF\u6CCA\u767D\u7B94\u7C95\u8236\u8584\u8FEB\u66DD\u6F20\u7206\u7E1B\u83AB\u99C1\u9EA6\u51FD\u7BB1\u7872\u7BB8\u8087\u7B48\u6AE8\u5E61\u808C\u7551\u7560\u516B\u9262\u6E8C\u767A\u9197\u9AEA\u4F10\u7F70\u629C\u7B4F\u95A5\u9CE9\u567A\u5859\u86E4\u96BC\u4F34\u5224\u534A\u53CD\u53DB\u5E06\u642C\u6591\u677F\u6C3E\u6C4E\u7248\u72AF\u73ED\u7554\u7E41\u822C\u85E9\u8CA9\u7BC4\u91C6\u7169\u9812\u98EF\u633D\u6669\u756A\u76E4\u78D0\u8543\u86EE\u532A\u5351\u5426\u5983\u5E87\u5F7C\u60B2\u6249\u6279\u62AB\u6590\u6BD4\u6CCC\u75B2\u76AE\u7891\u79D8\u7DCB\u7F77\u80A5\u88AB\u8AB9\u8CBB\u907F\u975E\u98DB\u6A0B\u7C38\u5099\u5C3E\u5FAE\u6787\u6BD8\u7435\u7709\u7F8E\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[148].length; ++j)
        if (D[148][j].charCodeAt(0) !== 65533) {
          e[D[148][j]] = 37888 + j;
          d[37888 + j] = D[148][j];
        }
      D[149] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9F3B\u67CA\u7A17\u5339\u758B\u9AED\u5F66\u819D\u83F1\u8098\u5F3C\u5FC5\u7562\u7B46\u903C\u6867\u59EB\u5A9B\u7D10\u767E\u8B2C\u4FF5\u5F6A\u6A19\u6C37\u6F02\u74E2\u7968\u8868\u8A55\u8C79\u5EDF\u63CF\u75C5\u79D2\u82D7\u9328\u92F2\u849C\u86ED\u9C2D\u54C1\u5F6C\u658C\u6D5C\u7015\u8CA7\u8CD3\u983B\u654F\u74F6\u4E0D\u4ED8\u57E0\u592B\u5A66\u5BCC\u51A8\u5E03\u5E9C\u6016\u6276\u6577\uFFFD\u65A7\u666E\u6D6E\u7236\u7B26\u8150\u819A\u8299\u8B5C\u8CA0\u8CE6\u8D74\u961C\u9644\u4FAE\u64AB\u6B66\u821E\u8461\u856A\u90E8\u5C01\u6953\u98A8\u847A\u8557\u4F0F\u526F\u5FA9\u5E45\u670D\u798F\u8179\u8907\u8986\u6DF5\u5F17\u6255\u6CB8\u4ECF\u7269\u9B92\u5206\u543B\u5674\u58B3\u61A4\u626E\u711A\u596E\u7C89\u7CDE\u7D1B\u96F0\u6587\u805E\u4E19\u4F75\u5175\u5840\u5E63\u5E73\u5F0A\u67C4\u4E26\u853D\u9589\u965B\u7C73\u9801\u50FB\u58C1\u7656\u78A7\u5225\u77A5\u8511\u7B86\u504F\u5909\u7247\u7BC7\u7DE8\u8FBA\u8FD4\u904D\u4FBF\u52C9\u5A29\u5F01\u97AD\u4FDD\u8217\u92EA\u5703\u6355\u6B69\u752B\u88DC\u8F14\u7A42\u52DF\u5893\u6155\u620A\u66AE\u6BCD\u7C3F\u83E9\u5023\u4FF8\u5305\u5446\u5831\u5949\u5B9D\u5CF0\u5CEF\u5D29\u5E96\u62B1\u6367\u653E\u65B9\u670B\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[149].length; ++j)
        if (D[149][j].charCodeAt(0) !== 65533) {
          e[D[149][j]] = 38144 + j;
          d[38144 + j] = D[149][j];
        }
      D[150] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6CD5\u6CE1\u70F9\u7832\u7E2B\u80DE\u82B3\u840C\u84EC\u8702\u8912\u8A2A\u8C4A\u90A6\u92D2\u98FD\u9CF3\u9D6C\u4E4F\u4EA1\u508D\u5256\u574A\u59A8\u5E3D\u5FD8\u5FD9\u623F\u66B4\u671B\u67D0\u68D2\u5192\u7D21\u80AA\u81A8\u8B00\u8C8C\u8CBF\u927E\u9632\u5420\u982C\u5317\u50D5\u535C\u58A8\u64B2\u6734\u7267\u7766\u7A46\u91E6\u52C3\u6CA1\u6B86\u5800\u5E4C\u5954\u672C\u7FFB\u51E1\u76C6\uFFFD\u6469\u78E8\u9B54\u9EBB\u57CB\u59B9\u6627\u679A\u6BCE\u54E9\u69D9\u5E55\u819C\u6795\u9BAA\u67FE\u9C52\u685D\u4EA6\u4FE3\u53C8\u62B9\u672B\u6CAB\u8FC4\u4FAD\u7E6D\u9EBF\u4E07\u6162\u6E80\u6F2B\u8513\u5473\u672A\u9B45\u5DF3\u7B95\u5CAC\u5BC6\u871C\u6E4A\u84D1\u7A14\u8108\u5999\u7C8D\u6C11\u7720\u52D9\u5922\u7121\u725F\u77DB\u9727\u9D61\u690B\u5A7F\u5A18\u51A5\u540D\u547D\u660E\u76DF\u8FF7\u9298\u9CF4\u59EA\u725D\u6EC5\u514D\u68C9\u7DBF\u7DEC\u9762\u9EBA\u6478\u6A21\u8302\u5984\u5B5F\u6BDB\u731B\u76F2\u7DB2\u8017\u8499\u5132\u6728\u9ED9\u76EE\u6762\u52FF\u9905\u5C24\u623B\u7C7E\u8CB0\u554F\u60B6\u7D0B\u9580\u5301\u4E5F\u51B6\u591C\u723A\u8036\u91CE\u5F25\u77E2\u5384\u5F79\u7D04\u85AC\u8A33\u8E8D\u9756\u67F3\u85AE\u9453\u6109\u6108\u6CB9\u7652\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[150].length; ++j)
        if (D[150][j].charCodeAt(0) !== 65533) {
          e[D[150][j]] = 38400 + j;
          d[38400 + j] = D[150][j];
        }
      D[151] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8AED\u8F38\u552F\u4F51\u512A\u52C7\u53CB\u5BA5\u5E7D\u60A0\u6182\u63D6\u6709\u67DA\u6E67\u6D8C\u7336\u7337\u7531\u7950\u88D5\u8A98\u904A\u9091\u90F5\u96C4\u878D\u5915\u4E88\u4F59\u4E0E\u8A89\u8F3F\u9810\u50AD\u5E7C\u5996\u5BB9\u5EB8\u63DA\u63FA\u64C1\u66DC\u694A\u69D8\u6D0B\u6EB6\u7194\u7528\u7AAF\u7F8A\u8000\u8449\u84C9\u8981\u8B21\u8E0A\u9065\u967D\u990A\u617E\u6291\u6B32\uFFFD\u6C83\u6D74\u7FCC\u7FFC\u6DC0\u7F85\u87BA\u88F8\u6765\u83B1\u983C\u96F7\u6D1B\u7D61\u843D\u916A\u4E71\u5375\u5D50\u6B04\u6FEB\u85CD\u862D\u89A7\u5229\u540F\u5C65\u674E\u68A8\u7406\u7483\u75E2\u88CF\u88E1\u91CC\u96E2\u9678\u5F8B\u7387\u7ACB\u844E\u63A0\u7565\u5289\u6D41\u6E9C\u7409\u7559\u786B\u7C92\u9686\u7ADC\u9F8D\u4FB6\u616E\u65C5\u865C\u4E86\u4EAE\u50DA\u4E21\u51CC\u5BEE\u6599\u6881\u6DBC\u731F\u7642\u77AD\u7A1C\u7CE7\u826F\u8AD2\u907C\u91CF\u9675\u9818\u529B\u7DD1\u502B\u5398\u6797\u6DCB\u71D0\u7433\u81E8\u8F2A\u96A3\u9C57\u9E9F\u7460\u5841\u6D99\u7D2F\u985E\u4EE4\u4F36\u4F8B\u51B7\u52B1\u5DBA\u601C\u73B2\u793C\u82D3\u9234\u96B7\u96F6\u970A\u9E97\u9F62\u66A6\u6B74\u5217\u52A3\u70C8\u88C2\u5EC9\u604B\u6190\u6F23\u7149\u7C3E\u7DF4\u806F\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[151].length; ++j)
        if (D[151][j].charCodeAt(0) !== 65533) {
          e[D[151][j]] = 38656 + j;
          d[38656 + j] = D[151][j];
        }
      D[152] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u84EE\u9023\u932C\u5442\u9B6F\u6AD3\u7089\u8CC2\u8DEF\u9732\u52B4\u5A41\u5ECA\u5F04\u6717\u697C\u6994\u6D6A\u6F0F\u7262\u72FC\u7BED\u8001\u807E\u874B\u90CE\u516D\u9E93\u7984\u808B\u9332\u8AD6\u502D\u548C\u8A71\u6B6A\u8CC4\u8107\u60D1\u67A0\u9DF2\u4E99\u4E98\u9C10\u8A6B\u85C1\u8568\u6900\u6E7E\u7897\u8155\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5F0C\u4E10\u4E15\u4E2A\u4E31\u4E36\u4E3C\u4E3F\u4E42\u4E56\u4E58\u4E82\u4E85\u8C6B\u4E8A\u8212\u5F0D\u4E8E\u4E9E\u4E9F\u4EA0\u4EA2\u4EB0\u4EB3\u4EB6\u4ECE\u4ECD\u4EC4\u4EC6\u4EC2\u4ED7\u4EDE\u4EED\u4EDF\u4EF7\u4F09\u4F5A\u4F30\u4F5B\u4F5D\u4F57\u4F47\u4F76\u4F88\u4F8F\u4F98\u4F7B\u4F69\u4F70\u4F91\u4F6F\u4F86\u4F96\u5118\u4FD4\u4FDF\u4FCE\u4FD8\u4FDB\u4FD1\u4FDA\u4FD0\u4FE4\u4FE5\u501A\u5028\u5014\u502A\u5025\u5005\u4F1C\u4FF6\u5021\u5029\u502C\u4FFE\u4FEF\u5011\u5006\u5043\u5047\u6703\u5055\u5050\u5048\u505A\u5056\u506C\u5078\u5080\u509A\u5085\u50B4\u50B2\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[152].length; ++j)
        if (D[152][j].charCodeAt(0) !== 65533) {
          e[D[152][j]] = 38912 + j;
          d[38912 + j] = D[152][j];
        }
      D[153] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u50C9\u50CA\u50B3\u50C2\u50D6\u50DE\u50E5\u50ED\u50E3\u50EE\u50F9\u50F5\u5109\u5101\u5102\u5116\u5115\u5114\u511A\u5121\u513A\u5137\u513C\u513B\u513F\u5140\u5152\u514C\u5154\u5162\u7AF8\u5169\u516A\u516E\u5180\u5182\u56D8\u518C\u5189\u518F\u5191\u5193\u5195\u5196\u51A4\u51A6\u51A2\u51A9\u51AA\u51AB\u51B3\u51B1\u51B2\u51B0\u51B5\u51BD\u51C5\u51C9\u51DB\u51E0\u8655\u51E9\u51ED\uFFFD\u51F0\u51F5\u51FE\u5204\u520B\u5214\u520E\u5227\u522A\u522E\u5233\u5239\u524F\u5244\u524B\u524C\u525E\u5254\u526A\u5274\u5269\u5273\u527F\u527D\u528D\u5294\u5292\u5271\u5288\u5291\u8FA8\u8FA7\u52AC\u52AD\u52BC\u52B5\u52C1\u52CD\u52D7\u52DE\u52E3\u52E6\u98ED\u52E0\u52F3\u52F5\u52F8\u52F9\u5306\u5308\u7538\u530D\u5310\u530F\u5315\u531A\u5323\u532F\u5331\u5333\u5338\u5340\u5346\u5345\u4E17\u5349\u534D\u51D6\u535E\u5369\u536E\u5918\u537B\u5377\u5382\u5396\u53A0\u53A6\u53A5\u53AE\u53B0\u53B6\u53C3\u7C12\u96D9\u53DF\u66FC\u71EE\u53EE\u53E8\u53ED\u53FA\u5401\u543D\u5440\u542C\u542D\u543C\u542E\u5436\u5429\u541D\u544E\u548F\u5475\u548E\u545F\u5471\u5477\u5470\u5492\u547B\u5480\u5476\u5484\u5490\u5486\u54C7\u54A2\u54B8\u54A5\u54AC\u54C4\u54C8\u54A8\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[153].length; ++j)
        if (D[153][j].charCodeAt(0) !== 65533) {
          e[D[153][j]] = 39168 + j;
          d[39168 + j] = D[153][j];
        }
      D[154] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54AB\u54C2\u54A4\u54BE\u54BC\u54D8\u54E5\u54E6\u550F\u5514\u54FD\u54EE\u54ED\u54FA\u54E2\u5539\u5540\u5563\u554C\u552E\u555C\u5545\u5556\u5557\u5538\u5533\u555D\u5599\u5580\u54AF\u558A\u559F\u557B\u557E\u5598\u559E\u55AE\u557C\u5583\u55A9\u5587\u55A8\u55DA\u55C5\u55DF\u55C4\u55DC\u55E4\u55D4\u5614\u55F7\u5616\u55FE\u55FD\u561B\u55F9\u564E\u5650\u71DF\u5634\u5636\u5632\u5638\uFFFD\u566B\u5664\u562F\u566C\u566A\u5686\u5680\u568A\u56A0\u5694\u568F\u56A5\u56AE\u56B6\u56B4\u56C2\u56BC\u56C1\u56C3\u56C0\u56C8\u56CE\u56D1\u56D3\u56D7\u56EE\u56F9\u5700\u56FF\u5704\u5709\u5708\u570B\u570D\u5713\u5718\u5716\u55C7\u571C\u5726\u5737\u5738\u574E\u573B\u5740\u574F\u5769\u57C0\u5788\u5761\u577F\u5789\u5793\u57A0\u57B3\u57A4\u57AA\u57B0\u57C3\u57C6\u57D4\u57D2\u57D3\u580A\u57D6\u57E3\u580B\u5819\u581D\u5872\u5821\u5862\u584B\u5870\u6BC0\u5852\u583D\u5879\u5885\u58B9\u589F\u58AB\u58BA\u58DE\u58BB\u58B8\u58AE\u58C5\u58D3\u58D1\u58D7\u58D9\u58D8\u58E5\u58DC\u58E4\u58DF\u58EF\u58FA\u58F9\u58FB\u58FC\u58FD\u5902\u590A\u5910\u591B\u68A6\u5925\u592C\u592D\u5932\u5938\u593E\u7AD2\u5955\u5950\u594E\u595A\u5958\u5962\u5960\u5967\u596C\u5969\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[154].length; ++j)
        if (D[154][j].charCodeAt(0) !== 65533) {
          e[D[154][j]] = 39424 + j;
          d[39424 + j] = D[154][j];
        }
      D[155] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5978\u5981\u599D\u4F5E\u4FAB\u59A3\u59B2\u59C6\u59E8\u59DC\u598D\u59D9\u59DA\u5A25\u5A1F\u5A11\u5A1C\u5A09\u5A1A\u5A40\u5A6C\u5A49\u5A35\u5A36\u5A62\u5A6A\u5A9A\u5ABC\u5ABE\u5ACB\u5AC2\u5ABD\u5AE3\u5AD7\u5AE6\u5AE9\u5AD6\u5AFA\u5AFB\u5B0C\u5B0B\u5B16\u5B32\u5AD0\u5B2A\u5B36\u5B3E\u5B43\u5B45\u5B40\u5B51\u5B55\u5B5A\u5B5B\u5B65\u5B69\u5B70\u5B73\u5B75\u5B78\u6588\u5B7A\u5B80\uFFFD\u5B83\u5BA6\u5BB8\u5BC3\u5BC7\u5BC9\u5BD4\u5BD0\u5BE4\u5BE6\u5BE2\u5BDE\u5BE5\u5BEB\u5BF0\u5BF6\u5BF3\u5C05\u5C07\u5C08\u5C0D\u5C13\u5C20\u5C22\u5C28\u5C38\u5C39\u5C41\u5C46\u5C4E\u5C53\u5C50\u5C4F\u5B71\u5C6C\u5C6E\u4E62\u5C76\u5C79\u5C8C\u5C91\u5C94\u599B\u5CAB\u5CBB\u5CB6\u5CBC\u5CB7\u5CC5\u5CBE\u5CC7\u5CD9\u5CE9\u5CFD\u5CFA\u5CED\u5D8C\u5CEA\u5D0B\u5D15\u5D17\u5D5C\u5D1F\u5D1B\u5D11\u5D14\u5D22\u5D1A\u5D19\u5D18\u5D4C\u5D52\u5D4E\u5D4B\u5D6C\u5D73\u5D76\u5D87\u5D84\u5D82\u5DA2\u5D9D\u5DAC\u5DAE\u5DBD\u5D90\u5DB7\u5DBC\u5DC9\u5DCD\u5DD3\u5DD2\u5DD6\u5DDB\u5DEB\u5DF2\u5DF5\u5E0B\u5E1A\u5E19\u5E11\u5E1B\u5E36\u5E37\u5E44\u5E43\u5E40\u5E4E\u5E57\u5E54\u5E5F\u5E62\u5E64\u5E47\u5E75\u5E76\u5E7A\u9EBC\u5E7F\u5EA0\u5EC1\u5EC2\u5EC8\u5ED0\u5ECF\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[155].length; ++j)
        if (D[155][j].charCodeAt(0) !== 65533) {
          e[D[155][j]] = 39680 + j;
          d[39680 + j] = D[155][j];
        }
      D[156] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5ED6\u5EE3\u5EDD\u5EDA\u5EDB\u5EE2\u5EE1\u5EE8\u5EE9\u5EEC\u5EF1\u5EF3\u5EF0\u5EF4\u5EF8\u5EFE\u5F03\u5F09\u5F5D\u5F5C\u5F0B\u5F11\u5F16\u5F29\u5F2D\u5F38\u5F41\u5F48\u5F4C\u5F4E\u5F2F\u5F51\u5F56\u5F57\u5F59\u5F61\u5F6D\u5F73\u5F77\u5F83\u5F82\u5F7F\u5F8A\u5F88\u5F91\u5F87\u5F9E\u5F99\u5F98\u5FA0\u5FA8\u5FAD\u5FBC\u5FD6\u5FFB\u5FE4\u5FF8\u5FF1\u5FDD\u60B3\u5FFF\u6021\u6060\uFFFD\u6019\u6010\u6029\u600E\u6031\u601B\u6015\u602B\u6026\u600F\u603A\u605A\u6041\u606A\u6077\u605F\u604A\u6046\u604D\u6063\u6043\u6064\u6042\u606C\u606B\u6059\u6081\u608D\u60E7\u6083\u609A\u6084\u609B\u6096\u6097\u6092\u60A7\u608B\u60E1\u60B8\u60E0\u60D3\u60B4\u5FF0\u60BD\u60C6\u60B5\u60D8\u614D\u6115\u6106\u60F6\u60F7\u6100\u60F4\u60FA\u6103\u6121\u60FB\u60F1\u610D\u610E\u6147\u613E\u6128\u6127\u614A\u613F\u613C\u612C\u6134\u613D\u6142\u6144\u6173\u6177\u6158\u6159\u615A\u616B\u6174\u616F\u6165\u6171\u615F\u615D\u6153\u6175\u6199\u6196\u6187\u61AC\u6194\u619A\u618A\u6191\u61AB\u61AE\u61CC\u61CA\u61C9\u61F7\u61C8\u61C3\u61C6\u61BA\u61CB\u7F79\u61CD\u61E6\u61E3\u61F6\u61FA\u61F4\u61FF\u61FD\u61FC\u61FE\u6200\u6208\u6209\u620D\u620C\u6214\u621B\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[156].length; ++j)
        if (D[156][j].charCodeAt(0) !== 65533) {
          e[D[156][j]] = 39936 + j;
          d[39936 + j] = D[156][j];
        }
      D[157] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u621E\u6221\u622A\u622E\u6230\u6232\u6233\u6241\u624E\u625E\u6263\u625B\u6260\u6268\u627C\u6282\u6289\u627E\u6292\u6293\u6296\u62D4\u6283\u6294\u62D7\u62D1\u62BB\u62CF\u62FF\u62C6\u64D4\u62C8\u62DC\u62CC\u62CA\u62C2\u62C7\u629B\u62C9\u630C\u62EE\u62F1\u6327\u6302\u6308\u62EF\u62F5\u6350\u633E\u634D\u641C\u634F\u6396\u638E\u6380\u63AB\u6376\u63A3\u638F\u6389\u639F\u63B5\u636B\uFFFD\u6369\u63BE\u63E9\u63C0\u63C6\u63E3\u63C9\u63D2\u63F6\u63C4\u6416\u6434\u6406\u6413\u6426\u6436\u651D\u6417\u6428\u640F\u6467\u646F\u6476\u644E\u652A\u6495\u6493\u64A5\u64A9\u6488\u64BC\u64DA\u64D2\u64C5\u64C7\u64BB\u64D8\u64C2\u64F1\u64E7\u8209\u64E0\u64E1\u62AC\u64E3\u64EF\u652C\u64F6\u64F4\u64F2\u64FA\u6500\u64FD\u6518\u651C\u6505\u6524\u6523\u652B\u6534\u6535\u6537\u6536\u6538\u754B\u6548\u6556\u6555\u654D\u6558\u655E\u655D\u6572\u6578\u6582\u6583\u8B8A\u659B\u659F\u65AB\u65B7\u65C3\u65C6\u65C1\u65C4\u65CC\u65D2\u65DB\u65D9\u65E0\u65E1\u65F1\u6772\u660A\u6603\u65FB\u6773\u6635\u6636\u6634\u661C\u664F\u6644\u6649\u6641\u665E\u665D\u6664\u6667\u6668\u665F\u6662\u6670\u6683\u6688\u668E\u6689\u6684\u6698\u669D\u66C1\u66B9\u66C9\u66BE\u66BC\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[157].length; ++j)
        if (D[157][j].charCodeAt(0) !== 65533) {
          e[D[157][j]] = 40192 + j;
          d[40192 + j] = D[157][j];
        }
      D[158] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u66C4\u66B8\u66D6\u66DA\u66E0\u663F\u66E6\u66E9\u66F0\u66F5\u66F7\u670F\u6716\u671E\u6726\u6727\u9738\u672E\u673F\u6736\u6741\u6738\u6737\u6746\u675E\u6760\u6759\u6763\u6764\u6789\u6770\u67A9\u677C\u676A\u678C\u678B\u67A6\u67A1\u6785\u67B7\u67EF\u67B4\u67EC\u67B3\u67E9\u67B8\u67E4\u67DE\u67DD\u67E2\u67EE\u67B9\u67CE\u67C6\u67E7\u6A9C\u681E\u6846\u6829\u6840\u684D\u6832\u684E\uFFFD\u68B3\u682B\u6859\u6863\u6877\u687F\u689F\u688F\u68AD\u6894\u689D\u689B\u6883\u6AAE\u68B9\u6874\u68B5\u68A0\u68BA\u690F\u688D\u687E\u6901\u68CA\u6908\u68D8\u6922\u6926\u68E1\u690C\u68CD\u68D4\u68E7\u68D5\u6936\u6912\u6904\u68D7\u68E3\u6925\u68F9\u68E0\u68EF\u6928\u692A\u691A\u6923\u6921\u68C6\u6979\u6977\u695C\u6978\u696B\u6954\u697E\u696E\u6939\u6974\u693D\u6959\u6930\u6961\u695E\u695D\u6981\u696A\u69B2\u69AE\u69D0\u69BF\u69C1\u69D3\u69BE\u69CE\u5BE8\u69CA\u69DD\u69BB\u69C3\u69A7\u6A2E\u6991\u69A0\u699C\u6995\u69B4\u69DE\u69E8\u6A02\u6A1B\u69FF\u6B0A\u69F9\u69F2\u69E7\u6A05\u69B1\u6A1E\u69ED\u6A14\u69EB\u6A0A\u6A12\u6AC1\u6A23\u6A13\u6A44\u6A0C\u6A72\u6A36\u6A78\u6A47\u6A62\u6A59\u6A66\u6A48\u6A38\u6A22\u6A90\u6A8D\u6AA0\u6A84\u6AA2\u6AA3\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[158].length; ++j)
        if (D[158][j].charCodeAt(0) !== 65533) {
          e[D[158][j]] = 40448 + j;
          d[40448 + j] = D[158][j];
        }
      D[159] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6A97\u8617\u6ABB\u6AC3\u6AC2\u6AB8\u6AB3\u6AAC\u6ADE\u6AD1\u6ADF\u6AAA\u6ADA\u6AEA\u6AFB\u6B05\u8616\u6AFA\u6B12\u6B16\u9B31\u6B1F\u6B38\u6B37\u76DC\u6B39\u98EE\u6B47\u6B43\u6B49\u6B50\u6B59\u6B54\u6B5B\u6B5F\u6B61\u6B78\u6B79\u6B7F\u6B80\u6B84\u6B83\u6B8D\u6B98\u6B95\u6B9E\u6BA4\u6BAA\u6BAB\u6BAF\u6BB2\u6BB1\u6BB3\u6BB7\u6BBC\u6BC6\u6BCB\u6BD3\u6BDF\u6BEC\u6BEB\u6BF3\u6BEF\uFFFD\u9EBE\u6C08\u6C13\u6C14\u6C1B\u6C24\u6C23\u6C5E\u6C55\u6C62\u6C6A\u6C82\u6C8D\u6C9A\u6C81\u6C9B\u6C7E\u6C68\u6C73\u6C92\u6C90\u6CC4\u6CF1\u6CD3\u6CBD\u6CD7\u6CC5\u6CDD\u6CAE\u6CB1\u6CBE\u6CBA\u6CDB\u6CEF\u6CD9\u6CEA\u6D1F\u884D\u6D36\u6D2B\u6D3D\u6D38\u6D19\u6D35\u6D33\u6D12\u6D0C\u6D63\u6D93\u6D64\u6D5A\u6D79\u6D59\u6D8E\u6D95\u6FE4\u6D85\u6DF9\u6E15\u6E0A\u6DB5\u6DC7\u6DE6\u6DB8\u6DC6\u6DEC\u6DDE\u6DCC\u6DE8\u6DD2\u6DC5\u6DFA\u6DD9\u6DE4\u6DD5\u6DEA\u6DEE\u6E2D\u6E6E\u6E2E\u6E19\u6E72\u6E5F\u6E3E\u6E23\u6E6B\u6E2B\u6E76\u6E4D\u6E1F\u6E43\u6E3A\u6E4E\u6E24\u6EFF\u6E1D\u6E38\u6E82\u6EAA\u6E98\u6EC9\u6EB7\u6ED3\u6EBD\u6EAF\u6EC4\u6EB2\u6ED4\u6ED5\u6E8F\u6EA5\u6EC2\u6E9F\u6F41\u6F11\u704C\u6EEC\u6EF8\u6EFE\u6F3F\u6EF2\u6F31\u6EEF\u6F32\u6ECC\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[159].length; ++j)
        if (D[159][j].charCodeAt(0) !== 65533) {
          e[D[159][j]] = 40704 + j;
          d[40704 + j] = D[159][j];
        }
      D[224] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6F3E\u6F13\u6EF7\u6F86\u6F7A\u6F78\u6F81\u6F80\u6F6F\u6F5B\u6FF3\u6F6D\u6F82\u6F7C\u6F58\u6F8E\u6F91\u6FC2\u6F66\u6FB3\u6FA3\u6FA1\u6FA4\u6FB9\u6FC6\u6FAA\u6FDF\u6FD5\u6FEC\u6FD4\u6FD8\u6FF1\u6FEE\u6FDB\u7009\u700B\u6FFA\u7011\u7001\u700F\u6FFE\u701B\u701A\u6F74\u701D\u7018\u701F\u7030\u703E\u7032\u7051\u7063\u7099\u7092\u70AF\u70F1\u70AC\u70B8\u70B3\u70AE\u70DF\u70CB\u70DD\uFFFD\u70D9\u7109\u70FD\u711C\u7119\u7165\u7155\u7188\u7166\u7162\u714C\u7156\u716C\u718F\u71FB\u7184\u7195\u71A8\u71AC\u71D7\u71B9\u71BE\u71D2\u71C9\u71D4\u71CE\u71E0\u71EC\u71E7\u71F5\u71FC\u71F9\u71FF\u720D\u7210\u721B\u7228\u722D\u722C\u7230\u7232\u723B\u723C\u723F\u7240\u7246\u724B\u7258\u7274\u727E\u7282\u7281\u7287\u7292\u7296\u72A2\u72A7\u72B9\u72B2\u72C3\u72C6\u72C4\u72CE\u72D2\u72E2\u72E0\u72E1\u72F9\u72F7\u500F\u7317\u730A\u731C\u7316\u731D\u7334\u732F\u7329\u7325\u733E\u734E\u734F\u9ED8\u7357\u736A\u7368\u7370\u7378\u7375\u737B\u737A\u73C8\u73B3\u73CE\u73BB\u73C0\u73E5\u73EE\u73DE\u74A2\u7405\u746F\u7425\u73F8\u7432\u743A\u7455\u743F\u745F\u7459\u7441\u745C\u7469\u7470\u7463\u746A\u7476\u747E\u748B\u749E\u74A7\u74CA\u74CF\u74D4\u73F1\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[224].length; ++j)
        if (D[224][j].charCodeAt(0) !== 65533) {
          e[D[224][j]] = 57344 + j;
          d[57344 + j] = D[224][j];
        }
      D[225] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u74E0\u74E3\u74E7\u74E9\u74EE\u74F2\u74F0\u74F1\u74F8\u74F7\u7504\u7503\u7505\u750C\u750E\u750D\u7515\u7513\u751E\u7526\u752C\u753C\u7544\u754D\u754A\u7549\u755B\u7546\u755A\u7569\u7564\u7567\u756B\u756D\u7578\u7576\u7586\u7587\u7574\u758A\u7589\u7582\u7594\u759A\u759D\u75A5\u75A3\u75C2\u75B3\u75C3\u75B5\u75BD\u75B8\u75BC\u75B1\u75CD\u75CA\u75D2\u75D9\u75E3\u75DE\u75FE\u75FF\uFFFD\u75FC\u7601\u75F0\u75FA\u75F2\u75F3\u760B\u760D\u7609\u761F\u7627\u7620\u7621\u7622\u7624\u7634\u7630\u763B\u7647\u7648\u7646\u765C\u7658\u7661\u7662\u7668\u7669\u766A\u7667\u766C\u7670\u7672\u7676\u7678\u767C\u7680\u7683\u7688\u768B\u768E\u7696\u7693\u7699\u769A\u76B0\u76B4\u76B8\u76B9\u76BA\u76C2\u76CD\u76D6\u76D2\u76DE\u76E1\u76E5\u76E7\u76EA\u862F\u76FB\u7708\u7707\u7704\u7729\u7724\u771E\u7725\u7726\u771B\u7737\u7738\u7747\u775A\u7768\u776B\u775B\u7765\u777F\u777E\u7779\u778E\u778B\u7791\u77A0\u779E\u77B0\u77B6\u77B9\u77BF\u77BC\u77BD\u77BB\u77C7\u77CD\u77D7\u77DA\u77DC\u77E3\u77EE\u77FC\u780C\u7812\u7926\u7820\u792A\u7845\u788E\u7874\u7886\u787C\u789A\u788C\u78A3\u78B5\u78AA\u78AF\u78D1\u78C6\u78CB\u78D4\u78BE\u78BC\u78C5\u78CA\u78EC\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[225].length; ++j)
        if (D[225][j].charCodeAt(0) !== 65533) {
          e[D[225][j]] = 57600 + j;
          d[57600 + j] = D[225][j];
        }
      D[226] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u78E7\u78DA\u78FD\u78F4\u7907\u7912\u7911\u7919\u792C\u792B\u7940\u7960\u7957\u795F\u795A\u7955\u7953\u797A\u797F\u798A\u799D\u79A7\u9F4B\u79AA\u79AE\u79B3\u79B9\u79BA\u79C9\u79D5\u79E7\u79EC\u79E1\u79E3\u7A08\u7A0D\u7A18\u7A19\u7A20\u7A1F\u7980\u7A31\u7A3B\u7A3E\u7A37\u7A43\u7A57\u7A49\u7A61\u7A62\u7A69\u9F9D\u7A70\u7A79\u7A7D\u7A88\u7A97\u7A95\u7A98\u7A96\u7AA9\u7AC8\u7AB0\uFFFD\u7AB6\u7AC5\u7AC4\u7ABF\u9083\u7AC7\u7ACA\u7ACD\u7ACF\u7AD5\u7AD3\u7AD9\u7ADA\u7ADD\u7AE1\u7AE2\u7AE6\u7AED\u7AF0\u7B02\u7B0F\u7B0A\u7B06\u7B33\u7B18\u7B19\u7B1E\u7B35\u7B28\u7B36\u7B50\u7B7A\u7B04\u7B4D\u7B0B\u7B4C\u7B45\u7B75\u7B65\u7B74\u7B67\u7B70\u7B71\u7B6C\u7B6E\u7B9D\u7B98\u7B9F\u7B8D\u7B9C\u7B9A\u7B8B\u7B92\u7B8F\u7B5D\u7B99\u7BCB\u7BC1\u7BCC\u7BCF\u7BB4\u7BC6\u7BDD\u7BE9\u7C11\u7C14\u7BE6\u7BE5\u7C60\u7C00\u7C07\u7C13\u7BF3\u7BF7\u7C17\u7C0D\u7BF6\u7C23\u7C27\u7C2A\u7C1F\u7C37\u7C2B\u7C3D\u7C4C\u7C43\u7C54\u7C4F\u7C40\u7C50\u7C58\u7C5F\u7C64\u7C56\u7C65\u7C6C\u7C75\u7C83\u7C90\u7CA4\u7CAD\u7CA2\u7CAB\u7CA1\u7CA8\u7CB3\u7CB2\u7CB1\u7CAE\u7CB9\u7CBD\u7CC0\u7CC5\u7CC2\u7CD8\u7CD2\u7CDC\u7CE2\u9B3B\u7CEF\u7CF2\u7CF4\u7CF6\u7CFA\u7D06\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[226].length; ++j)
        if (D[226][j].charCodeAt(0) !== 65533) {
          e[D[226][j]] = 57856 + j;
          d[57856 + j] = D[226][j];
        }
      D[227] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7D02\u7D1C\u7D15\u7D0A\u7D45\u7D4B\u7D2E\u7D32\u7D3F\u7D35\u7D46\u7D73\u7D56\u7D4E\u7D72\u7D68\u7D6E\u7D4F\u7D63\u7D93\u7D89\u7D5B\u7D8F\u7D7D\u7D9B\u7DBA\u7DAE\u7DA3\u7DB5\u7DC7\u7DBD\u7DAB\u7E3D\u7DA2\u7DAF\u7DDC\u7DB8\u7D9F\u7DB0\u7DD8\u7DDD\u7DE4\u7DDE\u7DFB\u7DF2\u7DE1\u7E05\u7E0A\u7E23\u7E21\u7E12\u7E31\u7E1F\u7E09\u7E0B\u7E22\u7E46\u7E66\u7E3B\u7E35\u7E39\u7E43\u7E37\uFFFD\u7E32\u7E3A\u7E67\u7E5D\u7E56\u7E5E\u7E59\u7E5A\u7E79\u7E6A\u7E69\u7E7C\u7E7B\u7E83\u7DD5\u7E7D\u8FAE\u7E7F\u7E88\u7E89\u7E8C\u7E92\u7E90\u7E93\u7E94\u7E96\u7E8E\u7E9B\u7E9C\u7F38\u7F3A\u7F45\u7F4C\u7F4D\u7F4E\u7F50\u7F51\u7F55\u7F54\u7F58\u7F5F\u7F60\u7F68\u7F69\u7F67\u7F78\u7F82\u7F86\u7F83\u7F88\u7F87\u7F8C\u7F94\u7F9E\u7F9D\u7F9A\u7FA3\u7FAF\u7FB2\u7FB9\u7FAE\u7FB6\u7FB8\u8B71\u7FC5\u7FC6\u7FCA\u7FD5\u7FD4\u7FE1\u7FE6\u7FE9\u7FF3\u7FF9\u98DC\u8006\u8004\u800B\u8012\u8018\u8019\u801C\u8021\u8028\u803F\u803B\u804A\u8046\u8052\u8058\u805A\u805F\u8062\u8068\u8073\u8072\u8070\u8076\u8079\u807D\u807F\u8084\u8086\u8085\u809B\u8093\u809A\u80AD\u5190\u80AC\u80DB\u80E5\u80D9\u80DD\u80C4\u80DA\u80D6\u8109\u80EF\u80F1\u811B\u8129\u8123\u812F\u814B\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[227].length; ++j)
        if (D[227][j].charCodeAt(0) !== 65533) {
          e[D[227][j]] = 58112 + j;
          d[58112 + j] = D[227][j];
        }
      D[228] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u968B\u8146\u813E\u8153\u8151\u80FC\u8171\u816E\u8165\u8166\u8174\u8183\u8188\u818A\u8180\u8182\u81A0\u8195\u81A4\u81A3\u815F\u8193\u81A9\u81B0\u81B5\u81BE\u81B8\u81BD\u81C0\u81C2\u81BA\u81C9\u81CD\u81D1\u81D9\u81D8\u81C8\u81DA\u81DF\u81E0\u81E7\u81FA\u81FB\u81FE\u8201\u8202\u8205\u8207\u820A\u820D\u8210\u8216\u8229\u822B\u8238\u8233\u8240\u8259\u8258\u825D\u825A\u825F\u8264\uFFFD\u8262\u8268\u826A\u826B\u822E\u8271\u8277\u8278\u827E\u828D\u8292\u82AB\u829F\u82BB\u82AC\u82E1\u82E3\u82DF\u82D2\u82F4\u82F3\u82FA\u8393\u8303\u82FB\u82F9\u82DE\u8306\u82DC\u8309\u82D9\u8335\u8334\u8316\u8332\u8331\u8340\u8339\u8350\u8345\u832F\u832B\u8317\u8318\u8385\u839A\u83AA\u839F\u83A2\u8396\u8323\u838E\u8387\u838A\u837C\u83B5\u8373\u8375\u83A0\u8389\u83A8\u83F4\u8413\u83EB\u83CE\u83FD\u8403\u83D8\u840B\u83C1\u83F7\u8407\u83E0\u83F2\u840D\u8422\u8420\u83BD\u8438\u8506\u83FB\u846D\u842A\u843C\u855A\u8484\u8477\u846B\u84AD\u846E\u8482\u8469\u8446\u842C\u846F\u8479\u8435\u84CA\u8462\u84B9\u84BF\u849F\u84D9\u84CD\u84BB\u84DA\u84D0\u84C1\u84C6\u84D6\u84A1\u8521\u84FF\u84F4\u8517\u8518\u852C\u851F\u8515\u8514\u84FC\u8540\u8563\u8558\u8548\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[228].length; ++j)
        if (D[228][j].charCodeAt(0) !== 65533) {
          e[D[228][j]] = 58368 + j;
          d[58368 + j] = D[228][j];
        }
      D[229] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8541\u8602\u854B\u8555\u8580\u85A4\u8588\u8591\u858A\u85A8\u856D\u8594\u859B\u85EA\u8587\u859C\u8577\u857E\u8590\u85C9\u85BA\u85CF\u85B9\u85D0\u85D5\u85DD\u85E5\u85DC\u85F9\u860A\u8613\u860B\u85FE\u85FA\u8606\u8622\u861A\u8630\u863F\u864D\u4E55\u8654\u865F\u8667\u8671\u8693\u86A3\u86A9\u86AA\u868B\u868C\u86B6\u86AF\u86C4\u86C6\u86B0\u86C9\u8823\u86AB\u86D4\u86DE\u86E9\u86EC\uFFFD\u86DF\u86DB\u86EF\u8712\u8706\u8708\u8700\u8703\u86FB\u8711\u8709\u870D\u86F9\u870A\u8734\u873F\u8737\u873B\u8725\u8729\u871A\u8760\u875F\u8778\u874C\u874E\u8774\u8757\u8768\u876E\u8759\u8753\u8763\u876A\u8805\u87A2\u879F\u8782\u87AF\u87CB\u87BD\u87C0\u87D0\u96D6\u87AB\u87C4\u87B3\u87C7\u87C6\u87BB\u87EF\u87F2\u87E0\u880F\u880D\u87FE\u87F6\u87F7\u880E\u87D2\u8811\u8816\u8815\u8822\u8821\u8831\u8836\u8839\u8827\u883B\u8844\u8842\u8852\u8859\u885E\u8862\u886B\u8881\u887E\u889E\u8875\u887D\u88B5\u8872\u8882\u8897\u8892\u88AE\u8899\u88A2\u888D\u88A4\u88B0\u88BF\u88B1\u88C3\u88C4\u88D4\u88D8\u88D9\u88DD\u88F9\u8902\u88FC\u88F4\u88E8\u88F2\u8904\u890C\u890A\u8913\u8943\u891E\u8925\u892A\u892B\u8941\u8944\u893B\u8936\u8938\u894C\u891D\u8960\u895E\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[229].length; ++j)
        if (D[229][j].charCodeAt(0) !== 65533) {
          e[D[229][j]] = 58624 + j;
          d[58624 + j] = D[229][j];
        }
      D[230] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8966\u8964\u896D\u896A\u896F\u8974\u8977\u897E\u8983\u8988\u898A\u8993\u8998\u89A1\u89A9\u89A6\u89AC\u89AF\u89B2\u89BA\u89BD\u89BF\u89C0\u89DA\u89DC\u89DD\u89E7\u89F4\u89F8\u8A03\u8A16\u8A10\u8A0C\u8A1B\u8A1D\u8A25\u8A36\u8A41\u8A5B\u8A52\u8A46\u8A48\u8A7C\u8A6D\u8A6C\u8A62\u8A85\u8A82\u8A84\u8AA8\u8AA1\u8A91\u8AA5\u8AA6\u8A9A\u8AA3\u8AC4\u8ACD\u8AC2\u8ADA\u8AEB\u8AF3\u8AE7\uFFFD\u8AE4\u8AF1\u8B14\u8AE0\u8AE2\u8AF7\u8ADE\u8ADB\u8B0C\u8B07\u8B1A\u8AE1\u8B16\u8B10\u8B17\u8B20\u8B33\u97AB\u8B26\u8B2B\u8B3E\u8B28\u8B41\u8B4C\u8B4F\u8B4E\u8B49\u8B56\u8B5B\u8B5A\u8B6B\u8B5F\u8B6C\u8B6F\u8B74\u8B7D\u8B80\u8B8C\u8B8E\u8B92\u8B93\u8B96\u8B99\u8B9A\u8C3A\u8C41\u8C3F\u8C48\u8C4C\u8C4E\u8C50\u8C55\u8C62\u8C6C\u8C78\u8C7A\u8C82\u8C89\u8C85\u8C8A\u8C8D\u8C8E\u8C94\u8C7C\u8C98\u621D\u8CAD\u8CAA\u8CBD\u8CB2\u8CB3\u8CAE\u8CB6\u8CC8\u8CC1\u8CE4\u8CE3\u8CDA\u8CFD\u8CFA\u8CFB\u8D04\u8D05\u8D0A\u8D07\u8D0F\u8D0D\u8D10\u9F4E\u8D13\u8CCD\u8D14\u8D16\u8D67\u8D6D\u8D71\u8D73\u8D81\u8D99\u8DC2\u8DBE\u8DBA\u8DCF\u8DDA\u8DD6\u8DCC\u8DDB\u8DCB\u8DEA\u8DEB\u8DDF\u8DE3\u8DFC\u8E08\u8E09\u8DFF\u8E1D\u8E1E\u8E10\u8E1F\u8E42\u8E35\u8E30\u8E34\u8E4A\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[230].length; ++j)
        if (D[230][j].charCodeAt(0) !== 65533) {
          e[D[230][j]] = 58880 + j;
          d[58880 + j] = D[230][j];
        }
      D[231] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8E47\u8E49\u8E4C\u8E50\u8E48\u8E59\u8E64\u8E60\u8E2A\u8E63\u8E55\u8E76\u8E72\u8E7C\u8E81\u8E87\u8E85\u8E84\u8E8B\u8E8A\u8E93\u8E91\u8E94\u8E99\u8EAA\u8EA1\u8EAC\u8EB0\u8EC6\u8EB1\u8EBE\u8EC5\u8EC8\u8ECB\u8EDB\u8EE3\u8EFC\u8EFB\u8EEB\u8EFE\u8F0A\u8F05\u8F15\u8F12\u8F19\u8F13\u8F1C\u8F1F\u8F1B\u8F0C\u8F26\u8F33\u8F3B\u8F39\u8F45\u8F42\u8F3E\u8F4C\u8F49\u8F46\u8F4E\u8F57\u8F5C\uFFFD\u8F62\u8F63\u8F64\u8F9C\u8F9F\u8FA3\u8FAD\u8FAF\u8FB7\u8FDA\u8FE5\u8FE2\u8FEA\u8FEF\u9087\u8FF4\u9005\u8FF9\u8FFA\u9011\u9015\u9021\u900D\u901E\u9016\u900B\u9027\u9036\u9035\u9039\u8FF8\u904F\u9050\u9051\u9052\u900E\u9049\u903E\u9056\u9058\u905E\u9068\u906F\u9076\u96A8\u9072\u9082\u907D\u9081\u9080\u908A\u9089\u908F\u90A8\u90AF\u90B1\u90B5\u90E2\u90E4\u6248\u90DB\u9102\u9112\u9119\u9132\u9130\u914A\u9156\u9158\u9163\u9165\u9169\u9173\u9172\u918B\u9189\u9182\u91A2\u91AB\u91AF\u91AA\u91B5\u91B4\u91BA\u91C0\u91C1\u91C9\u91CB\u91D0\u91D6\u91DF\u91E1\u91DB\u91FC\u91F5\u91F6\u921E\u91FF\u9214\u922C\u9215\u9211\u925E\u9257\u9245\u9249\u9264\u9248\u9295\u923F\u924B\u9250\u929C\u9296\u9293\u929B\u925A\u92CF\u92B9\u92B7\u92E9\u930F\u92FA\u9344\u932E\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[231].length; ++j)
        if (D[231][j].charCodeAt(0) !== 65533) {
          e[D[231][j]] = 59136 + j;
          d[59136 + j] = D[231][j];
        }
      D[232] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9319\u9322\u931A\u9323\u933A\u9335\u933B\u935C\u9360\u937C\u936E\u9356\u93B0\u93AC\u93AD\u9394\u93B9\u93D6\u93D7\u93E8\u93E5\u93D8\u93C3\u93DD\u93D0\u93C8\u93E4\u941A\u9414\u9413\u9403\u9407\u9410\u9436\u942B\u9435\u9421\u943A\u9441\u9452\u9444\u945B\u9460\u9462\u945E\u946A\u9229\u9470\u9475\u9477\u947D\u945A\u947C\u947E\u9481\u947F\u9582\u9587\u958A\u9594\u9596\u9598\u9599\uFFFD\u95A0\u95A8\u95A7\u95AD\u95BC\u95BB\u95B9\u95BE\u95CA\u6FF6\u95C3\u95CD\u95CC\u95D5\u95D4\u95D6\u95DC\u95E1\u95E5\u95E2\u9621\u9628\u962E\u962F\u9642\u964C\u964F\u964B\u9677\u965C\u965E\u965D\u965F\u9666\u9672\u966C\u968D\u9698\u9695\u9697\u96AA\u96A7\u96B1\u96B2\u96B0\u96B4\u96B6\u96B8\u96B9\u96CE\u96CB\u96C9\u96CD\u894D\u96DC\u970D\u96D5\u96F9\u9704\u9706\u9708\u9713\u970E\u9711\u970F\u9716\u9719\u9724\u972A\u9730\u9739\u973D\u973E\u9744\u9746\u9748\u9742\u9749\u975C\u9760\u9764\u9766\u9768\u52D2\u976B\u9771\u9779\u9785\u977C\u9781\u977A\u9786\u978B\u978F\u9790\u979C\u97A8\u97A6\u97A3\u97B3\u97B4\u97C3\u97C6\u97C8\u97CB\u97DC\u97ED\u9F4F\u97F2\u7ADF\u97F6\u97F5\u980F\u980C\u9838\u9824\u9821\u9837\u983D\u9846\u984F\u984B\u986B\u986F\u9870\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[232].length; ++j)
        if (D[232][j].charCodeAt(0) !== 65533) {
          e[D[232][j]] = 59392 + j;
          d[59392 + j] = D[232][j];
        }
      D[233] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9871\u9874\u9873\u98AA\u98AF\u98B1\u98B6\u98C4\u98C3\u98C6\u98E9\u98EB\u9903\u9909\u9912\u9914\u9918\u9921\u991D\u991E\u9924\u9920\u992C\u992E\u993D\u993E\u9942\u9949\u9945\u9950\u994B\u9951\u9952\u994C\u9955\u9997\u9998\u99A5\u99AD\u99AE\u99BC\u99DF\u99DB\u99DD\u99D8\u99D1\u99ED\u99EE\u99F1\u99F2\u99FB\u99F8\u9A01\u9A0F\u9A05\u99E2\u9A19\u9A2B\u9A37\u9A45\u9A42\u9A40\u9A43\uFFFD\u9A3E\u9A55\u9A4D\u9A5B\u9A57\u9A5F\u9A62\u9A65\u9A64\u9A69\u9A6B\u9A6A\u9AAD\u9AB0\u9ABC\u9AC0\u9ACF\u9AD1\u9AD3\u9AD4\u9ADE\u9ADF\u9AE2\u9AE3\u9AE6\u9AEF\u9AEB\u9AEE\u9AF4\u9AF1\u9AF7\u9AFB\u9B06\u9B18\u9B1A\u9B1F\u9B22\u9B23\u9B25\u9B27\u9B28\u9B29\u9B2A\u9B2E\u9B2F\u9B32\u9B44\u9B43\u9B4F\u9B4D\u9B4E\u9B51\u9B58\u9B74\u9B93\u9B83\u9B91\u9B96\u9B97\u9B9F\u9BA0\u9BA8\u9BB4\u9BC0\u9BCA\u9BB9\u9BC6\u9BCF\u9BD1\u9BD2\u9BE3\u9BE2\u9BE4\u9BD4\u9BE1\u9C3A\u9BF2\u9BF1\u9BF0\u9C15\u9C14\u9C09\u9C13\u9C0C\u9C06\u9C08\u9C12\u9C0A\u9C04\u9C2E\u9C1B\u9C25\u9C24\u9C21\u9C30\u9C47\u9C32\u9C46\u9C3E\u9C5A\u9C60\u9C67\u9C76\u9C78\u9CE7\u9CEC\u9CF0\u9D09\u9D08\u9CEB\u9D03\u9D06\u9D2A\u9D26\u9DAF\u9D23\u9D1F\u9D44\u9D15\u9D12\u9D41\u9D3F\u9D3E\u9D46\u9D48\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[233].length; ++j)
        if (D[233][j].charCodeAt(0) !== 65533) {
          e[D[233][j]] = 59648 + j;
          d[59648 + j] = D[233][j];
        }
      D[234] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9D5D\u9D5E\u9D64\u9D51\u9D50\u9D59\u9D72\u9D89\u9D87\u9DAB\u9D6F\u9D7A\u9D9A\u9DA4\u9DA9\u9DB2\u9DC4\u9DC1\u9DBB\u9DB8\u9DBA\u9DC6\u9DCF\u9DC2\u9DD9\u9DD3\u9DF8\u9DE6\u9DED\u9DEF\u9DFD\u9E1A\u9E1B\u9E1E\u9E75\u9E79\u9E7D\u9E81\u9E88\u9E8B\u9E8C\u9E92\u9E95\u9E91\u9E9D\u9EA5\u9EA9\u9EB8\u9EAA\u9EAD\u9761\u9ECC\u9ECE\u9ECF\u9ED0\u9ED4\u9EDC\u9EDE\u9EDD\u9EE0\u9EE5\u9EE8\u9EEF\uFFFD\u9EF4\u9EF6\u9EF7\u9EF9\u9EFB\u9EFC\u9EFD\u9F07\u9F08\u76B7\u9F15\u9F21\u9F2C\u9F3E\u9F4A\u9F52\u9F54\u9F63\u9F5F\u9F60\u9F61\u9F66\u9F67\u9F6C\u9F6A\u9F77\u9F72\u9F76\u9F95\u9F9C\u9FA0\u582F\u69C7\u9059\u7464\u51DC\u7199\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[234].length; ++j)
        if (D[234][j].charCodeAt(0) !== 65533) {
          e[D[234][j]] = 59904 + j;
          d[59904 + j] = D[234][j];
        }
      D[237] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E8A\u891C\u9348\u9288\u84DC\u4FC9\u70BB\u6631\u68C8\u92F9\u66FB\u5F45\u4E28\u4EE1\u4EFC\u4F00\u4F03\u4F39\u4F56\u4F92\u4F8A\u4F9A\u4F94\u4FCD\u5040\u5022\u4FFF\u501E\u5046\u5070\u5042\u5094\u50F4\u50D8\u514A\u5164\u519D\u51BE\u51EC\u5215\u529C\u52A6\u52C0\u52DB\u5300\u5307\u5324\u5372\u5393\u53B2\u53DD\uFA0E\u549C\u548A\u54A9\u54FF\u5586\u5759\u5765\u57AC\u57C8\u57C7\uFA0F\uFFFD\uFA10\u589E\u58B2\u590B\u5953\u595B\u595D\u5963\u59A4\u59BA\u5B56\u5BC0\u752F\u5BD8\u5BEC\u5C1E\u5CA6\u5CBA\u5CF5\u5D27\u5D53\uFA11\u5D42\u5D6D\u5DB8\u5DB9\u5DD0\u5F21\u5F34\u5F67\u5FB7\u5FDE\u605D\u6085\u608A\u60DE\u60D5\u6120\u60F2\u6111\u6137\u6130\u6198\u6213\u62A6\u63F5\u6460\u649D\u64CE\u654E\u6600\u6615\u663B\u6609\u662E\u661E\u6624\u6665\u6657\u6659\uFA12\u6673\u6699\u66A0\u66B2\u66BF\u66FA\u670E\uF929\u6766\u67BB\u6852\u67C0\u6801\u6844\u68CF\uFA13\u6968\uFA14\u6998\u69E2\u6A30\u6A6B\u6A46\u6A73\u6A7E\u6AE2\u6AE4\u6BD6\u6C3F\u6C5C\u6C86\u6C6F\u6CDA\u6D04\u6D87\u6D6F\u6D96\u6DAC\u6DCF\u6DF8\u6DF2\u6DFC\u6E39\u6E5C\u6E27\u6E3C\u6EBF\u6F88\u6FB5\u6FF5\u7005\u7007\u7028\u7085\u70AB\u710F\u7104\u715C\u7146\u7147\uFA15\u71C1\u71FE\u72B1\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[237].length; ++j)
        if (D[237][j].charCodeAt(0) !== 65533) {
          e[D[237][j]] = 60672 + j;
          d[60672 + j] = D[237][j];
        }
      D[238] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u72BE\u7324\uFA16\u7377\u73BD\u73C9\u73D6\u73E3\u73D2\u7407\u73F5\u7426\u742A\u7429\u742E\u7462\u7489\u749F\u7501\u756F\u7682\u769C\u769E\u769B\u76A6\uFA17\u7746\u52AF\u7821\u784E\u7864\u787A\u7930\uFA18\uFA19\uFA1A\u7994\uFA1B\u799B\u7AD1\u7AE7\uFA1C\u7AEB\u7B9E\uFA1D\u7D48\u7D5C\u7DB7\u7DA0\u7DD6\u7E52\u7F47\u7FA1\uFA1E\u8301\u8362\u837F\u83C7\u83F6\u8448\u84B4\u8553\u8559\uFFFD\u856B\uFA1F\u85B0\uFA20\uFA21\u8807\u88F5\u8A12\u8A37\u8A79\u8AA7\u8ABE\u8ADF\uFA22\u8AF6\u8B53\u8B7F\u8CF0\u8CF4\u8D12\u8D76\uFA23\u8ECF\uFA24\uFA25\u9067\u90DE\uFA26\u9115\u9127\u91DA\u91D7\u91DE\u91ED\u91EE\u91E4\u91E5\u9206\u9210\u920A\u923A\u9240\u923C\u924E\u9259\u9251\u9239\u9267\u92A7\u9277\u9278\u92E7\u92D7\u92D9\u92D0\uFA27\u92D5\u92E0\u92D3\u9325\u9321\u92FB\uFA28\u931E\u92FF\u931D\u9302\u9370\u9357\u93A4\u93C6\u93DE\u93F8\u9431\u9445\u9448\u9592\uF9DC\uFA29\u969D\u96AF\u9733\u973B\u9743\u974D\u974F\u9751\u9755\u9857\u9865\uFA2A\uFA2B\u9927\uFA2C\u999E\u9A4E\u9AD9\u9ADC\u9B75\u9B72\u9B8F\u9BB1\u9BBB\u9C00\u9D70\u9D6B\uFA2D\u9E19\u9ED1\uFFFD\uFFFD\u2170\u2171\u2172\u2173\u2174\u2175\u2176\u2177\u2178\u2179\uFFE2\uFFE4\uFF07\uFF02\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[238].length; ++j)
        if (D[238][j].charCodeAt(0) !== 65533) {
          e[D[238][j]] = 60928 + j;
          d[60928 + j] = D[238][j];
        }
      D[250] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2170\u2171\u2172\u2173\u2174\u2175\u2176\u2177\u2178\u2179\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\uFFE2\uFFE4\uFF07\uFF02\u3231\u2116\u2121\u2235\u7E8A\u891C\u9348\u9288\u84DC\u4FC9\u70BB\u6631\u68C8\u92F9\u66FB\u5F45\u4E28\u4EE1\u4EFC\u4F00\u4F03\u4F39\u4F56\u4F92\u4F8A\u4F9A\u4F94\u4FCD\u5040\u5022\u4FFF\u501E\u5046\u5070\u5042\u5094\u50F4\u50D8\u514A\uFFFD\u5164\u519D\u51BE\u51EC\u5215\u529C\u52A6\u52C0\u52DB\u5300\u5307\u5324\u5372\u5393\u53B2\u53DD\uFA0E\u549C\u548A\u54A9\u54FF\u5586\u5759\u5765\u57AC\u57C8\u57C7\uFA0F\uFA10\u589E\u58B2\u590B\u5953\u595B\u595D\u5963\u59A4\u59BA\u5B56\u5BC0\u752F\u5BD8\u5BEC\u5C1E\u5CA6\u5CBA\u5CF5\u5D27\u5D53\uFA11\u5D42\u5D6D\u5DB8\u5DB9\u5DD0\u5F21\u5F34\u5F67\u5FB7\u5FDE\u605D\u6085\u608A\u60DE\u60D5\u6120\u60F2\u6111\u6137\u6130\u6198\u6213\u62A6\u63F5\u6460\u649D\u64CE\u654E\u6600\u6615\u663B\u6609\u662E\u661E\u6624\u6665\u6657\u6659\uFA12\u6673\u6699\u66A0\u66B2\u66BF\u66FA\u670E\uF929\u6766\u67BB\u6852\u67C0\u6801\u6844\u68CF\uFA13\u6968\uFA14\u6998\u69E2\u6A30\u6A6B\u6A46\u6A73\u6A7E\u6AE2\u6AE4\u6BD6\u6C3F\u6C5C\u6C86\u6C6F\u6CDA\u6D04\u6D87\u6D6F\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[250].length; ++j)
        if (D[250][j].charCodeAt(0) !== 65533) {
          e[D[250][j]] = 64e3 + j;
          d[64e3 + j] = D[250][j];
        }
      D[251] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D96\u6DAC\u6DCF\u6DF8\u6DF2\u6DFC\u6E39\u6E5C\u6E27\u6E3C\u6EBF\u6F88\u6FB5\u6FF5\u7005\u7007\u7028\u7085\u70AB\u710F\u7104\u715C\u7146\u7147\uFA15\u71C1\u71FE\u72B1\u72BE\u7324\uFA16\u7377\u73BD\u73C9\u73D6\u73E3\u73D2\u7407\u73F5\u7426\u742A\u7429\u742E\u7462\u7489\u749F\u7501\u756F\u7682\u769C\u769E\u769B\u76A6\uFA17\u7746\u52AF\u7821\u784E\u7864\u787A\u7930\uFA18\uFA19\uFFFD\uFA1A\u7994\uFA1B\u799B\u7AD1\u7AE7\uFA1C\u7AEB\u7B9E\uFA1D\u7D48\u7D5C\u7DB7\u7DA0\u7DD6\u7E52\u7F47\u7FA1\uFA1E\u8301\u8362\u837F\u83C7\u83F6\u8448\u84B4\u8553\u8559\u856B\uFA1F\u85B0\uFA20\uFA21\u8807\u88F5\u8A12\u8A37\u8A79\u8AA7\u8ABE\u8ADF\uFA22\u8AF6\u8B53\u8B7F\u8CF0\u8CF4\u8D12\u8D76\uFA23\u8ECF\uFA24\uFA25\u9067\u90DE\uFA26\u9115\u9127\u91DA\u91D7\u91DE\u91ED\u91EE\u91E4\u91E5\u9206\u9210\u920A\u923A\u9240\u923C\u924E\u9259\u9251\u9239\u9267\u92A7\u9277\u9278\u92E7\u92D7\u92D9\u92D0\uFA27\u92D5\u92E0\u92D3\u9325\u9321\u92FB\uFA28\u931E\u92FF\u931D\u9302\u9370\u9357\u93A4\u93C6\u93DE\u93F8\u9431\u9445\u9448\u9592\uF9DC\uFA29\u969D\u96AF\u9733\u973B\u9743\u974D\u974F\u9751\u9755\u9857\u9865\uFA2A\uFA2B\u9927\uFA2C\u999E\u9A4E\u9AD9\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[251].length; ++j)
        if (D[251][j].charCodeAt(0) !== 65533) {
          e[D[251][j]] = 64256 + j;
          d[64256 + j] = D[251][j];
        }
      D[252] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9ADC\u9B75\u9B72\u9B8F\u9BB1\u9BBB\u9C00\u9D70\u9D6B\uFA2D\u9E19\u9ED1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[252].length; ++j)
        if (D[252][j].charCodeAt(0) !== 65533) {
          e[D[252][j]] = 64512 + j;
          d[64512 + j] = D[252][j];
        }
      return { "enc": e, "dec": d };
    }();
    cptable2[936] = function() {
      var d = [], e = {}, D = [], j;
      D[0] = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[0].length; ++j)
        if (D[0][j].charCodeAt(0) !== 65533) {
          e[D[0][j]] = 0 + j;
          d[0 + j] = D[0][j];
        }
      D[129] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E02\u4E04\u4E05\u4E06\u4E0F\u4E12\u4E17\u4E1F\u4E20\u4E21\u4E23\u4E26\u4E29\u4E2E\u4E2F\u4E31\u4E33\u4E35\u4E37\u4E3C\u4E40\u4E41\u4E42\u4E44\u4E46\u4E4A\u4E51\u4E55\u4E57\u4E5A\u4E5B\u4E62\u4E63\u4E64\u4E65\u4E67\u4E68\u4E6A\u4E6B\u4E6C\u4E6D\u4E6E\u4E6F\u4E72\u4E74\u4E75\u4E76\u4E77\u4E78\u4E79\u4E7A\u4E7B\u4E7C\u4E7D\u4E7F\u4E80\u4E81\u4E82\u4E83\u4E84\u4E85\u4E87\u4E8A\uFFFD\u4E90\u4E96\u4E97\u4E99\u4E9C\u4E9D\u4E9E\u4EA3\u4EAA\u4EAF\u4EB0\u4EB1\u4EB4\u4EB6\u4EB7\u4EB8\u4EB9\u4EBC\u4EBD\u4EBE\u4EC8\u4ECC\u4ECF\u4ED0\u4ED2\u4EDA\u4EDB\u4EDC\u4EE0\u4EE2\u4EE6\u4EE7\u4EE9\u4EED\u4EEE\u4EEF\u4EF1\u4EF4\u4EF8\u4EF9\u4EFA\u4EFC\u4EFE\u4F00\u4F02\u4F03\u4F04\u4F05\u4F06\u4F07\u4F08\u4F0B\u4F0C\u4F12\u4F13\u4F14\u4F15\u4F16\u4F1C\u4F1D\u4F21\u4F23\u4F28\u4F29\u4F2C\u4F2D\u4F2E\u4F31\u4F33\u4F35\u4F37\u4F39\u4F3B\u4F3E\u4F3F\u4F40\u4F41\u4F42\u4F44\u4F45\u4F47\u4F48\u4F49\u4F4A\u4F4B\u4F4C\u4F52\u4F54\u4F56\u4F61\u4F62\u4F66\u4F68\u4F6A\u4F6B\u4F6D\u4F6E\u4F71\u4F72\u4F75\u4F77\u4F78\u4F79\u4F7A\u4F7D\u4F80\u4F81\u4F82\u4F85\u4F86\u4F87\u4F8A\u4F8C\u4F8E\u4F90\u4F92\u4F93\u4F95\u4F96\u4F98\u4F99\u4F9A\u4F9C\u4F9E\u4F9F\u4FA1\u4FA2\uFFFD".split("");
      for (j = 0; j != D[129].length; ++j)
        if (D[129][j].charCodeAt(0) !== 65533) {
          e[D[129][j]] = 33024 + j;
          d[33024 + j] = D[129][j];
        }
      D[130] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4FA4\u4FAB\u4FAD\u4FB0\u4FB1\u4FB2\u4FB3\u4FB4\u4FB6\u4FB7\u4FB8\u4FB9\u4FBA\u4FBB\u4FBC\u4FBD\u4FBE\u4FC0\u4FC1\u4FC2\u4FC6\u4FC7\u4FC8\u4FC9\u4FCB\u4FCC\u4FCD\u4FD2\u4FD3\u4FD4\u4FD5\u4FD6\u4FD9\u4FDB\u4FE0\u4FE2\u4FE4\u4FE5\u4FE7\u4FEB\u4FEC\u4FF0\u4FF2\u4FF4\u4FF5\u4FF6\u4FF7\u4FF9\u4FFB\u4FFC\u4FFD\u4FFF\u5000\u5001\u5002\u5003\u5004\u5005\u5006\u5007\u5008\u5009\u500A\uFFFD\u500B\u500E\u5010\u5011\u5013\u5015\u5016\u5017\u501B\u501D\u501E\u5020\u5022\u5023\u5024\u5027\u502B\u502F\u5030\u5031\u5032\u5033\u5034\u5035\u5036\u5037\u5038\u5039\u503B\u503D\u503F\u5040\u5041\u5042\u5044\u5045\u5046\u5049\u504A\u504B\u504D\u5050\u5051\u5052\u5053\u5054\u5056\u5057\u5058\u5059\u505B\u505D\u505E\u505F\u5060\u5061\u5062\u5063\u5064\u5066\u5067\u5068\u5069\u506A\u506B\u506D\u506E\u506F\u5070\u5071\u5072\u5073\u5074\u5075\u5078\u5079\u507A\u507C\u507D\u5081\u5082\u5083\u5084\u5086\u5087\u5089\u508A\u508B\u508C\u508E\u508F\u5090\u5091\u5092\u5093\u5094\u5095\u5096\u5097\u5098\u5099\u509A\u509B\u509C\u509D\u509E\u509F\u50A0\u50A1\u50A2\u50A4\u50A6\u50AA\u50AB\u50AD\u50AE\u50AF\u50B0\u50B1\u50B3\u50B4\u50B5\u50B6\u50B7\u50B8\u50B9\u50BC\uFFFD".split("");
      for (j = 0; j != D[130].length; ++j)
        if (D[130][j].charCodeAt(0) !== 65533) {
          e[D[130][j]] = 33280 + j;
          d[33280 + j] = D[130][j];
        }
      D[131] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u50BD\u50BE\u50BF\u50C0\u50C1\u50C2\u50C3\u50C4\u50C5\u50C6\u50C7\u50C8\u50C9\u50CA\u50CB\u50CC\u50CD\u50CE\u50D0\u50D1\u50D2\u50D3\u50D4\u50D5\u50D7\u50D8\u50D9\u50DB\u50DC\u50DD\u50DE\u50DF\u50E0\u50E1\u50E2\u50E3\u50E4\u50E5\u50E8\u50E9\u50EA\u50EB\u50EF\u50F0\u50F1\u50F2\u50F4\u50F6\u50F7\u50F8\u50F9\u50FA\u50FC\u50FD\u50FE\u50FF\u5100\u5101\u5102\u5103\u5104\u5105\u5108\uFFFD\u5109\u510A\u510C\u510D\u510E\u510F\u5110\u5111\u5113\u5114\u5115\u5116\u5117\u5118\u5119\u511A\u511B\u511C\u511D\u511E\u511F\u5120\u5122\u5123\u5124\u5125\u5126\u5127\u5128\u5129\u512A\u512B\u512C\u512D\u512E\u512F\u5130\u5131\u5132\u5133\u5134\u5135\u5136\u5137\u5138\u5139\u513A\u513B\u513C\u513D\u513E\u5142\u5147\u514A\u514C\u514E\u514F\u5150\u5152\u5153\u5157\u5158\u5159\u515B\u515D\u515E\u515F\u5160\u5161\u5163\u5164\u5166\u5167\u5169\u516A\u516F\u5172\u517A\u517E\u517F\u5183\u5184\u5186\u5187\u518A\u518B\u518E\u518F\u5190\u5191\u5193\u5194\u5198\u519A\u519D\u519E\u519F\u51A1\u51A3\u51A6\u51A7\u51A8\u51A9\u51AA\u51AD\u51AE\u51B4\u51B8\u51B9\u51BA\u51BE\u51BF\u51C1\u51C2\u51C3\u51C5\u51C8\u51CA\u51CD\u51CE\u51D0\u51D2\u51D3\u51D4\u51D5\u51D6\u51D7\uFFFD".split("");
      for (j = 0; j != D[131].length; ++j)
        if (D[131][j].charCodeAt(0) !== 65533) {
          e[D[131][j]] = 33536 + j;
          d[33536 + j] = D[131][j];
        }
      D[132] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u51D8\u51D9\u51DA\u51DC\u51DE\u51DF\u51E2\u51E3\u51E5\u51E6\u51E7\u51E8\u51E9\u51EA\u51EC\u51EE\u51F1\u51F2\u51F4\u51F7\u51FE\u5204\u5205\u5209\u520B\u520C\u520F\u5210\u5213\u5214\u5215\u521C\u521E\u521F\u5221\u5222\u5223\u5225\u5226\u5227\u522A\u522C\u522F\u5231\u5232\u5234\u5235\u523C\u523E\u5244\u5245\u5246\u5247\u5248\u5249\u524B\u524E\u524F\u5252\u5253\u5255\u5257\u5258\uFFFD\u5259\u525A\u525B\u525D\u525F\u5260\u5262\u5263\u5264\u5266\u5268\u526B\u526C\u526D\u526E\u5270\u5271\u5273\u5274\u5275\u5276\u5277\u5278\u5279\u527A\u527B\u527C\u527E\u5280\u5283\u5284\u5285\u5286\u5287\u5289\u528A\u528B\u528C\u528D\u528E\u528F\u5291\u5292\u5294\u5295\u5296\u5297\u5298\u5299\u529A\u529C\u52A4\u52A5\u52A6\u52A7\u52AE\u52AF\u52B0\u52B4\u52B5\u52B6\u52B7\u52B8\u52B9\u52BA\u52BB\u52BC\u52BD\u52C0\u52C1\u52C2\u52C4\u52C5\u52C6\u52C8\u52CA\u52CC\u52CD\u52CE\u52CF\u52D1\u52D3\u52D4\u52D5\u52D7\u52D9\u52DA\u52DB\u52DC\u52DD\u52DE\u52E0\u52E1\u52E2\u52E3\u52E5\u52E6\u52E7\u52E8\u52E9\u52EA\u52EB\u52EC\u52ED\u52EE\u52EF\u52F1\u52F2\u52F3\u52F4\u52F5\u52F6\u52F7\u52F8\u52FB\u52FC\u52FD\u5301\u5302\u5303\u5304\u5307\u5309\u530A\u530B\u530C\u530E\uFFFD".split("");
      for (j = 0; j != D[132].length; ++j)
        if (D[132][j].charCodeAt(0) !== 65533) {
          e[D[132][j]] = 33792 + j;
          d[33792 + j] = D[132][j];
        }
      D[133] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5311\u5312\u5313\u5314\u5318\u531B\u531C\u531E\u531F\u5322\u5324\u5325\u5327\u5328\u5329\u532B\u532C\u532D\u532F\u5330\u5331\u5332\u5333\u5334\u5335\u5336\u5337\u5338\u533C\u533D\u5340\u5342\u5344\u5346\u534B\u534C\u534D\u5350\u5354\u5358\u5359\u535B\u535D\u5365\u5368\u536A\u536C\u536D\u5372\u5376\u5379\u537B\u537C\u537D\u537E\u5380\u5381\u5383\u5387\u5388\u538A\u538E\u538F\uFFFD\u5390\u5391\u5392\u5393\u5394\u5396\u5397\u5399\u539B\u539C\u539E\u53A0\u53A1\u53A4\u53A7\u53AA\u53AB\u53AC\u53AD\u53AF\u53B0\u53B1\u53B2\u53B3\u53B4\u53B5\u53B7\u53B8\u53B9\u53BA\u53BC\u53BD\u53BE\u53C0\u53C3\u53C4\u53C5\u53C6\u53C7\u53CE\u53CF\u53D0\u53D2\u53D3\u53D5\u53DA\u53DC\u53DD\u53DE\u53E1\u53E2\u53E7\u53F4\u53FA\u53FE\u53FF\u5400\u5402\u5405\u5407\u540B\u5414\u5418\u5419\u541A\u541C\u5422\u5424\u5425\u542A\u5430\u5433\u5436\u5437\u543A\u543D\u543F\u5441\u5442\u5444\u5445\u5447\u5449\u544C\u544D\u544E\u544F\u5451\u545A\u545D\u545E\u545F\u5460\u5461\u5463\u5465\u5467\u5469\u546A\u546B\u546C\u546D\u546E\u546F\u5470\u5474\u5479\u547A\u547E\u547F\u5481\u5483\u5485\u5487\u5488\u5489\u548A\u548D\u5491\u5493\u5497\u5498\u549C\u549E\u549F\u54A0\u54A1\uFFFD".split("");
      for (j = 0; j != D[133].length; ++j)
        if (D[133][j].charCodeAt(0) !== 65533) {
          e[D[133][j]] = 34048 + j;
          d[34048 + j] = D[133][j];
        }
      D[134] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54A2\u54A5\u54AE\u54B0\u54B2\u54B5\u54B6\u54B7\u54B9\u54BA\u54BC\u54BE\u54C3\u54C5\u54CA\u54CB\u54D6\u54D8\u54DB\u54E0\u54E1\u54E2\u54E3\u54E4\u54EB\u54EC\u54EF\u54F0\u54F1\u54F4\u54F5\u54F6\u54F7\u54F8\u54F9\u54FB\u54FE\u5500\u5502\u5503\u5504\u5505\u5508\u550A\u550B\u550C\u550D\u550E\u5512\u5513\u5515\u5516\u5517\u5518\u5519\u551A\u551C\u551D\u551E\u551F\u5521\u5525\u5526\uFFFD\u5528\u5529\u552B\u552D\u5532\u5534\u5535\u5536\u5538\u5539\u553A\u553B\u553D\u5540\u5542\u5545\u5547\u5548\u554B\u554C\u554D\u554E\u554F\u5551\u5552\u5553\u5554\u5557\u5558\u5559\u555A\u555B\u555D\u555E\u555F\u5560\u5562\u5563\u5568\u5569\u556B\u556F\u5570\u5571\u5572\u5573\u5574\u5579\u557A\u557D\u557F\u5585\u5586\u558C\u558D\u558E\u5590\u5592\u5593\u5595\u5596\u5597\u559A\u559B\u559E\u55A0\u55A1\u55A2\u55A3\u55A4\u55A5\u55A6\u55A8\u55A9\u55AA\u55AB\u55AC\u55AD\u55AE\u55AF\u55B0\u55B2\u55B4\u55B6\u55B8\u55BA\u55BC\u55BF\u55C0\u55C1\u55C2\u55C3\u55C6\u55C7\u55C8\u55CA\u55CB\u55CE\u55CF\u55D0\u55D5\u55D7\u55D8\u55D9\u55DA\u55DB\u55DE\u55E0\u55E2\u55E7\u55E9\u55ED\u55EE\u55F0\u55F1\u55F4\u55F6\u55F8\u55F9\u55FA\u55FB\u55FC\u55FF\u5602\u5603\u5604\u5605\uFFFD".split("");
      for (j = 0; j != D[134].length; ++j)
        if (D[134][j].charCodeAt(0) !== 65533) {
          e[D[134][j]] = 34304 + j;
          d[34304 + j] = D[134][j];
        }
      D[135] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5606\u5607\u560A\u560B\u560D\u5610\u5611\u5612\u5613\u5614\u5615\u5616\u5617\u5619\u561A\u561C\u561D\u5620\u5621\u5622\u5625\u5626\u5628\u5629\u562A\u562B\u562E\u562F\u5630\u5633\u5635\u5637\u5638\u563A\u563C\u563D\u563E\u5640\u5641\u5642\u5643\u5644\u5645\u5646\u5647\u5648\u5649\u564A\u564B\u564F\u5650\u5651\u5652\u5653\u5655\u5656\u565A\u565B\u565D\u565E\u565F\u5660\u5661\uFFFD\u5663\u5665\u5666\u5667\u566D\u566E\u566F\u5670\u5672\u5673\u5674\u5675\u5677\u5678\u5679\u567A\u567D\u567E\u567F\u5680\u5681\u5682\u5683\u5684\u5687\u5688\u5689\u568A\u568B\u568C\u568D\u5690\u5691\u5692\u5694\u5695\u5696\u5697\u5698\u5699\u569A\u569B\u569C\u569D\u569E\u569F\u56A0\u56A1\u56A2\u56A4\u56A5\u56A6\u56A7\u56A8\u56A9\u56AA\u56AB\u56AC\u56AD\u56AE\u56B0\u56B1\u56B2\u56B3\u56B4\u56B5\u56B6\u56B8\u56B9\u56BA\u56BB\u56BD\u56BE\u56BF\u56C0\u56C1\u56C2\u56C3\u56C4\u56C5\u56C6\u56C7\u56C8\u56C9\u56CB\u56CC\u56CD\u56CE\u56CF\u56D0\u56D1\u56D2\u56D3\u56D5\u56D6\u56D8\u56D9\u56DC\u56E3\u56E5\u56E6\u56E7\u56E8\u56E9\u56EA\u56EC\u56EE\u56EF\u56F2\u56F3\u56F6\u56F7\u56F8\u56FB\u56FC\u5700\u5701\u5702\u5705\u5707\u570B\u570C\u570D\u570E\u570F\u5710\u5711\uFFFD".split("");
      for (j = 0; j != D[135].length; ++j)
        if (D[135][j].charCodeAt(0) !== 65533) {
          e[D[135][j]] = 34560 + j;
          d[34560 + j] = D[135][j];
        }
      D[136] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5712\u5713\u5714\u5715\u5716\u5717\u5718\u5719\u571A\u571B\u571D\u571E\u5720\u5721\u5722\u5724\u5725\u5726\u5727\u572B\u5731\u5732\u5734\u5735\u5736\u5737\u5738\u573C\u573D\u573F\u5741\u5743\u5744\u5745\u5746\u5748\u5749\u574B\u5752\u5753\u5754\u5755\u5756\u5758\u5759\u5762\u5763\u5765\u5767\u576C\u576E\u5770\u5771\u5772\u5774\u5775\u5778\u5779\u577A\u577D\u577E\u577F\u5780\uFFFD\u5781\u5787\u5788\u5789\u578A\u578D\u578E\u578F\u5790\u5791\u5794\u5795\u5796\u5797\u5798\u5799\u579A\u579C\u579D\u579E\u579F\u57A5\u57A8\u57AA\u57AC\u57AF\u57B0\u57B1\u57B3\u57B5\u57B6\u57B7\u57B9\u57BA\u57BB\u57BC\u57BD\u57BE\u57BF\u57C0\u57C1\u57C4\u57C5\u57C6\u57C7\u57C8\u57C9\u57CA\u57CC\u57CD\u57D0\u57D1\u57D3\u57D6\u57D7\u57DB\u57DC\u57DE\u57E1\u57E2\u57E3\u57E5\u57E6\u57E7\u57E8\u57E9\u57EA\u57EB\u57EC\u57EE\u57F0\u57F1\u57F2\u57F3\u57F5\u57F6\u57F7\u57FB\u57FC\u57FE\u57FF\u5801\u5803\u5804\u5805\u5808\u5809\u580A\u580C\u580E\u580F\u5810\u5812\u5813\u5814\u5816\u5817\u5818\u581A\u581B\u581C\u581D\u581F\u5822\u5823\u5825\u5826\u5827\u5828\u5829\u582B\u582C\u582D\u582E\u582F\u5831\u5832\u5833\u5834\u5836\u5837\u5838\u5839\u583A\u583B\u583C\u583D\uFFFD".split("");
      for (j = 0; j != D[136].length; ++j)
        if (D[136][j].charCodeAt(0) !== 65533) {
          e[D[136][j]] = 34816 + j;
          d[34816 + j] = D[136][j];
        }
      D[137] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u583E\u583F\u5840\u5841\u5842\u5843\u5845\u5846\u5847\u5848\u5849\u584A\u584B\u584E\u584F\u5850\u5852\u5853\u5855\u5856\u5857\u5859\u585A\u585B\u585C\u585D\u585F\u5860\u5861\u5862\u5863\u5864\u5866\u5867\u5868\u5869\u586A\u586D\u586E\u586F\u5870\u5871\u5872\u5873\u5874\u5875\u5876\u5877\u5878\u5879\u587A\u587B\u587C\u587D\u587F\u5882\u5884\u5886\u5887\u5888\u588A\u588B\u588C\uFFFD\u588D\u588E\u588F\u5890\u5891\u5894\u5895\u5896\u5897\u5898\u589B\u589C\u589D\u58A0\u58A1\u58A2\u58A3\u58A4\u58A5\u58A6\u58A7\u58AA\u58AB\u58AC\u58AD\u58AE\u58AF\u58B0\u58B1\u58B2\u58B3\u58B4\u58B5\u58B6\u58B7\u58B8\u58B9\u58BA\u58BB\u58BD\u58BE\u58BF\u58C0\u58C2\u58C3\u58C4\u58C6\u58C7\u58C8\u58C9\u58CA\u58CB\u58CC\u58CD\u58CE\u58CF\u58D0\u58D2\u58D3\u58D4\u58D6\u58D7\u58D8\u58D9\u58DA\u58DB\u58DC\u58DD\u58DE\u58DF\u58E0\u58E1\u58E2\u58E3\u58E5\u58E6\u58E7\u58E8\u58E9\u58EA\u58ED\u58EF\u58F1\u58F2\u58F4\u58F5\u58F7\u58F8\u58FA\u58FB\u58FC\u58FD\u58FE\u58FF\u5900\u5901\u5903\u5905\u5906\u5908\u5909\u590A\u590B\u590C\u590E\u5910\u5911\u5912\u5913\u5917\u5918\u591B\u591D\u591E\u5920\u5921\u5922\u5923\u5926\u5928\u592C\u5930\u5932\u5933\u5935\u5936\u593B\uFFFD".split("");
      for (j = 0; j != D[137].length; ++j)
        if (D[137][j].charCodeAt(0) !== 65533) {
          e[D[137][j]] = 35072 + j;
          d[35072 + j] = D[137][j];
        }
      D[138] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u593D\u593E\u593F\u5940\u5943\u5945\u5946\u594A\u594C\u594D\u5950\u5952\u5953\u5959\u595B\u595C\u595D\u595E\u595F\u5961\u5963\u5964\u5966\u5967\u5968\u5969\u596A\u596B\u596C\u596D\u596E\u596F\u5970\u5971\u5972\u5975\u5977\u597A\u597B\u597C\u597E\u597F\u5980\u5985\u5989\u598B\u598C\u598E\u598F\u5990\u5991\u5994\u5995\u5998\u599A\u599B\u599C\u599D\u599F\u59A0\u59A1\u59A2\u59A6\uFFFD\u59A7\u59AC\u59AD\u59B0\u59B1\u59B3\u59B4\u59B5\u59B6\u59B7\u59B8\u59BA\u59BC\u59BD\u59BF\u59C0\u59C1\u59C2\u59C3\u59C4\u59C5\u59C7\u59C8\u59C9\u59CC\u59CD\u59CE\u59CF\u59D5\u59D6\u59D9\u59DB\u59DE\u59DF\u59E0\u59E1\u59E2\u59E4\u59E6\u59E7\u59E9\u59EA\u59EB\u59ED\u59EE\u59EF\u59F0\u59F1\u59F2\u59F3\u59F4\u59F5\u59F6\u59F7\u59F8\u59FA\u59FC\u59FD\u59FE\u5A00\u5A02\u5A0A\u5A0B\u5A0D\u5A0E\u5A0F\u5A10\u5A12\u5A14\u5A15\u5A16\u5A17\u5A19\u5A1A\u5A1B\u5A1D\u5A1E\u5A21\u5A22\u5A24\u5A26\u5A27\u5A28\u5A2A\u5A2B\u5A2C\u5A2D\u5A2E\u5A2F\u5A30\u5A33\u5A35\u5A37\u5A38\u5A39\u5A3A\u5A3B\u5A3D\u5A3E\u5A3F\u5A41\u5A42\u5A43\u5A44\u5A45\u5A47\u5A48\u5A4B\u5A4C\u5A4D\u5A4E\u5A4F\u5A50\u5A51\u5A52\u5A53\u5A54\u5A56\u5A57\u5A58\u5A59\u5A5B\u5A5C\u5A5D\u5A5E\u5A5F\u5A60\uFFFD".split("");
      for (j = 0; j != D[138].length; ++j)
        if (D[138][j].charCodeAt(0) !== 65533) {
          e[D[138][j]] = 35328 + j;
          d[35328 + j] = D[138][j];
        }
      D[139] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5A61\u5A63\u5A64\u5A65\u5A66\u5A68\u5A69\u5A6B\u5A6C\u5A6D\u5A6E\u5A6F\u5A70\u5A71\u5A72\u5A73\u5A78\u5A79\u5A7B\u5A7C\u5A7D\u5A7E\u5A80\u5A81\u5A82\u5A83\u5A84\u5A85\u5A86\u5A87\u5A88\u5A89\u5A8A\u5A8B\u5A8C\u5A8D\u5A8E\u5A8F\u5A90\u5A91\u5A93\u5A94\u5A95\u5A96\u5A97\u5A98\u5A99\u5A9C\u5A9D\u5A9E\u5A9F\u5AA0\u5AA1\u5AA2\u5AA3\u5AA4\u5AA5\u5AA6\u5AA7\u5AA8\u5AA9\u5AAB\u5AAC\uFFFD\u5AAD\u5AAE\u5AAF\u5AB0\u5AB1\u5AB4\u5AB6\u5AB7\u5AB9\u5ABA\u5ABB\u5ABC\u5ABD\u5ABF\u5AC0\u5AC3\u5AC4\u5AC5\u5AC6\u5AC7\u5AC8\u5ACA\u5ACB\u5ACD\u5ACE\u5ACF\u5AD0\u5AD1\u5AD3\u5AD5\u5AD7\u5AD9\u5ADA\u5ADB\u5ADD\u5ADE\u5ADF\u5AE2\u5AE4\u5AE5\u5AE7\u5AE8\u5AEA\u5AEC\u5AED\u5AEE\u5AEF\u5AF0\u5AF2\u5AF3\u5AF4\u5AF5\u5AF6\u5AF7\u5AF8\u5AF9\u5AFA\u5AFB\u5AFC\u5AFD\u5AFE\u5AFF\u5B00\u5B01\u5B02\u5B03\u5B04\u5B05\u5B06\u5B07\u5B08\u5B0A\u5B0B\u5B0C\u5B0D\u5B0E\u5B0F\u5B10\u5B11\u5B12\u5B13\u5B14\u5B15\u5B18\u5B19\u5B1A\u5B1B\u5B1C\u5B1D\u5B1E\u5B1F\u5B20\u5B21\u5B22\u5B23\u5B24\u5B25\u5B26\u5B27\u5B28\u5B29\u5B2A\u5B2B\u5B2C\u5B2D\u5B2E\u5B2F\u5B30\u5B31\u5B33\u5B35\u5B36\u5B38\u5B39\u5B3A\u5B3B\u5B3C\u5B3D\u5B3E\u5B3F\u5B41\u5B42\u5B43\u5B44\u5B45\u5B46\u5B47\uFFFD".split("");
      for (j = 0; j != D[139].length; ++j)
        if (D[139][j].charCodeAt(0) !== 65533) {
          e[D[139][j]] = 35584 + j;
          d[35584 + j] = D[139][j];
        }
      D[140] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5B48\u5B49\u5B4A\u5B4B\u5B4C\u5B4D\u5B4E\u5B4F\u5B52\u5B56\u5B5E\u5B60\u5B61\u5B67\u5B68\u5B6B\u5B6D\u5B6E\u5B6F\u5B72\u5B74\u5B76\u5B77\u5B78\u5B79\u5B7B\u5B7C\u5B7E\u5B7F\u5B82\u5B86\u5B8A\u5B8D\u5B8E\u5B90\u5B91\u5B92\u5B94\u5B96\u5B9F\u5BA7\u5BA8\u5BA9\u5BAC\u5BAD\u5BAE\u5BAF\u5BB1\u5BB2\u5BB7\u5BBA\u5BBB\u5BBC\u5BC0\u5BC1\u5BC3\u5BC8\u5BC9\u5BCA\u5BCB\u5BCD\u5BCE\u5BCF\uFFFD\u5BD1\u5BD4\u5BD5\u5BD6\u5BD7\u5BD8\u5BD9\u5BDA\u5BDB\u5BDC\u5BE0\u5BE2\u5BE3\u5BE6\u5BE7\u5BE9\u5BEA\u5BEB\u5BEC\u5BED\u5BEF\u5BF1\u5BF2\u5BF3\u5BF4\u5BF5\u5BF6\u5BF7\u5BFD\u5BFE\u5C00\u5C02\u5C03\u5C05\u5C07\u5C08\u5C0B\u5C0C\u5C0D\u5C0E\u5C10\u5C12\u5C13\u5C17\u5C19\u5C1B\u5C1E\u5C1F\u5C20\u5C21\u5C23\u5C26\u5C28\u5C29\u5C2A\u5C2B\u5C2D\u5C2E\u5C2F\u5C30\u5C32\u5C33\u5C35\u5C36\u5C37\u5C43\u5C44\u5C46\u5C47\u5C4C\u5C4D\u5C52\u5C53\u5C54\u5C56\u5C57\u5C58\u5C5A\u5C5B\u5C5C\u5C5D\u5C5F\u5C62\u5C64\u5C67\u5C68\u5C69\u5C6A\u5C6B\u5C6C\u5C6D\u5C70\u5C72\u5C73\u5C74\u5C75\u5C76\u5C77\u5C78\u5C7B\u5C7C\u5C7D\u5C7E\u5C80\u5C83\u5C84\u5C85\u5C86\u5C87\u5C89\u5C8A\u5C8B\u5C8E\u5C8F\u5C92\u5C93\u5C95\u5C9D\u5C9E\u5C9F\u5CA0\u5CA1\u5CA4\u5CA5\u5CA6\u5CA7\u5CA8\uFFFD".split("");
      for (j = 0; j != D[140].length; ++j)
        if (D[140][j].charCodeAt(0) !== 65533) {
          e[D[140][j]] = 35840 + j;
          d[35840 + j] = D[140][j];
        }
      D[141] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5CAA\u5CAE\u5CAF\u5CB0\u5CB2\u5CB4\u5CB6\u5CB9\u5CBA\u5CBB\u5CBC\u5CBE\u5CC0\u5CC2\u5CC3\u5CC5\u5CC6\u5CC7\u5CC8\u5CC9\u5CCA\u5CCC\u5CCD\u5CCE\u5CCF\u5CD0\u5CD1\u5CD3\u5CD4\u5CD5\u5CD6\u5CD7\u5CD8\u5CDA\u5CDB\u5CDC\u5CDD\u5CDE\u5CDF\u5CE0\u5CE2\u5CE3\u5CE7\u5CE9\u5CEB\u5CEC\u5CEE\u5CEF\u5CF1\u5CF2\u5CF3\u5CF4\u5CF5\u5CF6\u5CF7\u5CF8\u5CF9\u5CFA\u5CFC\u5CFD\u5CFE\u5CFF\u5D00\uFFFD\u5D01\u5D04\u5D05\u5D08\u5D09\u5D0A\u5D0B\u5D0C\u5D0D\u5D0F\u5D10\u5D11\u5D12\u5D13\u5D15\u5D17\u5D18\u5D19\u5D1A\u5D1C\u5D1D\u5D1F\u5D20\u5D21\u5D22\u5D23\u5D25\u5D28\u5D2A\u5D2B\u5D2C\u5D2F\u5D30\u5D31\u5D32\u5D33\u5D35\u5D36\u5D37\u5D38\u5D39\u5D3A\u5D3B\u5D3C\u5D3F\u5D40\u5D41\u5D42\u5D43\u5D44\u5D45\u5D46\u5D48\u5D49\u5D4D\u5D4E\u5D4F\u5D50\u5D51\u5D52\u5D53\u5D54\u5D55\u5D56\u5D57\u5D59\u5D5A\u5D5C\u5D5E\u5D5F\u5D60\u5D61\u5D62\u5D63\u5D64\u5D65\u5D66\u5D67\u5D68\u5D6A\u5D6D\u5D6E\u5D70\u5D71\u5D72\u5D73\u5D75\u5D76\u5D77\u5D78\u5D79\u5D7A\u5D7B\u5D7C\u5D7D\u5D7E\u5D7F\u5D80\u5D81\u5D83\u5D84\u5D85\u5D86\u5D87\u5D88\u5D89\u5D8A\u5D8B\u5D8C\u5D8D\u5D8E\u5D8F\u5D90\u5D91\u5D92\u5D93\u5D94\u5D95\u5D96\u5D97\u5D98\u5D9A\u5D9B\u5D9C\u5D9E\u5D9F\u5DA0\uFFFD".split("");
      for (j = 0; j != D[141].length; ++j)
        if (D[141][j].charCodeAt(0) !== 65533) {
          e[D[141][j]] = 36096 + j;
          d[36096 + j] = D[141][j];
        }
      D[142] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5DA1\u5DA2\u5DA3\u5DA4\u5DA5\u5DA6\u5DA7\u5DA8\u5DA9\u5DAA\u5DAB\u5DAC\u5DAD\u5DAE\u5DAF\u5DB0\u5DB1\u5DB2\u5DB3\u5DB4\u5DB5\u5DB6\u5DB8\u5DB9\u5DBA\u5DBB\u5DBC\u5DBD\u5DBE\u5DBF\u5DC0\u5DC1\u5DC2\u5DC3\u5DC4\u5DC6\u5DC7\u5DC8\u5DC9\u5DCA\u5DCB\u5DCC\u5DCE\u5DCF\u5DD0\u5DD1\u5DD2\u5DD3\u5DD4\u5DD5\u5DD6\u5DD7\u5DD8\u5DD9\u5DDA\u5DDC\u5DDF\u5DE0\u5DE3\u5DE4\u5DEA\u5DEC\u5DED\uFFFD\u5DF0\u5DF5\u5DF6\u5DF8\u5DF9\u5DFA\u5DFB\u5DFC\u5DFF\u5E00\u5E04\u5E07\u5E09\u5E0A\u5E0B\u5E0D\u5E0E\u5E12\u5E13\u5E17\u5E1E\u5E1F\u5E20\u5E21\u5E22\u5E23\u5E24\u5E25\u5E28\u5E29\u5E2A\u5E2B\u5E2C\u5E2F\u5E30\u5E32\u5E33\u5E34\u5E35\u5E36\u5E39\u5E3A\u5E3E\u5E3F\u5E40\u5E41\u5E43\u5E46\u5E47\u5E48\u5E49\u5E4A\u5E4B\u5E4D\u5E4E\u5E4F\u5E50\u5E51\u5E52\u5E53\u5E56\u5E57\u5E58\u5E59\u5E5A\u5E5C\u5E5D\u5E5F\u5E60\u5E63\u5E64\u5E65\u5E66\u5E67\u5E68\u5E69\u5E6A\u5E6B\u5E6C\u5E6D\u5E6E\u5E6F\u5E70\u5E71\u5E75\u5E77\u5E79\u5E7E\u5E81\u5E82\u5E83\u5E85\u5E88\u5E89\u5E8C\u5E8D\u5E8E\u5E92\u5E98\u5E9B\u5E9D\u5EA1\u5EA2\u5EA3\u5EA4\u5EA8\u5EA9\u5EAA\u5EAB\u5EAC\u5EAE\u5EAF\u5EB0\u5EB1\u5EB2\u5EB4\u5EBA\u5EBB\u5EBC\u5EBD\u5EBF\u5EC0\u5EC1\u5EC2\u5EC3\u5EC4\u5EC5\uFFFD".split("");
      for (j = 0; j != D[142].length; ++j)
        if (D[142][j].charCodeAt(0) !== 65533) {
          e[D[142][j]] = 36352 + j;
          d[36352 + j] = D[142][j];
        }
      D[143] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5EC6\u5EC7\u5EC8\u5ECB\u5ECC\u5ECD\u5ECE\u5ECF\u5ED0\u5ED4\u5ED5\u5ED7\u5ED8\u5ED9\u5EDA\u5EDC\u5EDD\u5EDE\u5EDF\u5EE0\u5EE1\u5EE2\u5EE3\u5EE4\u5EE5\u5EE6\u5EE7\u5EE9\u5EEB\u5EEC\u5EED\u5EEE\u5EEF\u5EF0\u5EF1\u5EF2\u5EF3\u5EF5\u5EF8\u5EF9\u5EFB\u5EFC\u5EFD\u5F05\u5F06\u5F07\u5F09\u5F0C\u5F0D\u5F0E\u5F10\u5F12\u5F14\u5F16\u5F19\u5F1A\u5F1C\u5F1D\u5F1E\u5F21\u5F22\u5F23\u5F24\uFFFD\u5F28\u5F2B\u5F2C\u5F2E\u5F30\u5F32\u5F33\u5F34\u5F35\u5F36\u5F37\u5F38\u5F3B\u5F3D\u5F3E\u5F3F\u5F41\u5F42\u5F43\u5F44\u5F45\u5F46\u5F47\u5F48\u5F49\u5F4A\u5F4B\u5F4C\u5F4D\u5F4E\u5F4F\u5F51\u5F54\u5F59\u5F5A\u5F5B\u5F5C\u5F5E\u5F5F\u5F60\u5F63\u5F65\u5F67\u5F68\u5F6B\u5F6E\u5F6F\u5F72\u5F74\u5F75\u5F76\u5F78\u5F7A\u5F7D\u5F7E\u5F7F\u5F83\u5F86\u5F8D\u5F8E\u5F8F\u5F91\u5F93\u5F94\u5F96\u5F9A\u5F9B\u5F9D\u5F9E\u5F9F\u5FA0\u5FA2\u5FA3\u5FA4\u5FA5\u5FA6\u5FA7\u5FA9\u5FAB\u5FAC\u5FAF\u5FB0\u5FB1\u5FB2\u5FB3\u5FB4\u5FB6\u5FB8\u5FB9\u5FBA\u5FBB\u5FBE\u5FBF\u5FC0\u5FC1\u5FC2\u5FC7\u5FC8\u5FCA\u5FCB\u5FCE\u5FD3\u5FD4\u5FD5\u5FDA\u5FDB\u5FDC\u5FDE\u5FDF\u5FE2\u5FE3\u5FE5\u5FE6\u5FE8\u5FE9\u5FEC\u5FEF\u5FF0\u5FF2\u5FF3\u5FF4\u5FF6\u5FF7\u5FF9\u5FFA\u5FFC\u6007\uFFFD".split("");
      for (j = 0; j != D[143].length; ++j)
        if (D[143][j].charCodeAt(0) !== 65533) {
          e[D[143][j]] = 36608 + j;
          d[36608 + j] = D[143][j];
        }
      D[144] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6008\u6009\u600B\u600C\u6010\u6011\u6013\u6017\u6018\u601A\u601E\u601F\u6022\u6023\u6024\u602C\u602D\u602E\u6030\u6031\u6032\u6033\u6034\u6036\u6037\u6038\u6039\u603A\u603D\u603E\u6040\u6044\u6045\u6046\u6047\u6048\u6049\u604A\u604C\u604E\u604F\u6051\u6053\u6054\u6056\u6057\u6058\u605B\u605C\u605E\u605F\u6060\u6061\u6065\u6066\u606E\u6071\u6072\u6074\u6075\u6077\u607E\u6080\uFFFD\u6081\u6082\u6085\u6086\u6087\u6088\u608A\u608B\u608E\u608F\u6090\u6091\u6093\u6095\u6097\u6098\u6099\u609C\u609E\u60A1\u60A2\u60A4\u60A5\u60A7\u60A9\u60AA\u60AE\u60B0\u60B3\u60B5\u60B6\u60B7\u60B9\u60BA\u60BD\u60BE\u60BF\u60C0\u60C1\u60C2\u60C3\u60C4\u60C7\u60C8\u60C9\u60CC\u60CD\u60CE\u60CF\u60D0\u60D2\u60D3\u60D4\u60D6\u60D7\u60D9\u60DB\u60DE\u60E1\u60E2\u60E3\u60E4\u60E5\u60EA\u60F1\u60F2\u60F5\u60F7\u60F8\u60FB\u60FC\u60FD\u60FE\u60FF\u6102\u6103\u6104\u6105\u6107\u610A\u610B\u610C\u6110\u6111\u6112\u6113\u6114\u6116\u6117\u6118\u6119\u611B\u611C\u611D\u611E\u6121\u6122\u6125\u6128\u6129\u612A\u612C\u612D\u612E\u612F\u6130\u6131\u6132\u6133\u6134\u6135\u6136\u6137\u6138\u6139\u613A\u613B\u613C\u613D\u613E\u6140\u6141\u6142\u6143\u6144\u6145\u6146\uFFFD".split("");
      for (j = 0; j != D[144].length; ++j)
        if (D[144][j].charCodeAt(0) !== 65533) {
          e[D[144][j]] = 36864 + j;
          d[36864 + j] = D[144][j];
        }
      D[145] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6147\u6149\u614B\u614D\u614F\u6150\u6152\u6153\u6154\u6156\u6157\u6158\u6159\u615A\u615B\u615C\u615E\u615F\u6160\u6161\u6163\u6164\u6165\u6166\u6169\u616A\u616B\u616C\u616D\u616E\u616F\u6171\u6172\u6173\u6174\u6176\u6178\u6179\u617A\u617B\u617C\u617D\u617E\u617F\u6180\u6181\u6182\u6183\u6184\u6185\u6186\u6187\u6188\u6189\u618A\u618C\u618D\u618F\u6190\u6191\u6192\u6193\u6195\uFFFD\u6196\u6197\u6198\u6199\u619A\u619B\u619C\u619E\u619F\u61A0\u61A1\u61A2\u61A3\u61A4\u61A5\u61A6\u61AA\u61AB\u61AD\u61AE\u61AF\u61B0\u61B1\u61B2\u61B3\u61B4\u61B5\u61B6\u61B8\u61B9\u61BA\u61BB\u61BC\u61BD\u61BF\u61C0\u61C1\u61C3\u61C4\u61C5\u61C6\u61C7\u61C9\u61CC\u61CD\u61CE\u61CF\u61D0\u61D3\u61D5\u61D6\u61D7\u61D8\u61D9\u61DA\u61DB\u61DC\u61DD\u61DE\u61DF\u61E0\u61E1\u61E2\u61E3\u61E4\u61E5\u61E7\u61E8\u61E9\u61EA\u61EB\u61EC\u61ED\u61EE\u61EF\u61F0\u61F1\u61F2\u61F3\u61F4\u61F6\u61F7\u61F8\u61F9\u61FA\u61FB\u61FC\u61FD\u61FE\u6200\u6201\u6202\u6203\u6204\u6205\u6207\u6209\u6213\u6214\u6219\u621C\u621D\u621E\u6220\u6223\u6226\u6227\u6228\u6229\u622B\u622D\u622F\u6230\u6231\u6232\u6235\u6236\u6238\u6239\u623A\u623B\u623C\u6242\u6244\u6245\u6246\u624A\uFFFD".split("");
      for (j = 0; j != D[145].length; ++j)
        if (D[145][j].charCodeAt(0) !== 65533) {
          e[D[145][j]] = 37120 + j;
          d[37120 + j] = D[145][j];
        }
      D[146] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u624F\u6250\u6255\u6256\u6257\u6259\u625A\u625C\u625D\u625E\u625F\u6260\u6261\u6262\u6264\u6265\u6268\u6271\u6272\u6274\u6275\u6277\u6278\u627A\u627B\u627D\u6281\u6282\u6283\u6285\u6286\u6287\u6288\u628B\u628C\u628D\u628E\u628F\u6290\u6294\u6299\u629C\u629D\u629E\u62A3\u62A6\u62A7\u62A9\u62AA\u62AD\u62AE\u62AF\u62B0\u62B2\u62B3\u62B4\u62B6\u62B7\u62B8\u62BA\u62BE\u62C0\u62C1\uFFFD\u62C3\u62CB\u62CF\u62D1\u62D5\u62DD\u62DE\u62E0\u62E1\u62E4\u62EA\u62EB\u62F0\u62F2\u62F5\u62F8\u62F9\u62FA\u62FB\u6300\u6303\u6304\u6305\u6306\u630A\u630B\u630C\u630D\u630F\u6310\u6312\u6313\u6314\u6315\u6317\u6318\u6319\u631C\u6326\u6327\u6329\u632C\u632D\u632E\u6330\u6331\u6333\u6334\u6335\u6336\u6337\u6338\u633B\u633C\u633E\u633F\u6340\u6341\u6344\u6347\u6348\u634A\u6351\u6352\u6353\u6354\u6356\u6357\u6358\u6359\u635A\u635B\u635C\u635D\u6360\u6364\u6365\u6366\u6368\u636A\u636B\u636C\u636F\u6370\u6372\u6373\u6374\u6375\u6378\u6379\u637C\u637D\u637E\u637F\u6381\u6383\u6384\u6385\u6386\u638B\u638D\u6391\u6393\u6394\u6395\u6397\u6399\u639A\u639B\u639C\u639D\u639E\u639F\u63A1\u63A4\u63A6\u63AB\u63AF\u63B1\u63B2\u63B5\u63B6\u63B9\u63BB\u63BD\u63BF\u63C0\uFFFD".split("");
      for (j = 0; j != D[146].length; ++j)
        if (D[146][j].charCodeAt(0) !== 65533) {
          e[D[146][j]] = 37376 + j;
          d[37376 + j] = D[146][j];
        }
      D[147] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u63C1\u63C2\u63C3\u63C5\u63C7\u63C8\u63CA\u63CB\u63CC\u63D1\u63D3\u63D4\u63D5\u63D7\u63D8\u63D9\u63DA\u63DB\u63DC\u63DD\u63DF\u63E2\u63E4\u63E5\u63E6\u63E7\u63E8\u63EB\u63EC\u63EE\u63EF\u63F0\u63F1\u63F3\u63F5\u63F7\u63F9\u63FA\u63FB\u63FC\u63FE\u6403\u6404\u6406\u6407\u6408\u6409\u640A\u640D\u640E\u6411\u6412\u6415\u6416\u6417\u6418\u6419\u641A\u641D\u641F\u6422\u6423\u6424\uFFFD\u6425\u6427\u6428\u6429\u642B\u642E\u642F\u6430\u6431\u6432\u6433\u6435\u6436\u6437\u6438\u6439\u643B\u643C\u643E\u6440\u6442\u6443\u6449\u644B\u644C\u644D\u644E\u644F\u6450\u6451\u6453\u6455\u6456\u6457\u6459\u645A\u645B\u645C\u645D\u645F\u6460\u6461\u6462\u6463\u6464\u6465\u6466\u6468\u646A\u646B\u646C\u646E\u646F\u6470\u6471\u6472\u6473\u6474\u6475\u6476\u6477\u647B\u647C\u647D\u647E\u647F\u6480\u6481\u6483\u6486\u6488\u6489\u648A\u648B\u648C\u648D\u648E\u648F\u6490\u6493\u6494\u6497\u6498\u649A\u649B\u649C\u649D\u649F\u64A0\u64A1\u64A2\u64A3\u64A5\u64A6\u64A7\u64A8\u64AA\u64AB\u64AF\u64B1\u64B2\u64B3\u64B4\u64B6\u64B9\u64BB\u64BD\u64BE\u64BF\u64C1\u64C3\u64C4\u64C6\u64C7\u64C8\u64C9\u64CA\u64CB\u64CC\u64CF\u64D1\u64D3\u64D4\u64D5\u64D6\u64D9\u64DA\uFFFD".split("");
      for (j = 0; j != D[147].length; ++j)
        if (D[147][j].charCodeAt(0) !== 65533) {
          e[D[147][j]] = 37632 + j;
          d[37632 + j] = D[147][j];
        }
      D[148] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u64DB\u64DC\u64DD\u64DF\u64E0\u64E1\u64E3\u64E5\u64E7\u64E8\u64E9\u64EA\u64EB\u64EC\u64ED\u64EE\u64EF\u64F0\u64F1\u64F2\u64F3\u64F4\u64F5\u64F6\u64F7\u64F8\u64F9\u64FA\u64FB\u64FC\u64FD\u64FE\u64FF\u6501\u6502\u6503\u6504\u6505\u6506\u6507\u6508\u650A\u650B\u650C\u650D\u650E\u650F\u6510\u6511\u6513\u6514\u6515\u6516\u6517\u6519\u651A\u651B\u651C\u651D\u651E\u651F\u6520\u6521\uFFFD\u6522\u6523\u6524\u6526\u6527\u6528\u6529\u652A\u652C\u652D\u6530\u6531\u6532\u6533\u6537\u653A\u653C\u653D\u6540\u6541\u6542\u6543\u6544\u6546\u6547\u654A\u654B\u654D\u654E\u6550\u6552\u6553\u6554\u6557\u6558\u655A\u655C\u655F\u6560\u6561\u6564\u6565\u6567\u6568\u6569\u656A\u656D\u656E\u656F\u6571\u6573\u6575\u6576\u6578\u6579\u657A\u657B\u657C\u657D\u657E\u657F\u6580\u6581\u6582\u6583\u6584\u6585\u6586\u6588\u6589\u658A\u658D\u658E\u658F\u6592\u6594\u6595\u6596\u6598\u659A\u659D\u659E\u65A0\u65A2\u65A3\u65A6\u65A8\u65AA\u65AC\u65AE\u65B1\u65B2\u65B3\u65B4\u65B5\u65B6\u65B7\u65B8\u65BA\u65BB\u65BE\u65BF\u65C0\u65C2\u65C7\u65C8\u65C9\u65CA\u65CD\u65D0\u65D1\u65D3\u65D4\u65D5\u65D8\u65D9\u65DA\u65DB\u65DC\u65DD\u65DE\u65DF\u65E1\u65E3\u65E4\u65EA\u65EB\uFFFD".split("");
      for (j = 0; j != D[148].length; ++j)
        if (D[148][j].charCodeAt(0) !== 65533) {
          e[D[148][j]] = 37888 + j;
          d[37888 + j] = D[148][j];
        }
      D[149] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u65F2\u65F3\u65F4\u65F5\u65F8\u65F9\u65FB\u65FC\u65FD\u65FE\u65FF\u6601\u6604\u6605\u6607\u6608\u6609\u660B\u660D\u6610\u6611\u6612\u6616\u6617\u6618\u661A\u661B\u661C\u661E\u6621\u6622\u6623\u6624\u6626\u6629\u662A\u662B\u662C\u662E\u6630\u6632\u6633\u6637\u6638\u6639\u663A\u663B\u663D\u663F\u6640\u6642\u6644\u6645\u6646\u6647\u6648\u6649\u664A\u664D\u664E\u6650\u6651\u6658\uFFFD\u6659\u665B\u665C\u665D\u665E\u6660\u6662\u6663\u6665\u6667\u6669\u666A\u666B\u666C\u666D\u6671\u6672\u6673\u6675\u6678\u6679\u667B\u667C\u667D\u667F\u6680\u6681\u6683\u6685\u6686\u6688\u6689\u668A\u668B\u668D\u668E\u668F\u6690\u6692\u6693\u6694\u6695\u6698\u6699\u669A\u669B\u669C\u669E\u669F\u66A0\u66A1\u66A2\u66A3\u66A4\u66A5\u66A6\u66A9\u66AA\u66AB\u66AC\u66AD\u66AF\u66B0\u66B1\u66B2\u66B3\u66B5\u66B6\u66B7\u66B8\u66BA\u66BB\u66BC\u66BD\u66BF\u66C0\u66C1\u66C2\u66C3\u66C4\u66C5\u66C6\u66C7\u66C8\u66C9\u66CA\u66CB\u66CC\u66CD\u66CE\u66CF\u66D0\u66D1\u66D2\u66D3\u66D4\u66D5\u66D6\u66D7\u66D8\u66DA\u66DE\u66DF\u66E0\u66E1\u66E2\u66E3\u66E4\u66E5\u66E7\u66E8\u66EA\u66EB\u66EC\u66ED\u66EE\u66EF\u66F1\u66F5\u66F6\u66F8\u66FA\u66FB\u66FD\u6701\u6702\u6703\uFFFD".split("");
      for (j = 0; j != D[149].length; ++j)
        if (D[149][j].charCodeAt(0) !== 65533) {
          e[D[149][j]] = 38144 + j;
          d[38144 + j] = D[149][j];
        }
      D[150] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6704\u6705\u6706\u6707\u670C\u670E\u670F\u6711\u6712\u6713\u6716\u6718\u6719\u671A\u671C\u671E\u6720\u6721\u6722\u6723\u6724\u6725\u6727\u6729\u672E\u6730\u6732\u6733\u6736\u6737\u6738\u6739\u673B\u673C\u673E\u673F\u6741\u6744\u6745\u6747\u674A\u674B\u674D\u6752\u6754\u6755\u6757\u6758\u6759\u675A\u675B\u675D\u6762\u6763\u6764\u6766\u6767\u676B\u676C\u676E\u6771\u6774\u6776\uFFFD\u6778\u6779\u677A\u677B\u677D\u6780\u6782\u6783\u6785\u6786\u6788\u678A\u678C\u678D\u678E\u678F\u6791\u6792\u6793\u6794\u6796\u6799\u679B\u679F\u67A0\u67A1\u67A4\u67A6\u67A9\u67AC\u67AE\u67B1\u67B2\u67B4\u67B9\u67BA\u67BB\u67BC\u67BD\u67BE\u67BF\u67C0\u67C2\u67C5\u67C6\u67C7\u67C8\u67C9\u67CA\u67CB\u67CC\u67CD\u67CE\u67D5\u67D6\u67D7\u67DB\u67DF\u67E1\u67E3\u67E4\u67E6\u67E7\u67E8\u67EA\u67EB\u67ED\u67EE\u67F2\u67F5\u67F6\u67F7\u67F8\u67F9\u67FA\u67FB\u67FC\u67FE\u6801\u6802\u6803\u6804\u6806\u680D\u6810\u6812\u6814\u6815\u6818\u6819\u681A\u681B\u681C\u681E\u681F\u6820\u6822\u6823\u6824\u6825\u6826\u6827\u6828\u682B\u682C\u682D\u682E\u682F\u6830\u6831\u6834\u6835\u6836\u683A\u683B\u683F\u6847\u684B\u684D\u684F\u6852\u6856\u6857\u6858\u6859\u685A\u685B\uFFFD".split("");
      for (j = 0; j != D[150].length; ++j)
        if (D[150][j].charCodeAt(0) !== 65533) {
          e[D[150][j]] = 38400 + j;
          d[38400 + j] = D[150][j];
        }
      D[151] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u685C\u685D\u685E\u685F\u686A\u686C\u686D\u686E\u686F\u6870\u6871\u6872\u6873\u6875\u6878\u6879\u687A\u687B\u687C\u687D\u687E\u687F\u6880\u6882\u6884\u6887\u6888\u6889\u688A\u688B\u688C\u688D\u688E\u6890\u6891\u6892\u6894\u6895\u6896\u6898\u6899\u689A\u689B\u689C\u689D\u689E\u689F\u68A0\u68A1\u68A3\u68A4\u68A5\u68A9\u68AA\u68AB\u68AC\u68AE\u68B1\u68B2\u68B4\u68B6\u68B7\u68B8\uFFFD\u68B9\u68BA\u68BB\u68BC\u68BD\u68BE\u68BF\u68C1\u68C3\u68C4\u68C5\u68C6\u68C7\u68C8\u68CA\u68CC\u68CE\u68CF\u68D0\u68D1\u68D3\u68D4\u68D6\u68D7\u68D9\u68DB\u68DC\u68DD\u68DE\u68DF\u68E1\u68E2\u68E4\u68E5\u68E6\u68E7\u68E8\u68E9\u68EA\u68EB\u68EC\u68ED\u68EF\u68F2\u68F3\u68F4\u68F6\u68F7\u68F8\u68FB\u68FD\u68FE\u68FF\u6900\u6902\u6903\u6904\u6906\u6907\u6908\u6909\u690A\u690C\u690F\u6911\u6913\u6914\u6915\u6916\u6917\u6918\u6919\u691A\u691B\u691C\u691D\u691E\u6921\u6922\u6923\u6925\u6926\u6927\u6928\u6929\u692A\u692B\u692C\u692E\u692F\u6931\u6932\u6933\u6935\u6936\u6937\u6938\u693A\u693B\u693C\u693E\u6940\u6941\u6943\u6944\u6945\u6946\u6947\u6948\u6949\u694A\u694B\u694C\u694D\u694E\u694F\u6950\u6951\u6952\u6953\u6955\u6956\u6958\u6959\u695B\u695C\u695F\uFFFD".split("");
      for (j = 0; j != D[151].length; ++j)
        if (D[151][j].charCodeAt(0) !== 65533) {
          e[D[151][j]] = 38656 + j;
          d[38656 + j] = D[151][j];
        }
      D[152] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6961\u6962\u6964\u6965\u6967\u6968\u6969\u696A\u696C\u696D\u696F\u6970\u6972\u6973\u6974\u6975\u6976\u697A\u697B\u697D\u697E\u697F\u6981\u6983\u6985\u698A\u698B\u698C\u698E\u698F\u6990\u6991\u6992\u6993\u6996\u6997\u6999\u699A\u699D\u699E\u699F\u69A0\u69A1\u69A2\u69A3\u69A4\u69A5\u69A6\u69A9\u69AA\u69AC\u69AE\u69AF\u69B0\u69B2\u69B3\u69B5\u69B6\u69B8\u69B9\u69BA\u69BC\u69BD\uFFFD\u69BE\u69BF\u69C0\u69C2\u69C3\u69C4\u69C5\u69C6\u69C7\u69C8\u69C9\u69CB\u69CD\u69CF\u69D1\u69D2\u69D3\u69D5\u69D6\u69D7\u69D8\u69D9\u69DA\u69DC\u69DD\u69DE\u69E1\u69E2\u69E3\u69E4\u69E5\u69E6\u69E7\u69E8\u69E9\u69EA\u69EB\u69EC\u69EE\u69EF\u69F0\u69F1\u69F3\u69F4\u69F5\u69F6\u69F7\u69F8\u69F9\u69FA\u69FB\u69FC\u69FE\u6A00\u6A01\u6A02\u6A03\u6A04\u6A05\u6A06\u6A07\u6A08\u6A09\u6A0B\u6A0C\u6A0D\u6A0E\u6A0F\u6A10\u6A11\u6A12\u6A13\u6A14\u6A15\u6A16\u6A19\u6A1A\u6A1B\u6A1C\u6A1D\u6A1E\u6A20\u6A22\u6A23\u6A24\u6A25\u6A26\u6A27\u6A29\u6A2B\u6A2C\u6A2D\u6A2E\u6A30\u6A32\u6A33\u6A34\u6A36\u6A37\u6A38\u6A39\u6A3A\u6A3B\u6A3C\u6A3F\u6A40\u6A41\u6A42\u6A43\u6A45\u6A46\u6A48\u6A49\u6A4A\u6A4B\u6A4C\u6A4D\u6A4E\u6A4F\u6A51\u6A52\u6A53\u6A54\u6A55\u6A56\u6A57\u6A5A\uFFFD".split("");
      for (j = 0; j != D[152].length; ++j)
        if (D[152][j].charCodeAt(0) !== 65533) {
          e[D[152][j]] = 38912 + j;
          d[38912 + j] = D[152][j];
        }
      D[153] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6A5C\u6A5D\u6A5E\u6A5F\u6A60\u6A62\u6A63\u6A64\u6A66\u6A67\u6A68\u6A69\u6A6A\u6A6B\u6A6C\u6A6D\u6A6E\u6A6F\u6A70\u6A72\u6A73\u6A74\u6A75\u6A76\u6A77\u6A78\u6A7A\u6A7B\u6A7D\u6A7E\u6A7F\u6A81\u6A82\u6A83\u6A85\u6A86\u6A87\u6A88\u6A89\u6A8A\u6A8B\u6A8C\u6A8D\u6A8F\u6A92\u6A93\u6A94\u6A95\u6A96\u6A98\u6A99\u6A9A\u6A9B\u6A9C\u6A9D\u6A9E\u6A9F\u6AA1\u6AA2\u6AA3\u6AA4\u6AA5\u6AA6\uFFFD\u6AA7\u6AA8\u6AAA\u6AAD\u6AAE\u6AAF\u6AB0\u6AB1\u6AB2\u6AB3\u6AB4\u6AB5\u6AB6\u6AB7\u6AB8\u6AB9\u6ABA\u6ABB\u6ABC\u6ABD\u6ABE\u6ABF\u6AC0\u6AC1\u6AC2\u6AC3\u6AC4\u6AC5\u6AC6\u6AC7\u6AC8\u6AC9\u6ACA\u6ACB\u6ACC\u6ACD\u6ACE\u6ACF\u6AD0\u6AD1\u6AD2\u6AD3\u6AD4\u6AD5\u6AD6\u6AD7\u6AD8\u6AD9\u6ADA\u6ADB\u6ADC\u6ADD\u6ADE\u6ADF\u6AE0\u6AE1\u6AE2\u6AE3\u6AE4\u6AE5\u6AE6\u6AE7\u6AE8\u6AE9\u6AEA\u6AEB\u6AEC\u6AED\u6AEE\u6AEF\u6AF0\u6AF1\u6AF2\u6AF3\u6AF4\u6AF5\u6AF6\u6AF7\u6AF8\u6AF9\u6AFA\u6AFB\u6AFC\u6AFD\u6AFE\u6AFF\u6B00\u6B01\u6B02\u6B03\u6B04\u6B05\u6B06\u6B07\u6B08\u6B09\u6B0A\u6B0B\u6B0C\u6B0D\u6B0E\u6B0F\u6B10\u6B11\u6B12\u6B13\u6B14\u6B15\u6B16\u6B17\u6B18\u6B19\u6B1A\u6B1B\u6B1C\u6B1D\u6B1E\u6B1F\u6B25\u6B26\u6B28\u6B29\u6B2A\u6B2B\u6B2C\u6B2D\u6B2E\uFFFD".split("");
      for (j = 0; j != D[153].length; ++j)
        if (D[153][j].charCodeAt(0) !== 65533) {
          e[D[153][j]] = 39168 + j;
          d[39168 + j] = D[153][j];
        }
      D[154] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6B2F\u6B30\u6B31\u6B33\u6B34\u6B35\u6B36\u6B38\u6B3B\u6B3C\u6B3D\u6B3F\u6B40\u6B41\u6B42\u6B44\u6B45\u6B48\u6B4A\u6B4B\u6B4D\u6B4E\u6B4F\u6B50\u6B51\u6B52\u6B53\u6B54\u6B55\u6B56\u6B57\u6B58\u6B5A\u6B5B\u6B5C\u6B5D\u6B5E\u6B5F\u6B60\u6B61\u6B68\u6B69\u6B6B\u6B6C\u6B6D\u6B6E\u6B6F\u6B70\u6B71\u6B72\u6B73\u6B74\u6B75\u6B76\u6B77\u6B78\u6B7A\u6B7D\u6B7E\u6B7F\u6B80\u6B85\u6B88\uFFFD\u6B8C\u6B8E\u6B8F\u6B90\u6B91\u6B94\u6B95\u6B97\u6B98\u6B99\u6B9C\u6B9D\u6B9E\u6B9F\u6BA0\u6BA2\u6BA3\u6BA4\u6BA5\u6BA6\u6BA7\u6BA8\u6BA9\u6BAB\u6BAC\u6BAD\u6BAE\u6BAF\u6BB0\u6BB1\u6BB2\u6BB6\u6BB8\u6BB9\u6BBA\u6BBB\u6BBC\u6BBD\u6BBE\u6BC0\u6BC3\u6BC4\u6BC6\u6BC7\u6BC8\u6BC9\u6BCA\u6BCC\u6BCE\u6BD0\u6BD1\u6BD8\u6BDA\u6BDC\u6BDD\u6BDE\u6BDF\u6BE0\u6BE2\u6BE3\u6BE4\u6BE5\u6BE6\u6BE7\u6BE8\u6BE9\u6BEC\u6BED\u6BEE\u6BF0\u6BF1\u6BF2\u6BF4\u6BF6\u6BF7\u6BF8\u6BFA\u6BFB\u6BFC\u6BFE\u6BFF\u6C00\u6C01\u6C02\u6C03\u6C04\u6C08\u6C09\u6C0A\u6C0B\u6C0C\u6C0E\u6C12\u6C17\u6C1C\u6C1D\u6C1E\u6C20\u6C23\u6C25\u6C2B\u6C2C\u6C2D\u6C31\u6C33\u6C36\u6C37\u6C39\u6C3A\u6C3B\u6C3C\u6C3E\u6C3F\u6C43\u6C44\u6C45\u6C48\u6C4B\u6C4C\u6C4D\u6C4E\u6C4F\u6C51\u6C52\u6C53\u6C56\u6C58\uFFFD".split("");
      for (j = 0; j != D[154].length; ++j)
        if (D[154][j].charCodeAt(0) !== 65533) {
          e[D[154][j]] = 39424 + j;
          d[39424 + j] = D[154][j];
        }
      D[155] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6C59\u6C5A\u6C62\u6C63\u6C65\u6C66\u6C67\u6C6B\u6C6C\u6C6D\u6C6E\u6C6F\u6C71\u6C73\u6C75\u6C77\u6C78\u6C7A\u6C7B\u6C7C\u6C7F\u6C80\u6C84\u6C87\u6C8A\u6C8B\u6C8D\u6C8E\u6C91\u6C92\u6C95\u6C96\u6C97\u6C98\u6C9A\u6C9C\u6C9D\u6C9E\u6CA0\u6CA2\u6CA8\u6CAC\u6CAF\u6CB0\u6CB4\u6CB5\u6CB6\u6CB7\u6CBA\u6CC0\u6CC1\u6CC2\u6CC3\u6CC6\u6CC7\u6CC8\u6CCB\u6CCD\u6CCE\u6CCF\u6CD1\u6CD2\u6CD8\uFFFD\u6CD9\u6CDA\u6CDC\u6CDD\u6CDF\u6CE4\u6CE6\u6CE7\u6CE9\u6CEC\u6CED\u6CF2\u6CF4\u6CF9\u6CFF\u6D00\u6D02\u6D03\u6D05\u6D06\u6D08\u6D09\u6D0A\u6D0D\u6D0F\u6D10\u6D11\u6D13\u6D14\u6D15\u6D16\u6D18\u6D1C\u6D1D\u6D1F\u6D20\u6D21\u6D22\u6D23\u6D24\u6D26\u6D28\u6D29\u6D2C\u6D2D\u6D2F\u6D30\u6D34\u6D36\u6D37\u6D38\u6D3A\u6D3F\u6D40\u6D42\u6D44\u6D49\u6D4C\u6D50\u6D55\u6D56\u6D57\u6D58\u6D5B\u6D5D\u6D5F\u6D61\u6D62\u6D64\u6D65\u6D67\u6D68\u6D6B\u6D6C\u6D6D\u6D70\u6D71\u6D72\u6D73\u6D75\u6D76\u6D79\u6D7A\u6D7B\u6D7D\u6D7E\u6D7F\u6D80\u6D81\u6D83\u6D84\u6D86\u6D87\u6D8A\u6D8B\u6D8D\u6D8F\u6D90\u6D92\u6D96\u6D97\u6D98\u6D99\u6D9A\u6D9C\u6DA2\u6DA5\u6DAC\u6DAD\u6DB0\u6DB1\u6DB3\u6DB4\u6DB6\u6DB7\u6DB9\u6DBA\u6DBB\u6DBC\u6DBD\u6DBE\u6DC1\u6DC2\u6DC3\u6DC8\u6DC9\u6DCA\uFFFD".split("");
      for (j = 0; j != D[155].length; ++j)
        if (D[155][j].charCodeAt(0) !== 65533) {
          e[D[155][j]] = 39680 + j;
          d[39680 + j] = D[155][j];
        }
      D[156] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6DCD\u6DCE\u6DCF\u6DD0\u6DD2\u6DD3\u6DD4\u6DD5\u6DD7\u6DDA\u6DDB\u6DDC\u6DDF\u6DE2\u6DE3\u6DE5\u6DE7\u6DE8\u6DE9\u6DEA\u6DED\u6DEF\u6DF0\u6DF2\u6DF4\u6DF5\u6DF6\u6DF8\u6DFA\u6DFD\u6DFE\u6DFF\u6E00\u6E01\u6E02\u6E03\u6E04\u6E06\u6E07\u6E08\u6E09\u6E0B\u6E0F\u6E12\u6E13\u6E15\u6E18\u6E19\u6E1B\u6E1C\u6E1E\u6E1F\u6E22\u6E26\u6E27\u6E28\u6E2A\u6E2C\u6E2E\u6E30\u6E31\u6E33\u6E35\uFFFD\u6E36\u6E37\u6E39\u6E3B\u6E3C\u6E3D\u6E3E\u6E3F\u6E40\u6E41\u6E42\u6E45\u6E46\u6E47\u6E48\u6E49\u6E4A\u6E4B\u6E4C\u6E4F\u6E50\u6E51\u6E52\u6E55\u6E57\u6E59\u6E5A\u6E5C\u6E5D\u6E5E\u6E60\u6E61\u6E62\u6E63\u6E64\u6E65\u6E66\u6E67\u6E68\u6E69\u6E6A\u6E6C\u6E6D\u6E6F\u6E70\u6E71\u6E72\u6E73\u6E74\u6E75\u6E76\u6E77\u6E78\u6E79\u6E7A\u6E7B\u6E7C\u6E7D\u6E80\u6E81\u6E82\u6E84\u6E87\u6E88\u6E8A\u6E8B\u6E8C\u6E8D\u6E8E\u6E91\u6E92\u6E93\u6E94\u6E95\u6E96\u6E97\u6E99\u6E9A\u6E9B\u6E9D\u6E9E\u6EA0\u6EA1\u6EA3\u6EA4\u6EA6\u6EA8\u6EA9\u6EAB\u6EAC\u6EAD\u6EAE\u6EB0\u6EB3\u6EB5\u6EB8\u6EB9\u6EBC\u6EBE\u6EBF\u6EC0\u6EC3\u6EC4\u6EC5\u6EC6\u6EC8\u6EC9\u6ECA\u6ECC\u6ECD\u6ECE\u6ED0\u6ED2\u6ED6\u6ED8\u6ED9\u6EDB\u6EDC\u6EDD\u6EE3\u6EE7\u6EEA\u6EEB\u6EEC\u6EED\u6EEE\u6EEF\uFFFD".split("");
      for (j = 0; j != D[156].length; ++j)
        if (D[156][j].charCodeAt(0) !== 65533) {
          e[D[156][j]] = 39936 + j;
          d[39936 + j] = D[156][j];
        }
      D[157] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6EF0\u6EF1\u6EF2\u6EF3\u6EF5\u6EF6\u6EF7\u6EF8\u6EFA\u6EFB\u6EFC\u6EFD\u6EFE\u6EFF\u6F00\u6F01\u6F03\u6F04\u6F05\u6F07\u6F08\u6F0A\u6F0B\u6F0C\u6F0D\u6F0E\u6F10\u6F11\u6F12\u6F16\u6F17\u6F18\u6F19\u6F1A\u6F1B\u6F1C\u6F1D\u6F1E\u6F1F\u6F21\u6F22\u6F23\u6F25\u6F26\u6F27\u6F28\u6F2C\u6F2E\u6F30\u6F32\u6F34\u6F35\u6F37\u6F38\u6F39\u6F3A\u6F3B\u6F3C\u6F3D\u6F3F\u6F40\u6F41\u6F42\uFFFD\u6F43\u6F44\u6F45\u6F48\u6F49\u6F4A\u6F4C\u6F4E\u6F4F\u6F50\u6F51\u6F52\u6F53\u6F54\u6F55\u6F56\u6F57\u6F59\u6F5A\u6F5B\u6F5D\u6F5F\u6F60\u6F61\u6F63\u6F64\u6F65\u6F67\u6F68\u6F69\u6F6A\u6F6B\u6F6C\u6F6F\u6F70\u6F71\u6F73\u6F75\u6F76\u6F77\u6F79\u6F7B\u6F7D\u6F7E\u6F7F\u6F80\u6F81\u6F82\u6F83\u6F85\u6F86\u6F87\u6F8A\u6F8B\u6F8F\u6F90\u6F91\u6F92\u6F93\u6F94\u6F95\u6F96\u6F97\u6F98\u6F99\u6F9A\u6F9B\u6F9D\u6F9E\u6F9F\u6FA0\u6FA2\u6FA3\u6FA4\u6FA5\u6FA6\u6FA8\u6FA9\u6FAA\u6FAB\u6FAC\u6FAD\u6FAE\u6FAF\u6FB0\u6FB1\u6FB2\u6FB4\u6FB5\u6FB7\u6FB8\u6FBA\u6FBB\u6FBC\u6FBD\u6FBE\u6FBF\u6FC1\u6FC3\u6FC4\u6FC5\u6FC6\u6FC7\u6FC8\u6FCA\u6FCB\u6FCC\u6FCD\u6FCE\u6FCF\u6FD0\u6FD3\u6FD4\u6FD5\u6FD6\u6FD7\u6FD8\u6FD9\u6FDA\u6FDB\u6FDC\u6FDD\u6FDF\u6FE2\u6FE3\u6FE4\u6FE5\uFFFD".split("");
      for (j = 0; j != D[157].length; ++j)
        if (D[157][j].charCodeAt(0) !== 65533) {
          e[D[157][j]] = 40192 + j;
          d[40192 + j] = D[157][j];
        }
      D[158] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6FE6\u6FE7\u6FE8\u6FE9\u6FEA\u6FEB\u6FEC\u6FED\u6FF0\u6FF1\u6FF2\u6FF3\u6FF4\u6FF5\u6FF6\u6FF7\u6FF8\u6FF9\u6FFA\u6FFB\u6FFC\u6FFD\u6FFE\u6FFF\u7000\u7001\u7002\u7003\u7004\u7005\u7006\u7007\u7008\u7009\u700A\u700B\u700C\u700D\u700E\u700F\u7010\u7012\u7013\u7014\u7015\u7016\u7017\u7018\u7019\u701C\u701D\u701E\u701F\u7020\u7021\u7022\u7024\u7025\u7026\u7027\u7028\u7029\u702A\uFFFD\u702B\u702C\u702D\u702E\u702F\u7030\u7031\u7032\u7033\u7034\u7036\u7037\u7038\u703A\u703B\u703C\u703D\u703E\u703F\u7040\u7041\u7042\u7043\u7044\u7045\u7046\u7047\u7048\u7049\u704A\u704B\u704D\u704E\u7050\u7051\u7052\u7053\u7054\u7055\u7056\u7057\u7058\u7059\u705A\u705B\u705C\u705D\u705F\u7060\u7061\u7062\u7063\u7064\u7065\u7066\u7067\u7068\u7069\u706A\u706E\u7071\u7072\u7073\u7074\u7077\u7079\u707A\u707B\u707D\u7081\u7082\u7083\u7084\u7086\u7087\u7088\u708B\u708C\u708D\u708F\u7090\u7091\u7093\u7097\u7098\u709A\u709B\u709E\u709F\u70A0\u70A1\u70A2\u70A3\u70A4\u70A5\u70A6\u70A7\u70A8\u70A9\u70AA\u70B0\u70B2\u70B4\u70B5\u70B6\u70BA\u70BE\u70BF\u70C4\u70C5\u70C6\u70C7\u70C9\u70CB\u70CC\u70CD\u70CE\u70CF\u70D0\u70D1\u70D2\u70D3\u70D4\u70D5\u70D6\u70D7\u70DA\uFFFD".split("");
      for (j = 0; j != D[158].length; ++j)
        if (D[158][j].charCodeAt(0) !== 65533) {
          e[D[158][j]] = 40448 + j;
          d[40448 + j] = D[158][j];
        }
      D[159] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u70DC\u70DD\u70DE\u70E0\u70E1\u70E2\u70E3\u70E5\u70EA\u70EE\u70F0\u70F1\u70F2\u70F3\u70F4\u70F5\u70F6\u70F8\u70FA\u70FB\u70FC\u70FE\u70FF\u7100\u7101\u7102\u7103\u7104\u7105\u7106\u7107\u7108\u710B\u710C\u710D\u710E\u710F\u7111\u7112\u7114\u7117\u711B\u711C\u711D\u711E\u711F\u7120\u7121\u7122\u7123\u7124\u7125\u7127\u7128\u7129\u712A\u712B\u712C\u712D\u712E\u7132\u7133\u7134\uFFFD\u7135\u7137\u7138\u7139\u713A\u713B\u713C\u713D\u713E\u713F\u7140\u7141\u7142\u7143\u7144\u7146\u7147\u7148\u7149\u714B\u714D\u714F\u7150\u7151\u7152\u7153\u7154\u7155\u7156\u7157\u7158\u7159\u715A\u715B\u715D\u715F\u7160\u7161\u7162\u7163\u7165\u7169\u716A\u716B\u716C\u716D\u716F\u7170\u7171\u7174\u7175\u7176\u7177\u7179\u717B\u717C\u717E\u717F\u7180\u7181\u7182\u7183\u7185\u7186\u7187\u7188\u7189\u718B\u718C\u718D\u718E\u7190\u7191\u7192\u7193\u7195\u7196\u7197\u719A\u719B\u719C\u719D\u719E\u71A1\u71A2\u71A3\u71A4\u71A5\u71A6\u71A7\u71A9\u71AA\u71AB\u71AD\u71AE\u71AF\u71B0\u71B1\u71B2\u71B4\u71B6\u71B7\u71B8\u71BA\u71BB\u71BC\u71BD\u71BE\u71BF\u71C0\u71C1\u71C2\u71C4\u71C5\u71C6\u71C7\u71C8\u71C9\u71CA\u71CB\u71CC\u71CD\u71CF\u71D0\u71D1\u71D2\u71D3\uFFFD".split("");
      for (j = 0; j != D[159].length; ++j)
        if (D[159][j].charCodeAt(0) !== 65533) {
          e[D[159][j]] = 40704 + j;
          d[40704 + j] = D[159][j];
        }
      D[160] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u71D6\u71D7\u71D8\u71D9\u71DA\u71DB\u71DC\u71DD\u71DE\u71DF\u71E1\u71E2\u71E3\u71E4\u71E6\u71E8\u71E9\u71EA\u71EB\u71EC\u71ED\u71EF\u71F0\u71F1\u71F2\u71F3\u71F4\u71F5\u71F6\u71F7\u71F8\u71FA\u71FB\u71FC\u71FD\u71FE\u71FF\u7200\u7201\u7202\u7203\u7204\u7205\u7207\u7208\u7209\u720A\u720B\u720C\u720D\u720E\u720F\u7210\u7211\u7212\u7213\u7214\u7215\u7216\u7217\u7218\u7219\u721A\uFFFD\u721B\u721C\u721E\u721F\u7220\u7221\u7222\u7223\u7224\u7225\u7226\u7227\u7229\u722B\u722D\u722E\u722F\u7232\u7233\u7234\u723A\u723C\u723E\u7240\u7241\u7242\u7243\u7244\u7245\u7246\u7249\u724A\u724B\u724E\u724F\u7250\u7251\u7253\u7254\u7255\u7257\u7258\u725A\u725C\u725E\u7260\u7263\u7264\u7265\u7268\u726A\u726B\u726C\u726D\u7270\u7271\u7273\u7274\u7276\u7277\u7278\u727B\u727C\u727D\u7282\u7283\u7285\u7286\u7287\u7288\u7289\u728C\u728E\u7290\u7291\u7293\u7294\u7295\u7296\u7297\u7298\u7299\u729A\u729B\u729C\u729D\u729E\u72A0\u72A1\u72A2\u72A3\u72A4\u72A5\u72A6\u72A7\u72A8\u72A9\u72AA\u72AB\u72AE\u72B1\u72B2\u72B3\u72B5\u72BA\u72BB\u72BC\u72BD\u72BE\u72BF\u72C0\u72C5\u72C6\u72C7\u72C9\u72CA\u72CB\u72CC\u72CF\u72D1\u72D3\u72D4\u72D5\u72D6\u72D8\u72DA\u72DB\uFFFD".split("");
      for (j = 0; j != D[160].length; ++j)
        if (D[160][j].charCodeAt(0) !== 65533) {
          e[D[160][j]] = 40960 + j;
          d[40960 + j] = D[160][j];
        }
      D[161] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3000\u3001\u3002\xB7\u02C9\u02C7\xA8\u3003\u3005\u2014\uFF5E\u2016\u2026\u2018\u2019\u201C\u201D\u3014\u3015\u3008\u3009\u300A\u300B\u300C\u300D\u300E\u300F\u3016\u3017\u3010\u3011\xB1\xD7\xF7\u2236\u2227\u2228\u2211\u220F\u222A\u2229\u2208\u2237\u221A\u22A5\u2225\u2220\u2312\u2299\u222B\u222E\u2261\u224C\u2248\u223D\u221D\u2260\u226E\u226F\u2264\u2265\u221E\u2235\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFF04\xA4\uFFE0\uFFE1\u2030\xA7\u2116\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u203B\u2192\u2190\u2191\u2193\u3013\uFFFD".split("");
      for (j = 0; j != D[161].length; ++j)
        if (D[161][j].charCodeAt(0) !== 65533) {
          e[D[161][j]] = 41216 + j;
          d[41216 + j] = D[161][j];
        }
      D[162] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2170\u2171\u2172\u2173\u2174\u2175\u2176\u2177\u2178\u2179\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2488\u2489\u248A\u248B\u248C\u248D\u248E\u248F\u2490\u2491\u2492\u2493\u2494\u2495\u2496\u2497\u2498\u2499\u249A\u249B\u2474\u2475\u2476\u2477\u2478\u2479\u247A\u247B\u247C\u247D\u247E\u247F\u2480\u2481\u2482\u2483\u2484\u2485\u2486\u2487\u2460\u2461\u2462\u2463\u2464\u2465\u2466\u2467\u2468\u2469\uFFFD\uFFFD\u3220\u3221\u3222\u3223\u3224\u3225\u3226\u3227\u3228\u3229\uFFFD\uFFFD\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\u216A\u216B\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[162].length; ++j)
        if (D[162][j].charCodeAt(0) !== 65533) {
          e[D[162][j]] = 41472 + j;
          d[41472 + j] = D[162][j];
        }
      D[163] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF01\uFF02\uFF03\uFFE5\uFF05\uFF06\uFF07\uFF08\uFF09\uFF0A\uFF0B\uFF0C\uFF0D\uFF0E\uFF0F\uFF10\uFF11\uFF12\uFF13\uFF14\uFF15\uFF16\uFF17\uFF18\uFF19\uFF1A\uFF1B\uFF1C\uFF1D\uFF1E\uFF1F\uFF20\uFF21\uFF22\uFF23\uFF24\uFF25\uFF26\uFF27\uFF28\uFF29\uFF2A\uFF2B\uFF2C\uFF2D\uFF2E\uFF2F\uFF30\uFF31\uFF32\uFF33\uFF34\uFF35\uFF36\uFF37\uFF38\uFF39\uFF3A\uFF3B\uFF3C\uFF3D\uFF3E\uFF3F\uFF40\uFF41\uFF42\uFF43\uFF44\uFF45\uFF46\uFF47\uFF48\uFF49\uFF4A\uFF4B\uFF4C\uFF4D\uFF4E\uFF4F\uFF50\uFF51\uFF52\uFF53\uFF54\uFF55\uFF56\uFF57\uFF58\uFF59\uFF5A\uFF5B\uFF5C\uFF5D\uFFE3\uFFFD".split("");
      for (j = 0; j != D[163].length; ++j)
        if (D[163][j].charCodeAt(0) !== 65533) {
          e[D[163][j]] = 41728 + j;
          d[41728 + j] = D[163][j];
        }
      D[164] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3041\u3042\u3043\u3044\u3045\u3046\u3047\u3048\u3049\u304A\u304B\u304C\u304D\u304E\u304F\u3050\u3051\u3052\u3053\u3054\u3055\u3056\u3057\u3058\u3059\u305A\u305B\u305C\u305D\u305E\u305F\u3060\u3061\u3062\u3063\u3064\u3065\u3066\u3067\u3068\u3069\u306A\u306B\u306C\u306D\u306E\u306F\u3070\u3071\u3072\u3073\u3074\u3075\u3076\u3077\u3078\u3079\u307A\u307B\u307C\u307D\u307E\u307F\u3080\u3081\u3082\u3083\u3084\u3085\u3086\u3087\u3088\u3089\u308A\u308B\u308C\u308D\u308E\u308F\u3090\u3091\u3092\u3093\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[164].length; ++j)
        if (D[164][j].charCodeAt(0) !== 65533) {
          e[D[164][j]] = 41984 + j;
          d[41984 + j] = D[164][j];
        }
      D[165] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u30A1\u30A2\u30A3\u30A4\u30A5\u30A6\u30A7\u30A8\u30A9\u30AA\u30AB\u30AC\u30AD\u30AE\u30AF\u30B0\u30B1\u30B2\u30B3\u30B4\u30B5\u30B6\u30B7\u30B8\u30B9\u30BA\u30BB\u30BC\u30BD\u30BE\u30BF\u30C0\u30C1\u30C2\u30C3\u30C4\u30C5\u30C6\u30C7\u30C8\u30C9\u30CA\u30CB\u30CC\u30CD\u30CE\u30CF\u30D0\u30D1\u30D2\u30D3\u30D4\u30D5\u30D6\u30D7\u30D8\u30D9\u30DA\u30DB\u30DC\u30DD\u30DE\u30DF\u30E0\u30E1\u30E2\u30E3\u30E4\u30E5\u30E6\u30E7\u30E8\u30E9\u30EA\u30EB\u30EC\u30ED\u30EE\u30EF\u30F0\u30F1\u30F2\u30F3\u30F4\u30F5\u30F6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[165].length; ++j)
        if (D[165][j].charCodeAt(0) !== 65533) {
          e[D[165][j]] = 42240 + j;
          d[42240 + j] = D[165][j];
        }
      D[166] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFE35\uFE36\uFE39\uFE3A\uFE3F\uFE40\uFE3D\uFE3E\uFE41\uFE42\uFE43\uFE44\uFFFD\uFFFD\uFE3B\uFE3C\uFE37\uFE38\uFE31\uFFFD\uFE33\uFE34\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[166].length; ++j)
        if (D[166][j].charCodeAt(0) !== 65533) {
          e[D[166][j]] = 42496 + j;
          d[42496 + j] = D[166][j];
        }
      D[167] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0410\u0411\u0412\u0413\u0414\u0415\u0401\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0430\u0431\u0432\u0433\u0434\u0435\u0451\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[167].length; ++j)
        if (D[167][j].charCodeAt(0) !== 65533) {
          e[D[167][j]] = 42752 + j;
          d[42752 + j] = D[167][j];
        }
      D[168] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u02CA\u02CB\u02D9\u2013\u2015\u2025\u2035\u2105\u2109\u2196\u2197\u2198\u2199\u2215\u221F\u2223\u2252\u2266\u2267\u22BF\u2550\u2551\u2552\u2553\u2554\u2555\u2556\u2557\u2558\u2559\u255A\u255B\u255C\u255D\u255E\u255F\u2560\u2561\u2562\u2563\u2564\u2565\u2566\u2567\u2568\u2569\u256A\u256B\u256C\u256D\u256E\u256F\u2570\u2571\u2572\u2573\u2581\u2582\u2583\u2584\u2585\u2586\u2587\uFFFD\u2588\u2589\u258A\u258B\u258C\u258D\u258E\u258F\u2593\u2594\u2595\u25BC\u25BD\u25E2\u25E3\u25E4\u25E5\u2609\u2295\u3012\u301D\u301E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0101\xE1\u01CE\xE0\u0113\xE9\u011B\xE8\u012B\xED\u01D0\xEC\u014D\xF3\u01D2\xF2\u016B\xFA\u01D4\xF9\u01D6\u01D8\u01DA\u01DC\xFC\xEA\u0251\uFFFD\u0144\u0148\uFFFD\u0261\uFFFD\uFFFD\uFFFD\uFFFD\u3105\u3106\u3107\u3108\u3109\u310A\u310B\u310C\u310D\u310E\u310F\u3110\u3111\u3112\u3113\u3114\u3115\u3116\u3117\u3118\u3119\u311A\u311B\u311C\u311D\u311E\u311F\u3120\u3121\u3122\u3123\u3124\u3125\u3126\u3127\u3128\u3129\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[168].length; ++j)
        if (D[168][j].charCodeAt(0) !== 65533) {
          e[D[168][j]] = 43008 + j;
          d[43008 + j] = D[168][j];
        }
      D[169] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3021\u3022\u3023\u3024\u3025\u3026\u3027\u3028\u3029\u32A3\u338E\u338F\u339C\u339D\u339E\u33A1\u33C4\u33CE\u33D1\u33D2\u33D5\uFE30\uFFE2\uFFE4\uFFFD\u2121\u3231\uFFFD\u2010\uFFFD\uFFFD\uFFFD\u30FC\u309B\u309C\u30FD\u30FE\u3006\u309D\u309E\uFE49\uFE4A\uFE4B\uFE4C\uFE4D\uFE4E\uFE4F\uFE50\uFE51\uFE52\uFE54\uFE55\uFE56\uFE57\uFE59\uFE5A\uFE5B\uFE5C\uFE5D\uFE5E\uFE5F\uFE60\uFE61\uFFFD\uFE62\uFE63\uFE64\uFE65\uFE66\uFE68\uFE69\uFE6A\uFE6B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3007\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2500\u2501\u2502\u2503\u2504\u2505\u2506\u2507\u2508\u2509\u250A\u250B\u250C\u250D\u250E\u250F\u2510\u2511\u2512\u2513\u2514\u2515\u2516\u2517\u2518\u2519\u251A\u251B\u251C\u251D\u251E\u251F\u2520\u2521\u2522\u2523\u2524\u2525\u2526\u2527\u2528\u2529\u252A\u252B\u252C\u252D\u252E\u252F\u2530\u2531\u2532\u2533\u2534\u2535\u2536\u2537\u2538\u2539\u253A\u253B\u253C\u253D\u253E\u253F\u2540\u2541\u2542\u2543\u2544\u2545\u2546\u2547\u2548\u2549\u254A\u254B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[169].length; ++j)
        if (D[169][j].charCodeAt(0) !== 65533) {
          e[D[169][j]] = 43264 + j;
          d[43264 + j] = D[169][j];
        }
      D[170] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u72DC\u72DD\u72DF\u72E2\u72E3\u72E4\u72E5\u72E6\u72E7\u72EA\u72EB\u72F5\u72F6\u72F9\u72FD\u72FE\u72FF\u7300\u7302\u7304\u7305\u7306\u7307\u7308\u7309\u730B\u730C\u730D\u730F\u7310\u7311\u7312\u7314\u7318\u7319\u731A\u731F\u7320\u7323\u7324\u7326\u7327\u7328\u732D\u732F\u7330\u7332\u7333\u7335\u7336\u733A\u733B\u733C\u733D\u7340\u7341\u7342\u7343\u7344\u7345\u7346\u7347\u7348\uFFFD\u7349\u734A\u734B\u734C\u734E\u734F\u7351\u7353\u7354\u7355\u7356\u7358\u7359\u735A\u735B\u735C\u735D\u735E\u735F\u7361\u7362\u7363\u7364\u7365\u7366\u7367\u7368\u7369\u736A\u736B\u736E\u7370\u7371\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[170].length; ++j)
        if (D[170][j].charCodeAt(0) !== 65533) {
          e[D[170][j]] = 43520 + j;
          d[43520 + j] = D[170][j];
        }
      D[171] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7372\u7373\u7374\u7375\u7376\u7377\u7378\u7379\u737A\u737B\u737C\u737D\u737F\u7380\u7381\u7382\u7383\u7385\u7386\u7388\u738A\u738C\u738D\u738F\u7390\u7392\u7393\u7394\u7395\u7397\u7398\u7399\u739A\u739C\u739D\u739E\u73A0\u73A1\u73A3\u73A4\u73A5\u73A6\u73A7\u73A8\u73AA\u73AC\u73AD\u73B1\u73B4\u73B5\u73B6\u73B8\u73B9\u73BC\u73BD\u73BE\u73BF\u73C1\u73C3\u73C4\u73C5\u73C6\u73C7\uFFFD\u73CB\u73CC\u73CE\u73D2\u73D3\u73D4\u73D5\u73D6\u73D7\u73D8\u73DA\u73DB\u73DC\u73DD\u73DF\u73E1\u73E2\u73E3\u73E4\u73E6\u73E8\u73EA\u73EB\u73EC\u73EE\u73EF\u73F0\u73F1\u73F3\u73F4\u73F5\u73F6\u73F7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[171].length; ++j)
        if (D[171][j].charCodeAt(0) !== 65533) {
          e[D[171][j]] = 43776 + j;
          d[43776 + j] = D[171][j];
        }
      D[172] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u73F8\u73F9\u73FA\u73FB\u73FC\u73FD\u73FE\u73FF\u7400\u7401\u7402\u7404\u7407\u7408\u740B\u740C\u740D\u740E\u7411\u7412\u7413\u7414\u7415\u7416\u7417\u7418\u7419\u741C\u741D\u741E\u741F\u7420\u7421\u7423\u7424\u7427\u7429\u742B\u742D\u742F\u7431\u7432\u7437\u7438\u7439\u743A\u743B\u743D\u743E\u743F\u7440\u7442\u7443\u7444\u7445\u7446\u7447\u7448\u7449\u744A\u744B\u744C\u744D\uFFFD\u744E\u744F\u7450\u7451\u7452\u7453\u7454\u7456\u7458\u745D\u7460\u7461\u7462\u7463\u7464\u7465\u7466\u7467\u7468\u7469\u746A\u746B\u746C\u746E\u746F\u7471\u7472\u7473\u7474\u7475\u7478\u7479\u747A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[172].length; ++j)
        if (D[172][j].charCodeAt(0) !== 65533) {
          e[D[172][j]] = 44032 + j;
          d[44032 + j] = D[172][j];
        }
      D[173] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u747B\u747C\u747D\u747F\u7482\u7484\u7485\u7486\u7488\u7489\u748A\u748C\u748D\u748F\u7491\u7492\u7493\u7494\u7495\u7496\u7497\u7498\u7499\u749A\u749B\u749D\u749F\u74A0\u74A1\u74A2\u74A3\u74A4\u74A5\u74A6\u74AA\u74AB\u74AC\u74AD\u74AE\u74AF\u74B0\u74B1\u74B2\u74B3\u74B4\u74B5\u74B6\u74B7\u74B8\u74B9\u74BB\u74BC\u74BD\u74BE\u74BF\u74C0\u74C1\u74C2\u74C3\u74C4\u74C5\u74C6\u74C7\uFFFD\u74C8\u74C9\u74CA\u74CB\u74CC\u74CD\u74CE\u74CF\u74D0\u74D1\u74D3\u74D4\u74D5\u74D6\u74D7\u74D8\u74D9\u74DA\u74DB\u74DD\u74DF\u74E1\u74E5\u74E7\u74E8\u74E9\u74EA\u74EB\u74EC\u74ED\u74F0\u74F1\u74F2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[173].length; ++j)
        if (D[173][j].charCodeAt(0) !== 65533) {
          e[D[173][j]] = 44288 + j;
          d[44288 + j] = D[173][j];
        }
      D[174] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u74F3\u74F5\u74F8\u74F9\u74FA\u74FB\u74FC\u74FD\u74FE\u7500\u7501\u7502\u7503\u7505\u7506\u7507\u7508\u7509\u750A\u750B\u750C\u750E\u7510\u7512\u7514\u7515\u7516\u7517\u751B\u751D\u751E\u7520\u7521\u7522\u7523\u7524\u7526\u7527\u752A\u752E\u7534\u7536\u7539\u753C\u753D\u753F\u7541\u7542\u7543\u7544\u7546\u7547\u7549\u754A\u754D\u7550\u7551\u7552\u7553\u7555\u7556\u7557\u7558\uFFFD\u755D\u755E\u755F\u7560\u7561\u7562\u7563\u7564\u7567\u7568\u7569\u756B\u756C\u756D\u756E\u756F\u7570\u7571\u7573\u7575\u7576\u7577\u757A\u757B\u757C\u757D\u757E\u7580\u7581\u7582\u7584\u7585\u7587\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[174].length; ++j)
        if (D[174][j].charCodeAt(0) !== 65533) {
          e[D[174][j]] = 44544 + j;
          d[44544 + j] = D[174][j];
        }
      D[175] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7588\u7589\u758A\u758C\u758D\u758E\u7590\u7593\u7595\u7598\u759B\u759C\u759E\u75A2\u75A6\u75A7\u75A8\u75A9\u75AA\u75AD\u75B6\u75B7\u75BA\u75BB\u75BF\u75C0\u75C1\u75C6\u75CB\u75CC\u75CE\u75CF\u75D0\u75D1\u75D3\u75D7\u75D9\u75DA\u75DC\u75DD\u75DF\u75E0\u75E1\u75E5\u75E9\u75EC\u75ED\u75EE\u75EF\u75F2\u75F3\u75F5\u75F6\u75F7\u75F8\u75FA\u75FB\u75FD\u75FE\u7602\u7604\u7606\u7607\uFFFD\u7608\u7609\u760B\u760D\u760E\u760F\u7611\u7612\u7613\u7614\u7616\u761A\u761C\u761D\u761E\u7621\u7623\u7627\u7628\u762C\u762E\u762F\u7631\u7632\u7636\u7637\u7639\u763A\u763B\u763D\u7641\u7642\u7644\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[175].length; ++j)
        if (D[175][j].charCodeAt(0) !== 65533) {
          e[D[175][j]] = 44800 + j;
          d[44800 + j] = D[175][j];
        }
      D[176] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7645\u7646\u7647\u7648\u7649\u764A\u764B\u764E\u764F\u7650\u7651\u7652\u7653\u7655\u7657\u7658\u7659\u765A\u765B\u765D\u765F\u7660\u7661\u7662\u7664\u7665\u7666\u7667\u7668\u7669\u766A\u766C\u766D\u766E\u7670\u7671\u7672\u7673\u7674\u7675\u7676\u7677\u7679\u767A\u767C\u767F\u7680\u7681\u7683\u7685\u7689\u768A\u768C\u768D\u768F\u7690\u7692\u7694\u7695\u7697\u7698\u769A\u769B\uFFFD\u769C\u769D\u769E\u769F\u76A0\u76A1\u76A2\u76A3\u76A5\u76A6\u76A7\u76A8\u76A9\u76AA\u76AB\u76AC\u76AD\u76AF\u76B0\u76B3\u76B5\u76B6\u76B7\u76B8\u76B9\u76BA\u76BB\u76BC\u76BD\u76BE\u76C0\u76C1\u76C3\u554A\u963F\u57C3\u6328\u54CE\u5509\u54C0\u7691\u764C\u853C\u77EE\u827E\u788D\u7231\u9698\u978D\u6C28\u5B89\u4FFA\u6309\u6697\u5CB8\u80FA\u6848\u80AE\u6602\u76CE\u51F9\u6556\u71AC\u7FF1\u8884\u50B2\u5965\u61CA\u6FB3\u82AD\u634C\u6252\u53ED\u5427\u7B06\u516B\u75A4\u5DF4\u62D4\u8DCB\u9776\u628A\u8019\u575D\u9738\u7F62\u7238\u767D\u67CF\u767E\u6446\u4F70\u8D25\u62DC\u7A17\u6591\u73ED\u642C\u6273\u822C\u9881\u677F\u7248\u626E\u62CC\u4F34\u74E3\u534A\u529E\u7ECA\u90A6\u5E2E\u6886\u699C\u8180\u7ED1\u68D2\u78C5\u868C\u9551\u508D\u8C24\u82DE\u80DE\u5305\u8912\u5265\uFFFD".split("");
      for (j = 0; j != D[176].length; ++j)
        if (D[176][j].charCodeAt(0) !== 65533) {
          e[D[176][j]] = 45056 + j;
          d[45056 + j] = D[176][j];
        }
      D[177] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u76C4\u76C7\u76C9\u76CB\u76CC\u76D3\u76D5\u76D9\u76DA\u76DC\u76DD\u76DE\u76E0\u76E1\u76E2\u76E3\u76E4\u76E6\u76E7\u76E8\u76E9\u76EA\u76EB\u76EC\u76ED\u76F0\u76F3\u76F5\u76F6\u76F7\u76FA\u76FB\u76FD\u76FF\u7700\u7702\u7703\u7705\u7706\u770A\u770C\u770E\u770F\u7710\u7711\u7712\u7713\u7714\u7715\u7716\u7717\u7718\u771B\u771C\u771D\u771E\u7721\u7723\u7724\u7725\u7727\u772A\u772B\uFFFD\u772C\u772E\u7730\u7731\u7732\u7733\u7734\u7739\u773B\u773D\u773E\u773F\u7742\u7744\u7745\u7746\u7748\u7749\u774A\u774B\u774C\u774D\u774E\u774F\u7752\u7753\u7754\u7755\u7756\u7757\u7758\u7759\u775C\u8584\u96F9\u4FDD\u5821\u9971\u5B9D\u62B1\u62A5\u66B4\u8C79\u9C8D\u7206\u676F\u7891\u60B2\u5351\u5317\u8F88\u80CC\u8D1D\u94A1\u500D\u72C8\u5907\u60EB\u7119\u88AB\u5954\u82EF\u672C\u7B28\u5D29\u7EF7\u752D\u6CF5\u8E66\u8FF8\u903C\u9F3B\u6BD4\u9119\u7B14\u5F7C\u78A7\u84D6\u853D\u6BD5\u6BD9\u6BD6\u5E01\u5E87\u75F9\u95ED\u655D\u5F0A\u5FC5\u8F9F\u58C1\u81C2\u907F\u965B\u97AD\u8FB9\u7F16\u8D2C\u6241\u4FBF\u53D8\u535E\u8FA8\u8FA9\u8FAB\u904D\u6807\u5F6A\u8198\u8868\u9CD6\u618B\u522B\u762A\u5F6C\u658C\u6FD2\u6EE8\u5BBE\u6448\u5175\u51B0\u67C4\u4E19\u79C9\u997C\u70B3\uFFFD".split("");
      for (j = 0; j != D[177].length; ++j)
        if (D[177][j].charCodeAt(0) !== 65533) {
          e[D[177][j]] = 45312 + j;
          d[45312 + j] = D[177][j];
        }
      D[178] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u775D\u775E\u775F\u7760\u7764\u7767\u7769\u776A\u776D\u776E\u776F\u7770\u7771\u7772\u7773\u7774\u7775\u7776\u7777\u7778\u777A\u777B\u777C\u7781\u7782\u7783\u7786\u7787\u7788\u7789\u778A\u778B\u778F\u7790\u7793\u7794\u7795\u7796\u7797\u7798\u7799\u779A\u779B\u779C\u779D\u779E\u77A1\u77A3\u77A4\u77A6\u77A8\u77AB\u77AD\u77AE\u77AF\u77B1\u77B2\u77B4\u77B6\u77B7\u77B8\u77B9\u77BA\uFFFD\u77BC\u77BE\u77C0\u77C1\u77C2\u77C3\u77C4\u77C5\u77C6\u77C7\u77C8\u77C9\u77CA\u77CB\u77CC\u77CE\u77CF\u77D0\u77D1\u77D2\u77D3\u77D4\u77D5\u77D6\u77D8\u77D9\u77DA\u77DD\u77DE\u77DF\u77E0\u77E1\u77E4\u75C5\u5E76\u73BB\u83E0\u64AD\u62E8\u94B5\u6CE2\u535A\u52C3\u640F\u94C2\u7B94\u4F2F\u5E1B\u8236\u8116\u818A\u6E24\u6CCA\u9A73\u6355\u535C\u54FA\u8865\u57E0\u4E0D\u5E03\u6B65\u7C3F\u90E8\u6016\u64E6\u731C\u88C1\u6750\u624D\u8D22\u776C\u8E29\u91C7\u5F69\u83DC\u8521\u9910\u53C2\u8695\u6B8B\u60ED\u60E8\u707F\u82CD\u8231\u4ED3\u6CA7\u85CF\u64CD\u7CD9\u69FD\u66F9\u8349\u5395\u7B56\u4FA7\u518C\u6D4B\u5C42\u8E6D\u63D2\u53C9\u832C\u8336\u67E5\u78B4\u643D\u5BDF\u5C94\u5DEE\u8BE7\u62C6\u67F4\u8C7A\u6400\u63BA\u8749\u998B\u8C17\u7F20\u94F2\u4EA7\u9610\u98A4\u660C\u7316\uFFFD".split("");
      for (j = 0; j != D[178].length; ++j)
        if (D[178][j].charCodeAt(0) !== 65533) {
          e[D[178][j]] = 45568 + j;
          d[45568 + j] = D[178][j];
        }
      D[179] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u77E6\u77E8\u77EA\u77EF\u77F0\u77F1\u77F2\u77F4\u77F5\u77F7\u77F9\u77FA\u77FB\u77FC\u7803\u7804\u7805\u7806\u7807\u7808\u780A\u780B\u780E\u780F\u7810\u7813\u7815\u7819\u781B\u781E\u7820\u7821\u7822\u7824\u7828\u782A\u782B\u782E\u782F\u7831\u7832\u7833\u7835\u7836\u783D\u783F\u7841\u7842\u7843\u7844\u7846\u7848\u7849\u784A\u784B\u784D\u784F\u7851\u7853\u7854\u7858\u7859\u785A\uFFFD\u785B\u785C\u785E\u785F\u7860\u7861\u7862\u7863\u7864\u7865\u7866\u7867\u7868\u7869\u786F\u7870\u7871\u7872\u7873\u7874\u7875\u7876\u7878\u7879\u787A\u787B\u787D\u787E\u787F\u7880\u7881\u7882\u7883\u573A\u5C1D\u5E38\u957F\u507F\u80A0\u5382\u655E\u7545\u5531\u5021\u8D85\u6284\u949E\u671D\u5632\u6F6E\u5DE2\u5435\u7092\u8F66\u626F\u64A4\u63A3\u5F7B\u6F88\u90F4\u81E3\u8FB0\u5C18\u6668\u5FF1\u6C89\u9648\u8D81\u886C\u6491\u79F0\u57CE\u6A59\u6210\u5448\u4E58\u7A0B\u60E9\u6F84\u8BDA\u627F\u901E\u9A8B\u79E4\u5403\u75F4\u6301\u5319\u6C60\u8FDF\u5F1B\u9A70\u803B\u9F7F\u4F88\u5C3A\u8D64\u7FC5\u65A5\u70BD\u5145\u51B2\u866B\u5D07\u5BA0\u62BD\u916C\u7574\u8E0C\u7A20\u6101\u7B79\u4EC7\u7EF8\u7785\u4E11\u81ED\u521D\u51FA\u6A71\u53A8\u8E87\u9504\u96CF\u6EC1\u9664\u695A\uFFFD".split("");
      for (j = 0; j != D[179].length; ++j)
        if (D[179][j].charCodeAt(0) !== 65533) {
          e[D[179][j]] = 45824 + j;
          d[45824 + j] = D[179][j];
        }
      D[180] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7884\u7885\u7886\u7888\u788A\u788B\u788F\u7890\u7892\u7894\u7895\u7896\u7899\u789D\u789E\u78A0\u78A2\u78A4\u78A6\u78A8\u78A9\u78AA\u78AB\u78AC\u78AD\u78AE\u78AF\u78B5\u78B6\u78B7\u78B8\u78BA\u78BB\u78BC\u78BD\u78BF\u78C0\u78C2\u78C3\u78C4\u78C6\u78C7\u78C8\u78CC\u78CD\u78CE\u78CF\u78D1\u78D2\u78D3\u78D6\u78D7\u78D8\u78DA\u78DB\u78DC\u78DD\u78DE\u78DF\u78E0\u78E1\u78E2\u78E3\uFFFD\u78E4\u78E5\u78E6\u78E7\u78E9\u78EA\u78EB\u78ED\u78EE\u78EF\u78F0\u78F1\u78F3\u78F5\u78F6\u78F8\u78F9\u78FB\u78FC\u78FD\u78FE\u78FF\u7900\u7902\u7903\u7904\u7906\u7907\u7908\u7909\u790A\u790B\u790C\u7840\u50A8\u77D7\u6410\u89E6\u5904\u63E3\u5DDD\u7A7F\u693D\u4F20\u8239\u5598\u4E32\u75AE\u7A97\u5E62\u5E8A\u95EF\u521B\u5439\u708A\u6376\u9524\u5782\u6625\u693F\u9187\u5507\u6DF3\u7EAF\u8822\u6233\u7EF0\u75B5\u8328\u78C1\u96CC\u8F9E\u6148\u74F7\u8BCD\u6B64\u523A\u8D50\u6B21\u806A\u8471\u56F1\u5306\u4ECE\u4E1B\u51D1\u7C97\u918B\u7C07\u4FC3\u8E7F\u7BE1\u7A9C\u6467\u5D14\u50AC\u8106\u7601\u7CB9\u6DEC\u7FE0\u6751\u5B58\u5BF8\u78CB\u64AE\u6413\u63AA\u632B\u9519\u642D\u8FBE\u7B54\u7629\u6253\u5927\u5446\u6B79\u50A3\u6234\u5E26\u6B86\u4EE3\u8D37\u888B\u5F85\u902E\uFFFD".split("");
      for (j = 0; j != D[180].length; ++j)
        if (D[180][j].charCodeAt(0) !== 65533) {
          e[D[180][j]] = 46080 + j;
          d[46080 + j] = D[180][j];
        }
      D[181] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u790D\u790E\u790F\u7910\u7911\u7912\u7914\u7915\u7916\u7917\u7918\u7919\u791A\u791B\u791C\u791D\u791F\u7920\u7921\u7922\u7923\u7925\u7926\u7927\u7928\u7929\u792A\u792B\u792C\u792D\u792E\u792F\u7930\u7931\u7932\u7933\u7935\u7936\u7937\u7938\u7939\u793D\u793F\u7942\u7943\u7944\u7945\u7947\u794A\u794B\u794C\u794D\u794E\u794F\u7950\u7951\u7952\u7954\u7955\u7958\u7959\u7961\u7963\uFFFD\u7964\u7966\u7969\u796A\u796B\u796C\u796E\u7970\u7971\u7972\u7973\u7974\u7975\u7976\u7979\u797B\u797C\u797D\u797E\u797F\u7982\u7983\u7986\u7987\u7988\u7989\u798B\u798C\u798D\u798E\u7990\u7991\u7992\u6020\u803D\u62C5\u4E39\u5355\u90F8\u63B8\u80C6\u65E6\u6C2E\u4F46\u60EE\u6DE1\u8BDE\u5F39\u86CB\u5F53\u6321\u515A\u8361\u6863\u5200\u6363\u8E48\u5012\u5C9B\u7977\u5BFC\u5230\u7A3B\u60BC\u9053\u76D7\u5FB7\u5F97\u7684\u8E6C\u706F\u767B\u7B49\u77AA\u51F3\u9093\u5824\u4F4E\u6EF4\u8FEA\u654C\u7B1B\u72C4\u6DA4\u7FDF\u5AE1\u62B5\u5E95\u5730\u8482\u7B2C\u5E1D\u5F1F\u9012\u7F14\u98A0\u6382\u6EC7\u7898\u70B9\u5178\u975B\u57AB\u7535\u4F43\u7538\u5E97\u60E6\u5960\u6DC0\u6BBF\u7889\u53FC\u96D5\u51CB\u5201\u6389\u540A\u9493\u8C03\u8DCC\u7239\u789F\u8776\u8FED\u8C0D\u53E0\uFFFD".split("");
      for (j = 0; j != D[181].length; ++j)
        if (D[181][j].charCodeAt(0) !== 65533) {
          e[D[181][j]] = 46336 + j;
          d[46336 + j] = D[181][j];
        }
      D[182] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7993\u7994\u7995\u7996\u7997\u7998\u7999\u799B\u799C\u799D\u799E\u799F\u79A0\u79A1\u79A2\u79A3\u79A4\u79A5\u79A6\u79A8\u79A9\u79AA\u79AB\u79AC\u79AD\u79AE\u79AF\u79B0\u79B1\u79B2\u79B4\u79B5\u79B6\u79B7\u79B8\u79BC\u79BF\u79C2\u79C4\u79C5\u79C7\u79C8\u79CA\u79CC\u79CE\u79CF\u79D0\u79D3\u79D4\u79D6\u79D7\u79D9\u79DA\u79DB\u79DC\u79DD\u79DE\u79E0\u79E1\u79E2\u79E5\u79E8\u79EA\uFFFD\u79EC\u79EE\u79F1\u79F2\u79F3\u79F4\u79F5\u79F6\u79F7\u79F9\u79FA\u79FC\u79FE\u79FF\u7A01\u7A04\u7A05\u7A07\u7A08\u7A09\u7A0A\u7A0C\u7A0F\u7A10\u7A11\u7A12\u7A13\u7A15\u7A16\u7A18\u7A19\u7A1B\u7A1C\u4E01\u76EF\u53EE\u9489\u9876\u9F0E\u952D\u5B9A\u8BA2\u4E22\u4E1C\u51AC\u8463\u61C2\u52A8\u680B\u4F97\u606B\u51BB\u6D1E\u515C\u6296\u6597\u9661\u8C46\u9017\u75D8\u90FD\u7763\u6BD2\u728A\u72EC\u8BFB\u5835\u7779\u8D4C\u675C\u9540\u809A\u5EA6\u6E21\u5992\u7AEF\u77ED\u953B\u6BB5\u65AD\u7F0E\u5806\u5151\u961F\u5BF9\u58A9\u5428\u8E72\u6566\u987F\u56E4\u949D\u76FE\u9041\u6387\u54C6\u591A\u593A\u579B\u8EB2\u6735\u8DFA\u8235\u5241\u60F0\u5815\u86FE\u5CE8\u9E45\u4FC4\u989D\u8BB9\u5A25\u6076\u5384\u627C\u904F\u9102\u997F\u6069\u800C\u513F\u8033\u5C14\u9975\u6D31\u4E8C\uFFFD".split("");
      for (j = 0; j != D[182].length; ++j)
        if (D[182][j].charCodeAt(0) !== 65533) {
          e[D[182][j]] = 46592 + j;
          d[46592 + j] = D[182][j];
        }
      D[183] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A1D\u7A1F\u7A21\u7A22\u7A24\u7A25\u7A26\u7A27\u7A28\u7A29\u7A2A\u7A2B\u7A2C\u7A2D\u7A2E\u7A2F\u7A30\u7A31\u7A32\u7A34\u7A35\u7A36\u7A38\u7A3A\u7A3E\u7A40\u7A41\u7A42\u7A43\u7A44\u7A45\u7A47\u7A48\u7A49\u7A4A\u7A4B\u7A4C\u7A4D\u7A4E\u7A4F\u7A50\u7A52\u7A53\u7A54\u7A55\u7A56\u7A58\u7A59\u7A5A\u7A5B\u7A5C\u7A5D\u7A5E\u7A5F\u7A60\u7A61\u7A62\u7A63\u7A64\u7A65\u7A66\u7A67\u7A68\uFFFD\u7A69\u7A6A\u7A6B\u7A6C\u7A6D\u7A6E\u7A6F\u7A71\u7A72\u7A73\u7A75\u7A7B\u7A7C\u7A7D\u7A7E\u7A82\u7A85\u7A87\u7A89\u7A8A\u7A8B\u7A8C\u7A8E\u7A8F\u7A90\u7A93\u7A94\u7A99\u7A9A\u7A9B\u7A9E\u7AA1\u7AA2\u8D30\u53D1\u7F5A\u7B4F\u4F10\u4E4F\u9600\u6CD5\u73D0\u85E9\u5E06\u756A\u7FFB\u6A0A\u77FE\u9492\u7E41\u51E1\u70E6\u53CD\u8FD4\u8303\u8D29\u72AF\u996D\u6CDB\u574A\u82B3\u65B9\u80AA\u623F\u9632\u59A8\u4EFF\u8BBF\u7EBA\u653E\u83F2\u975E\u5561\u98DE\u80A5\u532A\u8BFD\u5420\u80BA\u5E9F\u6CB8\u8D39\u82AC\u915A\u5429\u6C1B\u5206\u7EB7\u575F\u711A\u6C7E\u7C89\u594B\u4EFD\u5FFF\u6124\u7CAA\u4E30\u5C01\u67AB\u8702\u5CF0\u950B\u98CE\u75AF\u70FD\u9022\u51AF\u7F1D\u8BBD\u5949\u51E4\u4F5B\u5426\u592B\u6577\u80A4\u5B75\u6276\u62C2\u8F90\u5E45\u6C1F\u7B26\u4F0F\u4FD8\u670D\uFFFD".split("");
      for (j = 0; j != D[183].length; ++j)
        if (D[183][j].charCodeAt(0) !== 65533) {
          e[D[183][j]] = 46848 + j;
          d[46848 + j] = D[183][j];
        }
      D[184] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7AA3\u7AA4\u7AA7\u7AA9\u7AAA\u7AAB\u7AAE\u7AAF\u7AB0\u7AB1\u7AB2\u7AB4\u7AB5\u7AB6\u7AB7\u7AB8\u7AB9\u7ABA\u7ABB\u7ABC\u7ABD\u7ABE\u7AC0\u7AC1\u7AC2\u7AC3\u7AC4\u7AC5\u7AC6\u7AC7\u7AC8\u7AC9\u7ACA\u7ACC\u7ACD\u7ACE\u7ACF\u7AD0\u7AD1\u7AD2\u7AD3\u7AD4\u7AD5\u7AD7\u7AD8\u7ADA\u7ADB\u7ADC\u7ADD\u7AE1\u7AE2\u7AE4\u7AE7\u7AE8\u7AE9\u7AEA\u7AEB\u7AEC\u7AEE\u7AF0\u7AF1\u7AF2\u7AF3\uFFFD\u7AF4\u7AF5\u7AF6\u7AF7\u7AF8\u7AFB\u7AFC\u7AFE\u7B00\u7B01\u7B02\u7B05\u7B07\u7B09\u7B0C\u7B0D\u7B0E\u7B10\u7B12\u7B13\u7B16\u7B17\u7B18\u7B1A\u7B1C\u7B1D\u7B1F\u7B21\u7B22\u7B23\u7B27\u7B29\u7B2D\u6D6E\u6DAA\u798F\u88B1\u5F17\u752B\u629A\u8F85\u4FEF\u91DC\u65A7\u812F\u8151\u5E9C\u8150\u8D74\u526F\u8986\u8D4B\u590D\u5085\u4ED8\u961C\u7236\u8179\u8D1F\u5BCC\u8BA3\u9644\u5987\u7F1A\u5490\u5676\u560E\u8BE5\u6539\u6982\u9499\u76D6\u6E89\u5E72\u7518\u6746\u67D1\u7AFF\u809D\u8D76\u611F\u79C6\u6562\u8D63\u5188\u521A\u94A2\u7F38\u809B\u7EB2\u5C97\u6E2F\u6760\u7BD9\u768B\u9AD8\u818F\u7F94\u7CD5\u641E\u9550\u7A3F\u544A\u54E5\u6B4C\u6401\u6208\u9E3D\u80F3\u7599\u5272\u9769\u845B\u683C\u86E4\u9601\u9694\u94EC\u4E2A\u5404\u7ED9\u6839\u8DDF\u8015\u66F4\u5E9A\u7FB9\uFFFD".split("");
      for (j = 0; j != D[184].length; ++j)
        if (D[184][j].charCodeAt(0) !== 65533) {
          e[D[184][j]] = 47104 + j;
          d[47104 + j] = D[184][j];
        }
      D[185] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7B2F\u7B30\u7B32\u7B34\u7B35\u7B36\u7B37\u7B39\u7B3B\u7B3D\u7B3F\u7B40\u7B41\u7B42\u7B43\u7B44\u7B46\u7B48\u7B4A\u7B4D\u7B4E\u7B53\u7B55\u7B57\u7B59\u7B5C\u7B5E\u7B5F\u7B61\u7B63\u7B64\u7B65\u7B66\u7B67\u7B68\u7B69\u7B6A\u7B6B\u7B6C\u7B6D\u7B6F\u7B70\u7B73\u7B74\u7B76\u7B78\u7B7A\u7B7C\u7B7D\u7B7F\u7B81\u7B82\u7B83\u7B84\u7B86\u7B87\u7B88\u7B89\u7B8A\u7B8B\u7B8C\u7B8E\u7B8F\uFFFD\u7B91\u7B92\u7B93\u7B96\u7B98\u7B99\u7B9A\u7B9B\u7B9E\u7B9F\u7BA0\u7BA3\u7BA4\u7BA5\u7BAE\u7BAF\u7BB0\u7BB2\u7BB3\u7BB5\u7BB6\u7BB7\u7BB9\u7BBA\u7BBB\u7BBC\u7BBD\u7BBE\u7BBF\u7BC0\u7BC2\u7BC3\u7BC4\u57C2\u803F\u6897\u5DE5\u653B\u529F\u606D\u9F9A\u4F9B\u8EAC\u516C\u5BAB\u5F13\u5DE9\u6C5E\u62F1\u8D21\u5171\u94A9\u52FE\u6C9F\u82DF\u72D7\u57A2\u6784\u8D2D\u591F\u8F9C\u83C7\u5495\u7B8D\u4F30\u6CBD\u5B64\u59D1\u9F13\u53E4\u86CA\u9AA8\u8C37\u80A1\u6545\u987E\u56FA\u96C7\u522E\u74DC\u5250\u5BE1\u6302\u8902\u4E56\u62D0\u602A\u68FA\u5173\u5B98\u51A0\u89C2\u7BA1\u9986\u7F50\u60EF\u704C\u8D2F\u5149\u5E7F\u901B\u7470\u89C4\u572D\u7845\u5F52\u9F9F\u95FA\u8F68\u9B3C\u8BE1\u7678\u6842\u67DC\u8DEA\u8D35\u523D\u8F8A\u6EDA\u68CD\u9505\u90ED\u56FD\u679C\u88F9\u8FC7\u54C8\uFFFD".split("");
      for (j = 0; j != D[185].length; ++j)
        if (D[185][j].charCodeAt(0) !== 65533) {
          e[D[185][j]] = 47360 + j;
          d[47360 + j] = D[185][j];
        }
      D[186] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7BC5\u7BC8\u7BC9\u7BCA\u7BCB\u7BCD\u7BCE\u7BCF\u7BD0\u7BD2\u7BD4\u7BD5\u7BD6\u7BD7\u7BD8\u7BDB\u7BDC\u7BDE\u7BDF\u7BE0\u7BE2\u7BE3\u7BE4\u7BE7\u7BE8\u7BE9\u7BEB\u7BEC\u7BED\u7BEF\u7BF0\u7BF2\u7BF3\u7BF4\u7BF5\u7BF6\u7BF8\u7BF9\u7BFA\u7BFB\u7BFD\u7BFF\u7C00\u7C01\u7C02\u7C03\u7C04\u7C05\u7C06\u7C08\u7C09\u7C0A\u7C0D\u7C0E\u7C10\u7C11\u7C12\u7C13\u7C14\u7C15\u7C17\u7C18\u7C19\uFFFD\u7C1A\u7C1B\u7C1C\u7C1D\u7C1E\u7C20\u7C21\u7C22\u7C23\u7C24\u7C25\u7C28\u7C29\u7C2B\u7C2C\u7C2D\u7C2E\u7C2F\u7C30\u7C31\u7C32\u7C33\u7C34\u7C35\u7C36\u7C37\u7C39\u7C3A\u7C3B\u7C3C\u7C3D\u7C3E\u7C42\u9AB8\u5B69\u6D77\u6C26\u4EA5\u5BB3\u9A87\u9163\u61A8\u90AF\u97E9\u542B\u6DB5\u5BD2\u51FD\u558A\u7F55\u7FF0\u64BC\u634D\u65F1\u61BE\u608D\u710A\u6C57\u6C49\u592F\u676D\u822A\u58D5\u568E\u8C6A\u6BEB\u90DD\u597D\u8017\u53F7\u6D69\u5475\u559D\u8377\u83CF\u6838\u79BE\u548C\u4F55\u5408\u76D2\u8C89\u9602\u6CB3\u6DB8\u8D6B\u8910\u9E64\u8D3A\u563F\u9ED1\u75D5\u5F88\u72E0\u6068\u54FC\u4EA8\u6A2A\u8861\u6052\u8F70\u54C4\u70D8\u8679\u9E3F\u6D2A\u5B8F\u5F18\u7EA2\u5589\u4FAF\u7334\u543C\u539A\u5019\u540E\u547C\u4E4E\u5FFD\u745A\u58F6\u846B\u80E1\u8774\u72D0\u7CCA\u6E56\uFFFD".split("");
      for (j = 0; j != D[186].length; ++j)
        if (D[186][j].charCodeAt(0) !== 65533) {
          e[D[186][j]] = 47616 + j;
          d[47616 + j] = D[186][j];
        }
      D[187] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7C43\u7C44\u7C45\u7C46\u7C47\u7C48\u7C49\u7C4A\u7C4B\u7C4C\u7C4E\u7C4F\u7C50\u7C51\u7C52\u7C53\u7C54\u7C55\u7C56\u7C57\u7C58\u7C59\u7C5A\u7C5B\u7C5C\u7C5D\u7C5E\u7C5F\u7C60\u7C61\u7C62\u7C63\u7C64\u7C65\u7C66\u7C67\u7C68\u7C69\u7C6A\u7C6B\u7C6C\u7C6D\u7C6E\u7C6F\u7C70\u7C71\u7C72\u7C75\u7C76\u7C77\u7C78\u7C79\u7C7A\u7C7E\u7C7F\u7C80\u7C81\u7C82\u7C83\u7C84\u7C85\u7C86\u7C87\uFFFD\u7C88\u7C8A\u7C8B\u7C8C\u7C8D\u7C8E\u7C8F\u7C90\u7C93\u7C94\u7C96\u7C99\u7C9A\u7C9B\u7CA0\u7CA1\u7CA3\u7CA6\u7CA7\u7CA8\u7CA9\u7CAB\u7CAC\u7CAD\u7CAF\u7CB0\u7CB4\u7CB5\u7CB6\u7CB7\u7CB8\u7CBA\u7CBB\u5F27\u864E\u552C\u62A4\u4E92\u6CAA\u6237\u82B1\u54D7\u534E\u733E\u6ED1\u753B\u5212\u5316\u8BDD\u69D0\u5F8A\u6000\u6DEE\u574F\u6B22\u73AF\u6853\u8FD8\u7F13\u6362\u60A3\u5524\u75EA\u8C62\u7115\u6DA3\u5BA6\u5E7B\u8352\u614C\u9EC4\u78FA\u8757\u7C27\u7687\u51F0\u60F6\u714C\u6643\u5E4C\u604D\u8C0E\u7070\u6325\u8F89\u5FBD\u6062\u86D4\u56DE\u6BC1\u6094\u6167\u5349\u60E0\u6666\u8D3F\u79FD\u4F1A\u70E9\u6C47\u8BB3\u8BF2\u7ED8\u8364\u660F\u5A5A\u9B42\u6D51\u6DF7\u8C41\u6D3B\u4F19\u706B\u83B7\u6216\u60D1\u970D\u8D27\u7978\u51FB\u573E\u57FA\u673A\u7578\u7A3D\u79EF\u7B95\uFFFD".split("");
      for (j = 0; j != D[187].length; ++j)
        if (D[187][j].charCodeAt(0) !== 65533) {
          e[D[187][j]] = 47872 + j;
          d[47872 + j] = D[187][j];
        }
      D[188] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7CBF\u7CC0\u7CC2\u7CC3\u7CC4\u7CC6\u7CC9\u7CCB\u7CCE\u7CCF\u7CD0\u7CD1\u7CD2\u7CD3\u7CD4\u7CD8\u7CDA\u7CDB\u7CDD\u7CDE\u7CE1\u7CE2\u7CE3\u7CE4\u7CE5\u7CE6\u7CE7\u7CE9\u7CEA\u7CEB\u7CEC\u7CED\u7CEE\u7CF0\u7CF1\u7CF2\u7CF3\u7CF4\u7CF5\u7CF6\u7CF7\u7CF9\u7CFA\u7CFC\u7CFD\u7CFE\u7CFF\u7D00\u7D01\u7D02\u7D03\u7D04\u7D05\u7D06\u7D07\u7D08\u7D09\u7D0B\u7D0C\u7D0D\u7D0E\u7D0F\u7D10\uFFFD\u7D11\u7D12\u7D13\u7D14\u7D15\u7D16\u7D17\u7D18\u7D19\u7D1A\u7D1B\u7D1C\u7D1D\u7D1E\u7D1F\u7D21\u7D23\u7D24\u7D25\u7D26\u7D28\u7D29\u7D2A\u7D2C\u7D2D\u7D2E\u7D30\u7D31\u7D32\u7D33\u7D34\u7D35\u7D36\u808C\u9965\u8FF9\u6FC0\u8BA5\u9E21\u59EC\u7EE9\u7F09\u5409\u6781\u68D8\u8F91\u7C4D\u96C6\u53CA\u6025\u75BE\u6C72\u5373\u5AC9\u7EA7\u6324\u51E0\u810A\u5DF1\u84DF\u6280\u5180\u5B63\u4F0E\u796D\u5242\u60B8\u6D4E\u5BC4\u5BC2\u8BA1\u8BB0\u65E2\u5FCC\u9645\u5993\u7EE7\u7EAA\u5609\u67B7\u5939\u4F73\u5BB6\u52A0\u835A\u988A\u8D3E\u7532\u94BE\u5047\u7A3C\u4EF7\u67B6\u9A7E\u5AC1\u6B7C\u76D1\u575A\u5C16\u7B3A\u95F4\u714E\u517C\u80A9\u8270\u5978\u7F04\u8327\u68C0\u67EC\u78B1\u7877\u62E3\u6361\u7B80\u4FED\u526A\u51CF\u8350\u69DB\u9274\u8DF5\u8D31\u89C1\u952E\u7BAD\u4EF6\uFFFD".split("");
      for (j = 0; j != D[188].length; ++j)
        if (D[188][j].charCodeAt(0) !== 65533) {
          e[D[188][j]] = 48128 + j;
          d[48128 + j] = D[188][j];
        }
      D[189] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7D37\u7D38\u7D39\u7D3A\u7D3B\u7D3C\u7D3D\u7D3E\u7D3F\u7D40\u7D41\u7D42\u7D43\u7D44\u7D45\u7D46\u7D47\u7D48\u7D49\u7D4A\u7D4B\u7D4C\u7D4D\u7D4E\u7D4F\u7D50\u7D51\u7D52\u7D53\u7D54\u7D55\u7D56\u7D57\u7D58\u7D59\u7D5A\u7D5B\u7D5C\u7D5D\u7D5E\u7D5F\u7D60\u7D61\u7D62\u7D63\u7D64\u7D65\u7D66\u7D67\u7D68\u7D69\u7D6A\u7D6B\u7D6C\u7D6D\u7D6F\u7D70\u7D71\u7D72\u7D73\u7D74\u7D75\u7D76\uFFFD\u7D78\u7D79\u7D7A\u7D7B\u7D7C\u7D7D\u7D7E\u7D7F\u7D80\u7D81\u7D82\u7D83\u7D84\u7D85\u7D86\u7D87\u7D88\u7D89\u7D8A\u7D8B\u7D8C\u7D8D\u7D8E\u7D8F\u7D90\u7D91\u7D92\u7D93\u7D94\u7D95\u7D96\u7D97\u7D98\u5065\u8230\u5251\u996F\u6E10\u6E85\u6DA7\u5EFA\u50F5\u59DC\u5C06\u6D46\u6C5F\u7586\u848B\u6868\u5956\u8BB2\u5320\u9171\u964D\u8549\u6912\u7901\u7126\u80F6\u4EA4\u90CA\u6D47\u9A84\u5A07\u56BC\u6405\u94F0\u77EB\u4FA5\u811A\u72E1\u89D2\u997A\u7F34\u7EDE\u527F\u6559\u9175\u8F7F\u8F83\u53EB\u7A96\u63ED\u63A5\u7686\u79F8\u8857\u9636\u622A\u52AB\u8282\u6854\u6770\u6377\u776B\u7AED\u6D01\u7ED3\u89E3\u59D0\u6212\u85C9\u82A5\u754C\u501F\u4ECB\u75A5\u8BEB\u5C4A\u5DFE\u7B4B\u65A4\u91D1\u4ECA\u6D25\u895F\u7D27\u9526\u4EC5\u8C28\u8FDB\u9773\u664B\u7981\u8FD1\u70EC\u6D78\uFFFD".split("");
      for (j = 0; j != D[189].length; ++j)
        if (D[189][j].charCodeAt(0) !== 65533) {
          e[D[189][j]] = 48384 + j;
          d[48384 + j] = D[189][j];
        }
      D[190] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7D99\u7D9A\u7D9B\u7D9C\u7D9D\u7D9E\u7D9F\u7DA0\u7DA1\u7DA2\u7DA3\u7DA4\u7DA5\u7DA7\u7DA8\u7DA9\u7DAA\u7DAB\u7DAC\u7DAD\u7DAF\u7DB0\u7DB1\u7DB2\u7DB3\u7DB4\u7DB5\u7DB6\u7DB7\u7DB8\u7DB9\u7DBA\u7DBB\u7DBC\u7DBD\u7DBE\u7DBF\u7DC0\u7DC1\u7DC2\u7DC3\u7DC4\u7DC5\u7DC6\u7DC7\u7DC8\u7DC9\u7DCA\u7DCB\u7DCC\u7DCD\u7DCE\u7DCF\u7DD0\u7DD1\u7DD2\u7DD3\u7DD4\u7DD5\u7DD6\u7DD7\u7DD8\u7DD9\uFFFD\u7DDA\u7DDB\u7DDC\u7DDD\u7DDE\u7DDF\u7DE0\u7DE1\u7DE2\u7DE3\u7DE4\u7DE5\u7DE6\u7DE7\u7DE8\u7DE9\u7DEA\u7DEB\u7DEC\u7DED\u7DEE\u7DEF\u7DF0\u7DF1\u7DF2\u7DF3\u7DF4\u7DF5\u7DF6\u7DF7\u7DF8\u7DF9\u7DFA\u5C3D\u52B2\u8346\u5162\u830E\u775B\u6676\u9CB8\u4EAC\u60CA\u7CBE\u7CB3\u7ECF\u4E95\u8B66\u666F\u9888\u9759\u5883\u656C\u955C\u5F84\u75C9\u9756\u7ADF\u7ADE\u51C0\u70AF\u7A98\u63EA\u7A76\u7EA0\u7396\u97ED\u4E45\u7078\u4E5D\u9152\u53A9\u6551\u65E7\u81FC\u8205\u548E\u5C31\u759A\u97A0\u62D8\u72D9\u75BD\u5C45\u9A79\u83CA\u5C40\u5480\u77E9\u4E3E\u6CAE\u805A\u62D2\u636E\u5DE8\u5177\u8DDD\u8E1E\u952F\u4FF1\u53E5\u60E7\u70AC\u5267\u6350\u9E43\u5A1F\u5026\u7737\u5377\u7EE2\u6485\u652B\u6289\u6398\u5014\u7235\u89C9\u51B3\u8BC0\u7EDD\u5747\u83CC\u94A7\u519B\u541B\u5CFB\uFFFD".split("");
      for (j = 0; j != D[190].length; ++j)
        if (D[190][j].charCodeAt(0) !== 65533) {
          e[D[190][j]] = 48640 + j;
          d[48640 + j] = D[190][j];
        }
      D[191] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7DFB\u7DFC\u7DFD\u7DFE\u7DFF\u7E00\u7E01\u7E02\u7E03\u7E04\u7E05\u7E06\u7E07\u7E08\u7E09\u7E0A\u7E0B\u7E0C\u7E0D\u7E0E\u7E0F\u7E10\u7E11\u7E12\u7E13\u7E14\u7E15\u7E16\u7E17\u7E18\u7E19\u7E1A\u7E1B\u7E1C\u7E1D\u7E1E\u7E1F\u7E20\u7E21\u7E22\u7E23\u7E24\u7E25\u7E26\u7E27\u7E28\u7E29\u7E2A\u7E2B\u7E2C\u7E2D\u7E2E\u7E2F\u7E30\u7E31\u7E32\u7E33\u7E34\u7E35\u7E36\u7E37\u7E38\u7E39\uFFFD\u7E3A\u7E3C\u7E3D\u7E3E\u7E3F\u7E40\u7E42\u7E43\u7E44\u7E45\u7E46\u7E48\u7E49\u7E4A\u7E4B\u7E4C\u7E4D\u7E4E\u7E4F\u7E50\u7E51\u7E52\u7E53\u7E54\u7E55\u7E56\u7E57\u7E58\u7E59\u7E5A\u7E5B\u7E5C\u7E5D\u4FCA\u7AE3\u6D5A\u90E1\u9A8F\u5580\u5496\u5361\u54AF\u5F00\u63E9\u6977\u51EF\u6168\u520A\u582A\u52D8\u574E\u780D\u770B\u5EB7\u6177\u7CE0\u625B\u6297\u4EA2\u7095\u8003\u62F7\u70E4\u9760\u5777\u82DB\u67EF\u68F5\u78D5\u9897\u79D1\u58F3\u54B3\u53EF\u6E34\u514B\u523B\u5BA2\u8BFE\u80AF\u5543\u57A6\u6073\u5751\u542D\u7A7A\u6050\u5B54\u63A7\u62A0\u53E3\u6263\u5BC7\u67AF\u54ED\u7A9F\u82E6\u9177\u5E93\u88E4\u5938\u57AE\u630E\u8DE8\u80EF\u5757\u7B77\u4FA9\u5FEB\u5BBD\u6B3E\u5321\u7B50\u72C2\u6846\u77FF\u7736\u65F7\u51B5\u4E8F\u76D4\u5CBF\u7AA5\u8475\u594E\u9B41\u5080\uFFFD".split("");
      for (j = 0; j != D[191].length; ++j)
        if (D[191][j].charCodeAt(0) !== 65533) {
          e[D[191][j]] = 48896 + j;
          d[48896 + j] = D[191][j];
        }
      D[192] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E5E\u7E5F\u7E60\u7E61\u7E62\u7E63\u7E64\u7E65\u7E66\u7E67\u7E68\u7E69\u7E6A\u7E6B\u7E6C\u7E6D\u7E6E\u7E6F\u7E70\u7E71\u7E72\u7E73\u7E74\u7E75\u7E76\u7E77\u7E78\u7E79\u7E7A\u7E7B\u7E7C\u7E7D\u7E7E\u7E7F\u7E80\u7E81\u7E83\u7E84\u7E85\u7E86\u7E87\u7E88\u7E89\u7E8A\u7E8B\u7E8C\u7E8D\u7E8E\u7E8F\u7E90\u7E91\u7E92\u7E93\u7E94\u7E95\u7E96\u7E97\u7E98\u7E99\u7E9A\u7E9C\u7E9D\u7E9E\uFFFD\u7EAE\u7EB4\u7EBB\u7EBC\u7ED6\u7EE4\u7EEC\u7EF9\u7F0A\u7F10\u7F1E\u7F37\u7F39\u7F3B\u7F3C\u7F3D\u7F3E\u7F3F\u7F40\u7F41\u7F43\u7F46\u7F47\u7F48\u7F49\u7F4A\u7F4B\u7F4C\u7F4D\u7F4E\u7F4F\u7F52\u7F53\u9988\u6127\u6E83\u5764\u6606\u6346\u56F0\u62EC\u6269\u5ED3\u9614\u5783\u62C9\u5587\u8721\u814A\u8FA3\u5566\u83B1\u6765\u8D56\u84DD\u5A6A\u680F\u62E6\u7BEE\u9611\u5170\u6F9C\u8C30\u63FD\u89C8\u61D2\u7F06\u70C2\u6EE5\u7405\u6994\u72FC\u5ECA\u90CE\u6717\u6D6A\u635E\u52B3\u7262\u8001\u4F6C\u59E5\u916A\u70D9\u6D9D\u52D2\u4E50\u96F7\u956D\u857E\u78CA\u7D2F\u5121\u5792\u64C2\u808B\u7C7B\u6CEA\u68F1\u695E\u51B7\u5398\u68A8\u7281\u9ECE\u7BF1\u72F8\u79BB\u6F13\u7406\u674E\u91CC\u9CA4\u793C\u8389\u8354\u540F\u6817\u4E3D\u5389\u52B1\u783E\u5386\u5229\u5088\u4F8B\u4FD0\uFFFD".split("");
      for (j = 0; j != D[192].length; ++j)
        if (D[192][j].charCodeAt(0) !== 65533) {
          e[D[192][j]] = 49152 + j;
          d[49152 + j] = D[192][j];
        }
      D[193] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7F56\u7F59\u7F5B\u7F5C\u7F5D\u7F5E\u7F60\u7F63\u7F64\u7F65\u7F66\u7F67\u7F6B\u7F6C\u7F6D\u7F6F\u7F70\u7F73\u7F75\u7F76\u7F77\u7F78\u7F7A\u7F7B\u7F7C\u7F7D\u7F7F\u7F80\u7F82\u7F83\u7F84\u7F85\u7F86\u7F87\u7F88\u7F89\u7F8B\u7F8D\u7F8F\u7F90\u7F91\u7F92\u7F93\u7F95\u7F96\u7F97\u7F98\u7F99\u7F9B\u7F9C\u7FA0\u7FA2\u7FA3\u7FA5\u7FA6\u7FA8\u7FA9\u7FAA\u7FAB\u7FAC\u7FAD\u7FAE\u7FB1\uFFFD\u7FB3\u7FB4\u7FB5\u7FB6\u7FB7\u7FBA\u7FBB\u7FBE\u7FC0\u7FC2\u7FC3\u7FC4\u7FC6\u7FC7\u7FC8\u7FC9\u7FCB\u7FCD\u7FCF\u7FD0\u7FD1\u7FD2\u7FD3\u7FD6\u7FD7\u7FD9\u7FDA\u7FDB\u7FDC\u7FDD\u7FDE\u7FE2\u7FE3\u75E2\u7ACB\u7C92\u6CA5\u96B6\u529B\u7483\u54E9\u4FE9\u8054\u83B2\u8FDE\u9570\u5EC9\u601C\u6D9F\u5E18\u655B\u8138\u94FE\u604B\u70BC\u7EC3\u7CAE\u51C9\u6881\u7CB1\u826F\u4E24\u8F86\u91CF\u667E\u4EAE\u8C05\u64A9\u804A\u50DA\u7597\u71CE\u5BE5\u8FBD\u6F66\u4E86\u6482\u9563\u5ED6\u6599\u5217\u88C2\u70C8\u52A3\u730E\u7433\u6797\u78F7\u9716\u4E34\u90BB\u9CDE\u6DCB\u51DB\u8D41\u541D\u62CE\u73B2\u83F1\u96F6\u9F84\u94C3\u4F36\u7F9A\u51CC\u7075\u9675\u5CAD\u9886\u53E6\u4EE4\u6E9C\u7409\u69B4\u786B\u998F\u7559\u5218\u7624\u6D41\u67F3\u516D\u9F99\u804B\u5499\u7B3C\u7ABF\uFFFD".split("");
      for (j = 0; j != D[193].length; ++j)
        if (D[193][j].charCodeAt(0) !== 65533) {
          e[D[193][j]] = 49408 + j;
          d[49408 + j] = D[193][j];
        }
      D[194] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7FE4\u7FE7\u7FE8\u7FEA\u7FEB\u7FEC\u7FED\u7FEF\u7FF2\u7FF4\u7FF5\u7FF6\u7FF7\u7FF8\u7FF9\u7FFA\u7FFD\u7FFE\u7FFF\u8002\u8007\u8008\u8009\u800A\u800E\u800F\u8011\u8013\u801A\u801B\u801D\u801E\u801F\u8021\u8023\u8024\u802B\u802C\u802D\u802E\u802F\u8030\u8032\u8034\u8039\u803A\u803C\u803E\u8040\u8041\u8044\u8045\u8047\u8048\u8049\u804E\u804F\u8050\u8051\u8053\u8055\u8056\u8057\uFFFD\u8059\u805B\u805C\u805D\u805E\u805F\u8060\u8061\u8062\u8063\u8064\u8065\u8066\u8067\u8068\u806B\u806C\u806D\u806E\u806F\u8070\u8072\u8073\u8074\u8075\u8076\u8077\u8078\u8079\u807A\u807B\u807C\u807D\u9686\u5784\u62E2\u9647\u697C\u5A04\u6402\u7BD3\u6F0F\u964B\u82A6\u5362\u9885\u5E90\u7089\u63B3\u5364\u864F\u9C81\u9E93\u788C\u9732\u8DEF\u8D42\u9E7F\u6F5E\u7984\u5F55\u9646\u622E\u9A74\u5415\u94DD\u4FA3\u65C5\u5C65\u5C61\u7F15\u8651\u6C2F\u5F8B\u7387\u6EE4\u7EFF\u5CE6\u631B\u5B6A\u6EE6\u5375\u4E71\u63A0\u7565\u62A1\u8F6E\u4F26\u4ED1\u6CA6\u7EB6\u8BBA\u841D\u87BA\u7F57\u903B\u9523\u7BA9\u9AA1\u88F8\u843D\u6D1B\u9A86\u7EDC\u5988\u9EBB\u739B\u7801\u8682\u9A6C\u9A82\u561B\u5417\u57CB\u4E70\u9EA6\u5356\u8FC8\u8109\u7792\u9992\u86EE\u6EE1\u8513\u66FC\u6162\u6F2B\uFFFD".split("");
      for (j = 0; j != D[194].length; ++j)
        if (D[194][j].charCodeAt(0) !== 65533) {
          e[D[194][j]] = 49664 + j;
          d[49664 + j] = D[194][j];
        }
      D[195] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u807E\u8081\u8082\u8085\u8088\u808A\u808D\u808E\u808F\u8090\u8091\u8092\u8094\u8095\u8097\u8099\u809E\u80A3\u80A6\u80A7\u80A8\u80AC\u80B0\u80B3\u80B5\u80B6\u80B8\u80B9\u80BB\u80C5\u80C7\u80C8\u80C9\u80CA\u80CB\u80CF\u80D0\u80D1\u80D2\u80D3\u80D4\u80D5\u80D8\u80DF\u80E0\u80E2\u80E3\u80E6\u80EE\u80F5\u80F7\u80F9\u80FB\u80FE\u80FF\u8100\u8101\u8103\u8104\u8105\u8107\u8108\u810B\uFFFD\u810C\u8115\u8117\u8119\u811B\u811C\u811D\u811F\u8120\u8121\u8122\u8123\u8124\u8125\u8126\u8127\u8128\u8129\u812A\u812B\u812D\u812E\u8130\u8133\u8134\u8135\u8137\u8139\u813A\u813B\u813C\u813D\u813F\u8C29\u8292\u832B\u76F2\u6C13\u5FD9\u83BD\u732B\u8305\u951A\u6BDB\u77DB\u94C6\u536F\u8302\u5192\u5E3D\u8C8C\u8D38\u4E48\u73AB\u679A\u6885\u9176\u9709\u7164\u6CA1\u7709\u5A92\u9541\u6BCF\u7F8E\u6627\u5BD0\u59B9\u5A9A\u95E8\u95F7\u4EEC\u840C\u8499\u6AAC\u76DF\u9530\u731B\u68A6\u5B5F\u772F\u919A\u9761\u7CDC\u8FF7\u8C1C\u5F25\u7C73\u79D8\u89C5\u6CCC\u871C\u5BC6\u5E42\u68C9\u7720\u7EF5\u5195\u514D\u52C9\u5A29\u7F05\u9762\u82D7\u63CF\u7784\u85D0\u79D2\u6E3A\u5E99\u5999\u8511\u706D\u6C11\u62BF\u76BF\u654F\u60AF\u95FD\u660E\u879F\u9E23\u94ED\u540D\u547D\u8C2C\u6478\uFFFD".split("");
      for (j = 0; j != D[195].length; ++j)
        if (D[195][j].charCodeAt(0) !== 65533) {
          e[D[195][j]] = 49920 + j;
          d[49920 + j] = D[195][j];
        }
      D[196] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8140\u8141\u8142\u8143\u8144\u8145\u8147\u8149\u814D\u814E\u814F\u8152\u8156\u8157\u8158\u815B\u815C\u815D\u815E\u815F\u8161\u8162\u8163\u8164\u8166\u8168\u816A\u816B\u816C\u816F\u8172\u8173\u8175\u8176\u8177\u8178\u8181\u8183\u8184\u8185\u8186\u8187\u8189\u818B\u818C\u818D\u818E\u8190\u8192\u8193\u8194\u8195\u8196\u8197\u8199\u819A\u819E\u819F\u81A0\u81A1\u81A2\u81A4\u81A5\uFFFD\u81A7\u81A9\u81AB\u81AC\u81AD\u81AE\u81AF\u81B0\u81B1\u81B2\u81B4\u81B5\u81B6\u81B7\u81B8\u81B9\u81BC\u81BD\u81BE\u81BF\u81C4\u81C5\u81C7\u81C8\u81C9\u81CB\u81CD\u81CE\u81CF\u81D0\u81D1\u81D2\u81D3\u6479\u8611\u6A21\u819C\u78E8\u6469\u9B54\u62B9\u672B\u83AB\u58A8\u9ED8\u6CAB\u6F20\u5BDE\u964C\u8C0B\u725F\u67D0\u62C7\u7261\u4EA9\u59C6\u6BCD\u5893\u66AE\u5E55\u52DF\u6155\u6728\u76EE\u7766\u7267\u7A46\u62FF\u54EA\u5450\u94A0\u90A3\u5A1C\u7EB3\u6C16\u4E43\u5976\u8010\u5948\u5357\u7537\u96BE\u56CA\u6320\u8111\u607C\u95F9\u6DD6\u5462\u9981\u5185\u5AE9\u80FD\u59AE\u9713\u502A\u6CE5\u5C3C\u62DF\u4F60\u533F\u817B\u9006\u6EBA\u852B\u62C8\u5E74\u78BE\u64B5\u637B\u5FF5\u5A18\u917F\u9E1F\u5C3F\u634F\u8042\u5B7D\u556E\u954A\u954D\u6D85\u60A8\u67E0\u72DE\u51DD\u5B81\uFFFD".split("");
      for (j = 0; j != D[196].length; ++j)
        if (D[196][j].charCodeAt(0) !== 65533) {
          e[D[196][j]] = 50176 + j;
          d[50176 + j] = D[196][j];
        }
      D[197] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u81D4\u81D5\u81D6\u81D7\u81D8\u81D9\u81DA\u81DB\u81DC\u81DD\u81DE\u81DF\u81E0\u81E1\u81E2\u81E4\u81E5\u81E6\u81E8\u81E9\u81EB\u81EE\u81EF\u81F0\u81F1\u81F2\u81F5\u81F6\u81F7\u81F8\u81F9\u81FA\u81FD\u81FF\u8203\u8207\u8208\u8209\u820A\u820B\u820E\u820F\u8211\u8213\u8215\u8216\u8217\u8218\u8219\u821A\u821D\u8220\u8224\u8225\u8226\u8227\u8229\u822E\u8232\u823A\u823C\u823D\u823F\uFFFD\u8240\u8241\u8242\u8243\u8245\u8246\u8248\u824A\u824C\u824D\u824E\u8250\u8251\u8252\u8253\u8254\u8255\u8256\u8257\u8259\u825B\u825C\u825D\u825E\u8260\u8261\u8262\u8263\u8264\u8265\u8266\u8267\u8269\u62E7\u6CDE\u725B\u626D\u94AE\u7EBD\u8113\u6D53\u519C\u5F04\u5974\u52AA\u6012\u5973\u6696\u8650\u759F\u632A\u61E6\u7CEF\u8BFA\u54E6\u6B27\u9E25\u6BB4\u85D5\u5455\u5076\u6CA4\u556A\u8DB4\u722C\u5E15\u6015\u7436\u62CD\u6392\u724C\u5F98\u6E43\u6D3E\u6500\u6F58\u76D8\u78D0\u76FC\u7554\u5224\u53DB\u4E53\u5E9E\u65C1\u802A\u80D6\u629B\u5486\u5228\u70AE\u888D\u8DD1\u6CE1\u5478\u80DA\u57F9\u88F4\u8D54\u966A\u914D\u4F69\u6C9B\u55B7\u76C6\u7830\u62A8\u70F9\u6F8E\u5F6D\u84EC\u68DA\u787C\u7BF7\u81A8\u670B\u9E4F\u6367\u78B0\u576F\u7812\u9739\u6279\u62AB\u5288\u7435\u6BD7\uFFFD".split("");
      for (j = 0; j != D[197].length; ++j)
        if (D[197][j].charCodeAt(0) !== 65533) {
          e[D[197][j]] = 50432 + j;
          d[50432 + j] = D[197][j];
        }
      D[198] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u826A\u826B\u826C\u826D\u8271\u8275\u8276\u8277\u8278\u827B\u827C\u8280\u8281\u8283\u8285\u8286\u8287\u8289\u828C\u8290\u8293\u8294\u8295\u8296\u829A\u829B\u829E\u82A0\u82A2\u82A3\u82A7\u82B2\u82B5\u82B6\u82BA\u82BB\u82BC\u82BF\u82C0\u82C2\u82C3\u82C5\u82C6\u82C9\u82D0\u82D6\u82D9\u82DA\u82DD\u82E2\u82E7\u82E8\u82E9\u82EA\u82EC\u82ED\u82EE\u82F0\u82F2\u82F3\u82F5\u82F6\u82F8\uFFFD\u82FA\u82FC\u82FD\u82FE\u82FF\u8300\u830A\u830B\u830D\u8310\u8312\u8313\u8316\u8318\u8319\u831D\u831E\u831F\u8320\u8321\u8322\u8323\u8324\u8325\u8326\u8329\u832A\u832E\u8330\u8332\u8337\u833B\u833D\u5564\u813E\u75B2\u76AE\u5339\u75DE\u50FB\u5C41\u8B6C\u7BC7\u504F\u7247\u9A97\u98D8\u6F02\u74E2\u7968\u6487\u77A5\u62FC\u9891\u8D2B\u54C1\u8058\u4E52\u576A\u82F9\u840D\u5E73\u51ED\u74F6\u8BC4\u5C4F\u5761\u6CFC\u9887\u5A46\u7834\u9B44\u8FEB\u7C95\u5256\u6251\u94FA\u4EC6\u8386\u8461\u83E9\u84B2\u57D4\u6734\u5703\u666E\u6D66\u8C31\u66DD\u7011\u671F\u6B3A\u6816\u621A\u59BB\u4E03\u51C4\u6F06\u67D2\u6C8F\u5176\u68CB\u5947\u6B67\u7566\u5D0E\u8110\u9F50\u65D7\u7948\u7941\u9A91\u8D77\u5C82\u4E5E\u4F01\u542F\u5951\u780C\u5668\u6C14\u8FC4\u5F03\u6C7D\u6CE3\u8BAB\u6390\uFFFD".split("");
      for (j = 0; j != D[198].length; ++j)
        if (D[198][j].charCodeAt(0) !== 65533) {
          e[D[198][j]] = 50688 + j;
          d[50688 + j] = D[198][j];
        }
      D[199] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u833E\u833F\u8341\u8342\u8344\u8345\u8348\u834A\u834B\u834C\u834D\u834E\u8353\u8355\u8356\u8357\u8358\u8359\u835D\u8362\u8370\u8371\u8372\u8373\u8374\u8375\u8376\u8379\u837A\u837E\u837F\u8380\u8381\u8382\u8383\u8384\u8387\u8388\u838A\u838B\u838C\u838D\u838F\u8390\u8391\u8394\u8395\u8396\u8397\u8399\u839A\u839D\u839F\u83A1\u83A2\u83A3\u83A4\u83A5\u83A6\u83A7\u83AC\u83AD\u83AE\uFFFD\u83AF\u83B5\u83BB\u83BE\u83BF\u83C2\u83C3\u83C4\u83C6\u83C8\u83C9\u83CB\u83CD\u83CE\u83D0\u83D1\u83D2\u83D3\u83D5\u83D7\u83D9\u83DA\u83DB\u83DE\u83E2\u83E3\u83E4\u83E6\u83E7\u83E8\u83EB\u83EC\u83ED\u6070\u6D3D\u7275\u6266\u948E\u94C5\u5343\u8FC1\u7B7E\u4EDF\u8C26\u4E7E\u9ED4\u94B1\u94B3\u524D\u6F5C\u9063\u6D45\u8C34\u5811\u5D4C\u6B20\u6B49\u67AA\u545B\u8154\u7F8C\u5899\u8537\u5F3A\u62A2\u6A47\u9539\u6572\u6084\u6865\u77A7\u4E54\u4FA8\u5DE7\u9798\u64AC\u7FD8\u5CED\u4FCF\u7A8D\u5207\u8304\u4E14\u602F\u7A83\u94A6\u4FB5\u4EB2\u79E6\u7434\u52E4\u82B9\u64D2\u79BD\u5BDD\u6C81\u9752\u8F7B\u6C22\u503E\u537F\u6E05\u64CE\u6674\u6C30\u60C5\u9877\u8BF7\u5E86\u743C\u7A77\u79CB\u4E18\u90B1\u7403\u6C42\u56DA\u914B\u6CC5\u8D8B\u533A\u86C6\u66F2\u8EAF\u5C48\u9A71\u6E20\uFFFD".split("");
      for (j = 0; j != D[199].length; ++j)
        if (D[199][j].charCodeAt(0) !== 65533) {
          e[D[199][j]] = 50944 + j;
          d[50944 + j] = D[199][j];
        }
      D[200] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u83EE\u83EF\u83F3\u83F4\u83F5\u83F6\u83F7\u83FA\u83FB\u83FC\u83FE\u83FF\u8400\u8402\u8405\u8407\u8408\u8409\u840A\u8410\u8412\u8413\u8414\u8415\u8416\u8417\u8419\u841A\u841B\u841E\u841F\u8420\u8421\u8422\u8423\u8429\u842A\u842B\u842C\u842D\u842E\u842F\u8430\u8432\u8433\u8434\u8435\u8436\u8437\u8439\u843A\u843B\u843E\u843F\u8440\u8441\u8442\u8443\u8444\u8445\u8447\u8448\u8449\uFFFD\u844A\u844B\u844C\u844D\u844E\u844F\u8450\u8452\u8453\u8454\u8455\u8456\u8458\u845D\u845E\u845F\u8460\u8462\u8464\u8465\u8466\u8467\u8468\u846A\u846E\u846F\u8470\u8472\u8474\u8477\u8479\u847B\u847C\u53D6\u5A36\u9F8B\u8DA3\u53BB\u5708\u98A7\u6743\u919B\u6CC9\u5168\u75CA\u62F3\u72AC\u5238\u529D\u7F3A\u7094\u7638\u5374\u9E4A\u69B7\u786E\u96C0\u88D9\u7FA4\u7136\u71C3\u5189\u67D3\u74E4\u58E4\u6518\u56B7\u8BA9\u9976\u6270\u7ED5\u60F9\u70ED\u58EC\u4EC1\u4EBA\u5FCD\u97E7\u4EFB\u8BA4\u5203\u598A\u7EAB\u6254\u4ECD\u65E5\u620E\u8338\u84C9\u8363\u878D\u7194\u6EB6\u5BB9\u7ED2\u5197\u63C9\u67D4\u8089\u8339\u8815\u5112\u5B7A\u5982\u8FB1\u4E73\u6C5D\u5165\u8925\u8F6F\u962E\u854A\u745E\u9510\u95F0\u6DA6\u82E5\u5F31\u6492\u6D12\u8428\u816E\u9CC3\u585E\u8D5B\u4E09\u53C1\uFFFD".split("");
      for (j = 0; j != D[200].length; ++j)
        if (D[200][j].charCodeAt(0) !== 65533) {
          e[D[200][j]] = 51200 + j;
          d[51200 + j] = D[200][j];
        }
      D[201] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u847D\u847E\u847F\u8480\u8481\u8483\u8484\u8485\u8486\u848A\u848D\u848F\u8490\u8491\u8492\u8493\u8494\u8495\u8496\u8498\u849A\u849B\u849D\u849E\u849F\u84A0\u84A2\u84A3\u84A4\u84A5\u84A6\u84A7\u84A8\u84A9\u84AA\u84AB\u84AC\u84AD\u84AE\u84B0\u84B1\u84B3\u84B5\u84B6\u84B7\u84BB\u84BC\u84BE\u84C0\u84C2\u84C3\u84C5\u84C6\u84C7\u84C8\u84CB\u84CC\u84CE\u84CF\u84D2\u84D4\u84D5\u84D7\uFFFD\u84D8\u84D9\u84DA\u84DB\u84DC\u84DE\u84E1\u84E2\u84E4\u84E7\u84E8\u84E9\u84EA\u84EB\u84ED\u84EE\u84EF\u84F1\u84F2\u84F3\u84F4\u84F5\u84F6\u84F7\u84F8\u84F9\u84FA\u84FB\u84FD\u84FE\u8500\u8501\u8502\u4F1E\u6563\u6851\u55D3\u4E27\u6414\u9A9A\u626B\u5AC2\u745F\u8272\u6DA9\u68EE\u50E7\u838E\u7802\u6740\u5239\u6C99\u7EB1\u50BB\u5565\u715E\u7B5B\u6652\u73CA\u82EB\u6749\u5C71\u5220\u717D\u886B\u95EA\u9655\u64C5\u8D61\u81B3\u5584\u6C55\u6247\u7F2E\u5892\u4F24\u5546\u8D4F\u664C\u4E0A\u5C1A\u88F3\u68A2\u634E\u7A0D\u70E7\u828D\u52FA\u97F6\u5C11\u54E8\u90B5\u7ECD\u5962\u8D4A\u86C7\u820C\u820D\u8D66\u6444\u5C04\u6151\u6D89\u793E\u8BBE\u7837\u7533\u547B\u4F38\u8EAB\u6DF1\u5A20\u7EC5\u795E\u6C88\u5BA1\u5A76\u751A\u80BE\u614E\u6E17\u58F0\u751F\u7525\u7272\u5347\u7EF3\uFFFD".split("");
      for (j = 0; j != D[201].length; ++j)
        if (D[201][j].charCodeAt(0) !== 65533) {
          e[D[201][j]] = 51456 + j;
          d[51456 + j] = D[201][j];
        }
      D[202] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8503\u8504\u8505\u8506\u8507\u8508\u8509\u850A\u850B\u850D\u850E\u850F\u8510\u8512\u8514\u8515\u8516\u8518\u8519\u851B\u851C\u851D\u851E\u8520\u8522\u8523\u8524\u8525\u8526\u8527\u8528\u8529\u852A\u852D\u852E\u852F\u8530\u8531\u8532\u8533\u8534\u8535\u8536\u853E\u853F\u8540\u8541\u8542\u8544\u8545\u8546\u8547\u854B\u854C\u854D\u854E\u854F\u8550\u8551\u8552\u8553\u8554\u8555\uFFFD\u8557\u8558\u855A\u855B\u855C\u855D\u855F\u8560\u8561\u8562\u8563\u8565\u8566\u8567\u8569\u856A\u856B\u856C\u856D\u856E\u856F\u8570\u8571\u8573\u8575\u8576\u8577\u8578\u857C\u857D\u857F\u8580\u8581\u7701\u76DB\u5269\u80DC\u5723\u5E08\u5931\u72EE\u65BD\u6E7F\u8BD7\u5C38\u8671\u5341\u77F3\u62FE\u65F6\u4EC0\u98DF\u8680\u5B9E\u8BC6\u53F2\u77E2\u4F7F\u5C4E\u9A76\u59CB\u5F0F\u793A\u58EB\u4E16\u67FF\u4E8B\u62ED\u8A93\u901D\u52BF\u662F\u55DC\u566C\u9002\u4ED5\u4F8D\u91CA\u9970\u6C0F\u5E02\u6043\u5BA4\u89C6\u8BD5\u6536\u624B\u9996\u5B88\u5BFF\u6388\u552E\u53D7\u7626\u517D\u852C\u67A2\u68B3\u6B8A\u6292\u8F93\u53D4\u8212\u6DD1\u758F\u4E66\u8D4E\u5B70\u719F\u85AF\u6691\u66D9\u7F72\u8700\u9ECD\u9F20\u5C5E\u672F\u8FF0\u6811\u675F\u620D\u7AD6\u5885\u5EB6\u6570\u6F31\uFFFD".split("");
      for (j = 0; j != D[202].length; ++j)
        if (D[202][j].charCodeAt(0) !== 65533) {
          e[D[202][j]] = 51712 + j;
          d[51712 + j] = D[202][j];
        }
      D[203] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8582\u8583\u8586\u8588\u8589\u858A\u858B\u858C\u858D\u858E\u8590\u8591\u8592\u8593\u8594\u8595\u8596\u8597\u8598\u8599\u859A\u859D\u859E\u859F\u85A0\u85A1\u85A2\u85A3\u85A5\u85A6\u85A7\u85A9\u85AB\u85AC\u85AD\u85B1\u85B2\u85B3\u85B4\u85B5\u85B6\u85B8\u85BA\u85BB\u85BC\u85BD\u85BE\u85BF\u85C0\u85C2\u85C3\u85C4\u85C5\u85C6\u85C7\u85C8\u85CA\u85CB\u85CC\u85CD\u85CE\u85D1\u85D2\uFFFD\u85D4\u85D6\u85D7\u85D8\u85D9\u85DA\u85DB\u85DD\u85DE\u85DF\u85E0\u85E1\u85E2\u85E3\u85E5\u85E6\u85E7\u85E8\u85EA\u85EB\u85EC\u85ED\u85EE\u85EF\u85F0\u85F1\u85F2\u85F3\u85F4\u85F5\u85F6\u85F7\u85F8\u6055\u5237\u800D\u6454\u8870\u7529\u5E05\u6813\u62F4\u971C\u53CC\u723D\u8C01\u6C34\u7761\u7A0E\u542E\u77AC\u987A\u821C\u8BF4\u7855\u6714\u70C1\u65AF\u6495\u5636\u601D\u79C1\u53F8\u4E1D\u6B7B\u8086\u5BFA\u55E3\u56DB\u4F3A\u4F3C\u9972\u5DF3\u677E\u8038\u6002\u9882\u9001\u5B8B\u8BBC\u8BF5\u641C\u8258\u64DE\u55FD\u82CF\u9165\u4FD7\u7D20\u901F\u7C9F\u50F3\u5851\u6EAF\u5BBF\u8BC9\u8083\u9178\u849C\u7B97\u867D\u968B\u968F\u7EE5\u9AD3\u788E\u5C81\u7A57\u9042\u96A7\u795F\u5B59\u635F\u7B0B\u84D1\u68AD\u5506\u7F29\u7410\u7D22\u9501\u6240\u584C\u4ED6\u5B83\u5979\u5854\uFFFD".split("");
      for (j = 0; j != D[203].length; ++j)
        if (D[203][j].charCodeAt(0) !== 65533) {
          e[D[203][j]] = 51968 + j;
          d[51968 + j] = D[203][j];
        }
      D[204] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u85F9\u85FA\u85FC\u85FD\u85FE\u8600\u8601\u8602\u8603\u8604\u8606\u8607\u8608\u8609\u860A\u860B\u860C\u860D\u860E\u860F\u8610\u8612\u8613\u8614\u8615\u8617\u8618\u8619\u861A\u861B\u861C\u861D\u861E\u861F\u8620\u8621\u8622\u8623\u8624\u8625\u8626\u8628\u862A\u862B\u862C\u862D\u862E\u862F\u8630\u8631\u8632\u8633\u8634\u8635\u8636\u8637\u8639\u863A\u863B\u863D\u863E\u863F\u8640\uFFFD\u8641\u8642\u8643\u8644\u8645\u8646\u8647\u8648\u8649\u864A\u864B\u864C\u8652\u8653\u8655\u8656\u8657\u8658\u8659\u865B\u865C\u865D\u865F\u8660\u8661\u8663\u8664\u8665\u8666\u8667\u8668\u8669\u866A\u736D\u631E\u8E4B\u8E0F\u80CE\u82D4\u62AC\u53F0\u6CF0\u915E\u592A\u6001\u6C70\u574D\u644A\u8D2A\u762B\u6EE9\u575B\u6A80\u75F0\u6F6D\u8C2D\u8C08\u5766\u6BEF\u8892\u78B3\u63A2\u53F9\u70AD\u6C64\u5858\u642A\u5802\u68E0\u819B\u5510\u7CD6\u5018\u8EBA\u6DCC\u8D9F\u70EB\u638F\u6D9B\u6ED4\u7EE6\u8404\u6843\u9003\u6DD8\u9676\u8BA8\u5957\u7279\u85E4\u817E\u75BC\u8A8A\u68AF\u5254\u8E22\u9511\u63D0\u9898\u8E44\u557C\u4F53\u66FF\u568F\u60D5\u6D95\u5243\u5C49\u5929\u6DFB\u586B\u7530\u751C\u606C\u8214\u8146\u6311\u6761\u8FE2\u773A\u8DF3\u8D34\u94C1\u5E16\u5385\u542C\u70C3\uFFFD".split("");
      for (j = 0; j != D[204].length; ++j)
        if (D[204][j].charCodeAt(0) !== 65533) {
          e[D[204][j]] = 52224 + j;
          d[52224 + j] = D[204][j];
        }
      D[205] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u866D\u866F\u8670\u8672\u8673\u8674\u8675\u8676\u8677\u8678\u8683\u8684\u8685\u8686\u8687\u8688\u8689\u868E\u868F\u8690\u8691\u8692\u8694\u8696\u8697\u8698\u8699\u869A\u869B\u869E\u869F\u86A0\u86A1\u86A2\u86A5\u86A6\u86AB\u86AD\u86AE\u86B2\u86B3\u86B7\u86B8\u86B9\u86BB\u86BC\u86BD\u86BE\u86BF\u86C1\u86C2\u86C3\u86C5\u86C8\u86CC\u86CD\u86D2\u86D3\u86D5\u86D6\u86D7\u86DA\u86DC\uFFFD\u86DD\u86E0\u86E1\u86E2\u86E3\u86E5\u86E6\u86E7\u86E8\u86EA\u86EB\u86EC\u86EF\u86F5\u86F6\u86F7\u86FA\u86FB\u86FC\u86FD\u86FF\u8701\u8704\u8705\u8706\u870B\u870C\u870E\u870F\u8710\u8711\u8714\u8716\u6C40\u5EF7\u505C\u4EAD\u5EAD\u633A\u8247\u901A\u6850\u916E\u77B3\u540C\u94DC\u5F64\u7AE5\u6876\u6345\u7B52\u7EDF\u75DB\u5077\u6295\u5934\u900F\u51F8\u79C3\u7A81\u56FE\u5F92\u9014\u6D82\u5C60\u571F\u5410\u5154\u6E4D\u56E2\u63A8\u9893\u817F\u8715\u892A\u9000\u541E\u5C6F\u81C0\u62D6\u6258\u8131\u9E35\u9640\u9A6E\u9A7C\u692D\u59A5\u62D3\u553E\u6316\u54C7\u86D9\u6D3C\u5A03\u74E6\u889C\u6B6A\u5916\u8C4C\u5F2F\u6E7E\u73A9\u987D\u4E38\u70F7\u5B8C\u7897\u633D\u665A\u7696\u60CB\u5B9B\u5A49\u4E07\u8155\u6C6A\u738B\u4EA1\u6789\u7F51\u5F80\u65FA\u671B\u5FD8\u5984\u5A01\uFFFD".split("");
      for (j = 0; j != D[205].length; ++j)
        if (D[205][j].charCodeAt(0) !== 65533) {
          e[D[205][j]] = 52480 + j;
          d[52480 + j] = D[205][j];
        }
      D[206] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8719\u871B\u871D\u871F\u8720\u8724\u8726\u8727\u8728\u872A\u872B\u872C\u872D\u872F\u8730\u8732\u8733\u8735\u8736\u8738\u8739\u873A\u873C\u873D\u8740\u8741\u8742\u8743\u8744\u8745\u8746\u874A\u874B\u874D\u874F\u8750\u8751\u8752\u8754\u8755\u8756\u8758\u875A\u875B\u875C\u875D\u875E\u875F\u8761\u8762\u8766\u8767\u8768\u8769\u876A\u876B\u876C\u876D\u876F\u8771\u8772\u8773\u8775\uFFFD\u8777\u8778\u8779\u877A\u877F\u8780\u8781\u8784\u8786\u8787\u8789\u878A\u878C\u878E\u878F\u8790\u8791\u8792\u8794\u8795\u8796\u8798\u8799\u879A\u879B\u879C\u879D\u879E\u87A0\u87A1\u87A2\u87A3\u87A4\u5DCD\u5FAE\u5371\u97E6\u8FDD\u6845\u56F4\u552F\u60DF\u4E3A\u6F4D\u7EF4\u82C7\u840E\u59D4\u4F1F\u4F2A\u5C3E\u7EAC\u672A\u851A\u5473\u754F\u80C3\u5582\u9B4F\u4F4D\u6E2D\u8C13\u5C09\u6170\u536B\u761F\u6E29\u868A\u6587\u95FB\u7EB9\u543B\u7A33\u7D0A\u95EE\u55E1\u7FC1\u74EE\u631D\u8717\u6DA1\u7A9D\u6211\u65A1\u5367\u63E1\u6C83\u5DEB\u545C\u94A8\u4E4C\u6C61\u8BEC\u5C4B\u65E0\u829C\u68A7\u543E\u5434\u6BCB\u6B66\u4E94\u6342\u5348\u821E\u4F0D\u4FAE\u575E\u620A\u96FE\u6664\u7269\u52FF\u52A1\u609F\u8BEF\u6614\u7199\u6790\u897F\u7852\u77FD\u6670\u563B\u5438\u9521\u727A\uFFFD".split("");
      for (j = 0; j != D[206].length; ++j)
        if (D[206][j].charCodeAt(0) !== 65533) {
          e[D[206][j]] = 52736 + j;
          d[52736 + j] = D[206][j];
        }
      D[207] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u87A5\u87A6\u87A7\u87A9\u87AA\u87AE\u87B0\u87B1\u87B2\u87B4\u87B6\u87B7\u87B8\u87B9\u87BB\u87BC\u87BE\u87BF\u87C1\u87C2\u87C3\u87C4\u87C5\u87C7\u87C8\u87C9\u87CC\u87CD\u87CE\u87CF\u87D0\u87D4\u87D5\u87D6\u87D7\u87D8\u87D9\u87DA\u87DC\u87DD\u87DE\u87DF\u87E1\u87E2\u87E3\u87E4\u87E6\u87E7\u87E8\u87E9\u87EB\u87EC\u87ED\u87EF\u87F0\u87F1\u87F2\u87F3\u87F4\u87F5\u87F6\u87F7\u87F8\uFFFD\u87FA\u87FB\u87FC\u87FD\u87FF\u8800\u8801\u8802\u8804\u8805\u8806\u8807\u8808\u8809\u880B\u880C\u880D\u880E\u880F\u8810\u8811\u8812\u8814\u8817\u8818\u8819\u881A\u881C\u881D\u881E\u881F\u8820\u8823\u7A00\u606F\u5E0C\u6089\u819D\u5915\u60DC\u7184\u70EF\u6EAA\u6C50\u7280\u6A84\u88AD\u5E2D\u4E60\u5AB3\u559C\u94E3\u6D17\u7CFB\u9699\u620F\u7EC6\u778E\u867E\u5323\u971E\u8F96\u6687\u5CE1\u4FA0\u72ED\u4E0B\u53A6\u590F\u5413\u6380\u9528\u5148\u4ED9\u9C9C\u7EA4\u54B8\u8D24\u8854\u8237\u95F2\u6D8E\u5F26\u5ACC\u663E\u9669\u73B0\u732E\u53BF\u817A\u9985\u7FA1\u5BAA\u9677\u9650\u7EBF\u76F8\u53A2\u9576\u9999\u7BB1\u8944\u6E58\u4E61\u7FD4\u7965\u8BE6\u60F3\u54CD\u4EAB\u9879\u5DF7\u6A61\u50CF\u5411\u8C61\u8427\u785D\u9704\u524A\u54EE\u56A3\u9500\u6D88\u5BB5\u6DC6\u6653\uFFFD".split("");
      for (j = 0; j != D[207].length; ++j)
        if (D[207][j].charCodeAt(0) !== 65533) {
          e[D[207][j]] = 52992 + j;
          d[52992 + j] = D[207][j];
        }
      D[208] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8824\u8825\u8826\u8827\u8828\u8829\u882A\u882B\u882C\u882D\u882E\u882F\u8830\u8831\u8833\u8834\u8835\u8836\u8837\u8838\u883A\u883B\u883D\u883E\u883F\u8841\u8842\u8843\u8846\u8847\u8848\u8849\u884A\u884B\u884E\u884F\u8850\u8851\u8852\u8853\u8855\u8856\u8858\u885A\u885B\u885C\u885D\u885E\u885F\u8860\u8866\u8867\u886A\u886D\u886F\u8871\u8873\u8874\u8875\u8876\u8878\u8879\u887A\uFFFD\u887B\u887C\u8880\u8883\u8886\u8887\u8889\u888A\u888C\u888E\u888F\u8890\u8891\u8893\u8894\u8895\u8897\u8898\u8899\u889A\u889B\u889D\u889E\u889F\u88A0\u88A1\u88A3\u88A5\u88A6\u88A7\u88A8\u88A9\u88AA\u5C0F\u5B5D\u6821\u8096\u5578\u7B11\u6548\u6954\u4E9B\u6B47\u874E\u978B\u534F\u631F\u643A\u90AA\u659C\u80C1\u8C10\u5199\u68B0\u5378\u87F9\u61C8\u6CC4\u6CFB\u8C22\u5C51\u85AA\u82AF\u950C\u6B23\u8F9B\u65B0\u5FFB\u5FC3\u4FE1\u8845\u661F\u8165\u7329\u60FA\u5174\u5211\u578B\u5F62\u90A2\u884C\u9192\u5E78\u674F\u6027\u59D3\u5144\u51F6\u80F8\u5308\u6C79\u96C4\u718A\u4F11\u4FEE\u7F9E\u673D\u55C5\u9508\u79C0\u8896\u7EE3\u589F\u620C\u9700\u865A\u5618\u987B\u5F90\u8BB8\u84C4\u9157\u53D9\u65ED\u5E8F\u755C\u6064\u7D6E\u5A7F\u7EEA\u7EED\u8F69\u55A7\u5BA3\u60AC\u65CB\u7384\uFFFD".split("");
      for (j = 0; j != D[208].length; ++j)
        if (D[208][j].charCodeAt(0) !== 65533) {
          e[D[208][j]] = 53248 + j;
          d[53248 + j] = D[208][j];
        }
      D[209] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u88AC\u88AE\u88AF\u88B0\u88B2\u88B3\u88B4\u88B5\u88B6\u88B8\u88B9\u88BA\u88BB\u88BD\u88BE\u88BF\u88C0\u88C3\u88C4\u88C7\u88C8\u88CA\u88CB\u88CC\u88CD\u88CF\u88D0\u88D1\u88D3\u88D6\u88D7\u88DA\u88DB\u88DC\u88DD\u88DE\u88E0\u88E1\u88E6\u88E7\u88E9\u88EA\u88EB\u88EC\u88ED\u88EE\u88EF\u88F2\u88F5\u88F6\u88F7\u88FA\u88FB\u88FD\u88FF\u8900\u8901\u8903\u8904\u8905\u8906\u8907\u8908\uFFFD\u8909\u890B\u890C\u890D\u890E\u890F\u8911\u8914\u8915\u8916\u8917\u8918\u891C\u891D\u891E\u891F\u8920\u8922\u8923\u8924\u8926\u8927\u8928\u8929\u892C\u892D\u892E\u892F\u8931\u8932\u8933\u8935\u8937\u9009\u7663\u7729\u7EDA\u9774\u859B\u5B66\u7A74\u96EA\u8840\u52CB\u718F\u5FAA\u65EC\u8BE2\u5BFB\u9A6F\u5DE1\u6B89\u6C5B\u8BAD\u8BAF\u900A\u8FC5\u538B\u62BC\u9E26\u9E2D\u5440\u4E2B\u82BD\u7259\u869C\u5D16\u8859\u6DAF\u96C5\u54D1\u4E9A\u8BB6\u7109\u54BD\u9609\u70DF\u6DF9\u76D0\u4E25\u7814\u8712\u5CA9\u5EF6\u8A00\u989C\u960E\u708E\u6CBF\u5944\u63A9\u773C\u884D\u6F14\u8273\u5830\u71D5\u538C\u781A\u96C1\u5501\u5F66\u7130\u5BB4\u8C1A\u9A8C\u6B83\u592E\u9E2F\u79E7\u6768\u626C\u4F6F\u75A1\u7F8A\u6D0B\u9633\u6C27\u4EF0\u75D2\u517B\u6837\u6F3E\u9080\u8170\u5996\u7476\uFFFD".split("");
      for (j = 0; j != D[209].length; ++j)
        if (D[209][j].charCodeAt(0) !== 65533) {
          e[D[209][j]] = 53504 + j;
          d[53504 + j] = D[209][j];
        }
      D[210] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8938\u8939\u893A\u893B\u893C\u893D\u893E\u893F\u8940\u8942\u8943\u8945\u8946\u8947\u8948\u8949\u894A\u894B\u894C\u894D\u894E\u894F\u8950\u8951\u8952\u8953\u8954\u8955\u8956\u8957\u8958\u8959\u895A\u895B\u895C\u895D\u8960\u8961\u8962\u8963\u8964\u8965\u8967\u8968\u8969\u896A\u896B\u896C\u896D\u896E\u896F\u8970\u8971\u8972\u8973\u8974\u8975\u8976\u8977\u8978\u8979\u897A\u897C\uFFFD\u897D\u897E\u8980\u8982\u8984\u8985\u8987\u8988\u8989\u898A\u898B\u898C\u898D\u898E\u898F\u8990\u8991\u8992\u8993\u8994\u8995\u8996\u8997\u8998\u8999\u899A\u899B\u899C\u899D\u899E\u899F\u89A0\u89A1\u6447\u5C27\u9065\u7A91\u8C23\u59DA\u54AC\u8200\u836F\u8981\u8000\u6930\u564E\u8036\u7237\u91CE\u51B6\u4E5F\u9875\u6396\u4E1A\u53F6\u66F3\u814B\u591C\u6DB2\u4E00\u58F9\u533B\u63D6\u94F1\u4F9D\u4F0A\u8863\u9890\u5937\u9057\u79FB\u4EEA\u80F0\u7591\u6C82\u5B9C\u59E8\u5F5D\u6905\u8681\u501A\u5DF2\u4E59\u77E3\u4EE5\u827A\u6291\u6613\u9091\u5C79\u4EBF\u5F79\u81C6\u9038\u8084\u75AB\u4EA6\u88D4\u610F\u6BC5\u5FC6\u4E49\u76CA\u6EA2\u8BE3\u8BAE\u8C0A\u8BD1\u5F02\u7FFC\u7FCC\u7ECE\u8335\u836B\u56E0\u6BB7\u97F3\u9634\u59FB\u541F\u94F6\u6DEB\u5BC5\u996E\u5C39\u5F15\u9690\uFFFD".split("");
      for (j = 0; j != D[210].length; ++j)
        if (D[210][j].charCodeAt(0) !== 65533) {
          e[D[210][j]] = 53760 + j;
          d[53760 + j] = D[210][j];
        }
      D[211] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u89A2\u89A3\u89A4\u89A5\u89A6\u89A7\u89A8\u89A9\u89AA\u89AB\u89AC\u89AD\u89AE\u89AF\u89B0\u89B1\u89B2\u89B3\u89B4\u89B5\u89B6\u89B7\u89B8\u89B9\u89BA\u89BB\u89BC\u89BD\u89BE\u89BF\u89C0\u89C3\u89CD\u89D3\u89D4\u89D5\u89D7\u89D8\u89D9\u89DB\u89DD\u89DF\u89E0\u89E1\u89E2\u89E4\u89E7\u89E8\u89E9\u89EA\u89EC\u89ED\u89EE\u89F0\u89F1\u89F2\u89F4\u89F5\u89F6\u89F7\u89F8\u89F9\u89FA\uFFFD\u89FB\u89FC\u89FD\u89FE\u89FF\u8A01\u8A02\u8A03\u8A04\u8A05\u8A06\u8A08\u8A09\u8A0A\u8A0B\u8A0C\u8A0D\u8A0E\u8A0F\u8A10\u8A11\u8A12\u8A13\u8A14\u8A15\u8A16\u8A17\u8A18\u8A19\u8A1A\u8A1B\u8A1C\u8A1D\u5370\u82F1\u6A31\u5A74\u9E70\u5E94\u7F28\u83B9\u8424\u8425\u8367\u8747\u8FCE\u8D62\u76C8\u5F71\u9896\u786C\u6620\u54DF\u62E5\u4F63\u81C3\u75C8\u5EB8\u96CD\u8E0A\u86F9\u548F\u6CF3\u6D8C\u6C38\u607F\u52C7\u7528\u5E7D\u4F18\u60A0\u5FE7\u5C24\u7531\u90AE\u94C0\u72B9\u6CB9\u6E38\u9149\u6709\u53CB\u53F3\u4F51\u91C9\u8BF1\u53C8\u5E7C\u8FC2\u6DE4\u4E8E\u76C2\u6986\u865E\u611A\u8206\u4F59\u4FDE\u903E\u9C7C\u6109\u6E1D\u6E14\u9685\u4E88\u5A31\u96E8\u4E0E\u5C7F\u79B9\u5B87\u8BED\u7FBD\u7389\u57DF\u828B\u90C1\u5401\u9047\u55BB\u5CEA\u5FA1\u6108\u6B32\u72F1\u80B2\u8A89\uFFFD".split("");
      for (j = 0; j != D[211].length; ++j)
        if (D[211][j].charCodeAt(0) !== 65533) {
          e[D[211][j]] = 54016 + j;
          d[54016 + j] = D[211][j];
        }
      D[212] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8A1E\u8A1F\u8A20\u8A21\u8A22\u8A23\u8A24\u8A25\u8A26\u8A27\u8A28\u8A29\u8A2A\u8A2B\u8A2C\u8A2D\u8A2E\u8A2F\u8A30\u8A31\u8A32\u8A33\u8A34\u8A35\u8A36\u8A37\u8A38\u8A39\u8A3A\u8A3B\u8A3C\u8A3D\u8A3F\u8A40\u8A41\u8A42\u8A43\u8A44\u8A45\u8A46\u8A47\u8A49\u8A4A\u8A4B\u8A4C\u8A4D\u8A4E\u8A4F\u8A50\u8A51\u8A52\u8A53\u8A54\u8A55\u8A56\u8A57\u8A58\u8A59\u8A5A\u8A5B\u8A5C\u8A5D\u8A5E\uFFFD\u8A5F\u8A60\u8A61\u8A62\u8A63\u8A64\u8A65\u8A66\u8A67\u8A68\u8A69\u8A6A\u8A6B\u8A6C\u8A6D\u8A6E\u8A6F\u8A70\u8A71\u8A72\u8A73\u8A74\u8A75\u8A76\u8A77\u8A78\u8A7A\u8A7B\u8A7C\u8A7D\u8A7E\u8A7F\u8A80\u6D74\u5BD3\u88D5\u9884\u8C6B\u9A6D\u9E33\u6E0A\u51A4\u5143\u57A3\u8881\u539F\u63F4\u8F95\u56ED\u5458\u5706\u733F\u6E90\u7F18\u8FDC\u82D1\u613F\u6028\u9662\u66F0\u7EA6\u8D8A\u8DC3\u94A5\u5CB3\u7CA4\u6708\u60A6\u9605\u8018\u4E91\u90E7\u5300\u9668\u5141\u8FD0\u8574\u915D\u6655\u97F5\u5B55\u531D\u7838\u6742\u683D\u54C9\u707E\u5BB0\u8F7D\u518D\u5728\u54B1\u6512\u6682\u8D5E\u8D43\u810F\u846C\u906D\u7CDF\u51FF\u85FB\u67A3\u65E9\u6FA1\u86A4\u8E81\u566A\u9020\u7682\u7076\u71E5\u8D23\u62E9\u5219\u6CFD\u8D3C\u600E\u589E\u618E\u66FE\u8D60\u624E\u55B3\u6E23\u672D\u8F67\uFFFD".split("");
      for (j = 0; j != D[212].length; ++j)
        if (D[212][j].charCodeAt(0) !== 65533) {
          e[D[212][j]] = 54272 + j;
          d[54272 + j] = D[212][j];
        }
      D[213] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8A81\u8A82\u8A83\u8A84\u8A85\u8A86\u8A87\u8A88\u8A8B\u8A8C\u8A8D\u8A8E\u8A8F\u8A90\u8A91\u8A92\u8A94\u8A95\u8A96\u8A97\u8A98\u8A99\u8A9A\u8A9B\u8A9C\u8A9D\u8A9E\u8A9F\u8AA0\u8AA1\u8AA2\u8AA3\u8AA4\u8AA5\u8AA6\u8AA7\u8AA8\u8AA9\u8AAA\u8AAB\u8AAC\u8AAD\u8AAE\u8AAF\u8AB0\u8AB1\u8AB2\u8AB3\u8AB4\u8AB5\u8AB6\u8AB7\u8AB8\u8AB9\u8ABA\u8ABB\u8ABC\u8ABD\u8ABE\u8ABF\u8AC0\u8AC1\u8AC2\uFFFD\u8AC3\u8AC4\u8AC5\u8AC6\u8AC7\u8AC8\u8AC9\u8ACA\u8ACB\u8ACC\u8ACD\u8ACE\u8ACF\u8AD0\u8AD1\u8AD2\u8AD3\u8AD4\u8AD5\u8AD6\u8AD7\u8AD8\u8AD9\u8ADA\u8ADB\u8ADC\u8ADD\u8ADE\u8ADF\u8AE0\u8AE1\u8AE2\u8AE3\u94E1\u95F8\u7728\u6805\u69A8\u548B\u4E4D\u70B8\u8BC8\u6458\u658B\u5B85\u7A84\u503A\u5BE8\u77BB\u6BE1\u8A79\u7C98\u6CBE\u76CF\u65A9\u8F97\u5D2D\u5C55\u8638\u6808\u5360\u6218\u7AD9\u6E5B\u7EFD\u6A1F\u7AE0\u5F70\u6F33\u5F20\u638C\u6DA8\u6756\u4E08\u5E10\u8D26\u4ED7\u80C0\u7634\u969C\u62DB\u662D\u627E\u6CBC\u8D75\u7167\u7F69\u5146\u8087\u53EC\u906E\u6298\u54F2\u86F0\u8F99\u8005\u9517\u8517\u8FD9\u6D59\u73CD\u659F\u771F\u7504\u7827\u81FB\u8D1E\u9488\u4FA6\u6795\u75B9\u8BCA\u9707\u632F\u9547\u9635\u84B8\u6323\u7741\u5F81\u72F0\u4E89\u6014\u6574\u62EF\u6B63\u653F\uFFFD".split("");
      for (j = 0; j != D[213].length; ++j)
        if (D[213][j].charCodeAt(0) !== 65533) {
          e[D[213][j]] = 54528 + j;
          d[54528 + j] = D[213][j];
        }
      D[214] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8AE4\u8AE5\u8AE6\u8AE7\u8AE8\u8AE9\u8AEA\u8AEB\u8AEC\u8AED\u8AEE\u8AEF\u8AF0\u8AF1\u8AF2\u8AF3\u8AF4\u8AF5\u8AF6\u8AF7\u8AF8\u8AF9\u8AFA\u8AFB\u8AFC\u8AFD\u8AFE\u8AFF\u8B00\u8B01\u8B02\u8B03\u8B04\u8B05\u8B06\u8B08\u8B09\u8B0A\u8B0B\u8B0C\u8B0D\u8B0E\u8B0F\u8B10\u8B11\u8B12\u8B13\u8B14\u8B15\u8B16\u8B17\u8B18\u8B19\u8B1A\u8B1B\u8B1C\u8B1D\u8B1E\u8B1F\u8B20\u8B21\u8B22\u8B23\uFFFD\u8B24\u8B25\u8B27\u8B28\u8B29\u8B2A\u8B2B\u8B2C\u8B2D\u8B2E\u8B2F\u8B30\u8B31\u8B32\u8B33\u8B34\u8B35\u8B36\u8B37\u8B38\u8B39\u8B3A\u8B3B\u8B3C\u8B3D\u8B3E\u8B3F\u8B40\u8B41\u8B42\u8B43\u8B44\u8B45\u5E27\u75C7\u90D1\u8BC1\u829D\u679D\u652F\u5431\u8718\u77E5\u80A2\u8102\u6C41\u4E4B\u7EC7\u804C\u76F4\u690D\u6B96\u6267\u503C\u4F84\u5740\u6307\u6B62\u8DBE\u53EA\u65E8\u7EB8\u5FD7\u631A\u63B7\u81F3\u81F4\u7F6E\u5E1C\u5CD9\u5236\u667A\u79E9\u7A1A\u8D28\u7099\u75D4\u6EDE\u6CBB\u7A92\u4E2D\u76C5\u5FE0\u949F\u8877\u7EC8\u79CD\u80BF\u91CD\u4EF2\u4F17\u821F\u5468\u5DDE\u6D32\u8BCC\u7CA5\u8F74\u8098\u5E1A\u5492\u76B1\u5B99\u663C\u9AA4\u73E0\u682A\u86DB\u6731\u732A\u8BF8\u8BDB\u9010\u7AF9\u70DB\u716E\u62C4\u77A9\u5631\u4E3B\u8457\u67F1\u52A9\u86C0\u8D2E\u94F8\u7B51\uFFFD".split("");
      for (j = 0; j != D[214].length; ++j)
        if (D[214][j].charCodeAt(0) !== 65533) {
          e[D[214][j]] = 54784 + j;
          d[54784 + j] = D[214][j];
        }
      D[215] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B46\u8B47\u8B48\u8B49\u8B4A\u8B4B\u8B4C\u8B4D\u8B4E\u8B4F\u8B50\u8B51\u8B52\u8B53\u8B54\u8B55\u8B56\u8B57\u8B58\u8B59\u8B5A\u8B5B\u8B5C\u8B5D\u8B5E\u8B5F\u8B60\u8B61\u8B62\u8B63\u8B64\u8B65\u8B67\u8B68\u8B69\u8B6A\u8B6B\u8B6D\u8B6E\u8B6F\u8B70\u8B71\u8B72\u8B73\u8B74\u8B75\u8B76\u8B77\u8B78\u8B79\u8B7A\u8B7B\u8B7C\u8B7D\u8B7E\u8B7F\u8B80\u8B81\u8B82\u8B83\u8B84\u8B85\u8B86\uFFFD\u8B87\u8B88\u8B89\u8B8A\u8B8B\u8B8C\u8B8D\u8B8E\u8B8F\u8B90\u8B91\u8B92\u8B93\u8B94\u8B95\u8B96\u8B97\u8B98\u8B99\u8B9A\u8B9B\u8B9C\u8B9D\u8B9E\u8B9F\u8BAC\u8BB1\u8BBB\u8BC7\u8BD0\u8BEA\u8C09\u8C1E\u4F4F\u6CE8\u795D\u9A7B\u6293\u722A\u62FD\u4E13\u7816\u8F6C\u64B0\u8D5A\u7BC6\u6869\u5E84\u88C5\u5986\u649E\u58EE\u72B6\u690E\u9525\u8FFD\u8D58\u5760\u7F00\u8C06\u51C6\u6349\u62D9\u5353\u684C\u7422\u8301\u914C\u5544\u7740\u707C\u6D4A\u5179\u54A8\u8D44\u59FF\u6ECB\u6DC4\u5B5C\u7D2B\u4ED4\u7C7D\u6ED3\u5B50\u81EA\u6E0D\u5B57\u9B03\u68D5\u8E2A\u5B97\u7EFC\u603B\u7EB5\u90B9\u8D70\u594F\u63CD\u79DF\u8DB3\u5352\u65CF\u7956\u8BC5\u963B\u7EC4\u94BB\u7E82\u5634\u9189\u6700\u7F6A\u5C0A\u9075\u6628\u5DE6\u4F50\u67DE\u505A\u4F5C\u5750\u5EA7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[215].length; ++j)
        if (D[215][j].charCodeAt(0) !== 65533) {
          e[D[215][j]] = 55040 + j;
          d[55040 + j] = D[215][j];
        }
      D[216] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8C38\u8C39\u8C3A\u8C3B\u8C3C\u8C3D\u8C3E\u8C3F\u8C40\u8C42\u8C43\u8C44\u8C45\u8C48\u8C4A\u8C4B\u8C4D\u8C4E\u8C4F\u8C50\u8C51\u8C52\u8C53\u8C54\u8C56\u8C57\u8C58\u8C59\u8C5B\u8C5C\u8C5D\u8C5E\u8C5F\u8C60\u8C63\u8C64\u8C65\u8C66\u8C67\u8C68\u8C69\u8C6C\u8C6D\u8C6E\u8C6F\u8C70\u8C71\u8C72\u8C74\u8C75\u8C76\u8C77\u8C7B\u8C7C\u8C7D\u8C7E\u8C7F\u8C80\u8C81\u8C83\u8C84\u8C86\u8C87\uFFFD\u8C88\u8C8B\u8C8D\u8C8E\u8C8F\u8C90\u8C91\u8C92\u8C93\u8C95\u8C96\u8C97\u8C99\u8C9A\u8C9B\u8C9C\u8C9D\u8C9E\u8C9F\u8CA0\u8CA1\u8CA2\u8CA3\u8CA4\u8CA5\u8CA6\u8CA7\u8CA8\u8CA9\u8CAA\u8CAB\u8CAC\u8CAD\u4E8D\u4E0C\u5140\u4E10\u5EFF\u5345\u4E15\u4E98\u4E1E\u9B32\u5B6C\u5669\u4E28\u79BA\u4E3F\u5315\u4E47\u592D\u723B\u536E\u6C10\u56DF\u80E4\u9997\u6BD3\u777E\u9F17\u4E36\u4E9F\u9F10\u4E5C\u4E69\u4E93\u8288\u5B5B\u556C\u560F\u4EC4\u538D\u539D\u53A3\u53A5\u53AE\u9765\u8D5D\u531A\u53F5\u5326\u532E\u533E\u8D5C\u5366\u5363\u5202\u5208\u520E\u522D\u5233\u523F\u5240\u524C\u525E\u5261\u525C\u84AF\u527D\u5282\u5281\u5290\u5293\u5182\u7F54\u4EBB\u4EC3\u4EC9\u4EC2\u4EE8\u4EE1\u4EEB\u4EDE\u4F1B\u4EF3\u4F22\u4F64\u4EF5\u4F25\u4F27\u4F09\u4F2B\u4F5E\u4F67\u6538\u4F5A\u4F5D\uFFFD".split("");
      for (j = 0; j != D[216].length; ++j)
        if (D[216][j].charCodeAt(0) !== 65533) {
          e[D[216][j]] = 55296 + j;
          d[55296 + j] = D[216][j];
        }
      D[217] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8CAE\u8CAF\u8CB0\u8CB1\u8CB2\u8CB3\u8CB4\u8CB5\u8CB6\u8CB7\u8CB8\u8CB9\u8CBA\u8CBB\u8CBC\u8CBD\u8CBE\u8CBF\u8CC0\u8CC1\u8CC2\u8CC3\u8CC4\u8CC5\u8CC6\u8CC7\u8CC8\u8CC9\u8CCA\u8CCB\u8CCC\u8CCD\u8CCE\u8CCF\u8CD0\u8CD1\u8CD2\u8CD3\u8CD4\u8CD5\u8CD6\u8CD7\u8CD8\u8CD9\u8CDA\u8CDB\u8CDC\u8CDD\u8CDE\u8CDF\u8CE0\u8CE1\u8CE2\u8CE3\u8CE4\u8CE5\u8CE6\u8CE7\u8CE8\u8CE9\u8CEA\u8CEB\u8CEC\uFFFD\u8CED\u8CEE\u8CEF\u8CF0\u8CF1\u8CF2\u8CF3\u8CF4\u8CF5\u8CF6\u8CF7\u8CF8\u8CF9\u8CFA\u8CFB\u8CFC\u8CFD\u8CFE\u8CFF\u8D00\u8D01\u8D02\u8D03\u8D04\u8D05\u8D06\u8D07\u8D08\u8D09\u8D0A\u8D0B\u8D0C\u8D0D\u4F5F\u4F57\u4F32\u4F3D\u4F76\u4F74\u4F91\u4F89\u4F83\u4F8F\u4F7E\u4F7B\u4FAA\u4F7C\u4FAC\u4F94\u4FE6\u4FE8\u4FEA\u4FC5\u4FDA\u4FE3\u4FDC\u4FD1\u4FDF\u4FF8\u5029\u504C\u4FF3\u502C\u500F\u502E\u502D\u4FFE\u501C\u500C\u5025\u5028\u507E\u5043\u5055\u5048\u504E\u506C\u507B\u50A5\u50A7\u50A9\u50BA\u50D6\u5106\u50ED\u50EC\u50E6\u50EE\u5107\u510B\u4EDD\u6C3D\u4F58\u4F65\u4FCE\u9FA0\u6C46\u7C74\u516E\u5DFD\u9EC9\u9998\u5181\u5914\u52F9\u530D\u8A07\u5310\u51EB\u5919\u5155\u4EA0\u5156\u4EB3\u886E\u88A4\u4EB5\u8114\u88D2\u7980\u5B34\u8803\u7FB8\u51AB\u51B1\u51BD\u51BC\uFFFD".split("");
      for (j = 0; j != D[217].length; ++j)
        if (D[217][j].charCodeAt(0) !== 65533) {
          e[D[217][j]] = 55552 + j;
          d[55552 + j] = D[217][j];
        }
      D[218] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8D0E\u8D0F\u8D10\u8D11\u8D12\u8D13\u8D14\u8D15\u8D16\u8D17\u8D18\u8D19\u8D1A\u8D1B\u8D1C\u8D20\u8D51\u8D52\u8D57\u8D5F\u8D65\u8D68\u8D69\u8D6A\u8D6C\u8D6E\u8D6F\u8D71\u8D72\u8D78\u8D79\u8D7A\u8D7B\u8D7C\u8D7D\u8D7E\u8D7F\u8D80\u8D82\u8D83\u8D86\u8D87\u8D88\u8D89\u8D8C\u8D8D\u8D8E\u8D8F\u8D90\u8D92\u8D93\u8D95\u8D96\u8D97\u8D98\u8D99\u8D9A\u8D9B\u8D9C\u8D9D\u8D9E\u8DA0\u8DA1\uFFFD\u8DA2\u8DA4\u8DA5\u8DA6\u8DA7\u8DA8\u8DA9\u8DAA\u8DAB\u8DAC\u8DAD\u8DAE\u8DAF\u8DB0\u8DB2\u8DB6\u8DB7\u8DB9\u8DBB\u8DBD\u8DC0\u8DC1\u8DC2\u8DC5\u8DC7\u8DC8\u8DC9\u8DCA\u8DCD\u8DD0\u8DD2\u8DD3\u8DD4\u51C7\u5196\u51A2\u51A5\u8BA0\u8BA6\u8BA7\u8BAA\u8BB4\u8BB5\u8BB7\u8BC2\u8BC3\u8BCB\u8BCF\u8BCE\u8BD2\u8BD3\u8BD4\u8BD6\u8BD8\u8BD9\u8BDC\u8BDF\u8BE0\u8BE4\u8BE8\u8BE9\u8BEE\u8BF0\u8BF3\u8BF6\u8BF9\u8BFC\u8BFF\u8C00\u8C02\u8C04\u8C07\u8C0C\u8C0F\u8C11\u8C12\u8C14\u8C15\u8C16\u8C19\u8C1B\u8C18\u8C1D\u8C1F\u8C20\u8C21\u8C25\u8C27\u8C2A\u8C2B\u8C2E\u8C2F\u8C32\u8C33\u8C35\u8C36\u5369\u537A\u961D\u9622\u9621\u9631\u962A\u963D\u963C\u9642\u9649\u9654\u965F\u9667\u966C\u9672\u9674\u9688\u968D\u9697\u96B0\u9097\u909B\u909D\u9099\u90AC\u90A1\u90B4\u90B3\u90B6\u90BA\uFFFD".split("");
      for (j = 0; j != D[218].length; ++j)
        if (D[218][j].charCodeAt(0) !== 65533) {
          e[D[218][j]] = 55808 + j;
          d[55808 + j] = D[218][j];
        }
      D[219] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8DD5\u8DD8\u8DD9\u8DDC\u8DE0\u8DE1\u8DE2\u8DE5\u8DE6\u8DE7\u8DE9\u8DED\u8DEE\u8DF0\u8DF1\u8DF2\u8DF4\u8DF6\u8DFC\u8DFE\u8DFF\u8E00\u8E01\u8E02\u8E03\u8E04\u8E06\u8E07\u8E08\u8E0B\u8E0D\u8E0E\u8E10\u8E11\u8E12\u8E13\u8E15\u8E16\u8E17\u8E18\u8E19\u8E1A\u8E1B\u8E1C\u8E20\u8E21\u8E24\u8E25\u8E26\u8E27\u8E28\u8E2B\u8E2D\u8E30\u8E32\u8E33\u8E34\u8E36\u8E37\u8E38\u8E3B\u8E3C\u8E3E\uFFFD\u8E3F\u8E43\u8E45\u8E46\u8E4C\u8E4D\u8E4E\u8E4F\u8E50\u8E53\u8E54\u8E55\u8E56\u8E57\u8E58\u8E5A\u8E5B\u8E5C\u8E5D\u8E5E\u8E5F\u8E60\u8E61\u8E62\u8E63\u8E64\u8E65\u8E67\u8E68\u8E6A\u8E6B\u8E6E\u8E71\u90B8\u90B0\u90CF\u90C5\u90BE\u90D0\u90C4\u90C7\u90D3\u90E6\u90E2\u90DC\u90D7\u90DB\u90EB\u90EF\u90FE\u9104\u9122\u911E\u9123\u9131\u912F\u9139\u9143\u9146\u520D\u5942\u52A2\u52AC\u52AD\u52BE\u54FF\u52D0\u52D6\u52F0\u53DF\u71EE\u77CD\u5EF4\u51F5\u51FC\u9B2F\u53B6\u5F01\u755A\u5DEF\u574C\u57A9\u57A1\u587E\u58BC\u58C5\u58D1\u5729\u572C\u572A\u5733\u5739\u572E\u572F\u575C\u573B\u5742\u5769\u5785\u576B\u5786\u577C\u577B\u5768\u576D\u5776\u5773\u57AD\u57A4\u578C\u57B2\u57CF\u57A7\u57B4\u5793\u57A0\u57D5\u57D8\u57DA\u57D9\u57D2\u57B8\u57F4\u57EF\u57F8\u57E4\u57DD\uFFFD".split("");
      for (j = 0; j != D[219].length; ++j)
        if (D[219][j].charCodeAt(0) !== 65533) {
          e[D[219][j]] = 56064 + j;
          d[56064 + j] = D[219][j];
        }
      D[220] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8E73\u8E75\u8E77\u8E78\u8E79\u8E7A\u8E7B\u8E7D\u8E7E\u8E80\u8E82\u8E83\u8E84\u8E86\u8E88\u8E89\u8E8A\u8E8B\u8E8C\u8E8D\u8E8E\u8E91\u8E92\u8E93\u8E95\u8E96\u8E97\u8E98\u8E99\u8E9A\u8E9B\u8E9D\u8E9F\u8EA0\u8EA1\u8EA2\u8EA3\u8EA4\u8EA5\u8EA6\u8EA7\u8EA8\u8EA9\u8EAA\u8EAD\u8EAE\u8EB0\u8EB1\u8EB3\u8EB4\u8EB5\u8EB6\u8EB7\u8EB8\u8EB9\u8EBB\u8EBC\u8EBD\u8EBE\u8EBF\u8EC0\u8EC1\u8EC2\uFFFD\u8EC3\u8EC4\u8EC5\u8EC6\u8EC7\u8EC8\u8EC9\u8ECA\u8ECB\u8ECC\u8ECD\u8ECF\u8ED0\u8ED1\u8ED2\u8ED3\u8ED4\u8ED5\u8ED6\u8ED7\u8ED8\u8ED9\u8EDA\u8EDB\u8EDC\u8EDD\u8EDE\u8EDF\u8EE0\u8EE1\u8EE2\u8EE3\u8EE4\u580B\u580D\u57FD\u57ED\u5800\u581E\u5819\u5844\u5820\u5865\u586C\u5881\u5889\u589A\u5880\u99A8\u9F19\u61FF\u8279\u827D\u827F\u828F\u828A\u82A8\u8284\u828E\u8291\u8297\u8299\u82AB\u82B8\u82BE\u82B0\u82C8\u82CA\u82E3\u8298\u82B7\u82AE\u82CB\u82CC\u82C1\u82A9\u82B4\u82A1\u82AA\u829F\u82C4\u82CE\u82A4\u82E1\u8309\u82F7\u82E4\u830F\u8307\u82DC\u82F4\u82D2\u82D8\u830C\u82FB\u82D3\u8311\u831A\u8306\u8314\u8315\u82E0\u82D5\u831C\u8351\u835B\u835C\u8308\u8392\u833C\u8334\u8331\u839B\u835E\u832F\u834F\u8347\u8343\u835F\u8340\u8317\u8360\u832D\u833A\u8333\u8366\u8365\uFFFD".split("");
      for (j = 0; j != D[220].length; ++j)
        if (D[220][j].charCodeAt(0) !== 65533) {
          e[D[220][j]] = 56320 + j;
          d[56320 + j] = D[220][j];
        }
      D[221] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8EE5\u8EE6\u8EE7\u8EE8\u8EE9\u8EEA\u8EEB\u8EEC\u8EED\u8EEE\u8EEF\u8EF0\u8EF1\u8EF2\u8EF3\u8EF4\u8EF5\u8EF6\u8EF7\u8EF8\u8EF9\u8EFA\u8EFB\u8EFC\u8EFD\u8EFE\u8EFF\u8F00\u8F01\u8F02\u8F03\u8F04\u8F05\u8F06\u8F07\u8F08\u8F09\u8F0A\u8F0B\u8F0C\u8F0D\u8F0E\u8F0F\u8F10\u8F11\u8F12\u8F13\u8F14\u8F15\u8F16\u8F17\u8F18\u8F19\u8F1A\u8F1B\u8F1C\u8F1D\u8F1E\u8F1F\u8F20\u8F21\u8F22\u8F23\uFFFD\u8F24\u8F25\u8F26\u8F27\u8F28\u8F29\u8F2A\u8F2B\u8F2C\u8F2D\u8F2E\u8F2F\u8F30\u8F31\u8F32\u8F33\u8F34\u8F35\u8F36\u8F37\u8F38\u8F39\u8F3A\u8F3B\u8F3C\u8F3D\u8F3E\u8F3F\u8F40\u8F41\u8F42\u8F43\u8F44\u8368\u831B\u8369\u836C\u836A\u836D\u836E\u83B0\u8378\u83B3\u83B4\u83A0\u83AA\u8393\u839C\u8385\u837C\u83B6\u83A9\u837D\u83B8\u837B\u8398\u839E\u83A8\u83BA\u83BC\u83C1\u8401\u83E5\u83D8\u5807\u8418\u840B\u83DD\u83FD\u83D6\u841C\u8438\u8411\u8406\u83D4\u83DF\u840F\u8403\u83F8\u83F9\u83EA\u83C5\u83C0\u8426\u83F0\u83E1\u845C\u8451\u845A\u8459\u8473\u8487\u8488\u847A\u8489\u8478\u843C\u8446\u8469\u8476\u848C\u848E\u8431\u846D\u84C1\u84CD\u84D0\u84E6\u84BD\u84D3\u84CA\u84BF\u84BA\u84E0\u84A1\u84B9\u84B4\u8497\u84E5\u84E3\u850C\u750D\u8538\u84F0\u8539\u851F\u853A\uFFFD".split("");
      for (j = 0; j != D[221].length; ++j)
        if (D[221][j].charCodeAt(0) !== 65533) {
          e[D[221][j]] = 56576 + j;
          d[56576 + j] = D[221][j];
        }
      D[222] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8F45\u8F46\u8F47\u8F48\u8F49\u8F4A\u8F4B\u8F4C\u8F4D\u8F4E\u8F4F\u8F50\u8F51\u8F52\u8F53\u8F54\u8F55\u8F56\u8F57\u8F58\u8F59\u8F5A\u8F5B\u8F5C\u8F5D\u8F5E\u8F5F\u8F60\u8F61\u8F62\u8F63\u8F64\u8F65\u8F6A\u8F80\u8F8C\u8F92\u8F9D\u8FA0\u8FA1\u8FA2\u8FA4\u8FA5\u8FA6\u8FA7\u8FAA\u8FAC\u8FAD\u8FAE\u8FAF\u8FB2\u8FB3\u8FB4\u8FB5\u8FB7\u8FB8\u8FBA\u8FBB\u8FBC\u8FBF\u8FC0\u8FC3\u8FC6\uFFFD\u8FC9\u8FCA\u8FCB\u8FCC\u8FCD\u8FCF\u8FD2\u8FD6\u8FD7\u8FDA\u8FE0\u8FE1\u8FE3\u8FE7\u8FEC\u8FEF\u8FF1\u8FF2\u8FF4\u8FF5\u8FF6\u8FFA\u8FFB\u8FFC\u8FFE\u8FFF\u9007\u9008\u900C\u900E\u9013\u9015\u9018\u8556\u853B\u84FF\u84FC\u8559\u8548\u8568\u8564\u855E\u857A\u77A2\u8543\u8572\u857B\u85A4\u85A8\u8587\u858F\u8579\u85AE\u859C\u8585\u85B9\u85B7\u85B0\u85D3\u85C1\u85DC\u85FF\u8627\u8605\u8629\u8616\u863C\u5EFE\u5F08\u593C\u5941\u8037\u5955\u595A\u5958\u530F\u5C22\u5C25\u5C2C\u5C34\u624C\u626A\u629F\u62BB\u62CA\u62DA\u62D7\u62EE\u6322\u62F6\u6339\u634B\u6343\u63AD\u63F6\u6371\u637A\u638E\u63B4\u636D\u63AC\u638A\u6369\u63AE\u63BC\u63F2\u63F8\u63E0\u63FF\u63C4\u63DE\u63CE\u6452\u63C6\u63BE\u6445\u6441\u640B\u641B\u6420\u640C\u6426\u6421\u645E\u6484\u646D\u6496\uFFFD".split("");
      for (j = 0; j != D[222].length; ++j)
        if (D[222][j].charCodeAt(0) !== 65533) {
          e[D[222][j]] = 56832 + j;
          d[56832 + j] = D[222][j];
        }
      D[223] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9019\u901C\u9023\u9024\u9025\u9027\u9028\u9029\u902A\u902B\u902C\u9030\u9031\u9032\u9033\u9034\u9037\u9039\u903A\u903D\u903F\u9040\u9043\u9045\u9046\u9048\u9049\u904A\u904B\u904C\u904E\u9054\u9055\u9056\u9059\u905A\u905C\u905D\u905E\u905F\u9060\u9061\u9064\u9066\u9067\u9069\u906A\u906B\u906C\u906F\u9070\u9071\u9072\u9073\u9076\u9077\u9078\u9079\u907A\u907B\u907C\u907E\u9081\uFFFD\u9084\u9085\u9086\u9087\u9089\u908A\u908C\u908D\u908E\u908F\u9090\u9092\u9094\u9096\u9098\u909A\u909C\u909E\u909F\u90A0\u90A4\u90A5\u90A7\u90A8\u90A9\u90AB\u90AD\u90B2\u90B7\u90BC\u90BD\u90BF\u90C0\u647A\u64B7\u64B8\u6499\u64BA\u64C0\u64D0\u64D7\u64E4\u64E2\u6509\u6525\u652E\u5F0B\u5FD2\u7519\u5F11\u535F\u53F1\u53FD\u53E9\u53E8\u53FB\u5412\u5416\u5406\u544B\u5452\u5453\u5454\u5456\u5443\u5421\u5457\u5459\u5423\u5432\u5482\u5494\u5477\u5471\u5464\u549A\u549B\u5484\u5476\u5466\u549D\u54D0\u54AD\u54C2\u54B4\u54D2\u54A7\u54A6\u54D3\u54D4\u5472\u54A3\u54D5\u54BB\u54BF\u54CC\u54D9\u54DA\u54DC\u54A9\u54AA\u54A4\u54DD\u54CF\u54DE\u551B\u54E7\u5520\u54FD\u5514\u54F3\u5522\u5523\u550F\u5511\u5527\u552A\u5567\u558F\u55B5\u5549\u556D\u5541\u5555\u553F\u5550\u553C\uFFFD".split("");
      for (j = 0; j != D[223].length; ++j)
        if (D[223][j].charCodeAt(0) !== 65533) {
          e[D[223][j]] = 57088 + j;
          d[57088 + j] = D[223][j];
        }
      D[224] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u90C2\u90C3\u90C6\u90C8\u90C9\u90CB\u90CC\u90CD\u90D2\u90D4\u90D5\u90D6\u90D8\u90D9\u90DA\u90DE\u90DF\u90E0\u90E3\u90E4\u90E5\u90E9\u90EA\u90EC\u90EE\u90F0\u90F1\u90F2\u90F3\u90F5\u90F6\u90F7\u90F9\u90FA\u90FB\u90FC\u90FF\u9100\u9101\u9103\u9105\u9106\u9107\u9108\u9109\u910A\u910B\u910C\u910D\u910E\u910F\u9110\u9111\u9112\u9113\u9114\u9115\u9116\u9117\u9118\u911A\u911B\u911C\uFFFD\u911D\u911F\u9120\u9121\u9124\u9125\u9126\u9127\u9128\u9129\u912A\u912B\u912C\u912D\u912E\u9130\u9132\u9133\u9134\u9135\u9136\u9137\u9138\u913A\u913B\u913C\u913D\u913E\u913F\u9140\u9141\u9142\u9144\u5537\u5556\u5575\u5576\u5577\u5533\u5530\u555C\u558B\u55D2\u5583\u55B1\u55B9\u5588\u5581\u559F\u557E\u55D6\u5591\u557B\u55DF\u55BD\u55BE\u5594\u5599\u55EA\u55F7\u55C9\u561F\u55D1\u55EB\u55EC\u55D4\u55E6\u55DD\u55C4\u55EF\u55E5\u55F2\u55F3\u55CC\u55CD\u55E8\u55F5\u55E4\u8F94\u561E\u5608\u560C\u5601\u5624\u5623\u55FE\u5600\u5627\u562D\u5658\u5639\u5657\u562C\u564D\u5662\u5659\u565C\u564C\u5654\u5686\u5664\u5671\u566B\u567B\u567C\u5685\u5693\u56AF\u56D4\u56D7\u56DD\u56E1\u56F5\u56EB\u56F9\u56FF\u5704\u570A\u5709\u571C\u5E0F\u5E19\u5E14\u5E11\u5E31\u5E3B\u5E3C\uFFFD".split("");
      for (j = 0; j != D[224].length; ++j)
        if (D[224][j].charCodeAt(0) !== 65533) {
          e[D[224][j]] = 57344 + j;
          d[57344 + j] = D[224][j];
        }
      D[225] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9145\u9147\u9148\u9151\u9153\u9154\u9155\u9156\u9158\u9159\u915B\u915C\u915F\u9160\u9166\u9167\u9168\u916B\u916D\u9173\u917A\u917B\u917C\u9180\u9181\u9182\u9183\u9184\u9186\u9188\u918A\u918E\u918F\u9193\u9194\u9195\u9196\u9197\u9198\u9199\u919C\u919D\u919E\u919F\u91A0\u91A1\u91A4\u91A5\u91A6\u91A7\u91A8\u91A9\u91AB\u91AC\u91B0\u91B1\u91B2\u91B3\u91B6\u91B7\u91B8\u91B9\u91BB\uFFFD\u91BC\u91BD\u91BE\u91BF\u91C0\u91C1\u91C2\u91C3\u91C4\u91C5\u91C6\u91C8\u91CB\u91D0\u91D2\u91D3\u91D4\u91D5\u91D6\u91D7\u91D8\u91D9\u91DA\u91DB\u91DD\u91DE\u91DF\u91E0\u91E1\u91E2\u91E3\u91E4\u91E5\u5E37\u5E44\u5E54\u5E5B\u5E5E\u5E61\u5C8C\u5C7A\u5C8D\u5C90\u5C96\u5C88\u5C98\u5C99\u5C91\u5C9A\u5C9C\u5CB5\u5CA2\u5CBD\u5CAC\u5CAB\u5CB1\u5CA3\u5CC1\u5CB7\u5CC4\u5CD2\u5CE4\u5CCB\u5CE5\u5D02\u5D03\u5D27\u5D26\u5D2E\u5D24\u5D1E\u5D06\u5D1B\u5D58\u5D3E\u5D34\u5D3D\u5D6C\u5D5B\u5D6F\u5D5D\u5D6B\u5D4B\u5D4A\u5D69\u5D74\u5D82\u5D99\u5D9D\u8C73\u5DB7\u5DC5\u5F73\u5F77\u5F82\u5F87\u5F89\u5F8C\u5F95\u5F99\u5F9C\u5FA8\u5FAD\u5FB5\u5FBC\u8862\u5F61\u72AD\u72B0\u72B4\u72B7\u72B8\u72C3\u72C1\u72CE\u72CD\u72D2\u72E8\u72EF\u72E9\u72F2\u72F4\u72F7\u7301\u72F3\u7303\u72FA\uFFFD".split("");
      for (j = 0; j != D[225].length; ++j)
        if (D[225][j].charCodeAt(0) !== 65533) {
          e[D[225][j]] = 57600 + j;
          d[57600 + j] = D[225][j];
        }
      D[226] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u91E6\u91E7\u91E8\u91E9\u91EA\u91EB\u91EC\u91ED\u91EE\u91EF\u91F0\u91F1\u91F2\u91F3\u91F4\u91F5\u91F6\u91F7\u91F8\u91F9\u91FA\u91FB\u91FC\u91FD\u91FE\u91FF\u9200\u9201\u9202\u9203\u9204\u9205\u9206\u9207\u9208\u9209\u920A\u920B\u920C\u920D\u920E\u920F\u9210\u9211\u9212\u9213\u9214\u9215\u9216\u9217\u9218\u9219\u921A\u921B\u921C\u921D\u921E\u921F\u9220\u9221\u9222\u9223\u9224\uFFFD\u9225\u9226\u9227\u9228\u9229\u922A\u922B\u922C\u922D\u922E\u922F\u9230\u9231\u9232\u9233\u9234\u9235\u9236\u9237\u9238\u9239\u923A\u923B\u923C\u923D\u923E\u923F\u9240\u9241\u9242\u9243\u9244\u9245\u72FB\u7317\u7313\u7321\u730A\u731E\u731D\u7315\u7322\u7339\u7325\u732C\u7338\u7331\u7350\u734D\u7357\u7360\u736C\u736F\u737E\u821B\u5925\u98E7\u5924\u5902\u9963\u9967\u9968\u9969\u996A\u996B\u996C\u9974\u9977\u997D\u9980\u9984\u9987\u998A\u998D\u9990\u9991\u9993\u9994\u9995\u5E80\u5E91\u5E8B\u5E96\u5EA5\u5EA0\u5EB9\u5EB5\u5EBE\u5EB3\u8D53\u5ED2\u5ED1\u5EDB\u5EE8\u5EEA\u81BA\u5FC4\u5FC9\u5FD6\u5FCF\u6003\u5FEE\u6004\u5FE1\u5FE4\u5FFE\u6005\u6006\u5FEA\u5FED\u5FF8\u6019\u6035\u6026\u601B\u600F\u600D\u6029\u602B\u600A\u603F\u6021\u6078\u6079\u607B\u607A\u6042\uFFFD".split("");
      for (j = 0; j != D[226].length; ++j)
        if (D[226][j].charCodeAt(0) !== 65533) {
          e[D[226][j]] = 57856 + j;
          d[57856 + j] = D[226][j];
        }
      D[227] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9246\u9247\u9248\u9249\u924A\u924B\u924C\u924D\u924E\u924F\u9250\u9251\u9252\u9253\u9254\u9255\u9256\u9257\u9258\u9259\u925A\u925B\u925C\u925D\u925E\u925F\u9260\u9261\u9262\u9263\u9264\u9265\u9266\u9267\u9268\u9269\u926A\u926B\u926C\u926D\u926E\u926F\u9270\u9271\u9272\u9273\u9275\u9276\u9277\u9278\u9279\u927A\u927B\u927C\u927D\u927E\u927F\u9280\u9281\u9282\u9283\u9284\u9285\uFFFD\u9286\u9287\u9288\u9289\u928A\u928B\u928C\u928D\u928F\u9290\u9291\u9292\u9293\u9294\u9295\u9296\u9297\u9298\u9299\u929A\u929B\u929C\u929D\u929E\u929F\u92A0\u92A1\u92A2\u92A3\u92A4\u92A5\u92A6\u92A7\u606A\u607D\u6096\u609A\u60AD\u609D\u6083\u6092\u608C\u609B\u60EC\u60BB\u60B1\u60DD\u60D8\u60C6\u60DA\u60B4\u6120\u6126\u6115\u6123\u60F4\u6100\u610E\u612B\u614A\u6175\u61AC\u6194\u61A7\u61B7\u61D4\u61F5\u5FDD\u96B3\u95E9\u95EB\u95F1\u95F3\u95F5\u95F6\u95FC\u95FE\u9603\u9604\u9606\u9608\u960A\u960B\u960C\u960D\u960F\u9612\u9615\u9616\u9617\u9619\u961A\u4E2C\u723F\u6215\u6C35\u6C54\u6C5C\u6C4A\u6CA3\u6C85\u6C90\u6C94\u6C8C\u6C68\u6C69\u6C74\u6C76\u6C86\u6CA9\u6CD0\u6CD4\u6CAD\u6CF7\u6CF8\u6CF1\u6CD7\u6CB2\u6CE0\u6CD6\u6CFA\u6CEB\u6CEE\u6CB1\u6CD3\u6CEF\u6CFE\uFFFD".split("");
      for (j = 0; j != D[227].length; ++j)
        if (D[227][j].charCodeAt(0) !== 65533) {
          e[D[227][j]] = 58112 + j;
          d[58112 + j] = D[227][j];
        }
      D[228] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u92A8\u92A9\u92AA\u92AB\u92AC\u92AD\u92AF\u92B0\u92B1\u92B2\u92B3\u92B4\u92B5\u92B6\u92B7\u92B8\u92B9\u92BA\u92BB\u92BC\u92BD\u92BE\u92BF\u92C0\u92C1\u92C2\u92C3\u92C4\u92C5\u92C6\u92C7\u92C9\u92CA\u92CB\u92CC\u92CD\u92CE\u92CF\u92D0\u92D1\u92D2\u92D3\u92D4\u92D5\u92D6\u92D7\u92D8\u92D9\u92DA\u92DB\u92DC\u92DD\u92DE\u92DF\u92E0\u92E1\u92E2\u92E3\u92E4\u92E5\u92E6\u92E7\u92E8\uFFFD\u92E9\u92EA\u92EB\u92EC\u92ED\u92EE\u92EF\u92F0\u92F1\u92F2\u92F3\u92F4\u92F5\u92F6\u92F7\u92F8\u92F9\u92FA\u92FB\u92FC\u92FD\u92FE\u92FF\u9300\u9301\u9302\u9303\u9304\u9305\u9306\u9307\u9308\u9309\u6D39\u6D27\u6D0C\u6D43\u6D48\u6D07\u6D04\u6D19\u6D0E\u6D2B\u6D4D\u6D2E\u6D35\u6D1A\u6D4F\u6D52\u6D54\u6D33\u6D91\u6D6F\u6D9E\u6DA0\u6D5E\u6D93\u6D94\u6D5C\u6D60\u6D7C\u6D63\u6E1A\u6DC7\u6DC5\u6DDE\u6E0E\u6DBF\u6DE0\u6E11\u6DE6\u6DDD\u6DD9\u6E16\u6DAB\u6E0C\u6DAE\u6E2B\u6E6E\u6E4E\u6E6B\u6EB2\u6E5F\u6E86\u6E53\u6E54\u6E32\u6E25\u6E44\u6EDF\u6EB1\u6E98\u6EE0\u6F2D\u6EE2\u6EA5\u6EA7\u6EBD\u6EBB\u6EB7\u6ED7\u6EB4\u6ECF\u6E8F\u6EC2\u6E9F\u6F62\u6F46\u6F47\u6F24\u6F15\u6EF9\u6F2F\u6F36\u6F4B\u6F74\u6F2A\u6F09\u6F29\u6F89\u6F8D\u6F8C\u6F78\u6F72\u6F7C\u6F7A\u6FD1\uFFFD".split("");
      for (j = 0; j != D[228].length; ++j)
        if (D[228][j].charCodeAt(0) !== 65533) {
          e[D[228][j]] = 58368 + j;
          d[58368 + j] = D[228][j];
        }
      D[229] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u930A\u930B\u930C\u930D\u930E\u930F\u9310\u9311\u9312\u9313\u9314\u9315\u9316\u9317\u9318\u9319\u931A\u931B\u931C\u931D\u931E\u931F\u9320\u9321\u9322\u9323\u9324\u9325\u9326\u9327\u9328\u9329\u932A\u932B\u932C\u932D\u932E\u932F\u9330\u9331\u9332\u9333\u9334\u9335\u9336\u9337\u9338\u9339\u933A\u933B\u933C\u933D\u933F\u9340\u9341\u9342\u9343\u9344\u9345\u9346\u9347\u9348\u9349\uFFFD\u934A\u934B\u934C\u934D\u934E\u934F\u9350\u9351\u9352\u9353\u9354\u9355\u9356\u9357\u9358\u9359\u935A\u935B\u935C\u935D\u935E\u935F\u9360\u9361\u9362\u9363\u9364\u9365\u9366\u9367\u9368\u9369\u936B\u6FC9\u6FA7\u6FB9\u6FB6\u6FC2\u6FE1\u6FEE\u6FDE\u6FE0\u6FEF\u701A\u7023\u701B\u7039\u7035\u704F\u705E\u5B80\u5B84\u5B95\u5B93\u5BA5\u5BB8\u752F\u9A9E\u6434\u5BE4\u5BEE\u8930\u5BF0\u8E47\u8B07\u8FB6\u8FD3\u8FD5\u8FE5\u8FEE\u8FE4\u8FE9\u8FE6\u8FF3\u8FE8\u9005\u9004\u900B\u9026\u9011\u900D\u9016\u9021\u9035\u9036\u902D\u902F\u9044\u9051\u9052\u9050\u9068\u9058\u9062\u905B\u66B9\u9074\u907D\u9082\u9088\u9083\u908B\u5F50\u5F57\u5F56\u5F58\u5C3B\u54AB\u5C50\u5C59\u5B71\u5C63\u5C66\u7FBC\u5F2A\u5F29\u5F2D\u8274\u5F3C\u9B3B\u5C6E\u5981\u5983\u598D\u59A9\u59AA\u59A3\uFFFD".split("");
      for (j = 0; j != D[229].length; ++j)
        if (D[229][j].charCodeAt(0) !== 65533) {
          e[D[229][j]] = 58624 + j;
          d[58624 + j] = D[229][j];
        }
      D[230] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u936C\u936D\u936E\u936F\u9370\u9371\u9372\u9373\u9374\u9375\u9376\u9377\u9378\u9379\u937A\u937B\u937C\u937D\u937E\u937F\u9380\u9381\u9382\u9383\u9384\u9385\u9386\u9387\u9388\u9389\u938A\u938B\u938C\u938D\u938E\u9390\u9391\u9392\u9393\u9394\u9395\u9396\u9397\u9398\u9399\u939A\u939B\u939C\u939D\u939E\u939F\u93A0\u93A1\u93A2\u93A3\u93A4\u93A5\u93A6\u93A7\u93A8\u93A9\u93AA\u93AB\uFFFD\u93AC\u93AD\u93AE\u93AF\u93B0\u93B1\u93B2\u93B3\u93B4\u93B5\u93B6\u93B7\u93B8\u93B9\u93BA\u93BB\u93BC\u93BD\u93BE\u93BF\u93C0\u93C1\u93C2\u93C3\u93C4\u93C5\u93C6\u93C7\u93C8\u93C9\u93CB\u93CC\u93CD\u5997\u59CA\u59AB\u599E\u59A4\u59D2\u59B2\u59AF\u59D7\u59BE\u5A05\u5A06\u59DD\u5A08\u59E3\u59D8\u59F9\u5A0C\u5A09\u5A32\u5A34\u5A11\u5A23\u5A13\u5A40\u5A67\u5A4A\u5A55\u5A3C\u5A62\u5A75\u80EC\u5AAA\u5A9B\u5A77\u5A7A\u5ABE\u5AEB\u5AB2\u5AD2\u5AD4\u5AB8\u5AE0\u5AE3\u5AF1\u5AD6\u5AE6\u5AD8\u5ADC\u5B09\u5B17\u5B16\u5B32\u5B37\u5B40\u5C15\u5C1C\u5B5A\u5B65\u5B73\u5B51\u5B53\u5B62\u9A75\u9A77\u9A78\u9A7A\u9A7F\u9A7D\u9A80\u9A81\u9A85\u9A88\u9A8A\u9A90\u9A92\u9A93\u9A96\u9A98\u9A9B\u9A9C\u9A9D\u9A9F\u9AA0\u9AA2\u9AA3\u9AA5\u9AA7\u7E9F\u7EA1\u7EA3\u7EA5\u7EA8\u7EA9\uFFFD".split("");
      for (j = 0; j != D[230].length; ++j)
        if (D[230][j].charCodeAt(0) !== 65533) {
          e[D[230][j]] = 58880 + j;
          d[58880 + j] = D[230][j];
        }
      D[231] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u93CE\u93CF\u93D0\u93D1\u93D2\u93D3\u93D4\u93D5\u93D7\u93D8\u93D9\u93DA\u93DB\u93DC\u93DD\u93DE\u93DF\u93E0\u93E1\u93E2\u93E3\u93E4\u93E5\u93E6\u93E7\u93E8\u93E9\u93EA\u93EB\u93EC\u93ED\u93EE\u93EF\u93F0\u93F1\u93F2\u93F3\u93F4\u93F5\u93F6\u93F7\u93F8\u93F9\u93FA\u93FB\u93FC\u93FD\u93FE\u93FF\u9400\u9401\u9402\u9403\u9404\u9405\u9406\u9407\u9408\u9409\u940A\u940B\u940C\u940D\uFFFD\u940E\u940F\u9410\u9411\u9412\u9413\u9414\u9415\u9416\u9417\u9418\u9419\u941A\u941B\u941C\u941D\u941E\u941F\u9420\u9421\u9422\u9423\u9424\u9425\u9426\u9427\u9428\u9429\u942A\u942B\u942C\u942D\u942E\u7EAD\u7EB0\u7EBE\u7EC0\u7EC1\u7EC2\u7EC9\u7ECB\u7ECC\u7ED0\u7ED4\u7ED7\u7EDB\u7EE0\u7EE1\u7EE8\u7EEB\u7EEE\u7EEF\u7EF1\u7EF2\u7F0D\u7EF6\u7EFA\u7EFB\u7EFE\u7F01\u7F02\u7F03\u7F07\u7F08\u7F0B\u7F0C\u7F0F\u7F11\u7F12\u7F17\u7F19\u7F1C\u7F1B\u7F1F\u7F21\u7F22\u7F23\u7F24\u7F25\u7F26\u7F27\u7F2A\u7F2B\u7F2C\u7F2D\u7F2F\u7F30\u7F31\u7F32\u7F33\u7F35\u5E7A\u757F\u5DDB\u753E\u9095\u738E\u7391\u73AE\u73A2\u739F\u73CF\u73C2\u73D1\u73B7\u73B3\u73C0\u73C9\u73C8\u73E5\u73D9\u987C\u740A\u73E9\u73E7\u73DE\u73BA\u73F2\u740F\u742A\u745B\u7426\u7425\u7428\u7430\u742E\u742C\uFFFD".split("");
      for (j = 0; j != D[231].length; ++j)
        if (D[231][j].charCodeAt(0) !== 65533) {
          e[D[231][j]] = 59136 + j;
          d[59136 + j] = D[231][j];
        }
      D[232] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u942F\u9430\u9431\u9432\u9433\u9434\u9435\u9436\u9437\u9438\u9439\u943A\u943B\u943C\u943D\u943F\u9440\u9441\u9442\u9443\u9444\u9445\u9446\u9447\u9448\u9449\u944A\u944B\u944C\u944D\u944E\u944F\u9450\u9451\u9452\u9453\u9454\u9455\u9456\u9457\u9458\u9459\u945A\u945B\u945C\u945D\u945E\u945F\u9460\u9461\u9462\u9463\u9464\u9465\u9466\u9467\u9468\u9469\u946A\u946C\u946D\u946E\u946F\uFFFD\u9470\u9471\u9472\u9473\u9474\u9475\u9476\u9477\u9478\u9479\u947A\u947B\u947C\u947D\u947E\u947F\u9480\u9481\u9482\u9483\u9484\u9491\u9496\u9498\u94C7\u94CF\u94D3\u94D4\u94DA\u94E6\u94FB\u951C\u9520\u741B\u741A\u7441\u745C\u7457\u7455\u7459\u7477\u746D\u747E\u749C\u748E\u7480\u7481\u7487\u748B\u749E\u74A8\u74A9\u7490\u74A7\u74D2\u74BA\u97EA\u97EB\u97EC\u674C\u6753\u675E\u6748\u6769\u67A5\u6787\u676A\u6773\u6798\u67A7\u6775\u67A8\u679E\u67AD\u678B\u6777\u677C\u67F0\u6809\u67D8\u680A\u67E9\u67B0\u680C\u67D9\u67B5\u67DA\u67B3\u67DD\u6800\u67C3\u67B8\u67E2\u680E\u67C1\u67FD\u6832\u6833\u6860\u6861\u684E\u6862\u6844\u6864\u6883\u681D\u6855\u6866\u6841\u6867\u6840\u683E\u684A\u6849\u6829\u68B5\u688F\u6874\u6877\u6893\u686B\u68C2\u696E\u68FC\u691F\u6920\u68F9\uFFFD".split("");
      for (j = 0; j != D[232].length; ++j)
        if (D[232][j].charCodeAt(0) !== 65533) {
          e[D[232][j]] = 59392 + j;
          d[59392 + j] = D[232][j];
        }
      D[233] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9527\u9533\u953D\u9543\u9548\u954B\u9555\u955A\u9560\u956E\u9574\u9575\u9577\u9578\u9579\u957A\u957B\u957C\u957D\u957E\u9580\u9581\u9582\u9583\u9584\u9585\u9586\u9587\u9588\u9589\u958A\u958B\u958C\u958D\u958E\u958F\u9590\u9591\u9592\u9593\u9594\u9595\u9596\u9597\u9598\u9599\u959A\u959B\u959C\u959D\u959E\u959F\u95A0\u95A1\u95A2\u95A3\u95A4\u95A5\u95A6\u95A7\u95A8\u95A9\u95AA\uFFFD\u95AB\u95AC\u95AD\u95AE\u95AF\u95B0\u95B1\u95B2\u95B3\u95B4\u95B5\u95B6\u95B7\u95B8\u95B9\u95BA\u95BB\u95BC\u95BD\u95BE\u95BF\u95C0\u95C1\u95C2\u95C3\u95C4\u95C5\u95C6\u95C7\u95C8\u95C9\u95CA\u95CB\u6924\u68F0\u690B\u6901\u6957\u68E3\u6910\u6971\u6939\u6960\u6942\u695D\u6984\u696B\u6980\u6998\u6978\u6934\u69CC\u6987\u6988\u69CE\u6989\u6966\u6963\u6979\u699B\u69A7\u69BB\u69AB\u69AD\u69D4\u69B1\u69C1\u69CA\u69DF\u6995\u69E0\u698D\u69FF\u6A2F\u69ED\u6A17\u6A18\u6A65\u69F2\u6A44\u6A3E\u6AA0\u6A50\u6A5B\u6A35\u6A8E\u6A79\u6A3D\u6A28\u6A58\u6A7C\u6A91\u6A90\u6AA9\u6A97\u6AAB\u7337\u7352\u6B81\u6B82\u6B87\u6B84\u6B92\u6B93\u6B8D\u6B9A\u6B9B\u6BA1\u6BAA\u8F6B\u8F6D\u8F71\u8F72\u8F73\u8F75\u8F76\u8F78\u8F77\u8F79\u8F7A\u8F7C\u8F7E\u8F81\u8F82\u8F84\u8F87\u8F8B\uFFFD".split("");
      for (j = 0; j != D[233].length; ++j)
        if (D[233][j].charCodeAt(0) !== 65533) {
          e[D[233][j]] = 59648 + j;
          d[59648 + j] = D[233][j];
        }
      D[234] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u95CC\u95CD\u95CE\u95CF\u95D0\u95D1\u95D2\u95D3\u95D4\u95D5\u95D6\u95D7\u95D8\u95D9\u95DA\u95DB\u95DC\u95DD\u95DE\u95DF\u95E0\u95E1\u95E2\u95E3\u95E4\u95E5\u95E6\u95E7\u95EC\u95FF\u9607\u9613\u9618\u961B\u961E\u9620\u9623\u9624\u9625\u9626\u9627\u9628\u9629\u962B\u962C\u962D\u962F\u9630\u9637\u9638\u9639\u963A\u963E\u9641\u9643\u964A\u964E\u964F\u9651\u9652\u9653\u9656\u9657\uFFFD\u9658\u9659\u965A\u965C\u965D\u965E\u9660\u9663\u9665\u9666\u966B\u966D\u966E\u966F\u9670\u9671\u9673\u9678\u9679\u967A\u967B\u967C\u967D\u967E\u967F\u9680\u9681\u9682\u9683\u9684\u9687\u9689\u968A\u8F8D\u8F8E\u8F8F\u8F98\u8F9A\u8ECE\u620B\u6217\u621B\u621F\u6222\u6221\u6225\u6224\u622C\u81E7\u74EF\u74F4\u74FF\u750F\u7511\u7513\u6534\u65EE\u65EF\u65F0\u660A\u6619\u6772\u6603\u6615\u6600\u7085\u66F7\u661D\u6634\u6631\u6636\u6635\u8006\u665F\u6654\u6641\u664F\u6656\u6661\u6657\u6677\u6684\u668C\u66A7\u669D\u66BE\u66DB\u66DC\u66E6\u66E9\u8D32\u8D33\u8D36\u8D3B\u8D3D\u8D40\u8D45\u8D46\u8D48\u8D49\u8D47\u8D4D\u8D55\u8D59\u89C7\u89CA\u89CB\u89CC\u89CE\u89CF\u89D0\u89D1\u726E\u729F\u725D\u7266\u726F\u727E\u727F\u7284\u728B\u728D\u728F\u7292\u6308\u6332\u63B0\uFFFD".split("");
      for (j = 0; j != D[234].length; ++j)
        if (D[234][j].charCodeAt(0) !== 65533) {
          e[D[234][j]] = 59904 + j;
          d[59904 + j] = D[234][j];
        }
      D[235] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u968C\u968E\u9691\u9692\u9693\u9695\u9696\u969A\u969B\u969D\u969E\u969F\u96A0\u96A1\u96A2\u96A3\u96A4\u96A5\u96A6\u96A8\u96A9\u96AA\u96AB\u96AC\u96AD\u96AE\u96AF\u96B1\u96B2\u96B4\u96B5\u96B7\u96B8\u96BA\u96BB\u96BF\u96C2\u96C3\u96C8\u96CA\u96CB\u96D0\u96D1\u96D3\u96D4\u96D6\u96D7\u96D8\u96D9\u96DA\u96DB\u96DC\u96DD\u96DE\u96DF\u96E1\u96E2\u96E3\u96E4\u96E5\u96E6\u96E7\u96EB\uFFFD\u96EC\u96ED\u96EE\u96F0\u96F1\u96F2\u96F4\u96F5\u96F8\u96FA\u96FB\u96FC\u96FD\u96FF\u9702\u9703\u9705\u970A\u970B\u970C\u9710\u9711\u9712\u9714\u9715\u9717\u9718\u9719\u971A\u971B\u971D\u971F\u9720\u643F\u64D8\u8004\u6BEA\u6BF3\u6BFD\u6BF5\u6BF9\u6C05\u6C07\u6C06\u6C0D\u6C15\u6C18\u6C19\u6C1A\u6C21\u6C29\u6C24\u6C2A\u6C32\u6535\u6555\u656B\u724D\u7252\u7256\u7230\u8662\u5216\u809F\u809C\u8093\u80BC\u670A\u80BD\u80B1\u80AB\u80AD\u80B4\u80B7\u80E7\u80E8\u80E9\u80EA\u80DB\u80C2\u80C4\u80D9\u80CD\u80D7\u6710\u80DD\u80EB\u80F1\u80F4\u80ED\u810D\u810E\u80F2\u80FC\u6715\u8112\u8C5A\u8136\u811E\u812C\u8118\u8132\u8148\u814C\u8153\u8174\u8159\u815A\u8171\u8160\u8169\u817C\u817D\u816D\u8167\u584D\u5AB5\u8188\u8182\u8191\u6ED5\u81A3\u81AA\u81CC\u6726\u81CA\u81BB\uFFFD".split("");
      for (j = 0; j != D[235].length; ++j)
        if (D[235][j].charCodeAt(0) !== 65533) {
          e[D[235][j]] = 60160 + j;
          d[60160 + j] = D[235][j];
        }
      D[236] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9721\u9722\u9723\u9724\u9725\u9726\u9727\u9728\u9729\u972B\u972C\u972E\u972F\u9731\u9733\u9734\u9735\u9736\u9737\u973A\u973B\u973C\u973D\u973F\u9740\u9741\u9742\u9743\u9744\u9745\u9746\u9747\u9748\u9749\u974A\u974B\u974C\u974D\u974E\u974F\u9750\u9751\u9754\u9755\u9757\u9758\u975A\u975C\u975D\u975F\u9763\u9764\u9766\u9767\u9768\u976A\u976B\u976C\u976D\u976E\u976F\u9770\u9771\uFFFD\u9772\u9775\u9777\u9778\u9779\u977A\u977B\u977D\u977E\u977F\u9780\u9781\u9782\u9783\u9784\u9786\u9787\u9788\u9789\u978A\u978C\u978E\u978F\u9790\u9793\u9795\u9796\u9797\u9799\u979A\u979B\u979C\u979D\u81C1\u81A6\u6B24\u6B37\u6B39\u6B43\u6B46\u6B59\u98D1\u98D2\u98D3\u98D5\u98D9\u98DA\u6BB3\u5F40\u6BC2\u89F3\u6590\u9F51\u6593\u65BC\u65C6\u65C4\u65C3\u65CC\u65CE\u65D2\u65D6\u7080\u709C\u7096\u709D\u70BB\u70C0\u70B7\u70AB\u70B1\u70E8\u70CA\u7110\u7113\u7116\u712F\u7131\u7173\u715C\u7168\u7145\u7172\u714A\u7178\u717A\u7198\u71B3\u71B5\u71A8\u71A0\u71E0\u71D4\u71E7\u71F9\u721D\u7228\u706C\u7118\u7166\u71B9\u623E\u623D\u6243\u6248\u6249\u793B\u7940\u7946\u7949\u795B\u795C\u7953\u795A\u7962\u7957\u7960\u796F\u7967\u797A\u7985\u798A\u799A\u79A7\u79B3\u5FD1\u5FD0\uFFFD".split("");
      for (j = 0; j != D[236].length; ++j)
        if (D[236][j].charCodeAt(0) !== 65533) {
          e[D[236][j]] = 60416 + j;
          d[60416 + j] = D[236][j];
        }
      D[237] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u979E\u979F\u97A1\u97A2\u97A4\u97A5\u97A6\u97A7\u97A8\u97A9\u97AA\u97AC\u97AE\u97B0\u97B1\u97B3\u97B5\u97B6\u97B7\u97B8\u97B9\u97BA\u97BB\u97BC\u97BD\u97BE\u97BF\u97C0\u97C1\u97C2\u97C3\u97C4\u97C5\u97C6\u97C7\u97C8\u97C9\u97CA\u97CB\u97CC\u97CD\u97CE\u97CF\u97D0\u97D1\u97D2\u97D3\u97D4\u97D5\u97D6\u97D7\u97D8\u97D9\u97DA\u97DB\u97DC\u97DD\u97DE\u97DF\u97E0\u97E1\u97E2\u97E3\uFFFD\u97E4\u97E5\u97E8\u97EE\u97EF\u97F0\u97F1\u97F2\u97F4\u97F7\u97F8\u97F9\u97FA\u97FB\u97FC\u97FD\u97FE\u97FF\u9800\u9801\u9802\u9803\u9804\u9805\u9806\u9807\u9808\u9809\u980A\u980B\u980C\u980D\u980E\u603C\u605D\u605A\u6067\u6041\u6059\u6063\u60AB\u6106\u610D\u615D\u61A9\u619D\u61CB\u61D1\u6206\u8080\u807F\u6C93\u6CF6\u6DFC\u77F6\u77F8\u7800\u7809\u7817\u7818\u7811\u65AB\u782D\u781C\u781D\u7839\u783A\u783B\u781F\u783C\u7825\u782C\u7823\u7829\u784E\u786D\u7856\u7857\u7826\u7850\u7847\u784C\u786A\u789B\u7893\u789A\u7887\u789C\u78A1\u78A3\u78B2\u78B9\u78A5\u78D4\u78D9\u78C9\u78EC\u78F2\u7905\u78F4\u7913\u7924\u791E\u7934\u9F9B\u9EF9\u9EFB\u9EFC\u76F1\u7704\u770D\u76F9\u7707\u7708\u771A\u7722\u7719\u772D\u7726\u7735\u7738\u7750\u7751\u7747\u7743\u775A\u7768\uFFFD".split("");
      for (j = 0; j != D[237].length; ++j)
        if (D[237][j].charCodeAt(0) !== 65533) {
          e[D[237][j]] = 60672 + j;
          d[60672 + j] = D[237][j];
        }
      D[238] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u980F\u9810\u9811\u9812\u9813\u9814\u9815\u9816\u9817\u9818\u9819\u981A\u981B\u981C\u981D\u981E\u981F\u9820\u9821\u9822\u9823\u9824\u9825\u9826\u9827\u9828\u9829\u982A\u982B\u982C\u982D\u982E\u982F\u9830\u9831\u9832\u9833\u9834\u9835\u9836\u9837\u9838\u9839\u983A\u983B\u983C\u983D\u983E\u983F\u9840\u9841\u9842\u9843\u9844\u9845\u9846\u9847\u9848\u9849\u984A\u984B\u984C\u984D\uFFFD\u984E\u984F\u9850\u9851\u9852\u9853\u9854\u9855\u9856\u9857\u9858\u9859\u985A\u985B\u985C\u985D\u985E\u985F\u9860\u9861\u9862\u9863\u9864\u9865\u9866\u9867\u9868\u9869\u986A\u986B\u986C\u986D\u986E\u7762\u7765\u777F\u778D\u777D\u7780\u778C\u7791\u779F\u77A0\u77B0\u77B5\u77BD\u753A\u7540\u754E\u754B\u7548\u755B\u7572\u7579\u7583\u7F58\u7F61\u7F5F\u8A48\u7F68\u7F74\u7F71\u7F79\u7F81\u7F7E\u76CD\u76E5\u8832\u9485\u9486\u9487\u948B\u948A\u948C\u948D\u948F\u9490\u9494\u9497\u9495\u949A\u949B\u949C\u94A3\u94A4\u94AB\u94AA\u94AD\u94AC\u94AF\u94B0\u94B2\u94B4\u94B6\u94B7\u94B8\u94B9\u94BA\u94BC\u94BD\u94BF\u94C4\u94C8\u94C9\u94CA\u94CB\u94CC\u94CD\u94CE\u94D0\u94D1\u94D2\u94D5\u94D6\u94D7\u94D9\u94D8\u94DB\u94DE\u94DF\u94E0\u94E2\u94E4\u94E5\u94E7\u94E8\u94EA\uFFFD".split("");
      for (j = 0; j != D[238].length; ++j)
        if (D[238][j].charCodeAt(0) !== 65533) {
          e[D[238][j]] = 60928 + j;
          d[60928 + j] = D[238][j];
        }
      D[239] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u986F\u9870\u9871\u9872\u9873\u9874\u988B\u988E\u9892\u9895\u9899\u98A3\u98A8\u98A9\u98AA\u98AB\u98AC\u98AD\u98AE\u98AF\u98B0\u98B1\u98B2\u98B3\u98B4\u98B5\u98B6\u98B7\u98B8\u98B9\u98BA\u98BB\u98BC\u98BD\u98BE\u98BF\u98C0\u98C1\u98C2\u98C3\u98C4\u98C5\u98C6\u98C7\u98C8\u98C9\u98CA\u98CB\u98CC\u98CD\u98CF\u98D0\u98D4\u98D6\u98D7\u98DB\u98DC\u98DD\u98E0\u98E1\u98E2\u98E3\u98E4\uFFFD\u98E5\u98E6\u98E9\u98EA\u98EB\u98EC\u98ED\u98EE\u98EF\u98F0\u98F1\u98F2\u98F3\u98F4\u98F5\u98F6\u98F7\u98F8\u98F9\u98FA\u98FB\u98FC\u98FD\u98FE\u98FF\u9900\u9901\u9902\u9903\u9904\u9905\u9906\u9907\u94E9\u94EB\u94EE\u94EF\u94F3\u94F4\u94F5\u94F7\u94F9\u94FC\u94FD\u94FF\u9503\u9502\u9506\u9507\u9509\u950A\u950D\u950E\u950F\u9512\u9513\u9514\u9515\u9516\u9518\u951B\u951D\u951E\u951F\u9522\u952A\u952B\u9529\u952C\u9531\u9532\u9534\u9536\u9537\u9538\u953C\u953E\u953F\u9542\u9535\u9544\u9545\u9546\u9549\u954C\u954E\u954F\u9552\u9553\u9554\u9556\u9557\u9558\u9559\u955B\u955E\u955F\u955D\u9561\u9562\u9564\u9565\u9566\u9567\u9568\u9569\u956A\u956B\u956C\u956F\u9571\u9572\u9573\u953A\u77E7\u77EC\u96C9\u79D5\u79ED\u79E3\u79EB\u7A06\u5D47\u7A03\u7A02\u7A1E\u7A14\uFFFD".split("");
      for (j = 0; j != D[239].length; ++j)
        if (D[239][j].charCodeAt(0) !== 65533) {
          e[D[239][j]] = 61184 + j;
          d[61184 + j] = D[239][j];
        }
      D[240] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9908\u9909\u990A\u990B\u990C\u990E\u990F\u9911\u9912\u9913\u9914\u9915\u9916\u9917\u9918\u9919\u991A\u991B\u991C\u991D\u991E\u991F\u9920\u9921\u9922\u9923\u9924\u9925\u9926\u9927\u9928\u9929\u992A\u992B\u992C\u992D\u992F\u9930\u9931\u9932\u9933\u9934\u9935\u9936\u9937\u9938\u9939\u993A\u993B\u993C\u993D\u993E\u993F\u9940\u9941\u9942\u9943\u9944\u9945\u9946\u9947\u9948\u9949\uFFFD\u994A\u994B\u994C\u994D\u994E\u994F\u9950\u9951\u9952\u9953\u9956\u9957\u9958\u9959\u995A\u995B\u995C\u995D\u995E\u995F\u9960\u9961\u9962\u9964\u9966\u9973\u9978\u9979\u997B\u997E\u9982\u9983\u9989\u7A39\u7A37\u7A51\u9ECF\u99A5\u7A70\u7688\u768E\u7693\u7699\u76A4\u74DE\u74E0\u752C\u9E20\u9E22\u9E28\u9E29\u9E2A\u9E2B\u9E2C\u9E32\u9E31\u9E36\u9E38\u9E37\u9E39\u9E3A\u9E3E\u9E41\u9E42\u9E44\u9E46\u9E47\u9E48\u9E49\u9E4B\u9E4C\u9E4E\u9E51\u9E55\u9E57\u9E5A\u9E5B\u9E5C\u9E5E\u9E63\u9E66\u9E67\u9E68\u9E69\u9E6A\u9E6B\u9E6C\u9E71\u9E6D\u9E73\u7592\u7594\u7596\u75A0\u759D\u75AC\u75A3\u75B3\u75B4\u75B8\u75C4\u75B1\u75B0\u75C3\u75C2\u75D6\u75CD\u75E3\u75E8\u75E6\u75E4\u75EB\u75E7\u7603\u75F1\u75FC\u75FF\u7610\u7600\u7605\u760C\u7617\u760A\u7625\u7618\u7615\u7619\uFFFD".split("");
      for (j = 0; j != D[240].length; ++j)
        if (D[240][j].charCodeAt(0) !== 65533) {
          e[D[240][j]] = 61440 + j;
          d[61440 + j] = D[240][j];
        }
      D[241] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u998C\u998E\u999A\u999B\u999C\u999D\u999E\u999F\u99A0\u99A1\u99A2\u99A3\u99A4\u99A6\u99A7\u99A9\u99AA\u99AB\u99AC\u99AD\u99AE\u99AF\u99B0\u99B1\u99B2\u99B3\u99B4\u99B5\u99B6\u99B7\u99B8\u99B9\u99BA\u99BB\u99BC\u99BD\u99BE\u99BF\u99C0\u99C1\u99C2\u99C3\u99C4\u99C5\u99C6\u99C7\u99C8\u99C9\u99CA\u99CB\u99CC\u99CD\u99CE\u99CF\u99D0\u99D1\u99D2\u99D3\u99D4\u99D5\u99D6\u99D7\u99D8\uFFFD\u99D9\u99DA\u99DB\u99DC\u99DD\u99DE\u99DF\u99E0\u99E1\u99E2\u99E3\u99E4\u99E5\u99E6\u99E7\u99E8\u99E9\u99EA\u99EB\u99EC\u99ED\u99EE\u99EF\u99F0\u99F1\u99F2\u99F3\u99F4\u99F5\u99F6\u99F7\u99F8\u99F9\u761B\u763C\u7622\u7620\u7640\u762D\u7630\u763F\u7635\u7643\u763E\u7633\u764D\u765E\u7654\u765C\u7656\u766B\u766F\u7FCA\u7AE6\u7A78\u7A79\u7A80\u7A86\u7A88\u7A95\u7AA6\u7AA0\u7AAC\u7AA8\u7AAD\u7AB3\u8864\u8869\u8872\u887D\u887F\u8882\u88A2\u88C6\u88B7\u88BC\u88C9\u88E2\u88CE\u88E3\u88E5\u88F1\u891A\u88FC\u88E8\u88FE\u88F0\u8921\u8919\u8913\u891B\u890A\u8934\u892B\u8936\u8941\u8966\u897B\u758B\u80E5\u76B2\u76B4\u77DC\u8012\u8014\u8016\u801C\u8020\u8022\u8025\u8026\u8027\u8029\u8028\u8031\u800B\u8035\u8043\u8046\u804D\u8052\u8069\u8071\u8983\u9878\u9880\u9883\uFFFD".split("");
      for (j = 0; j != D[241].length; ++j)
        if (D[241][j].charCodeAt(0) !== 65533) {
          e[D[241][j]] = 61696 + j;
          d[61696 + j] = D[241][j];
        }
      D[242] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u99FA\u99FB\u99FC\u99FD\u99FE\u99FF\u9A00\u9A01\u9A02\u9A03\u9A04\u9A05\u9A06\u9A07\u9A08\u9A09\u9A0A\u9A0B\u9A0C\u9A0D\u9A0E\u9A0F\u9A10\u9A11\u9A12\u9A13\u9A14\u9A15\u9A16\u9A17\u9A18\u9A19\u9A1A\u9A1B\u9A1C\u9A1D\u9A1E\u9A1F\u9A20\u9A21\u9A22\u9A23\u9A24\u9A25\u9A26\u9A27\u9A28\u9A29\u9A2A\u9A2B\u9A2C\u9A2D\u9A2E\u9A2F\u9A30\u9A31\u9A32\u9A33\u9A34\u9A35\u9A36\u9A37\u9A38\uFFFD\u9A39\u9A3A\u9A3B\u9A3C\u9A3D\u9A3E\u9A3F\u9A40\u9A41\u9A42\u9A43\u9A44\u9A45\u9A46\u9A47\u9A48\u9A49\u9A4A\u9A4B\u9A4C\u9A4D\u9A4E\u9A4F\u9A50\u9A51\u9A52\u9A53\u9A54\u9A55\u9A56\u9A57\u9A58\u9A59\u9889\u988C\u988D\u988F\u9894\u989A\u989B\u989E\u989F\u98A1\u98A2\u98A5\u98A6\u864D\u8654\u866C\u866E\u867F\u867A\u867C\u867B\u86A8\u868D\u868B\u86AC\u869D\u86A7\u86A3\u86AA\u8693\u86A9\u86B6\u86C4\u86B5\u86CE\u86B0\u86BA\u86B1\u86AF\u86C9\u86CF\u86B4\u86E9\u86F1\u86F2\u86ED\u86F3\u86D0\u8713\u86DE\u86F4\u86DF\u86D8\u86D1\u8703\u8707\u86F8\u8708\u870A\u870D\u8709\u8723\u873B\u871E\u8725\u872E\u871A\u873E\u8748\u8734\u8731\u8729\u8737\u873F\u8782\u8722\u877D\u877E\u877B\u8760\u8770\u874C\u876E\u878B\u8753\u8763\u877C\u8764\u8759\u8765\u8793\u87AF\u87A8\u87D2\uFFFD".split("");
      for (j = 0; j != D[242].length; ++j)
        if (D[242][j].charCodeAt(0) !== 65533) {
          e[D[242][j]] = 61952 + j;
          d[61952 + j] = D[242][j];
        }
      D[243] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9A5A\u9A5B\u9A5C\u9A5D\u9A5E\u9A5F\u9A60\u9A61\u9A62\u9A63\u9A64\u9A65\u9A66\u9A67\u9A68\u9A69\u9A6A\u9A6B\u9A72\u9A83\u9A89\u9A8D\u9A8E\u9A94\u9A95\u9A99\u9AA6\u9AA9\u9AAA\u9AAB\u9AAC\u9AAD\u9AAE\u9AAF\u9AB2\u9AB3\u9AB4\u9AB5\u9AB9\u9ABB\u9ABD\u9ABE\u9ABF\u9AC3\u9AC4\u9AC6\u9AC7\u9AC8\u9AC9\u9ACA\u9ACD\u9ACE\u9ACF\u9AD0\u9AD2\u9AD4\u9AD5\u9AD6\u9AD7\u9AD9\u9ADA\u9ADB\u9ADC\uFFFD\u9ADD\u9ADE\u9AE0\u9AE2\u9AE3\u9AE4\u9AE5\u9AE7\u9AE8\u9AE9\u9AEA\u9AEC\u9AEE\u9AF0\u9AF1\u9AF2\u9AF3\u9AF4\u9AF5\u9AF6\u9AF7\u9AF8\u9AFA\u9AFC\u9AFD\u9AFE\u9AFF\u9B00\u9B01\u9B02\u9B04\u9B05\u9B06\u87C6\u8788\u8785\u87AD\u8797\u8783\u87AB\u87E5\u87AC\u87B5\u87B3\u87CB\u87D3\u87BD\u87D1\u87C0\u87CA\u87DB\u87EA\u87E0\u87EE\u8816\u8813\u87FE\u880A\u881B\u8821\u8839\u883C\u7F36\u7F42\u7F44\u7F45\u8210\u7AFA\u7AFD\u7B08\u7B03\u7B04\u7B15\u7B0A\u7B2B\u7B0F\u7B47\u7B38\u7B2A\u7B19\u7B2E\u7B31\u7B20\u7B25\u7B24\u7B33\u7B3E\u7B1E\u7B58\u7B5A\u7B45\u7B75\u7B4C\u7B5D\u7B60\u7B6E\u7B7B\u7B62\u7B72\u7B71\u7B90\u7BA6\u7BA7\u7BB8\u7BAC\u7B9D\u7BA8\u7B85\u7BAA\u7B9C\u7BA2\u7BAB\u7BB4\u7BD1\u7BC1\u7BCC\u7BDD\u7BDA\u7BE5\u7BE6\u7BEA\u7C0C\u7BFE\u7BFC\u7C0F\u7C16\u7C0B\uFFFD".split("");
      for (j = 0; j != D[243].length; ++j)
        if (D[243][j].charCodeAt(0) !== 65533) {
          e[D[243][j]] = 62208 + j;
          d[62208 + j] = D[243][j];
        }
      D[244] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9B07\u9B09\u9B0A\u9B0B\u9B0C\u9B0D\u9B0E\u9B10\u9B11\u9B12\u9B14\u9B15\u9B16\u9B17\u9B18\u9B19\u9B1A\u9B1B\u9B1C\u9B1D\u9B1E\u9B20\u9B21\u9B22\u9B24\u9B25\u9B26\u9B27\u9B28\u9B29\u9B2A\u9B2B\u9B2C\u9B2D\u9B2E\u9B30\u9B31\u9B33\u9B34\u9B35\u9B36\u9B37\u9B38\u9B39\u9B3A\u9B3D\u9B3E\u9B3F\u9B40\u9B46\u9B4A\u9B4B\u9B4C\u9B4E\u9B50\u9B52\u9B53\u9B55\u9B56\u9B57\u9B58\u9B59\u9B5A\uFFFD\u9B5B\u9B5C\u9B5D\u9B5E\u9B5F\u9B60\u9B61\u9B62\u9B63\u9B64\u9B65\u9B66\u9B67\u9B68\u9B69\u9B6A\u9B6B\u9B6C\u9B6D\u9B6E\u9B6F\u9B70\u9B71\u9B72\u9B73\u9B74\u9B75\u9B76\u9B77\u9B78\u9B79\u9B7A\u9B7B\u7C1F\u7C2A\u7C26\u7C38\u7C41\u7C40\u81FE\u8201\u8202\u8204\u81EC\u8844\u8221\u8222\u8223\u822D\u822F\u8228\u822B\u8238\u823B\u8233\u8234\u823E\u8244\u8249\u824B\u824F\u825A\u825F\u8268\u887E\u8885\u8888\u88D8\u88DF\u895E\u7F9D\u7F9F\u7FA7\u7FAF\u7FB0\u7FB2\u7C7C\u6549\u7C91\u7C9D\u7C9C\u7C9E\u7CA2\u7CB2\u7CBC\u7CBD\u7CC1\u7CC7\u7CCC\u7CCD\u7CC8\u7CC5\u7CD7\u7CE8\u826E\u66A8\u7FBF\u7FCE\u7FD5\u7FE5\u7FE1\u7FE6\u7FE9\u7FEE\u7FF3\u7CF8\u7D77\u7DA6\u7DAE\u7E47\u7E9B\u9EB8\u9EB4\u8D73\u8D84\u8D94\u8D91\u8DB1\u8D67\u8D6D\u8C47\u8C49\u914A\u9150\u914E\u914F\u9164\uFFFD".split("");
      for (j = 0; j != D[244].length; ++j)
        if (D[244][j].charCodeAt(0) !== 65533) {
          e[D[244][j]] = 62464 + j;
          d[62464 + j] = D[244][j];
        }
      D[245] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9B7C\u9B7D\u9B7E\u9B7F\u9B80\u9B81\u9B82\u9B83\u9B84\u9B85\u9B86\u9B87\u9B88\u9B89\u9B8A\u9B8B\u9B8C\u9B8D\u9B8E\u9B8F\u9B90\u9B91\u9B92\u9B93\u9B94\u9B95\u9B96\u9B97\u9B98\u9B99\u9B9A\u9B9B\u9B9C\u9B9D\u9B9E\u9B9F\u9BA0\u9BA1\u9BA2\u9BA3\u9BA4\u9BA5\u9BA6\u9BA7\u9BA8\u9BA9\u9BAA\u9BAB\u9BAC\u9BAD\u9BAE\u9BAF\u9BB0\u9BB1\u9BB2\u9BB3\u9BB4\u9BB5\u9BB6\u9BB7\u9BB8\u9BB9\u9BBA\uFFFD\u9BBB\u9BBC\u9BBD\u9BBE\u9BBF\u9BC0\u9BC1\u9BC2\u9BC3\u9BC4\u9BC5\u9BC6\u9BC7\u9BC8\u9BC9\u9BCA\u9BCB\u9BCC\u9BCD\u9BCE\u9BCF\u9BD0\u9BD1\u9BD2\u9BD3\u9BD4\u9BD5\u9BD6\u9BD7\u9BD8\u9BD9\u9BDA\u9BDB\u9162\u9161\u9170\u9169\u916F\u917D\u917E\u9172\u9174\u9179\u918C\u9185\u9190\u918D\u9191\u91A2\u91A3\u91AA\u91AD\u91AE\u91AF\u91B5\u91B4\u91BA\u8C55\u9E7E\u8DB8\u8DEB\u8E05\u8E59\u8E69\u8DB5\u8DBF\u8DBC\u8DBA\u8DC4\u8DD6\u8DD7\u8DDA\u8DDE\u8DCE\u8DCF\u8DDB\u8DC6\u8DEC\u8DF7\u8DF8\u8DE3\u8DF9\u8DFB\u8DE4\u8E09\u8DFD\u8E14\u8E1D\u8E1F\u8E2C\u8E2E\u8E23\u8E2F\u8E3A\u8E40\u8E39\u8E35\u8E3D\u8E31\u8E49\u8E41\u8E42\u8E51\u8E52\u8E4A\u8E70\u8E76\u8E7C\u8E6F\u8E74\u8E85\u8E8F\u8E94\u8E90\u8E9C\u8E9E\u8C78\u8C82\u8C8A\u8C85\u8C98\u8C94\u659B\u89D6\u89DE\u89DA\u89DC\uFFFD".split("");
      for (j = 0; j != D[245].length; ++j)
        if (D[245][j].charCodeAt(0) !== 65533) {
          e[D[245][j]] = 62720 + j;
          d[62720 + j] = D[245][j];
        }
      D[246] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9BDC\u9BDD\u9BDE\u9BDF\u9BE0\u9BE1\u9BE2\u9BE3\u9BE4\u9BE5\u9BE6\u9BE7\u9BE8\u9BE9\u9BEA\u9BEB\u9BEC\u9BED\u9BEE\u9BEF\u9BF0\u9BF1\u9BF2\u9BF3\u9BF4\u9BF5\u9BF6\u9BF7\u9BF8\u9BF9\u9BFA\u9BFB\u9BFC\u9BFD\u9BFE\u9BFF\u9C00\u9C01\u9C02\u9C03\u9C04\u9C05\u9C06\u9C07\u9C08\u9C09\u9C0A\u9C0B\u9C0C\u9C0D\u9C0E\u9C0F\u9C10\u9C11\u9C12\u9C13\u9C14\u9C15\u9C16\u9C17\u9C18\u9C19\u9C1A\uFFFD\u9C1B\u9C1C\u9C1D\u9C1E\u9C1F\u9C20\u9C21\u9C22\u9C23\u9C24\u9C25\u9C26\u9C27\u9C28\u9C29\u9C2A\u9C2B\u9C2C\u9C2D\u9C2E\u9C2F\u9C30\u9C31\u9C32\u9C33\u9C34\u9C35\u9C36\u9C37\u9C38\u9C39\u9C3A\u9C3B\u89E5\u89EB\u89EF\u8A3E\u8B26\u9753\u96E9\u96F3\u96EF\u9706\u9701\u9708\u970F\u970E\u972A\u972D\u9730\u973E\u9F80\u9F83\u9F85\u9F86\u9F87\u9F88\u9F89\u9F8A\u9F8C\u9EFE\u9F0B\u9F0D\u96B9\u96BC\u96BD\u96CE\u96D2\u77BF\u96E0\u928E\u92AE\u92C8\u933E\u936A\u93CA\u938F\u943E\u946B\u9C7F\u9C82\u9C85\u9C86\u9C87\u9C88\u7A23\u9C8B\u9C8E\u9C90\u9C91\u9C92\u9C94\u9C95\u9C9A\u9C9B\u9C9E\u9C9F\u9CA0\u9CA1\u9CA2\u9CA3\u9CA5\u9CA6\u9CA7\u9CA8\u9CA9\u9CAB\u9CAD\u9CAE\u9CB0\u9CB1\u9CB2\u9CB3\u9CB4\u9CB5\u9CB6\u9CB7\u9CBA\u9CBB\u9CBC\u9CBD\u9CC4\u9CC5\u9CC6\u9CC7\u9CCA\u9CCB\uFFFD".split("");
      for (j = 0; j != D[246].length; ++j)
        if (D[246][j].charCodeAt(0) !== 65533) {
          e[D[246][j]] = 62976 + j;
          d[62976 + j] = D[246][j];
        }
      D[247] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9C3C\u9C3D\u9C3E\u9C3F\u9C40\u9C41\u9C42\u9C43\u9C44\u9C45\u9C46\u9C47\u9C48\u9C49\u9C4A\u9C4B\u9C4C\u9C4D\u9C4E\u9C4F\u9C50\u9C51\u9C52\u9C53\u9C54\u9C55\u9C56\u9C57\u9C58\u9C59\u9C5A\u9C5B\u9C5C\u9C5D\u9C5E\u9C5F\u9C60\u9C61\u9C62\u9C63\u9C64\u9C65\u9C66\u9C67\u9C68\u9C69\u9C6A\u9C6B\u9C6C\u9C6D\u9C6E\u9C6F\u9C70\u9C71\u9C72\u9C73\u9C74\u9C75\u9C76\u9C77\u9C78\u9C79\u9C7A\uFFFD\u9C7B\u9C7D\u9C7E\u9C80\u9C83\u9C84\u9C89\u9C8A\u9C8C\u9C8F\u9C93\u9C96\u9C97\u9C98\u9C99\u9C9D\u9CAA\u9CAC\u9CAF\u9CB9\u9CBE\u9CBF\u9CC0\u9CC1\u9CC2\u9CC8\u9CC9\u9CD1\u9CD2\u9CDA\u9CDB\u9CE0\u9CE1\u9CCC\u9CCD\u9CCE\u9CCF\u9CD0\u9CD3\u9CD4\u9CD5\u9CD7\u9CD8\u9CD9\u9CDC\u9CDD\u9CDF\u9CE2\u977C\u9785\u9791\u9792\u9794\u97AF\u97AB\u97A3\u97B2\u97B4\u9AB1\u9AB0\u9AB7\u9E58\u9AB6\u9ABA\u9ABC\u9AC1\u9AC0\u9AC5\u9AC2\u9ACB\u9ACC\u9AD1\u9B45\u9B43\u9B47\u9B49\u9B48\u9B4D\u9B51\u98E8\u990D\u992E\u9955\u9954\u9ADF\u9AE1\u9AE6\u9AEF\u9AEB\u9AFB\u9AED\u9AF9\u9B08\u9B0F\u9B13\u9B1F\u9B23\u9EBD\u9EBE\u7E3B\u9E82\u9E87\u9E88\u9E8B\u9E92\u93D6\u9E9D\u9E9F\u9EDB\u9EDC\u9EDD\u9EE0\u9EDF\u9EE2\u9EE9\u9EE7\u9EE5\u9EEA\u9EEF\u9F22\u9F2C\u9F2F\u9F39\u9F37\u9F3D\u9F3E\u9F44\uFFFD".split("");
      for (j = 0; j != D[247].length; ++j)
        if (D[247][j].charCodeAt(0) !== 65533) {
          e[D[247][j]] = 63232 + j;
          d[63232 + j] = D[247][j];
        }
      D[248] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9CE3\u9CE4\u9CE5\u9CE6\u9CE7\u9CE8\u9CE9\u9CEA\u9CEB\u9CEC\u9CED\u9CEE\u9CEF\u9CF0\u9CF1\u9CF2\u9CF3\u9CF4\u9CF5\u9CF6\u9CF7\u9CF8\u9CF9\u9CFA\u9CFB\u9CFC\u9CFD\u9CFE\u9CFF\u9D00\u9D01\u9D02\u9D03\u9D04\u9D05\u9D06\u9D07\u9D08\u9D09\u9D0A\u9D0B\u9D0C\u9D0D\u9D0E\u9D0F\u9D10\u9D11\u9D12\u9D13\u9D14\u9D15\u9D16\u9D17\u9D18\u9D19\u9D1A\u9D1B\u9D1C\u9D1D\u9D1E\u9D1F\u9D20\u9D21\uFFFD\u9D22\u9D23\u9D24\u9D25\u9D26\u9D27\u9D28\u9D29\u9D2A\u9D2B\u9D2C\u9D2D\u9D2E\u9D2F\u9D30\u9D31\u9D32\u9D33\u9D34\u9D35\u9D36\u9D37\u9D38\u9D39\u9D3A\u9D3B\u9D3C\u9D3D\u9D3E\u9D3F\u9D40\u9D41\u9D42\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[248].length; ++j)
        if (D[248][j].charCodeAt(0) !== 65533) {
          e[D[248][j]] = 63488 + j;
          d[63488 + j] = D[248][j];
        }
      D[249] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9D43\u9D44\u9D45\u9D46\u9D47\u9D48\u9D49\u9D4A\u9D4B\u9D4C\u9D4D\u9D4E\u9D4F\u9D50\u9D51\u9D52\u9D53\u9D54\u9D55\u9D56\u9D57\u9D58\u9D59\u9D5A\u9D5B\u9D5C\u9D5D\u9D5E\u9D5F\u9D60\u9D61\u9D62\u9D63\u9D64\u9D65\u9D66\u9D67\u9D68\u9D69\u9D6A\u9D6B\u9D6C\u9D6D\u9D6E\u9D6F\u9D70\u9D71\u9D72\u9D73\u9D74\u9D75\u9D76\u9D77\u9D78\u9D79\u9D7A\u9D7B\u9D7C\u9D7D\u9D7E\u9D7F\u9D80\u9D81\uFFFD\u9D82\u9D83\u9D84\u9D85\u9D86\u9D87\u9D88\u9D89\u9D8A\u9D8B\u9D8C\u9D8D\u9D8E\u9D8F\u9D90\u9D91\u9D92\u9D93\u9D94\u9D95\u9D96\u9D97\u9D98\u9D99\u9D9A\u9D9B\u9D9C\u9D9D\u9D9E\u9D9F\u9DA0\u9DA1\u9DA2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[249].length; ++j)
        if (D[249][j].charCodeAt(0) !== 65533) {
          e[D[249][j]] = 63744 + j;
          d[63744 + j] = D[249][j];
        }
      D[250] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9DA3\u9DA4\u9DA5\u9DA6\u9DA7\u9DA8\u9DA9\u9DAA\u9DAB\u9DAC\u9DAD\u9DAE\u9DAF\u9DB0\u9DB1\u9DB2\u9DB3\u9DB4\u9DB5\u9DB6\u9DB7\u9DB8\u9DB9\u9DBA\u9DBB\u9DBC\u9DBD\u9DBE\u9DBF\u9DC0\u9DC1\u9DC2\u9DC3\u9DC4\u9DC5\u9DC6\u9DC7\u9DC8\u9DC9\u9DCA\u9DCB\u9DCC\u9DCD\u9DCE\u9DCF\u9DD0\u9DD1\u9DD2\u9DD3\u9DD4\u9DD5\u9DD6\u9DD7\u9DD8\u9DD9\u9DDA\u9DDB\u9DDC\u9DDD\u9DDE\u9DDF\u9DE0\u9DE1\uFFFD\u9DE2\u9DE3\u9DE4\u9DE5\u9DE6\u9DE7\u9DE8\u9DE9\u9DEA\u9DEB\u9DEC\u9DED\u9DEE\u9DEF\u9DF0\u9DF1\u9DF2\u9DF3\u9DF4\u9DF5\u9DF6\u9DF7\u9DF8\u9DF9\u9DFA\u9DFB\u9DFC\u9DFD\u9DFE\u9DFF\u9E00\u9E01\u9E02\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[250].length; ++j)
        if (D[250][j].charCodeAt(0) !== 65533) {
          e[D[250][j]] = 64e3 + j;
          d[64e3 + j] = D[250][j];
        }
      D[251] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9E03\u9E04\u9E05\u9E06\u9E07\u9E08\u9E09\u9E0A\u9E0B\u9E0C\u9E0D\u9E0E\u9E0F\u9E10\u9E11\u9E12\u9E13\u9E14\u9E15\u9E16\u9E17\u9E18\u9E19\u9E1A\u9E1B\u9E1C\u9E1D\u9E1E\u9E24\u9E27\u9E2E\u9E30\u9E34\u9E3B\u9E3C\u9E40\u9E4D\u9E50\u9E52\u9E53\u9E54\u9E56\u9E59\u9E5D\u9E5F\u9E60\u9E61\u9E62\u9E65\u9E6E\u9E6F\u9E72\u9E74\u9E75\u9E76\u9E77\u9E78\u9E79\u9E7A\u9E7B\u9E7C\u9E7D\u9E80\uFFFD\u9E81\u9E83\u9E84\u9E85\u9E86\u9E89\u9E8A\u9E8C\u9E8D\u9E8E\u9E8F\u9E90\u9E91\u9E94\u9E95\u9E96\u9E97\u9E98\u9E99\u9E9A\u9E9B\u9E9C\u9E9E\u9EA0\u9EA1\u9EA2\u9EA3\u9EA4\u9EA5\u9EA7\u9EA8\u9EA9\u9EAA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[251].length; ++j)
        if (D[251][j].charCodeAt(0) !== 65533) {
          e[D[251][j]] = 64256 + j;
          d[64256 + j] = D[251][j];
        }
      D[252] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9EAB\u9EAC\u9EAD\u9EAE\u9EAF\u9EB0\u9EB1\u9EB2\u9EB3\u9EB5\u9EB6\u9EB7\u9EB9\u9EBA\u9EBC\u9EBF\u9EC0\u9EC1\u9EC2\u9EC3\u9EC5\u9EC6\u9EC7\u9EC8\u9ECA\u9ECB\u9ECC\u9ED0\u9ED2\u9ED3\u9ED5\u9ED6\u9ED7\u9ED9\u9EDA\u9EDE\u9EE1\u9EE3\u9EE4\u9EE6\u9EE8\u9EEB\u9EEC\u9EED\u9EEE\u9EF0\u9EF1\u9EF2\u9EF3\u9EF4\u9EF5\u9EF6\u9EF7\u9EF8\u9EFA\u9EFD\u9EFF\u9F00\u9F01\u9F02\u9F03\u9F04\u9F05\uFFFD\u9F06\u9F07\u9F08\u9F09\u9F0A\u9F0C\u9F0F\u9F11\u9F12\u9F14\u9F15\u9F16\u9F18\u9F1A\u9F1B\u9F1C\u9F1D\u9F1E\u9F1F\u9F21\u9F23\u9F24\u9F25\u9F26\u9F27\u9F28\u9F29\u9F2A\u9F2B\u9F2D\u9F2E\u9F30\u9F31\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[252].length; ++j)
        if (D[252][j].charCodeAt(0) !== 65533) {
          e[D[252][j]] = 64512 + j;
          d[64512 + j] = D[252][j];
        }
      D[253] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9F32\u9F33\u9F34\u9F35\u9F36\u9F38\u9F3A\u9F3C\u9F3F\u9F40\u9F41\u9F42\u9F43\u9F45\u9F46\u9F47\u9F48\u9F49\u9F4A\u9F4B\u9F4C\u9F4D\u9F4E\u9F4F\u9F52\u9F53\u9F54\u9F55\u9F56\u9F57\u9F58\u9F59\u9F5A\u9F5B\u9F5C\u9F5D\u9F5E\u9F5F\u9F60\u9F61\u9F62\u9F63\u9F64\u9F65\u9F66\u9F67\u9F68\u9F69\u9F6A\u9F6B\u9F6C\u9F6D\u9F6E\u9F6F\u9F70\u9F71\u9F72\u9F73\u9F74\u9F75\u9F76\u9F77\u9F78\uFFFD\u9F79\u9F7A\u9F7B\u9F7C\u9F7D\u9F7E\u9F81\u9F82\u9F8D\u9F8E\u9F8F\u9F90\u9F91\u9F92\u9F93\u9F94\u9F95\u9F96\u9F97\u9F98\u9F9C\u9F9D\u9F9E\u9FA1\u9FA2\u9FA3\u9FA4\u9FA5\uF92C\uF979\uF995\uF9E7\uF9F1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[253].length; ++j)
        if (D[253][j].charCodeAt(0) !== 65533) {
          e[D[253][j]] = 64768 + j;
          d[64768 + j] = D[253][j];
        }
      D[254] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFA0C\uFA0D\uFA0E\uFA0F\uFA11\uFA13\uFA14\uFA18\uFA1F\uFA20\uFA21\uFA23\uFA24\uFA27\uFA28\uFA29\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[254].length; ++j)
        if (D[254][j].charCodeAt(0) !== 65533) {
          e[D[254][j]] = 65024 + j;
          d[65024 + j] = D[254][j];
        }
      return { "enc": e, "dec": d };
    }();
    cptable2[949] = function() {
      var d = [], e = {}, D = [], j;
      D[0] = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[0].length; ++j)
        if (D[0][j].charCodeAt(0) !== 65533) {
          e[D[0][j]] = 0 + j;
          d[0 + j] = D[0][j];
        }
      D[129] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAC02\uAC03\uAC05\uAC06\uAC0B\uAC0C\uAC0D\uAC0E\uAC0F\uAC18\uAC1E\uAC1F\uAC21\uAC22\uAC23\uAC25\uAC26\uAC27\uAC28\uAC29\uAC2A\uAC2B\uAC2E\uAC32\uAC33\uAC34\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAC35\uAC36\uAC37\uAC3A\uAC3B\uAC3D\uAC3E\uAC3F\uAC41\uAC42\uAC43\uAC44\uAC45\uAC46\uAC47\uAC48\uAC49\uAC4A\uAC4C\uAC4E\uAC4F\uAC50\uAC51\uAC52\uAC53\uAC55\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAC56\uAC57\uAC59\uAC5A\uAC5B\uAC5D\uAC5E\uAC5F\uAC60\uAC61\uAC62\uAC63\uAC64\uAC65\uAC66\uAC67\uAC68\uAC69\uAC6A\uAC6B\uAC6C\uAC6D\uAC6E\uAC6F\uAC72\uAC73\uAC75\uAC76\uAC79\uAC7B\uAC7C\uAC7D\uAC7E\uAC7F\uAC82\uAC87\uAC88\uAC8D\uAC8E\uAC8F\uAC91\uAC92\uAC93\uAC95\uAC96\uAC97\uAC98\uAC99\uAC9A\uAC9B\uAC9E\uACA2\uACA3\uACA4\uACA5\uACA6\uACA7\uACAB\uACAD\uACAE\uACB1\uACB2\uACB3\uACB4\uACB5\uACB6\uACB7\uACBA\uACBE\uACBF\uACC0\uACC2\uACC3\uACC5\uACC6\uACC7\uACC9\uACCA\uACCB\uACCD\uACCE\uACCF\uACD0\uACD1\uACD2\uACD3\uACD4\uACD6\uACD8\uACD9\uACDA\uACDB\uACDC\uACDD\uACDE\uACDF\uACE2\uACE3\uACE5\uACE6\uACE9\uACEB\uACED\uACEE\uACF2\uACF4\uACF7\uACF8\uACF9\uACFA\uACFB\uACFE\uACFF\uAD01\uAD02\uAD03\uAD05\uAD07\uAD08\uAD09\uAD0A\uAD0B\uAD0E\uAD10\uAD12\uAD13\uFFFD".split("");
      for (j = 0; j != D[129].length; ++j)
        if (D[129][j].charCodeAt(0) !== 65533) {
          e[D[129][j]] = 33024 + j;
          d[33024 + j] = D[129][j];
        }
      D[130] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAD14\uAD15\uAD16\uAD17\uAD19\uAD1A\uAD1B\uAD1D\uAD1E\uAD1F\uAD21\uAD22\uAD23\uAD24\uAD25\uAD26\uAD27\uAD28\uAD2A\uAD2B\uAD2E\uAD2F\uAD30\uAD31\uAD32\uAD33\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAD36\uAD37\uAD39\uAD3A\uAD3B\uAD3D\uAD3E\uAD3F\uAD40\uAD41\uAD42\uAD43\uAD46\uAD48\uAD4A\uAD4B\uAD4C\uAD4D\uAD4E\uAD4F\uAD51\uAD52\uAD53\uAD55\uAD56\uAD57\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAD59\uAD5A\uAD5B\uAD5C\uAD5D\uAD5E\uAD5F\uAD60\uAD62\uAD64\uAD65\uAD66\uAD67\uAD68\uAD69\uAD6A\uAD6B\uAD6E\uAD6F\uAD71\uAD72\uAD77\uAD78\uAD79\uAD7A\uAD7E\uAD80\uAD83\uAD84\uAD85\uAD86\uAD87\uAD8A\uAD8B\uAD8D\uAD8E\uAD8F\uAD91\uAD92\uAD93\uAD94\uAD95\uAD96\uAD97\uAD98\uAD99\uAD9A\uAD9B\uAD9E\uAD9F\uADA0\uADA1\uADA2\uADA3\uADA5\uADA6\uADA7\uADA8\uADA9\uADAA\uADAB\uADAC\uADAD\uADAE\uADAF\uADB0\uADB1\uADB2\uADB3\uADB4\uADB5\uADB6\uADB8\uADB9\uADBA\uADBB\uADBC\uADBD\uADBE\uADBF\uADC2\uADC3\uADC5\uADC6\uADC7\uADC9\uADCA\uADCB\uADCC\uADCD\uADCE\uADCF\uADD2\uADD4\uADD5\uADD6\uADD7\uADD8\uADD9\uADDA\uADDB\uADDD\uADDE\uADDF\uADE1\uADE2\uADE3\uADE5\uADE6\uADE7\uADE8\uADE9\uADEA\uADEB\uADEC\uADED\uADEE\uADEF\uADF0\uADF1\uADF2\uADF3\uADF4\uADF5\uADF6\uADF7\uFFFD".split("");
      for (j = 0; j != D[130].length; ++j)
        if (D[130][j].charCodeAt(0) !== 65533) {
          e[D[130][j]] = 33280 + j;
          d[33280 + j] = D[130][j];
        }
      D[131] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uADFA\uADFB\uADFD\uADFE\uAE02\uAE03\uAE04\uAE05\uAE06\uAE07\uAE0A\uAE0C\uAE0E\uAE0F\uAE10\uAE11\uAE12\uAE13\uAE15\uAE16\uAE17\uAE18\uAE19\uAE1A\uAE1B\uAE1C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAE1D\uAE1E\uAE1F\uAE20\uAE21\uAE22\uAE23\uAE24\uAE25\uAE26\uAE27\uAE28\uAE29\uAE2A\uAE2B\uAE2C\uAE2D\uAE2E\uAE2F\uAE32\uAE33\uAE35\uAE36\uAE39\uAE3B\uAE3C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAE3D\uAE3E\uAE3F\uAE42\uAE44\uAE47\uAE48\uAE49\uAE4B\uAE4F\uAE51\uAE52\uAE53\uAE55\uAE57\uAE58\uAE59\uAE5A\uAE5B\uAE5E\uAE62\uAE63\uAE64\uAE66\uAE67\uAE6A\uAE6B\uAE6D\uAE6E\uAE6F\uAE71\uAE72\uAE73\uAE74\uAE75\uAE76\uAE77\uAE7A\uAE7E\uAE7F\uAE80\uAE81\uAE82\uAE83\uAE86\uAE87\uAE88\uAE89\uAE8A\uAE8B\uAE8D\uAE8E\uAE8F\uAE90\uAE91\uAE92\uAE93\uAE94\uAE95\uAE96\uAE97\uAE98\uAE99\uAE9A\uAE9B\uAE9C\uAE9D\uAE9E\uAE9F\uAEA0\uAEA1\uAEA2\uAEA3\uAEA4\uAEA5\uAEA6\uAEA7\uAEA8\uAEA9\uAEAA\uAEAB\uAEAC\uAEAD\uAEAE\uAEAF\uAEB0\uAEB1\uAEB2\uAEB3\uAEB4\uAEB5\uAEB6\uAEB7\uAEB8\uAEB9\uAEBA\uAEBB\uAEBF\uAEC1\uAEC2\uAEC3\uAEC5\uAEC6\uAEC7\uAEC8\uAEC9\uAECA\uAECB\uAECE\uAED2\uAED3\uAED4\uAED5\uAED6\uAED7\uAEDA\uAEDB\uAEDD\uAEDE\uAEDF\uAEE0\uAEE1\uAEE2\uAEE3\uAEE4\uAEE5\uFFFD".split("");
      for (j = 0; j != D[131].length; ++j)
        if (D[131][j].charCodeAt(0) !== 65533) {
          e[D[131][j]] = 33536 + j;
          d[33536 + j] = D[131][j];
        }
      D[132] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAEE6\uAEE7\uAEE9\uAEEA\uAEEC\uAEEE\uAEEF\uAEF0\uAEF1\uAEF2\uAEF3\uAEF5\uAEF6\uAEF7\uAEF9\uAEFA\uAEFB\uAEFD\uAEFE\uAEFF\uAF00\uAF01\uAF02\uAF03\uAF04\uAF05\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAF06\uAF09\uAF0A\uAF0B\uAF0C\uAF0E\uAF0F\uAF11\uAF12\uAF13\uAF14\uAF15\uAF16\uAF17\uAF18\uAF19\uAF1A\uAF1B\uAF1C\uAF1D\uAF1E\uAF1F\uAF20\uAF21\uAF22\uAF23\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAF24\uAF25\uAF26\uAF27\uAF28\uAF29\uAF2A\uAF2B\uAF2E\uAF2F\uAF31\uAF33\uAF35\uAF36\uAF37\uAF38\uAF39\uAF3A\uAF3B\uAF3E\uAF40\uAF44\uAF45\uAF46\uAF47\uAF4A\uAF4B\uAF4C\uAF4D\uAF4E\uAF4F\uAF51\uAF52\uAF53\uAF54\uAF55\uAF56\uAF57\uAF58\uAF59\uAF5A\uAF5B\uAF5E\uAF5F\uAF60\uAF61\uAF62\uAF63\uAF66\uAF67\uAF68\uAF69\uAF6A\uAF6B\uAF6C\uAF6D\uAF6E\uAF6F\uAF70\uAF71\uAF72\uAF73\uAF74\uAF75\uAF76\uAF77\uAF78\uAF7A\uAF7B\uAF7C\uAF7D\uAF7E\uAF7F\uAF81\uAF82\uAF83\uAF85\uAF86\uAF87\uAF89\uAF8A\uAF8B\uAF8C\uAF8D\uAF8E\uAF8F\uAF92\uAF93\uAF94\uAF96\uAF97\uAF98\uAF99\uAF9A\uAF9B\uAF9D\uAF9E\uAF9F\uAFA0\uAFA1\uAFA2\uAFA3\uAFA4\uAFA5\uAFA6\uAFA7\uAFA8\uAFA9\uAFAA\uAFAB\uAFAC\uAFAD\uAFAE\uAFAF\uAFB0\uAFB1\uAFB2\uAFB3\uAFB4\uAFB5\uAFB6\uAFB7\uAFBA\uAFBB\uAFBD\uAFBE\uFFFD".split("");
      for (j = 0; j != D[132].length; ++j)
        if (D[132][j].charCodeAt(0) !== 65533) {
          e[D[132][j]] = 33792 + j;
          d[33792 + j] = D[132][j];
        }
      D[133] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAFBF\uAFC1\uAFC2\uAFC3\uAFC4\uAFC5\uAFC6\uAFCA\uAFCC\uAFCF\uAFD0\uAFD1\uAFD2\uAFD3\uAFD5\uAFD6\uAFD7\uAFD8\uAFD9\uAFDA\uAFDB\uAFDD\uAFDE\uAFDF\uAFE0\uAFE1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uAFE2\uAFE3\uAFE4\uAFE5\uAFE6\uAFE7\uAFEA\uAFEB\uAFEC\uAFED\uAFEE\uAFEF\uAFF2\uAFF3\uAFF5\uAFF6\uAFF7\uAFF9\uAFFA\uAFFB\uAFFC\uAFFD\uAFFE\uAFFF\uB002\uB003\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB005\uB006\uB007\uB008\uB009\uB00A\uB00B\uB00D\uB00E\uB00F\uB011\uB012\uB013\uB015\uB016\uB017\uB018\uB019\uB01A\uB01B\uB01E\uB01F\uB020\uB021\uB022\uB023\uB024\uB025\uB026\uB027\uB029\uB02A\uB02B\uB02C\uB02D\uB02E\uB02F\uB030\uB031\uB032\uB033\uB034\uB035\uB036\uB037\uB038\uB039\uB03A\uB03B\uB03C\uB03D\uB03E\uB03F\uB040\uB041\uB042\uB043\uB046\uB047\uB049\uB04B\uB04D\uB04F\uB050\uB051\uB052\uB056\uB058\uB05A\uB05B\uB05C\uB05E\uB05F\uB060\uB061\uB062\uB063\uB064\uB065\uB066\uB067\uB068\uB069\uB06A\uB06B\uB06C\uB06D\uB06E\uB06F\uB070\uB071\uB072\uB073\uB074\uB075\uB076\uB077\uB078\uB079\uB07A\uB07B\uB07E\uB07F\uB081\uB082\uB083\uB085\uB086\uB087\uB088\uB089\uB08A\uB08B\uB08E\uB090\uB092\uB093\uB094\uB095\uB096\uB097\uB09B\uB09D\uB09E\uB0A3\uB0A4\uFFFD".split("");
      for (j = 0; j != D[133].length; ++j)
        if (D[133][j].charCodeAt(0) !== 65533) {
          e[D[133][j]] = 34048 + j;
          d[34048 + j] = D[133][j];
        }
      D[134] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB0A5\uB0A6\uB0A7\uB0AA\uB0B0\uB0B2\uB0B6\uB0B7\uB0B9\uB0BA\uB0BB\uB0BD\uB0BE\uB0BF\uB0C0\uB0C1\uB0C2\uB0C3\uB0C6\uB0CA\uB0CB\uB0CC\uB0CD\uB0CE\uB0CF\uB0D2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB0D3\uB0D5\uB0D6\uB0D7\uB0D9\uB0DA\uB0DB\uB0DC\uB0DD\uB0DE\uB0DF\uB0E1\uB0E2\uB0E3\uB0E4\uB0E6\uB0E7\uB0E8\uB0E9\uB0EA\uB0EB\uB0EC\uB0ED\uB0EE\uB0EF\uB0F0\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB0F1\uB0F2\uB0F3\uB0F4\uB0F5\uB0F6\uB0F7\uB0F8\uB0F9\uB0FA\uB0FB\uB0FC\uB0FD\uB0FE\uB0FF\uB100\uB101\uB102\uB103\uB104\uB105\uB106\uB107\uB10A\uB10D\uB10E\uB10F\uB111\uB114\uB115\uB116\uB117\uB11A\uB11E\uB11F\uB120\uB121\uB122\uB126\uB127\uB129\uB12A\uB12B\uB12D\uB12E\uB12F\uB130\uB131\uB132\uB133\uB136\uB13A\uB13B\uB13C\uB13D\uB13E\uB13F\uB142\uB143\uB145\uB146\uB147\uB149\uB14A\uB14B\uB14C\uB14D\uB14E\uB14F\uB152\uB153\uB156\uB157\uB159\uB15A\uB15B\uB15D\uB15E\uB15F\uB161\uB162\uB163\uB164\uB165\uB166\uB167\uB168\uB169\uB16A\uB16B\uB16C\uB16D\uB16E\uB16F\uB170\uB171\uB172\uB173\uB174\uB175\uB176\uB177\uB17A\uB17B\uB17D\uB17E\uB17F\uB181\uB183\uB184\uB185\uB186\uB187\uB18A\uB18C\uB18E\uB18F\uB190\uB191\uB195\uB196\uB197\uB199\uB19A\uB19B\uB19D\uFFFD".split("");
      for (j = 0; j != D[134].length; ++j)
        if (D[134][j].charCodeAt(0) !== 65533) {
          e[D[134][j]] = 34304 + j;
          d[34304 + j] = D[134][j];
        }
      D[135] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB19E\uB19F\uB1A0\uB1A1\uB1A2\uB1A3\uB1A4\uB1A5\uB1A6\uB1A7\uB1A9\uB1AA\uB1AB\uB1AC\uB1AD\uB1AE\uB1AF\uB1B0\uB1B1\uB1B2\uB1B3\uB1B4\uB1B5\uB1B6\uB1B7\uB1B8\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB1B9\uB1BA\uB1BB\uB1BC\uB1BD\uB1BE\uB1BF\uB1C0\uB1C1\uB1C2\uB1C3\uB1C4\uB1C5\uB1C6\uB1C7\uB1C8\uB1C9\uB1CA\uB1CB\uB1CD\uB1CE\uB1CF\uB1D1\uB1D2\uB1D3\uB1D5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB1D6\uB1D7\uB1D8\uB1D9\uB1DA\uB1DB\uB1DE\uB1E0\uB1E1\uB1E2\uB1E3\uB1E4\uB1E5\uB1E6\uB1E7\uB1EA\uB1EB\uB1ED\uB1EE\uB1EF\uB1F1\uB1F2\uB1F3\uB1F4\uB1F5\uB1F6\uB1F7\uB1F8\uB1FA\uB1FC\uB1FE\uB1FF\uB200\uB201\uB202\uB203\uB206\uB207\uB209\uB20A\uB20D\uB20E\uB20F\uB210\uB211\uB212\uB213\uB216\uB218\uB21A\uB21B\uB21C\uB21D\uB21E\uB21F\uB221\uB222\uB223\uB224\uB225\uB226\uB227\uB228\uB229\uB22A\uB22B\uB22C\uB22D\uB22E\uB22F\uB230\uB231\uB232\uB233\uB235\uB236\uB237\uB238\uB239\uB23A\uB23B\uB23D\uB23E\uB23F\uB240\uB241\uB242\uB243\uB244\uB245\uB246\uB247\uB248\uB249\uB24A\uB24B\uB24C\uB24D\uB24E\uB24F\uB250\uB251\uB252\uB253\uB254\uB255\uB256\uB257\uB259\uB25A\uB25B\uB25D\uB25E\uB25F\uB261\uB262\uB263\uB264\uB265\uB266\uB267\uB26A\uB26B\uB26C\uB26D\uB26E\uFFFD".split("");
      for (j = 0; j != D[135].length; ++j)
        if (D[135][j].charCodeAt(0) !== 65533) {
          e[D[135][j]] = 34560 + j;
          d[34560 + j] = D[135][j];
        }
      D[136] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB26F\uB270\uB271\uB272\uB273\uB276\uB277\uB278\uB279\uB27A\uB27B\uB27D\uB27E\uB27F\uB280\uB281\uB282\uB283\uB286\uB287\uB288\uB28A\uB28B\uB28C\uB28D\uB28E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB28F\uB292\uB293\uB295\uB296\uB297\uB29B\uB29C\uB29D\uB29E\uB29F\uB2A2\uB2A4\uB2A7\uB2A8\uB2A9\uB2AB\uB2AD\uB2AE\uB2AF\uB2B1\uB2B2\uB2B3\uB2B5\uB2B6\uB2B7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB2B8\uB2B9\uB2BA\uB2BB\uB2BC\uB2BD\uB2BE\uB2BF\uB2C0\uB2C1\uB2C2\uB2C3\uB2C4\uB2C5\uB2C6\uB2C7\uB2CA\uB2CB\uB2CD\uB2CE\uB2CF\uB2D1\uB2D3\uB2D4\uB2D5\uB2D6\uB2D7\uB2DA\uB2DC\uB2DE\uB2DF\uB2E0\uB2E1\uB2E3\uB2E7\uB2E9\uB2EA\uB2F0\uB2F1\uB2F2\uB2F6\uB2FC\uB2FD\uB2FE\uB302\uB303\uB305\uB306\uB307\uB309\uB30A\uB30B\uB30C\uB30D\uB30E\uB30F\uB312\uB316\uB317\uB318\uB319\uB31A\uB31B\uB31D\uB31E\uB31F\uB320\uB321\uB322\uB323\uB324\uB325\uB326\uB327\uB328\uB329\uB32A\uB32B\uB32C\uB32D\uB32E\uB32F\uB330\uB331\uB332\uB333\uB334\uB335\uB336\uB337\uB338\uB339\uB33A\uB33B\uB33C\uB33D\uB33E\uB33F\uB340\uB341\uB342\uB343\uB344\uB345\uB346\uB347\uB348\uB349\uB34A\uB34B\uB34C\uB34D\uB34E\uB34F\uB350\uB351\uB352\uB353\uB357\uB359\uB35A\uB35D\uB360\uB361\uB362\uB363\uFFFD".split("");
      for (j = 0; j != D[136].length; ++j)
        if (D[136][j].charCodeAt(0) !== 65533) {
          e[D[136][j]] = 34816 + j;
          d[34816 + j] = D[136][j];
        }
      D[137] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB366\uB368\uB36A\uB36C\uB36D\uB36F\uB372\uB373\uB375\uB376\uB377\uB379\uB37A\uB37B\uB37C\uB37D\uB37E\uB37F\uB382\uB386\uB387\uB388\uB389\uB38A\uB38B\uB38D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB38E\uB38F\uB391\uB392\uB393\uB395\uB396\uB397\uB398\uB399\uB39A\uB39B\uB39C\uB39D\uB39E\uB39F\uB3A2\uB3A3\uB3A4\uB3A5\uB3A6\uB3A7\uB3A9\uB3AA\uB3AB\uB3AD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB3AE\uB3AF\uB3B0\uB3B1\uB3B2\uB3B3\uB3B4\uB3B5\uB3B6\uB3B7\uB3B8\uB3B9\uB3BA\uB3BB\uB3BC\uB3BD\uB3BE\uB3BF\uB3C0\uB3C1\uB3C2\uB3C3\uB3C6\uB3C7\uB3C9\uB3CA\uB3CD\uB3CF\uB3D1\uB3D2\uB3D3\uB3D6\uB3D8\uB3DA\uB3DC\uB3DE\uB3DF\uB3E1\uB3E2\uB3E3\uB3E5\uB3E6\uB3E7\uB3E9\uB3EA\uB3EB\uB3EC\uB3ED\uB3EE\uB3EF\uB3F0\uB3F1\uB3F2\uB3F3\uB3F4\uB3F5\uB3F6\uB3F7\uB3F8\uB3F9\uB3FA\uB3FB\uB3FD\uB3FE\uB3FF\uB400\uB401\uB402\uB403\uB404\uB405\uB406\uB407\uB408\uB409\uB40A\uB40B\uB40C\uB40D\uB40E\uB40F\uB411\uB412\uB413\uB414\uB415\uB416\uB417\uB419\uB41A\uB41B\uB41D\uB41E\uB41F\uB421\uB422\uB423\uB424\uB425\uB426\uB427\uB42A\uB42C\uB42D\uB42E\uB42F\uB430\uB431\uB432\uB433\uB435\uB436\uB437\uB438\uB439\uB43A\uB43B\uB43C\uB43D\uB43E\uB43F\uB440\uB441\uB442\uB443\uB444\uFFFD".split("");
      for (j = 0; j != D[137].length; ++j)
        if (D[137][j].charCodeAt(0) !== 65533) {
          e[D[137][j]] = 35072 + j;
          d[35072 + j] = D[137][j];
        }
      D[138] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB445\uB446\uB447\uB448\uB449\uB44A\uB44B\uB44C\uB44D\uB44E\uB44F\uB452\uB453\uB455\uB456\uB457\uB459\uB45A\uB45B\uB45C\uB45D\uB45E\uB45F\uB462\uB464\uB466\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB467\uB468\uB469\uB46A\uB46B\uB46D\uB46E\uB46F\uB470\uB471\uB472\uB473\uB474\uB475\uB476\uB477\uB478\uB479\uB47A\uB47B\uB47C\uB47D\uB47E\uB47F\uB481\uB482\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB483\uB484\uB485\uB486\uB487\uB489\uB48A\uB48B\uB48C\uB48D\uB48E\uB48F\uB490\uB491\uB492\uB493\uB494\uB495\uB496\uB497\uB498\uB499\uB49A\uB49B\uB49C\uB49E\uB49F\uB4A0\uB4A1\uB4A2\uB4A3\uB4A5\uB4A6\uB4A7\uB4A9\uB4AA\uB4AB\uB4AD\uB4AE\uB4AF\uB4B0\uB4B1\uB4B2\uB4B3\uB4B4\uB4B6\uB4B8\uB4BA\uB4BB\uB4BC\uB4BD\uB4BE\uB4BF\uB4C1\uB4C2\uB4C3\uB4C5\uB4C6\uB4C7\uB4C9\uB4CA\uB4CB\uB4CC\uB4CD\uB4CE\uB4CF\uB4D1\uB4D2\uB4D3\uB4D4\uB4D6\uB4D7\uB4D8\uB4D9\uB4DA\uB4DB\uB4DE\uB4DF\uB4E1\uB4E2\uB4E5\uB4E7\uB4E8\uB4E9\uB4EA\uB4EB\uB4EE\uB4F0\uB4F2\uB4F3\uB4F4\uB4F5\uB4F6\uB4F7\uB4F9\uB4FA\uB4FB\uB4FC\uB4FD\uB4FE\uB4FF\uB500\uB501\uB502\uB503\uB504\uB505\uB506\uB507\uB508\uB509\uB50A\uB50B\uB50C\uB50D\uB50E\uB50F\uB510\uB511\uB512\uB513\uB516\uB517\uB519\uB51A\uB51D\uFFFD".split("");
      for (j = 0; j != D[138].length; ++j)
        if (D[138][j].charCodeAt(0) !== 65533) {
          e[D[138][j]] = 35328 + j;
          d[35328 + j] = D[138][j];
        }
      D[139] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB51E\uB51F\uB520\uB521\uB522\uB523\uB526\uB52B\uB52C\uB52D\uB52E\uB52F\uB532\uB533\uB535\uB536\uB537\uB539\uB53A\uB53B\uB53C\uB53D\uB53E\uB53F\uB542\uB546\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB547\uB548\uB549\uB54A\uB54E\uB54F\uB551\uB552\uB553\uB555\uB556\uB557\uB558\uB559\uB55A\uB55B\uB55E\uB562\uB563\uB564\uB565\uB566\uB567\uB568\uB569\uB56A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB56B\uB56C\uB56D\uB56E\uB56F\uB570\uB571\uB572\uB573\uB574\uB575\uB576\uB577\uB578\uB579\uB57A\uB57B\uB57C\uB57D\uB57E\uB57F\uB580\uB581\uB582\uB583\uB584\uB585\uB586\uB587\uB588\uB589\uB58A\uB58B\uB58C\uB58D\uB58E\uB58F\uB590\uB591\uB592\uB593\uB594\uB595\uB596\uB597\uB598\uB599\uB59A\uB59B\uB59C\uB59D\uB59E\uB59F\uB5A2\uB5A3\uB5A5\uB5A6\uB5A7\uB5A9\uB5AC\uB5AD\uB5AE\uB5AF\uB5B2\uB5B6\uB5B7\uB5B8\uB5B9\uB5BA\uB5BE\uB5BF\uB5C1\uB5C2\uB5C3\uB5C5\uB5C6\uB5C7\uB5C8\uB5C9\uB5CA\uB5CB\uB5CE\uB5D2\uB5D3\uB5D4\uB5D5\uB5D6\uB5D7\uB5D9\uB5DA\uB5DB\uB5DC\uB5DD\uB5DE\uB5DF\uB5E0\uB5E1\uB5E2\uB5E3\uB5E4\uB5E5\uB5E6\uB5E7\uB5E8\uB5E9\uB5EA\uB5EB\uB5ED\uB5EE\uB5EF\uB5F0\uB5F1\uB5F2\uB5F3\uB5F4\uB5F5\uB5F6\uB5F7\uB5F8\uB5F9\uB5FA\uB5FB\uB5FC\uB5FD\uB5FE\uB5FF\uFFFD".split("");
      for (j = 0; j != D[139].length; ++j)
        if (D[139][j].charCodeAt(0) !== 65533) {
          e[D[139][j]] = 35584 + j;
          d[35584 + j] = D[139][j];
        }
      D[140] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB600\uB601\uB602\uB603\uB604\uB605\uB606\uB607\uB608\uB609\uB60A\uB60B\uB60C\uB60D\uB60E\uB60F\uB612\uB613\uB615\uB616\uB617\uB619\uB61A\uB61B\uB61C\uB61D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB61E\uB61F\uB620\uB621\uB622\uB623\uB624\uB626\uB627\uB628\uB629\uB62A\uB62B\uB62D\uB62E\uB62F\uB630\uB631\uB632\uB633\uB635\uB636\uB637\uB638\uB639\uB63A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB63B\uB63C\uB63D\uB63E\uB63F\uB640\uB641\uB642\uB643\uB644\uB645\uB646\uB647\uB649\uB64A\uB64B\uB64C\uB64D\uB64E\uB64F\uB650\uB651\uB652\uB653\uB654\uB655\uB656\uB657\uB658\uB659\uB65A\uB65B\uB65C\uB65D\uB65E\uB65F\uB660\uB661\uB662\uB663\uB665\uB666\uB667\uB669\uB66A\uB66B\uB66C\uB66D\uB66E\uB66F\uB670\uB671\uB672\uB673\uB674\uB675\uB676\uB677\uB678\uB679\uB67A\uB67B\uB67C\uB67D\uB67E\uB67F\uB680\uB681\uB682\uB683\uB684\uB685\uB686\uB687\uB688\uB689\uB68A\uB68B\uB68C\uB68D\uB68E\uB68F\uB690\uB691\uB692\uB693\uB694\uB695\uB696\uB697\uB698\uB699\uB69A\uB69B\uB69E\uB69F\uB6A1\uB6A2\uB6A3\uB6A5\uB6A6\uB6A7\uB6A8\uB6A9\uB6AA\uB6AD\uB6AE\uB6AF\uB6B0\uB6B2\uB6B3\uB6B4\uB6B5\uB6B6\uB6B7\uB6B8\uB6B9\uB6BA\uB6BB\uB6BC\uB6BD\uB6BE\uB6BF\uB6C0\uB6C1\uB6C2\uFFFD".split("");
      for (j = 0; j != D[140].length; ++j)
        if (D[140][j].charCodeAt(0) !== 65533) {
          e[D[140][j]] = 35840 + j;
          d[35840 + j] = D[140][j];
        }
      D[141] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB6C3\uB6C4\uB6C5\uB6C6\uB6C7\uB6C8\uB6C9\uB6CA\uB6CB\uB6CC\uB6CD\uB6CE\uB6CF\uB6D0\uB6D1\uB6D2\uB6D3\uB6D5\uB6D6\uB6D7\uB6D8\uB6D9\uB6DA\uB6DB\uB6DC\uB6DD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB6DE\uB6DF\uB6E0\uB6E1\uB6E2\uB6E3\uB6E4\uB6E5\uB6E6\uB6E7\uB6E8\uB6E9\uB6EA\uB6EB\uB6EC\uB6ED\uB6EE\uB6EF\uB6F1\uB6F2\uB6F3\uB6F5\uB6F6\uB6F7\uB6F9\uB6FA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB6FB\uB6FC\uB6FD\uB6FE\uB6FF\uB702\uB703\uB704\uB706\uB707\uB708\uB709\uB70A\uB70B\uB70C\uB70D\uB70E\uB70F\uB710\uB711\uB712\uB713\uB714\uB715\uB716\uB717\uB718\uB719\uB71A\uB71B\uB71C\uB71D\uB71E\uB71F\uB720\uB721\uB722\uB723\uB724\uB725\uB726\uB727\uB72A\uB72B\uB72D\uB72E\uB731\uB732\uB733\uB734\uB735\uB736\uB737\uB73A\uB73C\uB73D\uB73E\uB73F\uB740\uB741\uB742\uB743\uB745\uB746\uB747\uB749\uB74A\uB74B\uB74D\uB74E\uB74F\uB750\uB751\uB752\uB753\uB756\uB757\uB758\uB759\uB75A\uB75B\uB75C\uB75D\uB75E\uB75F\uB761\uB762\uB763\uB765\uB766\uB767\uB769\uB76A\uB76B\uB76C\uB76D\uB76E\uB76F\uB772\uB774\uB776\uB777\uB778\uB779\uB77A\uB77B\uB77E\uB77F\uB781\uB782\uB783\uB785\uB786\uB787\uB788\uB789\uB78A\uB78B\uB78E\uB793\uB794\uB795\uB79A\uB79B\uB79D\uB79E\uFFFD".split("");
      for (j = 0; j != D[141].length; ++j)
        if (D[141][j].charCodeAt(0) !== 65533) {
          e[D[141][j]] = 36096 + j;
          d[36096 + j] = D[141][j];
        }
      D[142] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB79F\uB7A1\uB7A2\uB7A3\uB7A4\uB7A5\uB7A6\uB7A7\uB7AA\uB7AE\uB7AF\uB7B0\uB7B1\uB7B2\uB7B3\uB7B6\uB7B7\uB7B9\uB7BA\uB7BB\uB7BC\uB7BD\uB7BE\uB7BF\uB7C0\uB7C1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB7C2\uB7C3\uB7C4\uB7C5\uB7C6\uB7C8\uB7CA\uB7CB\uB7CC\uB7CD\uB7CE\uB7CF\uB7D0\uB7D1\uB7D2\uB7D3\uB7D4\uB7D5\uB7D6\uB7D7\uB7D8\uB7D9\uB7DA\uB7DB\uB7DC\uB7DD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB7DE\uB7DF\uB7E0\uB7E1\uB7E2\uB7E3\uB7E4\uB7E5\uB7E6\uB7E7\uB7E8\uB7E9\uB7EA\uB7EB\uB7EE\uB7EF\uB7F1\uB7F2\uB7F3\uB7F5\uB7F6\uB7F7\uB7F8\uB7F9\uB7FA\uB7FB\uB7FE\uB802\uB803\uB804\uB805\uB806\uB80A\uB80B\uB80D\uB80E\uB80F\uB811\uB812\uB813\uB814\uB815\uB816\uB817\uB81A\uB81C\uB81E\uB81F\uB820\uB821\uB822\uB823\uB826\uB827\uB829\uB82A\uB82B\uB82D\uB82E\uB82F\uB830\uB831\uB832\uB833\uB836\uB83A\uB83B\uB83C\uB83D\uB83E\uB83F\uB841\uB842\uB843\uB845\uB846\uB847\uB848\uB849\uB84A\uB84B\uB84C\uB84D\uB84E\uB84F\uB850\uB852\uB854\uB855\uB856\uB857\uB858\uB859\uB85A\uB85B\uB85E\uB85F\uB861\uB862\uB863\uB865\uB866\uB867\uB868\uB869\uB86A\uB86B\uB86E\uB870\uB872\uB873\uB874\uB875\uB876\uB877\uB879\uB87A\uB87B\uB87D\uB87E\uB87F\uB880\uB881\uB882\uB883\uB884\uFFFD".split("");
      for (j = 0; j != D[142].length; ++j)
        if (D[142][j].charCodeAt(0) !== 65533) {
          e[D[142][j]] = 36352 + j;
          d[36352 + j] = D[142][j];
        }
      D[143] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB885\uB886\uB887\uB888\uB889\uB88A\uB88B\uB88C\uB88E\uB88F\uB890\uB891\uB892\uB893\uB894\uB895\uB896\uB897\uB898\uB899\uB89A\uB89B\uB89C\uB89D\uB89E\uB89F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB8A0\uB8A1\uB8A2\uB8A3\uB8A4\uB8A5\uB8A6\uB8A7\uB8A9\uB8AA\uB8AB\uB8AC\uB8AD\uB8AE\uB8AF\uB8B1\uB8B2\uB8B3\uB8B5\uB8B6\uB8B7\uB8B9\uB8BA\uB8BB\uB8BC\uB8BD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB8BE\uB8BF\uB8C2\uB8C4\uB8C6\uB8C7\uB8C8\uB8C9\uB8CA\uB8CB\uB8CD\uB8CE\uB8CF\uB8D1\uB8D2\uB8D3\uB8D5\uB8D6\uB8D7\uB8D8\uB8D9\uB8DA\uB8DB\uB8DC\uB8DE\uB8E0\uB8E2\uB8E3\uB8E4\uB8E5\uB8E6\uB8E7\uB8EA\uB8EB\uB8ED\uB8EE\uB8EF\uB8F1\uB8F2\uB8F3\uB8F4\uB8F5\uB8F6\uB8F7\uB8FA\uB8FC\uB8FE\uB8FF\uB900\uB901\uB902\uB903\uB905\uB906\uB907\uB908\uB909\uB90A\uB90B\uB90C\uB90D\uB90E\uB90F\uB910\uB911\uB912\uB913\uB914\uB915\uB916\uB917\uB919\uB91A\uB91B\uB91C\uB91D\uB91E\uB91F\uB921\uB922\uB923\uB924\uB925\uB926\uB927\uB928\uB929\uB92A\uB92B\uB92C\uB92D\uB92E\uB92F\uB930\uB931\uB932\uB933\uB934\uB935\uB936\uB937\uB938\uB939\uB93A\uB93B\uB93E\uB93F\uB941\uB942\uB943\uB945\uB946\uB947\uB948\uB949\uB94A\uB94B\uB94D\uB94E\uB950\uB952\uB953\uB954\uB955\uB956\uB957\uFFFD".split("");
      for (j = 0; j != D[143].length; ++j)
        if (D[143][j].charCodeAt(0) !== 65533) {
          e[D[143][j]] = 36608 + j;
          d[36608 + j] = D[143][j];
        }
      D[144] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB95A\uB95B\uB95D\uB95E\uB95F\uB961\uB962\uB963\uB964\uB965\uB966\uB967\uB96A\uB96C\uB96E\uB96F\uB970\uB971\uB972\uB973\uB976\uB977\uB979\uB97A\uB97B\uB97D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB97E\uB97F\uB980\uB981\uB982\uB983\uB986\uB988\uB98B\uB98C\uB98F\uB990\uB991\uB992\uB993\uB994\uB995\uB996\uB997\uB998\uB999\uB99A\uB99B\uB99C\uB99D\uB99E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uB99F\uB9A0\uB9A1\uB9A2\uB9A3\uB9A4\uB9A5\uB9A6\uB9A7\uB9A8\uB9A9\uB9AA\uB9AB\uB9AE\uB9AF\uB9B1\uB9B2\uB9B3\uB9B5\uB9B6\uB9B7\uB9B8\uB9B9\uB9BA\uB9BB\uB9BE\uB9C0\uB9C2\uB9C3\uB9C4\uB9C5\uB9C6\uB9C7\uB9CA\uB9CB\uB9CD\uB9D3\uB9D4\uB9D5\uB9D6\uB9D7\uB9DA\uB9DC\uB9DF\uB9E0\uB9E2\uB9E6\uB9E7\uB9E9\uB9EA\uB9EB\uB9ED\uB9EE\uB9EF\uB9F0\uB9F1\uB9F2\uB9F3\uB9F6\uB9FB\uB9FC\uB9FD\uB9FE\uB9FF\uBA02\uBA03\uBA04\uBA05\uBA06\uBA07\uBA09\uBA0A\uBA0B\uBA0C\uBA0D\uBA0E\uBA0F\uBA10\uBA11\uBA12\uBA13\uBA14\uBA16\uBA17\uBA18\uBA19\uBA1A\uBA1B\uBA1C\uBA1D\uBA1E\uBA1F\uBA20\uBA21\uBA22\uBA23\uBA24\uBA25\uBA26\uBA27\uBA28\uBA29\uBA2A\uBA2B\uBA2C\uBA2D\uBA2E\uBA2F\uBA30\uBA31\uBA32\uBA33\uBA34\uBA35\uBA36\uBA37\uBA3A\uBA3B\uBA3D\uBA3E\uBA3F\uBA41\uBA43\uBA44\uBA45\uBA46\uFFFD".split("");
      for (j = 0; j != D[144].length; ++j)
        if (D[144][j].charCodeAt(0) !== 65533) {
          e[D[144][j]] = 36864 + j;
          d[36864 + j] = D[144][j];
        }
      D[145] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBA47\uBA4A\uBA4C\uBA4F\uBA50\uBA51\uBA52\uBA56\uBA57\uBA59\uBA5A\uBA5B\uBA5D\uBA5E\uBA5F\uBA60\uBA61\uBA62\uBA63\uBA66\uBA6A\uBA6B\uBA6C\uBA6D\uBA6E\uBA6F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBA72\uBA73\uBA75\uBA76\uBA77\uBA79\uBA7A\uBA7B\uBA7C\uBA7D\uBA7E\uBA7F\uBA80\uBA81\uBA82\uBA86\uBA88\uBA89\uBA8A\uBA8B\uBA8D\uBA8E\uBA8F\uBA90\uBA91\uBA92\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBA93\uBA94\uBA95\uBA96\uBA97\uBA98\uBA99\uBA9A\uBA9B\uBA9C\uBA9D\uBA9E\uBA9F\uBAA0\uBAA1\uBAA2\uBAA3\uBAA4\uBAA5\uBAA6\uBAA7\uBAAA\uBAAD\uBAAE\uBAAF\uBAB1\uBAB3\uBAB4\uBAB5\uBAB6\uBAB7\uBABA\uBABC\uBABE\uBABF\uBAC0\uBAC1\uBAC2\uBAC3\uBAC5\uBAC6\uBAC7\uBAC9\uBACA\uBACB\uBACC\uBACD\uBACE\uBACF\uBAD0\uBAD1\uBAD2\uBAD3\uBAD4\uBAD5\uBAD6\uBAD7\uBADA\uBADB\uBADC\uBADD\uBADE\uBADF\uBAE0\uBAE1\uBAE2\uBAE3\uBAE4\uBAE5\uBAE6\uBAE7\uBAE8\uBAE9\uBAEA\uBAEB\uBAEC\uBAED\uBAEE\uBAEF\uBAF0\uBAF1\uBAF2\uBAF3\uBAF4\uBAF5\uBAF6\uBAF7\uBAF8\uBAF9\uBAFA\uBAFB\uBAFD\uBAFE\uBAFF\uBB01\uBB02\uBB03\uBB05\uBB06\uBB07\uBB08\uBB09\uBB0A\uBB0B\uBB0C\uBB0E\uBB10\uBB12\uBB13\uBB14\uBB15\uBB16\uBB17\uBB19\uBB1A\uBB1B\uBB1D\uBB1E\uBB1F\uBB21\uBB22\uBB23\uBB24\uBB25\uBB26\uBB27\uFFFD".split("");
      for (j = 0; j != D[145].length; ++j)
        if (D[145][j].charCodeAt(0) !== 65533) {
          e[D[145][j]] = 37120 + j;
          d[37120 + j] = D[145][j];
        }
      D[146] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBB28\uBB2A\uBB2C\uBB2D\uBB2E\uBB2F\uBB30\uBB31\uBB32\uBB33\uBB37\uBB39\uBB3A\uBB3F\uBB40\uBB41\uBB42\uBB43\uBB46\uBB48\uBB4A\uBB4B\uBB4C\uBB4E\uBB51\uBB52\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBB53\uBB55\uBB56\uBB57\uBB59\uBB5A\uBB5B\uBB5C\uBB5D\uBB5E\uBB5F\uBB60\uBB62\uBB64\uBB65\uBB66\uBB67\uBB68\uBB69\uBB6A\uBB6B\uBB6D\uBB6E\uBB6F\uBB70\uBB71\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBB72\uBB73\uBB74\uBB75\uBB76\uBB77\uBB78\uBB79\uBB7A\uBB7B\uBB7C\uBB7D\uBB7E\uBB7F\uBB80\uBB81\uBB82\uBB83\uBB84\uBB85\uBB86\uBB87\uBB89\uBB8A\uBB8B\uBB8D\uBB8E\uBB8F\uBB91\uBB92\uBB93\uBB94\uBB95\uBB96\uBB97\uBB98\uBB99\uBB9A\uBB9B\uBB9C\uBB9D\uBB9E\uBB9F\uBBA0\uBBA1\uBBA2\uBBA3\uBBA5\uBBA6\uBBA7\uBBA9\uBBAA\uBBAB\uBBAD\uBBAE\uBBAF\uBBB0\uBBB1\uBBB2\uBBB3\uBBB5\uBBB6\uBBB8\uBBB9\uBBBA\uBBBB\uBBBC\uBBBD\uBBBE\uBBBF\uBBC1\uBBC2\uBBC3\uBBC5\uBBC6\uBBC7\uBBC9\uBBCA\uBBCB\uBBCC\uBBCD\uBBCE\uBBCF\uBBD1\uBBD2\uBBD4\uBBD5\uBBD6\uBBD7\uBBD8\uBBD9\uBBDA\uBBDB\uBBDC\uBBDD\uBBDE\uBBDF\uBBE0\uBBE1\uBBE2\uBBE3\uBBE4\uBBE5\uBBE6\uBBE7\uBBE8\uBBE9\uBBEA\uBBEB\uBBEC\uBBED\uBBEE\uBBEF\uBBF0\uBBF1\uBBF2\uBBF3\uBBF4\uBBF5\uBBF6\uBBF7\uBBFA\uBBFB\uBBFD\uBBFE\uBC01\uFFFD".split("");
      for (j = 0; j != D[146].length; ++j)
        if (D[146][j].charCodeAt(0) !== 65533) {
          e[D[146][j]] = 37376 + j;
          d[37376 + j] = D[146][j];
        }
      D[147] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBC03\uBC04\uBC05\uBC06\uBC07\uBC0A\uBC0E\uBC10\uBC12\uBC13\uBC19\uBC1A\uBC20\uBC21\uBC22\uBC23\uBC26\uBC28\uBC2A\uBC2B\uBC2C\uBC2E\uBC2F\uBC32\uBC33\uBC35\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBC36\uBC37\uBC39\uBC3A\uBC3B\uBC3C\uBC3D\uBC3E\uBC3F\uBC42\uBC46\uBC47\uBC48\uBC4A\uBC4B\uBC4E\uBC4F\uBC51\uBC52\uBC53\uBC54\uBC55\uBC56\uBC57\uBC58\uBC59\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBC5A\uBC5B\uBC5C\uBC5E\uBC5F\uBC60\uBC61\uBC62\uBC63\uBC64\uBC65\uBC66\uBC67\uBC68\uBC69\uBC6A\uBC6B\uBC6C\uBC6D\uBC6E\uBC6F\uBC70\uBC71\uBC72\uBC73\uBC74\uBC75\uBC76\uBC77\uBC78\uBC79\uBC7A\uBC7B\uBC7C\uBC7D\uBC7E\uBC7F\uBC80\uBC81\uBC82\uBC83\uBC86\uBC87\uBC89\uBC8A\uBC8D\uBC8F\uBC90\uBC91\uBC92\uBC93\uBC96\uBC98\uBC9B\uBC9C\uBC9D\uBC9E\uBC9F\uBCA2\uBCA3\uBCA5\uBCA6\uBCA9\uBCAA\uBCAB\uBCAC\uBCAD\uBCAE\uBCAF\uBCB2\uBCB6\uBCB7\uBCB8\uBCB9\uBCBA\uBCBB\uBCBE\uBCBF\uBCC1\uBCC2\uBCC3\uBCC5\uBCC6\uBCC7\uBCC8\uBCC9\uBCCA\uBCCB\uBCCC\uBCCE\uBCD2\uBCD3\uBCD4\uBCD6\uBCD7\uBCD9\uBCDA\uBCDB\uBCDD\uBCDE\uBCDF\uBCE0\uBCE1\uBCE2\uBCE3\uBCE4\uBCE5\uBCE6\uBCE7\uBCE8\uBCE9\uBCEA\uBCEB\uBCEC\uBCED\uBCEE\uBCEF\uBCF0\uBCF1\uBCF2\uBCF3\uBCF7\uBCF9\uBCFA\uBCFB\uBCFD\uFFFD".split("");
      for (j = 0; j != D[147].length; ++j)
        if (D[147][j].charCodeAt(0) !== 65533) {
          e[D[147][j]] = 37632 + j;
          d[37632 + j] = D[147][j];
        }
      D[148] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBCFE\uBCFF\uBD00\uBD01\uBD02\uBD03\uBD06\uBD08\uBD0A\uBD0B\uBD0C\uBD0D\uBD0E\uBD0F\uBD11\uBD12\uBD13\uBD15\uBD16\uBD17\uBD18\uBD19\uBD1A\uBD1B\uBD1C\uBD1D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBD1E\uBD1F\uBD20\uBD21\uBD22\uBD23\uBD25\uBD26\uBD27\uBD28\uBD29\uBD2A\uBD2B\uBD2D\uBD2E\uBD2F\uBD30\uBD31\uBD32\uBD33\uBD34\uBD35\uBD36\uBD37\uBD38\uBD39\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBD3A\uBD3B\uBD3C\uBD3D\uBD3E\uBD3F\uBD41\uBD42\uBD43\uBD44\uBD45\uBD46\uBD47\uBD4A\uBD4B\uBD4D\uBD4E\uBD4F\uBD51\uBD52\uBD53\uBD54\uBD55\uBD56\uBD57\uBD5A\uBD5B\uBD5C\uBD5D\uBD5E\uBD5F\uBD60\uBD61\uBD62\uBD63\uBD65\uBD66\uBD67\uBD69\uBD6A\uBD6B\uBD6C\uBD6D\uBD6E\uBD6F\uBD70\uBD71\uBD72\uBD73\uBD74\uBD75\uBD76\uBD77\uBD78\uBD79\uBD7A\uBD7B\uBD7C\uBD7D\uBD7E\uBD7F\uBD82\uBD83\uBD85\uBD86\uBD8B\uBD8C\uBD8D\uBD8E\uBD8F\uBD92\uBD94\uBD96\uBD97\uBD98\uBD9B\uBD9D\uBD9E\uBD9F\uBDA0\uBDA1\uBDA2\uBDA3\uBDA5\uBDA6\uBDA7\uBDA8\uBDA9\uBDAA\uBDAB\uBDAC\uBDAD\uBDAE\uBDAF\uBDB1\uBDB2\uBDB3\uBDB4\uBDB5\uBDB6\uBDB7\uBDB9\uBDBA\uBDBB\uBDBC\uBDBD\uBDBE\uBDBF\uBDC0\uBDC1\uBDC2\uBDC3\uBDC4\uBDC5\uBDC6\uBDC7\uBDC8\uBDC9\uBDCA\uBDCB\uBDCC\uBDCD\uBDCE\uBDCF\uBDD0\uBDD1\uFFFD".split("");
      for (j = 0; j != D[148].length; ++j)
        if (D[148][j].charCodeAt(0) !== 65533) {
          e[D[148][j]] = 37888 + j;
          d[37888 + j] = D[148][j];
        }
      D[149] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBDD2\uBDD3\uBDD6\uBDD7\uBDD9\uBDDA\uBDDB\uBDDD\uBDDE\uBDDF\uBDE0\uBDE1\uBDE2\uBDE3\uBDE4\uBDE5\uBDE6\uBDE7\uBDE8\uBDEA\uBDEB\uBDEC\uBDED\uBDEE\uBDEF\uBDF1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBDF2\uBDF3\uBDF5\uBDF6\uBDF7\uBDF9\uBDFA\uBDFB\uBDFC\uBDFD\uBDFE\uBDFF\uBE01\uBE02\uBE04\uBE06\uBE07\uBE08\uBE09\uBE0A\uBE0B\uBE0E\uBE0F\uBE11\uBE12\uBE13\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBE15\uBE16\uBE17\uBE18\uBE19\uBE1A\uBE1B\uBE1E\uBE20\uBE21\uBE22\uBE23\uBE24\uBE25\uBE26\uBE27\uBE28\uBE29\uBE2A\uBE2B\uBE2C\uBE2D\uBE2E\uBE2F\uBE30\uBE31\uBE32\uBE33\uBE34\uBE35\uBE36\uBE37\uBE38\uBE39\uBE3A\uBE3B\uBE3C\uBE3D\uBE3E\uBE3F\uBE40\uBE41\uBE42\uBE43\uBE46\uBE47\uBE49\uBE4A\uBE4B\uBE4D\uBE4F\uBE50\uBE51\uBE52\uBE53\uBE56\uBE58\uBE5C\uBE5D\uBE5E\uBE5F\uBE62\uBE63\uBE65\uBE66\uBE67\uBE69\uBE6B\uBE6C\uBE6D\uBE6E\uBE6F\uBE72\uBE76\uBE77\uBE78\uBE79\uBE7A\uBE7E\uBE7F\uBE81\uBE82\uBE83\uBE85\uBE86\uBE87\uBE88\uBE89\uBE8A\uBE8B\uBE8E\uBE92\uBE93\uBE94\uBE95\uBE96\uBE97\uBE9A\uBE9B\uBE9C\uBE9D\uBE9E\uBE9F\uBEA0\uBEA1\uBEA2\uBEA3\uBEA4\uBEA5\uBEA6\uBEA7\uBEA9\uBEAA\uBEAB\uBEAC\uBEAD\uBEAE\uBEAF\uBEB0\uBEB1\uBEB2\uBEB3\uBEB4\uBEB5\uBEB6\uBEB7\uFFFD".split("");
      for (j = 0; j != D[149].length; ++j)
        if (D[149][j].charCodeAt(0) !== 65533) {
          e[D[149][j]] = 38144 + j;
          d[38144 + j] = D[149][j];
        }
      D[150] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBEB8\uBEB9\uBEBA\uBEBB\uBEBC\uBEBD\uBEBE\uBEBF\uBEC0\uBEC1\uBEC2\uBEC3\uBEC4\uBEC5\uBEC6\uBEC7\uBEC8\uBEC9\uBECA\uBECB\uBECC\uBECD\uBECE\uBECF\uBED2\uBED3\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBED5\uBED6\uBED9\uBEDA\uBEDB\uBEDC\uBEDD\uBEDE\uBEDF\uBEE1\uBEE2\uBEE6\uBEE7\uBEE8\uBEE9\uBEEA\uBEEB\uBEED\uBEEE\uBEEF\uBEF0\uBEF1\uBEF2\uBEF3\uBEF4\uBEF5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBEF6\uBEF7\uBEF8\uBEF9\uBEFA\uBEFB\uBEFC\uBEFD\uBEFE\uBEFF\uBF00\uBF02\uBF03\uBF04\uBF05\uBF06\uBF07\uBF0A\uBF0B\uBF0C\uBF0D\uBF0E\uBF0F\uBF10\uBF11\uBF12\uBF13\uBF14\uBF15\uBF16\uBF17\uBF1A\uBF1E\uBF1F\uBF20\uBF21\uBF22\uBF23\uBF24\uBF25\uBF26\uBF27\uBF28\uBF29\uBF2A\uBF2B\uBF2C\uBF2D\uBF2E\uBF2F\uBF30\uBF31\uBF32\uBF33\uBF34\uBF35\uBF36\uBF37\uBF38\uBF39\uBF3A\uBF3B\uBF3C\uBF3D\uBF3E\uBF3F\uBF42\uBF43\uBF45\uBF46\uBF47\uBF49\uBF4A\uBF4B\uBF4C\uBF4D\uBF4E\uBF4F\uBF52\uBF53\uBF54\uBF56\uBF57\uBF58\uBF59\uBF5A\uBF5B\uBF5C\uBF5D\uBF5E\uBF5F\uBF60\uBF61\uBF62\uBF63\uBF64\uBF65\uBF66\uBF67\uBF68\uBF69\uBF6A\uBF6B\uBF6C\uBF6D\uBF6E\uBF6F\uBF70\uBF71\uBF72\uBF73\uBF74\uBF75\uBF76\uBF77\uBF78\uBF79\uBF7A\uBF7B\uBF7C\uBF7D\uBF7E\uBF7F\uBF80\uBF81\uBF82\uFFFD".split("");
      for (j = 0; j != D[150].length; ++j)
        if (D[150][j].charCodeAt(0) !== 65533) {
          e[D[150][j]] = 38400 + j;
          d[38400 + j] = D[150][j];
        }
      D[151] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBF83\uBF84\uBF85\uBF86\uBF87\uBF88\uBF89\uBF8A\uBF8B\uBF8C\uBF8D\uBF8E\uBF8F\uBF90\uBF91\uBF92\uBF93\uBF95\uBF96\uBF97\uBF98\uBF99\uBF9A\uBF9B\uBF9C\uBF9D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBF9E\uBF9F\uBFA0\uBFA1\uBFA2\uBFA3\uBFA4\uBFA5\uBFA6\uBFA7\uBFA8\uBFA9\uBFAA\uBFAB\uBFAC\uBFAD\uBFAE\uBFAF\uBFB1\uBFB2\uBFB3\uBFB4\uBFB5\uBFB6\uBFB7\uBFB8\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uBFB9\uBFBA\uBFBB\uBFBC\uBFBD\uBFBE\uBFBF\uBFC0\uBFC1\uBFC2\uBFC3\uBFC4\uBFC6\uBFC7\uBFC8\uBFC9\uBFCA\uBFCB\uBFCE\uBFCF\uBFD1\uBFD2\uBFD3\uBFD5\uBFD6\uBFD7\uBFD8\uBFD9\uBFDA\uBFDB\uBFDD\uBFDE\uBFE0\uBFE2\uBFE3\uBFE4\uBFE5\uBFE6\uBFE7\uBFE8\uBFE9\uBFEA\uBFEB\uBFEC\uBFED\uBFEE\uBFEF\uBFF0\uBFF1\uBFF2\uBFF3\uBFF4\uBFF5\uBFF6\uBFF7\uBFF8\uBFF9\uBFFA\uBFFB\uBFFC\uBFFD\uBFFE\uBFFF\uC000\uC001\uC002\uC003\uC004\uC005\uC006\uC007\uC008\uC009\uC00A\uC00B\uC00C\uC00D\uC00E\uC00F\uC010\uC011\uC012\uC013\uC014\uC015\uC016\uC017\uC018\uC019\uC01A\uC01B\uC01C\uC01D\uC01E\uC01F\uC020\uC021\uC022\uC023\uC024\uC025\uC026\uC027\uC028\uC029\uC02A\uC02B\uC02C\uC02D\uC02E\uC02F\uC030\uC031\uC032\uC033\uC034\uC035\uC036\uC037\uC038\uC039\uC03A\uC03B\uC03D\uC03E\uC03F\uFFFD".split("");
      for (j = 0; j != D[151].length; ++j)
        if (D[151][j].charCodeAt(0) !== 65533) {
          e[D[151][j]] = 38656 + j;
          d[38656 + j] = D[151][j];
        }
      D[152] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC040\uC041\uC042\uC043\uC044\uC045\uC046\uC047\uC048\uC049\uC04A\uC04B\uC04C\uC04D\uC04E\uC04F\uC050\uC052\uC053\uC054\uC055\uC056\uC057\uC059\uC05A\uC05B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC05D\uC05E\uC05F\uC061\uC062\uC063\uC064\uC065\uC066\uC067\uC06A\uC06B\uC06C\uC06D\uC06E\uC06F\uC070\uC071\uC072\uC073\uC074\uC075\uC076\uC077\uC078\uC079\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC07A\uC07B\uC07C\uC07D\uC07E\uC07F\uC080\uC081\uC082\uC083\uC084\uC085\uC086\uC087\uC088\uC089\uC08A\uC08B\uC08C\uC08D\uC08E\uC08F\uC092\uC093\uC095\uC096\uC097\uC099\uC09A\uC09B\uC09C\uC09D\uC09E\uC09F\uC0A2\uC0A4\uC0A6\uC0A7\uC0A8\uC0A9\uC0AA\uC0AB\uC0AE\uC0B1\uC0B2\uC0B7\uC0B8\uC0B9\uC0BA\uC0BB\uC0BE\uC0C2\uC0C3\uC0C4\uC0C6\uC0C7\uC0CA\uC0CB\uC0CD\uC0CE\uC0CF\uC0D1\uC0D2\uC0D3\uC0D4\uC0D5\uC0D6\uC0D7\uC0DA\uC0DE\uC0DF\uC0E0\uC0E1\uC0E2\uC0E3\uC0E6\uC0E7\uC0E9\uC0EA\uC0EB\uC0ED\uC0EE\uC0EF\uC0F0\uC0F1\uC0F2\uC0F3\uC0F6\uC0F8\uC0FA\uC0FB\uC0FC\uC0FD\uC0FE\uC0FF\uC101\uC102\uC103\uC105\uC106\uC107\uC109\uC10A\uC10B\uC10C\uC10D\uC10E\uC10F\uC111\uC112\uC113\uC114\uC116\uC117\uC118\uC119\uC11A\uC11B\uC121\uC122\uC125\uC128\uC129\uC12A\uC12B\uC12E\uFFFD".split("");
      for (j = 0; j != D[152].length; ++j)
        if (D[152][j].charCodeAt(0) !== 65533) {
          e[D[152][j]] = 38912 + j;
          d[38912 + j] = D[152][j];
        }
      D[153] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC132\uC133\uC134\uC135\uC137\uC13A\uC13B\uC13D\uC13E\uC13F\uC141\uC142\uC143\uC144\uC145\uC146\uC147\uC14A\uC14E\uC14F\uC150\uC151\uC152\uC153\uC156\uC157\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC159\uC15A\uC15B\uC15D\uC15E\uC15F\uC160\uC161\uC162\uC163\uC166\uC16A\uC16B\uC16C\uC16D\uC16E\uC16F\uC171\uC172\uC173\uC175\uC176\uC177\uC179\uC17A\uC17B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC17C\uC17D\uC17E\uC17F\uC180\uC181\uC182\uC183\uC184\uC186\uC187\uC188\uC189\uC18A\uC18B\uC18F\uC191\uC192\uC193\uC195\uC197\uC198\uC199\uC19A\uC19B\uC19E\uC1A0\uC1A2\uC1A3\uC1A4\uC1A6\uC1A7\uC1AA\uC1AB\uC1AD\uC1AE\uC1AF\uC1B1\uC1B2\uC1B3\uC1B4\uC1B5\uC1B6\uC1B7\uC1B8\uC1B9\uC1BA\uC1BB\uC1BC\uC1BE\uC1BF\uC1C0\uC1C1\uC1C2\uC1C3\uC1C5\uC1C6\uC1C7\uC1C9\uC1CA\uC1CB\uC1CD\uC1CE\uC1CF\uC1D0\uC1D1\uC1D2\uC1D3\uC1D5\uC1D6\uC1D9\uC1DA\uC1DB\uC1DC\uC1DD\uC1DE\uC1DF\uC1E1\uC1E2\uC1E3\uC1E5\uC1E6\uC1E7\uC1E9\uC1EA\uC1EB\uC1EC\uC1ED\uC1EE\uC1EF\uC1F2\uC1F4\uC1F5\uC1F6\uC1F7\uC1F8\uC1F9\uC1FA\uC1FB\uC1FE\uC1FF\uC201\uC202\uC203\uC205\uC206\uC207\uC208\uC209\uC20A\uC20B\uC20E\uC210\uC212\uC213\uC214\uC215\uC216\uC217\uC21A\uC21B\uC21D\uC21E\uC221\uC222\uC223\uFFFD".split("");
      for (j = 0; j != D[153].length; ++j)
        if (D[153][j].charCodeAt(0) !== 65533) {
          e[D[153][j]] = 39168 + j;
          d[39168 + j] = D[153][j];
        }
      D[154] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC224\uC225\uC226\uC227\uC22A\uC22C\uC22E\uC230\uC233\uC235\uC236\uC237\uC238\uC239\uC23A\uC23B\uC23C\uC23D\uC23E\uC23F\uC240\uC241\uC242\uC243\uC244\uC245\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC246\uC247\uC249\uC24A\uC24B\uC24C\uC24D\uC24E\uC24F\uC252\uC253\uC255\uC256\uC257\uC259\uC25A\uC25B\uC25C\uC25D\uC25E\uC25F\uC261\uC262\uC263\uC264\uC266\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC267\uC268\uC269\uC26A\uC26B\uC26E\uC26F\uC271\uC272\uC273\uC275\uC276\uC277\uC278\uC279\uC27A\uC27B\uC27E\uC280\uC282\uC283\uC284\uC285\uC286\uC287\uC28A\uC28B\uC28C\uC28D\uC28E\uC28F\uC291\uC292\uC293\uC294\uC295\uC296\uC297\uC299\uC29A\uC29C\uC29E\uC29F\uC2A0\uC2A1\uC2A2\uC2A3\uC2A6\uC2A7\uC2A9\uC2AA\uC2AB\uC2AE\uC2AF\uC2B0\uC2B1\uC2B2\uC2B3\uC2B6\uC2B8\uC2BA\uC2BB\uC2BC\uC2BD\uC2BE\uC2BF\uC2C0\uC2C1\uC2C2\uC2C3\uC2C4\uC2C5\uC2C6\uC2C7\uC2C8\uC2C9\uC2CA\uC2CB\uC2CC\uC2CD\uC2CE\uC2CF\uC2D0\uC2D1\uC2D2\uC2D3\uC2D4\uC2D5\uC2D6\uC2D7\uC2D8\uC2D9\uC2DA\uC2DB\uC2DE\uC2DF\uC2E1\uC2E2\uC2E5\uC2E6\uC2E7\uC2E8\uC2E9\uC2EA\uC2EE\uC2F0\uC2F2\uC2F3\uC2F4\uC2F5\uC2F7\uC2FA\uC2FD\uC2FE\uC2FF\uC301\uC302\uC303\uC304\uC305\uC306\uC307\uC30A\uC30B\uC30E\uC30F\uFFFD".split("");
      for (j = 0; j != D[154].length; ++j)
        if (D[154][j].charCodeAt(0) !== 65533) {
          e[D[154][j]] = 39424 + j;
          d[39424 + j] = D[154][j];
        }
      D[155] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC310\uC311\uC312\uC316\uC317\uC319\uC31A\uC31B\uC31D\uC31E\uC31F\uC320\uC321\uC322\uC323\uC326\uC327\uC32A\uC32B\uC32C\uC32D\uC32E\uC32F\uC330\uC331\uC332\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC333\uC334\uC335\uC336\uC337\uC338\uC339\uC33A\uC33B\uC33C\uC33D\uC33E\uC33F\uC340\uC341\uC342\uC343\uC344\uC346\uC347\uC348\uC349\uC34A\uC34B\uC34C\uC34D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC34E\uC34F\uC350\uC351\uC352\uC353\uC354\uC355\uC356\uC357\uC358\uC359\uC35A\uC35B\uC35C\uC35D\uC35E\uC35F\uC360\uC361\uC362\uC363\uC364\uC365\uC366\uC367\uC36A\uC36B\uC36D\uC36E\uC36F\uC371\uC373\uC374\uC375\uC376\uC377\uC37A\uC37B\uC37E\uC37F\uC380\uC381\uC382\uC383\uC385\uC386\uC387\uC389\uC38A\uC38B\uC38D\uC38E\uC38F\uC390\uC391\uC392\uC393\uC394\uC395\uC396\uC397\uC398\uC399\uC39A\uC39B\uC39C\uC39D\uC39E\uC39F\uC3A0\uC3A1\uC3A2\uC3A3\uC3A4\uC3A5\uC3A6\uC3A7\uC3A8\uC3A9\uC3AA\uC3AB\uC3AC\uC3AD\uC3AE\uC3AF\uC3B0\uC3B1\uC3B2\uC3B3\uC3B4\uC3B5\uC3B6\uC3B7\uC3B8\uC3B9\uC3BA\uC3BB\uC3BC\uC3BD\uC3BE\uC3BF\uC3C1\uC3C2\uC3C3\uC3C4\uC3C5\uC3C6\uC3C7\uC3C8\uC3C9\uC3CA\uC3CB\uC3CC\uC3CD\uC3CE\uC3CF\uC3D0\uC3D1\uC3D2\uC3D3\uC3D4\uC3D5\uC3D6\uC3D7\uC3DA\uFFFD".split("");
      for (j = 0; j != D[155].length; ++j)
        if (D[155][j].charCodeAt(0) !== 65533) {
          e[D[155][j]] = 39680 + j;
          d[39680 + j] = D[155][j];
        }
      D[156] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC3DB\uC3DD\uC3DE\uC3E1\uC3E3\uC3E4\uC3E5\uC3E6\uC3E7\uC3EA\uC3EB\uC3EC\uC3EE\uC3EF\uC3F0\uC3F1\uC3F2\uC3F3\uC3F6\uC3F7\uC3F9\uC3FA\uC3FB\uC3FC\uC3FD\uC3FE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC3FF\uC400\uC401\uC402\uC403\uC404\uC405\uC406\uC407\uC409\uC40A\uC40B\uC40C\uC40D\uC40E\uC40F\uC411\uC412\uC413\uC414\uC415\uC416\uC417\uC418\uC419\uC41A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC41B\uC41C\uC41D\uC41E\uC41F\uC420\uC421\uC422\uC423\uC425\uC426\uC427\uC428\uC429\uC42A\uC42B\uC42D\uC42E\uC42F\uC431\uC432\uC433\uC435\uC436\uC437\uC438\uC439\uC43A\uC43B\uC43E\uC43F\uC440\uC441\uC442\uC443\uC444\uC445\uC446\uC447\uC449\uC44A\uC44B\uC44C\uC44D\uC44E\uC44F\uC450\uC451\uC452\uC453\uC454\uC455\uC456\uC457\uC458\uC459\uC45A\uC45B\uC45C\uC45D\uC45E\uC45F\uC460\uC461\uC462\uC463\uC466\uC467\uC469\uC46A\uC46B\uC46D\uC46E\uC46F\uC470\uC471\uC472\uC473\uC476\uC477\uC478\uC47A\uC47B\uC47C\uC47D\uC47E\uC47F\uC481\uC482\uC483\uC484\uC485\uC486\uC487\uC488\uC489\uC48A\uC48B\uC48C\uC48D\uC48E\uC48F\uC490\uC491\uC492\uC493\uC495\uC496\uC497\uC498\uC499\uC49A\uC49B\uC49D\uC49E\uC49F\uC4A0\uC4A1\uC4A2\uC4A3\uC4A4\uC4A5\uC4A6\uC4A7\uC4A8\uC4A9\uFFFD".split("");
      for (j = 0; j != D[156].length; ++j)
        if (D[156][j].charCodeAt(0) !== 65533) {
          e[D[156][j]] = 39936 + j;
          d[39936 + j] = D[156][j];
        }
      D[157] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC4AA\uC4AB\uC4AC\uC4AD\uC4AE\uC4AF\uC4B0\uC4B1\uC4B2\uC4B3\uC4B4\uC4B5\uC4B6\uC4B7\uC4B9\uC4BA\uC4BB\uC4BD\uC4BE\uC4BF\uC4C0\uC4C1\uC4C2\uC4C3\uC4C4\uC4C5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC4C6\uC4C7\uC4C8\uC4C9\uC4CA\uC4CB\uC4CC\uC4CD\uC4CE\uC4CF\uC4D0\uC4D1\uC4D2\uC4D3\uC4D4\uC4D5\uC4D6\uC4D7\uC4D8\uC4D9\uC4DA\uC4DB\uC4DC\uC4DD\uC4DE\uC4DF\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC4E0\uC4E1\uC4E2\uC4E3\uC4E4\uC4E5\uC4E6\uC4E7\uC4E8\uC4EA\uC4EB\uC4EC\uC4ED\uC4EE\uC4EF\uC4F2\uC4F3\uC4F5\uC4F6\uC4F7\uC4F9\uC4FB\uC4FC\uC4FD\uC4FE\uC502\uC503\uC504\uC505\uC506\uC507\uC508\uC509\uC50A\uC50B\uC50D\uC50E\uC50F\uC511\uC512\uC513\uC515\uC516\uC517\uC518\uC519\uC51A\uC51B\uC51D\uC51E\uC51F\uC520\uC521\uC522\uC523\uC524\uC525\uC526\uC527\uC52A\uC52B\uC52D\uC52E\uC52F\uC531\uC532\uC533\uC534\uC535\uC536\uC537\uC53A\uC53C\uC53E\uC53F\uC540\uC541\uC542\uC543\uC546\uC547\uC54B\uC54F\uC550\uC551\uC552\uC556\uC55A\uC55B\uC55C\uC55F\uC562\uC563\uC565\uC566\uC567\uC569\uC56A\uC56B\uC56C\uC56D\uC56E\uC56F\uC572\uC576\uC577\uC578\uC579\uC57A\uC57B\uC57E\uC57F\uC581\uC582\uC583\uC585\uC586\uC588\uC589\uC58A\uC58B\uC58E\uC590\uC592\uC593\uC594\uFFFD".split("");
      for (j = 0; j != D[157].length; ++j)
        if (D[157][j].charCodeAt(0) !== 65533) {
          e[D[157][j]] = 40192 + j;
          d[40192 + j] = D[157][j];
        }
      D[158] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC596\uC599\uC59A\uC59B\uC59D\uC59E\uC59F\uC5A1\uC5A2\uC5A3\uC5A4\uC5A5\uC5A6\uC5A7\uC5A8\uC5AA\uC5AB\uC5AC\uC5AD\uC5AE\uC5AF\uC5B0\uC5B1\uC5B2\uC5B3\uC5B6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC5B7\uC5BA\uC5BF\uC5C0\uC5C1\uC5C2\uC5C3\uC5CB\uC5CD\uC5CF\uC5D2\uC5D3\uC5D5\uC5D6\uC5D7\uC5D9\uC5DA\uC5DB\uC5DC\uC5DD\uC5DE\uC5DF\uC5E2\uC5E4\uC5E6\uC5E7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC5E8\uC5E9\uC5EA\uC5EB\uC5EF\uC5F1\uC5F2\uC5F3\uC5F5\uC5F8\uC5F9\uC5FA\uC5FB\uC602\uC603\uC604\uC609\uC60A\uC60B\uC60D\uC60E\uC60F\uC611\uC612\uC613\uC614\uC615\uC616\uC617\uC61A\uC61D\uC61E\uC61F\uC620\uC621\uC622\uC623\uC626\uC627\uC629\uC62A\uC62B\uC62F\uC631\uC632\uC636\uC638\uC63A\uC63C\uC63D\uC63E\uC63F\uC642\uC643\uC645\uC646\uC647\uC649\uC64A\uC64B\uC64C\uC64D\uC64E\uC64F\uC652\uC656\uC657\uC658\uC659\uC65A\uC65B\uC65E\uC65F\uC661\uC662\uC663\uC664\uC665\uC666\uC667\uC668\uC669\uC66A\uC66B\uC66D\uC66E\uC670\uC672\uC673\uC674\uC675\uC676\uC677\uC67A\uC67B\uC67D\uC67E\uC67F\uC681\uC682\uC683\uC684\uC685\uC686\uC687\uC68A\uC68C\uC68E\uC68F\uC690\uC691\uC692\uC693\uC696\uC697\uC699\uC69A\uC69B\uC69D\uC69E\uC69F\uC6A0\uC6A1\uC6A2\uC6A3\uC6A6\uFFFD".split("");
      for (j = 0; j != D[158].length; ++j)
        if (D[158][j].charCodeAt(0) !== 65533) {
          e[D[158][j]] = 40448 + j;
          d[40448 + j] = D[158][j];
        }
      D[159] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC6A8\uC6AA\uC6AB\uC6AC\uC6AD\uC6AE\uC6AF\uC6B2\uC6B3\uC6B5\uC6B6\uC6B7\uC6BB\uC6BC\uC6BD\uC6BE\uC6BF\uC6C2\uC6C4\uC6C6\uC6C7\uC6C8\uC6C9\uC6CA\uC6CB\uC6CE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC6CF\uC6D1\uC6D2\uC6D3\uC6D5\uC6D6\uC6D7\uC6D8\uC6D9\uC6DA\uC6DB\uC6DE\uC6DF\uC6E2\uC6E3\uC6E4\uC6E5\uC6E6\uC6E7\uC6EA\uC6EB\uC6ED\uC6EE\uC6EF\uC6F1\uC6F2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC6F3\uC6F4\uC6F5\uC6F6\uC6F7\uC6FA\uC6FB\uC6FC\uC6FE\uC6FF\uC700\uC701\uC702\uC703\uC706\uC707\uC709\uC70A\uC70B\uC70D\uC70E\uC70F\uC710\uC711\uC712\uC713\uC716\uC718\uC71A\uC71B\uC71C\uC71D\uC71E\uC71F\uC722\uC723\uC725\uC726\uC727\uC729\uC72A\uC72B\uC72C\uC72D\uC72E\uC72F\uC732\uC734\uC736\uC738\uC739\uC73A\uC73B\uC73E\uC73F\uC741\uC742\uC743\uC745\uC746\uC747\uC748\uC749\uC74B\uC74E\uC750\uC759\uC75A\uC75B\uC75D\uC75E\uC75F\uC761\uC762\uC763\uC764\uC765\uC766\uC767\uC769\uC76A\uC76C\uC76D\uC76E\uC76F\uC770\uC771\uC772\uC773\uC776\uC777\uC779\uC77A\uC77B\uC77F\uC780\uC781\uC782\uC786\uC78B\uC78C\uC78D\uC78F\uC792\uC793\uC795\uC799\uC79B\uC79C\uC79D\uC79E\uC79F\uC7A2\uC7A7\uC7A8\uC7A9\uC7AA\uC7AB\uC7AE\uC7AF\uC7B1\uC7B2\uC7B3\uC7B5\uC7B6\uC7B7\uFFFD".split("");
      for (j = 0; j != D[159].length; ++j)
        if (D[159][j].charCodeAt(0) !== 65533) {
          e[D[159][j]] = 40704 + j;
          d[40704 + j] = D[159][j];
        }
      D[160] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC7B8\uC7B9\uC7BA\uC7BB\uC7BE\uC7C2\uC7C3\uC7C4\uC7C5\uC7C6\uC7C7\uC7CA\uC7CB\uC7CD\uC7CF\uC7D1\uC7D2\uC7D3\uC7D4\uC7D5\uC7D6\uC7D7\uC7D9\uC7DA\uC7DB\uC7DC\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC7DE\uC7DF\uC7E0\uC7E1\uC7E2\uC7E3\uC7E5\uC7E6\uC7E7\uC7E9\uC7EA\uC7EB\uC7ED\uC7EE\uC7EF\uC7F0\uC7F1\uC7F2\uC7F3\uC7F4\uC7F5\uC7F6\uC7F7\uC7F8\uC7F9\uC7FA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC7FB\uC7FC\uC7FD\uC7FE\uC7FF\uC802\uC803\uC805\uC806\uC807\uC809\uC80B\uC80C\uC80D\uC80E\uC80F\uC812\uC814\uC817\uC818\uC819\uC81A\uC81B\uC81E\uC81F\uC821\uC822\uC823\uC825\uC826\uC827\uC828\uC829\uC82A\uC82B\uC82E\uC830\uC832\uC833\uC834\uC835\uC836\uC837\uC839\uC83A\uC83B\uC83D\uC83E\uC83F\uC841\uC842\uC843\uC844\uC845\uC846\uC847\uC84A\uC84B\uC84E\uC84F\uC850\uC851\uC852\uC853\uC855\uC856\uC857\uC858\uC859\uC85A\uC85B\uC85C\uC85D\uC85E\uC85F\uC860\uC861\uC862\uC863\uC864\uC865\uC866\uC867\uC868\uC869\uC86A\uC86B\uC86C\uC86D\uC86E\uC86F\uC872\uC873\uC875\uC876\uC877\uC879\uC87B\uC87C\uC87D\uC87E\uC87F\uC882\uC884\uC888\uC889\uC88A\uC88E\uC88F\uC890\uC891\uC892\uC893\uC895\uC896\uC897\uC898\uC899\uC89A\uC89B\uC89C\uC89E\uC8A0\uC8A2\uC8A3\uC8A4\uFFFD".split("");
      for (j = 0; j != D[160].length; ++j)
        if (D[160][j].charCodeAt(0) !== 65533) {
          e[D[160][j]] = 40960 + j;
          d[40960 + j] = D[160][j];
        }
      D[161] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC8A5\uC8A6\uC8A7\uC8A9\uC8AA\uC8AB\uC8AC\uC8AD\uC8AE\uC8AF\uC8B0\uC8B1\uC8B2\uC8B3\uC8B4\uC8B5\uC8B6\uC8B7\uC8B8\uC8B9\uC8BA\uC8BB\uC8BE\uC8BF\uC8C0\uC8C1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC8C2\uC8C3\uC8C5\uC8C6\uC8C7\uC8C9\uC8CA\uC8CB\uC8CD\uC8CE\uC8CF\uC8D0\uC8D1\uC8D2\uC8D3\uC8D6\uC8D8\uC8DA\uC8DB\uC8DC\uC8DD\uC8DE\uC8DF\uC8E2\uC8E3\uC8E5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC8E6\uC8E7\uC8E8\uC8E9\uC8EA\uC8EB\uC8EC\uC8ED\uC8EE\uC8EF\uC8F0\uC8F1\uC8F2\uC8F3\uC8F4\uC8F6\uC8F7\uC8F8\uC8F9\uC8FA\uC8FB\uC8FE\uC8FF\uC901\uC902\uC903\uC907\uC908\uC909\uC90A\uC90B\uC90E\u3000\u3001\u3002\xB7\u2025\u2026\xA8\u3003\xAD\u2015\u2225\uFF3C\u223C\u2018\u2019\u201C\u201D\u3014\u3015\u3008\u3009\u300A\u300B\u300C\u300D\u300E\u300F\u3010\u3011\xB1\xD7\xF7\u2260\u2264\u2265\u221E\u2234\xB0\u2032\u2033\u2103\u212B\uFFE0\uFFE1\uFFE5\u2642\u2640\u2220\u22A5\u2312\u2202\u2207\u2261\u2252\xA7\u203B\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u25BD\u25BC\u2192\u2190\u2191\u2193\u2194\u3013\u226A\u226B\u221A\u223D\u221D\u2235\u222B\u222C\u2208\u220B\u2286\u2287\u2282\u2283\u222A\u2229\u2227\u2228\uFFE2\uFFFD".split("");
      for (j = 0; j != D[161].length; ++j)
        if (D[161][j].charCodeAt(0) !== 65533) {
          e[D[161][j]] = 41216 + j;
          d[41216 + j] = D[161][j];
        }
      D[162] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC910\uC912\uC913\uC914\uC915\uC916\uC917\uC919\uC91A\uC91B\uC91C\uC91D\uC91E\uC91F\uC920\uC921\uC922\uC923\uC924\uC925\uC926\uC927\uC928\uC929\uC92A\uC92B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC92D\uC92E\uC92F\uC930\uC931\uC932\uC933\uC935\uC936\uC937\uC938\uC939\uC93A\uC93B\uC93C\uC93D\uC93E\uC93F\uC940\uC941\uC942\uC943\uC944\uC945\uC946\uC947\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC948\uC949\uC94A\uC94B\uC94C\uC94D\uC94E\uC94F\uC952\uC953\uC955\uC956\uC957\uC959\uC95A\uC95B\uC95C\uC95D\uC95E\uC95F\uC962\uC964\uC965\uC966\uC967\uC968\uC969\uC96A\uC96B\uC96D\uC96E\uC96F\u21D2\u21D4\u2200\u2203\xB4\uFF5E\u02C7\u02D8\u02DD\u02DA\u02D9\xB8\u02DB\xA1\xBF\u02D0\u222E\u2211\u220F\xA4\u2109\u2030\u25C1\u25C0\u25B7\u25B6\u2664\u2660\u2661\u2665\u2667\u2663\u2299\u25C8\u25A3\u25D0\u25D1\u2592\u25A4\u25A5\u25A8\u25A7\u25A6\u25A9\u2668\u260F\u260E\u261C\u261E\xB6\u2020\u2021\u2195\u2197\u2199\u2196\u2198\u266D\u2669\u266A\u266C\u327F\u321C\u2116\u33C7\u2122\u33C2\u33D8\u2121\u20AC\xAE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[162].length; ++j)
        if (D[162][j].charCodeAt(0) !== 65533) {
          e[D[162][j]] = 41472 + j;
          d[41472 + j] = D[162][j];
        }
      D[163] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC971\uC972\uC973\uC975\uC976\uC977\uC978\uC979\uC97A\uC97B\uC97D\uC97E\uC97F\uC980\uC981\uC982\uC983\uC984\uC985\uC986\uC987\uC98A\uC98B\uC98D\uC98E\uC98F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC991\uC992\uC993\uC994\uC995\uC996\uC997\uC99A\uC99C\uC99E\uC99F\uC9A0\uC9A1\uC9A2\uC9A3\uC9A4\uC9A5\uC9A6\uC9A7\uC9A8\uC9A9\uC9AA\uC9AB\uC9AC\uC9AD\uC9AE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC9AF\uC9B0\uC9B1\uC9B2\uC9B3\uC9B4\uC9B5\uC9B6\uC9B7\uC9B8\uC9B9\uC9BA\uC9BB\uC9BC\uC9BD\uC9BE\uC9BF\uC9C2\uC9C3\uC9C5\uC9C6\uC9C9\uC9CB\uC9CC\uC9CD\uC9CE\uC9CF\uC9D2\uC9D4\uC9D7\uC9D8\uC9DB\uFF01\uFF02\uFF03\uFF04\uFF05\uFF06\uFF07\uFF08\uFF09\uFF0A\uFF0B\uFF0C\uFF0D\uFF0E\uFF0F\uFF10\uFF11\uFF12\uFF13\uFF14\uFF15\uFF16\uFF17\uFF18\uFF19\uFF1A\uFF1B\uFF1C\uFF1D\uFF1E\uFF1F\uFF20\uFF21\uFF22\uFF23\uFF24\uFF25\uFF26\uFF27\uFF28\uFF29\uFF2A\uFF2B\uFF2C\uFF2D\uFF2E\uFF2F\uFF30\uFF31\uFF32\uFF33\uFF34\uFF35\uFF36\uFF37\uFF38\uFF39\uFF3A\uFF3B\uFFE6\uFF3D\uFF3E\uFF3F\uFF40\uFF41\uFF42\uFF43\uFF44\uFF45\uFF46\uFF47\uFF48\uFF49\uFF4A\uFF4B\uFF4C\uFF4D\uFF4E\uFF4F\uFF50\uFF51\uFF52\uFF53\uFF54\uFF55\uFF56\uFF57\uFF58\uFF59\uFF5A\uFF5B\uFF5C\uFF5D\uFFE3\uFFFD".split("");
      for (j = 0; j != D[163].length; ++j)
        if (D[163][j].charCodeAt(0) !== 65533) {
          e[D[163][j]] = 41728 + j;
          d[41728 + j] = D[163][j];
        }
      D[164] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uC9DE\uC9DF\uC9E1\uC9E3\uC9E5\uC9E6\uC9E8\uC9E9\uC9EA\uC9EB\uC9EE\uC9F2\uC9F3\uC9F4\uC9F5\uC9F6\uC9F7\uC9FA\uC9FB\uC9FD\uC9FE\uC9FF\uCA01\uCA02\uCA03\uCA04\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCA05\uCA06\uCA07\uCA0A\uCA0E\uCA0F\uCA10\uCA11\uCA12\uCA13\uCA15\uCA16\uCA17\uCA19\uCA1A\uCA1B\uCA1C\uCA1D\uCA1E\uCA1F\uCA20\uCA21\uCA22\uCA23\uCA24\uCA25\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCA26\uCA27\uCA28\uCA2A\uCA2B\uCA2C\uCA2D\uCA2E\uCA2F\uCA30\uCA31\uCA32\uCA33\uCA34\uCA35\uCA36\uCA37\uCA38\uCA39\uCA3A\uCA3B\uCA3C\uCA3D\uCA3E\uCA3F\uCA40\uCA41\uCA42\uCA43\uCA44\uCA45\uCA46\u3131\u3132\u3133\u3134\u3135\u3136\u3137\u3138\u3139\u313A\u313B\u313C\u313D\u313E\u313F\u3140\u3141\u3142\u3143\u3144\u3145\u3146\u3147\u3148\u3149\u314A\u314B\u314C\u314D\u314E\u314F\u3150\u3151\u3152\u3153\u3154\u3155\u3156\u3157\u3158\u3159\u315A\u315B\u315C\u315D\u315E\u315F\u3160\u3161\u3162\u3163\u3164\u3165\u3166\u3167\u3168\u3169\u316A\u316B\u316C\u316D\u316E\u316F\u3170\u3171\u3172\u3173\u3174\u3175\u3176\u3177\u3178\u3179\u317A\u317B\u317C\u317D\u317E\u317F\u3180\u3181\u3182\u3183\u3184\u3185\u3186\u3187\u3188\u3189\u318A\u318B\u318C\u318D\u318E\uFFFD".split("");
      for (j = 0; j != D[164].length; ++j)
        if (D[164][j].charCodeAt(0) !== 65533) {
          e[D[164][j]] = 41984 + j;
          d[41984 + j] = D[164][j];
        }
      D[165] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCA47\uCA48\uCA49\uCA4A\uCA4B\uCA4E\uCA4F\uCA51\uCA52\uCA53\uCA55\uCA56\uCA57\uCA58\uCA59\uCA5A\uCA5B\uCA5E\uCA62\uCA63\uCA64\uCA65\uCA66\uCA67\uCA69\uCA6A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCA6B\uCA6C\uCA6D\uCA6E\uCA6F\uCA70\uCA71\uCA72\uCA73\uCA74\uCA75\uCA76\uCA77\uCA78\uCA79\uCA7A\uCA7B\uCA7C\uCA7E\uCA7F\uCA80\uCA81\uCA82\uCA83\uCA85\uCA86\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCA87\uCA88\uCA89\uCA8A\uCA8B\uCA8C\uCA8D\uCA8E\uCA8F\uCA90\uCA91\uCA92\uCA93\uCA94\uCA95\uCA96\uCA97\uCA99\uCA9A\uCA9B\uCA9C\uCA9D\uCA9E\uCA9F\uCAA0\uCAA1\uCAA2\uCAA3\uCAA4\uCAA5\uCAA6\uCAA7\u2170\u2171\u2172\u2173\u2174\u2175\u2176\u2177\u2178\u2179\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[165].length; ++j)
        if (D[165][j].charCodeAt(0) !== 65533) {
          e[D[165][j]] = 42240 + j;
          d[42240 + j] = D[165][j];
        }
      D[166] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCAA8\uCAA9\uCAAA\uCAAB\uCAAC\uCAAD\uCAAE\uCAAF\uCAB0\uCAB1\uCAB2\uCAB3\uCAB4\uCAB5\uCAB6\uCAB7\uCAB8\uCAB9\uCABA\uCABB\uCABE\uCABF\uCAC1\uCAC2\uCAC3\uCAC5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCAC6\uCAC7\uCAC8\uCAC9\uCACA\uCACB\uCACE\uCAD0\uCAD2\uCAD4\uCAD5\uCAD6\uCAD7\uCADA\uCADB\uCADC\uCADD\uCADE\uCADF\uCAE1\uCAE2\uCAE3\uCAE4\uCAE5\uCAE6\uCAE7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCAE8\uCAE9\uCAEA\uCAEB\uCAED\uCAEE\uCAEF\uCAF0\uCAF1\uCAF2\uCAF3\uCAF5\uCAF6\uCAF7\uCAF8\uCAF9\uCAFA\uCAFB\uCAFC\uCAFD\uCAFE\uCAFF\uCB00\uCB01\uCB02\uCB03\uCB04\uCB05\uCB06\uCB07\uCB09\uCB0A\u2500\u2502\u250C\u2510\u2518\u2514\u251C\u252C\u2524\u2534\u253C\u2501\u2503\u250F\u2513\u251B\u2517\u2523\u2533\u252B\u253B\u254B\u2520\u252F\u2528\u2537\u253F\u251D\u2530\u2525\u2538\u2542\u2512\u2511\u251A\u2519\u2516\u2515\u250E\u250D\u251E\u251F\u2521\u2522\u2526\u2527\u2529\u252A\u252D\u252E\u2531\u2532\u2535\u2536\u2539\u253A\u253D\u253E\u2540\u2541\u2543\u2544\u2545\u2546\u2547\u2548\u2549\u254A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[166].length; ++j)
        if (D[166][j].charCodeAt(0) !== 65533) {
          e[D[166][j]] = 42496 + j;
          d[42496 + j] = D[166][j];
        }
      D[167] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCB0B\uCB0C\uCB0D\uCB0E\uCB0F\uCB11\uCB12\uCB13\uCB15\uCB16\uCB17\uCB19\uCB1A\uCB1B\uCB1C\uCB1D\uCB1E\uCB1F\uCB22\uCB23\uCB24\uCB25\uCB26\uCB27\uCB28\uCB29\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCB2A\uCB2B\uCB2C\uCB2D\uCB2E\uCB2F\uCB30\uCB31\uCB32\uCB33\uCB34\uCB35\uCB36\uCB37\uCB38\uCB39\uCB3A\uCB3B\uCB3C\uCB3D\uCB3E\uCB3F\uCB40\uCB42\uCB43\uCB44\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCB45\uCB46\uCB47\uCB4A\uCB4B\uCB4D\uCB4E\uCB4F\uCB51\uCB52\uCB53\uCB54\uCB55\uCB56\uCB57\uCB5A\uCB5B\uCB5C\uCB5E\uCB5F\uCB60\uCB61\uCB62\uCB63\uCB65\uCB66\uCB67\uCB68\uCB69\uCB6A\uCB6B\uCB6C\u3395\u3396\u3397\u2113\u3398\u33C4\u33A3\u33A4\u33A5\u33A6\u3399\u339A\u339B\u339C\u339D\u339E\u339F\u33A0\u33A1\u33A2\u33CA\u338D\u338E\u338F\u33CF\u3388\u3389\u33C8\u33A7\u33A8\u33B0\u33B1\u33B2\u33B3\u33B4\u33B5\u33B6\u33B7\u33B8\u33B9\u3380\u3381\u3382\u3383\u3384\u33BA\u33BB\u33BC\u33BD\u33BE\u33BF\u3390\u3391\u3392\u3393\u3394\u2126\u33C0\u33C1\u338A\u338B\u338C\u33D6\u33C5\u33AD\u33AE\u33AF\u33DB\u33A9\u33AA\u33AB\u33AC\u33DD\u33D0\u33D3\u33C3\u33C9\u33DC\u33C6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[167].length; ++j)
        if (D[167][j].charCodeAt(0) !== 65533) {
          e[D[167][j]] = 42752 + j;
          d[42752 + j] = D[167][j];
        }
      D[168] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCB6D\uCB6E\uCB6F\uCB70\uCB71\uCB72\uCB73\uCB74\uCB75\uCB76\uCB77\uCB7A\uCB7B\uCB7C\uCB7D\uCB7E\uCB7F\uCB80\uCB81\uCB82\uCB83\uCB84\uCB85\uCB86\uCB87\uCB88\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCB89\uCB8A\uCB8B\uCB8C\uCB8D\uCB8E\uCB8F\uCB90\uCB91\uCB92\uCB93\uCB94\uCB95\uCB96\uCB97\uCB98\uCB99\uCB9A\uCB9B\uCB9D\uCB9E\uCB9F\uCBA0\uCBA1\uCBA2\uCBA3\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCBA4\uCBA5\uCBA6\uCBA7\uCBA8\uCBA9\uCBAA\uCBAB\uCBAC\uCBAD\uCBAE\uCBAF\uCBB0\uCBB1\uCBB2\uCBB3\uCBB4\uCBB5\uCBB6\uCBB7\uCBB9\uCBBA\uCBBB\uCBBC\uCBBD\uCBBE\uCBBF\uCBC0\uCBC1\uCBC2\uCBC3\uCBC4\xC6\xD0\xAA\u0126\uFFFD\u0132\uFFFD\u013F\u0141\xD8\u0152\xBA\xDE\u0166\u014A\uFFFD\u3260\u3261\u3262\u3263\u3264\u3265\u3266\u3267\u3268\u3269\u326A\u326B\u326C\u326D\u326E\u326F\u3270\u3271\u3272\u3273\u3274\u3275\u3276\u3277\u3278\u3279\u327A\u327B\u24D0\u24D1\u24D2\u24D3\u24D4\u24D5\u24D6\u24D7\u24D8\u24D9\u24DA\u24DB\u24DC\u24DD\u24DE\u24DF\u24E0\u24E1\u24E2\u24E3\u24E4\u24E5\u24E6\u24E7\u24E8\u24E9\u2460\u2461\u2462\u2463\u2464\u2465\u2466\u2467\u2468\u2469\u246A\u246B\u246C\u246D\u246E\xBD\u2153\u2154\xBC\xBE\u215B\u215C\u215D\u215E\uFFFD".split("");
      for (j = 0; j != D[168].length; ++j)
        if (D[168][j].charCodeAt(0) !== 65533) {
          e[D[168][j]] = 43008 + j;
          d[43008 + j] = D[168][j];
        }
      D[169] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCBC5\uCBC6\uCBC7\uCBC8\uCBC9\uCBCA\uCBCB\uCBCC\uCBCD\uCBCE\uCBCF\uCBD0\uCBD1\uCBD2\uCBD3\uCBD5\uCBD6\uCBD7\uCBD8\uCBD9\uCBDA\uCBDB\uCBDC\uCBDD\uCBDE\uCBDF\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCBE0\uCBE1\uCBE2\uCBE3\uCBE5\uCBE6\uCBE8\uCBEA\uCBEB\uCBEC\uCBED\uCBEE\uCBEF\uCBF0\uCBF1\uCBF2\uCBF3\uCBF4\uCBF5\uCBF6\uCBF7\uCBF8\uCBF9\uCBFA\uCBFB\uCBFC\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCBFD\uCBFE\uCBFF\uCC00\uCC01\uCC02\uCC03\uCC04\uCC05\uCC06\uCC07\uCC08\uCC09\uCC0A\uCC0B\uCC0E\uCC0F\uCC11\uCC12\uCC13\uCC15\uCC16\uCC17\uCC18\uCC19\uCC1A\uCC1B\uCC1E\uCC1F\uCC20\uCC23\uCC24\xE6\u0111\xF0\u0127\u0131\u0133\u0138\u0140\u0142\xF8\u0153\xDF\xFE\u0167\u014B\u0149\u3200\u3201\u3202\u3203\u3204\u3205\u3206\u3207\u3208\u3209\u320A\u320B\u320C\u320D\u320E\u320F\u3210\u3211\u3212\u3213\u3214\u3215\u3216\u3217\u3218\u3219\u321A\u321B\u249C\u249D\u249E\u249F\u24A0\u24A1\u24A2\u24A3\u24A4\u24A5\u24A6\u24A7\u24A8\u24A9\u24AA\u24AB\u24AC\u24AD\u24AE\u24AF\u24B0\u24B1\u24B2\u24B3\u24B4\u24B5\u2474\u2475\u2476\u2477\u2478\u2479\u247A\u247B\u247C\u247D\u247E\u247F\u2480\u2481\u2482\xB9\xB2\xB3\u2074\u207F\u2081\u2082\u2083\u2084\uFFFD".split("");
      for (j = 0; j != D[169].length; ++j)
        if (D[169][j].charCodeAt(0) !== 65533) {
          e[D[169][j]] = 43264 + j;
          d[43264 + j] = D[169][j];
        }
      D[170] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCC25\uCC26\uCC2A\uCC2B\uCC2D\uCC2F\uCC31\uCC32\uCC33\uCC34\uCC35\uCC36\uCC37\uCC3A\uCC3F\uCC40\uCC41\uCC42\uCC43\uCC46\uCC47\uCC49\uCC4A\uCC4B\uCC4D\uCC4E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCC4F\uCC50\uCC51\uCC52\uCC53\uCC56\uCC5A\uCC5B\uCC5C\uCC5D\uCC5E\uCC5F\uCC61\uCC62\uCC63\uCC65\uCC67\uCC69\uCC6A\uCC6B\uCC6C\uCC6D\uCC6E\uCC6F\uCC71\uCC72\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCC73\uCC74\uCC76\uCC77\uCC78\uCC79\uCC7A\uCC7B\uCC7C\uCC7D\uCC7E\uCC7F\uCC80\uCC81\uCC82\uCC83\uCC84\uCC85\uCC86\uCC87\uCC88\uCC89\uCC8A\uCC8B\uCC8C\uCC8D\uCC8E\uCC8F\uCC90\uCC91\uCC92\uCC93\u3041\u3042\u3043\u3044\u3045\u3046\u3047\u3048\u3049\u304A\u304B\u304C\u304D\u304E\u304F\u3050\u3051\u3052\u3053\u3054\u3055\u3056\u3057\u3058\u3059\u305A\u305B\u305C\u305D\u305E\u305F\u3060\u3061\u3062\u3063\u3064\u3065\u3066\u3067\u3068\u3069\u306A\u306B\u306C\u306D\u306E\u306F\u3070\u3071\u3072\u3073\u3074\u3075\u3076\u3077\u3078\u3079\u307A\u307B\u307C\u307D\u307E\u307F\u3080\u3081\u3082\u3083\u3084\u3085\u3086\u3087\u3088\u3089\u308A\u308B\u308C\u308D\u308E\u308F\u3090\u3091\u3092\u3093\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[170].length; ++j)
        if (D[170][j].charCodeAt(0) !== 65533) {
          e[D[170][j]] = 43520 + j;
          d[43520 + j] = D[170][j];
        }
      D[171] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCC94\uCC95\uCC96\uCC97\uCC9A\uCC9B\uCC9D\uCC9E\uCC9F\uCCA1\uCCA2\uCCA3\uCCA4\uCCA5\uCCA6\uCCA7\uCCAA\uCCAE\uCCAF\uCCB0\uCCB1\uCCB2\uCCB3\uCCB6\uCCB7\uCCB9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCCBA\uCCBB\uCCBD\uCCBE\uCCBF\uCCC0\uCCC1\uCCC2\uCCC3\uCCC6\uCCC8\uCCCA\uCCCB\uCCCC\uCCCD\uCCCE\uCCCF\uCCD1\uCCD2\uCCD3\uCCD5\uCCD6\uCCD7\uCCD8\uCCD9\uCCDA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCCDB\uCCDC\uCCDD\uCCDE\uCCDF\uCCE0\uCCE1\uCCE2\uCCE3\uCCE5\uCCE6\uCCE7\uCCE8\uCCE9\uCCEA\uCCEB\uCCED\uCCEE\uCCEF\uCCF1\uCCF2\uCCF3\uCCF4\uCCF5\uCCF6\uCCF7\uCCF8\uCCF9\uCCFA\uCCFB\uCCFC\uCCFD\u30A1\u30A2\u30A3\u30A4\u30A5\u30A6\u30A7\u30A8\u30A9\u30AA\u30AB\u30AC\u30AD\u30AE\u30AF\u30B0\u30B1\u30B2\u30B3\u30B4\u30B5\u30B6\u30B7\u30B8\u30B9\u30BA\u30BB\u30BC\u30BD\u30BE\u30BF\u30C0\u30C1\u30C2\u30C3\u30C4\u30C5\u30C6\u30C7\u30C8\u30C9\u30CA\u30CB\u30CC\u30CD\u30CE\u30CF\u30D0\u30D1\u30D2\u30D3\u30D4\u30D5\u30D6\u30D7\u30D8\u30D9\u30DA\u30DB\u30DC\u30DD\u30DE\u30DF\u30E0\u30E1\u30E2\u30E3\u30E4\u30E5\u30E6\u30E7\u30E8\u30E9\u30EA\u30EB\u30EC\u30ED\u30EE\u30EF\u30F0\u30F1\u30F2\u30F3\u30F4\u30F5\u30F6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[171].length; ++j)
        if (D[171][j].charCodeAt(0) !== 65533) {
          e[D[171][j]] = 43776 + j;
          d[43776 + j] = D[171][j];
        }
      D[172] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCCFE\uCCFF\uCD00\uCD02\uCD03\uCD04\uCD05\uCD06\uCD07\uCD0A\uCD0B\uCD0D\uCD0E\uCD0F\uCD11\uCD12\uCD13\uCD14\uCD15\uCD16\uCD17\uCD1A\uCD1C\uCD1E\uCD1F\uCD20\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCD21\uCD22\uCD23\uCD25\uCD26\uCD27\uCD29\uCD2A\uCD2B\uCD2D\uCD2E\uCD2F\uCD30\uCD31\uCD32\uCD33\uCD34\uCD35\uCD36\uCD37\uCD38\uCD3A\uCD3B\uCD3C\uCD3D\uCD3E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCD3F\uCD40\uCD41\uCD42\uCD43\uCD44\uCD45\uCD46\uCD47\uCD48\uCD49\uCD4A\uCD4B\uCD4C\uCD4D\uCD4E\uCD4F\uCD50\uCD51\uCD52\uCD53\uCD54\uCD55\uCD56\uCD57\uCD58\uCD59\uCD5A\uCD5B\uCD5D\uCD5E\uCD5F\u0410\u0411\u0412\u0413\u0414\u0415\u0401\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0430\u0431\u0432\u0433\u0434\u0435\u0451\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[172].length; ++j)
        if (D[172][j].charCodeAt(0) !== 65533) {
          e[D[172][j]] = 44032 + j;
          d[44032 + j] = D[172][j];
        }
      D[173] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCD61\uCD62\uCD63\uCD65\uCD66\uCD67\uCD68\uCD69\uCD6A\uCD6B\uCD6E\uCD70\uCD72\uCD73\uCD74\uCD75\uCD76\uCD77\uCD79\uCD7A\uCD7B\uCD7C\uCD7D\uCD7E\uCD7F\uCD80\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCD81\uCD82\uCD83\uCD84\uCD85\uCD86\uCD87\uCD89\uCD8A\uCD8B\uCD8C\uCD8D\uCD8E\uCD8F\uCD90\uCD91\uCD92\uCD93\uCD96\uCD97\uCD99\uCD9A\uCD9B\uCD9D\uCD9E\uCD9F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCDA0\uCDA1\uCDA2\uCDA3\uCDA6\uCDA8\uCDAA\uCDAB\uCDAC\uCDAD\uCDAE\uCDAF\uCDB1\uCDB2\uCDB3\uCDB4\uCDB5\uCDB6\uCDB7\uCDB8\uCDB9\uCDBA\uCDBB\uCDBC\uCDBD\uCDBE\uCDBF\uCDC0\uCDC1\uCDC2\uCDC3\uCDC5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[173].length; ++j)
        if (D[173][j].charCodeAt(0) !== 65533) {
          e[D[173][j]] = 44288 + j;
          d[44288 + j] = D[173][j];
        }
      D[174] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCDC6\uCDC7\uCDC8\uCDC9\uCDCA\uCDCB\uCDCD\uCDCE\uCDCF\uCDD1\uCDD2\uCDD3\uCDD4\uCDD5\uCDD6\uCDD7\uCDD8\uCDD9\uCDDA\uCDDB\uCDDC\uCDDD\uCDDE\uCDDF\uCDE0\uCDE1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCDE2\uCDE3\uCDE4\uCDE5\uCDE6\uCDE7\uCDE9\uCDEA\uCDEB\uCDED\uCDEE\uCDEF\uCDF1\uCDF2\uCDF3\uCDF4\uCDF5\uCDF6\uCDF7\uCDFA\uCDFC\uCDFE\uCDFF\uCE00\uCE01\uCE02\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCE03\uCE05\uCE06\uCE07\uCE09\uCE0A\uCE0B\uCE0D\uCE0E\uCE0F\uCE10\uCE11\uCE12\uCE13\uCE15\uCE16\uCE17\uCE18\uCE1A\uCE1B\uCE1C\uCE1D\uCE1E\uCE1F\uCE22\uCE23\uCE25\uCE26\uCE27\uCE29\uCE2A\uCE2B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[174].length; ++j)
        if (D[174][j].charCodeAt(0) !== 65533) {
          e[D[174][j]] = 44544 + j;
          d[44544 + j] = D[174][j];
        }
      D[175] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCE2C\uCE2D\uCE2E\uCE2F\uCE32\uCE34\uCE36\uCE37\uCE38\uCE39\uCE3A\uCE3B\uCE3C\uCE3D\uCE3E\uCE3F\uCE40\uCE41\uCE42\uCE43\uCE44\uCE45\uCE46\uCE47\uCE48\uCE49\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCE4A\uCE4B\uCE4C\uCE4D\uCE4E\uCE4F\uCE50\uCE51\uCE52\uCE53\uCE54\uCE55\uCE56\uCE57\uCE5A\uCE5B\uCE5D\uCE5E\uCE62\uCE63\uCE64\uCE65\uCE66\uCE67\uCE6A\uCE6C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCE6E\uCE6F\uCE70\uCE71\uCE72\uCE73\uCE76\uCE77\uCE79\uCE7A\uCE7B\uCE7D\uCE7E\uCE7F\uCE80\uCE81\uCE82\uCE83\uCE86\uCE88\uCE8A\uCE8B\uCE8C\uCE8D\uCE8E\uCE8F\uCE92\uCE93\uCE95\uCE96\uCE97\uCE99\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[175].length; ++j)
        if (D[175][j].charCodeAt(0) !== 65533) {
          e[D[175][j]] = 44800 + j;
          d[44800 + j] = D[175][j];
        }
      D[176] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCE9A\uCE9B\uCE9C\uCE9D\uCE9E\uCE9F\uCEA2\uCEA6\uCEA7\uCEA8\uCEA9\uCEAA\uCEAB\uCEAE\uCEAF\uCEB0\uCEB1\uCEB2\uCEB3\uCEB4\uCEB5\uCEB6\uCEB7\uCEB8\uCEB9\uCEBA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCEBB\uCEBC\uCEBD\uCEBE\uCEBF\uCEC0\uCEC2\uCEC3\uCEC4\uCEC5\uCEC6\uCEC7\uCEC8\uCEC9\uCECA\uCECB\uCECC\uCECD\uCECE\uCECF\uCED0\uCED1\uCED2\uCED3\uCED4\uCED5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCED6\uCED7\uCED8\uCED9\uCEDA\uCEDB\uCEDC\uCEDD\uCEDE\uCEDF\uCEE0\uCEE1\uCEE2\uCEE3\uCEE6\uCEE7\uCEE9\uCEEA\uCEED\uCEEE\uCEEF\uCEF0\uCEF1\uCEF2\uCEF3\uCEF6\uCEFA\uCEFB\uCEFC\uCEFD\uCEFE\uCEFF\uAC00\uAC01\uAC04\uAC07\uAC08\uAC09\uAC0A\uAC10\uAC11\uAC12\uAC13\uAC14\uAC15\uAC16\uAC17\uAC19\uAC1A\uAC1B\uAC1C\uAC1D\uAC20\uAC24\uAC2C\uAC2D\uAC2F\uAC30\uAC31\uAC38\uAC39\uAC3C\uAC40\uAC4B\uAC4D\uAC54\uAC58\uAC5C\uAC70\uAC71\uAC74\uAC77\uAC78\uAC7A\uAC80\uAC81\uAC83\uAC84\uAC85\uAC86\uAC89\uAC8A\uAC8B\uAC8C\uAC90\uAC94\uAC9C\uAC9D\uAC9F\uACA0\uACA1\uACA8\uACA9\uACAA\uACAC\uACAF\uACB0\uACB8\uACB9\uACBB\uACBC\uACBD\uACC1\uACC4\uACC8\uACCC\uACD5\uACD7\uACE0\uACE1\uACE4\uACE7\uACE8\uACEA\uACEC\uACEF\uACF0\uACF1\uACF3\uACF5\uACF6\uACFC\uACFD\uAD00\uAD04\uAD06\uFFFD".split("");
      for (j = 0; j != D[176].length; ++j)
        if (D[176][j].charCodeAt(0) !== 65533) {
          e[D[176][j]] = 45056 + j;
          d[45056 + j] = D[176][j];
        }
      D[177] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCF02\uCF03\uCF05\uCF06\uCF07\uCF09\uCF0A\uCF0B\uCF0C\uCF0D\uCF0E\uCF0F\uCF12\uCF14\uCF16\uCF17\uCF18\uCF19\uCF1A\uCF1B\uCF1D\uCF1E\uCF1F\uCF21\uCF22\uCF23\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCF25\uCF26\uCF27\uCF28\uCF29\uCF2A\uCF2B\uCF2E\uCF32\uCF33\uCF34\uCF35\uCF36\uCF37\uCF39\uCF3A\uCF3B\uCF3C\uCF3D\uCF3E\uCF3F\uCF40\uCF41\uCF42\uCF43\uCF44\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCF45\uCF46\uCF47\uCF48\uCF49\uCF4A\uCF4B\uCF4C\uCF4D\uCF4E\uCF4F\uCF50\uCF51\uCF52\uCF53\uCF56\uCF57\uCF59\uCF5A\uCF5B\uCF5D\uCF5E\uCF5F\uCF60\uCF61\uCF62\uCF63\uCF66\uCF68\uCF6A\uCF6B\uCF6C\uAD0C\uAD0D\uAD0F\uAD11\uAD18\uAD1C\uAD20\uAD29\uAD2C\uAD2D\uAD34\uAD35\uAD38\uAD3C\uAD44\uAD45\uAD47\uAD49\uAD50\uAD54\uAD58\uAD61\uAD63\uAD6C\uAD6D\uAD70\uAD73\uAD74\uAD75\uAD76\uAD7B\uAD7C\uAD7D\uAD7F\uAD81\uAD82\uAD88\uAD89\uAD8C\uAD90\uAD9C\uAD9D\uADA4\uADB7\uADC0\uADC1\uADC4\uADC8\uADD0\uADD1\uADD3\uADDC\uADE0\uADE4\uADF8\uADF9\uADFC\uADFF\uAE00\uAE01\uAE08\uAE09\uAE0B\uAE0D\uAE14\uAE30\uAE31\uAE34\uAE37\uAE38\uAE3A\uAE40\uAE41\uAE43\uAE45\uAE46\uAE4A\uAE4C\uAE4D\uAE4E\uAE50\uAE54\uAE56\uAE5C\uAE5D\uAE5F\uAE60\uAE61\uAE65\uAE68\uAE69\uAE6C\uAE70\uAE78\uFFFD".split("");
      for (j = 0; j != D[177].length; ++j)
        if (D[177][j].charCodeAt(0) !== 65533) {
          e[D[177][j]] = 45312 + j;
          d[45312 + j] = D[177][j];
        }
      D[178] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCF6D\uCF6E\uCF6F\uCF72\uCF73\uCF75\uCF76\uCF77\uCF79\uCF7A\uCF7B\uCF7C\uCF7D\uCF7E\uCF7F\uCF81\uCF82\uCF83\uCF84\uCF86\uCF87\uCF88\uCF89\uCF8A\uCF8B\uCF8D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCF8E\uCF8F\uCF90\uCF91\uCF92\uCF93\uCF94\uCF95\uCF96\uCF97\uCF98\uCF99\uCF9A\uCF9B\uCF9C\uCF9D\uCF9E\uCF9F\uCFA0\uCFA2\uCFA3\uCFA4\uCFA5\uCFA6\uCFA7\uCFA9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCFAA\uCFAB\uCFAC\uCFAD\uCFAE\uCFAF\uCFB1\uCFB2\uCFB3\uCFB4\uCFB5\uCFB6\uCFB7\uCFB8\uCFB9\uCFBA\uCFBB\uCFBC\uCFBD\uCFBE\uCFBF\uCFC0\uCFC1\uCFC2\uCFC3\uCFC5\uCFC6\uCFC7\uCFC8\uCFC9\uCFCA\uCFCB\uAE79\uAE7B\uAE7C\uAE7D\uAE84\uAE85\uAE8C\uAEBC\uAEBD\uAEBE\uAEC0\uAEC4\uAECC\uAECD\uAECF\uAED0\uAED1\uAED8\uAED9\uAEDC\uAEE8\uAEEB\uAEED\uAEF4\uAEF8\uAEFC\uAF07\uAF08\uAF0D\uAF10\uAF2C\uAF2D\uAF30\uAF32\uAF34\uAF3C\uAF3D\uAF3F\uAF41\uAF42\uAF43\uAF48\uAF49\uAF50\uAF5C\uAF5D\uAF64\uAF65\uAF79\uAF80\uAF84\uAF88\uAF90\uAF91\uAF95\uAF9C\uAFB8\uAFB9\uAFBC\uAFC0\uAFC7\uAFC8\uAFC9\uAFCB\uAFCD\uAFCE\uAFD4\uAFDC\uAFE8\uAFE9\uAFF0\uAFF1\uAFF4\uAFF8\uB000\uB001\uB004\uB00C\uB010\uB014\uB01C\uB01D\uB028\uB044\uB045\uB048\uB04A\uB04C\uB04E\uB053\uB054\uB055\uB057\uB059\uFFFD".split("");
      for (j = 0; j != D[178].length; ++j)
        if (D[178][j].charCodeAt(0) !== 65533) {
          e[D[178][j]] = 45568 + j;
          d[45568 + j] = D[178][j];
        }
      D[179] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCFCC\uCFCD\uCFCE\uCFCF\uCFD0\uCFD1\uCFD2\uCFD3\uCFD4\uCFD5\uCFD6\uCFD7\uCFD8\uCFD9\uCFDA\uCFDB\uCFDC\uCFDD\uCFDE\uCFDF\uCFE2\uCFE3\uCFE5\uCFE6\uCFE7\uCFE9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uCFEA\uCFEB\uCFEC\uCFED\uCFEE\uCFEF\uCFF2\uCFF4\uCFF6\uCFF7\uCFF8\uCFF9\uCFFA\uCFFB\uCFFD\uCFFE\uCFFF\uD001\uD002\uD003\uD005\uD006\uD007\uD008\uD009\uD00A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD00B\uD00C\uD00D\uD00E\uD00F\uD010\uD012\uD013\uD014\uD015\uD016\uD017\uD019\uD01A\uD01B\uD01C\uD01D\uD01E\uD01F\uD020\uD021\uD022\uD023\uD024\uD025\uD026\uD027\uD028\uD029\uD02A\uD02B\uD02C\uB05D\uB07C\uB07D\uB080\uB084\uB08C\uB08D\uB08F\uB091\uB098\uB099\uB09A\uB09C\uB09F\uB0A0\uB0A1\uB0A2\uB0A8\uB0A9\uB0AB\uB0AC\uB0AD\uB0AE\uB0AF\uB0B1\uB0B3\uB0B4\uB0B5\uB0B8\uB0BC\uB0C4\uB0C5\uB0C7\uB0C8\uB0C9\uB0D0\uB0D1\uB0D4\uB0D8\uB0E0\uB0E5\uB108\uB109\uB10B\uB10C\uB110\uB112\uB113\uB118\uB119\uB11B\uB11C\uB11D\uB123\uB124\uB125\uB128\uB12C\uB134\uB135\uB137\uB138\uB139\uB140\uB141\uB144\uB148\uB150\uB151\uB154\uB155\uB158\uB15C\uB160\uB178\uB179\uB17C\uB180\uB182\uB188\uB189\uB18B\uB18D\uB192\uB193\uB194\uB198\uB19C\uB1A8\uB1CC\uB1D0\uB1D4\uB1DC\uB1DD\uFFFD".split("");
      for (j = 0; j != D[179].length; ++j)
        if (D[179][j].charCodeAt(0) !== 65533) {
          e[D[179][j]] = 45824 + j;
          d[45824 + j] = D[179][j];
        }
      D[180] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD02E\uD02F\uD030\uD031\uD032\uD033\uD036\uD037\uD039\uD03A\uD03B\uD03D\uD03E\uD03F\uD040\uD041\uD042\uD043\uD046\uD048\uD04A\uD04B\uD04C\uD04D\uD04E\uD04F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD051\uD052\uD053\uD055\uD056\uD057\uD059\uD05A\uD05B\uD05C\uD05D\uD05E\uD05F\uD061\uD062\uD063\uD064\uD065\uD066\uD067\uD068\uD069\uD06A\uD06B\uD06E\uD06F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD071\uD072\uD073\uD075\uD076\uD077\uD078\uD079\uD07A\uD07B\uD07E\uD07F\uD080\uD082\uD083\uD084\uD085\uD086\uD087\uD088\uD089\uD08A\uD08B\uD08C\uD08D\uD08E\uD08F\uD090\uD091\uD092\uD093\uD094\uB1DF\uB1E8\uB1E9\uB1EC\uB1F0\uB1F9\uB1FB\uB1FD\uB204\uB205\uB208\uB20B\uB20C\uB214\uB215\uB217\uB219\uB220\uB234\uB23C\uB258\uB25C\uB260\uB268\uB269\uB274\uB275\uB27C\uB284\uB285\uB289\uB290\uB291\uB294\uB298\uB299\uB29A\uB2A0\uB2A1\uB2A3\uB2A5\uB2A6\uB2AA\uB2AC\uB2B0\uB2B4\uB2C8\uB2C9\uB2CC\uB2D0\uB2D2\uB2D8\uB2D9\uB2DB\uB2DD\uB2E2\uB2E4\uB2E5\uB2E6\uB2E8\uB2EB\uB2EC\uB2ED\uB2EE\uB2EF\uB2F3\uB2F4\uB2F5\uB2F7\uB2F8\uB2F9\uB2FA\uB2FB\uB2FF\uB300\uB301\uB304\uB308\uB310\uB311\uB313\uB314\uB315\uB31C\uB354\uB355\uB356\uB358\uB35B\uB35C\uB35E\uB35F\uB364\uB365\uFFFD".split("");
      for (j = 0; j != D[180].length; ++j)
        if (D[180][j].charCodeAt(0) !== 65533) {
          e[D[180][j]] = 46080 + j;
          d[46080 + j] = D[180][j];
        }
      D[181] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD095\uD096\uD097\uD098\uD099\uD09A\uD09B\uD09C\uD09D\uD09E\uD09F\uD0A0\uD0A1\uD0A2\uD0A3\uD0A6\uD0A7\uD0A9\uD0AA\uD0AB\uD0AD\uD0AE\uD0AF\uD0B0\uD0B1\uD0B2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD0B3\uD0B6\uD0B8\uD0BA\uD0BB\uD0BC\uD0BD\uD0BE\uD0BF\uD0C2\uD0C3\uD0C5\uD0C6\uD0C7\uD0CA\uD0CB\uD0CC\uD0CD\uD0CE\uD0CF\uD0D2\uD0D6\uD0D7\uD0D8\uD0D9\uD0DA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD0DB\uD0DE\uD0DF\uD0E1\uD0E2\uD0E3\uD0E5\uD0E6\uD0E7\uD0E8\uD0E9\uD0EA\uD0EB\uD0EE\uD0F2\uD0F3\uD0F4\uD0F5\uD0F6\uD0F7\uD0F9\uD0FA\uD0FB\uD0FC\uD0FD\uD0FE\uD0FF\uD100\uD101\uD102\uD103\uD104\uB367\uB369\uB36B\uB36E\uB370\uB371\uB374\uB378\uB380\uB381\uB383\uB384\uB385\uB38C\uB390\uB394\uB3A0\uB3A1\uB3A8\uB3AC\uB3C4\uB3C5\uB3C8\uB3CB\uB3CC\uB3CE\uB3D0\uB3D4\uB3D5\uB3D7\uB3D9\uB3DB\uB3DD\uB3E0\uB3E4\uB3E8\uB3FC\uB410\uB418\uB41C\uB420\uB428\uB429\uB42B\uB434\uB450\uB451\uB454\uB458\uB460\uB461\uB463\uB465\uB46C\uB480\uB488\uB49D\uB4A4\uB4A8\uB4AC\uB4B5\uB4B7\uB4B9\uB4C0\uB4C4\uB4C8\uB4D0\uB4D5\uB4DC\uB4DD\uB4E0\uB4E3\uB4E4\uB4E6\uB4EC\uB4ED\uB4EF\uB4F1\uB4F8\uB514\uB515\uB518\uB51B\uB51C\uB524\uB525\uB527\uB528\uB529\uB52A\uB530\uB531\uB534\uB538\uFFFD".split("");
      for (j = 0; j != D[181].length; ++j)
        if (D[181][j].charCodeAt(0) !== 65533) {
          e[D[181][j]] = 46336 + j;
          d[46336 + j] = D[181][j];
        }
      D[182] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD105\uD106\uD107\uD108\uD109\uD10A\uD10B\uD10C\uD10E\uD10F\uD110\uD111\uD112\uD113\uD114\uD115\uD116\uD117\uD118\uD119\uD11A\uD11B\uD11C\uD11D\uD11E\uD11F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD120\uD121\uD122\uD123\uD124\uD125\uD126\uD127\uD128\uD129\uD12A\uD12B\uD12C\uD12D\uD12E\uD12F\uD132\uD133\uD135\uD136\uD137\uD139\uD13B\uD13C\uD13D\uD13E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD13F\uD142\uD146\uD147\uD148\uD149\uD14A\uD14B\uD14E\uD14F\uD151\uD152\uD153\uD155\uD156\uD157\uD158\uD159\uD15A\uD15B\uD15E\uD160\uD162\uD163\uD164\uD165\uD166\uD167\uD169\uD16A\uD16B\uD16D\uB540\uB541\uB543\uB544\uB545\uB54B\uB54C\uB54D\uB550\uB554\uB55C\uB55D\uB55F\uB560\uB561\uB5A0\uB5A1\uB5A4\uB5A8\uB5AA\uB5AB\uB5B0\uB5B1\uB5B3\uB5B4\uB5B5\uB5BB\uB5BC\uB5BD\uB5C0\uB5C4\uB5CC\uB5CD\uB5CF\uB5D0\uB5D1\uB5D8\uB5EC\uB610\uB611\uB614\uB618\uB625\uB62C\uB634\uB648\uB664\uB668\uB69C\uB69D\uB6A0\uB6A4\uB6AB\uB6AC\uB6B1\uB6D4\uB6F0\uB6F4\uB6F8\uB700\uB701\uB705\uB728\uB729\uB72C\uB72F\uB730\uB738\uB739\uB73B\uB744\uB748\uB74C\uB754\uB755\uB760\uB764\uB768\uB770\uB771\uB773\uB775\uB77C\uB77D\uB780\uB784\uB78C\uB78D\uB78F\uB790\uB791\uB792\uB796\uB797\uFFFD".split("");
      for (j = 0; j != D[182].length; ++j)
        if (D[182][j].charCodeAt(0) !== 65533) {
          e[D[182][j]] = 46592 + j;
          d[46592 + j] = D[182][j];
        }
      D[183] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD16E\uD16F\uD170\uD171\uD172\uD173\uD174\uD175\uD176\uD177\uD178\uD179\uD17A\uD17B\uD17D\uD17E\uD17F\uD180\uD181\uD182\uD183\uD185\uD186\uD187\uD189\uD18A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD18B\uD18C\uD18D\uD18E\uD18F\uD190\uD191\uD192\uD193\uD194\uD195\uD196\uD197\uD198\uD199\uD19A\uD19B\uD19C\uD19D\uD19E\uD19F\uD1A2\uD1A3\uD1A5\uD1A6\uD1A7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD1A9\uD1AA\uD1AB\uD1AC\uD1AD\uD1AE\uD1AF\uD1B2\uD1B4\uD1B6\uD1B7\uD1B8\uD1B9\uD1BB\uD1BD\uD1BE\uD1BF\uD1C1\uD1C2\uD1C3\uD1C4\uD1C5\uD1C6\uD1C7\uD1C8\uD1C9\uD1CA\uD1CB\uD1CC\uD1CD\uD1CE\uD1CF\uB798\uB799\uB79C\uB7A0\uB7A8\uB7A9\uB7AB\uB7AC\uB7AD\uB7B4\uB7B5\uB7B8\uB7C7\uB7C9\uB7EC\uB7ED\uB7F0\uB7F4\uB7FC\uB7FD\uB7FF\uB800\uB801\uB807\uB808\uB809\uB80C\uB810\uB818\uB819\uB81B\uB81D\uB824\uB825\uB828\uB82C\uB834\uB835\uB837\uB838\uB839\uB840\uB844\uB851\uB853\uB85C\uB85D\uB860\uB864\uB86C\uB86D\uB86F\uB871\uB878\uB87C\uB88D\uB8A8\uB8B0\uB8B4\uB8B8\uB8C0\uB8C1\uB8C3\uB8C5\uB8CC\uB8D0\uB8D4\uB8DD\uB8DF\uB8E1\uB8E8\uB8E9\uB8EC\uB8F0\uB8F8\uB8F9\uB8FB\uB8FD\uB904\uB918\uB920\uB93C\uB93D\uB940\uB944\uB94C\uB94F\uB951\uB958\uB959\uB95C\uB960\uB968\uB969\uFFFD".split("");
      for (j = 0; j != D[183].length; ++j)
        if (D[183][j].charCodeAt(0) !== 65533) {
          e[D[183][j]] = 46848 + j;
          d[46848 + j] = D[183][j];
        }
      D[184] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD1D0\uD1D1\uD1D2\uD1D3\uD1D4\uD1D5\uD1D6\uD1D7\uD1D9\uD1DA\uD1DB\uD1DC\uD1DD\uD1DE\uD1DF\uD1E0\uD1E1\uD1E2\uD1E3\uD1E4\uD1E5\uD1E6\uD1E7\uD1E8\uD1E9\uD1EA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD1EB\uD1EC\uD1ED\uD1EE\uD1EF\uD1F0\uD1F1\uD1F2\uD1F3\uD1F5\uD1F6\uD1F7\uD1F9\uD1FA\uD1FB\uD1FC\uD1FD\uD1FE\uD1FF\uD200\uD201\uD202\uD203\uD204\uD205\uD206\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD208\uD20A\uD20B\uD20C\uD20D\uD20E\uD20F\uD211\uD212\uD213\uD214\uD215\uD216\uD217\uD218\uD219\uD21A\uD21B\uD21C\uD21D\uD21E\uD21F\uD220\uD221\uD222\uD223\uD224\uD225\uD226\uD227\uD228\uD229\uB96B\uB96D\uB974\uB975\uB978\uB97C\uB984\uB985\uB987\uB989\uB98A\uB98D\uB98E\uB9AC\uB9AD\uB9B0\uB9B4\uB9BC\uB9BD\uB9BF\uB9C1\uB9C8\uB9C9\uB9CC\uB9CE\uB9CF\uB9D0\uB9D1\uB9D2\uB9D8\uB9D9\uB9DB\uB9DD\uB9DE\uB9E1\uB9E3\uB9E4\uB9E5\uB9E8\uB9EC\uB9F4\uB9F5\uB9F7\uB9F8\uB9F9\uB9FA\uBA00\uBA01\uBA08\uBA15\uBA38\uBA39\uBA3C\uBA40\uBA42\uBA48\uBA49\uBA4B\uBA4D\uBA4E\uBA53\uBA54\uBA55\uBA58\uBA5C\uBA64\uBA65\uBA67\uBA68\uBA69\uBA70\uBA71\uBA74\uBA78\uBA83\uBA84\uBA85\uBA87\uBA8C\uBAA8\uBAA9\uBAAB\uBAAC\uBAB0\uBAB2\uBAB8\uBAB9\uBABB\uBABD\uBAC4\uBAC8\uBAD8\uBAD9\uBAFC\uFFFD".split("");
      for (j = 0; j != D[184].length; ++j)
        if (D[184][j].charCodeAt(0) !== 65533) {
          e[D[184][j]] = 47104 + j;
          d[47104 + j] = D[184][j];
        }
      D[185] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD22A\uD22B\uD22E\uD22F\uD231\uD232\uD233\uD235\uD236\uD237\uD238\uD239\uD23A\uD23B\uD23E\uD240\uD242\uD243\uD244\uD245\uD246\uD247\uD249\uD24A\uD24B\uD24C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD24D\uD24E\uD24F\uD250\uD251\uD252\uD253\uD254\uD255\uD256\uD257\uD258\uD259\uD25A\uD25B\uD25D\uD25E\uD25F\uD260\uD261\uD262\uD263\uD265\uD266\uD267\uD268\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD269\uD26A\uD26B\uD26C\uD26D\uD26E\uD26F\uD270\uD271\uD272\uD273\uD274\uD275\uD276\uD277\uD278\uD279\uD27A\uD27B\uD27C\uD27D\uD27E\uD27F\uD282\uD283\uD285\uD286\uD287\uD289\uD28A\uD28B\uD28C\uBB00\uBB04\uBB0D\uBB0F\uBB11\uBB18\uBB1C\uBB20\uBB29\uBB2B\uBB34\uBB35\uBB36\uBB38\uBB3B\uBB3C\uBB3D\uBB3E\uBB44\uBB45\uBB47\uBB49\uBB4D\uBB4F\uBB50\uBB54\uBB58\uBB61\uBB63\uBB6C\uBB88\uBB8C\uBB90\uBBA4\uBBA8\uBBAC\uBBB4\uBBB7\uBBC0\uBBC4\uBBC8\uBBD0\uBBD3\uBBF8\uBBF9\uBBFC\uBBFF\uBC00\uBC02\uBC08\uBC09\uBC0B\uBC0C\uBC0D\uBC0F\uBC11\uBC14\uBC15\uBC16\uBC17\uBC18\uBC1B\uBC1C\uBC1D\uBC1E\uBC1F\uBC24\uBC25\uBC27\uBC29\uBC2D\uBC30\uBC31\uBC34\uBC38\uBC40\uBC41\uBC43\uBC44\uBC45\uBC49\uBC4C\uBC4D\uBC50\uBC5D\uBC84\uBC85\uBC88\uBC8B\uBC8C\uBC8E\uBC94\uBC95\uBC97\uFFFD".split("");
      for (j = 0; j != D[185].length; ++j)
        if (D[185][j].charCodeAt(0) !== 65533) {
          e[D[185][j]] = 47360 + j;
          d[47360 + j] = D[185][j];
        }
      D[186] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD28D\uD28E\uD28F\uD292\uD293\uD294\uD296\uD297\uD298\uD299\uD29A\uD29B\uD29D\uD29E\uD29F\uD2A1\uD2A2\uD2A3\uD2A5\uD2A6\uD2A7\uD2A8\uD2A9\uD2AA\uD2AB\uD2AD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD2AE\uD2AF\uD2B0\uD2B2\uD2B3\uD2B4\uD2B5\uD2B6\uD2B7\uD2BA\uD2BB\uD2BD\uD2BE\uD2C1\uD2C3\uD2C4\uD2C5\uD2C6\uD2C7\uD2CA\uD2CC\uD2CD\uD2CE\uD2CF\uD2D0\uD2D1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD2D2\uD2D3\uD2D5\uD2D6\uD2D7\uD2D9\uD2DA\uD2DB\uD2DD\uD2DE\uD2DF\uD2E0\uD2E1\uD2E2\uD2E3\uD2E6\uD2E7\uD2E8\uD2E9\uD2EA\uD2EB\uD2EC\uD2ED\uD2EE\uD2EF\uD2F2\uD2F3\uD2F5\uD2F6\uD2F7\uD2F9\uD2FA\uBC99\uBC9A\uBCA0\uBCA1\uBCA4\uBCA7\uBCA8\uBCB0\uBCB1\uBCB3\uBCB4\uBCB5\uBCBC\uBCBD\uBCC0\uBCC4\uBCCD\uBCCF\uBCD0\uBCD1\uBCD5\uBCD8\uBCDC\uBCF4\uBCF5\uBCF6\uBCF8\uBCFC\uBD04\uBD05\uBD07\uBD09\uBD10\uBD14\uBD24\uBD2C\uBD40\uBD48\uBD49\uBD4C\uBD50\uBD58\uBD59\uBD64\uBD68\uBD80\uBD81\uBD84\uBD87\uBD88\uBD89\uBD8A\uBD90\uBD91\uBD93\uBD95\uBD99\uBD9A\uBD9C\uBDA4\uBDB0\uBDB8\uBDD4\uBDD5\uBDD8\uBDDC\uBDE9\uBDF0\uBDF4\uBDF8\uBE00\uBE03\uBE05\uBE0C\uBE0D\uBE10\uBE14\uBE1C\uBE1D\uBE1F\uBE44\uBE45\uBE48\uBE4C\uBE4E\uBE54\uBE55\uBE57\uBE59\uBE5A\uBE5B\uBE60\uBE61\uBE64\uFFFD".split("");
      for (j = 0; j != D[186].length; ++j)
        if (D[186][j].charCodeAt(0) !== 65533) {
          e[D[186][j]] = 47616 + j;
          d[47616 + j] = D[186][j];
        }
      D[187] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD2FB\uD2FC\uD2FD\uD2FE\uD2FF\uD302\uD304\uD306\uD307\uD308\uD309\uD30A\uD30B\uD30F\uD311\uD312\uD313\uD315\uD317\uD318\uD319\uD31A\uD31B\uD31E\uD322\uD323\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD324\uD326\uD327\uD32A\uD32B\uD32D\uD32E\uD32F\uD331\uD332\uD333\uD334\uD335\uD336\uD337\uD33A\uD33E\uD33F\uD340\uD341\uD342\uD343\uD346\uD347\uD348\uD349\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD34A\uD34B\uD34C\uD34D\uD34E\uD34F\uD350\uD351\uD352\uD353\uD354\uD355\uD356\uD357\uD358\uD359\uD35A\uD35B\uD35C\uD35D\uD35E\uD35F\uD360\uD361\uD362\uD363\uD364\uD365\uD366\uD367\uD368\uD369\uBE68\uBE6A\uBE70\uBE71\uBE73\uBE74\uBE75\uBE7B\uBE7C\uBE7D\uBE80\uBE84\uBE8C\uBE8D\uBE8F\uBE90\uBE91\uBE98\uBE99\uBEA8\uBED0\uBED1\uBED4\uBED7\uBED8\uBEE0\uBEE3\uBEE4\uBEE5\uBEEC\uBF01\uBF08\uBF09\uBF18\uBF19\uBF1B\uBF1C\uBF1D\uBF40\uBF41\uBF44\uBF48\uBF50\uBF51\uBF55\uBF94\uBFB0\uBFC5\uBFCC\uBFCD\uBFD0\uBFD4\uBFDC\uBFDF\uBFE1\uC03C\uC051\uC058\uC05C\uC060\uC068\uC069\uC090\uC091\uC094\uC098\uC0A0\uC0A1\uC0A3\uC0A5\uC0AC\uC0AD\uC0AF\uC0B0\uC0B3\uC0B4\uC0B5\uC0B6\uC0BC\uC0BD\uC0BF\uC0C0\uC0C1\uC0C5\uC0C8\uC0C9\uC0CC\uC0D0\uC0D8\uC0D9\uC0DB\uC0DC\uC0DD\uC0E4\uFFFD".split("");
      for (j = 0; j != D[187].length; ++j)
        if (D[187][j].charCodeAt(0) !== 65533) {
          e[D[187][j]] = 47872 + j;
          d[47872 + j] = D[187][j];
        }
      D[188] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD36A\uD36B\uD36C\uD36D\uD36E\uD36F\uD370\uD371\uD372\uD373\uD374\uD375\uD376\uD377\uD378\uD379\uD37A\uD37B\uD37E\uD37F\uD381\uD382\uD383\uD385\uD386\uD387\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD388\uD389\uD38A\uD38B\uD38E\uD392\uD393\uD394\uD395\uD396\uD397\uD39A\uD39B\uD39D\uD39E\uD39F\uD3A1\uD3A2\uD3A3\uD3A4\uD3A5\uD3A6\uD3A7\uD3AA\uD3AC\uD3AE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD3AF\uD3B0\uD3B1\uD3B2\uD3B3\uD3B5\uD3B6\uD3B7\uD3B9\uD3BA\uD3BB\uD3BD\uD3BE\uD3BF\uD3C0\uD3C1\uD3C2\uD3C3\uD3C6\uD3C7\uD3CA\uD3CB\uD3CC\uD3CD\uD3CE\uD3CF\uD3D1\uD3D2\uD3D3\uD3D4\uD3D5\uD3D6\uC0E5\uC0E8\uC0EC\uC0F4\uC0F5\uC0F7\uC0F9\uC100\uC104\uC108\uC110\uC115\uC11C\uC11D\uC11E\uC11F\uC120\uC123\uC124\uC126\uC127\uC12C\uC12D\uC12F\uC130\uC131\uC136\uC138\uC139\uC13C\uC140\uC148\uC149\uC14B\uC14C\uC14D\uC154\uC155\uC158\uC15C\uC164\uC165\uC167\uC168\uC169\uC170\uC174\uC178\uC185\uC18C\uC18D\uC18E\uC190\uC194\uC196\uC19C\uC19D\uC19F\uC1A1\uC1A5\uC1A8\uC1A9\uC1AC\uC1B0\uC1BD\uC1C4\uC1C8\uC1CC\uC1D4\uC1D7\uC1D8\uC1E0\uC1E4\uC1E8\uC1F0\uC1F1\uC1F3\uC1FC\uC1FD\uC200\uC204\uC20C\uC20D\uC20F\uC211\uC218\uC219\uC21C\uC21F\uC220\uC228\uC229\uC22B\uC22D\uFFFD".split("");
      for (j = 0; j != D[188].length; ++j)
        if (D[188][j].charCodeAt(0) !== 65533) {
          e[D[188][j]] = 48128 + j;
          d[48128 + j] = D[188][j];
        }
      D[189] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD3D7\uD3D9\uD3DA\uD3DB\uD3DC\uD3DD\uD3DE\uD3DF\uD3E0\uD3E2\uD3E4\uD3E5\uD3E6\uD3E7\uD3E8\uD3E9\uD3EA\uD3EB\uD3EE\uD3EF\uD3F1\uD3F2\uD3F3\uD3F5\uD3F6\uD3F7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD3F8\uD3F9\uD3FA\uD3FB\uD3FE\uD400\uD402\uD403\uD404\uD405\uD406\uD407\uD409\uD40A\uD40B\uD40C\uD40D\uD40E\uD40F\uD410\uD411\uD412\uD413\uD414\uD415\uD416\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD417\uD418\uD419\uD41A\uD41B\uD41C\uD41E\uD41F\uD420\uD421\uD422\uD423\uD424\uD425\uD426\uD427\uD428\uD429\uD42A\uD42B\uD42C\uD42D\uD42E\uD42F\uD430\uD431\uD432\uD433\uD434\uD435\uD436\uD437\uC22F\uC231\uC232\uC234\uC248\uC250\uC251\uC254\uC258\uC260\uC265\uC26C\uC26D\uC270\uC274\uC27C\uC27D\uC27F\uC281\uC288\uC289\uC290\uC298\uC29B\uC29D\uC2A4\uC2A5\uC2A8\uC2AC\uC2AD\uC2B4\uC2B5\uC2B7\uC2B9\uC2DC\uC2DD\uC2E0\uC2E3\uC2E4\uC2EB\uC2EC\uC2ED\uC2EF\uC2F1\uC2F6\uC2F8\uC2F9\uC2FB\uC2FC\uC300\uC308\uC309\uC30C\uC30D\uC313\uC314\uC315\uC318\uC31C\uC324\uC325\uC328\uC329\uC345\uC368\uC369\uC36C\uC370\uC372\uC378\uC379\uC37C\uC37D\uC384\uC388\uC38C\uC3C0\uC3D8\uC3D9\uC3DC\uC3DF\uC3E0\uC3E2\uC3E8\uC3E9\uC3ED\uC3F4\uC3F5\uC3F8\uC408\uC410\uC424\uC42C\uC430\uFFFD".split("");
      for (j = 0; j != D[189].length; ++j)
        if (D[189][j].charCodeAt(0) !== 65533) {
          e[D[189][j]] = 48384 + j;
          d[48384 + j] = D[189][j];
        }
      D[190] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD438\uD439\uD43A\uD43B\uD43C\uD43D\uD43E\uD43F\uD441\uD442\uD443\uD445\uD446\uD447\uD448\uD449\uD44A\uD44B\uD44C\uD44D\uD44E\uD44F\uD450\uD451\uD452\uD453\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD454\uD455\uD456\uD457\uD458\uD459\uD45A\uD45B\uD45D\uD45E\uD45F\uD461\uD462\uD463\uD465\uD466\uD467\uD468\uD469\uD46A\uD46B\uD46C\uD46E\uD470\uD471\uD472\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD473\uD474\uD475\uD476\uD477\uD47A\uD47B\uD47D\uD47E\uD481\uD483\uD484\uD485\uD486\uD487\uD48A\uD48C\uD48E\uD48F\uD490\uD491\uD492\uD493\uD495\uD496\uD497\uD498\uD499\uD49A\uD49B\uD49C\uD49D\uC434\uC43C\uC43D\uC448\uC464\uC465\uC468\uC46C\uC474\uC475\uC479\uC480\uC494\uC49C\uC4B8\uC4BC\uC4E9\uC4F0\uC4F1\uC4F4\uC4F8\uC4FA\uC4FF\uC500\uC501\uC50C\uC510\uC514\uC51C\uC528\uC529\uC52C\uC530\uC538\uC539\uC53B\uC53D\uC544\uC545\uC548\uC549\uC54A\uC54C\uC54D\uC54E\uC553\uC554\uC555\uC557\uC558\uC559\uC55D\uC55E\uC560\uC561\uC564\uC568\uC570\uC571\uC573\uC574\uC575\uC57C\uC57D\uC580\uC584\uC587\uC58C\uC58D\uC58F\uC591\uC595\uC597\uC598\uC59C\uC5A0\uC5A9\uC5B4\uC5B5\uC5B8\uC5B9\uC5BB\uC5BC\uC5BD\uC5BE\uC5C4\uC5C5\uC5C6\uC5C7\uC5C8\uC5C9\uC5CA\uC5CC\uC5CE\uFFFD".split("");
      for (j = 0; j != D[190].length; ++j)
        if (D[190][j].charCodeAt(0) !== 65533) {
          e[D[190][j]] = 48640 + j;
          d[48640 + j] = D[190][j];
        }
      D[191] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD49E\uD49F\uD4A0\uD4A1\uD4A2\uD4A3\uD4A4\uD4A5\uD4A6\uD4A7\uD4A8\uD4AA\uD4AB\uD4AC\uD4AD\uD4AE\uD4AF\uD4B0\uD4B1\uD4B2\uD4B3\uD4B4\uD4B5\uD4B6\uD4B7\uD4B8\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD4B9\uD4BA\uD4BB\uD4BC\uD4BD\uD4BE\uD4BF\uD4C0\uD4C1\uD4C2\uD4C3\uD4C4\uD4C5\uD4C6\uD4C7\uD4C8\uD4C9\uD4CA\uD4CB\uD4CD\uD4CE\uD4CF\uD4D1\uD4D2\uD4D3\uD4D5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD4D6\uD4D7\uD4D8\uD4D9\uD4DA\uD4DB\uD4DD\uD4DE\uD4E0\uD4E1\uD4E2\uD4E3\uD4E4\uD4E5\uD4E6\uD4E7\uD4E9\uD4EA\uD4EB\uD4ED\uD4EE\uD4EF\uD4F1\uD4F2\uD4F3\uD4F4\uD4F5\uD4F6\uD4F7\uD4F9\uD4FA\uD4FC\uC5D0\uC5D1\uC5D4\uC5D8\uC5E0\uC5E1\uC5E3\uC5E5\uC5EC\uC5ED\uC5EE\uC5F0\uC5F4\uC5F6\uC5F7\uC5FC\uC5FD\uC5FE\uC5FF\uC600\uC601\uC605\uC606\uC607\uC608\uC60C\uC610\uC618\uC619\uC61B\uC61C\uC624\uC625\uC628\uC62C\uC62D\uC62E\uC630\uC633\uC634\uC635\uC637\uC639\uC63B\uC640\uC641\uC644\uC648\uC650\uC651\uC653\uC654\uC655\uC65C\uC65D\uC660\uC66C\uC66F\uC671\uC678\uC679\uC67C\uC680\uC688\uC689\uC68B\uC68D\uC694\uC695\uC698\uC69C\uC6A4\uC6A5\uC6A7\uC6A9\uC6B0\uC6B1\uC6B4\uC6B8\uC6B9\uC6BA\uC6C0\uC6C1\uC6C3\uC6C5\uC6CC\uC6CD\uC6D0\uC6D4\uC6DC\uC6DD\uC6E0\uC6E1\uC6E8\uFFFD".split("");
      for (j = 0; j != D[191].length; ++j)
        if (D[191][j].charCodeAt(0) !== 65533) {
          e[D[191][j]] = 48896 + j;
          d[48896 + j] = D[191][j];
        }
      D[192] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD4FE\uD4FF\uD500\uD501\uD502\uD503\uD505\uD506\uD507\uD509\uD50A\uD50B\uD50D\uD50E\uD50F\uD510\uD511\uD512\uD513\uD516\uD518\uD519\uD51A\uD51B\uD51C\uD51D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD51E\uD51F\uD520\uD521\uD522\uD523\uD524\uD525\uD526\uD527\uD528\uD529\uD52A\uD52B\uD52C\uD52D\uD52E\uD52F\uD530\uD531\uD532\uD533\uD534\uD535\uD536\uD537\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD538\uD539\uD53A\uD53B\uD53E\uD53F\uD541\uD542\uD543\uD545\uD546\uD547\uD548\uD549\uD54A\uD54B\uD54E\uD550\uD552\uD553\uD554\uD555\uD556\uD557\uD55A\uD55B\uD55D\uD55E\uD55F\uD561\uD562\uD563\uC6E9\uC6EC\uC6F0\uC6F8\uC6F9\uC6FD\uC704\uC705\uC708\uC70C\uC714\uC715\uC717\uC719\uC720\uC721\uC724\uC728\uC730\uC731\uC733\uC735\uC737\uC73C\uC73D\uC740\uC744\uC74A\uC74C\uC74D\uC74F\uC751\uC752\uC753\uC754\uC755\uC756\uC757\uC758\uC75C\uC760\uC768\uC76B\uC774\uC775\uC778\uC77C\uC77D\uC77E\uC783\uC784\uC785\uC787\uC788\uC789\uC78A\uC78E\uC790\uC791\uC794\uC796\uC797\uC798\uC79A\uC7A0\uC7A1\uC7A3\uC7A4\uC7A5\uC7A6\uC7AC\uC7AD\uC7B0\uC7B4\uC7BC\uC7BD\uC7BF\uC7C0\uC7C1\uC7C8\uC7C9\uC7CC\uC7CE\uC7D0\uC7D8\uC7DD\uC7E4\uC7E8\uC7EC\uC800\uC801\uC804\uC808\uC80A\uFFFD".split("");
      for (j = 0; j != D[192].length; ++j)
        if (D[192][j].charCodeAt(0) !== 65533) {
          e[D[192][j]] = 49152 + j;
          d[49152 + j] = D[192][j];
        }
      D[193] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD564\uD566\uD567\uD56A\uD56C\uD56E\uD56F\uD570\uD571\uD572\uD573\uD576\uD577\uD579\uD57A\uD57B\uD57D\uD57E\uD57F\uD580\uD581\uD582\uD583\uD586\uD58A\uD58B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD58C\uD58D\uD58E\uD58F\uD591\uD592\uD593\uD594\uD595\uD596\uD597\uD598\uD599\uD59A\uD59B\uD59C\uD59D\uD59E\uD59F\uD5A0\uD5A1\uD5A2\uD5A3\uD5A4\uD5A6\uD5A7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD5A8\uD5A9\uD5AA\uD5AB\uD5AC\uD5AD\uD5AE\uD5AF\uD5B0\uD5B1\uD5B2\uD5B3\uD5B4\uD5B5\uD5B6\uD5B7\uD5B8\uD5B9\uD5BA\uD5BB\uD5BC\uD5BD\uD5BE\uD5BF\uD5C0\uD5C1\uD5C2\uD5C3\uD5C4\uD5C5\uD5C6\uD5C7\uC810\uC811\uC813\uC815\uC816\uC81C\uC81D\uC820\uC824\uC82C\uC82D\uC82F\uC831\uC838\uC83C\uC840\uC848\uC849\uC84C\uC84D\uC854\uC870\uC871\uC874\uC878\uC87A\uC880\uC881\uC883\uC885\uC886\uC887\uC88B\uC88C\uC88D\uC894\uC89D\uC89F\uC8A1\uC8A8\uC8BC\uC8BD\uC8C4\uC8C8\uC8CC\uC8D4\uC8D5\uC8D7\uC8D9\uC8E0\uC8E1\uC8E4\uC8F5\uC8FC\uC8FD\uC900\uC904\uC905\uC906\uC90C\uC90D\uC90F\uC911\uC918\uC92C\uC934\uC950\uC951\uC954\uC958\uC960\uC961\uC963\uC96C\uC970\uC974\uC97C\uC988\uC989\uC98C\uC990\uC998\uC999\uC99B\uC99D\uC9C0\uC9C1\uC9C4\uC9C7\uC9C8\uC9CA\uC9D0\uC9D1\uC9D3\uFFFD".split("");
      for (j = 0; j != D[193].length; ++j)
        if (D[193][j].charCodeAt(0) !== 65533) {
          e[D[193][j]] = 49408 + j;
          d[49408 + j] = D[193][j];
        }
      D[194] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD5CA\uD5CB\uD5CD\uD5CE\uD5CF\uD5D1\uD5D3\uD5D4\uD5D5\uD5D6\uD5D7\uD5DA\uD5DC\uD5DE\uD5DF\uD5E0\uD5E1\uD5E2\uD5E3\uD5E6\uD5E7\uD5E9\uD5EA\uD5EB\uD5ED\uD5EE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD5EF\uD5F0\uD5F1\uD5F2\uD5F3\uD5F6\uD5F8\uD5FA\uD5FB\uD5FC\uD5FD\uD5FE\uD5FF\uD602\uD603\uD605\uD606\uD607\uD609\uD60A\uD60B\uD60C\uD60D\uD60E\uD60F\uD612\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD616\uD617\uD618\uD619\uD61A\uD61B\uD61D\uD61E\uD61F\uD621\uD622\uD623\uD625\uD626\uD627\uD628\uD629\uD62A\uD62B\uD62C\uD62E\uD62F\uD630\uD631\uD632\uD633\uD634\uD635\uD636\uD637\uD63A\uD63B\uC9D5\uC9D6\uC9D9\uC9DA\uC9DC\uC9DD\uC9E0\uC9E2\uC9E4\uC9E7\uC9EC\uC9ED\uC9EF\uC9F0\uC9F1\uC9F8\uC9F9\uC9FC\uCA00\uCA08\uCA09\uCA0B\uCA0C\uCA0D\uCA14\uCA18\uCA29\uCA4C\uCA4D\uCA50\uCA54\uCA5C\uCA5D\uCA5F\uCA60\uCA61\uCA68\uCA7D\uCA84\uCA98\uCABC\uCABD\uCAC0\uCAC4\uCACC\uCACD\uCACF\uCAD1\uCAD3\uCAD8\uCAD9\uCAE0\uCAEC\uCAF4\uCB08\uCB10\uCB14\uCB18\uCB20\uCB21\uCB41\uCB48\uCB49\uCB4C\uCB50\uCB58\uCB59\uCB5D\uCB64\uCB78\uCB79\uCB9C\uCBB8\uCBD4\uCBE4\uCBE7\uCBE9\uCC0C\uCC0D\uCC10\uCC14\uCC1C\uCC1D\uCC21\uCC22\uCC27\uCC28\uCC29\uCC2C\uCC2E\uCC30\uCC38\uCC39\uCC3B\uFFFD".split("");
      for (j = 0; j != D[194].length; ++j)
        if (D[194][j].charCodeAt(0) !== 65533) {
          e[D[194][j]] = 49664 + j;
          d[49664 + j] = D[194][j];
        }
      D[195] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD63D\uD63E\uD63F\uD641\uD642\uD643\uD644\uD646\uD647\uD64A\uD64C\uD64E\uD64F\uD650\uD652\uD653\uD656\uD657\uD659\uD65A\uD65B\uD65D\uD65E\uD65F\uD660\uD661\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD662\uD663\uD664\uD665\uD666\uD668\uD66A\uD66B\uD66C\uD66D\uD66E\uD66F\uD672\uD673\uD675\uD676\uD677\uD678\uD679\uD67A\uD67B\uD67C\uD67D\uD67E\uD67F\uD680\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD681\uD682\uD684\uD686\uD687\uD688\uD689\uD68A\uD68B\uD68E\uD68F\uD691\uD692\uD693\uD695\uD696\uD697\uD698\uD699\uD69A\uD69B\uD69C\uD69E\uD6A0\uD6A2\uD6A3\uD6A4\uD6A5\uD6A6\uD6A7\uD6A9\uD6AA\uCC3C\uCC3D\uCC3E\uCC44\uCC45\uCC48\uCC4C\uCC54\uCC55\uCC57\uCC58\uCC59\uCC60\uCC64\uCC66\uCC68\uCC70\uCC75\uCC98\uCC99\uCC9C\uCCA0\uCCA8\uCCA9\uCCAB\uCCAC\uCCAD\uCCB4\uCCB5\uCCB8\uCCBC\uCCC4\uCCC5\uCCC7\uCCC9\uCCD0\uCCD4\uCCE4\uCCEC\uCCF0\uCD01\uCD08\uCD09\uCD0C\uCD10\uCD18\uCD19\uCD1B\uCD1D\uCD24\uCD28\uCD2C\uCD39\uCD5C\uCD60\uCD64\uCD6C\uCD6D\uCD6F\uCD71\uCD78\uCD88\uCD94\uCD95\uCD98\uCD9C\uCDA4\uCDA5\uCDA7\uCDA9\uCDB0\uCDC4\uCDCC\uCDD0\uCDE8\uCDEC\uCDF0\uCDF8\uCDF9\uCDFB\uCDFD\uCE04\uCE08\uCE0C\uCE14\uCE19\uCE20\uCE21\uCE24\uCE28\uCE30\uCE31\uCE33\uCE35\uFFFD".split("");
      for (j = 0; j != D[195].length; ++j)
        if (D[195][j].charCodeAt(0) !== 65533) {
          e[D[195][j]] = 49920 + j;
          d[49920 + j] = D[195][j];
        }
      D[196] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD6AB\uD6AD\uD6AE\uD6AF\uD6B1\uD6B2\uD6B3\uD6B4\uD6B5\uD6B6\uD6B7\uD6B8\uD6BA\uD6BC\uD6BD\uD6BE\uD6BF\uD6C0\uD6C1\uD6C2\uD6C3\uD6C6\uD6C7\uD6C9\uD6CA\uD6CB\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD6CD\uD6CE\uD6CF\uD6D0\uD6D2\uD6D3\uD6D5\uD6D6\uD6D8\uD6DA\uD6DB\uD6DC\uD6DD\uD6DE\uD6DF\uD6E1\uD6E2\uD6E3\uD6E5\uD6E6\uD6E7\uD6E9\uD6EA\uD6EB\uD6EC\uD6ED\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD6EE\uD6EF\uD6F1\uD6F2\uD6F3\uD6F4\uD6F6\uD6F7\uD6F8\uD6F9\uD6FA\uD6FB\uD6FE\uD6FF\uD701\uD702\uD703\uD705\uD706\uD707\uD708\uD709\uD70A\uD70B\uD70C\uD70D\uD70E\uD70F\uD710\uD712\uD713\uD714\uCE58\uCE59\uCE5C\uCE5F\uCE60\uCE61\uCE68\uCE69\uCE6B\uCE6D\uCE74\uCE75\uCE78\uCE7C\uCE84\uCE85\uCE87\uCE89\uCE90\uCE91\uCE94\uCE98\uCEA0\uCEA1\uCEA3\uCEA4\uCEA5\uCEAC\uCEAD\uCEC1\uCEE4\uCEE5\uCEE8\uCEEB\uCEEC\uCEF4\uCEF5\uCEF7\uCEF8\uCEF9\uCF00\uCF01\uCF04\uCF08\uCF10\uCF11\uCF13\uCF15\uCF1C\uCF20\uCF24\uCF2C\uCF2D\uCF2F\uCF30\uCF31\uCF38\uCF54\uCF55\uCF58\uCF5C\uCF64\uCF65\uCF67\uCF69\uCF70\uCF71\uCF74\uCF78\uCF80\uCF85\uCF8C\uCFA1\uCFA8\uCFB0\uCFC4\uCFE0\uCFE1\uCFE4\uCFE8\uCFF0\uCFF1\uCFF3\uCFF5\uCFFC\uD000\uD004\uD011\uD018\uD02D\uD034\uD035\uD038\uD03C\uFFFD".split("");
      for (j = 0; j != D[196].length; ++j)
        if (D[196][j].charCodeAt(0) !== 65533) {
          e[D[196][j]] = 50176 + j;
          d[50176 + j] = D[196][j];
        }
      D[197] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD715\uD716\uD717\uD71A\uD71B\uD71D\uD71E\uD71F\uD721\uD722\uD723\uD724\uD725\uD726\uD727\uD72A\uD72C\uD72E\uD72F\uD730\uD731\uD732\uD733\uD736\uD737\uD739\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD73A\uD73B\uD73D\uD73E\uD73F\uD740\uD741\uD742\uD743\uD745\uD746\uD748\uD74A\uD74B\uD74C\uD74D\uD74E\uD74F\uD752\uD753\uD755\uD75A\uD75B\uD75C\uD75D\uD75E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD75F\uD762\uD764\uD766\uD767\uD768\uD76A\uD76B\uD76D\uD76E\uD76F\uD771\uD772\uD773\uD775\uD776\uD777\uD778\uD779\uD77A\uD77B\uD77E\uD77F\uD780\uD782\uD783\uD784\uD785\uD786\uD787\uD78A\uD78B\uD044\uD045\uD047\uD049\uD050\uD054\uD058\uD060\uD06C\uD06D\uD070\uD074\uD07C\uD07D\uD081\uD0A4\uD0A5\uD0A8\uD0AC\uD0B4\uD0B5\uD0B7\uD0B9\uD0C0\uD0C1\uD0C4\uD0C8\uD0C9\uD0D0\uD0D1\uD0D3\uD0D4\uD0D5\uD0DC\uD0DD\uD0E0\uD0E4\uD0EC\uD0ED\uD0EF\uD0F0\uD0F1\uD0F8\uD10D\uD130\uD131\uD134\uD138\uD13A\uD140\uD141\uD143\uD144\uD145\uD14C\uD14D\uD150\uD154\uD15C\uD15D\uD15F\uD161\uD168\uD16C\uD17C\uD184\uD188\uD1A0\uD1A1\uD1A4\uD1A8\uD1B0\uD1B1\uD1B3\uD1B5\uD1BA\uD1BC\uD1C0\uD1D8\uD1F4\uD1F8\uD207\uD209\uD210\uD22C\uD22D\uD230\uD234\uD23C\uD23D\uD23F\uD241\uD248\uD25C\uFFFD".split("");
      for (j = 0; j != D[197].length; ++j)
        if (D[197][j].charCodeAt(0) !== 65533) {
          e[D[197][j]] = 50432 + j;
          d[50432 + j] = D[197][j];
        }
      D[198] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD78D\uD78E\uD78F\uD791\uD792\uD793\uD794\uD795\uD796\uD797\uD79A\uD79C\uD79E\uD79F\uD7A0\uD7A1\uD7A2\uD7A3\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD264\uD280\uD281\uD284\uD288\uD290\uD291\uD295\uD29C\uD2A0\uD2A4\uD2AC\uD2B1\uD2B8\uD2B9\uD2BC\uD2BF\uD2C0\uD2C2\uD2C8\uD2C9\uD2CB\uD2D4\uD2D8\uD2DC\uD2E4\uD2E5\uD2F0\uD2F1\uD2F4\uD2F8\uD300\uD301\uD303\uD305\uD30C\uD30D\uD30E\uD310\uD314\uD316\uD31C\uD31D\uD31F\uD320\uD321\uD325\uD328\uD329\uD32C\uD330\uD338\uD339\uD33B\uD33C\uD33D\uD344\uD345\uD37C\uD37D\uD380\uD384\uD38C\uD38D\uD38F\uD390\uD391\uD398\uD399\uD39C\uD3A0\uD3A8\uD3A9\uD3AB\uD3AD\uD3B4\uD3B8\uD3BC\uD3C4\uD3C5\uD3C8\uD3C9\uD3D0\uD3D8\uD3E1\uD3E3\uD3EC\uD3ED\uD3F0\uD3F4\uD3FC\uD3FD\uD3FF\uD401\uFFFD".split("");
      for (j = 0; j != D[198].length; ++j)
        if (D[198][j].charCodeAt(0) !== 65533) {
          e[D[198][j]] = 50688 + j;
          d[50688 + j] = D[198][j];
        }
      D[199] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD408\uD41D\uD440\uD444\uD45C\uD460\uD464\uD46D\uD46F\uD478\uD479\uD47C\uD47F\uD480\uD482\uD488\uD489\uD48B\uD48D\uD494\uD4A9\uD4CC\uD4D0\uD4D4\uD4DC\uD4DF\uD4E8\uD4EC\uD4F0\uD4F8\uD4FB\uD4FD\uD504\uD508\uD50C\uD514\uD515\uD517\uD53C\uD53D\uD540\uD544\uD54C\uD54D\uD54F\uD551\uD558\uD559\uD55C\uD560\uD565\uD568\uD569\uD56B\uD56D\uD574\uD575\uD578\uD57C\uD584\uD585\uD587\uD588\uD589\uD590\uD5A5\uD5C8\uD5C9\uD5CC\uD5D0\uD5D2\uD5D8\uD5D9\uD5DB\uD5DD\uD5E4\uD5E5\uD5E8\uD5EC\uD5F4\uD5F5\uD5F7\uD5F9\uD600\uD601\uD604\uD608\uD610\uD611\uD613\uD614\uD615\uD61C\uD620\uFFFD".split("");
      for (j = 0; j != D[199].length; ++j)
        if (D[199][j].charCodeAt(0) !== 65533) {
          e[D[199][j]] = 50944 + j;
          d[50944 + j] = D[199][j];
        }
      D[200] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uD624\uD62D\uD638\uD639\uD63C\uD640\uD645\uD648\uD649\uD64B\uD64D\uD651\uD654\uD655\uD658\uD65C\uD667\uD669\uD670\uD671\uD674\uD683\uD685\uD68C\uD68D\uD690\uD694\uD69D\uD69F\uD6A1\uD6A8\uD6AC\uD6B0\uD6B9\uD6BB\uD6C4\uD6C5\uD6C8\uD6CC\uD6D1\uD6D4\uD6D7\uD6D9\uD6E0\uD6E4\uD6E8\uD6F0\uD6F5\uD6FC\uD6FD\uD700\uD704\uD711\uD718\uD719\uD71C\uD720\uD728\uD729\uD72B\uD72D\uD734\uD735\uD738\uD73C\uD744\uD747\uD749\uD750\uD751\uD754\uD756\uD757\uD758\uD759\uD760\uD761\uD763\uD765\uD769\uD76C\uD770\uD774\uD77C\uD77D\uD781\uD788\uD789\uD78C\uD790\uD798\uD799\uD79B\uD79D\uFFFD".split("");
      for (j = 0; j != D[200].length; ++j)
        if (D[200][j].charCodeAt(0) !== 65533) {
          e[D[200][j]] = 51200 + j;
          d[51200 + j] = D[200][j];
        }
      D[202] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4F3D\u4F73\u5047\u50F9\u52A0\u53EF\u5475\u54E5\u5609\u5AC1\u5BB6\u6687\u67B6\u67B7\u67EF\u6B4C\u73C2\u75C2\u7A3C\u82DB\u8304\u8857\u8888\u8A36\u8CC8\u8DCF\u8EFB\u8FE6\u99D5\u523B\u5374\u5404\u606A\u6164\u6BBC\u73CF\u811A\u89BA\u89D2\u95A3\u4F83\u520A\u58BE\u5978\u59E6\u5E72\u5E79\u61C7\u63C0\u6746\u67EC\u687F\u6F97\u764E\u770B\u78F5\u7A08\u7AFF\u7C21\u809D\u826E\u8271\u8AEB\u9593\u4E6B\u559D\u66F7\u6E34\u78A3\u7AED\u845B\u8910\u874E\u97A8\u52D8\u574E\u582A\u5D4C\u611F\u61BE\u6221\u6562\u67D1\u6A44\u6E1B\u7518\u75B3\u76E3\u77B0\u7D3A\u90AF\u9451\u9452\u9F95\uFFFD".split("");
      for (j = 0; j != D[202].length; ++j)
        if (D[202][j].charCodeAt(0) !== 65533) {
          e[D[202][j]] = 51712 + j;
          d[51712 + j] = D[202][j];
        }
      D[203] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5323\u5CAC\u7532\u80DB\u9240\u9598\u525B\u5808\u59DC\u5CA1\u5D17\u5EB7\u5F3A\u5F4A\u6177\u6C5F\u757A\u7586\u7CE0\u7D73\u7DB1\u7F8C\u8154\u8221\u8591\u8941\u8B1B\u92FC\u964D\u9C47\u4ECB\u4EF7\u500B\u51F1\u584F\u6137\u613E\u6168\u6539\u69EA\u6F11\u75A5\u7686\u76D6\u7B87\u82A5\u84CB\uF900\u93A7\u958B\u5580\u5BA2\u5751\uF901\u7CB3\u7FB9\u91B5\u5028\u53BB\u5C45\u5DE8\u62D2\u636E\u64DA\u64E7\u6E20\u70AC\u795B\u8DDD\u8E1E\uF902\u907D\u9245\u92F8\u4E7E\u4EF6\u5065\u5DFE\u5EFA\u6106\u6957\u8171\u8654\u8E47\u9375\u9A2B\u4E5E\u5091\u6770\u6840\u5109\u528D\u5292\u6AA2\uFFFD".split("");
      for (j = 0; j != D[203].length; ++j)
        if (D[203][j].charCodeAt(0) !== 65533) {
          e[D[203][j]] = 51968 + j;
          d[51968 + j] = D[203][j];
        }
      D[204] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u77BC\u9210\u9ED4\u52AB\u602F\u8FF2\u5048\u61A9\u63ED\u64CA\u683C\u6A84\u6FC0\u8188\u89A1\u9694\u5805\u727D\u72AC\u7504\u7D79\u7E6D\u80A9\u898B\u8B74\u9063\u9D51\u6289\u6C7A\u6F54\u7D50\u7F3A\u8A23\u517C\u614A\u7B9D\u8B19\u9257\u938C\u4EAC\u4FD3\u501E\u50BE\u5106\u52C1\u52CD\u537F\u5770\u5883\u5E9A\u5F91\u6176\u61AC\u64CE\u656C\u666F\u66BB\u66F4\u6897\u6D87\u7085\u70F1\u749F\u74A5\u74CA\u75D9\u786C\u78EC\u7ADF\u7AF6\u7D45\u7D93\u8015\u803F\u811B\u8396\u8B66\u8F15\u9015\u93E1\u9803\u9838\u9A5A\u9BE8\u4FC2\u5553\u583A\u5951\u5B63\u5C46\u60B8\u6212\u6842\u68B0\uFFFD".split("");
      for (j = 0; j != D[204].length; ++j)
        if (D[204][j].charCodeAt(0) !== 65533) {
          e[D[204][j]] = 52224 + j;
          d[52224 + j] = D[204][j];
        }
      D[205] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u68E8\u6EAA\u754C\u7678\u78CE\u7A3D\u7CFB\u7E6B\u7E7C\u8A08\u8AA1\u8C3F\u968E\u9DC4\u53E4\u53E9\u544A\u5471\u56FA\u59D1\u5B64\u5C3B\u5EAB\u62F7\u6537\u6545\u6572\u66A0\u67AF\u69C1\u6CBD\u75FC\u7690\u777E\u7A3F\u7F94\u8003\u80A1\u818F\u82E6\u82FD\u83F0\u85C1\u8831\u88B4\u8AA5\uF903\u8F9C\u932E\u96C7\u9867\u9AD8\u9F13\u54ED\u659B\u66F2\u688F\u7A40\u8C37\u9D60\u56F0\u5764\u5D11\u6606\u68B1\u68CD\u6EFE\u7428\u889E\u9BE4\u6C68\uF904\u9AA8\u4F9B\u516C\u5171\u529F\u5B54\u5DE5\u6050\u606D\u62F1\u63A7\u653B\u73D9\u7A7A\u86A3\u8CA2\u978F\u4E32\u5BE1\u6208\u679C\u74DC\uFFFD".split("");
      for (j = 0; j != D[205].length; ++j)
        if (D[205][j].charCodeAt(0) !== 65533) {
          e[D[205][j]] = 52480 + j;
          d[52480 + j] = D[205][j];
        }
      D[206] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u79D1\u83D3\u8A87\u8AB2\u8DE8\u904E\u934B\u9846\u5ED3\u69E8\u85FF\u90ED\uF905\u51A0\u5B98\u5BEC\u6163\u68FA\u6B3E\u704C\u742F\u74D8\u7BA1\u7F50\u83C5\u89C0\u8CAB\u95DC\u9928\u522E\u605D\u62EC\u9002\u4F8A\u5149\u5321\u58D9\u5EE3\u66E0\u6D38\u709A\u72C2\u73D6\u7B50\u80F1\u945B\u5366\u639B\u7F6B\u4E56\u5080\u584A\u58DE\u602A\u6127\u62D0\u69D0\u9B41\u5B8F\u7D18\u80B1\u8F5F\u4EA4\u50D1\u54AC\u55AC\u5B0C\u5DA0\u5DE7\u652A\u654E\u6821\u6A4B\u72E1\u768E\u77EF\u7D5E\u7FF9\u81A0\u854E\u86DF\u8F03\u8F4E\u90CA\u9903\u9A55\u9BAB\u4E18\u4E45\u4E5D\u4EC7\u4FF1\u5177\u52FE\uFFFD".split("");
      for (j = 0; j != D[206].length; ++j)
        if (D[206][j].charCodeAt(0) !== 65533) {
          e[D[206][j]] = 52736 + j;
          d[52736 + j] = D[206][j];
        }
      D[207] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5340\u53E3\u53E5\u548E\u5614\u5775\u57A2\u5BC7\u5D87\u5ED0\u61FC\u62D8\u6551\u67B8\u67E9\u69CB\u6B50\u6BC6\u6BEC\u6C42\u6E9D\u7078\u72D7\u7396\u7403\u77BF\u77E9\u7A76\u7D7F\u8009\u81FC\u8205\u820A\u82DF\u8862\u8B33\u8CFC\u8EC0\u9011\u90B1\u9264\u92B6\u99D2\u9A45\u9CE9\u9DD7\u9F9C\u570B\u5C40\u83CA\u97A0\u97AB\u9EB4\u541B\u7A98\u7FA4\u88D9\u8ECD\u90E1\u5800\u5C48\u6398\u7A9F\u5BAE\u5F13\u7A79\u7AAE\u828E\u8EAC\u5026\u5238\u52F8\u5377\u5708\u62F3\u6372\u6B0A\u6DC3\u7737\u53A5\u7357\u8568\u8E76\u95D5\u673A\u6AC3\u6F70\u8A6D\u8ECC\u994B\uF906\u6677\u6B78\u8CB4\uFFFD".split("");
      for (j = 0; j != D[207].length; ++j)
        if (D[207][j].charCodeAt(0) !== 65533) {
          e[D[207][j]] = 52992 + j;
          d[52992 + j] = D[207][j];
        }
      D[208] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9B3C\uF907\u53EB\u572D\u594E\u63C6\u69FB\u73EA\u7845\u7ABA\u7AC5\u7CFE\u8475\u898F\u8D73\u9035\u95A8\u52FB\u5747\u7547\u7B60\u83CC\u921E\uF908\u6A58\u514B\u524B\u5287\u621F\u68D8\u6975\u9699\u50C5\u52A4\u52E4\u61C3\u65A4\u6839\u69FF\u747E\u7B4B\u82B9\u83EB\u89B2\u8B39\u8FD1\u9949\uF909\u4ECA\u5997\u64D2\u6611\u6A8E\u7434\u7981\u79BD\u82A9\u887E\u887F\u895F\uF90A\u9326\u4F0B\u53CA\u6025\u6271\u6C72\u7D1A\u7D66\u4E98\u5162\u77DC\u80AF\u4F01\u4F0E\u5176\u5180\u55DC\u5668\u573B\u57FA\u57FC\u5914\u5947\u5993\u5BC4\u5C90\u5D0E\u5DF1\u5E7E\u5FCC\u6280\u65D7\u65E3\uFFFD".split("");
      for (j = 0; j != D[208].length; ++j)
        if (D[208][j].charCodeAt(0) !== 65533) {
          e[D[208][j]] = 53248 + j;
          d[53248 + j] = D[208][j];
        }
      D[209] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u671E\u671F\u675E\u68CB\u68C4\u6A5F\u6B3A\u6C23\u6C7D\u6C82\u6DC7\u7398\u7426\u742A\u7482\u74A3\u7578\u757F\u7881\u78EF\u7941\u7947\u7948\u797A\u7B95\u7D00\u7DBA\u7F88\u8006\u802D\u808C\u8A18\u8B4F\u8C48\u8D77\u9321\u9324\u98E2\u9951\u9A0E\u9A0F\u9A65\u9E92\u7DCA\u4F76\u5409\u62EE\u6854\u91D1\u55AB\u513A\uF90B\uF90C\u5A1C\u61E6\uF90D\u62CF\u62FF\uF90E\uF90F\uF910\uF911\uF912\uF913\u90A3\uF914\uF915\uF916\uF917\uF918\u8AFE\uF919\uF91A\uF91B\uF91C\u6696\uF91D\u7156\uF91E\uF91F\u96E3\uF920\u634F\u637A\u5357\uF921\u678F\u6960\u6E73\uF922\u7537\uF923\uF924\uF925\uFFFD".split("");
      for (j = 0; j != D[209].length; ++j)
        if (D[209][j].charCodeAt(0) !== 65533) {
          e[D[209][j]] = 53504 + j;
          d[53504 + j] = D[209][j];
        }
      D[210] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7D0D\uF926\uF927\u8872\u56CA\u5A18\uF928\uF929\uF92A\uF92B\uF92C\u4E43\uF92D\u5167\u5948\u67F0\u8010\uF92E\u5973\u5E74\u649A\u79CA\u5FF5\u606C\u62C8\u637B\u5BE7\u5BD7\u52AA\uF92F\u5974\u5F29\u6012\uF930\uF931\uF932\u7459\uF933\uF934\uF935\uF936\uF937\uF938\u99D1\uF939\uF93A\uF93B\uF93C\uF93D\uF93E\uF93F\uF940\uF941\uF942\uF943\u6FC3\uF944\uF945\u81BF\u8FB2\u60F1\uF946\uF947\u8166\uF948\uF949\u5C3F\uF94A\uF94B\uF94C\uF94D\uF94E\uF94F\uF950\uF951\u5AE9\u8A25\u677B\u7D10\uF952\uF953\uF954\uF955\uF956\uF957\u80FD\uF958\uF959\u5C3C\u6CE5\u533F\u6EBA\u591A\u8336\uFFFD".split("");
      for (j = 0; j != D[210].length; ++j)
        if (D[210][j].charCodeAt(0) !== 65533) {
          e[D[210][j]] = 53760 + j;
          d[53760 + j] = D[210][j];
        }
      D[211] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E39\u4EB6\u4F46\u55AE\u5718\u58C7\u5F56\u65B7\u65E6\u6A80\u6BB5\u6E4D\u77ED\u7AEF\u7C1E\u7DDE\u86CB\u8892\u9132\u935B\u64BB\u6FBE\u737A\u75B8\u9054\u5556\u574D\u61BA\u64D4\u66C7\u6DE1\u6E5B\u6F6D\u6FB9\u75F0\u8043\u81BD\u8541\u8983\u8AC7\u8B5A\u931F\u6C93\u7553\u7B54\u8E0F\u905D\u5510\u5802\u5858\u5E62\u6207\u649E\u68E0\u7576\u7CD6\u87B3\u9EE8\u4EE3\u5788\u576E\u5927\u5C0D\u5CB1\u5E36\u5F85\u6234\u64E1\u73B3\u81FA\u888B\u8CB8\u968A\u9EDB\u5B85\u5FB7\u60B3\u5012\u5200\u5230\u5716\u5835\u5857\u5C0E\u5C60\u5CF6\u5D8B\u5EA6\u5F92\u60BC\u6311\u6389\u6417\u6843\uFFFD".split("");
      for (j = 0; j != D[211].length; ++j)
        if (D[211][j].charCodeAt(0) !== 65533) {
          e[D[211][j]] = 54016 + j;
          d[54016 + j] = D[211][j];
        }
      D[212] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u68F9\u6AC2\u6DD8\u6E21\u6ED4\u6FE4\u71FE\u76DC\u7779\u79B1\u7A3B\u8404\u89A9\u8CED\u8DF3\u8E48\u9003\u9014\u9053\u90FD\u934D\u9676\u97DC\u6BD2\u7006\u7258\u72A2\u7368\u7763\u79BF\u7BE4\u7E9B\u8B80\u58A9\u60C7\u6566\u65FD\u66BE\u6C8C\u711E\u71C9\u8C5A\u9813\u4E6D\u7A81\u4EDD\u51AC\u51CD\u52D5\u540C\u61A7\u6771\u6850\u68DF\u6D1E\u6F7C\u75BC\u77B3\u7AE5\u80F4\u8463\u9285\u515C\u6597\u675C\u6793\u75D8\u7AC7\u8373\uF95A\u8C46\u9017\u982D\u5C6F\u81C0\u829A\u9041\u906F\u920D\u5F97\u5D9D\u6A59\u71C8\u767B\u7B49\u85E4\u8B04\u9127\u9A30\u5587\u61F6\uF95B\u7669\u7F85\uFFFD".split("");
      for (j = 0; j != D[212].length; ++j)
        if (D[212][j].charCodeAt(0) !== 65533) {
          e[D[212][j]] = 54272 + j;
          d[54272 + j] = D[212][j];
        }
      D[213] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u863F\u87BA\u88F8\u908F\uF95C\u6D1B\u70D9\u73DE\u7D61\u843D\uF95D\u916A\u99F1\uF95E\u4E82\u5375\u6B04\u6B12\u703E\u721B\u862D\u9E1E\u524C\u8FA3\u5D50\u64E5\u652C\u6B16\u6FEB\u7C43\u7E9C\u85CD\u8964\u89BD\u62C9\u81D8\u881F\u5ECA\u6717\u6D6A\u72FC\u7405\u746F\u8782\u90DE\u4F86\u5D0D\u5FA0\u840A\u51B7\u63A0\u7565\u4EAE\u5006\u5169\u51C9\u6881\u6A11\u7CAE\u7CB1\u7CE7\u826F\u8AD2\u8F1B\u91CF\u4FB6\u5137\u52F5\u5442\u5EEC\u616E\u623E\u65C5\u6ADA\u6FFE\u792A\u85DC\u8823\u95AD\u9A62\u9A6A\u9E97\u9ECE\u529B\u66C6\u6B77\u701D\u792B\u8F62\u9742\u6190\u6200\u6523\u6F23\uFFFD".split("");
      for (j = 0; j != D[213].length; ++j)
        if (D[213][j].charCodeAt(0) !== 65533) {
          e[D[213][j]] = 54528 + j;
          d[54528 + j] = D[213][j];
        }
      D[214] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7149\u7489\u7DF4\u806F\u84EE\u8F26\u9023\u934A\u51BD\u5217\u52A3\u6D0C\u70C8\u88C2\u5EC9\u6582\u6BAE\u6FC2\u7C3E\u7375\u4EE4\u4F36\u56F9\uF95F\u5CBA\u5DBA\u601C\u73B2\u7B2D\u7F9A\u7FCE\u8046\u901E\u9234\u96F6\u9748\u9818\u9F61\u4F8B\u6FA7\u79AE\u91B4\u96B7\u52DE\uF960\u6488\u64C4\u6AD3\u6F5E\u7018\u7210\u76E7\u8001\u8606\u865C\u8DEF\u8F05\u9732\u9B6F\u9DFA\u9E75\u788C\u797F\u7DA0\u83C9\u9304\u9E7F\u9E93\u8AD6\u58DF\u5F04\u6727\u7027\u74CF\u7C60\u807E\u5121\u7028\u7262\u78CA\u8CC2\u8CDA\u8CF4\u96F7\u4E86\u50DA\u5BEE\u5ED6\u6599\u71CE\u7642\u77AD\u804A\u84FC\uFFFD".split("");
      for (j = 0; j != D[214].length; ++j)
        if (D[214][j].charCodeAt(0) !== 65533) {
          e[D[214][j]] = 54784 + j;
          d[54784 + j] = D[214][j];
        }
      D[215] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u907C\u9B27\u9F8D\u58D8\u5A41\u5C62\u6A13\u6DDA\u6F0F\u763B\u7D2F\u7E37\u851E\u8938\u93E4\u964B\u5289\u65D2\u67F3\u69B4\u6D41\u6E9C\u700F\u7409\u7460\u7559\u7624\u786B\u8B2C\u985E\u516D\u622E\u9678\u4F96\u502B\u5D19\u6DEA\u7DB8\u8F2A\u5F8B\u6144\u6817\uF961\u9686\u52D2\u808B\u51DC\u51CC\u695E\u7A1C\u7DBE\u83F1\u9675\u4FDA\u5229\u5398\u540F\u550E\u5C65\u60A7\u674E\u68A8\u6D6C\u7281\u72F8\u7406\u7483\uF962\u75E2\u7C6C\u7F79\u7FB8\u8389\u88CF\u88E1\u91CC\u91D0\u96E2\u9BC9\u541D\u6F7E\u71D0\u7498\u85FA\u8EAA\u96A3\u9C57\u9E9F\u6797\u6DCB\u7433\u81E8\u9716\u782C\uFFFD".split("");
      for (j = 0; j != D[215].length; ++j)
        if (D[215][j].charCodeAt(0) !== 65533) {
          e[D[215][j]] = 55040 + j;
          d[55040 + j] = D[215][j];
        }
      D[216] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7ACB\u7B20\u7C92\u6469\u746A\u75F2\u78BC\u78E8\u99AC\u9B54\u9EBB\u5BDE\u5E55\u6F20\u819C\u83AB\u9088\u4E07\u534D\u5A29\u5DD2\u5F4E\u6162\u633D\u6669\u66FC\u6EFF\u6F2B\u7063\u779E\u842C\u8513\u883B\u8F13\u9945\u9C3B\u551C\u62B9\u672B\u6CAB\u8309\u896A\u977A\u4EA1\u5984\u5FD8\u5FD9\u671B\u7DB2\u7F54\u8292\u832B\u83BD\u8F1E\u9099\u57CB\u59B9\u5A92\u5BD0\u6627\u679A\u6885\u6BCF\u7164\u7F75\u8CB7\u8CE3\u9081\u9B45\u8108\u8C8A\u964C\u9A40\u9EA5\u5B5F\u6C13\u731B\u76F2\u76DF\u840C\u51AA\u8993\u514D\u5195\u52C9\u68C9\u6C94\u7704\u7720\u7DBF\u7DEC\u9762\u9EB5\u6EC5\uFFFD".split("");
      for (j = 0; j != D[216].length; ++j)
        if (D[216][j].charCodeAt(0) !== 65533) {
          e[D[216][j]] = 55296 + j;
          d[55296 + j] = D[216][j];
        }
      D[217] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8511\u51A5\u540D\u547D\u660E\u669D\u6927\u6E9F\u76BF\u7791\u8317\u84C2\u879F\u9169\u9298\u9CF4\u8882\u4FAE\u5192\u52DF\u59C6\u5E3D\u6155\u6478\u6479\u66AE\u67D0\u6A21\u6BCD\u6BDB\u725F\u7261\u7441\u7738\u77DB\u8017\u82BC\u8305\u8B00\u8B28\u8C8C\u6728\u6C90\u7267\u76EE\u7766\u7A46\u9DA9\u6B7F\u6C92\u5922\u6726\u8499\u536F\u5893\u5999\u5EDF\u63CF\u6634\u6773\u6E3A\u732B\u7AD7\u82D7\u9328\u52D9\u5DEB\u61AE\u61CB\u620A\u62C7\u64AB\u65E0\u6959\u6B66\u6BCB\u7121\u73F7\u755D\u7E46\u821E\u8302\u856A\u8AA3\u8CBF\u9727\u9D61\u58A8\u9ED8\u5011\u520E\u543B\u554F\u6587\uFFFD".split("");
      for (j = 0; j != D[217].length; ++j)
        if (D[217][j].charCodeAt(0) !== 65533) {
          e[D[217][j]] = 55552 + j;
          d[55552 + j] = D[217][j];
        }
      D[218] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6C76\u7D0A\u7D0B\u805E\u868A\u9580\u96EF\u52FF\u6C95\u7269\u5473\u5A9A\u5C3E\u5D4B\u5F4C\u5FAE\u672A\u68B6\u6963\u6E3C\u6E44\u7709\u7C73\u7F8E\u8587\u8B0E\u8FF7\u9761\u9EF4\u5CB7\u60B6\u610D\u61AB\u654F\u65FB\u65FC\u6C11\u6CEF\u739F\u73C9\u7DE1\u9594\u5BC6\u871C\u8B10\u525D\u535A\u62CD\u640F\u64B2\u6734\u6A38\u6CCA\u73C0\u749E\u7B94\u7C95\u7E1B\u818A\u8236\u8584\u8FEB\u96F9\u99C1\u4F34\u534A\u53CD\u53DB\u62CC\u642C\u6500\u6591\u69C3\u6CEE\u6F58\u73ED\u7554\u7622\u76E4\u76FC\u78D0\u78FB\u792C\u7D46\u822C\u87E0\u8FD4\u9812\u98EF\u52C3\u62D4\u64A5\u6E24\u6F51\uFFFD".split("");
      for (j = 0; j != D[218].length; ++j)
        if (D[218][j].charCodeAt(0) !== 65533) {
          e[D[218][j]] = 55808 + j;
          d[55808 + j] = D[218][j];
        }
      D[219] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u767C\u8DCB\u91B1\u9262\u9AEE\u9B43\u5023\u508D\u574A\u59A8\u5C28\u5E47\u5F77\u623F\u653E\u65B9\u65C1\u6609\u678B\u699C\u6EC2\u78C5\u7D21\u80AA\u8180\u822B\u82B3\u84A1\u868C\u8A2A\u8B17\u90A6\u9632\u9F90\u500D\u4FF3\uF963\u57F9\u5F98\u62DC\u6392\u676F\u6E43\u7119\u76C3\u80CC\u80DA\u88F4\u88F5\u8919\u8CE0\u8F29\u914D\u966A\u4F2F\u4F70\u5E1B\u67CF\u6822\u767D\u767E\u9B44\u5E61\u6A0A\u7169\u71D4\u756A\uF964\u7E41\u8543\u85E9\u98DC\u4F10\u7B4F\u7F70\u95A5\u51E1\u5E06\u68B5\u6C3E\u6C4E\u6CDB\u72AF\u7BC4\u8303\u6CD5\u743A\u50FB\u5288\u58C1\u64D8\u6A97\u74A7\u7656\uFFFD".split("");
      for (j = 0; j != D[219].length; ++j)
        if (D[219][j].charCodeAt(0) !== 65533) {
          e[D[219][j]] = 56064 + j;
          d[56064 + j] = D[219][j];
        }
      D[220] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u78A7\u8617\u95E2\u9739\uF965\u535E\u5F01\u8B8A\u8FA8\u8FAF\u908A\u5225\u77A5\u9C49\u9F08\u4E19\u5002\u5175\u5C5B\u5E77\u661E\u663A\u67C4\u68C5\u70B3\u7501\u75C5\u79C9\u7ADD\u8F27\u9920\u9A08\u4FDD\u5821\u5831\u5BF6\u666E\u6B65\u6D11\u6E7A\u6F7D\u73E4\u752B\u83E9\u88DC\u8913\u8B5C\u8F14\u4F0F\u50D5\u5310\u535C\u5B93\u5FA9\u670D\u798F\u8179\u832F\u8514\u8907\u8986\u8F39\u8F3B\u99A5\u9C12\u672C\u4E76\u4FF8\u5949\u5C01\u5CEF\u5CF0\u6367\u68D2\u70FD\u71A2\u742B\u7E2B\u84EC\u8702\u9022\u92D2\u9CF3\u4E0D\u4ED8\u4FEF\u5085\u5256\u526F\u5426\u5490\u57E0\u592B\u5A66\uFFFD".split("");
      for (j = 0; j != D[220].length; ++j)
        if (D[220][j].charCodeAt(0) !== 65533) {
          e[D[220][j]] = 56320 + j;
          d[56320 + j] = D[220][j];
        }
      D[221] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5B5A\u5B75\u5BCC\u5E9C\uF966\u6276\u6577\u65A7\u6D6E\u6EA5\u7236\u7B26\u7C3F\u7F36\u8150\u8151\u819A\u8240\u8299\u83A9\u8A03\u8CA0\u8CE6\u8CFB\u8D74\u8DBA\u90E8\u91DC\u961C\u9644\u99D9\u9CE7\u5317\u5206\u5429\u5674\u58B3\u5954\u596E\u5FFF\u61A4\u626E\u6610\u6C7E\u711A\u76C6\u7C89\u7CDE\u7D1B\u82AC\u8CC1\u96F0\uF967\u4F5B\u5F17\u5F7F\u62C2\u5D29\u670B\u68DA\u787C\u7E43\u9D6C\u4E15\u5099\u5315\u532A\u5351\u5983\u5A62\u5E87\u60B2\u618A\u6249\u6279\u6590\u6787\u69A7\u6BD4\u6BD6\u6BD7\u6BD8\u6CB8\uF968\u7435\u75FA\u7812\u7891\u79D5\u79D8\u7C83\u7DCB\u7FE1\u80A5\uFFFD".split("");
      for (j = 0; j != D[221].length; ++j)
        if (D[221][j].charCodeAt(0) !== 65533) {
          e[D[221][j]] = 56576 + j;
          d[56576 + j] = D[221][j];
        }
      D[222] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u813E\u81C2\u83F2\u871A\u88E8\u8AB9\u8B6C\u8CBB\u9119\u975E\u98DB\u9F3B\u56AC\u5B2A\u5F6C\u658C\u6AB3\u6BAF\u6D5C\u6FF1\u7015\u725D\u73AD\u8CA7\u8CD3\u983B\u6191\u6C37\u8058\u9A01\u4E4D\u4E8B\u4E9B\u4ED5\u4F3A\u4F3C\u4F7F\u4FDF\u50FF\u53F2\u53F8\u5506\u55E3\u56DB\u58EB\u5962\u5A11\u5BEB\u5BFA\u5C04\u5DF3\u5E2B\u5F99\u601D\u6368\u659C\u65AF\u67F6\u67FB\u68AD\u6B7B\u6C99\u6CD7\u6E23\u7009\u7345\u7802\u793E\u7940\u7960\u79C1\u7BE9\u7D17\u7D72\u8086\u820D\u838E\u84D1\u86C7\u88DF\u8A50\u8A5E\u8B1D\u8CDC\u8D66\u8FAD\u90AA\u98FC\u99DF\u9E9D\u524A\uF969\u6714\uF96A\uFFFD".split("");
      for (j = 0; j != D[222].length; ++j)
        if (D[222][j].charCodeAt(0) !== 65533) {
          e[D[222][j]] = 56832 + j;
          d[56832 + j] = D[222][j];
        }
      D[223] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5098\u522A\u5C71\u6563\u6C55\u73CA\u7523\u759D\u7B97\u849C\u9178\u9730\u4E77\u6492\u6BBA\u715E\u85A9\u4E09\uF96B\u6749\u68EE\u6E17\u829F\u8518\u886B\u63F7\u6F81\u9212\u98AF\u4E0A\u50B7\u50CF\u511F\u5546\u55AA\u5617\u5B40\u5C19\u5CE0\u5E38\u5E8A\u5EA0\u5EC2\u60F3\u6851\u6A61\u6E58\u723D\u7240\u72C0\u76F8\u7965\u7BB1\u7FD4\u88F3\u89F4\u8A73\u8C61\u8CDE\u971C\u585E\u74BD\u8CFD\u55C7\uF96C\u7A61\u7D22\u8272\u7272\u751F\u7525\uF96D\u7B19\u5885\u58FB\u5DBC\u5E8F\u5EB6\u5F90\u6055\u6292\u637F\u654D\u6691\u66D9\u66F8\u6816\u68F2\u7280\u745E\u7B6E\u7D6E\u7DD6\u7F72\uFFFD".split("");
      for (j = 0; j != D[223].length; ++j)
        if (D[223][j].charCodeAt(0) !== 65533) {
          e[D[223][j]] = 57088 + j;
          d[57088 + j] = D[223][j];
        }
      D[224] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u80E5\u8212\u85AF\u897F\u8A93\u901D\u92E4\u9ECD\u9F20\u5915\u596D\u5E2D\u60DC\u6614\u6673\u6790\u6C50\u6DC5\u6F5F\u77F3\u78A9\u84C6\u91CB\u932B\u4ED9\u50CA\u5148\u5584\u5B0B\u5BA3\u6247\u657E\u65CB\u6E32\u717D\u7401\u7444\u7487\u74BF\u766C\u79AA\u7DDA\u7E55\u7FA8\u817A\u81B3\u8239\u861A\u87EC\u8A75\u8DE3\u9078\u9291\u9425\u994D\u9BAE\u5368\u5C51\u6954\u6CC4\u6D29\u6E2B\u820C\u859B\u893B\u8A2D\u8AAA\u96EA\u9F67\u5261\u66B9\u6BB2\u7E96\u87FE\u8D0D\u9583\u965D\u651D\u6D89\u71EE\uF96E\u57CE\u59D3\u5BAC\u6027\u60FA\u6210\u661F\u665F\u7329\u73F9\u76DB\u7701\u7B6C\uFFFD".split("");
      for (j = 0; j != D[224].length; ++j)
        if (D[224][j].charCodeAt(0) !== 65533) {
          e[D[224][j]] = 57344 + j;
          d[57344 + j] = D[224][j];
        }
      D[225] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8056\u8072\u8165\u8AA0\u9192\u4E16\u52E2\u6B72\u6D17\u7A05\u7B39\u7D30\uF96F\u8CB0\u53EC\u562F\u5851\u5BB5\u5C0F\u5C11\u5DE2\u6240\u6383\u6414\u662D\u68B3\u6CBC\u6D88\u6EAF\u701F\u70A4\u71D2\u7526\u758F\u758E\u7619\u7B11\u7BE0\u7C2B\u7D20\u7D39\u852C\u856D\u8607\u8A34\u900D\u9061\u90B5\u92B7\u97F6\u9A37\u4FD7\u5C6C\u675F\u6D91\u7C9F\u7E8C\u8B16\u8D16\u901F\u5B6B\u5DFD\u640D\u84C0\u905C\u98E1\u7387\u5B8B\u609A\u677E\u6DDE\u8A1F\u8AA6\u9001\u980C\u5237\uF970\u7051\u788E\u9396\u8870\u91D7\u4FEE\u53D7\u55FD\u56DA\u5782\u58FD\u5AC2\u5B88\u5CAB\u5CC0\u5E25\u6101\uFFFD".split("");
      for (j = 0; j != D[225].length; ++j)
        if (D[225][j].charCodeAt(0) !== 65533) {
          e[D[225][j]] = 57600 + j;
          d[57600 + j] = D[225][j];
        }
      D[226] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u620D\u624B\u6388\u641C\u6536\u6578\u6A39\u6B8A\u6C34\u6D19\u6F31\u71E7\u72E9\u7378\u7407\u74B2\u7626\u7761\u79C0\u7A57\u7AEA\u7CB9\u7D8F\u7DAC\u7E61\u7F9E\u8129\u8331\u8490\u84DA\u85EA\u8896\u8AB0\u8B90\u8F38\u9042\u9083\u916C\u9296\u92B9\u968B\u96A7\u96A8\u96D6\u9700\u9808\u9996\u9AD3\u9B1A\u53D4\u587E\u5919\u5B70\u5BBF\u6DD1\u6F5A\u719F\u7421\u74B9\u8085\u83FD\u5DE1\u5F87\u5FAA\u6042\u65EC\u6812\u696F\u6A53\u6B89\u6D35\u6DF3\u73E3\u76FE\u77AC\u7B4D\u7D14\u8123\u821C\u8340\u84F4\u8563\u8A62\u8AC4\u9187\u931E\u9806\u99B4\u620C\u8853\u8FF0\u9265\u5D07\u5D27\uFFFD".split("");
      for (j = 0; j != D[226].length; ++j)
        if (D[226][j].charCodeAt(0) !== 65533) {
          e[D[226][j]] = 57856 + j;
          d[57856 + j] = D[226][j];
        }
      D[227] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5D69\u745F\u819D\u8768\u6FD5\u62FE\u7FD2\u8936\u8972\u4E1E\u4E58\u50E7\u52DD\u5347\u627F\u6607\u7E69\u8805\u965E\u4F8D\u5319\u5636\u59CB\u5AA4\u5C38\u5C4E\u5C4D\u5E02\u5F11\u6043\u65BD\u662F\u6642\u67BE\u67F4\u731C\u77E2\u793A\u7FC5\u8494\u84CD\u8996\u8A66\u8A69\u8AE1\u8C55\u8C7A\u57F4\u5BD4\u5F0F\u606F\u62ED\u690D\u6B96\u6E5C\u7184\u7BD2\u8755\u8B58\u8EFE\u98DF\u98FE\u4F38\u4F81\u4FE1\u547B\u5A20\u5BB8\u613C\u65B0\u6668\u71FC\u7533\u795E\u7D33\u814E\u81E3\u8398\u85AA\u85CE\u8703\u8A0A\u8EAB\u8F9B\uF971\u8FC5\u5931\u5BA4\u5BE6\u6089\u5BE9\u5C0B\u5FC3\u6C81\uFFFD".split("");
      for (j = 0; j != D[227].length; ++j)
        if (D[227][j].charCodeAt(0) !== 65533) {
          e[D[227][j]] = 58112 + j;
          d[58112 + j] = D[227][j];
        }
      D[228] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uF972\u6DF1\u700B\u751A\u82AF\u8AF6\u4EC0\u5341\uF973\u96D9\u6C0F\u4E9E\u4FC4\u5152\u555E\u5A25\u5CE8\u6211\u7259\u82BD\u83AA\u86FE\u8859\u8A1D\u963F\u96C5\u9913\u9D09\u9D5D\u580A\u5CB3\u5DBD\u5E44\u60E1\u6115\u63E1\u6A02\u6E25\u9102\u9354\u984E\u9C10\u9F77\u5B89\u5CB8\u6309\u664F\u6848\u773C\u96C1\u978D\u9854\u9B9F\u65A1\u8B01\u8ECB\u95BC\u5535\u5CA9\u5DD6\u5EB5\u6697\u764C\u83F4\u95C7\u58D3\u62BC\u72CE\u9D28\u4EF0\u592E\u600F\u663B\u6B83\u79E7\u9D26\u5393\u54C0\u57C3\u5D16\u611B\u66D6\u6DAF\u788D\u827E\u9698\u9744\u5384\u627C\u6396\u6DB2\u7E0A\u814B\u984D\uFFFD".split("");
      for (j = 0; j != D[228].length; ++j)
        if (D[228][j].charCodeAt(0) !== 65533) {
          e[D[228][j]] = 58368 + j;
          d[58368 + j] = D[228][j];
        }
      D[229] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6AFB\u7F4C\u9DAF\u9E1A\u4E5F\u503B\u51B6\u591C\u60F9\u63F6\u6930\u723A\u8036\uF974\u91CE\u5F31\uF975\uF976\u7D04\u82E5\u846F\u84BB\u85E5\u8E8D\uF977\u4F6F\uF978\uF979\u58E4\u5B43\u6059\u63DA\u6518\u656D\u6698\uF97A\u694A\u6A23\u6D0B\u7001\u716C\u75D2\u760D\u79B3\u7A70\uF97B\u7F8A\uF97C\u8944\uF97D\u8B93\u91C0\u967D\uF97E\u990A\u5704\u5FA1\u65BC\u6F01\u7600\u79A6\u8A9E\u99AD\u9B5A\u9F6C\u5104\u61B6\u6291\u6A8D\u81C6\u5043\u5830\u5F66\u7109\u8A00\u8AFA\u5B7C\u8616\u4FFA\u513C\u56B4\u5944\u63A9\u6DF9\u5DAA\u696D\u5186\u4E88\u4F59\uF97F\uF980\uF981\u5982\uF982\uFFFD".split("");
      for (j = 0; j != D[229].length; ++j)
        if (D[229][j].charCodeAt(0) !== 65533) {
          e[D[229][j]] = 58624 + j;
          d[58624 + j] = D[229][j];
        }
      D[230] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uF983\u6B5F\u6C5D\uF984\u74B5\u7916\uF985\u8207\u8245\u8339\u8F3F\u8F5D\uF986\u9918\uF987\uF988\uF989\u4EA6\uF98A\u57DF\u5F79\u6613\uF98B\uF98C\u75AB\u7E79\u8B6F\uF98D\u9006\u9A5B\u56A5\u5827\u59F8\u5A1F\u5BB4\uF98E\u5EF6\uF98F\uF990\u6350\u633B\uF991\u693D\u6C87\u6CBF\u6D8E\u6D93\u6DF5\u6F14\uF992\u70DF\u7136\u7159\uF993\u71C3\u71D5\uF994\u784F\u786F\uF995\u7B75\u7DE3\uF996\u7E2F\uF997\u884D\u8EDF\uF998\uF999\uF99A\u925B\uF99B\u9CF6\uF99C\uF99D\uF99E\u6085\u6D85\uF99F\u71B1\uF9A0\uF9A1\u95B1\u53AD\uF9A2\uF9A3\uF9A4\u67D3\uF9A5\u708E\u7130\u7430\u8276\u82D2\uFFFD".split("");
      for (j = 0; j != D[230].length; ++j)
        if (D[230][j].charCodeAt(0) !== 65533) {
          e[D[230][j]] = 58880 + j;
          d[58880 + j] = D[230][j];
        }
      D[231] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uF9A6\u95BB\u9AE5\u9E7D\u66C4\uF9A7\u71C1\u8449\uF9A8\uF9A9\u584B\uF9AA\uF9AB\u5DB8\u5F71\uF9AC\u6620\u668E\u6979\u69AE\u6C38\u6CF3\u6E36\u6F41\u6FDA\u701B\u702F\u7150\u71DF\u7370\uF9AD\u745B\uF9AE\u74D4\u76C8\u7A4E\u7E93\uF9AF\uF9B0\u82F1\u8A60\u8FCE\uF9B1\u9348\uF9B2\u9719\uF9B3\uF9B4\u4E42\u502A\uF9B5\u5208\u53E1\u66F3\u6C6D\u6FCA\u730A\u777F\u7A62\u82AE\u85DD\u8602\uF9B6\u88D4\u8A63\u8B7D\u8C6B\uF9B7\u92B3\uF9B8\u9713\u9810\u4E94\u4F0D\u4FC9\u50B2\u5348\u543E\u5433\u55DA\u5862\u58BA\u5967\u5A1B\u5BE4\u609F\uF9B9\u61CA\u6556\u65FF\u6664\u68A7\u6C5A\u6FB3\uFFFD".split("");
      for (j = 0; j != D[231].length; ++j)
        if (D[231][j].charCodeAt(0) !== 65533) {
          e[D[231][j]] = 59136 + j;
          d[59136 + j] = D[231][j];
        }
      D[232] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u70CF\u71AC\u7352\u7B7D\u8708\u8AA4\u9C32\u9F07\u5C4B\u6C83\u7344\u7389\u923A\u6EAB\u7465\u761F\u7A69\u7E15\u860A\u5140\u58C5\u64C1\u74EE\u7515\u7670\u7FC1\u9095\u96CD\u9954\u6E26\u74E6\u7AA9\u7AAA\u81E5\u86D9\u8778\u8A1B\u5A49\u5B8C\u5B9B\u68A1\u6900\u6D63\u73A9\u7413\u742C\u7897\u7DE9\u7FEB\u8118\u8155\u839E\u8C4C\u962E\u9811\u66F0\u5F80\u65FA\u6789\u6C6A\u738B\u502D\u5A03\u6B6A\u77EE\u5916\u5D6C\u5DCD\u7325\u754F\uF9BA\uF9BB\u50E5\u51F9\u582F\u592D\u5996\u59DA\u5BE5\uF9BC\uF9BD\u5DA2\u62D7\u6416\u6493\u64FE\uF9BE\u66DC\uF9BF\u6A48\uF9C0\u71FF\u7464\uF9C1\uFFFD".split("");
      for (j = 0; j != D[232].length; ++j)
        if (D[232][j].charCodeAt(0) !== 65533) {
          e[D[232][j]] = 59392 + j;
          d[59392 + j] = D[232][j];
        }
      D[233] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A88\u7AAF\u7E47\u7E5E\u8000\u8170\uF9C2\u87EF\u8981\u8B20\u9059\uF9C3\u9080\u9952\u617E\u6B32\u6D74\u7E1F\u8925\u8FB1\u4FD1\u50AD\u5197\u52C7\u57C7\u5889\u5BB9\u5EB8\u6142\u6995\u6D8C\u6E67\u6EB6\u7194\u7462\u7528\u752C\u8073\u8338\u84C9\u8E0A\u9394\u93DE\uF9C4\u4E8E\u4F51\u5076\u512A\u53C8\u53CB\u53F3\u5B87\u5BD3\u5C24\u611A\u6182\u65F4\u725B\u7397\u7440\u76C2\u7950\u7991\u79B9\u7D06\u7FBD\u828B\u85D5\u865E\u8FC2\u9047\u90F5\u91EA\u9685\u96E8\u96E9\u52D6\u5F67\u65ED\u6631\u682F\u715C\u7A36\u90C1\u980A\u4E91\uF9C5\u6A52\u6B9E\u6F90\u7189\u8018\u82B8\u8553\uFFFD".split("");
      for (j = 0; j != D[233].length; ++j)
        if (D[233][j].charCodeAt(0) !== 65533) {
          e[D[233][j]] = 59648 + j;
          d[59648 + j] = D[233][j];
        }
      D[234] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u904B\u9695\u96F2\u97FB\u851A\u9B31\u4E90\u718A\u96C4\u5143\u539F\u54E1\u5713\u5712\u57A3\u5A9B\u5AC4\u5BC3\u6028\u613F\u63F4\u6C85\u6D39\u6E72\u6E90\u7230\u733F\u7457\u82D1\u8881\u8F45\u9060\uF9C6\u9662\u9858\u9D1B\u6708\u8D8A\u925E\u4F4D\u5049\u50DE\u5371\u570D\u59D4\u5A01\u5C09\u6170\u6690\u6E2D\u7232\u744B\u7DEF\u80C3\u840E\u8466\u853F\u875F\u885B\u8918\u8B02\u9055\u97CB\u9B4F\u4E73\u4F91\u5112\u516A\uF9C7\u552F\u55A9\u5B7A\u5BA5\u5E7C\u5E7D\u5EBE\u60A0\u60DF\u6108\u6109\u63C4\u6538\u6709\uF9C8\u67D4\u67DA\uF9C9\u6961\u6962\u6CB9\u6D27\uF9CA\u6E38\uF9CB\uFFFD".split("");
      for (j = 0; j != D[234].length; ++j)
        if (D[234][j].charCodeAt(0) !== 65533) {
          e[D[234][j]] = 59904 + j;
          d[59904 + j] = D[234][j];
        }
      D[235] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6FE1\u7336\u7337\uF9CC\u745C\u7531\uF9CD\u7652\uF9CE\uF9CF\u7DAD\u81FE\u8438\u88D5\u8A98\u8ADB\u8AED\u8E30\u8E42\u904A\u903E\u907A\u9149\u91C9\u936E\uF9D0\uF9D1\u5809\uF9D2\u6BD3\u8089\u80B2\uF9D3\uF9D4\u5141\u596B\u5C39\uF9D5\uF9D6\u6F64\u73A7\u80E4\u8D07\uF9D7\u9217\u958F\uF9D8\uF9D9\uF9DA\uF9DB\u807F\u620E\u701C\u7D68\u878D\uF9DC\u57A0\u6069\u6147\u6BB7\u8ABE\u9280\u96B1\u4E59\u541F\u6DEB\u852D\u9670\u97F3\u98EE\u63D6\u6CE3\u9091\u51DD\u61C9\u81BA\u9DF9\u4F9D\u501A\u5100\u5B9C\u610F\u61FF\u64EC\u6905\u6BC5\u7591\u77E3\u7FA9\u8264\u858F\u87FB\u8863\u8ABC\uFFFD".split("");
      for (j = 0; j != D[235].length; ++j)
        if (D[235][j].charCodeAt(0) !== 65533) {
          e[D[235][j]] = 60160 + j;
          d[60160 + j] = D[235][j];
        }
      D[236] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B70\u91AB\u4E8C\u4EE5\u4F0A\uF9DD\uF9DE\u5937\u59E8\uF9DF\u5DF2\u5F1B\u5F5B\u6021\uF9E0\uF9E1\uF9E2\uF9E3\u723E\u73E5\uF9E4\u7570\u75CD\uF9E5\u79FB\uF9E6\u800C\u8033\u8084\u82E1\u8351\uF9E7\uF9E8\u8CBD\u8CB3\u9087\uF9E9\uF9EA\u98F4\u990C\uF9EB\uF9EC\u7037\u76CA\u7FCA\u7FCC\u7FFC\u8B1A\u4EBA\u4EC1\u5203\u5370\uF9ED\u54BD\u56E0\u59FB\u5BC5\u5F15\u5FCD\u6E6E\uF9EE\uF9EF\u7D6A\u8335\uF9F0\u8693\u8A8D\uF9F1\u976D\u9777\uF9F2\uF9F3\u4E00\u4F5A\u4F7E\u58F9\u65E5\u6EA2\u9038\u93B0\u99B9\u4EFB\u58EC\u598A\u59D9\u6041\uF9F4\uF9F5\u7A14\uF9F6\u834F\u8CC3\u5165\u5344\uFFFD".split("");
      for (j = 0; j != D[236].length; ++j)
        if (D[236][j].charCodeAt(0) !== 65533) {
          e[D[236][j]] = 60416 + j;
          d[60416 + j] = D[236][j];
        }
      D[237] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uF9F7\uF9F8\uF9F9\u4ECD\u5269\u5B55\u82BF\u4ED4\u523A\u54A8\u59C9\u59FF\u5B50\u5B57\u5B5C\u6063\u6148\u6ECB\u7099\u716E\u7386\u74F7\u75B5\u78C1\u7D2B\u8005\u81EA\u8328\u8517\u85C9\u8AEE\u8CC7\u96CC\u4F5C\u52FA\u56BC\u65AB\u6628\u707C\u70B8\u7235\u7DBD\u828D\u914C\u96C0\u9D72\u5B71\u68E7\u6B98\u6F7A\u76DE\u5C91\u66AB\u6F5B\u7BB4\u7C2A\u8836\u96DC\u4E08\u4ED7\u5320\u5834\u58BB\u58EF\u596C\u5C07\u5E33\u5E84\u5F35\u638C\u66B2\u6756\u6A1F\u6AA3\u6B0C\u6F3F\u7246\uF9FA\u7350\u748B\u7AE0\u7CA7\u8178\u81DF\u81E7\u838A\u846C\u8523\u8594\u85CF\u88DD\u8D13\u91AC\u9577\uFFFD".split("");
      for (j = 0; j != D[237].length; ++j)
        if (D[237][j].charCodeAt(0) !== 65533) {
          e[D[237][j]] = 60672 + j;
          d[60672 + j] = D[237][j];
        }
      D[238] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u969C\u518D\u54C9\u5728\u5BB0\u624D\u6750\u683D\u6893\u6E3D\u6ED3\u707D\u7E21\u88C1\u8CA1\u8F09\u9F4B\u9F4E\u722D\u7B8F\u8ACD\u931A\u4F47\u4F4E\u5132\u5480\u59D0\u5E95\u62B5\u6775\u696E\u6A17\u6CAE\u6E1A\u72D9\u732A\u75BD\u7BB8\u7D35\u82E7\u83F9\u8457\u85F7\u8A5B\u8CAF\u8E87\u9019\u90B8\u96CE\u9F5F\u52E3\u540A\u5AE1\u5BC2\u6458\u6575\u6EF4\u72C4\uF9FB\u7684\u7A4D\u7B1B\u7C4D\u7E3E\u7FDF\u837B\u8B2B\u8CCA\u8D64\u8DE1\u8E5F\u8FEA\u8FF9\u9069\u93D1\u4F43\u4F7A\u50B3\u5168\u5178\u524D\u526A\u5861\u587C\u5960\u5C08\u5C55\u5EDB\u609B\u6230\u6813\u6BBF\u6C08\u6FB1\uFFFD".split("");
      for (j = 0; j != D[238].length; ++j)
        if (D[238][j].charCodeAt(0) !== 65533) {
          e[D[238][j]] = 60928 + j;
          d[60928 + j] = D[238][j];
        }
      D[239] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u714E\u7420\u7530\u7538\u7551\u7672\u7B4C\u7B8B\u7BAD\u7BC6\u7E8F\u8A6E\u8F3E\u8F49\u923F\u9293\u9322\u942B\u96FB\u985A\u986B\u991E\u5207\u622A\u6298\u6D59\u7664\u7ACA\u7BC0\u7D76\u5360\u5CBE\u5E97\u6F38\u70B9\u7C98\u9711\u9B8E\u9EDE\u63A5\u647A\u8776\u4E01\u4E95\u4EAD\u505C\u5075\u5448\u59C3\u5B9A\u5E40\u5EAD\u5EF7\u5F81\u60C5\u633A\u653F\u6574\u65CC\u6676\u6678\u67FE\u6968\u6A89\u6B63\u6C40\u6DC0\u6DE8\u6E1F\u6E5E\u701E\u70A1\u738E\u73FD\u753A\u775B\u7887\u798E\u7A0B\u7A7D\u7CBE\u7D8E\u8247\u8A02\u8AEA\u8C9E\u912D\u914A\u91D8\u9266\u92CC\u9320\u9706\u9756\uFFFD".split("");
      for (j = 0; j != D[239].length; ++j)
        if (D[239][j].charCodeAt(0) !== 65533) {
          e[D[239][j]] = 61184 + j;
          d[61184 + j] = D[239][j];
        }
      D[240] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u975C\u9802\u9F0E\u5236\u5291\u557C\u5824\u5E1D\u5F1F\u608C\u63D0\u68AF\u6FDF\u796D\u7B2C\u81CD\u85BA\u88FD\u8AF8\u8E44\u918D\u9664\u969B\u973D\u984C\u9F4A\u4FCE\u5146\u51CB\u52A9\u5632\u5F14\u5F6B\u63AA\u64CD\u65E9\u6641\u66FA\u66F9\u671D\u689D\u68D7\u69FD\u6F15\u6F6E\u7167\u71E5\u722A\u74AA\u773A\u7956\u795A\u79DF\u7A20\u7A95\u7C97\u7CDF\u7D44\u7E70\u8087\u85FB\u86A4\u8A54\u8ABF\u8D99\u8E81\u9020\u906D\u91E3\u963B\u96D5\u9CE5\u65CF\u7C07\u8DB3\u93C3\u5B58\u5C0A\u5352\u62D9\u731D\u5027\u5B97\u5F9E\u60B0\u616B\u68D5\u6DD9\u742E\u7A2E\u7D42\u7D9C\u7E31\u816B\uFFFD".split("");
      for (j = 0; j != D[240].length; ++j)
        if (D[240][j].charCodeAt(0) !== 65533) {
          e[D[240][j]] = 61440 + j;
          d[61440 + j] = D[240][j];
        }
      D[241] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8E2A\u8E35\u937E\u9418\u4F50\u5750\u5DE6\u5EA7\u632B\u7F6A\u4E3B\u4F4F\u4F8F\u505A\u59DD\u80C4\u546A\u5468\u55FE\u594F\u5B99\u5DDE\u5EDA\u665D\u6731\u67F1\u682A\u6CE8\u6D32\u6E4A\u6F8D\u70B7\u73E0\u7587\u7C4C\u7D02\u7D2C\u7DA2\u821F\u86DB\u8A3B\u8A85\u8D70\u8E8A\u8F33\u9031\u914E\u9152\u9444\u99D0\u7AF9\u7CA5\u4FCA\u5101\u51C6\u57C8\u5BEF\u5CFB\u6659\u6A3D\u6D5A\u6E96\u6FEC\u710C\u756F\u7AE3\u8822\u9021\u9075\u96CB\u99FF\u8301\u4E2D\u4EF2\u8846\u91CD\u537D\u6ADB\u696B\u6C41\u847A\u589E\u618E\u66FE\u62EF\u70DD\u7511\u75C7\u7E52\u84B8\u8B49\u8D08\u4E4B\u53EA\uFFFD".split("");
      for (j = 0; j != D[241].length; ++j)
        if (D[241][j].charCodeAt(0) !== 65533) {
          e[D[241][j]] = 61696 + j;
          d[61696 + j] = D[241][j];
        }
      D[242] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54AB\u5730\u5740\u5FD7\u6301\u6307\u646F\u652F\u65E8\u667A\u679D\u67B3\u6B62\u6C60\u6C9A\u6F2C\u77E5\u7825\u7949\u7957\u7D19\u80A2\u8102\u81F3\u829D\u82B7\u8718\u8A8C\uF9FC\u8D04\u8DBE\u9072\u76F4\u7A19\u7A37\u7E54\u8077\u5507\u55D4\u5875\u632F\u6422\u6649\u664B\u686D\u699B\u6B84\u6D25\u6EB1\u73CD\u7468\u74A1\u755B\u75B9\u76E1\u771E\u778B\u79E6\u7E09\u7E1D\u81FB\u852F\u8897\u8A3A\u8CD1\u8EEB\u8FB0\u9032\u93AD\u9663\u9673\u9707\u4F84\u53F1\u59EA\u5AC9\u5E19\u684E\u74C6\u75BE\u79E9\u7A92\u81A3\u86ED\u8CEA\u8DCC\u8FED\u659F\u6715\uF9FD\u57F7\u6F57\u7DDD\u8F2F\uFFFD".split("");
      for (j = 0; j != D[242].length; ++j)
        if (D[242][j].charCodeAt(0) !== 65533) {
          e[D[242][j]] = 61952 + j;
          d[61952 + j] = D[242][j];
        }
      D[243] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u93F6\u96C6\u5FB5\u61F2\u6F84\u4E14\u4F98\u501F\u53C9\u55DF\u5D6F\u5DEE\u6B21\u6B64\u78CB\u7B9A\uF9FE\u8E49\u8ECA\u906E\u6349\u643E\u7740\u7A84\u932F\u947F\u9F6A\u64B0\u6FAF\u71E6\u74A8\u74DA\u7AC4\u7C12\u7E82\u7CB2\u7E98\u8B9A\u8D0A\u947D\u9910\u994C\u5239\u5BDF\u64E6\u672D\u7D2E\u50ED\u53C3\u5879\u6158\u6159\u61FA\u65AC\u7AD9\u8B92\u8B96\u5009\u5021\u5275\u5531\u5A3C\u5EE0\u5F70\u6134\u655E\u660C\u6636\u66A2\u69CD\u6EC4\u6F32\u7316\u7621\u7A93\u8139\u8259\u83D6\u84BC\u50B5\u57F0\u5BC0\u5BE8\u5F69\u63A1\u7826\u7DB5\u83DC\u8521\u91C7\u91F5\u518A\u67F5\u7B56\uFFFD".split("");
      for (j = 0; j != D[243].length; ++j)
        if (D[243][j].charCodeAt(0) !== 65533) {
          e[D[243][j]] = 62208 + j;
          d[62208 + j] = D[243][j];
        }
      D[244] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8CAC\u51C4\u59BB\u60BD\u8655\u501C\uF9FF\u5254\u5C3A\u617D\u621A\u62D3\u64F2\u65A5\u6ECC\u7620\u810A\u8E60\u965F\u96BB\u4EDF\u5343\u5598\u5929\u5DDD\u64C5\u6CC9\u6DFA\u7394\u7A7F\u821B\u85A6\u8CE4\u8E10\u9077\u91E7\u95E1\u9621\u97C6\u51F8\u54F2\u5586\u5FB9\u64A4\u6F88\u7DB4\u8F1F\u8F4D\u9435\u50C9\u5C16\u6CBE\u6DFB\u751B\u77BB\u7C3D\u7C64\u8A79\u8AC2\u581E\u59BE\u5E16\u6377\u7252\u758A\u776B\u8ADC\u8CBC\u8F12\u5EF3\u6674\u6DF8\u807D\u83C1\u8ACB\u9751\u9BD6\uFA00\u5243\u66FF\u6D95\u6EEF\u7DE0\u8AE6\u902E\u905E\u9AD4\u521D\u527F\u54E8\u6194\u6284\u62DB\u68A2\uFFFD".split("");
      for (j = 0; j != D[244].length; ++j)
        if (D[244][j].charCodeAt(0) !== 65533) {
          e[D[244][j]] = 62464 + j;
          d[62464 + j] = D[244][j];
        }
      D[245] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6912\u695A\u6A35\u7092\u7126\u785D\u7901\u790E\u79D2\u7A0D\u8096\u8278\u82D5\u8349\u8549\u8C82\u8D85\u9162\u918B\u91AE\u4FC3\u56D1\u71ED\u77D7\u8700\u89F8\u5BF8\u5FD6\u6751\u90A8\u53E2\u585A\u5BF5\u60A4\u6181\u6460\u7E3D\u8070\u8525\u9283\u64AE\u50AC\u5D14\u6700\u589C\u62BD\u63A8\u690E\u6978\u6A1E\u6E6B\u76BA\u79CB\u82BB\u8429\u8ACF\u8DA8\u8FFD\u9112\u914B\u919C\u9310\u9318\u939A\u96DB\u9A36\u9C0D\u4E11\u755C\u795D\u7AFA\u7B51\u7BC9\u7E2E\u84C4\u8E59\u8E74\u8EF8\u9010\u6625\u693F\u7443\u51FA\u672E\u9EDC\u5145\u5FE0\u6C96\u87F2\u885D\u8877\u60B4\u81B5\u8403\uFFFD".split("");
      for (j = 0; j != D[245].length; ++j)
        if (D[245][j].charCodeAt(0) !== 65533) {
          e[D[245][j]] = 62720 + j;
          d[62720 + j] = D[245][j];
        }
      D[246] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8D05\u53D6\u5439\u5634\u5A36\u5C31\u708A\u7FE0\u805A\u8106\u81ED\u8DA3\u9189\u9A5F\u9DF2\u5074\u4EC4\u53A0\u60FB\u6E2C\u5C64\u4F88\u5024\u55E4\u5CD9\u5E5F\u6065\u6894\u6CBB\u6DC4\u71BE\u75D4\u75F4\u7661\u7A1A\u7A49\u7DC7\u7DFB\u7F6E\u81F4\u86A9\u8F1C\u96C9\u99B3\u9F52\u5247\u52C5\u98ED\u89AA\u4E03\u67D2\u6F06\u4FB5\u5BE2\u6795\u6C88\u6D78\u741B\u7827\u91DD\u937C\u87C4\u79E4\u7A31\u5FEB\u4ED6\u54A4\u553E\u58AE\u59A5\u60F0\u6253\u62D6\u6736\u6955\u8235\u9640\u99B1\u99DD\u502C\u5353\u5544\u577C\uFA01\u6258\uFA02\u64E2\u666B\u67DD\u6FC1\u6FEF\u7422\u7438\u8A17\uFFFD".split("");
      for (j = 0; j != D[246].length; ++j)
        if (D[246][j].charCodeAt(0) !== 65533) {
          e[D[246][j]] = 62976 + j;
          d[62976 + j] = D[246][j];
        }
      D[247] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9438\u5451\u5606\u5766\u5F48\u619A\u6B4E\u7058\u70AD\u7DBB\u8A95\u596A\u812B\u63A2\u7708\u803D\u8CAA\u5854\u642D\u69BB\u5B95\u5E11\u6E6F\uFA03\u8569\u514C\u53F0\u592A\u6020\u614B\u6B86\u6C70\u6CF0\u7B1E\u80CE\u82D4\u8DC6\u90B0\u98B1\uFA04\u64C7\u6FA4\u6491\u6504\u514E\u5410\u571F\u8A0E\u615F\u6876\uFA05\u75DB\u7B52\u7D71\u901A\u5806\u69CC\u817F\u892A\u9000\u9839\u5078\u5957\u59AC\u6295\u900F\u9B2A\u615D\u7279\u95D6\u5761\u5A46\u5DF4\u628A\u64AD\u64FA\u6777\u6CE2\u6D3E\u722C\u7436\u7834\u7F77\u82AD\u8DDB\u9817\u5224\u5742\u677F\u7248\u74E3\u8CA9\u8FA6\u9211\uFFFD".split("");
      for (j = 0; j != D[247].length; ++j)
        if (D[247][j].charCodeAt(0) !== 65533) {
          e[D[247][j]] = 63232 + j;
          d[63232 + j] = D[247][j];
        }
      D[248] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u962A\u516B\u53ED\u634C\u4F69\u5504\u6096\u6557\u6C9B\u6D7F\u724C\u72FD\u7A17\u8987\u8C9D\u5F6D\u6F8E\u70F9\u81A8\u610E\u4FBF\u504F\u6241\u7247\u7BC7\u7DE8\u7FE9\u904D\u97AD\u9A19\u8CB6\u576A\u5E73\u67B0\u840D\u8A55\u5420\u5B16\u5E63\u5EE2\u5F0A\u6583\u80BA\u853D\u9589\u965B\u4F48\u5305\u530D\u530F\u5486\u54FA\u5703\u5E03\u6016\u629B\u62B1\u6355\uFA06\u6CE1\u6D66\u75B1\u7832\u80DE\u812F\u82DE\u8461\u84B2\u888D\u8912\u900B\u92EA\u98FD\u9B91\u5E45\u66B4\u66DD\u7011\u7206\uFA07\u4FF5\u527D\u5F6A\u6153\u6753\u6A19\u6F02\u74E2\u7968\u8868\u8C79\u98C7\u98C4\u9A43\uFFFD".split("");
      for (j = 0; j != D[248].length; ++j)
        if (D[248][j].charCodeAt(0) !== 65533) {
          e[D[248][j]] = 63488 + j;
          d[63488 + j] = D[248][j];
        }
      D[249] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54C1\u7A1F\u6953\u8AF7\u8C4A\u98A8\u99AE\u5F7C\u62AB\u75B2\u76AE\u88AB\u907F\u9642\u5339\u5F3C\u5FC5\u6CCC\u73CC\u7562\u758B\u7B46\u82FE\u999D\u4E4F\u903C\u4E0B\u4F55\u53A6\u590F\u5EC8\u6630\u6CB3\u7455\u8377\u8766\u8CC0\u9050\u971E\u9C15\u58D1\u5B78\u8650\u8B14\u9DB4\u5BD2\u6068\u608D\u65F1\u6C57\u6F22\u6FA3\u701A\u7F55\u7FF0\u9591\u9592\u9650\u97D3\u5272\u8F44\u51FD\u542B\u54B8\u5563\u558A\u6ABB\u6DB5\u7DD8\u8266\u929C\u9677\u9E79\u5408\u54C8\u76D2\u86E4\u95A4\u95D4\u965C\u4EA2\u4F09\u59EE\u5AE6\u5DF7\u6052\u6297\u676D\u6841\u6C86\u6E2F\u7F38\u809B\u822A\uFFFD".split("");
      for (j = 0; j != D[249].length; ++j)
        if (D[249][j].charCodeAt(0) !== 65533) {
          e[D[249][j]] = 63744 + j;
          d[63744 + j] = D[249][j];
        }
      D[250] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFA08\uFA09\u9805\u4EA5\u5055\u54B3\u5793\u595A\u5B69\u5BB3\u61C8\u6977\u6D77\u7023\u87F9\u89E3\u8A72\u8AE7\u9082\u99ED\u9AB8\u52BE\u6838\u5016\u5E78\u674F\u8347\u884C\u4EAB\u5411\u56AE\u73E6\u9115\u97FF\u9909\u9957\u9999\u5653\u589F\u865B\u8A31\u61B2\u6AF6\u737B\u8ED2\u6B47\u96AA\u9A57\u5955\u7200\u8D6B\u9769\u4FD4\u5CF4\u5F26\u61F8\u665B\u6CEB\u70AB\u7384\u73B9\u73FE\u7729\u774D\u7D43\u7D62\u7E23\u8237\u8852\uFA0A\u8CE2\u9249\u986F\u5B51\u7A74\u8840\u9801\u5ACC\u4FE0\u5354\u593E\u5CFD\u633E\u6D79\u72F9\u8105\u8107\u83A2\u92CF\u9830\u4EA8\u5144\u5211\u578B\uFFFD".split("");
      for (j = 0; j != D[250].length; ++j)
        if (D[250][j].charCodeAt(0) !== 65533) {
          e[D[250][j]] = 64e3 + j;
          d[64e3 + j] = D[250][j];
        }
      D[251] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5F62\u6CC2\u6ECE\u7005\u7050\u70AF\u7192\u73E9\u7469\u834A\u87A2\u8861\u9008\u90A2\u93A3\u99A8\u516E\u5F57\u60E0\u6167\u66B3\u8559\u8E4A\u91AF\u978B\u4E4E\u4E92\u547C\u58D5\u58FA\u597D\u5CB5\u5F27\u6236\u6248\u660A\u6667\u6BEB\u6D69\u6DCF\u6E56\u6EF8\u6F94\u6FE0\u6FE9\u705D\u72D0\u7425\u745A\u74E0\u7693\u795C\u7CCA\u7E1E\u80E1\u82A6\u846B\u84BF\u864E\u865F\u8774\u8B77\u8C6A\u93AC\u9800\u9865\u60D1\u6216\u9177\u5A5A\u660F\u6DF7\u6E3E\u743F\u9B42\u5FFD\u60DA\u7B0F\u54C4\u5F18\u6C5E\u6CD3\u6D2A\u70D8\u7D05\u8679\u8A0C\u9D3B\u5316\u548C\u5B05\u6A3A\u706B\u7575\uFFFD".split("");
      for (j = 0; j != D[251].length; ++j)
        if (D[251][j].charCodeAt(0) !== 65533) {
          e[D[251][j]] = 64256 + j;
          d[64256 + j] = D[251][j];
        }
      D[252] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u798D\u79BE\u82B1\u83EF\u8A71\u8B41\u8CA8\u9774\uFA0B\u64F4\u652B\u78BA\u78BB\u7A6B\u4E38\u559A\u5950\u5BA6\u5E7B\u60A3\u63DB\u6B61\u6665\u6853\u6E19\u7165\u74B0\u7D08\u9084\u9A69\u9C25\u6D3B\u6ED1\u733E\u8C41\u95CA\u51F0\u5E4C\u5FA8\u604D\u60F6\u6130\u614C\u6643\u6644\u69A5\u6CC1\u6E5F\u6EC9\u6F62\u714C\u749C\u7687\u7BC1\u7C27\u8352\u8757\u9051\u968D\u9EC3\u532F\u56DE\u5EFB\u5F8A\u6062\u6094\u61F7\u6666\u6703\u6A9C\u6DEE\u6FAE\u7070\u736A\u7E6A\u81BE\u8334\u86D4\u8AA8\u8CC4\u5283\u7372\u5B96\u6A6B\u9404\u54EE\u5686\u5B5D\u6548\u6585\u66C9\u689F\u6D8D\u6DC6\uFFFD".split("");
      for (j = 0; j != D[252].length; ++j)
        if (D[252][j].charCodeAt(0) !== 65533) {
          e[D[252][j]] = 64512 + j;
          d[64512 + j] = D[252][j];
        }
      D[253] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u723B\u80B4\u9175\u9A4D\u4FAF\u5019\u539A\u540E\u543C\u5589\u55C5\u5E3F\u5F8C\u673D\u7166\u73DD\u9005\u52DB\u52F3\u5864\u58CE\u7104\u718F\u71FB\u85B0\u8A13\u6688\u85A8\u55A7\u6684\u714A\u8431\u5349\u5599\u6BC1\u5F59\u5FBD\u63EE\u6689\u7147\u8AF1\u8F1D\u9EBE\u4F11\u643A\u70CB\u7566\u8667\u6064\u8B4E\u9DF8\u5147\u51F6\u5308\u6D36\u80F8\u9ED1\u6615\u6B23\u7098\u75D5\u5403\u5C79\u7D07\u8A16\u6B20\u6B3D\u6B46\u5438\u6070\u6D3D\u7FD5\u8208\u50D6\u51DE\u559C\u566B\u56CD\u59EC\u5B09\u5E0C\u6199\u6198\u6231\u665E\u66E6\u7199\u71B9\u71BA\u72A7\u79A7\u7A00\u7FB2\u8A70\uFFFD".split("");
      for (j = 0; j != D[253].length; ++j)
        if (D[253][j].charCodeAt(0) !== 65533) {
          e[D[253][j]] = 64768 + j;
          d[64768 + j] = D[253][j];
        }
      return { "enc": e, "dec": d };
    }();
    cptable2[950] = function() {
      var d = [], e = {}, D = [], j;
      D[0] = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[0].length; ++j)
        if (D[0][j].charCodeAt(0) !== 65533) {
          e[D[0][j]] = 0 + j;
          d[0 + j] = D[0][j];
        }
      D[161] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3000\uFF0C\u3001\u3002\uFF0E\u2027\uFF1B\uFF1A\uFF1F\uFF01\uFE30\u2026\u2025\uFE50\uFE51\uFE52\xB7\uFE54\uFE55\uFE56\uFE57\uFF5C\u2013\uFE31\u2014\uFE33\u2574\uFE34\uFE4F\uFF08\uFF09\uFE35\uFE36\uFF5B\uFF5D\uFE37\uFE38\u3014\u3015\uFE39\uFE3A\u3010\u3011\uFE3B\uFE3C\u300A\u300B\uFE3D\uFE3E\u3008\u3009\uFE3F\uFE40\u300C\u300D\uFE41\uFE42\u300E\u300F\uFE43\uFE44\uFE59\uFE5A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFE5B\uFE5C\uFE5D\uFE5E\u2018\u2019\u201C\u201D\u301D\u301E\u2035\u2032\uFF03\uFF06\uFF0A\u203B\xA7\u3003\u25CB\u25CF\u25B3\u25B2\u25CE\u2606\u2605\u25C7\u25C6\u25A1\u25A0\u25BD\u25BC\u32A3\u2105\xAF\uFFE3\uFF3F\u02CD\uFE49\uFE4A\uFE4D\uFE4E\uFE4B\uFE4C\uFE5F\uFE60\uFE61\uFF0B\uFF0D\xD7\xF7\xB1\u221A\uFF1C\uFF1E\uFF1D\u2266\u2267\u2260\u221E\u2252\u2261\uFE62\uFE63\uFE64\uFE65\uFE66\uFF5E\u2229\u222A\u22A5\u2220\u221F\u22BF\u33D2\u33D1\u222B\u222E\u2235\u2234\u2640\u2642\u2295\u2299\u2191\u2193\u2190\u2192\u2196\u2197\u2199\u2198\u2225\u2223\uFF0F\uFFFD".split("");
      for (j = 0; j != D[161].length; ++j)
        if (D[161][j].charCodeAt(0) !== 65533) {
          e[D[161][j]] = 41216 + j;
          d[41216 + j] = D[161][j];
        }
      D[162] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF3C\u2215\uFE68\uFF04\uFFE5\u3012\uFFE0\uFFE1\uFF05\uFF20\u2103\u2109\uFE69\uFE6A\uFE6B\u33D5\u339C\u339D\u339E\u33CE\u33A1\u338E\u338F\u33C4\xB0\u5159\u515B\u515E\u515D\u5161\u5163\u55E7\u74E9\u7CCE\u2581\u2582\u2583\u2584\u2585\u2586\u2587\u2588\u258F\u258E\u258D\u258C\u258B\u258A\u2589\u253C\u2534\u252C\u2524\u251C\u2594\u2500\u2502\u2595\u250C\u2510\u2514\u2518\u256D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u256E\u2570\u256F\u2550\u255E\u256A\u2561\u25E2\u25E3\u25E5\u25E4\u2571\u2572\u2573\uFF10\uFF11\uFF12\uFF13\uFF14\uFF15\uFF16\uFF17\uFF18\uFF19\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\u3021\u3022\u3023\u3024\u3025\u3026\u3027\u3028\u3029\u5341\u5344\u5345\uFF21\uFF22\uFF23\uFF24\uFF25\uFF26\uFF27\uFF28\uFF29\uFF2A\uFF2B\uFF2C\uFF2D\uFF2E\uFF2F\uFF30\uFF31\uFF32\uFF33\uFF34\uFF35\uFF36\uFF37\uFF38\uFF39\uFF3A\uFF41\uFF42\uFF43\uFF44\uFF45\uFF46\uFF47\uFF48\uFF49\uFF4A\uFF4B\uFF4C\uFF4D\uFF4E\uFF4F\uFF50\uFF51\uFF52\uFF53\uFF54\uFF55\uFF56\uFFFD".split("");
      for (j = 0; j != D[162].length; ++j)
        if (D[162][j].charCodeAt(0) !== 65533) {
          e[D[162][j]] = 41472 + j;
          d[41472 + j] = D[162][j];
        }
      D[163] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF57\uFF58\uFF59\uFF5A\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\u3105\u3106\u3107\u3108\u3109\u310A\u310B\u310C\u310D\u310E\u310F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3110\u3111\u3112\u3113\u3114\u3115\u3116\u3117\u3118\u3119\u311A\u311B\u311C\u311D\u311E\u311F\u3120\u3121\u3122\u3123\u3124\u3125\u3126\u3127\u3128\u3129\u02D9\u02C9\u02CA\u02C7\u02CB\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u20AC\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[163].length; ++j)
        if (D[163][j].charCodeAt(0) !== 65533) {
          e[D[163][j]] = 41728 + j;
          d[41728 + j] = D[163][j];
        }
      D[164] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E00\u4E59\u4E01\u4E03\u4E43\u4E5D\u4E86\u4E8C\u4EBA\u513F\u5165\u516B\u51E0\u5200\u5201\u529B\u5315\u5341\u535C\u53C8\u4E09\u4E0B\u4E08\u4E0A\u4E2B\u4E38\u51E1\u4E45\u4E48\u4E5F\u4E5E\u4E8E\u4EA1\u5140\u5203\u52FA\u5343\u53C9\u53E3\u571F\u58EB\u5915\u5927\u5973\u5B50\u5B51\u5B53\u5BF8\u5C0F\u5C22\u5C38\u5C71\u5DDD\u5DE5\u5DF1\u5DF2\u5DF3\u5DFE\u5E72\u5EFE\u5F0B\u5F13\u624D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E11\u4E10\u4E0D\u4E2D\u4E30\u4E39\u4E4B\u5C39\u4E88\u4E91\u4E95\u4E92\u4E94\u4EA2\u4EC1\u4EC0\u4EC3\u4EC6\u4EC7\u4ECD\u4ECA\u4ECB\u4EC4\u5143\u5141\u5167\u516D\u516E\u516C\u5197\u51F6\u5206\u5207\u5208\u52FB\u52FE\u52FF\u5316\u5339\u5348\u5347\u5345\u535E\u5384\u53CB\u53CA\u53CD\u58EC\u5929\u592B\u592A\u592D\u5B54\u5C11\u5C24\u5C3A\u5C6F\u5DF4\u5E7B\u5EFF\u5F14\u5F15\u5FC3\u6208\u6236\u624B\u624E\u652F\u6587\u6597\u65A4\u65B9\u65E5\u66F0\u6708\u6728\u6B20\u6B62\u6B79\u6BCB\u6BD4\u6BDB\u6C0F\u6C34\u706B\u722A\u7236\u723B\u7247\u7259\u725B\u72AC\u738B\u4E19\uFFFD".split("");
      for (j = 0; j != D[164].length; ++j)
        if (D[164][j].charCodeAt(0) !== 65533) {
          e[D[164][j]] = 41984 + j;
          d[41984 + j] = D[164][j];
        }
      D[165] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E16\u4E15\u4E14\u4E18\u4E3B\u4E4D\u4E4F\u4E4E\u4EE5\u4ED8\u4ED4\u4ED5\u4ED6\u4ED7\u4EE3\u4EE4\u4ED9\u4EDE\u5145\u5144\u5189\u518A\u51AC\u51F9\u51FA\u51F8\u520A\u52A0\u529F\u5305\u5306\u5317\u531D\u4EDF\u534A\u5349\u5361\u5360\u536F\u536E\u53BB\u53EF\u53E4\u53F3\u53EC\u53EE\u53E9\u53E8\u53FC\u53F8\u53F5\u53EB\u53E6\u53EA\u53F2\u53F1\u53F0\u53E5\u53ED\u53FB\u56DB\u56DA\u5916\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u592E\u5931\u5974\u5976\u5B55\u5B83\u5C3C\u5DE8\u5DE7\u5DE6\u5E02\u5E03\u5E73\u5E7C\u5F01\u5F18\u5F17\u5FC5\u620A\u6253\u6254\u6252\u6251\u65A5\u65E6\u672E\u672C\u672A\u672B\u672D\u6B63\u6BCD\u6C11\u6C10\u6C38\u6C41\u6C40\u6C3E\u72AF\u7384\u7389\u74DC\u74E6\u7518\u751F\u7528\u7529\u7530\u7531\u7532\u7533\u758B\u767D\u76AE\u76BF\u76EE\u77DB\u77E2\u77F3\u793A\u79BE\u7A74\u7ACB\u4E1E\u4E1F\u4E52\u4E53\u4E69\u4E99\u4EA4\u4EA6\u4EA5\u4EFF\u4F09\u4F19\u4F0A\u4F15\u4F0D\u4F10\u4F11\u4F0F\u4EF2\u4EF6\u4EFB\u4EF0\u4EF3\u4EFD\u4F01\u4F0B\u5149\u5147\u5146\u5148\u5168\uFFFD".split("");
      for (j = 0; j != D[165].length; ++j)
        if (D[165][j].charCodeAt(0) !== 65533) {
          e[D[165][j]] = 42240 + j;
          d[42240 + j] = D[165][j];
        }
      D[166] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5171\u518D\u51B0\u5217\u5211\u5212\u520E\u5216\u52A3\u5308\u5321\u5320\u5370\u5371\u5409\u540F\u540C\u540A\u5410\u5401\u540B\u5404\u5411\u540D\u5408\u5403\u540E\u5406\u5412\u56E0\u56DE\u56DD\u5733\u5730\u5728\u572D\u572C\u572F\u5729\u5919\u591A\u5937\u5938\u5984\u5978\u5983\u597D\u5979\u5982\u5981\u5B57\u5B58\u5B87\u5B88\u5B85\u5B89\u5BFA\u5C16\u5C79\u5DDE\u5E06\u5E76\u5E74\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5F0F\u5F1B\u5FD9\u5FD6\u620E\u620C\u620D\u6210\u6263\u625B\u6258\u6536\u65E9\u65E8\u65EC\u65ED\u66F2\u66F3\u6709\u673D\u6734\u6731\u6735\u6B21\u6B64\u6B7B\u6C16\u6C5D\u6C57\u6C59\u6C5F\u6C60\u6C50\u6C55\u6C61\u6C5B\u6C4D\u6C4E\u7070\u725F\u725D\u767E\u7AF9\u7C73\u7CF8\u7F36\u7F8A\u7FBD\u8001\u8003\u800C\u8012\u8033\u807F\u8089\u808B\u808C\u81E3\u81EA\u81F3\u81FC\u820C\u821B\u821F\u826E\u8272\u827E\u866B\u8840\u884C\u8863\u897F\u9621\u4E32\u4EA8\u4F4D\u4F4F\u4F47\u4F57\u4F5E\u4F34\u4F5B\u4F55\u4F30\u4F50\u4F51\u4F3D\u4F3A\u4F38\u4F43\u4F54\u4F3C\u4F46\u4F63\uFFFD".split("");
      for (j = 0; j != D[166].length; ++j)
        if (D[166][j].charCodeAt(0) !== 65533) {
          e[D[166][j]] = 42496 + j;
          d[42496 + j] = D[166][j];
        }
      D[167] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4F5C\u4F60\u4F2F\u4F4E\u4F36\u4F59\u4F5D\u4F48\u4F5A\u514C\u514B\u514D\u5175\u51B6\u51B7\u5225\u5224\u5229\u522A\u5228\u52AB\u52A9\u52AA\u52AC\u5323\u5373\u5375\u541D\u542D\u541E\u543E\u5426\u544E\u5427\u5446\u5443\u5433\u5448\u5442\u541B\u5429\u544A\u5439\u543B\u5438\u542E\u5435\u5436\u5420\u543C\u5440\u5431\u542B\u541F\u542C\u56EA\u56F0\u56E4\u56EB\u574A\u5751\u5740\u574D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5747\u574E\u573E\u5750\u574F\u573B\u58EF\u593E\u599D\u5992\u59A8\u599E\u59A3\u5999\u5996\u598D\u59A4\u5993\u598A\u59A5\u5B5D\u5B5C\u5B5A\u5B5B\u5B8C\u5B8B\u5B8F\u5C2C\u5C40\u5C41\u5C3F\u5C3E\u5C90\u5C91\u5C94\u5C8C\u5DEB\u5E0C\u5E8F\u5E87\u5E8A\u5EF7\u5F04\u5F1F\u5F64\u5F62\u5F77\u5F79\u5FD8\u5FCC\u5FD7\u5FCD\u5FF1\u5FEB\u5FF8\u5FEA\u6212\u6211\u6284\u6297\u6296\u6280\u6276\u6289\u626D\u628A\u627C\u627E\u6279\u6273\u6292\u626F\u6298\u626E\u6295\u6293\u6291\u6286\u6539\u653B\u6538\u65F1\u66F4\u675F\u674E\u674F\u6750\u6751\u675C\u6756\u675E\u6749\u6746\u6760\uFFFD".split("");
      for (j = 0; j != D[167].length; ++j)
        if (D[167][j].charCodeAt(0) !== 65533) {
          e[D[167][j]] = 42752 + j;
          d[42752 + j] = D[167][j];
        }
      D[168] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6753\u6757\u6B65\u6BCF\u6C42\u6C5E\u6C99\u6C81\u6C88\u6C89\u6C85\u6C9B\u6C6A\u6C7A\u6C90\u6C70\u6C8C\u6C68\u6C96\u6C92\u6C7D\u6C83\u6C72\u6C7E\u6C74\u6C86\u6C76\u6C8D\u6C94\u6C98\u6C82\u7076\u707C\u707D\u7078\u7262\u7261\u7260\u72C4\u72C2\u7396\u752C\u752B\u7537\u7538\u7682\u76EF\u77E3\u79C1\u79C0\u79BF\u7A76\u7CFB\u7F55\u8096\u8093\u809D\u8098\u809B\u809A\u80B2\u826F\u8292\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u828B\u828D\u898B\u89D2\u8A00\u8C37\u8C46\u8C55\u8C9D\u8D64\u8D70\u8DB3\u8EAB\u8ECA\u8F9B\u8FB0\u8FC2\u8FC6\u8FC5\u8FC4\u5DE1\u9091\u90A2\u90AA\u90A6\u90A3\u9149\u91C6\u91CC\u9632\u962E\u9631\u962A\u962C\u4E26\u4E56\u4E73\u4E8B\u4E9B\u4E9E\u4EAB\u4EAC\u4F6F\u4F9D\u4F8D\u4F73\u4F7F\u4F6C\u4F9B\u4F8B\u4F86\u4F83\u4F70\u4F75\u4F88\u4F69\u4F7B\u4F96\u4F7E\u4F8F\u4F91\u4F7A\u5154\u5152\u5155\u5169\u5177\u5176\u5178\u51BD\u51FD\u523B\u5238\u5237\u523A\u5230\u522E\u5236\u5241\u52BE\u52BB\u5352\u5354\u5353\u5351\u5366\u5377\u5378\u5379\u53D6\u53D4\u53D7\u5473\u5475\uFFFD".split("");
      for (j = 0; j != D[168].length; ++j)
        if (D[168][j].charCodeAt(0) !== 65533) {
          e[D[168][j]] = 43008 + j;
          d[43008 + j] = D[168][j];
        }
      D[169] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5496\u5478\u5495\u5480\u547B\u5477\u5484\u5492\u5486\u547C\u5490\u5471\u5476\u548C\u549A\u5462\u5468\u548B\u547D\u548E\u56FA\u5783\u5777\u576A\u5769\u5761\u5766\u5764\u577C\u591C\u5949\u5947\u5948\u5944\u5954\u59BE\u59BB\u59D4\u59B9\u59AE\u59D1\u59C6\u59D0\u59CD\u59CB\u59D3\u59CA\u59AF\u59B3\u59D2\u59C5\u5B5F\u5B64\u5B63\u5B97\u5B9A\u5B98\u5B9C\u5B99\u5B9B\u5C1A\u5C48\u5C45\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5C46\u5CB7\u5CA1\u5CB8\u5CA9\u5CAB\u5CB1\u5CB3\u5E18\u5E1A\u5E16\u5E15\u5E1B\u5E11\u5E78\u5E9A\u5E97\u5E9C\u5E95\u5E96\u5EF6\u5F26\u5F27\u5F29\u5F80\u5F81\u5F7F\u5F7C\u5FDD\u5FE0\u5FFD\u5FF5\u5FFF\u600F\u6014\u602F\u6035\u6016\u602A\u6015\u6021\u6027\u6029\u602B\u601B\u6216\u6215\u623F\u623E\u6240\u627F\u62C9\u62CC\u62C4\u62BF\u62C2\u62B9\u62D2\u62DB\u62AB\u62D3\u62D4\u62CB\u62C8\u62A8\u62BD\u62BC\u62D0\u62D9\u62C7\u62CD\u62B5\u62DA\u62B1\u62D8\u62D6\u62D7\u62C6\u62AC\u62CE\u653E\u65A7\u65BC\u65FA\u6614\u6613\u660C\u6606\u6602\u660E\u6600\u660F\u6615\u660A\uFFFD".split("");
      for (j = 0; j != D[169].length; ++j)
        if (D[169][j].charCodeAt(0) !== 65533) {
          e[D[169][j]] = 43264 + j;
          d[43264 + j] = D[169][j];
        }
      D[170] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6607\u670D\u670B\u676D\u678B\u6795\u6771\u679C\u6773\u6777\u6787\u679D\u6797\u676F\u6770\u677F\u6789\u677E\u6790\u6775\u679A\u6793\u677C\u676A\u6772\u6B23\u6B66\u6B67\u6B7F\u6C13\u6C1B\u6CE3\u6CE8\u6CF3\u6CB1\u6CCC\u6CE5\u6CB3\u6CBD\u6CBE\u6CBC\u6CE2\u6CAB\u6CD5\u6CD3\u6CB8\u6CC4\u6CB9\u6CC1\u6CAE\u6CD7\u6CC5\u6CF1\u6CBF\u6CBB\u6CE1\u6CDB\u6CCA\u6CAC\u6CEF\u6CDC\u6CD6\u6CE0\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7095\u708E\u7092\u708A\u7099\u722C\u722D\u7238\u7248\u7267\u7269\u72C0\u72CE\u72D9\u72D7\u72D0\u73A9\u73A8\u739F\u73AB\u73A5\u753D\u759D\u7599\u759A\u7684\u76C2\u76F2\u76F4\u77E5\u77FD\u793E\u7940\u7941\u79C9\u79C8\u7A7A\u7A79\u7AFA\u7CFE\u7F54\u7F8C\u7F8B\u8005\u80BA\u80A5\u80A2\u80B1\u80A1\u80AB\u80A9\u80B4\u80AA\u80AF\u81E5\u81FE\u820D\u82B3\u829D\u8299\u82AD\u82BD\u829F\u82B9\u82B1\u82AC\u82A5\u82AF\u82B8\u82A3\u82B0\u82BE\u82B7\u864E\u8671\u521D\u8868\u8ECB\u8FCE\u8FD4\u8FD1\u90B5\u90B8\u90B1\u90B6\u91C7\u91D1\u9577\u9580\u961C\u9640\u963F\u963B\u9644\uFFFD".split("");
      for (j = 0; j != D[170].length; ++j)
        if (D[170][j].charCodeAt(0) !== 65533) {
          e[D[170][j]] = 43520 + j;
          d[43520 + j] = D[170][j];
        }
      D[171] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9642\u96B9\u96E8\u9752\u975E\u4E9F\u4EAD\u4EAE\u4FE1\u4FB5\u4FAF\u4FBF\u4FE0\u4FD1\u4FCF\u4FDD\u4FC3\u4FB6\u4FD8\u4FDF\u4FCA\u4FD7\u4FAE\u4FD0\u4FC4\u4FC2\u4FDA\u4FCE\u4FDE\u4FB7\u5157\u5192\u5191\u51A0\u524E\u5243\u524A\u524D\u524C\u524B\u5247\u52C7\u52C9\u52C3\u52C1\u530D\u5357\u537B\u539A\u53DB\u54AC\u54C0\u54A8\u54CE\u54C9\u54B8\u54A6\u54B3\u54C7\u54C2\u54BD\u54AA\u54C1\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54C4\u54C8\u54AF\u54AB\u54B1\u54BB\u54A9\u54A7\u54BF\u56FF\u5782\u578B\u57A0\u57A3\u57A2\u57CE\u57AE\u5793\u5955\u5951\u594F\u594E\u5950\u59DC\u59D8\u59FF\u59E3\u59E8\u5A03\u59E5\u59EA\u59DA\u59E6\u5A01\u59FB\u5B69\u5BA3\u5BA6\u5BA4\u5BA2\u5BA5\u5C01\u5C4E\u5C4F\u5C4D\u5C4B\u5CD9\u5CD2\u5DF7\u5E1D\u5E25\u5E1F\u5E7D\u5EA0\u5EA6\u5EFA\u5F08\u5F2D\u5F65\u5F88\u5F85\u5F8A\u5F8B\u5F87\u5F8C\u5F89\u6012\u601D\u6020\u6025\u600E\u6028\u604D\u6070\u6068\u6062\u6046\u6043\u606C\u606B\u606A\u6064\u6241\u62DC\u6316\u6309\u62FC\u62ED\u6301\u62EE\u62FD\u6307\u62F1\u62F7\uFFFD".split("");
      for (j = 0; j != D[171].length; ++j)
        if (D[171][j].charCodeAt(0) !== 65533) {
          e[D[171][j]] = 43776 + j;
          d[43776 + j] = D[171][j];
        }
      D[172] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u62EF\u62EC\u62FE\u62F4\u6311\u6302\u653F\u6545\u65AB\u65BD\u65E2\u6625\u662D\u6620\u6627\u662F\u661F\u6628\u6631\u6624\u66F7\u67FF\u67D3\u67F1\u67D4\u67D0\u67EC\u67B6\u67AF\u67F5\u67E9\u67EF\u67C4\u67D1\u67B4\u67DA\u67E5\u67B8\u67CF\u67DE\u67F3\u67B0\u67D9\u67E2\u67DD\u67D2\u6B6A\u6B83\u6B86\u6BB5\u6BD2\u6BD7\u6C1F\u6CC9\u6D0B\u6D32\u6D2A\u6D41\u6D25\u6D0C\u6D31\u6D1E\u6D17\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D3B\u6D3D\u6D3E\u6D36\u6D1B\u6CF5\u6D39\u6D27\u6D38\u6D29\u6D2E\u6D35\u6D0E\u6D2B\u70AB\u70BA\u70B3\u70AC\u70AF\u70AD\u70B8\u70AE\u70A4\u7230\u7272\u726F\u7274\u72E9\u72E0\u72E1\u73B7\u73CA\u73BB\u73B2\u73CD\u73C0\u73B3\u751A\u752D\u754F\u754C\u754E\u754B\u75AB\u75A4\u75A5\u75A2\u75A3\u7678\u7686\u7687\u7688\u76C8\u76C6\u76C3\u76C5\u7701\u76F9\u76F8\u7709\u770B\u76FE\u76FC\u7707\u77DC\u7802\u7814\u780C\u780D\u7946\u7949\u7948\u7947\u79B9\u79BA\u79D1\u79D2\u79CB\u7A7F\u7A81\u7AFF\u7AFD\u7C7D\u7D02\u7D05\u7D00\u7D09\u7D07\u7D04\u7D06\u7F38\u7F8E\u7FBF\u8004\uFFFD".split("");
      for (j = 0; j != D[172].length; ++j)
        if (D[172][j].charCodeAt(0) !== 65533) {
          e[D[172][j]] = 44032 + j;
          d[44032 + j] = D[172][j];
        }
      D[173] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8010\u800D\u8011\u8036\u80D6\u80E5\u80DA\u80C3\u80C4\u80CC\u80E1\u80DB\u80CE\u80DE\u80E4\u80DD\u81F4\u8222\u82E7\u8303\u8305\u82E3\u82DB\u82E6\u8304\u82E5\u8302\u8309\u82D2\u82D7\u82F1\u8301\u82DC\u82D4\u82D1\u82DE\u82D3\u82DF\u82EF\u8306\u8650\u8679\u867B\u867A\u884D\u886B\u8981\u89D4\u8A08\u8A02\u8A03\u8C9E\u8CA0\u8D74\u8D73\u8DB4\u8ECD\u8ECC\u8FF0\u8FE6\u8FE2\u8FEA\u8FE5\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8FED\u8FEB\u8FE4\u8FE8\u90CA\u90CE\u90C1\u90C3\u914B\u914A\u91CD\u9582\u9650\u964B\u964C\u964D\u9762\u9769\u97CB\u97ED\u97F3\u9801\u98A8\u98DB\u98DF\u9996\u9999\u4E58\u4EB3\u500C\u500D\u5023\u4FEF\u5026\u5025\u4FF8\u5029\u5016\u5006\u503C\u501F\u501A\u5012\u5011\u4FFA\u5000\u5014\u5028\u4FF1\u5021\u500B\u5019\u5018\u4FF3\u4FEE\u502D\u502A\u4FFE\u502B\u5009\u517C\u51A4\u51A5\u51A2\u51CD\u51CC\u51C6\u51CB\u5256\u525C\u5254\u525B\u525D\u532A\u537F\u539F\u539D\u53DF\u54E8\u5510\u5501\u5537\u54FC\u54E5\u54F2\u5506\u54FA\u5514\u54E9\u54ED\u54E1\u5509\u54EE\u54EA\uFFFD".split("");
      for (j = 0; j != D[173].length; ++j)
        if (D[173][j].charCodeAt(0) !== 65533) {
          e[D[173][j]] = 44288 + j;
          d[44288 + j] = D[173][j];
        }
      D[174] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54E6\u5527\u5507\u54FD\u550F\u5703\u5704\u57C2\u57D4\u57CB\u57C3\u5809\u590F\u5957\u5958\u595A\u5A11\u5A18\u5A1C\u5A1F\u5A1B\u5A13\u59EC\u5A20\u5A23\u5A29\u5A25\u5A0C\u5A09\u5B6B\u5C58\u5BB0\u5BB3\u5BB6\u5BB4\u5BAE\u5BB5\u5BB9\u5BB8\u5C04\u5C51\u5C55\u5C50\u5CED\u5CFD\u5CFB\u5CEA\u5CE8\u5CF0\u5CF6\u5D01\u5CF4\u5DEE\u5E2D\u5E2B\u5EAB\u5EAD\u5EA7\u5F31\u5F92\u5F91\u5F90\u6059\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6063\u6065\u6050\u6055\u606D\u6069\u606F\u6084\u609F\u609A\u608D\u6094\u608C\u6085\u6096\u6247\u62F3\u6308\u62FF\u634E\u633E\u632F\u6355\u6342\u6346\u634F\u6349\u633A\u6350\u633D\u632A\u632B\u6328\u634D\u634C\u6548\u6549\u6599\u65C1\u65C5\u6642\u6649\u664F\u6643\u6652\u664C\u6645\u6641\u66F8\u6714\u6715\u6717\u6821\u6838\u6848\u6846\u6853\u6839\u6842\u6854\u6829\u68B3\u6817\u684C\u6851\u683D\u67F4\u6850\u6840\u683C\u6843\u682A\u6845\u6813\u6818\u6841\u6B8A\u6B89\u6BB7\u6C23\u6C27\u6C28\u6C26\u6C24\u6CF0\u6D6A\u6D95\u6D88\u6D87\u6D66\u6D78\u6D77\u6D59\u6D93\uFFFD".split("");
      for (j = 0; j != D[174].length; ++j)
        if (D[174][j].charCodeAt(0) !== 65533) {
          e[D[174][j]] = 44544 + j;
          d[44544 + j] = D[174][j];
        }
      D[175] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D6C\u6D89\u6D6E\u6D5A\u6D74\u6D69\u6D8C\u6D8A\u6D79\u6D85\u6D65\u6D94\u70CA\u70D8\u70E4\u70D9\u70C8\u70CF\u7239\u7279\u72FC\u72F9\u72FD\u72F8\u72F7\u7386\u73ED\u7409\u73EE\u73E0\u73EA\u73DE\u7554\u755D\u755C\u755A\u7559\u75BE\u75C5\u75C7\u75B2\u75B3\u75BD\u75BC\u75B9\u75C2\u75B8\u768B\u76B0\u76CA\u76CD\u76CE\u7729\u771F\u7720\u7728\u77E9\u7830\u7827\u7838\u781D\u7834\u7837\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7825\u782D\u7820\u781F\u7832\u7955\u7950\u7960\u795F\u7956\u795E\u795D\u7957\u795A\u79E4\u79E3\u79E7\u79DF\u79E6\u79E9\u79D8\u7A84\u7A88\u7AD9\u7B06\u7B11\u7C89\u7D21\u7D17\u7D0B\u7D0A\u7D20\u7D22\u7D14\u7D10\u7D15\u7D1A\u7D1C\u7D0D\u7D19\u7D1B\u7F3A\u7F5F\u7F94\u7FC5\u7FC1\u8006\u8018\u8015\u8019\u8017\u803D\u803F\u80F1\u8102\u80F0\u8105\u80ED\u80F4\u8106\u80F8\u80F3\u8108\u80FD\u810A\u80FC\u80EF\u81ED\u81EC\u8200\u8210\u822A\u822B\u8228\u822C\u82BB\u832B\u8352\u8354\u834A\u8338\u8350\u8349\u8335\u8334\u834F\u8332\u8339\u8336\u8317\u8340\u8331\u8328\u8343\uFFFD".split("");
      for (j = 0; j != D[175].length; ++j)
        if (D[175][j].charCodeAt(0) !== 65533) {
          e[D[175][j]] = 44800 + j;
          d[44800 + j] = D[175][j];
        }
      D[176] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8654\u868A\u86AA\u8693\u86A4\u86A9\u868C\u86A3\u869C\u8870\u8877\u8881\u8882\u887D\u8879\u8A18\u8A10\u8A0E\u8A0C\u8A15\u8A0A\u8A17\u8A13\u8A16\u8A0F\u8A11\u8C48\u8C7A\u8C79\u8CA1\u8CA2\u8D77\u8EAC\u8ED2\u8ED4\u8ECF\u8FB1\u9001\u9006\u8FF7\u9000\u8FFA\u8FF4\u9003\u8FFD\u9005\u8FF8\u9095\u90E1\u90DD\u90E2\u9152\u914D\u914C\u91D8\u91DD\u91D7\u91DC\u91D9\u9583\u9662\u9663\u9661\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u965B\u965D\u9664\u9658\u965E\u96BB\u98E2\u99AC\u9AA8\u9AD8\u9B25\u9B32\u9B3C\u4E7E\u507A\u507D\u505C\u5047\u5043\u504C\u505A\u5049\u5065\u5076\u504E\u5055\u5075\u5074\u5077\u504F\u500F\u506F\u506D\u515C\u5195\u51F0\u526A\u526F\u52D2\u52D9\u52D8\u52D5\u5310\u530F\u5319\u533F\u5340\u533E\u53C3\u66FC\u5546\u556A\u5566\u5544\u555E\u5561\u5543\u554A\u5531\u5556\u554F\u5555\u552F\u5564\u5538\u552E\u555C\u552C\u5563\u5533\u5541\u5557\u5708\u570B\u5709\u57DF\u5805\u580A\u5806\u57E0\u57E4\u57FA\u5802\u5835\u57F7\u57F9\u5920\u5962\u5A36\u5A41\u5A49\u5A66\u5A6A\u5A40\uFFFD".split("");
      for (j = 0; j != D[176].length; ++j)
        if (D[176][j].charCodeAt(0) !== 65533) {
          e[D[176][j]] = 45056 + j;
          d[45056 + j] = D[176][j];
        }
      D[177] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5A3C\u5A62\u5A5A\u5A46\u5A4A\u5B70\u5BC7\u5BC5\u5BC4\u5BC2\u5BBF\u5BC6\u5C09\u5C08\u5C07\u5C60\u5C5C\u5C5D\u5D07\u5D06\u5D0E\u5D1B\u5D16\u5D22\u5D11\u5D29\u5D14\u5D19\u5D24\u5D27\u5D17\u5DE2\u5E38\u5E36\u5E33\u5E37\u5EB7\u5EB8\u5EB6\u5EB5\u5EBE\u5F35\u5F37\u5F57\u5F6C\u5F69\u5F6B\u5F97\u5F99\u5F9E\u5F98\u5FA1\u5FA0\u5F9C\u607F\u60A3\u6089\u60A0\u60A8\u60CB\u60B4\u60E6\u60BD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u60C5\u60BB\u60B5\u60DC\u60BC\u60D8\u60D5\u60C6\u60DF\u60B8\u60DA\u60C7\u621A\u621B\u6248\u63A0\u63A7\u6372\u6396\u63A2\u63A5\u6377\u6367\u6398\u63AA\u6371\u63A9\u6389\u6383\u639B\u636B\u63A8\u6384\u6388\u6399\u63A1\u63AC\u6392\u638F\u6380\u637B\u6369\u6368\u637A\u655D\u6556\u6551\u6559\u6557\u555F\u654F\u6558\u6555\u6554\u659C\u659B\u65AC\u65CF\u65CB\u65CC\u65CE\u665D\u665A\u6664\u6668\u6666\u665E\u66F9\u52D7\u671B\u6881\u68AF\u68A2\u6893\u68B5\u687F\u6876\u68B1\u68A7\u6897\u68B0\u6883\u68C4\u68AD\u6886\u6885\u6894\u689D\u68A8\u689F\u68A1\u6882\u6B32\u6BBA\uFFFD".split("");
      for (j = 0; j != D[177].length; ++j)
        if (D[177][j].charCodeAt(0) !== 65533) {
          e[D[177][j]] = 45312 + j;
          d[45312 + j] = D[177][j];
        }
      D[178] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6BEB\u6BEC\u6C2B\u6D8E\u6DBC\u6DF3\u6DD9\u6DB2\u6DE1\u6DCC\u6DE4\u6DFB\u6DFA\u6E05\u6DC7\u6DCB\u6DAF\u6DD1\u6DAE\u6DDE\u6DF9\u6DB8\u6DF7\u6DF5\u6DC5\u6DD2\u6E1A\u6DB5\u6DDA\u6DEB\u6DD8\u6DEA\u6DF1\u6DEE\u6DE8\u6DC6\u6DC4\u6DAA\u6DEC\u6DBF\u6DE6\u70F9\u7109\u710A\u70FD\u70EF\u723D\u727D\u7281\u731C\u731B\u7316\u7313\u7319\u7387\u7405\u740A\u7403\u7406\u73FE\u740D\u74E0\u74F6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u74F7\u751C\u7522\u7565\u7566\u7562\u7570\u758F\u75D4\u75D5\u75B5\u75CA\u75CD\u768E\u76D4\u76D2\u76DB\u7737\u773E\u773C\u7736\u7738\u773A\u786B\u7843\u784E\u7965\u7968\u796D\u79FB\u7A92\u7A95\u7B20\u7B28\u7B1B\u7B2C\u7B26\u7B19\u7B1E\u7B2E\u7C92\u7C97\u7C95\u7D46\u7D43\u7D71\u7D2E\u7D39\u7D3C\u7D40\u7D30\u7D33\u7D44\u7D2F\u7D42\u7D32\u7D31\u7F3D\u7F9E\u7F9A\u7FCC\u7FCE\u7FD2\u801C\u804A\u8046\u812F\u8116\u8123\u812B\u8129\u8130\u8124\u8202\u8235\u8237\u8236\u8239\u838E\u839E\u8398\u8378\u83A2\u8396\u83BD\u83AB\u8392\u838A\u8393\u8389\u83A0\u8377\u837B\u837C\uFFFD".split("");
      for (j = 0; j != D[178].length; ++j)
        if (D[178][j].charCodeAt(0) !== 65533) {
          e[D[178][j]] = 45568 + j;
          d[45568 + j] = D[178][j];
        }
      D[179] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8386\u83A7\u8655\u5F6A\u86C7\u86C0\u86B6\u86C4\u86B5\u86C6\u86CB\u86B1\u86AF\u86C9\u8853\u889E\u8888\u88AB\u8892\u8896\u888D\u888B\u8993\u898F\u8A2A\u8A1D\u8A23\u8A25\u8A31\u8A2D\u8A1F\u8A1B\u8A22\u8C49\u8C5A\u8CA9\u8CAC\u8CAB\u8CA8\u8CAA\u8CA7\u8D67\u8D66\u8DBE\u8DBA\u8EDB\u8EDF\u9019\u900D\u901A\u9017\u9023\u901F\u901D\u9010\u9015\u901E\u9020\u900F\u9022\u9016\u901B\u9014\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u90E8\u90ED\u90FD\u9157\u91CE\u91F5\u91E6\u91E3\u91E7\u91ED\u91E9\u9589\u966A\u9675\u9673\u9678\u9670\u9674\u9676\u9677\u966C\u96C0\u96EA\u96E9\u7AE0\u7ADF\u9802\u9803\u9B5A\u9CE5\u9E75\u9E7F\u9EA5\u9EBB\u50A2\u508D\u5085\u5099\u5091\u5080\u5096\u5098\u509A\u6700\u51F1\u5272\u5274\u5275\u5269\u52DE\u52DD\u52DB\u535A\u53A5\u557B\u5580\u55A7\u557C\u558A\u559D\u5598\u5582\u559C\u55AA\u5594\u5587\u558B\u5583\u55B3\u55AE\u559F\u553E\u55B2\u559A\u55BB\u55AC\u55B1\u557E\u5589\u55AB\u5599\u570D\u582F\u582A\u5834\u5824\u5830\u5831\u5821\u581D\u5820\u58F9\u58FA\u5960\uFFFD".split("");
      for (j = 0; j != D[179].length; ++j)
        if (D[179][j].charCodeAt(0) !== 65533) {
          e[D[179][j]] = 45824 + j;
          d[45824 + j] = D[179][j];
        }
      D[180] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5A77\u5A9A\u5A7F\u5A92\u5A9B\u5AA7\u5B73\u5B71\u5BD2\u5BCC\u5BD3\u5BD0\u5C0A\u5C0B\u5C31\u5D4C\u5D50\u5D34\u5D47\u5DFD\u5E45\u5E3D\u5E40\u5E43\u5E7E\u5ECA\u5EC1\u5EC2\u5EC4\u5F3C\u5F6D\u5FA9\u5FAA\u5FA8\u60D1\u60E1\u60B2\u60B6\u60E0\u611C\u6123\u60FA\u6115\u60F0\u60FB\u60F4\u6168\u60F1\u610E\u60F6\u6109\u6100\u6112\u621F\u6249\u63A3\u638C\u63CF\u63C0\u63E9\u63C9\u63C6\u63CD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u63D2\u63E3\u63D0\u63E1\u63D6\u63ED\u63EE\u6376\u63F4\u63EA\u63DB\u6452\u63DA\u63F9\u655E\u6566\u6562\u6563\u6591\u6590\u65AF\u666E\u6670\u6674\u6676\u666F\u6691\u667A\u667E\u6677\u66FE\u66FF\u671F\u671D\u68FA\u68D5\u68E0\u68D8\u68D7\u6905\u68DF\u68F5\u68EE\u68E7\u68F9\u68D2\u68F2\u68E3\u68CB\u68CD\u690D\u6912\u690E\u68C9\u68DA\u696E\u68FB\u6B3E\u6B3A\u6B3D\u6B98\u6B96\u6BBC\u6BEF\u6C2E\u6C2F\u6C2C\u6E2F\u6E38\u6E54\u6E21\u6E32\u6E67\u6E4A\u6E20\u6E25\u6E23\u6E1B\u6E5B\u6E58\u6E24\u6E56\u6E6E\u6E2D\u6E26\u6E6F\u6E34\u6E4D\u6E3A\u6E2C\u6E43\u6E1D\u6E3E\u6ECB\uFFFD".split("");
      for (j = 0; j != D[180].length; ++j)
        if (D[180][j].charCodeAt(0) !== 65533) {
          e[D[180][j]] = 46080 + j;
          d[46080 + j] = D[180][j];
        }
      D[181] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6E89\u6E19\u6E4E\u6E63\u6E44\u6E72\u6E69\u6E5F\u7119\u711A\u7126\u7130\u7121\u7136\u716E\u711C\u724C\u7284\u7280\u7336\u7325\u7334\u7329\u743A\u742A\u7433\u7422\u7425\u7435\u7436\u7434\u742F\u741B\u7426\u7428\u7525\u7526\u756B\u756A\u75E2\u75DB\u75E3\u75D9\u75D8\u75DE\u75E0\u767B\u767C\u7696\u7693\u76B4\u76DC\u774F\u77ED\u785D\u786C\u786F\u7A0D\u7A08\u7A0B\u7A05\u7A00\u7A98\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A97\u7A96\u7AE5\u7AE3\u7B49\u7B56\u7B46\u7B50\u7B52\u7B54\u7B4D\u7B4B\u7B4F\u7B51\u7C9F\u7CA5\u7D5E\u7D50\u7D68\u7D55\u7D2B\u7D6E\u7D72\u7D61\u7D66\u7D62\u7D70\u7D73\u5584\u7FD4\u7FD5\u800B\u8052\u8085\u8155\u8154\u814B\u8151\u814E\u8139\u8146\u813E\u814C\u8153\u8174\u8212\u821C\u83E9\u8403\u83F8\u840D\u83E0\u83C5\u840B\u83C1\u83EF\u83F1\u83F4\u8457\u840A\u83F0\u840C\u83CC\u83FD\u83F2\u83CA\u8438\u840E\u8404\u83DC\u8407\u83D4\u83DF\u865B\u86DF\u86D9\u86ED\u86D4\u86DB\u86E4\u86D0\u86DE\u8857\u88C1\u88C2\u88B1\u8983\u8996\u8A3B\u8A60\u8A55\u8A5E\u8A3C\u8A41\uFFFD".split("");
      for (j = 0; j != D[181].length; ++j)
        if (D[181][j].charCodeAt(0) !== 65533) {
          e[D[181][j]] = 46336 + j;
          d[46336 + j] = D[181][j];
        }
      D[182] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8A54\u8A5B\u8A50\u8A46\u8A34\u8A3A\u8A36\u8A56\u8C61\u8C82\u8CAF\u8CBC\u8CB3\u8CBD\u8CC1\u8CBB\u8CC0\u8CB4\u8CB7\u8CB6\u8CBF\u8CB8\u8D8A\u8D85\u8D81\u8DCE\u8DDD\u8DCB\u8DDA\u8DD1\u8DCC\u8DDB\u8DC6\u8EFB\u8EF8\u8EFC\u8F9C\u902E\u9035\u9031\u9038\u9032\u9036\u9102\u90F5\u9109\u90FE\u9163\u9165\u91CF\u9214\u9215\u9223\u9209\u921E\u920D\u9210\u9207\u9211\u9594\u958F\u958B\u9591\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9593\u9592\u958E\u968A\u968E\u968B\u967D\u9685\u9686\u968D\u9672\u9684\u96C1\u96C5\u96C4\u96C6\u96C7\u96EF\u96F2\u97CC\u9805\u9806\u9808\u98E7\u98EA\u98EF\u98E9\u98F2\u98ED\u99AE\u99AD\u9EC3\u9ECD\u9ED1\u4E82\u50AD\u50B5\u50B2\u50B3\u50C5\u50BE\u50AC\u50B7\u50BB\u50AF\u50C7\u527F\u5277\u527D\u52DF\u52E6\u52E4\u52E2\u52E3\u532F\u55DF\u55E8\u55D3\u55E6\u55CE\u55DC\u55C7\u55D1\u55E3\u55E4\u55EF\u55DA\u55E1\u55C5\u55C6\u55E5\u55C9\u5712\u5713\u585E\u5851\u5858\u5857\u585A\u5854\u586B\u584C\u586D\u584A\u5862\u5852\u584B\u5967\u5AC1\u5AC9\u5ACC\u5ABE\u5ABD\u5ABC\uFFFD".split("");
      for (j = 0; j != D[182].length; ++j)
        if (D[182][j].charCodeAt(0) !== 65533) {
          e[D[182][j]] = 46592 + j;
          d[46592 + j] = D[182][j];
        }
      D[183] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5AB3\u5AC2\u5AB2\u5D69\u5D6F\u5E4C\u5E79\u5EC9\u5EC8\u5F12\u5F59\u5FAC\u5FAE\u611A\u610F\u6148\u611F\u60F3\u611B\u60F9\u6101\u6108\u614E\u614C\u6144\u614D\u613E\u6134\u6127\u610D\u6106\u6137\u6221\u6222\u6413\u643E\u641E\u642A\u642D\u643D\u642C\u640F\u641C\u6414\u640D\u6436\u6416\u6417\u6406\u656C\u659F\u65B0\u6697\u6689\u6687\u6688\u6696\u6684\u6698\u668D\u6703\u6994\u696D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u695A\u6977\u6960\u6954\u6975\u6930\u6982\u694A\u6968\u696B\u695E\u6953\u6979\u6986\u695D\u6963\u695B\u6B47\u6B72\u6BC0\u6BBF\u6BD3\u6BFD\u6EA2\u6EAF\u6ED3\u6EB6\u6EC2\u6E90\u6E9D\u6EC7\u6EC5\u6EA5\u6E98\u6EBC\u6EBA\u6EAB\u6ED1\u6E96\u6E9C\u6EC4\u6ED4\u6EAA\u6EA7\u6EB4\u714E\u7159\u7169\u7164\u7149\u7167\u715C\u716C\u7166\u714C\u7165\u715E\u7146\u7168\u7156\u723A\u7252\u7337\u7345\u733F\u733E\u746F\u745A\u7455\u745F\u745E\u7441\u743F\u7459\u745B\u745C\u7576\u7578\u7600\u75F0\u7601\u75F2\u75F1\u75FA\u75FF\u75F4\u75F3\u76DE\u76DF\u775B\u776B\u7766\u775E\u7763\uFFFD".split("");
      for (j = 0; j != D[183].length; ++j)
        if (D[183][j].charCodeAt(0) !== 65533) {
          e[D[183][j]] = 46848 + j;
          d[46848 + j] = D[183][j];
        }
      D[184] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7779\u776A\u776C\u775C\u7765\u7768\u7762\u77EE\u788E\u78B0\u7897\u7898\u788C\u7889\u787C\u7891\u7893\u787F\u797A\u797F\u7981\u842C\u79BD\u7A1C\u7A1A\u7A20\u7A14\u7A1F\u7A1E\u7A9F\u7AA0\u7B77\u7BC0\u7B60\u7B6E\u7B67\u7CB1\u7CB3\u7CB5\u7D93\u7D79\u7D91\u7D81\u7D8F\u7D5B\u7F6E\u7F69\u7F6A\u7F72\u7FA9\u7FA8\u7FA4\u8056\u8058\u8086\u8084\u8171\u8170\u8178\u8165\u816E\u8173\u816B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8179\u817A\u8166\u8205\u8247\u8482\u8477\u843D\u8431\u8475\u8466\u846B\u8449\u846C\u845B\u843C\u8435\u8461\u8463\u8469\u846D\u8446\u865E\u865C\u865F\u86F9\u8713\u8708\u8707\u8700\u86FE\u86FB\u8702\u8703\u8706\u870A\u8859\u88DF\u88D4\u88D9\u88DC\u88D8\u88DD\u88E1\u88CA\u88D5\u88D2\u899C\u89E3\u8A6B\u8A72\u8A73\u8A66\u8A69\u8A70\u8A87\u8A7C\u8A63\u8AA0\u8A71\u8A85\u8A6D\u8A62\u8A6E\u8A6C\u8A79\u8A7B\u8A3E\u8A68\u8C62\u8C8A\u8C89\u8CCA\u8CC7\u8CC8\u8CC4\u8CB2\u8CC3\u8CC2\u8CC5\u8DE1\u8DDF\u8DE8\u8DEF\u8DF3\u8DFA\u8DEA\u8DE4\u8DE6\u8EB2\u8F03\u8F09\u8EFE\u8F0A\uFFFD".split("");
      for (j = 0; j != D[184].length; ++j)
        if (D[184][j].charCodeAt(0) !== 65533) {
          e[D[184][j]] = 47104 + j;
          d[47104 + j] = D[184][j];
        }
      D[185] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8F9F\u8FB2\u904B\u904A\u9053\u9042\u9054\u903C\u9055\u9050\u9047\u904F\u904E\u904D\u9051\u903E\u9041\u9112\u9117\u916C\u916A\u9169\u91C9\u9237\u9257\u9238\u923D\u9240\u923E\u925B\u924B\u9264\u9251\u9234\u9249\u924D\u9245\u9239\u923F\u925A\u9598\u9698\u9694\u9695\u96CD\u96CB\u96C9\u96CA\u96F7\u96FB\u96F9\u96F6\u9756\u9774\u9776\u9810\u9811\u9813\u980A\u9812\u980C\u98FC\u98F4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u98FD\u98FE\u99B3\u99B1\u99B4\u9AE1\u9CE9\u9E82\u9F0E\u9F13\u9F20\u50E7\u50EE\u50E5\u50D6\u50ED\u50DA\u50D5\u50CF\u50D1\u50F1\u50CE\u50E9\u5162\u51F3\u5283\u5282\u5331\u53AD\u55FE\u5600\u561B\u5617\u55FD\u5614\u5606\u5609\u560D\u560E\u55F7\u5616\u561F\u5608\u5610\u55F6\u5718\u5716\u5875\u587E\u5883\u5893\u588A\u5879\u5885\u587D\u58FD\u5925\u5922\u5924\u596A\u5969\u5AE1\u5AE6\u5AE9\u5AD7\u5AD6\u5AD8\u5AE3\u5B75\u5BDE\u5BE7\u5BE1\u5BE5\u5BE6\u5BE8\u5BE2\u5BE4\u5BDF\u5C0D\u5C62\u5D84\u5D87\u5E5B\u5E63\u5E55\u5E57\u5E54\u5ED3\u5ED6\u5F0A\u5F46\u5F70\u5FB9\u6147\uFFFD".split("");
      for (j = 0; j != D[185].length; ++j)
        if (D[185][j].charCodeAt(0) !== 65533) {
          e[D[185][j]] = 47360 + j;
          d[47360 + j] = D[185][j];
        }
      D[186] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u613F\u614B\u6177\u6162\u6163\u615F\u615A\u6158\u6175\u622A\u6487\u6458\u6454\u64A4\u6478\u645F\u647A\u6451\u6467\u6434\u646D\u647B\u6572\u65A1\u65D7\u65D6\u66A2\u66A8\u669D\u699C\u69A8\u6995\u69C1\u69AE\u69D3\u69CB\u699B\u69B7\u69BB\u69AB\u69B4\u69D0\u69CD\u69AD\u69CC\u69A6\u69C3\u69A3\u6B49\u6B4C\u6C33\u6F33\u6F14\u6EFE\u6F13\u6EF4\u6F29\u6F3E\u6F20\u6F2C\u6F0F\u6F02\u6F22\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6EFF\u6EEF\u6F06\u6F31\u6F38\u6F32\u6F23\u6F15\u6F2B\u6F2F\u6F88\u6F2A\u6EEC\u6F01\u6EF2\u6ECC\u6EF7\u7194\u7199\u717D\u718A\u7184\u7192\u723E\u7292\u7296\u7344\u7350\u7464\u7463\u746A\u7470\u746D\u7504\u7591\u7627\u760D\u760B\u7609\u7613\u76E1\u76E3\u7784\u777D\u777F\u7761\u78C1\u789F\u78A7\u78B3\u78A9\u78A3\u798E\u798F\u798D\u7A2E\u7A31\u7AAA\u7AA9\u7AED\u7AEF\u7BA1\u7B95\u7B8B\u7B75\u7B97\u7B9D\u7B94\u7B8F\u7BB8\u7B87\u7B84\u7CB9\u7CBD\u7CBE\u7DBB\u7DB0\u7D9C\u7DBD\u7DBE\u7DA0\u7DCA\u7DB4\u7DB2\u7DB1\u7DBA\u7DA2\u7DBF\u7DB5\u7DB8\u7DAD\u7DD2\u7DC7\u7DAC\uFFFD".split("");
      for (j = 0; j != D[186].length; ++j)
        if (D[186][j].charCodeAt(0) !== 65533) {
          e[D[186][j]] = 47616 + j;
          d[47616 + j] = D[186][j];
        }
      D[187] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7F70\u7FE0\u7FE1\u7FDF\u805E\u805A\u8087\u8150\u8180\u818F\u8188\u818A\u817F\u8182\u81E7\u81FA\u8207\u8214\u821E\u824B\u84C9\u84BF\u84C6\u84C4\u8499\u849E\u84B2\u849C\u84CB\u84B8\u84C0\u84D3\u8490\u84BC\u84D1\u84CA\u873F\u871C\u873B\u8722\u8725\u8734\u8718\u8755\u8737\u8729\u88F3\u8902\u88F4\u88F9\u88F8\u88FD\u88E8\u891A\u88EF\u8AA6\u8A8C\u8A9E\u8AA3\u8A8D\u8AA1\u8A93\u8AA4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8AAA\u8AA5\u8AA8\u8A98\u8A91\u8A9A\u8AA7\u8C6A\u8C8D\u8C8C\u8CD3\u8CD1\u8CD2\u8D6B\u8D99\u8D95\u8DFC\u8F14\u8F12\u8F15\u8F13\u8FA3\u9060\u9058\u905C\u9063\u9059\u905E\u9062\u905D\u905B\u9119\u9118\u911E\u9175\u9178\u9177\u9174\u9278\u9280\u9285\u9298\u9296\u927B\u9293\u929C\u92A8\u927C\u9291\u95A1\u95A8\u95A9\u95A3\u95A5\u95A4\u9699\u969C\u969B\u96CC\u96D2\u9700\u977C\u9785\u97F6\u9817\u9818\u98AF\u98B1\u9903\u9905\u990C\u9909\u99C1\u9AAF\u9AB0\u9AE6\u9B41\u9B42\u9CF4\u9CF6\u9CF3\u9EBC\u9F3B\u9F4A\u5104\u5100\u50FB\u50F5\u50F9\u5102\u5108\u5109\u5105\u51DC\uFFFD".split("");
      for (j = 0; j != D[187].length; ++j)
        if (D[187][j].charCodeAt(0) !== 65533) {
          e[D[187][j]] = 47872 + j;
          d[47872 + j] = D[187][j];
        }
      D[188] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5287\u5288\u5289\u528D\u528A\u52F0\u53B2\u562E\u563B\u5639\u5632\u563F\u5634\u5629\u5653\u564E\u5657\u5674\u5636\u562F\u5630\u5880\u589F\u589E\u58B3\u589C\u58AE\u58A9\u58A6\u596D\u5B09\u5AFB\u5B0B\u5AF5\u5B0C\u5B08\u5BEE\u5BEC\u5BE9\u5BEB\u5C64\u5C65\u5D9D\u5D94\u5E62\u5E5F\u5E61\u5EE2\u5EDA\u5EDF\u5EDD\u5EE3\u5EE0\u5F48\u5F71\u5FB7\u5FB5\u6176\u6167\u616E\u615D\u6155\u6182\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u617C\u6170\u616B\u617E\u61A7\u6190\u61AB\u618E\u61AC\u619A\u61A4\u6194\u61AE\u622E\u6469\u646F\u6479\u649E\u64B2\u6488\u6490\u64B0\u64A5\u6493\u6495\u64A9\u6492\u64AE\u64AD\u64AB\u649A\u64AC\u6499\u64A2\u64B3\u6575\u6577\u6578\u66AE\u66AB\u66B4\u66B1\u6A23\u6A1F\u69E8\u6A01\u6A1E\u6A19\u69FD\u6A21\u6A13\u6A0A\u69F3\u6A02\u6A05\u69ED\u6A11\u6B50\u6B4E\u6BA4\u6BC5\u6BC6\u6F3F\u6F7C\u6F84\u6F51\u6F66\u6F54\u6F86\u6F6D\u6F5B\u6F78\u6F6E\u6F8E\u6F7A\u6F70\u6F64\u6F97\u6F58\u6ED5\u6F6F\u6F60\u6F5F\u719F\u71AC\u71B1\u71A8\u7256\u729B\u734E\u7357\u7469\u748B\u7483\uFFFD".split("");
      for (j = 0; j != D[188].length; ++j)
        if (D[188][j].charCodeAt(0) !== 65533) {
          e[D[188][j]] = 48128 + j;
          d[48128 + j] = D[188][j];
        }
      D[189] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u747E\u7480\u757F\u7620\u7629\u761F\u7624\u7626\u7621\u7622\u769A\u76BA\u76E4\u778E\u7787\u778C\u7791\u778B\u78CB\u78C5\u78BA\u78CA\u78BE\u78D5\u78BC\u78D0\u7A3F\u7A3C\u7A40\u7A3D\u7A37\u7A3B\u7AAF\u7AAE\u7BAD\u7BB1\u7BC4\u7BB4\u7BC6\u7BC7\u7BC1\u7BA0\u7BCC\u7CCA\u7DE0\u7DF4\u7DEF\u7DFB\u7DD8\u7DEC\u7DDD\u7DE8\u7DE3\u7DDA\u7DDE\u7DE9\u7D9E\u7DD9\u7DF2\u7DF9\u7F75\u7F77\u7FAF\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7FE9\u8026\u819B\u819C\u819D\u81A0\u819A\u8198\u8517\u853D\u851A\u84EE\u852C\u852D\u8513\u8511\u8523\u8521\u8514\u84EC\u8525\u84FF\u8506\u8782\u8774\u8776\u8760\u8766\u8778\u8768\u8759\u8757\u874C\u8753\u885B\u885D\u8910\u8907\u8912\u8913\u8915\u890A\u8ABC\u8AD2\u8AC7\u8AC4\u8A95\u8ACB\u8AF8\u8AB2\u8AC9\u8AC2\u8ABF\u8AB0\u8AD6\u8ACD\u8AB6\u8AB9\u8ADB\u8C4C\u8C4E\u8C6C\u8CE0\u8CDE\u8CE6\u8CE4\u8CEC\u8CED\u8CE2\u8CE3\u8CDC\u8CEA\u8CE1\u8D6D\u8D9F\u8DA3\u8E2B\u8E10\u8E1D\u8E22\u8E0F\u8E29\u8E1F\u8E21\u8E1E\u8EBA\u8F1D\u8F1B\u8F1F\u8F29\u8F26\u8F2A\u8F1C\u8F1E\uFFFD".split("");
      for (j = 0; j != D[189].length; ++j)
        if (D[189][j].charCodeAt(0) !== 65533) {
          e[D[189][j]] = 48384 + j;
          d[48384 + j] = D[189][j];
        }
      D[190] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8F25\u9069\u906E\u9068\u906D\u9077\u9130\u912D\u9127\u9131\u9187\u9189\u918B\u9183\u92C5\u92BB\u92B7\u92EA\u92AC\u92E4\u92C1\u92B3\u92BC\u92D2\u92C7\u92F0\u92B2\u95AD\u95B1\u9704\u9706\u9707\u9709\u9760\u978D\u978B\u978F\u9821\u982B\u981C\u98B3\u990A\u9913\u9912\u9918\u99DD\u99D0\u99DF\u99DB\u99D1\u99D5\u99D2\u99D9\u9AB7\u9AEE\u9AEF\u9B27\u9B45\u9B44\u9B77\u9B6F\u9D06\u9D09\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9D03\u9EA9\u9EBE\u9ECE\u58A8\u9F52\u5112\u5118\u5114\u5110\u5115\u5180\u51AA\u51DD\u5291\u5293\u52F3\u5659\u566B\u5679\u5669\u5664\u5678\u566A\u5668\u5665\u5671\u566F\u566C\u5662\u5676\u58C1\u58BE\u58C7\u58C5\u596E\u5B1D\u5B34\u5B78\u5BF0\u5C0E\u5F4A\u61B2\u6191\u61A9\u618A\u61CD\u61B6\u61BE\u61CA\u61C8\u6230\u64C5\u64C1\u64CB\u64BB\u64BC\u64DA\u64C4\u64C7\u64C2\u64CD\u64BF\u64D2\u64D4\u64BE\u6574\u66C6\u66C9\u66B9\u66C4\u66C7\u66B8\u6A3D\u6A38\u6A3A\u6A59\u6A6B\u6A58\u6A39\u6A44\u6A62\u6A61\u6A4B\u6A47\u6A35\u6A5F\u6A48\u6B59\u6B77\u6C05\u6FC2\u6FB1\u6FA1\uFFFD".split("");
      for (j = 0; j != D[190].length; ++j)
        if (D[190][j].charCodeAt(0) !== 65533) {
          e[D[190][j]] = 48640 + j;
          d[48640 + j] = D[190][j];
        }
      D[191] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6FC3\u6FA4\u6FC1\u6FA7\u6FB3\u6FC0\u6FB9\u6FB6\u6FA6\u6FA0\u6FB4\u71BE\u71C9\u71D0\u71D2\u71C8\u71D5\u71B9\u71CE\u71D9\u71DC\u71C3\u71C4\u7368\u749C\u74A3\u7498\u749F\u749E\u74E2\u750C\u750D\u7634\u7638\u763A\u76E7\u76E5\u77A0\u779E\u779F\u77A5\u78E8\u78DA\u78EC\u78E7\u79A6\u7A4D\u7A4E\u7A46\u7A4C\u7A4B\u7ABA\u7BD9\u7C11\u7BC9\u7BE4\u7BDB\u7BE1\u7BE9\u7BE6\u7CD5\u7CD6\u7E0A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E11\u7E08\u7E1B\u7E23\u7E1E\u7E1D\u7E09\u7E10\u7F79\u7FB2\u7FF0\u7FF1\u7FEE\u8028\u81B3\u81A9\u81A8\u81FB\u8208\u8258\u8259\u854A\u8559\u8548\u8568\u8569\u8543\u8549\u856D\u856A\u855E\u8783\u879F\u879E\u87A2\u878D\u8861\u892A\u8932\u8925\u892B\u8921\u89AA\u89A6\u8AE6\u8AFA\u8AEB\u8AF1\u8B00\u8ADC\u8AE7\u8AEE\u8AFE\u8B01\u8B02\u8AF7\u8AED\u8AF3\u8AF6\u8AFC\u8C6B\u8C6D\u8C93\u8CF4\u8E44\u8E31\u8E34\u8E42\u8E39\u8E35\u8F3B\u8F2F\u8F38\u8F33\u8FA8\u8FA6\u9075\u9074\u9078\u9072\u907C\u907A\u9134\u9192\u9320\u9336\u92F8\u9333\u932F\u9322\u92FC\u932B\u9304\u931A\uFFFD".split("");
      for (j = 0; j != D[191].length; ++j)
        if (D[191][j].charCodeAt(0) !== 65533) {
          e[D[191][j]] = 48896 + j;
          d[48896 + j] = D[191][j];
        }
      D[192] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9310\u9326\u9321\u9315\u932E\u9319\u95BB\u96A7\u96A8\u96AA\u96D5\u970E\u9711\u9716\u970D\u9713\u970F\u975B\u975C\u9766\u9798\u9830\u9838\u983B\u9837\u982D\u9839\u9824\u9910\u9928\u991E\u991B\u9921\u991A\u99ED\u99E2\u99F1\u9AB8\u9ABC\u9AFB\u9AED\u9B28\u9B91\u9D15\u9D23\u9D26\u9D28\u9D12\u9D1B\u9ED8\u9ED4\u9F8D\u9F9C\u512A\u511F\u5121\u5132\u52F5\u568E\u5680\u5690\u5685\u5687\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u568F\u58D5\u58D3\u58D1\u58CE\u5B30\u5B2A\u5B24\u5B7A\u5C37\u5C68\u5DBC\u5DBA\u5DBD\u5DB8\u5E6B\u5F4C\u5FBD\u61C9\u61C2\u61C7\u61E6\u61CB\u6232\u6234\u64CE\u64CA\u64D8\u64E0\u64F0\u64E6\u64EC\u64F1\u64E2\u64ED\u6582\u6583\u66D9\u66D6\u6A80\u6A94\u6A84\u6AA2\u6A9C\u6ADB\u6AA3\u6A7E\u6A97\u6A90\u6AA0\u6B5C\u6BAE\u6BDA\u6C08\u6FD8\u6FF1\u6FDF\u6FE0\u6FDB\u6FE4\u6FEB\u6FEF\u6F80\u6FEC\u6FE1\u6FE9\u6FD5\u6FEE\u6FF0\u71E7\u71DF\u71EE\u71E6\u71E5\u71ED\u71EC\u71F4\u71E0\u7235\u7246\u7370\u7372\u74A9\u74B0\u74A6\u74A8\u7646\u7642\u764C\u76EA\u77B3\u77AA\u77B0\u77AC\uFFFD".split("");
      for (j = 0; j != D[192].length; ++j)
        if (D[192][j].charCodeAt(0) !== 65533) {
          e[D[192][j]] = 49152 + j;
          d[49152 + j] = D[192][j];
        }
      D[193] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u77A7\u77AD\u77EF\u78F7\u78FA\u78F4\u78EF\u7901\u79A7\u79AA\u7A57\u7ABF\u7C07\u7C0D\u7BFE\u7BF7\u7C0C\u7BE0\u7CE0\u7CDC\u7CDE\u7CE2\u7CDF\u7CD9\u7CDD\u7E2E\u7E3E\u7E46\u7E37\u7E32\u7E43\u7E2B\u7E3D\u7E31\u7E45\u7E41\u7E34\u7E39\u7E48\u7E35\u7E3F\u7E2F\u7F44\u7FF3\u7FFC\u8071\u8072\u8070\u806F\u8073\u81C6\u81C3\u81BA\u81C2\u81C0\u81BF\u81BD\u81C9\u81BE\u81E8\u8209\u8271\u85AA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8584\u857E\u859C\u8591\u8594\u85AF\u859B\u8587\u85A8\u858A\u8667\u87C0\u87D1\u87B3\u87D2\u87C6\u87AB\u87BB\u87BA\u87C8\u87CB\u893B\u8936\u8944\u8938\u893D\u89AC\u8B0E\u8B17\u8B19\u8B1B\u8B0A\u8B20\u8B1D\u8B04\u8B10\u8C41\u8C3F\u8C73\u8CFA\u8CFD\u8CFC\u8CF8\u8CFB\u8DA8\u8E49\u8E4B\u8E48\u8E4A\u8F44\u8F3E\u8F42\u8F45\u8F3F\u907F\u907D\u9084\u9081\u9082\u9080\u9139\u91A3\u919E\u919C\u934D\u9382\u9328\u9375\u934A\u9365\u934B\u9318\u937E\u936C\u935B\u9370\u935A\u9354\u95CA\u95CB\u95CC\u95C8\u95C6\u96B1\u96B8\u96D6\u971C\u971E\u97A0\u97D3\u9846\u98B6\u9935\u9A01\uFFFD".split("");
      for (j = 0; j != D[193].length; ++j)
        if (D[193][j].charCodeAt(0) !== 65533) {
          e[D[193][j]] = 49408 + j;
          d[49408 + j] = D[193][j];
        }
      D[194] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u99FF\u9BAE\u9BAB\u9BAA\u9BAD\u9D3B\u9D3F\u9E8B\u9ECF\u9EDE\u9EDC\u9EDD\u9EDB\u9F3E\u9F4B\u53E2\u5695\u56AE\u58D9\u58D8\u5B38\u5F5D\u61E3\u6233\u64F4\u64F2\u64FE\u6506\u64FA\u64FB\u64F7\u65B7\u66DC\u6726\u6AB3\u6AAC\u6AC3\u6ABB\u6AB8\u6AC2\u6AAE\u6AAF\u6B5F\u6B78\u6BAF\u7009\u700B\u6FFE\u7006\u6FFA\u7011\u700F\u71FB\u71FC\u71FE\u71F8\u7377\u7375\u74A7\u74BF\u7515\u7656\u7658\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7652\u77BD\u77BF\u77BB\u77BC\u790E\u79AE\u7A61\u7A62\u7A60\u7AC4\u7AC5\u7C2B\u7C27\u7C2A\u7C1E\u7C23\u7C21\u7CE7\u7E54\u7E55\u7E5E\u7E5A\u7E61\u7E52\u7E59\u7F48\u7FF9\u7FFB\u8077\u8076\u81CD\u81CF\u820A\u85CF\u85A9\u85CD\u85D0\u85C9\u85B0\u85BA\u85B9\u85A6\u87EF\u87EC\u87F2\u87E0\u8986\u89B2\u89F4\u8B28\u8B39\u8B2C\u8B2B\u8C50\u8D05\u8E59\u8E63\u8E66\u8E64\u8E5F\u8E55\u8EC0\u8F49\u8F4D\u9087\u9083\u9088\u91AB\u91AC\u91D0\u9394\u938A\u9396\u93A2\u93B3\u93AE\u93AC\u93B0\u9398\u939A\u9397\u95D4\u95D6\u95D0\u95D5\u96E2\u96DC\u96D9\u96DB\u96DE\u9724\u97A3\u97A6\uFFFD".split("");
      for (j = 0; j != D[194].length; ++j)
        if (D[194][j].charCodeAt(0) !== 65533) {
          e[D[194][j]] = 49664 + j;
          d[49664 + j] = D[194][j];
        }
      D[195] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u97AD\u97F9\u984D\u984F\u984C\u984E\u9853\u98BA\u993E\u993F\u993D\u992E\u99A5\u9A0E\u9AC1\u9B03\u9B06\u9B4F\u9B4E\u9B4D\u9BCA\u9BC9\u9BFD\u9BC8\u9BC0\u9D51\u9D5D\u9D60\u9EE0\u9F15\u9F2C\u5133\u56A5\u58DE\u58DF\u58E2\u5BF5\u9F90\u5EEC\u61F2\u61F7\u61F6\u61F5\u6500\u650F\u66E0\u66DD\u6AE5\u6ADD\u6ADA\u6AD3\u701B\u701F\u7028\u701A\u701D\u7015\u7018\u7206\u720D\u7258\u72A2\u7378\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u737A\u74BD\u74CA\u74E3\u7587\u7586\u765F\u7661\u77C7\u7919\u79B1\u7A6B\u7A69\u7C3E\u7C3F\u7C38\u7C3D\u7C37\u7C40\u7E6B\u7E6D\u7E79\u7E69\u7E6A\u7F85\u7E73\u7FB6\u7FB9\u7FB8\u81D8\u85E9\u85DD\u85EA\u85D5\u85E4\u85E5\u85F7\u87FB\u8805\u880D\u87F9\u87FE\u8960\u895F\u8956\u895E\u8B41\u8B5C\u8B58\u8B49\u8B5A\u8B4E\u8B4F\u8B46\u8B59\u8D08\u8D0A\u8E7C\u8E72\u8E87\u8E76\u8E6C\u8E7A\u8E74\u8F54\u8F4E\u8FAD\u908A\u908B\u91B1\u91AE\u93E1\u93D1\u93DF\u93C3\u93C8\u93DC\u93DD\u93D6\u93E2\u93CD\u93D8\u93E4\u93D7\u93E8\u95DC\u96B4\u96E3\u972A\u9727\u9761\u97DC\u97FB\u985E\uFFFD".split("");
      for (j = 0; j != D[195].length; ++j)
        if (D[195][j].charCodeAt(0) !== 65533) {
          e[D[195][j]] = 49920 + j;
          d[49920 + j] = D[195][j];
        }
      D[196] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9858\u985B\u98BC\u9945\u9949\u9A16\u9A19\u9B0D\u9BE8\u9BE7\u9BD6\u9BDB\u9D89\u9D61\u9D72\u9D6A\u9D6C\u9E92\u9E97\u9E93\u9EB4\u52F8\u56A8\u56B7\u56B6\u56B4\u56BC\u58E4\u5B40\u5B43\u5B7D\u5BF6\u5DC9\u61F8\u61FA\u6518\u6514\u6519\u66E6\u6727\u6AEC\u703E\u7030\u7032\u7210\u737B\u74CF\u7662\u7665\u7926\u792A\u792C\u792B\u7AC7\u7AF6\u7C4C\u7C43\u7C4D\u7CEF\u7CF0\u8FAE\u7E7D\u7E7C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E82\u7F4C\u8000\u81DA\u8266\u85FB\u85F9\u8611\u85FA\u8606\u860B\u8607\u860A\u8814\u8815\u8964\u89BA\u89F8\u8B70\u8B6C\u8B66\u8B6F\u8B5F\u8B6B\u8D0F\u8D0D\u8E89\u8E81\u8E85\u8E82\u91B4\u91CB\u9418\u9403\u93FD\u95E1\u9730\u98C4\u9952\u9951\u99A8\u9A2B\u9A30\u9A37\u9A35\u9C13\u9C0D\u9E79\u9EB5\u9EE8\u9F2F\u9F5F\u9F63\u9F61\u5137\u5138\u56C1\u56C0\u56C2\u5914\u5C6C\u5DCD\u61FC\u61FE\u651D\u651C\u6595\u66E9\u6AFB\u6B04\u6AFA\u6BB2\u704C\u721B\u72A7\u74D6\u74D4\u7669\u77D3\u7C50\u7E8F\u7E8C\u7FBC\u8617\u862D\u861A\u8823\u8822\u8821\u881F\u896A\u896C\u89BD\u8B74\uFFFD".split("");
      for (j = 0; j != D[196].length; ++j)
        if (D[196][j].charCodeAt(0) !== 65533) {
          e[D[196][j]] = 50176 + j;
          d[50176 + j] = D[196][j];
        }
      D[197] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B77\u8B7D\u8D13\u8E8A\u8E8D\u8E8B\u8F5F\u8FAF\u91BA\u942E\u9433\u9435\u943A\u9438\u9432\u942B\u95E2\u9738\u9739\u9732\u97FF\u9867\u9865\u9957\u9A45\u9A43\u9A40\u9A3E\u9ACF\u9B54\u9B51\u9C2D\u9C25\u9DAF\u9DB4\u9DC2\u9DB8\u9E9D\u9EEF\u9F19\u9F5C\u9F66\u9F67\u513C\u513B\u56C8\u56CA\u56C9\u5B7F\u5DD4\u5DD2\u5F4E\u61FF\u6524\u6B0A\u6B61\u7051\u7058\u7380\u74E4\u758A\u766E\u766C\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u79B3\u7C60\u7C5F\u807E\u807D\u81DF\u8972\u896F\u89FC\u8B80\u8D16\u8D17\u8E91\u8E93\u8F61\u9148\u9444\u9451\u9452\u973D\u973E\u97C3\u97C1\u986B\u9955\u9A55\u9A4D\u9AD2\u9B1A\u9C49\u9C31\u9C3E\u9C3B\u9DD3\u9DD7\u9F34\u9F6C\u9F6A\u9F94\u56CC\u5DD6\u6200\u6523\u652B\u652A\u66EC\u6B10\u74DA\u7ACA\u7C64\u7C63\u7C65\u7E93\u7E96\u7E94\u81E2\u8638\u863F\u8831\u8B8A\u9090\u908F\u9463\u9460\u9464\u9768\u986F\u995C\u9A5A\u9A5B\u9A57\u9AD3\u9AD4\u9AD1\u9C54\u9C57\u9C56\u9DE5\u9E9F\u9EF4\u56D1\u58E9\u652C\u705E\u7671\u7672\u77D7\u7F50\u7F88\u8836\u8839\u8862\u8B93\u8B92\uFFFD".split("");
      for (j = 0; j != D[197].length; ++j)
        if (D[197][j].charCodeAt(0) !== 65533) {
          e[D[197][j]] = 50432 + j;
          d[50432 + j] = D[197][j];
        }
      D[198] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B96\u8277\u8D1B\u91C0\u946A\u9742\u9748\u9744\u97C6\u9870\u9A5F\u9B22\u9B58\u9C5F\u9DF9\u9DFA\u9E7C\u9E7D\u9F07\u9F77\u9F72\u5EF3\u6B16\u7063\u7C6C\u7C6E\u883B\u89C0\u8EA1\u91C1\u9472\u9470\u9871\u995E\u9AD6\u9B23\u9ECC\u7064\u77DA\u8B9A\u9477\u97C9\u9A62\u9A65\u7E9C\u8B9C\u8EAA\u91C5\u947D\u947E\u947C\u9C77\u9C78\u9EF7\u8C54\u947F\u9E1A\u7228\u9A6A\u9B31\u9E1B\u9E1E\u7C72\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[198].length; ++j)
        if (D[198][j].charCodeAt(0) !== 65533) {
          e[D[198][j]] = 50688 + j;
          d[50688 + j] = D[198][j];
        }
      D[201] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E42\u4E5C\u51F5\u531A\u5382\u4E07\u4E0C\u4E47\u4E8D\u56D7\uFA0C\u5C6E\u5F73\u4E0F\u5187\u4E0E\u4E2E\u4E93\u4EC2\u4EC9\u4EC8\u5198\u52FC\u536C\u53B9\u5720\u5903\u592C\u5C10\u5DFF\u65E1\u6BB3\u6BCC\u6C14\u723F\u4E31\u4E3C\u4EE8\u4EDC\u4EE9\u4EE1\u4EDD\u4EDA\u520C\u531C\u534C\u5722\u5723\u5917\u592F\u5B81\u5B84\u5C12\u5C3B\u5C74\u5C73\u5E04\u5E80\u5E82\u5FC9\u6209\u6250\u6C15\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6C36\u6C43\u6C3F\u6C3B\u72AE\u72B0\u738A\u79B8\u808A\u961E\u4F0E\u4F18\u4F2C\u4EF5\u4F14\u4EF1\u4F00\u4EF7\u4F08\u4F1D\u4F02\u4F05\u4F22\u4F13\u4F04\u4EF4\u4F12\u51B1\u5213\u5209\u5210\u52A6\u5322\u531F\u534D\u538A\u5407\u56E1\u56DF\u572E\u572A\u5734\u593C\u5980\u597C\u5985\u597B\u597E\u5977\u597F\u5B56\u5C15\u5C25\u5C7C\u5C7A\u5C7B\u5C7E\u5DDF\u5E75\u5E84\u5F02\u5F1A\u5F74\u5FD5\u5FD4\u5FCF\u625C\u625E\u6264\u6261\u6266\u6262\u6259\u6260\u625A\u6265\u65EF\u65EE\u673E\u6739\u6738\u673B\u673A\u673F\u673C\u6733\u6C18\u6C46\u6C52\u6C5C\u6C4F\u6C4A\u6C54\u6C4B\uFFFD".split("");
      for (j = 0; j != D[201].length; ++j)
        if (D[201][j].charCodeAt(0) !== 65533) {
          e[D[201][j]] = 51456 + j;
          d[51456 + j] = D[201][j];
        }
      D[202] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6C4C\u7071\u725E\u72B4\u72B5\u738E\u752A\u767F\u7A75\u7F51\u8278\u827C\u8280\u827D\u827F\u864D\u897E\u9099\u9097\u9098\u909B\u9094\u9622\u9624\u9620\u9623\u4F56\u4F3B\u4F62\u4F49\u4F53\u4F64\u4F3E\u4F67\u4F52\u4F5F\u4F41\u4F58\u4F2D\u4F33\u4F3F\u4F61\u518F\u51B9\u521C\u521E\u5221\u52AD\u52AE\u5309\u5363\u5372\u538E\u538F\u5430\u5437\u542A\u5454\u5445\u5419\u541C\u5425\u5418\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u543D\u544F\u5441\u5428\u5424\u5447\u56EE\u56E7\u56E5\u5741\u5745\u574C\u5749\u574B\u5752\u5906\u5940\u59A6\u5998\u59A0\u5997\u598E\u59A2\u5990\u598F\u59A7\u59A1\u5B8E\u5B92\u5C28\u5C2A\u5C8D\u5C8F\u5C88\u5C8B\u5C89\u5C92\u5C8A\u5C86\u5C93\u5C95\u5DE0\u5E0A\u5E0E\u5E8B\u5E89\u5E8C\u5E88\u5E8D\u5F05\u5F1D\u5F78\u5F76\u5FD2\u5FD1\u5FD0\u5FED\u5FE8\u5FEE\u5FF3\u5FE1\u5FE4\u5FE3\u5FFA\u5FEF\u5FF7\u5FFB\u6000\u5FF4\u623A\u6283\u628C\u628E\u628F\u6294\u6287\u6271\u627B\u627A\u6270\u6281\u6288\u6277\u627D\u6272\u6274\u6537\u65F0\u65F4\u65F3\u65F2\u65F5\u6745\u6747\uFFFD".split("");
      for (j = 0; j != D[202].length; ++j)
        if (D[202][j].charCodeAt(0) !== 65533) {
          e[D[202][j]] = 51712 + j;
          d[51712 + j] = D[202][j];
        }
      D[203] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6759\u6755\u674C\u6748\u675D\u674D\u675A\u674B\u6BD0\u6C19\u6C1A\u6C78\u6C67\u6C6B\u6C84\u6C8B\u6C8F\u6C71\u6C6F\u6C69\u6C9A\u6C6D\u6C87\u6C95\u6C9C\u6C66\u6C73\u6C65\u6C7B\u6C8E\u7074\u707A\u7263\u72BF\u72BD\u72C3\u72C6\u72C1\u72BA\u72C5\u7395\u7397\u7393\u7394\u7392\u753A\u7539\u7594\u7595\u7681\u793D\u8034\u8095\u8099\u8090\u8092\u809C\u8290\u828F\u8285\u828E\u8291\u8293\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u828A\u8283\u8284\u8C78\u8FC9\u8FBF\u909F\u90A1\u90A5\u909E\u90A7\u90A0\u9630\u9628\u962F\u962D\u4E33\u4F98\u4F7C\u4F85\u4F7D\u4F80\u4F87\u4F76\u4F74\u4F89\u4F84\u4F77\u4F4C\u4F97\u4F6A\u4F9A\u4F79\u4F81\u4F78\u4F90\u4F9C\u4F94\u4F9E\u4F92\u4F82\u4F95\u4F6B\u4F6E\u519E\u51BC\u51BE\u5235\u5232\u5233\u5246\u5231\u52BC\u530A\u530B\u533C\u5392\u5394\u5487\u547F\u5481\u5491\u5482\u5488\u546B\u547A\u547E\u5465\u546C\u5474\u5466\u548D\u546F\u5461\u5460\u5498\u5463\u5467\u5464\u56F7\u56F9\u576F\u5772\u576D\u576B\u5771\u5770\u5776\u5780\u5775\u577B\u5773\u5774\u5762\uFFFD".split("");
      for (j = 0; j != D[203].length; ++j)
        if (D[203][j].charCodeAt(0) !== 65533) {
          e[D[203][j]] = 51968 + j;
          d[51968 + j] = D[203][j];
        }
      D[204] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5768\u577D\u590C\u5945\u59B5\u59BA\u59CF\u59CE\u59B2\u59CC\u59C1\u59B6\u59BC\u59C3\u59D6\u59B1\u59BD\u59C0\u59C8\u59B4\u59C7\u5B62\u5B65\u5B93\u5B95\u5C44\u5C47\u5CAE\u5CA4\u5CA0\u5CB5\u5CAF\u5CA8\u5CAC\u5C9F\u5CA3\u5CAD\u5CA2\u5CAA\u5CA7\u5C9D\u5CA5\u5CB6\u5CB0\u5CA6\u5E17\u5E14\u5E19\u5F28\u5F22\u5F23\u5F24\u5F54\u5F82\u5F7E\u5F7D\u5FDE\u5FE5\u602D\u6026\u6019\u6032\u600B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6034\u600A\u6017\u6033\u601A\u601E\u602C\u6022\u600D\u6010\u602E\u6013\u6011\u600C\u6009\u601C\u6214\u623D\u62AD\u62B4\u62D1\u62BE\u62AA\u62B6\u62CA\u62AE\u62B3\u62AF\u62BB\u62A9\u62B0\u62B8\u653D\u65A8\u65BB\u6609\u65FC\u6604\u6612\u6608\u65FB\u6603\u660B\u660D\u6605\u65FD\u6611\u6610\u66F6\u670A\u6785\u676C\u678E\u6792\u6776\u677B\u6798\u6786\u6784\u6774\u678D\u678C\u677A\u679F\u6791\u6799\u6783\u677D\u6781\u6778\u6779\u6794\u6B25\u6B80\u6B7E\u6BDE\u6C1D\u6C93\u6CEC\u6CEB\u6CEE\u6CD9\u6CB6\u6CD4\u6CAD\u6CE7\u6CB7\u6CD0\u6CC2\u6CBA\u6CC3\u6CC6\u6CED\u6CF2\uFFFD".split("");
      for (j = 0; j != D[204].length; ++j)
        if (D[204][j].charCodeAt(0) !== 65533) {
          e[D[204][j]] = 52224 + j;
          d[52224 + j] = D[204][j];
        }
      D[205] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6CD2\u6CDD\u6CB4\u6C8A\u6C9D\u6C80\u6CDE\u6CC0\u6D30\u6CCD\u6CC7\u6CB0\u6CF9\u6CCF\u6CE9\u6CD1\u7094\u7098\u7085\u7093\u7086\u7084\u7091\u7096\u7082\u709A\u7083\u726A\u72D6\u72CB\u72D8\u72C9\u72DC\u72D2\u72D4\u72DA\u72CC\u72D1\u73A4\u73A1\u73AD\u73A6\u73A2\u73A0\u73AC\u739D\u74DD\u74E8\u753F\u7540\u753E\u758C\u7598\u76AF\u76F3\u76F1\u76F0\u76F5\u77F8\u77FC\u77F9\u77FB\u77FA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u77F7\u7942\u793F\u79C5\u7A78\u7A7B\u7AFB\u7C75\u7CFD\u8035\u808F\u80AE\u80A3\u80B8\u80B5\u80AD\u8220\u82A0\u82C0\u82AB\u829A\u8298\u829B\u82B5\u82A7\u82AE\u82BC\u829E\u82BA\u82B4\u82A8\u82A1\u82A9\u82C2\u82A4\u82C3\u82B6\u82A2\u8670\u866F\u866D\u866E\u8C56\u8FD2\u8FCB\u8FD3\u8FCD\u8FD6\u8FD5\u8FD7\u90B2\u90B4\u90AF\u90B3\u90B0\u9639\u963D\u963C\u963A\u9643\u4FCD\u4FC5\u4FD3\u4FB2\u4FC9\u4FCB\u4FC1\u4FD4\u4FDC\u4FD9\u4FBB\u4FB3\u4FDB\u4FC7\u4FD6\u4FBA\u4FC0\u4FB9\u4FEC\u5244\u5249\u52C0\u52C2\u533D\u537C\u5397\u5396\u5399\u5398\u54BA\u54A1\u54AD\u54A5\u54CF\uFFFD".split("");
      for (j = 0; j != D[205].length; ++j)
        if (D[205][j].charCodeAt(0) !== 65533) {
          e[D[205][j]] = 52480 + j;
          d[52480 + j] = D[205][j];
        }
      D[206] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u54C3\u830D\u54B7\u54AE\u54D6\u54B6\u54C5\u54C6\u54A0\u5470\u54BC\u54A2\u54BE\u5472\u54DE\u54B0\u57B5\u579E\u579F\u57A4\u578C\u5797\u579D\u579B\u5794\u5798\u578F\u5799\u57A5\u579A\u5795\u58F4\u590D\u5953\u59E1\u59DE\u59EE\u5A00\u59F1\u59DD\u59FA\u59FD\u59FC\u59F6\u59E4\u59F2\u59F7\u59DB\u59E9\u59F3\u59F5\u59E0\u59FE\u59F4\u59ED\u5BA8\u5C4C\u5CD0\u5CD8\u5CCC\u5CD7\u5CCB\u5CDB\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5CDE\u5CDA\u5CC9\u5CC7\u5CCA\u5CD6\u5CD3\u5CD4\u5CCF\u5CC8\u5CC6\u5CCE\u5CDF\u5CF8\u5DF9\u5E21\u5E22\u5E23\u5E20\u5E24\u5EB0\u5EA4\u5EA2\u5E9B\u5EA3\u5EA5\u5F07\u5F2E\u5F56\u5F86\u6037\u6039\u6054\u6072\u605E\u6045\u6053\u6047\u6049\u605B\u604C\u6040\u6042\u605F\u6024\u6044\u6058\u6066\u606E\u6242\u6243\u62CF\u630D\u630B\u62F5\u630E\u6303\u62EB\u62F9\u630F\u630C\u62F8\u62F6\u6300\u6313\u6314\u62FA\u6315\u62FB\u62F0\u6541\u6543\u65AA\u65BF\u6636\u6621\u6632\u6635\u661C\u6626\u6622\u6633\u662B\u663A\u661D\u6634\u6639\u662E\u670F\u6710\u67C1\u67F2\u67C8\u67BA\uFFFD".split("");
      for (j = 0; j != D[206].length; ++j)
        if (D[206][j].charCodeAt(0) !== 65533) {
          e[D[206][j]] = 52736 + j;
          d[52736 + j] = D[206][j];
        }
      D[207] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u67DC\u67BB\u67F8\u67D8\u67C0\u67B7\u67C5\u67EB\u67E4\u67DF\u67B5\u67CD\u67B3\u67F7\u67F6\u67EE\u67E3\u67C2\u67B9\u67CE\u67E7\u67F0\u67B2\u67FC\u67C6\u67ED\u67CC\u67AE\u67E6\u67DB\u67FA\u67C9\u67CA\u67C3\u67EA\u67CB\u6B28\u6B82\u6B84\u6BB6\u6BD6\u6BD8\u6BE0\u6C20\u6C21\u6D28\u6D34\u6D2D\u6D1F\u6D3C\u6D3F\u6D12\u6D0A\u6CDA\u6D33\u6D04\u6D19\u6D3A\u6D1A\u6D11\u6D00\u6D1D\u6D42\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D01\u6D18\u6D37\u6D03\u6D0F\u6D40\u6D07\u6D20\u6D2C\u6D08\u6D22\u6D09\u6D10\u70B7\u709F\u70BE\u70B1\u70B0\u70A1\u70B4\u70B5\u70A9\u7241\u7249\u724A\u726C\u7270\u7273\u726E\u72CA\u72E4\u72E8\u72EB\u72DF\u72EA\u72E6\u72E3\u7385\u73CC\u73C2\u73C8\u73C5\u73B9\u73B6\u73B5\u73B4\u73EB\u73BF\u73C7\u73BE\u73C3\u73C6\u73B8\u73CB\u74EC\u74EE\u752E\u7547\u7548\u75A7\u75AA\u7679\u76C4\u7708\u7703\u7704\u7705\u770A\u76F7\u76FB\u76FA\u77E7\u77E8\u7806\u7811\u7812\u7805\u7810\u780F\u780E\u7809\u7803\u7813\u794A\u794C\u794B\u7945\u7944\u79D5\u79CD\u79CF\u79D6\u79CE\u7A80\uFFFD".split("");
      for (j = 0; j != D[207].length; ++j)
        if (D[207][j].charCodeAt(0) !== 65533) {
          e[D[207][j]] = 52992 + j;
          d[52992 + j] = D[207][j];
        }
      D[208] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A7E\u7AD1\u7B00\u7B01\u7C7A\u7C78\u7C79\u7C7F\u7C80\u7C81\u7D03\u7D08\u7D01\u7F58\u7F91\u7F8D\u7FBE\u8007\u800E\u800F\u8014\u8037\u80D8\u80C7\u80E0\u80D1\u80C8\u80C2\u80D0\u80C5\u80E3\u80D9\u80DC\u80CA\u80D5\u80C9\u80CF\u80D7\u80E6\u80CD\u81FF\u8221\u8294\u82D9\u82FE\u82F9\u8307\u82E8\u8300\u82D5\u833A\u82EB\u82D6\u82F4\u82EC\u82E1\u82F2\u82F5\u830C\u82FB\u82F6\u82F0\u82EA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u82E4\u82E0\u82FA\u82F3\u82ED\u8677\u8674\u867C\u8673\u8841\u884E\u8867\u886A\u8869\u89D3\u8A04\u8A07\u8D72\u8FE3\u8FE1\u8FEE\u8FE0\u90F1\u90BD\u90BF\u90D5\u90C5\u90BE\u90C7\u90CB\u90C8\u91D4\u91D3\u9654\u964F\u9651\u9653\u964A\u964E\u501E\u5005\u5007\u5013\u5022\u5030\u501B\u4FF5\u4FF4\u5033\u5037\u502C\u4FF6\u4FF7\u5017\u501C\u5020\u5027\u5035\u502F\u5031\u500E\u515A\u5194\u5193\u51CA\u51C4\u51C5\u51C8\u51CE\u5261\u525A\u5252\u525E\u525F\u5255\u5262\u52CD\u530E\u539E\u5526\u54E2\u5517\u5512\u54E7\u54F3\u54E4\u551A\u54FF\u5504\u5508\u54EB\u5511\u5505\u54F1\uFFFD".split("");
      for (j = 0; j != D[208].length; ++j)
        if (D[208][j].charCodeAt(0) !== 65533) {
          e[D[208][j]] = 53248 + j;
          d[53248 + j] = D[208][j];
        }
      D[209] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u550A\u54FB\u54F7\u54F8\u54E0\u550E\u5503\u550B\u5701\u5702\u57CC\u5832\u57D5\u57D2\u57BA\u57C6\u57BD\u57BC\u57B8\u57B6\u57BF\u57C7\u57D0\u57B9\u57C1\u590E\u594A\u5A19\u5A16\u5A2D\u5A2E\u5A15\u5A0F\u5A17\u5A0A\u5A1E\u5A33\u5B6C\u5BA7\u5BAD\u5BAC\u5C03\u5C56\u5C54\u5CEC\u5CFF\u5CEE\u5CF1\u5CF7\u5D00\u5CF9\u5E29\u5E28\u5EA8\u5EAE\u5EAA\u5EAC\u5F33\u5F30\u5F67\u605D\u605A\u6067\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6041\u60A2\u6088\u6080\u6092\u6081\u609D\u6083\u6095\u609B\u6097\u6087\u609C\u608E\u6219\u6246\u62F2\u6310\u6356\u632C\u6344\u6345\u6336\u6343\u63E4\u6339\u634B\u634A\u633C\u6329\u6341\u6334\u6358\u6354\u6359\u632D\u6347\u6333\u635A\u6351\u6338\u6357\u6340\u6348\u654A\u6546\u65C6\u65C3\u65C4\u65C2\u664A\u665F\u6647\u6651\u6712\u6713\u681F\u681A\u6849\u6832\u6833\u683B\u684B\u684F\u6816\u6831\u681C\u6835\u682B\u682D\u682F\u684E\u6844\u6834\u681D\u6812\u6814\u6826\u6828\u682E\u684D\u683A\u6825\u6820\u6B2C\u6B2F\u6B2D\u6B31\u6B34\u6B6D\u8082\u6B88\u6BE6\u6BE4\uFFFD".split("");
      for (j = 0; j != D[209].length; ++j)
        if (D[209][j].charCodeAt(0) !== 65533) {
          e[D[209][j]] = 53504 + j;
          d[53504 + j] = D[209][j];
        }
      D[210] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6BE8\u6BE3\u6BE2\u6BE7\u6C25\u6D7A\u6D63\u6D64\u6D76\u6D0D\u6D61\u6D92\u6D58\u6D62\u6D6D\u6D6F\u6D91\u6D8D\u6DEF\u6D7F\u6D86\u6D5E\u6D67\u6D60\u6D97\u6D70\u6D7C\u6D5F\u6D82\u6D98\u6D2F\u6D68\u6D8B\u6D7E\u6D80\u6D84\u6D16\u6D83\u6D7B\u6D7D\u6D75\u6D90\u70DC\u70D3\u70D1\u70DD\u70CB\u7F39\u70E2\u70D7\u70D2\u70DE\u70E0\u70D4\u70CD\u70C5\u70C6\u70C7\u70DA\u70CE\u70E1\u7242\u7278\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7277\u7276\u7300\u72FA\u72F4\u72FE\u72F6\u72F3\u72FB\u7301\u73D3\u73D9\u73E5\u73D6\u73BC\u73E7\u73E3\u73E9\u73DC\u73D2\u73DB\u73D4\u73DD\u73DA\u73D7\u73D8\u73E8\u74DE\u74DF\u74F4\u74F5\u7521\u755B\u755F\u75B0\u75C1\u75BB\u75C4\u75C0\u75BF\u75B6\u75BA\u768A\u76C9\u771D\u771B\u7710\u7713\u7712\u7723\u7711\u7715\u7719\u771A\u7722\u7727\u7823\u782C\u7822\u7835\u782F\u7828\u782E\u782B\u7821\u7829\u7833\u782A\u7831\u7954\u795B\u794F\u795C\u7953\u7952\u7951\u79EB\u79EC\u79E0\u79EE\u79ED\u79EA\u79DC\u79DE\u79DD\u7A86\u7A89\u7A85\u7A8B\u7A8C\u7A8A\u7A87\u7AD8\u7B10\uFFFD".split("");
      for (j = 0; j != D[210].length; ++j)
        if (D[210][j].charCodeAt(0) !== 65533) {
          e[D[210][j]] = 53760 + j;
          d[53760 + j] = D[210][j];
        }
      D[211] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7B04\u7B13\u7B05\u7B0F\u7B08\u7B0A\u7B0E\u7B09\u7B12\u7C84\u7C91\u7C8A\u7C8C\u7C88\u7C8D\u7C85\u7D1E\u7D1D\u7D11\u7D0E\u7D18\u7D16\u7D13\u7D1F\u7D12\u7D0F\u7D0C\u7F5C\u7F61\u7F5E\u7F60\u7F5D\u7F5B\u7F96\u7F92\u7FC3\u7FC2\u7FC0\u8016\u803E\u8039\u80FA\u80F2\u80F9\u80F5\u8101\u80FB\u8100\u8201\u822F\u8225\u8333\u832D\u8344\u8319\u8351\u8325\u8356\u833F\u8341\u8326\u831C\u8322\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8342\u834E\u831B\u832A\u8308\u833C\u834D\u8316\u8324\u8320\u8337\u832F\u8329\u8347\u8345\u834C\u8353\u831E\u832C\u834B\u8327\u8348\u8653\u8652\u86A2\u86A8\u8696\u868D\u8691\u869E\u8687\u8697\u8686\u868B\u869A\u8685\u86A5\u8699\u86A1\u86A7\u8695\u8698\u868E\u869D\u8690\u8694\u8843\u8844\u886D\u8875\u8876\u8872\u8880\u8871\u887F\u886F\u8883\u887E\u8874\u887C\u8A12\u8C47\u8C57\u8C7B\u8CA4\u8CA3\u8D76\u8D78\u8DB5\u8DB7\u8DB6\u8ED1\u8ED3\u8FFE\u8FF5\u9002\u8FFF\u8FFB\u9004\u8FFC\u8FF6\u90D6\u90E0\u90D9\u90DA\u90E3\u90DF\u90E5\u90D8\u90DB\u90D7\u90DC\u90E4\u9150\uFFFD".split("");
      for (j = 0; j != D[211].length; ++j)
        if (D[211][j].charCodeAt(0) !== 65533) {
          e[D[211][j]] = 54016 + j;
          d[54016 + j] = D[211][j];
        }
      D[212] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u914E\u914F\u91D5\u91E2\u91DA\u965C\u965F\u96BC\u98E3\u9ADF\u9B2F\u4E7F\u5070\u506A\u5061\u505E\u5060\u5053\u504B\u505D\u5072\u5048\u504D\u5041\u505B\u504A\u5062\u5015\u5045\u505F\u5069\u506B\u5063\u5064\u5046\u5040\u506E\u5073\u5057\u5051\u51D0\u526B\u526D\u526C\u526E\u52D6\u52D3\u532D\u539C\u5575\u5576\u553C\u554D\u5550\u5534\u552A\u5551\u5562\u5536\u5535\u5530\u5552\u5545\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u550C\u5532\u5565\u554E\u5539\u5548\u552D\u553B\u5540\u554B\u570A\u5707\u57FB\u5814\u57E2\u57F6\u57DC\u57F4\u5800\u57ED\u57FD\u5808\u57F8\u580B\u57F3\u57CF\u5807\u57EE\u57E3\u57F2\u57E5\u57EC\u57E1\u580E\u57FC\u5810\u57E7\u5801\u580C\u57F1\u57E9\u57F0\u580D\u5804\u595C\u5A60\u5A58\u5A55\u5A67\u5A5E\u5A38\u5A35\u5A6D\u5A50\u5A5F\u5A65\u5A6C\u5A53\u5A64\u5A57\u5A43\u5A5D\u5A52\u5A44\u5A5B\u5A48\u5A8E\u5A3E\u5A4D\u5A39\u5A4C\u5A70\u5A69\u5A47\u5A51\u5A56\u5A42\u5A5C\u5B72\u5B6E\u5BC1\u5BC0\u5C59\u5D1E\u5D0B\u5D1D\u5D1A\u5D20\u5D0C\u5D28\u5D0D\u5D26\u5D25\u5D0F\uFFFD".split("");
      for (j = 0; j != D[212].length; ++j)
        if (D[212][j].charCodeAt(0) !== 65533) {
          e[D[212][j]] = 54272 + j;
          d[54272 + j] = D[212][j];
        }
      D[213] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5D30\u5D12\u5D23\u5D1F\u5D2E\u5E3E\u5E34\u5EB1\u5EB4\u5EB9\u5EB2\u5EB3\u5F36\u5F38\u5F9B\u5F96\u5F9F\u608A\u6090\u6086\u60BE\u60B0\u60BA\u60D3\u60D4\u60CF\u60E4\u60D9\u60DD\u60C8\u60B1\u60DB\u60B7\u60CA\u60BF\u60C3\u60CD\u60C0\u6332\u6365\u638A\u6382\u637D\u63BD\u639E\u63AD\u639D\u6397\u63AB\u638E\u636F\u6387\u6390\u636E\u63AF\u6375\u639C\u636D\u63AE\u637C\u63A4\u633B\u639F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6378\u6385\u6381\u6391\u638D\u6370\u6553\u65CD\u6665\u6661\u665B\u6659\u665C\u6662\u6718\u6879\u6887\u6890\u689C\u686D\u686E\u68AE\u68AB\u6956\u686F\u68A3\u68AC\u68A9\u6875\u6874\u68B2\u688F\u6877\u6892\u687C\u686B\u6872\u68AA\u6880\u6871\u687E\u689B\u6896\u688B\u68A0\u6889\u68A4\u6878\u687B\u6891\u688C\u688A\u687D\u6B36\u6B33\u6B37\u6B38\u6B91\u6B8F\u6B8D\u6B8E\u6B8C\u6C2A\u6DC0\u6DAB\u6DB4\u6DB3\u6E74\u6DAC\u6DE9\u6DE2\u6DB7\u6DF6\u6DD4\u6E00\u6DC8\u6DE0\u6DDF\u6DD6\u6DBE\u6DE5\u6DDC\u6DDD\u6DDB\u6DF4\u6DCA\u6DBD\u6DED\u6DF0\u6DBA\u6DD5\u6DC2\u6DCF\u6DC9\uFFFD".split("");
      for (j = 0; j != D[213].length; ++j)
        if (D[213][j].charCodeAt(0) !== 65533) {
          e[D[213][j]] = 54528 + j;
          d[54528 + j] = D[213][j];
        }
      D[214] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6DD0\u6DF2\u6DD3\u6DFD\u6DD7\u6DCD\u6DE3\u6DBB\u70FA\u710D\u70F7\u7117\u70F4\u710C\u70F0\u7104\u70F3\u7110\u70FC\u70FF\u7106\u7113\u7100\u70F8\u70F6\u710B\u7102\u710E\u727E\u727B\u727C\u727F\u731D\u7317\u7307\u7311\u7318\u730A\u7308\u72FF\u730F\u731E\u7388\u73F6\u73F8\u73F5\u7404\u7401\u73FD\u7407\u7400\u73FA\u73FC\u73FF\u740C\u740B\u73F4\u7408\u7564\u7563\u75CE\u75D2\u75CF\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u75CB\u75CC\u75D1\u75D0\u768F\u7689\u76D3\u7739\u772F\u772D\u7731\u7732\u7734\u7733\u773D\u7725\u773B\u7735\u7848\u7852\u7849\u784D\u784A\u784C\u7826\u7845\u7850\u7964\u7967\u7969\u796A\u7963\u796B\u7961\u79BB\u79FA\u79F8\u79F6\u79F7\u7A8F\u7A94\u7A90\u7B35\u7B47\u7B34\u7B25\u7B30\u7B22\u7B24\u7B33\u7B18\u7B2A\u7B1D\u7B31\u7B2B\u7B2D\u7B2F\u7B32\u7B38\u7B1A\u7B23\u7C94\u7C98\u7C96\u7CA3\u7D35\u7D3D\u7D38\u7D36\u7D3A\u7D45\u7D2C\u7D29\u7D41\u7D47\u7D3E\u7D3F\u7D4A\u7D3B\u7D28\u7F63\u7F95\u7F9C\u7F9D\u7F9B\u7FCA\u7FCB\u7FCD\u7FD0\u7FD1\u7FC7\u7FCF\u7FC9\u801F\uFFFD".split("");
      for (j = 0; j != D[214].length; ++j)
        if (D[214][j].charCodeAt(0) !== 65533) {
          e[D[214][j]] = 54784 + j;
          d[54784 + j] = D[214][j];
        }
      D[215] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u801E\u801B\u8047\u8043\u8048\u8118\u8125\u8119\u811B\u812D\u811F\u812C\u811E\u8121\u8115\u8127\u811D\u8122\u8211\u8238\u8233\u823A\u8234\u8232\u8274\u8390\u83A3\u83A8\u838D\u837A\u8373\u83A4\u8374\u838F\u8381\u8395\u8399\u8375\u8394\u83A9\u837D\u8383\u838C\u839D\u839B\u83AA\u838B\u837E\u83A5\u83AF\u8388\u8397\u83B0\u837F\u83A6\u8387\u83AE\u8376\u839A\u8659\u8656\u86BF\u86B7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u86C2\u86C1\u86C5\u86BA\u86B0\u86C8\u86B9\u86B3\u86B8\u86CC\u86B4\u86BB\u86BC\u86C3\u86BD\u86BE\u8852\u8889\u8895\u88A8\u88A2\u88AA\u889A\u8891\u88A1\u889F\u8898\u88A7\u8899\u889B\u8897\u88A4\u88AC\u888C\u8893\u888E\u8982\u89D6\u89D9\u89D5\u8A30\u8A27\u8A2C\u8A1E\u8C39\u8C3B\u8C5C\u8C5D\u8C7D\u8CA5\u8D7D\u8D7B\u8D79\u8DBC\u8DC2\u8DB9\u8DBF\u8DC1\u8ED8\u8EDE\u8EDD\u8EDC\u8ED7\u8EE0\u8EE1\u9024\u900B\u9011\u901C\u900C\u9021\u90EF\u90EA\u90F0\u90F4\u90F2\u90F3\u90D4\u90EB\u90EC\u90E9\u9156\u9158\u915A\u9153\u9155\u91EC\u91F4\u91F1\u91F3\u91F8\u91E4\u91F9\u91EA\uFFFD".split("");
      for (j = 0; j != D[215].length; ++j)
        if (D[215][j].charCodeAt(0) !== 65533) {
          e[D[215][j]] = 55040 + j;
          d[55040 + j] = D[215][j];
        }
      D[216] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u91EB\u91F7\u91E8\u91EE\u957A\u9586\u9588\u967C\u966D\u966B\u9671\u966F\u96BF\u976A\u9804\u98E5\u9997\u509B\u5095\u5094\u509E\u508B\u50A3\u5083\u508C\u508E\u509D\u5068\u509C\u5092\u5082\u5087\u515F\u51D4\u5312\u5311\u53A4\u53A7\u5591\u55A8\u55A5\u55AD\u5577\u5645\u55A2\u5593\u5588\u558F\u55B5\u5581\u55A3\u5592\u55A4\u557D\u558C\u55A6\u557F\u5595\u55A1\u558E\u570C\u5829\u5837\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5819\u581E\u5827\u5823\u5828\u57F5\u5848\u5825\u581C\u581B\u5833\u583F\u5836\u582E\u5839\u5838\u582D\u582C\u583B\u5961\u5AAF\u5A94\u5A9F\u5A7A\u5AA2\u5A9E\u5A78\u5AA6\u5A7C\u5AA5\u5AAC\u5A95\u5AAE\u5A37\u5A84\u5A8A\u5A97\u5A83\u5A8B\u5AA9\u5A7B\u5A7D\u5A8C\u5A9C\u5A8F\u5A93\u5A9D\u5BEA\u5BCD\u5BCB\u5BD4\u5BD1\u5BCA\u5BCE\u5C0C\u5C30\u5D37\u5D43\u5D6B\u5D41\u5D4B\u5D3F\u5D35\u5D51\u5D4E\u5D55\u5D33\u5D3A\u5D52\u5D3D\u5D31\u5D59\u5D42\u5D39\u5D49\u5D38\u5D3C\u5D32\u5D36\u5D40\u5D45\u5E44\u5E41\u5F58\u5FA6\u5FA5\u5FAB\u60C9\u60B9\u60CC\u60E2\u60CE\u60C4\u6114\uFFFD".split("");
      for (j = 0; j != D[216].length; ++j)
        if (D[216][j].charCodeAt(0) !== 65533) {
          e[D[216][j]] = 55296 + j;
          d[55296 + j] = D[216][j];
        }
      D[217] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u60F2\u610A\u6116\u6105\u60F5\u6113\u60F8\u60FC\u60FE\u60C1\u6103\u6118\u611D\u6110\u60FF\u6104\u610B\u624A\u6394\u63B1\u63B0\u63CE\u63E5\u63E8\u63EF\u63C3\u649D\u63F3\u63CA\u63E0\u63F6\u63D5\u63F2\u63F5\u6461\u63DF\u63BE\u63DD\u63DC\u63C4\u63D8\u63D3\u63C2\u63C7\u63CC\u63CB\u63C8\u63F0\u63D7\u63D9\u6532\u6567\u656A\u6564\u655C\u6568\u6565\u658C\u659D\u659E\u65AE\u65D0\u65D2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u667C\u666C\u667B\u6680\u6671\u6679\u666A\u6672\u6701\u690C\u68D3\u6904\u68DC\u692A\u68EC\u68EA\u68F1\u690F\u68D6\u68F7\u68EB\u68E4\u68F6\u6913\u6910\u68F3\u68E1\u6907\u68CC\u6908\u6970\u68B4\u6911\u68EF\u68C6\u6914\u68F8\u68D0\u68FD\u68FC\u68E8\u690B\u690A\u6917\u68CE\u68C8\u68DD\u68DE\u68E6\u68F4\u68D1\u6906\u68D4\u68E9\u6915\u6925\u68C7\u6B39\u6B3B\u6B3F\u6B3C\u6B94\u6B97\u6B99\u6B95\u6BBD\u6BF0\u6BF2\u6BF3\u6C30\u6DFC\u6E46\u6E47\u6E1F\u6E49\u6E88\u6E3C\u6E3D\u6E45\u6E62\u6E2B\u6E3F\u6E41\u6E5D\u6E73\u6E1C\u6E33\u6E4B\u6E40\u6E51\u6E3B\u6E03\u6E2E\u6E5E\uFFFD".split("");
      for (j = 0; j != D[217].length; ++j)
        if (D[217][j].charCodeAt(0) !== 65533) {
          e[D[217][j]] = 55552 + j;
          d[55552 + j] = D[217][j];
        }
      D[218] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6E68\u6E5C\u6E61\u6E31\u6E28\u6E60\u6E71\u6E6B\u6E39\u6E22\u6E30\u6E53\u6E65\u6E27\u6E78\u6E64\u6E77\u6E55\u6E79\u6E52\u6E66\u6E35\u6E36\u6E5A\u7120\u711E\u712F\u70FB\u712E\u7131\u7123\u7125\u7122\u7132\u711F\u7128\u713A\u711B\u724B\u725A\u7288\u7289\u7286\u7285\u728B\u7312\u730B\u7330\u7322\u7331\u7333\u7327\u7332\u732D\u7326\u7323\u7335\u730C\u742E\u742C\u7430\u742B\u7416\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u741A\u7421\u742D\u7431\u7424\u7423\u741D\u7429\u7420\u7432\u74FB\u752F\u756F\u756C\u75E7\u75DA\u75E1\u75E6\u75DD\u75DF\u75E4\u75D7\u7695\u7692\u76DA\u7746\u7747\u7744\u774D\u7745\u774A\u774E\u774B\u774C\u77DE\u77EC\u7860\u7864\u7865\u785C\u786D\u7871\u786A\u786E\u7870\u7869\u7868\u785E\u7862\u7974\u7973\u7972\u7970\u7A02\u7A0A\u7A03\u7A0C\u7A04\u7A99\u7AE6\u7AE4\u7B4A\u7B3B\u7B44\u7B48\u7B4C\u7B4E\u7B40\u7B58\u7B45\u7CA2\u7C9E\u7CA8\u7CA1\u7D58\u7D6F\u7D63\u7D53\u7D56\u7D67\u7D6A\u7D4F\u7D6D\u7D5C\u7D6B\u7D52\u7D54\u7D69\u7D51\u7D5F\u7D4E\u7F3E\u7F3F\u7F65\uFFFD".split("");
      for (j = 0; j != D[218].length; ++j)
        if (D[218][j].charCodeAt(0) !== 65533) {
          e[D[218][j]] = 55808 + j;
          d[55808 + j] = D[218][j];
        }
      D[219] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7F66\u7FA2\u7FA0\u7FA1\u7FD7\u8051\u804F\u8050\u80FE\u80D4\u8143\u814A\u8152\u814F\u8147\u813D\u814D\u813A\u81E6\u81EE\u81F7\u81F8\u81F9\u8204\u823C\u823D\u823F\u8275\u833B\u83CF\u83F9\u8423\u83C0\u83E8\u8412\u83E7\u83E4\u83FC\u83F6\u8410\u83C6\u83C8\u83EB\u83E3\u83BF\u8401\u83DD\u83E5\u83D8\u83FF\u83E1\u83CB\u83CE\u83D6\u83F5\u83C9\u8409\u840F\u83DE\u8411\u8406\u83C2\u83F3\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u83D5\u83FA\u83C7\u83D1\u83EA\u8413\u83C3\u83EC\u83EE\u83C4\u83FB\u83D7\u83E2\u841B\u83DB\u83FE\u86D8\u86E2\u86E6\u86D3\u86E3\u86DA\u86EA\u86DD\u86EB\u86DC\u86EC\u86E9\u86D7\u86E8\u86D1\u8848\u8856\u8855\u88BA\u88D7\u88B9\u88B8\u88C0\u88BE\u88B6\u88BC\u88B7\u88BD\u88B2\u8901\u88C9\u8995\u8998\u8997\u89DD\u89DA\u89DB\u8A4E\u8A4D\u8A39\u8A59\u8A40\u8A57\u8A58\u8A44\u8A45\u8A52\u8A48\u8A51\u8A4A\u8A4C\u8A4F\u8C5F\u8C81\u8C80\u8CBA\u8CBE\u8CB0\u8CB9\u8CB5\u8D84\u8D80\u8D89\u8DD8\u8DD3\u8DCD\u8DC7\u8DD6\u8DDC\u8DCF\u8DD5\u8DD9\u8DC8\u8DD7\u8DC5\u8EEF\u8EF7\u8EFA\uFFFD".split("");
      for (j = 0; j != D[219].length; ++j)
        if (D[219][j].charCodeAt(0) !== 65533) {
          e[D[219][j]] = 56064 + j;
          d[56064 + j] = D[219][j];
        }
      D[220] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8EF9\u8EE6\u8EEE\u8EE5\u8EF5\u8EE7\u8EE8\u8EF6\u8EEB\u8EF1\u8EEC\u8EF4\u8EE9\u902D\u9034\u902F\u9106\u912C\u9104\u90FF\u90FC\u9108\u90F9\u90FB\u9101\u9100\u9107\u9105\u9103\u9161\u9164\u915F\u9162\u9160\u9201\u920A\u9225\u9203\u921A\u9226\u920F\u920C\u9200\u9212\u91FF\u91FD\u9206\u9204\u9227\u9202\u921C\u9224\u9219\u9217\u9205\u9216\u957B\u958D\u958C\u9590\u9687\u967E\u9688\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9689\u9683\u9680\u96C2\u96C8\u96C3\u96F1\u96F0\u976C\u9770\u976E\u9807\u98A9\u98EB\u9CE6\u9EF9\u4E83\u4E84\u4EB6\u50BD\u50BF\u50C6\u50AE\u50C4\u50CA\u50B4\u50C8\u50C2\u50B0\u50C1\u50BA\u50B1\u50CB\u50C9\u50B6\u50B8\u51D7\u527A\u5278\u527B\u527C\u55C3\u55DB\u55CC\u55D0\u55CB\u55CA\u55DD\u55C0\u55D4\u55C4\u55E9\u55BF\u55D2\u558D\u55CF\u55D5\u55E2\u55D6\u55C8\u55F2\u55CD\u55D9\u55C2\u5714\u5853\u5868\u5864\u584F\u584D\u5849\u586F\u5855\u584E\u585D\u5859\u5865\u585B\u583D\u5863\u5871\u58FC\u5AC7\u5AC4\u5ACB\u5ABA\u5AB8\u5AB1\u5AB5\u5AB0\u5ABF\u5AC8\u5ABB\u5AC6\uFFFD".split("");
      for (j = 0; j != D[220].length; ++j)
        if (D[220][j].charCodeAt(0) !== 65533) {
          e[D[220][j]] = 56320 + j;
          d[56320 + j] = D[220][j];
        }
      D[221] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5AB7\u5AC0\u5ACA\u5AB4\u5AB6\u5ACD\u5AB9\u5A90\u5BD6\u5BD8\u5BD9\u5C1F\u5C33\u5D71\u5D63\u5D4A\u5D65\u5D72\u5D6C\u5D5E\u5D68\u5D67\u5D62\u5DF0\u5E4F\u5E4E\u5E4A\u5E4D\u5E4B\u5EC5\u5ECC\u5EC6\u5ECB\u5EC7\u5F40\u5FAF\u5FAD\u60F7\u6149\u614A\u612B\u6145\u6136\u6132\u612E\u6146\u612F\u614F\u6129\u6140\u6220\u9168\u6223\u6225\u6224\u63C5\u63F1\u63EB\u6410\u6412\u6409\u6420\u6424\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6433\u6443\u641F\u6415\u6418\u6439\u6437\u6422\u6423\u640C\u6426\u6430\u6428\u6441\u6435\u642F\u640A\u641A\u6440\u6425\u6427\u640B\u63E7\u641B\u642E\u6421\u640E\u656F\u6592\u65D3\u6686\u668C\u6695\u6690\u668B\u668A\u6699\u6694\u6678\u6720\u6966\u695F\u6938\u694E\u6962\u6971\u693F\u6945\u696A\u6939\u6942\u6957\u6959\u697A\u6948\u6949\u6935\u696C\u6933\u693D\u6965\u68F0\u6978\u6934\u6969\u6940\u696F\u6944\u6976\u6958\u6941\u6974\u694C\u693B\u694B\u6937\u695C\u694F\u6951\u6932\u6952\u692F\u697B\u693C\u6B46\u6B45\u6B43\u6B42\u6B48\u6B41\u6B9B\uFA0D\u6BFB\u6BFC\uFFFD".split("");
      for (j = 0; j != D[221].length; ++j)
        if (D[221][j].charCodeAt(0) !== 65533) {
          e[D[221][j]] = 56576 + j;
          d[56576 + j] = D[221][j];
        }
      D[222] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6BF9\u6BF7\u6BF8\u6E9B\u6ED6\u6EC8\u6E8F\u6EC0\u6E9F\u6E93\u6E94\u6EA0\u6EB1\u6EB9\u6EC6\u6ED2\u6EBD\u6EC1\u6E9E\u6EC9\u6EB7\u6EB0\u6ECD\u6EA6\u6ECF\u6EB2\u6EBE\u6EC3\u6EDC\u6ED8\u6E99\u6E92\u6E8E\u6E8D\u6EA4\u6EA1\u6EBF\u6EB3\u6ED0\u6ECA\u6E97\u6EAE\u6EA3\u7147\u7154\u7152\u7163\u7160\u7141\u715D\u7162\u7172\u7178\u716A\u7161\u7142\u7158\u7143\u714B\u7170\u715F\u7150\u7153\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7144\u714D\u715A\u724F\u728D\u728C\u7291\u7290\u728E\u733C\u7342\u733B\u733A\u7340\u734A\u7349\u7444\u744A\u744B\u7452\u7451\u7457\u7440\u744F\u7450\u744E\u7442\u7446\u744D\u7454\u74E1\u74FF\u74FE\u74FD\u751D\u7579\u7577\u6983\u75EF\u760F\u7603\u75F7\u75FE\u75FC\u75F9\u75F8\u7610\u75FB\u75F6\u75ED\u75F5\u75FD\u7699\u76B5\u76DD\u7755\u775F\u7760\u7752\u7756\u775A\u7769\u7767\u7754\u7759\u776D\u77E0\u7887\u789A\u7894\u788F\u7884\u7895\u7885\u7886\u78A1\u7883\u7879\u7899\u7880\u7896\u787B\u797C\u7982\u797D\u7979\u7A11\u7A18\u7A19\u7A12\u7A17\u7A15\u7A22\u7A13\uFFFD".split("");
      for (j = 0; j != D[222].length; ++j)
        if (D[222][j].charCodeAt(0) !== 65533) {
          e[D[222][j]] = 56832 + j;
          d[56832 + j] = D[222][j];
        }
      D[223] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A1B\u7A10\u7AA3\u7AA2\u7A9E\u7AEB\u7B66\u7B64\u7B6D\u7B74\u7B69\u7B72\u7B65\u7B73\u7B71\u7B70\u7B61\u7B78\u7B76\u7B63\u7CB2\u7CB4\u7CAF\u7D88\u7D86\u7D80\u7D8D\u7D7F\u7D85\u7D7A\u7D8E\u7D7B\u7D83\u7D7C\u7D8C\u7D94\u7D84\u7D7D\u7D92\u7F6D\u7F6B\u7F67\u7F68\u7F6C\u7FA6\u7FA5\u7FA7\u7FDB\u7FDC\u8021\u8164\u8160\u8177\u815C\u8169\u815B\u8162\u8172\u6721\u815E\u8176\u8167\u816F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8144\u8161\u821D\u8249\u8244\u8240\u8242\u8245\u84F1\u843F\u8456\u8476\u8479\u848F\u848D\u8465\u8451\u8440\u8486\u8467\u8430\u844D\u847D\u845A\u8459\u8474\u8473\u845D\u8507\u845E\u8437\u843A\u8434\u847A\u8443\u8478\u8432\u8445\u8429\u83D9\u844B\u842F\u8442\u842D\u845F\u8470\u8439\u844E\u844C\u8452\u846F\u84C5\u848E\u843B\u8447\u8436\u8433\u8468\u847E\u8444\u842B\u8460\u8454\u846E\u8450\u870B\u8704\u86F7\u870C\u86FA\u86D6\u86F5\u874D\u86F8\u870E\u8709\u8701\u86F6\u870D\u8705\u88D6\u88CB\u88CD\u88CE\u88DE\u88DB\u88DA\u88CC\u88D0\u8985\u899B\u89DF\u89E5\u89E4\uFFFD".split("");
      for (j = 0; j != D[223].length; ++j)
        if (D[223][j].charCodeAt(0) !== 65533) {
          e[D[223][j]] = 57088 + j;
          d[57088 + j] = D[223][j];
        }
      D[224] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u89E1\u89E0\u89E2\u89DC\u89E6\u8A76\u8A86\u8A7F\u8A61\u8A3F\u8A77\u8A82\u8A84\u8A75\u8A83\u8A81\u8A74\u8A7A\u8C3C\u8C4B\u8C4A\u8C65\u8C64\u8C66\u8C86\u8C84\u8C85\u8CCC\u8D68\u8D69\u8D91\u8D8C\u8D8E\u8D8F\u8D8D\u8D93\u8D94\u8D90\u8D92\u8DF0\u8DE0\u8DEC\u8DF1\u8DEE\u8DD0\u8DE9\u8DE3\u8DE2\u8DE7\u8DF2\u8DEB\u8DF4\u8F06\u8EFF\u8F01\u8F00\u8F05\u8F07\u8F08\u8F02\u8F0B\u9052\u903F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9044\u9049\u903D\u9110\u910D\u910F\u9111\u9116\u9114\u910B\u910E\u916E\u916F\u9248\u9252\u9230\u923A\u9266\u9233\u9265\u925E\u9283\u922E\u924A\u9246\u926D\u926C\u924F\u9260\u9267\u926F\u9236\u9261\u9270\u9231\u9254\u9263\u9250\u9272\u924E\u9253\u924C\u9256\u9232\u959F\u959C\u959E\u959B\u9692\u9693\u9691\u9697\u96CE\u96FA\u96FD\u96F8\u96F5\u9773\u9777\u9778\u9772\u980F\u980D\u980E\u98AC\u98F6\u98F9\u99AF\u99B2\u99B0\u99B5\u9AAD\u9AAB\u9B5B\u9CEA\u9CED\u9CE7\u9E80\u9EFD\u50E6\u50D4\u50D7\u50E8\u50F3\u50DB\u50EA\u50DD\u50E4\u50D3\u50EC\u50F0\u50EF\u50E3\u50E0\uFFFD".split("");
      for (j = 0; j != D[224].length; ++j)
        if (D[224][j].charCodeAt(0) !== 65533) {
          e[D[224][j]] = 57344 + j;
          d[57344 + j] = D[224][j];
        }
      D[225] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u51D8\u5280\u5281\u52E9\u52EB\u5330\u53AC\u5627\u5615\u560C\u5612\u55FC\u560F\u561C\u5601\u5613\u5602\u55FA\u561D\u5604\u55FF\u55F9\u5889\u587C\u5890\u5898\u5886\u5881\u587F\u5874\u588B\u587A\u5887\u5891\u588E\u5876\u5882\u5888\u587B\u5894\u588F\u58FE\u596B\u5ADC\u5AEE\u5AE5\u5AD5\u5AEA\u5ADA\u5AED\u5AEB\u5AF3\u5AE2\u5AE0\u5ADB\u5AEC\u5ADE\u5ADD\u5AD9\u5AE8\u5ADF\u5B77\u5BE0\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5BE3\u5C63\u5D82\u5D80\u5D7D\u5D86\u5D7A\u5D81\u5D77\u5D8A\u5D89\u5D88\u5D7E\u5D7C\u5D8D\u5D79\u5D7F\u5E58\u5E59\u5E53\u5ED8\u5ED1\u5ED7\u5ECE\u5EDC\u5ED5\u5ED9\u5ED2\u5ED4\u5F44\u5F43\u5F6F\u5FB6\u612C\u6128\u6141\u615E\u6171\u6173\u6152\u6153\u6172\u616C\u6180\u6174\u6154\u617A\u615B\u6165\u613B\u616A\u6161\u6156\u6229\u6227\u622B\u642B\u644D\u645B\u645D\u6474\u6476\u6472\u6473\u647D\u6475\u6466\u64A6\u644E\u6482\u645E\u645C\u644B\u6453\u6460\u6450\u647F\u643F\u646C\u646B\u6459\u6465\u6477\u6573\u65A0\u66A1\u66A0\u669F\u6705\u6704\u6722\u69B1\u69B6\u69C9\uFFFD".split("");
      for (j = 0; j != D[225].length; ++j)
        if (D[225][j].charCodeAt(0) !== 65533) {
          e[D[225][j]] = 57600 + j;
          d[57600 + j] = D[225][j];
        }
      D[226] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u69A0\u69CE\u6996\u69B0\u69AC\u69BC\u6991\u6999\u698E\u69A7\u698D\u69A9\u69BE\u69AF\u69BF\u69C4\u69BD\u69A4\u69D4\u69B9\u69CA\u699A\u69CF\u69B3\u6993\u69AA\u69A1\u699E\u69D9\u6997\u6990\u69C2\u69B5\u69A5\u69C6\u6B4A\u6B4D\u6B4B\u6B9E\u6B9F\u6BA0\u6BC3\u6BC4\u6BFE\u6ECE\u6EF5\u6EF1\u6F03\u6F25\u6EF8\u6F37\u6EFB\u6F2E\u6F09\u6F4E\u6F19\u6F1A\u6F27\u6F18\u6F3B\u6F12\u6EED\u6F0A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6F36\u6F73\u6EF9\u6EEE\u6F2D\u6F40\u6F30\u6F3C\u6F35\u6EEB\u6F07\u6F0E\u6F43\u6F05\u6EFD\u6EF6\u6F39\u6F1C\u6EFC\u6F3A\u6F1F\u6F0D\u6F1E\u6F08\u6F21\u7187\u7190\u7189\u7180\u7185\u7182\u718F\u717B\u7186\u7181\u7197\u7244\u7253\u7297\u7295\u7293\u7343\u734D\u7351\u734C\u7462\u7473\u7471\u7475\u7472\u7467\u746E\u7500\u7502\u7503\u757D\u7590\u7616\u7608\u760C\u7615\u7611\u760A\u7614\u76B8\u7781\u777C\u7785\u7782\u776E\u7780\u776F\u777E\u7783\u78B2\u78AA\u78B4\u78AD\u78A8\u787E\u78AB\u789E\u78A5\u78A0\u78AC\u78A2\u78A4\u7998\u798A\u798B\u7996\u7995\u7994\u7993\uFFFD".split("");
      for (j = 0; j != D[226].length; ++j)
        if (D[226][j].charCodeAt(0) !== 65533) {
          e[D[226][j]] = 57856 + j;
          d[57856 + j] = D[226][j];
        }
      D[227] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7997\u7988\u7992\u7990\u7A2B\u7A4A\u7A30\u7A2F\u7A28\u7A26\u7AA8\u7AAB\u7AAC\u7AEE\u7B88\u7B9C\u7B8A\u7B91\u7B90\u7B96\u7B8D\u7B8C\u7B9B\u7B8E\u7B85\u7B98\u5284\u7B99\u7BA4\u7B82\u7CBB\u7CBF\u7CBC\u7CBA\u7DA7\u7DB7\u7DC2\u7DA3\u7DAA\u7DC1\u7DC0\u7DC5\u7D9D\u7DCE\u7DC4\u7DC6\u7DCB\u7DCC\u7DAF\u7DB9\u7D96\u7DBC\u7D9F\u7DA6\u7DAE\u7DA9\u7DA1\u7DC9\u7F73\u7FE2\u7FE3\u7FE5\u7FDE\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8024\u805D\u805C\u8189\u8186\u8183\u8187\u818D\u818C\u818B\u8215\u8497\u84A4\u84A1\u849F\u84BA\u84CE\u84C2\u84AC\u84AE\u84AB\u84B9\u84B4\u84C1\u84CD\u84AA\u849A\u84B1\u84D0\u849D\u84A7\u84BB\u84A2\u8494\u84C7\u84CC\u849B\u84A9\u84AF\u84A8\u84D6\u8498\u84B6\u84CF\u84A0\u84D7\u84D4\u84D2\u84DB\u84B0\u8491\u8661\u8733\u8723\u8728\u876B\u8740\u872E\u871E\u8721\u8719\u871B\u8743\u872C\u8741\u873E\u8746\u8720\u8732\u872A\u872D\u873C\u8712\u873A\u8731\u8735\u8742\u8726\u8727\u8738\u8724\u871A\u8730\u8711\u88F7\u88E7\u88F1\u88F2\u88FA\u88FE\u88EE\u88FC\u88F6\u88FB\uFFFD".split("");
      for (j = 0; j != D[227].length; ++j)
        if (D[227][j].charCodeAt(0) !== 65533) {
          e[D[227][j]] = 58112 + j;
          d[58112 + j] = D[227][j];
        }
      D[228] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u88F0\u88EC\u88EB\u899D\u89A1\u899F\u899E\u89E9\u89EB\u89E8\u8AAB\u8A99\u8A8B\u8A92\u8A8F\u8A96\u8C3D\u8C68\u8C69\u8CD5\u8CCF\u8CD7\u8D96\u8E09\u8E02\u8DFF\u8E0D\u8DFD\u8E0A\u8E03\u8E07\u8E06\u8E05\u8DFE\u8E00\u8E04\u8F10\u8F11\u8F0E\u8F0D\u9123\u911C\u9120\u9122\u911F\u911D\u911A\u9124\u9121\u911B\u917A\u9172\u9179\u9173\u92A5\u92A4\u9276\u929B\u927A\u92A0\u9294\u92AA\u928D\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u92A6\u929A\u92AB\u9279\u9297\u927F\u92A3\u92EE\u928E\u9282\u9295\u92A2\u927D\u9288\u92A1\u928A\u9286\u928C\u9299\u92A7\u927E\u9287\u92A9\u929D\u928B\u922D\u969E\u96A1\u96FF\u9758\u977D\u977A\u977E\u9783\u9780\u9782\u977B\u9784\u9781\u977F\u97CE\u97CD\u9816\u98AD\u98AE\u9902\u9900\u9907\u999D\u999C\u99C3\u99B9\u99BB\u99BA\u99C2\u99BD\u99C7\u9AB1\u9AE3\u9AE7\u9B3E\u9B3F\u9B60\u9B61\u9B5F\u9CF1\u9CF2\u9CF5\u9EA7\u50FF\u5103\u5130\u50F8\u5106\u5107\u50F6\u50FE\u510B\u510C\u50FD\u510A\u528B\u528C\u52F1\u52EF\u5648\u5642\u564C\u5635\u5641\u564A\u5649\u5646\u5658\uFFFD".split("");
      for (j = 0; j != D[228].length; ++j)
        if (D[228][j].charCodeAt(0) !== 65533) {
          e[D[228][j]] = 58368 + j;
          d[58368 + j] = D[228][j];
        }
      D[229] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u565A\u5640\u5633\u563D\u562C\u563E\u5638\u562A\u563A\u571A\u58AB\u589D\u58B1\u58A0\u58A3\u58AF\u58AC\u58A5\u58A1\u58FF\u5AFF\u5AF4\u5AFD\u5AF7\u5AF6\u5B03\u5AF8\u5B02\u5AF9\u5B01\u5B07\u5B05\u5B0F\u5C67\u5D99\u5D97\u5D9F\u5D92\u5DA2\u5D93\u5D95\u5DA0\u5D9C\u5DA1\u5D9A\u5D9E\u5E69\u5E5D\u5E60\u5E5C\u7DF3\u5EDB\u5EDE\u5EE1\u5F49\u5FB2\u618B\u6183\u6179\u61B1\u61B0\u61A2\u6189\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u619B\u6193\u61AF\u61AD\u619F\u6192\u61AA\u61A1\u618D\u6166\u61B3\u622D\u646E\u6470\u6496\u64A0\u6485\u6497\u649C\u648F\u648B\u648A\u648C\u64A3\u649F\u6468\u64B1\u6498\u6576\u657A\u6579\u657B\u65B2\u65B3\u66B5\u66B0\u66A9\u66B2\u66B7\u66AA\u66AF\u6A00\u6A06\u6A17\u69E5\u69F8\u6A15\u69F1\u69E4\u6A20\u69FF\u69EC\u69E2\u6A1B\u6A1D\u69FE\u6A27\u69F2\u69EE\u6A14\u69F7\u69E7\u6A40\u6A08\u69E6\u69FB\u6A0D\u69FC\u69EB\u6A09\u6A04\u6A18\u6A25\u6A0F\u69F6\u6A26\u6A07\u69F4\u6A16\u6B51\u6BA5\u6BA3\u6BA2\u6BA6\u6C01\u6C00\u6BFF\u6C02\u6F41\u6F26\u6F7E\u6F87\u6FC6\u6F92\uFFFD".split("");
      for (j = 0; j != D[229].length; ++j)
        if (D[229][j].charCodeAt(0) !== 65533) {
          e[D[229][j]] = 58624 + j;
          d[58624 + j] = D[229][j];
        }
      D[230] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6F8D\u6F89\u6F8C\u6F62\u6F4F\u6F85\u6F5A\u6F96\u6F76\u6F6C\u6F82\u6F55\u6F72\u6F52\u6F50\u6F57\u6F94\u6F93\u6F5D\u6F00\u6F61\u6F6B\u6F7D\u6F67\u6F90\u6F53\u6F8B\u6F69\u6F7F\u6F95\u6F63\u6F77\u6F6A\u6F7B\u71B2\u71AF\u719B\u71B0\u71A0\u719A\u71A9\u71B5\u719D\u71A5\u719E\u71A4\u71A1\u71AA\u719C\u71A7\u71B3\u7298\u729A\u7358\u7352\u735E\u735F\u7360\u735D\u735B\u7361\u735A\u7359\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7362\u7487\u7489\u748A\u7486\u7481\u747D\u7485\u7488\u747C\u7479\u7508\u7507\u757E\u7625\u761E\u7619\u761D\u761C\u7623\u761A\u7628\u761B\u769C\u769D\u769E\u769B\u778D\u778F\u7789\u7788\u78CD\u78BB\u78CF\u78CC\u78D1\u78CE\u78D4\u78C8\u78C3\u78C4\u78C9\u799A\u79A1\u79A0\u799C\u79A2\u799B\u6B76\u7A39\u7AB2\u7AB4\u7AB3\u7BB7\u7BCB\u7BBE\u7BAC\u7BCE\u7BAF\u7BB9\u7BCA\u7BB5\u7CC5\u7CC8\u7CCC\u7CCB\u7DF7\u7DDB\u7DEA\u7DE7\u7DD7\u7DE1\u7E03\u7DFA\u7DE6\u7DF6\u7DF1\u7DF0\u7DEE\u7DDF\u7F76\u7FAC\u7FB0\u7FAD\u7FED\u7FEB\u7FEA\u7FEC\u7FE6\u7FE8\u8064\u8067\u81A3\u819F\uFFFD".split("");
      for (j = 0; j != D[230].length; ++j)
        if (D[230][j].charCodeAt(0) !== 65533) {
          e[D[230][j]] = 58880 + j;
          d[58880 + j] = D[230][j];
        }
      D[231] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u819E\u8195\u81A2\u8199\u8197\u8216\u824F\u8253\u8252\u8250\u824E\u8251\u8524\u853B\u850F\u8500\u8529\u850E\u8509\u850D\u851F\u850A\u8527\u851C\u84FB\u852B\u84FA\u8508\u850C\u84F4\u852A\u84F2\u8515\u84F7\u84EB\u84F3\u84FC\u8512\u84EA\u84E9\u8516\u84FE\u8528\u851D\u852E\u8502\u84FD\u851E\u84F6\u8531\u8526\u84E7\u84E8\u84F0\u84EF\u84F9\u8518\u8520\u8530\u850B\u8519\u852F\u8662\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8756\u8763\u8764\u8777\u87E1\u8773\u8758\u8754\u875B\u8752\u8761\u875A\u8751\u875E\u876D\u876A\u8750\u874E\u875F\u875D\u876F\u876C\u877A\u876E\u875C\u8765\u874F\u877B\u8775\u8762\u8767\u8769\u885A\u8905\u890C\u8914\u890B\u8917\u8918\u8919\u8906\u8916\u8911\u890E\u8909\u89A2\u89A4\u89A3\u89ED\u89F0\u89EC\u8ACF\u8AC6\u8AB8\u8AD3\u8AD1\u8AD4\u8AD5\u8ABB\u8AD7\u8ABE\u8AC0\u8AC5\u8AD8\u8AC3\u8ABA\u8ABD\u8AD9\u8C3E\u8C4D\u8C8F\u8CE5\u8CDF\u8CD9\u8CE8\u8CDA\u8CDD\u8CE7\u8DA0\u8D9C\u8DA1\u8D9B\u8E20\u8E23\u8E25\u8E24\u8E2E\u8E15\u8E1B\u8E16\u8E11\u8E19\u8E26\u8E27\uFFFD".split("");
      for (j = 0; j != D[231].length; ++j)
        if (D[231][j].charCodeAt(0) !== 65533) {
          e[D[231][j]] = 59136 + j;
          d[59136 + j] = D[231][j];
        }
      D[232] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8E14\u8E12\u8E18\u8E13\u8E1C\u8E17\u8E1A\u8F2C\u8F24\u8F18\u8F1A\u8F20\u8F23\u8F16\u8F17\u9073\u9070\u906F\u9067\u906B\u912F\u912B\u9129\u912A\u9132\u9126\u912E\u9185\u9186\u918A\u9181\u9182\u9184\u9180\u92D0\u92C3\u92C4\u92C0\u92D9\u92B6\u92CF\u92F1\u92DF\u92D8\u92E9\u92D7\u92DD\u92CC\u92EF\u92C2\u92E8\u92CA\u92C8\u92CE\u92E6\u92CD\u92D5\u92C9\u92E0\u92DE\u92E7\u92D1\u92D3\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u92B5\u92E1\u92C6\u92B4\u957C\u95AC\u95AB\u95AE\u95B0\u96A4\u96A2\u96D3\u9705\u9708\u9702\u975A\u978A\u978E\u9788\u97D0\u97CF\u981E\u981D\u9826\u9829\u9828\u9820\u981B\u9827\u98B2\u9908\u98FA\u9911\u9914\u9916\u9917\u9915\u99DC\u99CD\u99CF\u99D3\u99D4\u99CE\u99C9\u99D6\u99D8\u99CB\u99D7\u99CC\u9AB3\u9AEC\u9AEB\u9AF3\u9AF2\u9AF1\u9B46\u9B43\u9B67\u9B74\u9B71\u9B66\u9B76\u9B75\u9B70\u9B68\u9B64\u9B6C\u9CFC\u9CFA\u9CFD\u9CFF\u9CF7\u9D07\u9D00\u9CF9\u9CFB\u9D08\u9D05\u9D04\u9E83\u9ED3\u9F0F\u9F10\u511C\u5113\u5117\u511A\u5111\u51DE\u5334\u53E1\u5670\u5660\u566E\uFFFD".split("");
      for (j = 0; j != D[232].length; ++j)
        if (D[232][j].charCodeAt(0) !== 65533) {
          e[D[232][j]] = 59392 + j;
          d[59392 + j] = D[232][j];
        }
      D[233] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5673\u5666\u5663\u566D\u5672\u565E\u5677\u571C\u571B\u58C8\u58BD\u58C9\u58BF\u58BA\u58C2\u58BC\u58C6\u5B17\u5B19\u5B1B\u5B21\u5B14\u5B13\u5B10\u5B16\u5B28\u5B1A\u5B20\u5B1E\u5BEF\u5DAC\u5DB1\u5DA9\u5DA7\u5DB5\u5DB0\u5DAE\u5DAA\u5DA8\u5DB2\u5DAD\u5DAF\u5DB4\u5E67\u5E68\u5E66\u5E6F\u5EE9\u5EE7\u5EE6\u5EE8\u5EE5\u5F4B\u5FBC\u619D\u61A8\u6196\u61C5\u61B4\u61C6\u61C1\u61CC\u61BA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u61BF\u61B8\u618C\u64D7\u64D6\u64D0\u64CF\u64C9\u64BD\u6489\u64C3\u64DB\u64F3\u64D9\u6533\u657F\u657C\u65A2\u66C8\u66BE\u66C0\u66CA\u66CB\u66CF\u66BD\u66BB\u66BA\u66CC\u6723\u6A34\u6A66\u6A49\u6A67\u6A32\u6A68\u6A3E\u6A5D\u6A6D\u6A76\u6A5B\u6A51\u6A28\u6A5A\u6A3B\u6A3F\u6A41\u6A6A\u6A64\u6A50\u6A4F\u6A54\u6A6F\u6A69\u6A60\u6A3C\u6A5E\u6A56\u6A55\u6A4D\u6A4E\u6A46\u6B55\u6B54\u6B56\u6BA7\u6BAA\u6BAB\u6BC8\u6BC7\u6C04\u6C03\u6C06\u6FAD\u6FCB\u6FA3\u6FC7\u6FBC\u6FCE\u6FC8\u6F5E\u6FC4\u6FBD\u6F9E\u6FCA\u6FA8\u7004\u6FA5\u6FAE\u6FBA\u6FAC\u6FAA\u6FCF\u6FBF\u6FB8\uFFFD".split("");
      for (j = 0; j != D[233].length; ++j)
        if (D[233][j].charCodeAt(0) !== 65533) {
          e[D[233][j]] = 59648 + j;
          d[59648 + j] = D[233][j];
        }
      D[234] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6FA2\u6FC9\u6FAB\u6FCD\u6FAF\u6FB2\u6FB0\u71C5\u71C2\u71BF\u71B8\u71D6\u71C0\u71C1\u71CB\u71D4\u71CA\u71C7\u71CF\u71BD\u71D8\u71BC\u71C6\u71DA\u71DB\u729D\u729E\u7369\u7366\u7367\u736C\u7365\u736B\u736A\u747F\u749A\u74A0\u7494\u7492\u7495\u74A1\u750B\u7580\u762F\u762D\u7631\u763D\u7633\u763C\u7635\u7632\u7630\u76BB\u76E6\u779A\u779D\u77A1\u779C\u779B\u77A2\u77A3\u7795\u7799\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7797\u78DD\u78E9\u78E5\u78EA\u78DE\u78E3\u78DB\u78E1\u78E2\u78ED\u78DF\u78E0\u79A4\u7A44\u7A48\u7A47\u7AB6\u7AB8\u7AB5\u7AB1\u7AB7\u7BDE\u7BE3\u7BE7\u7BDD\u7BD5\u7BE5\u7BDA\u7BE8\u7BF9\u7BD4\u7BEA\u7BE2\u7BDC\u7BEB\u7BD8\u7BDF\u7CD2\u7CD4\u7CD7\u7CD0\u7CD1\u7E12\u7E21\u7E17\u7E0C\u7E1F\u7E20\u7E13\u7E0E\u7E1C\u7E15\u7E1A\u7E22\u7E0B\u7E0F\u7E16\u7E0D\u7E14\u7E25\u7E24\u7F43\u7F7B\u7F7C\u7F7A\u7FB1\u7FEF\u802A\u8029\u806C\u81B1\u81A6\u81AE\u81B9\u81B5\u81AB\u81B0\u81AC\u81B4\u81B2\u81B7\u81A7\u81F2\u8255\u8256\u8257\u8556\u8545\u856B\u854D\u8553\u8561\u8558\uFFFD".split("");
      for (j = 0; j != D[234].length; ++j)
        if (D[234][j].charCodeAt(0) !== 65533) {
          e[D[234][j]] = 59904 + j;
          d[59904 + j] = D[234][j];
        }
      D[235] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8540\u8546\u8564\u8541\u8562\u8544\u8551\u8547\u8563\u853E\u855B\u8571\u854E\u856E\u8575\u8555\u8567\u8560\u858C\u8566\u855D\u8554\u8565\u856C\u8663\u8665\u8664\u879B\u878F\u8797\u8793\u8792\u8788\u8781\u8796\u8798\u8779\u8787\u87A3\u8785\u8790\u8791\u879D\u8784\u8794\u879C\u879A\u8789\u891E\u8926\u8930\u892D\u892E\u8927\u8931\u8922\u8929\u8923\u892F\u892C\u891F\u89F1\u8AE0\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8AE2\u8AF2\u8AF4\u8AF5\u8ADD\u8B14\u8AE4\u8ADF\u8AF0\u8AC8\u8ADE\u8AE1\u8AE8\u8AFF\u8AEF\u8AFB\u8C91\u8C92\u8C90\u8CF5\u8CEE\u8CF1\u8CF0\u8CF3\u8D6C\u8D6E\u8DA5\u8DA7\u8E33\u8E3E\u8E38\u8E40\u8E45\u8E36\u8E3C\u8E3D\u8E41\u8E30\u8E3F\u8EBD\u8F36\u8F2E\u8F35\u8F32\u8F39\u8F37\u8F34\u9076\u9079\u907B\u9086\u90FA\u9133\u9135\u9136\u9193\u9190\u9191\u918D\u918F\u9327\u931E\u9308\u931F\u9306\u930F\u937A\u9338\u933C\u931B\u9323\u9312\u9301\u9346\u932D\u930E\u930D\u92CB\u931D\u92FA\u9325\u9313\u92F9\u92F7\u9334\u9302\u9324\u92FF\u9329\u9339\u9335\u932A\u9314\u930C\uFFFD".split("");
      for (j = 0; j != D[235].length; ++j)
        if (D[235][j].charCodeAt(0) !== 65533) {
          e[D[235][j]] = 60160 + j;
          d[60160 + j] = D[235][j];
        }
      D[236] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u930B\u92FE\u9309\u9300\u92FB\u9316\u95BC\u95CD\u95BE\u95B9\u95BA\u95B6\u95BF\u95B5\u95BD\u96A9\u96D4\u970B\u9712\u9710\u9799\u9797\u9794\u97F0\u97F8\u9835\u982F\u9832\u9924\u991F\u9927\u9929\u999E\u99EE\u99EC\u99E5\u99E4\u99F0\u99E3\u99EA\u99E9\u99E7\u9AB9\u9ABF\u9AB4\u9ABB\u9AF6\u9AFA\u9AF9\u9AF7\u9B33\u9B80\u9B85\u9B87\u9B7C\u9B7E\u9B7B\u9B82\u9B93\u9B92\u9B90\u9B7A\u9B95\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9B7D\u9B88\u9D25\u9D17\u9D20\u9D1E\u9D14\u9D29\u9D1D\u9D18\u9D22\u9D10\u9D19\u9D1F\u9E88\u9E86\u9E87\u9EAE\u9EAD\u9ED5\u9ED6\u9EFA\u9F12\u9F3D\u5126\u5125\u5122\u5124\u5120\u5129\u52F4\u5693\u568C\u568D\u5686\u5684\u5683\u567E\u5682\u567F\u5681\u58D6\u58D4\u58CF\u58D2\u5B2D\u5B25\u5B32\u5B23\u5B2C\u5B27\u5B26\u5B2F\u5B2E\u5B7B\u5BF1\u5BF2\u5DB7\u5E6C\u5E6A\u5FBE\u5FBB\u61C3\u61B5\u61BC\u61E7\u61E0\u61E5\u61E4\u61E8\u61DE\u64EF\u64E9\u64E3\u64EB\u64E4\u64E8\u6581\u6580\u65B6\u65DA\u66D2\u6A8D\u6A96\u6A81\u6AA5\u6A89\u6A9F\u6A9B\u6AA1\u6A9E\u6A87\u6A93\u6A8E\uFFFD".split("");
      for (j = 0; j != D[236].length; ++j)
        if (D[236][j].charCodeAt(0) !== 65533) {
          e[D[236][j]] = 60416 + j;
          d[60416 + j] = D[236][j];
        }
      D[237] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6A95\u6A83\u6AA8\u6AA4\u6A91\u6A7F\u6AA6\u6A9A\u6A85\u6A8C\u6A92\u6B5B\u6BAD\u6C09\u6FCC\u6FA9\u6FF4\u6FD4\u6FE3\u6FDC\u6FED\u6FE7\u6FE6\u6FDE\u6FF2\u6FDD\u6FE2\u6FE8\u71E1\u71F1\u71E8\u71F2\u71E4\u71F0\u71E2\u7373\u736E\u736F\u7497\u74B2\u74AB\u7490\u74AA\u74AD\u74B1\u74A5\u74AF\u7510\u7511\u7512\u750F\u7584\u7643\u7648\u7649\u7647\u76A4\u76E9\u77B5\u77AB\u77B2\u77B7\u77B6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u77B4\u77B1\u77A8\u77F0\u78F3\u78FD\u7902\u78FB\u78FC\u78F2\u7905\u78F9\u78FE\u7904\u79AB\u79A8\u7A5C\u7A5B\u7A56\u7A58\u7A54\u7A5A\u7ABE\u7AC0\u7AC1\u7C05\u7C0F\u7BF2\u7C00\u7BFF\u7BFB\u7C0E\u7BF4\u7C0B\u7BF3\u7C02\u7C09\u7C03\u7C01\u7BF8\u7BFD\u7C06\u7BF0\u7BF1\u7C10\u7C0A\u7CE8\u7E2D\u7E3C\u7E42\u7E33\u9848\u7E38\u7E2A\u7E49\u7E40\u7E47\u7E29\u7E4C\u7E30\u7E3B\u7E36\u7E44\u7E3A\u7F45\u7F7F\u7F7E\u7F7D\u7FF4\u7FF2\u802C\u81BB\u81C4\u81CC\u81CA\u81C5\u81C7\u81BC\u81E9\u825B\u825A\u825C\u8583\u8580\u858F\u85A7\u8595\u85A0\u858B\u85A3\u857B\u85A4\u859A\u859E\uFFFD".split("");
      for (j = 0; j != D[237].length; ++j)
        if (D[237][j].charCodeAt(0) !== 65533) {
          e[D[237][j]] = 60672 + j;
          d[60672 + j] = D[237][j];
        }
      D[238] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8577\u857C\u8589\u85A1\u857A\u8578\u8557\u858E\u8596\u8586\u858D\u8599\u859D\u8581\u85A2\u8582\u8588\u8585\u8579\u8576\u8598\u8590\u859F\u8668\u87BE\u87AA\u87AD\u87C5\u87B0\u87AC\u87B9\u87B5\u87BC\u87AE\u87C9\u87C3\u87C2\u87CC\u87B7\u87AF\u87C4\u87CA\u87B4\u87B6\u87BF\u87B8\u87BD\u87DE\u87B2\u8935\u8933\u893C\u893E\u8941\u8952\u8937\u8942\u89AD\u89AF\u89AE\u89F2\u89F3\u8B1E\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B18\u8B16\u8B11\u8B05\u8B0B\u8B22\u8B0F\u8B12\u8B15\u8B07\u8B0D\u8B08\u8B06\u8B1C\u8B13\u8B1A\u8C4F\u8C70\u8C72\u8C71\u8C6F\u8C95\u8C94\u8CF9\u8D6F\u8E4E\u8E4D\u8E53\u8E50\u8E4C\u8E47\u8F43\u8F40\u9085\u907E\u9138\u919A\u91A2\u919B\u9199\u919F\u91A1\u919D\u91A0\u93A1\u9383\u93AF\u9364\u9356\u9347\u937C\u9358\u935C\u9376\u9349\u9350\u9351\u9360\u936D\u938F\u934C\u936A\u9379\u9357\u9355\u9352\u934F\u9371\u9377\u937B\u9361\u935E\u9363\u9367\u9380\u934E\u9359\u95C7\u95C0\u95C9\u95C3\u95C5\u95B7\u96AE\u96B0\u96AC\u9720\u971F\u9718\u971D\u9719\u979A\u97A1\u979C\uFFFD".split("");
      for (j = 0; j != D[238].length; ++j)
        if (D[238][j].charCodeAt(0) !== 65533) {
          e[D[238][j]] = 60928 + j;
          d[60928 + j] = D[238][j];
        }
      D[239] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u979E\u979D\u97D5\u97D4\u97F1\u9841\u9844\u984A\u9849\u9845\u9843\u9925\u992B\u992C\u992A\u9933\u9932\u992F\u992D\u9931\u9930\u9998\u99A3\u99A1\u9A02\u99FA\u99F4\u99F7\u99F9\u99F8\u99F6\u99FB\u99FD\u99FE\u99FC\u9A03\u9ABE\u9AFE\u9AFD\u9B01\u9AFC\u9B48\u9B9A\u9BA8\u9B9E\u9B9B\u9BA6\u9BA1\u9BA5\u9BA4\u9B86\u9BA2\u9BA0\u9BAF\u9D33\u9D41\u9D67\u9D36\u9D2E\u9D2F\u9D31\u9D38\u9D30\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9D45\u9D42\u9D43\u9D3E\u9D37\u9D40\u9D3D\u7FF5\u9D2D\u9E8A\u9E89\u9E8D\u9EB0\u9EC8\u9EDA\u9EFB\u9EFF\u9F24\u9F23\u9F22\u9F54\u9FA0\u5131\u512D\u512E\u5698\u569C\u5697\u569A\u569D\u5699\u5970\u5B3C\u5C69\u5C6A\u5DC0\u5E6D\u5E6E\u61D8\u61DF\u61ED\u61EE\u61F1\u61EA\u61F0\u61EB\u61D6\u61E9\u64FF\u6504\u64FD\u64F8\u6501\u6503\u64FC\u6594\u65DB\u66DA\u66DB\u66D8\u6AC5\u6AB9\u6ABD\u6AE1\u6AC6\u6ABA\u6AB6\u6AB7\u6AC7\u6AB4\u6AAD\u6B5E\u6BC9\u6C0B\u7007\u700C\u700D\u7001\u7005\u7014\u700E\u6FFF\u7000\u6FFB\u7026\u6FFC\u6FF7\u700A\u7201\u71FF\u71F9\u7203\u71FD\u7376\uFFFD".split("");
      for (j = 0; j != D[239].length; ++j)
        if (D[239][j].charCodeAt(0) !== 65533) {
          e[D[239][j]] = 61184 + j;
          d[61184 + j] = D[239][j];
        }
      D[240] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u74B8\u74C0\u74B5\u74C1\u74BE\u74B6\u74BB\u74C2\u7514\u7513\u765C\u7664\u7659\u7650\u7653\u7657\u765A\u76A6\u76BD\u76EC\u77C2\u77BA\u78FF\u790C\u7913\u7914\u7909\u7910\u7912\u7911\u79AD\u79AC\u7A5F\u7C1C\u7C29\u7C19\u7C20\u7C1F\u7C2D\u7C1D\u7C26\u7C28\u7C22\u7C25\u7C30\u7E5C\u7E50\u7E56\u7E63\u7E58\u7E62\u7E5F\u7E51\u7E60\u7E57\u7E53\u7FB5\u7FB3\u7FF7\u7FF8\u8075\u81D1\u81D2\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u81D0\u825F\u825E\u85B4\u85C6\u85C0\u85C3\u85C2\u85B3\u85B5\u85BD\u85C7\u85C4\u85BF\u85CB\u85CE\u85C8\u85C5\u85B1\u85B6\u85D2\u8624\u85B8\u85B7\u85BE\u8669\u87E7\u87E6\u87E2\u87DB\u87EB\u87EA\u87E5\u87DF\u87F3\u87E4\u87D4\u87DC\u87D3\u87ED\u87D8\u87E3\u87A4\u87D7\u87D9\u8801\u87F4\u87E8\u87DD\u8953\u894B\u894F\u894C\u8946\u8950\u8951\u8949\u8B2A\u8B27\u8B23\u8B33\u8B30\u8B35\u8B47\u8B2F\u8B3C\u8B3E\u8B31\u8B25\u8B37\u8B26\u8B36\u8B2E\u8B24\u8B3B\u8B3D\u8B3A\u8C42\u8C75\u8C99\u8C98\u8C97\u8CFE\u8D04\u8D02\u8D00\u8E5C\u8E62\u8E60\u8E57\u8E56\u8E5E\u8E65\u8E67\uFFFD".split("");
      for (j = 0; j != D[240].length; ++j)
        if (D[240][j].charCodeAt(0) !== 65533) {
          e[D[240][j]] = 61440 + j;
          d[61440 + j] = D[240][j];
        }
      D[241] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8E5B\u8E5A\u8E61\u8E5D\u8E69\u8E54\u8F46\u8F47\u8F48\u8F4B\u9128\u913A\u913B\u913E\u91A8\u91A5\u91A7\u91AF\u91AA\u93B5\u938C\u9392\u93B7\u939B\u939D\u9389\u93A7\u938E\u93AA\u939E\u93A6\u9395\u9388\u9399\u939F\u938D\u93B1\u9391\u93B2\u93A4\u93A8\u93B4\u93A3\u93A5\u95D2\u95D3\u95D1\u96B3\u96D7\u96DA\u5DC2\u96DF\u96D8\u96DD\u9723\u9722\u9725\u97AC\u97AE\u97A8\u97AB\u97A4\u97AA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u97A2\u97A5\u97D7\u97D9\u97D6\u97D8\u97FA\u9850\u9851\u9852\u98B8\u9941\u993C\u993A\u9A0F\u9A0B\u9A09\u9A0D\u9A04\u9A11\u9A0A\u9A05\u9A07\u9A06\u9AC0\u9ADC\u9B08\u9B04\u9B05\u9B29\u9B35\u9B4A\u9B4C\u9B4B\u9BC7\u9BC6\u9BC3\u9BBF\u9BC1\u9BB5\u9BB8\u9BD3\u9BB6\u9BC4\u9BB9\u9BBD\u9D5C\u9D53\u9D4F\u9D4A\u9D5B\u9D4B\u9D59\u9D56\u9D4C\u9D57\u9D52\u9D54\u9D5F\u9D58\u9D5A\u9E8E\u9E8C\u9EDF\u9F01\u9F00\u9F16\u9F25\u9F2B\u9F2A\u9F29\u9F28\u9F4C\u9F55\u5134\u5135\u5296\u52F7\u53B4\u56AB\u56AD\u56A6\u56A7\u56AA\u56AC\u58DA\u58DD\u58DB\u5912\u5B3D\u5B3E\u5B3F\u5DC3\u5E70\uFFFD".split("");
      for (j = 0; j != D[241].length; ++j)
        if (D[241][j].charCodeAt(0) !== 65533) {
          e[D[241][j]] = 61696 + j;
          d[61696 + j] = D[241][j];
        }
      D[242] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5FBF\u61FB\u6507\u6510\u650D\u6509\u650C\u650E\u6584\u65DE\u65DD\u66DE\u6AE7\u6AE0\u6ACC\u6AD1\u6AD9\u6ACB\u6ADF\u6ADC\u6AD0\u6AEB\u6ACF\u6ACD\u6ADE\u6B60\u6BB0\u6C0C\u7019\u7027\u7020\u7016\u702B\u7021\u7022\u7023\u7029\u7017\u7024\u701C\u702A\u720C\u720A\u7207\u7202\u7205\u72A5\u72A6\u72A4\u72A3\u72A1\u74CB\u74C5\u74B7\u74C3\u7516\u7660\u77C9\u77CA\u77C4\u77F1\u791D\u791B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7921\u791C\u7917\u791E\u79B0\u7A67\u7A68\u7C33\u7C3C\u7C39\u7C2C\u7C3B\u7CEC\u7CEA\u7E76\u7E75\u7E78\u7E70\u7E77\u7E6F\u7E7A\u7E72\u7E74\u7E68\u7F4B\u7F4A\u7F83\u7F86\u7FB7\u7FFD\u7FFE\u8078\u81D7\u81D5\u8264\u8261\u8263\u85EB\u85F1\u85ED\u85D9\u85E1\u85E8\u85DA\u85D7\u85EC\u85F2\u85F8\u85D8\u85DF\u85E3\u85DC\u85D1\u85F0\u85E6\u85EF\u85DE\u85E2\u8800\u87FA\u8803\u87F6\u87F7\u8809\u880C\u880B\u8806\u87FC\u8808\u87FF\u880A\u8802\u8962\u895A\u895B\u8957\u8961\u895C\u8958\u895D\u8959\u8988\u89B7\u89B6\u89F6\u8B50\u8B48\u8B4A\u8B40\u8B53\u8B56\u8B54\u8B4B\u8B55\uFFFD".split("");
      for (j = 0; j != D[242].length; ++j)
        if (D[242][j].charCodeAt(0) !== 65533) {
          e[D[242][j]] = 61952 + j;
          d[61952 + j] = D[242][j];
        }
      D[243] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B51\u8B42\u8B52\u8B57\u8C43\u8C77\u8C76\u8C9A\u8D06\u8D07\u8D09\u8DAC\u8DAA\u8DAD\u8DAB\u8E6D\u8E78\u8E73\u8E6A\u8E6F\u8E7B\u8EC2\u8F52\u8F51\u8F4F\u8F50\u8F53\u8FB4\u9140\u913F\u91B0\u91AD\u93DE\u93C7\u93CF\u93C2\u93DA\u93D0\u93F9\u93EC\u93CC\u93D9\u93A9\u93E6\u93CA\u93D4\u93EE\u93E3\u93D5\u93C4\u93CE\u93C0\u93D2\u93E7\u957D\u95DA\u95DB\u96E1\u9729\u972B\u972C\u9728\u9726\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u97B3\u97B7\u97B6\u97DD\u97DE\u97DF\u985C\u9859\u985D\u9857\u98BF\u98BD\u98BB\u98BE\u9948\u9947\u9943\u99A6\u99A7\u9A1A\u9A15\u9A25\u9A1D\u9A24\u9A1B\u9A22\u9A20\u9A27\u9A23\u9A1E\u9A1C\u9A14\u9AC2\u9B0B\u9B0A\u9B0E\u9B0C\u9B37\u9BEA\u9BEB\u9BE0\u9BDE\u9BE4\u9BE6\u9BE2\u9BF0\u9BD4\u9BD7\u9BEC\u9BDC\u9BD9\u9BE5\u9BD5\u9BE1\u9BDA\u9D77\u9D81\u9D8A\u9D84\u9D88\u9D71\u9D80\u9D78\u9D86\u9D8B\u9D8C\u9D7D\u9D6B\u9D74\u9D75\u9D70\u9D69\u9D85\u9D73\u9D7B\u9D82\u9D6F\u9D79\u9D7F\u9D87\u9D68\u9E94\u9E91\u9EC0\u9EFC\u9F2D\u9F40\u9F41\u9F4D\u9F56\u9F57\u9F58\u5337\u56B2\uFFFD".split("");
      for (j = 0; j != D[243].length; ++j)
        if (D[243][j].charCodeAt(0) !== 65533) {
          e[D[243][j]] = 62208 + j;
          d[62208 + j] = D[243][j];
        }
      D[244] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u56B5\u56B3\u58E3\u5B45\u5DC6\u5DC7\u5EEE\u5EEF\u5FC0\u5FC1\u61F9\u6517\u6516\u6515\u6513\u65DF\u66E8\u66E3\u66E4\u6AF3\u6AF0\u6AEA\u6AE8\u6AF9\u6AF1\u6AEE\u6AEF\u703C\u7035\u702F\u7037\u7034\u7031\u7042\u7038\u703F\u703A\u7039\u7040\u703B\u7033\u7041\u7213\u7214\u72A8\u737D\u737C\u74BA\u76AB\u76AA\u76BE\u76ED\u77CC\u77CE\u77CF\u77CD\u77F2\u7925\u7923\u7927\u7928\u7924\u7929\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u79B2\u7A6E\u7A6C\u7A6D\u7AF7\u7C49\u7C48\u7C4A\u7C47\u7C45\u7CEE\u7E7B\u7E7E\u7E81\u7E80\u7FBA\u7FFF\u8079\u81DB\u81D9\u820B\u8268\u8269\u8622\u85FF\u8601\u85FE\u861B\u8600\u85F6\u8604\u8609\u8605\u860C\u85FD\u8819\u8810\u8811\u8817\u8813\u8816\u8963\u8966\u89B9\u89F7\u8B60\u8B6A\u8B5D\u8B68\u8B63\u8B65\u8B67\u8B6D\u8DAE\u8E86\u8E88\u8E84\u8F59\u8F56\u8F57\u8F55\u8F58\u8F5A\u908D\u9143\u9141\u91B7\u91B5\u91B2\u91B3\u940B\u9413\u93FB\u9420\u940F\u9414\u93FE\u9415\u9410\u9428\u9419\u940D\u93F5\u9400\u93F7\u9407\u940E\u9416\u9412\u93FA\u9409\u93F8\u940A\u93FF\uFFFD".split("");
      for (j = 0; j != D[244].length; ++j)
        if (D[244][j].charCodeAt(0) !== 65533) {
          e[D[244][j]] = 62464 + j;
          d[62464 + j] = D[244][j];
        }
      D[245] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u93FC\u940C\u93F6\u9411\u9406\u95DE\u95E0\u95DF\u972E\u972F\u97B9\u97BB\u97FD\u97FE\u9860\u9862\u9863\u985F\u98C1\u98C2\u9950\u994E\u9959\u994C\u994B\u9953\u9A32\u9A34\u9A31\u9A2C\u9A2A\u9A36\u9A29\u9A2E\u9A38\u9A2D\u9AC7\u9ACA\u9AC6\u9B10\u9B12\u9B11\u9C0B\u9C08\u9BF7\u9C05\u9C12\u9BF8\u9C40\u9C07\u9C0E\u9C06\u9C17\u9C14\u9C09\u9D9F\u9D99\u9DA4\u9D9D\u9D92\u9D98\u9D90\u9D9B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9DA0\u9D94\u9D9C\u9DAA\u9D97\u9DA1\u9D9A\u9DA2\u9DA8\u9D9E\u9DA3\u9DBF\u9DA9\u9D96\u9DA6\u9DA7\u9E99\u9E9B\u9E9A\u9EE5\u9EE4\u9EE7\u9EE6\u9F30\u9F2E\u9F5B\u9F60\u9F5E\u9F5D\u9F59\u9F91\u513A\u5139\u5298\u5297\u56C3\u56BD\u56BE\u5B48\u5B47\u5DCB\u5DCF\u5EF1\u61FD\u651B\u6B02\u6AFC\u6B03\u6AF8\u6B00\u7043\u7044\u704A\u7048\u7049\u7045\u7046\u721D\u721A\u7219\u737E\u7517\u766A\u77D0\u792D\u7931\u792F\u7C54\u7C53\u7CF2\u7E8A\u7E87\u7E88\u7E8B\u7E86\u7E8D\u7F4D\u7FBB\u8030\u81DD\u8618\u862A\u8626\u861F\u8623\u861C\u8619\u8627\u862E\u8621\u8620\u8629\u861E\u8625\uFFFD".split("");
      for (j = 0; j != D[245].length; ++j)
        if (D[245][j].charCodeAt(0) !== 65533) {
          e[D[245][j]] = 62720 + j;
          d[62720 + j] = D[245][j];
        }
      D[246] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8829\u881D\u881B\u8820\u8824\u881C\u882B\u884A\u896D\u8969\u896E\u896B\u89FA\u8B79\u8B78\u8B45\u8B7A\u8B7B\u8D10\u8D14\u8DAF\u8E8E\u8E8C\u8F5E\u8F5B\u8F5D\u9146\u9144\u9145\u91B9\u943F\u943B\u9436\u9429\u943D\u943C\u9430\u9439\u942A\u9437\u942C\u9440\u9431\u95E5\u95E4\u95E3\u9735\u973A\u97BF\u97E1\u9864\u98C9\u98C6\u98C0\u9958\u9956\u9A39\u9A3D\u9A46\u9A44\u9A42\u9A41\u9A3A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9A3F\u9ACD\u9B15\u9B17\u9B18\u9B16\u9B3A\u9B52\u9C2B\u9C1D\u9C1C\u9C2C\u9C23\u9C28\u9C29\u9C24\u9C21\u9DB7\u9DB6\u9DBC\u9DC1\u9DC7\u9DCA\u9DCF\u9DBE\u9DC5\u9DC3\u9DBB\u9DB5\u9DCE\u9DB9\u9DBA\u9DAC\u9DC8\u9DB1\u9DAD\u9DCC\u9DB3\u9DCD\u9DB2\u9E7A\u9E9C\u9EEB\u9EEE\u9EED\u9F1B\u9F18\u9F1A\u9F31\u9F4E\u9F65\u9F64\u9F92\u4EB9\u56C6\u56C5\u56CB\u5971\u5B4B\u5B4C\u5DD5\u5DD1\u5EF2\u6521\u6520\u6526\u6522\u6B0B\u6B08\u6B09\u6C0D\u7055\u7056\u7057\u7052\u721E\u721F\u72A9\u737F\u74D8\u74D5\u74D9\u74D7\u766D\u76AD\u7935\u79B4\u7A70\u7A71\u7C57\u7C5C\u7C59\u7C5B\u7C5A\uFFFD".split("");
      for (j = 0; j != D[246].length; ++j)
        if (D[246][j].charCodeAt(0) !== 65533) {
          e[D[246][j]] = 62976 + j;
          d[62976 + j] = D[246][j];
        }
      D[247] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7CF4\u7CF1\u7E91\u7F4F\u7F87\u81DE\u826B\u8634\u8635\u8633\u862C\u8632\u8636\u882C\u8828\u8826\u882A\u8825\u8971\u89BF\u89BE\u89FB\u8B7E\u8B84\u8B82\u8B86\u8B85\u8B7F\u8D15\u8E95\u8E94\u8E9A\u8E92\u8E90\u8E96\u8E97\u8F60\u8F62\u9147\u944C\u9450\u944A\u944B\u944F\u9447\u9445\u9448\u9449\u9446\u973F\u97E3\u986A\u9869\u98CB\u9954\u995B\u9A4E\u9A53\u9A54\u9A4C\u9A4F\u9A48\u9A4A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9A49\u9A52\u9A50\u9AD0\u9B19\u9B2B\u9B3B\u9B56\u9B55\u9C46\u9C48\u9C3F\u9C44\u9C39\u9C33\u9C41\u9C3C\u9C37\u9C34\u9C32\u9C3D\u9C36\u9DDB\u9DD2\u9DDE\u9DDA\u9DCB\u9DD0\u9DDC\u9DD1\u9DDF\u9DE9\u9DD9\u9DD8\u9DD6\u9DF5\u9DD5\u9DDD\u9EB6\u9EF0\u9F35\u9F33\u9F32\u9F42\u9F6B\u9F95\u9FA2\u513D\u5299\u58E8\u58E7\u5972\u5B4D\u5DD8\u882F\u5F4F\u6201\u6203\u6204\u6529\u6525\u6596\u66EB\u6B11\u6B12\u6B0F\u6BCA\u705B\u705A\u7222\u7382\u7381\u7383\u7670\u77D4\u7C67\u7C66\u7E95\u826C\u863A\u8640\u8639\u863C\u8631\u863B\u863E\u8830\u8832\u882E\u8833\u8976\u8974\u8973\u89FE\uFFFD".split("");
      for (j = 0; j != D[247].length; ++j)
        if (D[247][j].charCodeAt(0) !== 65533) {
          e[D[247][j]] = 63232 + j;
          d[63232 + j] = D[247][j];
        }
      D[248] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8B8C\u8B8E\u8B8B\u8B88\u8C45\u8D19\u8E98\u8F64\u8F63\u91BC\u9462\u9455\u945D\u9457\u945E\u97C4\u97C5\u9800\u9A56\u9A59\u9B1E\u9B1F\u9B20\u9C52\u9C58\u9C50\u9C4A\u9C4D\u9C4B\u9C55\u9C59\u9C4C\u9C4E\u9DFB\u9DF7\u9DEF\u9DE3\u9DEB\u9DF8\u9DE4\u9DF6\u9DE1\u9DEE\u9DE6\u9DF2\u9DF0\u9DE2\u9DEC\u9DF4\u9DF3\u9DE8\u9DED\u9EC2\u9ED0\u9EF2\u9EF3\u9F06\u9F1C\u9F38\u9F37\u9F36\u9F43\u9F4F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9F71\u9F70\u9F6E\u9F6F\u56D3\u56CD\u5B4E\u5C6D\u652D\u66ED\u66EE\u6B13\u705F\u7061\u705D\u7060\u7223\u74DB\u74E5\u77D5\u7938\u79B7\u79B6\u7C6A\u7E97\u7F89\u826D\u8643\u8838\u8837\u8835\u884B\u8B94\u8B95\u8E9E\u8E9F\u8EA0\u8E9D\u91BE\u91BD\u91C2\u946B\u9468\u9469\u96E5\u9746\u9743\u9747\u97C7\u97E5\u9A5E\u9AD5\u9B59\u9C63\u9C67\u9C66\u9C62\u9C5E\u9C60\u9E02\u9DFE\u9E07\u9E03\u9E06\u9E05\u9E00\u9E01\u9E09\u9DFF\u9DFD\u9E04\u9EA0\u9F1E\u9F46\u9F74\u9F75\u9F76\u56D4\u652E\u65B8\u6B18\u6B19\u6B17\u6B1A\u7062\u7226\u72AA\u77D8\u77D9\u7939\u7C69\u7C6B\u7CF6\u7E9A\uFFFD".split("");
      for (j = 0; j != D[248].length; ++j)
        if (D[248][j].charCodeAt(0) !== 65533) {
          e[D[248][j]] = 63488 + j;
          d[63488 + j] = D[248][j];
        }
      D[249] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7E98\u7E9B\u7E99\u81E0\u81E1\u8646\u8647\u8648\u8979\u897A\u897C\u897B\u89FF\u8B98\u8B99\u8EA5\u8EA4\u8EA3\u946E\u946D\u946F\u9471\u9473\u9749\u9872\u995F\u9C68\u9C6E\u9C6D\u9E0B\u9E0D\u9E10\u9E0F\u9E12\u9E11\u9EA1\u9EF5\u9F09\u9F47\u9F78\u9F7B\u9F7A\u9F79\u571E\u7066\u7C6F\u883C\u8DB2\u8EA6\u91C3\u9474\u9478\u9476\u9475\u9A60\u9C74\u9C73\u9C71\u9C75\u9E14\u9E13\u9EF6\u9F0A\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9FA4\u7068\u7065\u7CF7\u866A\u883E\u883D\u883F\u8B9E\u8C9C\u8EA9\u8EC9\u974B\u9873\u9874\u98CC\u9961\u99AB\u9A64\u9A66\u9A67\u9B24\u9E15\u9E17\u9F48\u6207\u6B1E\u7227\u864C\u8EA8\u9482\u9480\u9481\u9A69\u9A68\u9B2E\u9E19\u7229\u864B\u8B9F\u9483\u9C79\u9EB7\u7675\u9A6B\u9C7A\u9E1D\u7069\u706A\u9EA4\u9F7E\u9F49\u9F98\u7881\u92B9\u88CF\u58BB\u6052\u7CA7\u5AFA\u2554\u2566\u2557\u2560\u256C\u2563\u255A\u2569\u255D\u2552\u2564\u2555\u255E\u256A\u2561\u2558\u2567\u255B\u2553\u2565\u2556\u255F\u256B\u2562\u2559\u2568\u255C\u2551\u2550\u256D\u256E\u2570\u256F\u2593\uFFFD".split("");
      for (j = 0; j != D[249].length; ++j)
        if (D[249][j].charCodeAt(0) !== 65533) {
          e[D[249][j]] = 63744 + j;
          d[63744 + j] = D[249][j];
        }
      return { "enc": e, "dec": d };
    }();
    cptable2[1250] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\uFFFD\u201E\u2026\u2020\u2021\uFFFD\u2030\u0160\u2039\u015A\u0164\u017D\u0179\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\u0161\u203A\u015B\u0165\u017E\u017A\xA0\u02C7\u02D8\u0141\xA4\u0104\xA6\xA7\xA8\xA9\u015E\xAB\xAC\xAD\xAE\u017B\xB0\xB1\u02DB\u0142\xB4\xB5\xB6\xB7\xB8\u0105\u015F\xBB\u013D\u02DD\u013E\u017C\u0154\xC1\xC2\u0102\xC4\u0139\u0106\xC7\u010C\xC9\u0118\xCB\u011A\xCD\xCE\u010E\u0110\u0143\u0147\xD3\xD4\u0150\xD6\xD7\u0158\u016E\xDA\u0170\xDC\xDD\u0162\xDF\u0155\xE1\xE2\u0103\xE4\u013A\u0107\xE7\u010D\xE9\u0119\xEB\u011B\xED\xEE\u010F\u0111\u0144\u0148\xF3\xF4\u0151\xF6\xF7\u0159\u016F\xFA\u0171\xFC\xFD\u0163\u02D9", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1251] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u0402\u0403\u201A\u0453\u201E\u2026\u2020\u2021\u20AC\u2030\u0409\u2039\u040A\u040C\u040B\u040F\u0452\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\u0459\u203A\u045A\u045C\u045B\u045F\xA0\u040E\u045E\u0408\xA4\u0490\xA6\xA7\u0401\xA9\u0404\xAB\xAC\xAD\xAE\u0407\xB0\xB1\u0406\u0456\u0491\xB5\xB6\xB7\u0451\u2116\u0454\xBB\u0458\u0405\u0455\u0457\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1252] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\uFFFD\u017D\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\uFFFD\u017E\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1253] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\uFFFD\u2030\uFFFD\u2039\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\uFFFD\u203A\uFFFD\uFFFD\uFFFD\uFFFD\xA0\u0385\u0386\xA3\xA4\xA5\xA6\xA7\xA8\xA9\uFFFD\xAB\xAC\xAD\xAE\u2015\xB0\xB1\xB2\xB3\u0384\xB5\xB6\xB7\u0388\u0389\u038A\xBB\u038C\xBD\u038E\u038F\u0390\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\uFFFD\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\u03AA\u03AB\u03AC\u03AD\u03AE\u03AF\u03B0\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C2\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\u03CA\u03CB\u03CC\u03CD\u03CE\uFFFD", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1254] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\uFFFD\uFFFD\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\u011E\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u0130\u015E\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\u011F\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u0131\u015F\xFF", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1255] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\uFFFD\u2039\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\uFFFD\u203A\uFFFD\uFFFD\uFFFD\uFFFD\xA0\xA1\xA2\xA3\u20AA\xA5\xA6\xA7\xA8\xA9\xD7\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xF7\xBB\xBC\xBD\xBE\xBF\u05B0\u05B1\u05B2\u05B3\u05B4\u05B5\u05B6\u05B7\u05B8\u05B9\uFFFD\u05BB\u05BC\u05BD\u05BE\u05BF\u05C0\u05C1\u05C2\u05C3\u05F0\u05F1\u05F2\u05F3\u05F4\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u05D0\u05D1\u05D2\u05D3\u05D4\u05D5\u05D6\u05D7\u05D8\u05D9\u05DA\u05DB\u05DC\u05DD\u05DE\u05DF\u05E0\u05E1\u05E2\u05E3\u05E4\u05E5\u05E6\u05E7\u05E8\u05E9\u05EA\uFFFD\uFFFD\u200E\u200F\uFFFD", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1256] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\u067E\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0679\u2039\u0152\u0686\u0698\u0688\u06AF\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u06A9\u2122\u0691\u203A\u0153\u200C\u200D\u06BA\xA0\u060C\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\u06BE\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\u061B\xBB\xBC\xBD\xBE\u061F\u06C1\u0621\u0622\u0623\u0624\u0625\u0626\u0627\u0628\u0629\u062A\u062B\u062C\u062D\u062E\u062F\u0630\u0631\u0632\u0633\u0634\u0635\u0636\xD7\u0637\u0638\u0639\u063A\u0640\u0641\u0642\u0643\xE0\u0644\xE2\u0645\u0646\u0647\u0648\xE7\xE8\xE9\xEA\xEB\u0649\u064A\xEE\xEF\u064B\u064C\u064D\u064E\xF4\u064F\u0650\xF7\u0651\xF9\u0652\xFB\xFC\u200E\u200F\u06D2", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1257] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\uFFFD\u201E\u2026\u2020\u2021\uFFFD\u2030\uFFFD\u2039\uFFFD\xA8\u02C7\xB8\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\uFFFD\u2122\uFFFD\u203A\uFFFD\xAF\u02DB\uFFFD\xA0\uFFFD\xA2\xA3\xA4\uFFFD\xA6\xA7\xD8\xA9\u0156\xAB\xAC\xAD\xAE\xC6\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xF8\xB9\u0157\xBB\xBC\xBD\xBE\xE6\u0104\u012E\u0100\u0106\xC4\xC5\u0118\u0112\u010C\xC9\u0179\u0116\u0122\u0136\u012A\u013B\u0160\u0143\u0145\xD3\u014C\xD5\xD6\xD7\u0172\u0141\u015A\u016A\xDC\u017B\u017D\xDF\u0105\u012F\u0101\u0107\xE4\xE5\u0119\u0113\u010D\xE9\u017A\u0117\u0123\u0137\u012B\u013C\u0161\u0144\u0146\xF3\u014D\xF5\xF6\xF7\u0173\u0142\u015B\u016B\xFC\u017C\u017E\u02D9", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1258] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u20AC\uFFFD\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\uFFFD\u2039\u0152\uFFFD\uFFFD\uFFFD\uFFFD\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\uFFFD\u203A\u0153\uFFFD\uFFFD\u0178\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\u0102\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\u0300\xCD\xCE\xCF\u0110\xD1\u0309\xD3\xD4\u01A0\xD6\xD7\xD8\xD9\xDA\xDB\xDC\u01AF\u0303\xDF\xE0\xE1\xE2\u0103\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\u0301\xED\xEE\xEF\u0111\xF1\u0323\xF3\xF4\u01A1\xF6\xF7\xF8\xF9\xFA\xFB\xFC\u01B0\u20AB\xFF", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[1e4] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\u2039\u203A\uFB01\uFB02\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[10006] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC4\xB9\xB2\xC9\xB3\xD6\xDC\u0385\xE0\xE2\xE4\u0384\xA8\xE7\xE9\xE8\xEA\xEB\xA3\u2122\xEE\xEF\u2022\xBD\u2030\xF4\xF6\xA6\xAD\xF9\xFB\xFC\u2020\u0393\u0394\u0398\u039B\u039E\u03A0\xDF\xAE\xA9\u03A3\u03AA\xA7\u2260\xB0\u0387\u0391\xB1\u2264\u2265\xA5\u0392\u0395\u0396\u0397\u0399\u039A\u039C\u03A6\u03AB\u03A8\u03A9\u03AC\u039D\xAC\u039F\u03A1\u2248\u03A4\xAB\xBB\u2026\xA0\u03A5\u03A7\u0386\u0388\u0153\u2013\u2015\u201C\u201D\u2018\u2019\xF7\u0389\u038A\u038C\u038E\u03AD\u03AE\u03AF\u03CC\u038F\u03CD\u03B1\u03B2\u03C8\u03B4\u03B5\u03C6\u03B3\u03B7\u03B9\u03BE\u03BA\u03BB\u03BC\u03BD\u03BF\u03C0\u03CE\u03C1\u03C3\u03C4\u03B8\u03C9\u03C2\u03C7\u03C5\u03B6\u03CA\u03CB\u0390\u03B0\uFFFD", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[10007] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\u0410\u0411\u0412\u0413\u0414\u0415\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\u2020\xB0\xA2\xA3\xA7\u2022\xB6\u0406\xAE\xA9\u2122\u0402\u0452\u2260\u0403\u0453\u221E\xB1\u2264\u2265\u0456\xB5\u2202\u0408\u0404\u0454\u0407\u0457\u0409\u0459\u040A\u045A\u0458\u0405\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\u040B\u045B\u040C\u045C\u0455\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u201E\u040E\u045E\u040F\u045F\u2116\u0401\u0451\u044F\u0430\u0431\u0432\u0433\u0434\u0435\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\xA4", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[10008] = function() {
      var d = [], e = {}, D = [], j;
      D[0] = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\x80\uF8D8\uF8D9\uF8DA\uF8DB\uF8DC\uF8DD\uF8DE\uF8DF\uF8E0\uF8E1\uF8E2\uF8E3\uF8E4\uF8E5\uF8E6\uF8E7\uF8E8\uF8E9\uF8EA\uF8EB\uF8EC\uF8ED\uF8EE\uF8EF\uF8F0\uF8F1\uF8F2\uF8F3\uF8F4\uF8F5\uF8F6\uF8F7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uF8F8\uF8F9\uF8FA\uF8FB\uF8FC\uF8FD\uF8FE\uF8FF".split("");
      for (j = 0; j != D[0].length; ++j)
        if (D[0][j].charCodeAt(0) !== 65533) {
          e[D[0][j]] = 0 + j;
          d[0 + j] = D[0][j];
        }
      D[161] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3000\u3001\u3002\u30FB\u02C9\u02C7\xA8\u3003\u3005\u2015\uFF5E\uFFFD\u2026\u2018\u2019\u201C\u201D\u3014\u3015\u3008\u3009\u300A\u300B\u300C\u300D\u300E\u300F\u3016\u3017\u3010\u3011\xB1\xD7\xF7\u2236\u2227\u2228\u2211\u220F\u222A\u2229\u2208\u2237\u221A\u22A5\u2225\u2220\u2312\u2299\u222B\u222E\u2261\u224C\u2248\u223D\u221D\u2260\u226E\u226F\u2264\u2265\u221E\u2235\u2234\u2642\u2640\xB0\u2032\u2033\u2103\uFF04\xA4\uFFE0\uFFE1\u2030\xA7\u2116\u2606\u2605\u25CB\u25CF\u25CE\u25C7\u25C6\u25A1\u25A0\u25B3\u25B2\u203B\u2192\u2190\u2191\u2193\u3013\uFFFD".split("");
      for (j = 0; j != D[161].length; ++j)
        if (D[161][j].charCodeAt(0) !== 65533) {
          e[D[161][j]] = 41216 + j;
          d[41216 + j] = D[161][j];
        }
      D[162] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2488\u2489\u248A\u248B\u248C\u248D\u248E\u248F\u2490\u2491\u2492\u2493\u2494\u2495\u2496\u2497\u2498\u2499\u249A\u249B\u2474\u2475\u2476\u2477\u2478\u2479\u247A\u247B\u247C\u247D\u247E\u247F\u2480\u2481\u2482\u2483\u2484\u2485\u2486\u2487\u2460\u2461\u2462\u2463\u2464\u2465\u2466\u2467\u2468\u2469\uFFFD\uFFFD\u3220\u3221\u3222\u3223\u3224\u3225\u3226\u3227\u3228\u3229\uFFFD\uFFFD\u2160\u2161\u2162\u2163\u2164\u2165\u2166\u2167\u2168\u2169\u216A\u216B\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[162].length; ++j)
        if (D[162][j].charCodeAt(0) !== 65533) {
          e[D[162][j]] = 41472 + j;
          d[41472 + j] = D[162][j];
        }
      D[163] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFF01\uFF02\uFF03\uFFE5\uFF05\uFF06\uFF07\uFF08\uFF09\uFF0A\uFF0B\uFF0C\uFF0D\uFF0E\uFF0F\uFF10\uFF11\uFF12\uFF13\uFF14\uFF15\uFF16\uFF17\uFF18\uFF19\uFF1A\uFF1B\uFF1C\uFF1D\uFF1E\uFF1F\uFF20\uFF21\uFF22\uFF23\uFF24\uFF25\uFF26\uFF27\uFF28\uFF29\uFF2A\uFF2B\uFF2C\uFF2D\uFF2E\uFF2F\uFF30\uFF31\uFF32\uFF33\uFF34\uFF35\uFF36\uFF37\uFF38\uFF39\uFF3A\uFF3B\uFF3C\uFF3D\uFF3E\uFF3F\uFF40\uFF41\uFF42\uFF43\uFF44\uFF45\uFF46\uFF47\uFF48\uFF49\uFF4A\uFF4B\uFF4C\uFF4D\uFF4E\uFF4F\uFF50\uFF51\uFF52\uFF53\uFF54\uFF55\uFF56\uFF57\uFF58\uFF59\uFF5A\uFF5B\uFF5C\uFF5D\uFFE3\uFFFD".split("");
      for (j = 0; j != D[163].length; ++j)
        if (D[163][j].charCodeAt(0) !== 65533) {
          e[D[163][j]] = 41728 + j;
          d[41728 + j] = D[163][j];
        }
      D[164] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3041\u3042\u3043\u3044\u3045\u3046\u3047\u3048\u3049\u304A\u304B\u304C\u304D\u304E\u304F\u3050\u3051\u3052\u3053\u3054\u3055\u3056\u3057\u3058\u3059\u305A\u305B\u305C\u305D\u305E\u305F\u3060\u3061\u3062\u3063\u3064\u3065\u3066\u3067\u3068\u3069\u306A\u306B\u306C\u306D\u306E\u306F\u3070\u3071\u3072\u3073\u3074\u3075\u3076\u3077\u3078\u3079\u307A\u307B\u307C\u307D\u307E\u307F\u3080\u3081\u3082\u3083\u3084\u3085\u3086\u3087\u3088\u3089\u308A\u308B\u308C\u308D\u308E\u308F\u3090\u3091\u3092\u3093\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[164].length; ++j)
        if (D[164][j].charCodeAt(0) !== 65533) {
          e[D[164][j]] = 41984 + j;
          d[41984 + j] = D[164][j];
        }
      D[165] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u30A1\u30A2\u30A3\u30A4\u30A5\u30A6\u30A7\u30A8\u30A9\u30AA\u30AB\u30AC\u30AD\u30AE\u30AF\u30B0\u30B1\u30B2\u30B3\u30B4\u30B5\u30B6\u30B7\u30B8\u30B9\u30BA\u30BB\u30BC\u30BD\u30BE\u30BF\u30C0\u30C1\u30C2\u30C3\u30C4\u30C5\u30C6\u30C7\u30C8\u30C9\u30CA\u30CB\u30CC\u30CD\u30CE\u30CF\u30D0\u30D1\u30D2\u30D3\u30D4\u30D5\u30D6\u30D7\u30D8\u30D9\u30DA\u30DB\u30DC\u30DD\u30DE\u30DF\u30E0\u30E1\u30E2\u30E3\u30E4\u30E5\u30E6\u30E7\u30E8\u30E9\u30EA\u30EB\u30EC\u30ED\u30EE\u30EF\u30F0\u30F1\u30F2\u30F3\u30F4\u30F5\u30F6\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[165].length; ++j)
        if (D[165][j].charCodeAt(0) !== 65533) {
          e[D[165][j]] = 42240 + j;
          d[42240 + j] = D[165][j];
        }
      D[166] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0391\u0392\u0393\u0394\u0395\u0396\u0397\u0398\u0399\u039A\u039B\u039C\u039D\u039E\u039F\u03A0\u03A1\u03A3\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3\u03C4\u03C5\u03C6\u03C7\u03C8\u03C9\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[166].length; ++j)
        if (D[166][j].charCodeAt(0) !== 65533) {
          e[D[166][j]] = 42496 + j;
          d[42496 + j] = D[166][j];
        }
      D[167] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0410\u0411\u0412\u0413\u0414\u0415\u0401\u0416\u0417\u0418\u0419\u041A\u041B\u041C\u041D\u041E\u041F\u0420\u0421\u0422\u0423\u0424\u0425\u0426\u0427\u0428\u0429\u042A\u042B\u042C\u042D\u042E\u042F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0430\u0431\u0432\u0433\u0434\u0435\u0451\u0436\u0437\u0438\u0439\u043A\u043B\u043C\u043D\u043E\u043F\u0440\u0441\u0442\u0443\u0444\u0445\u0446\u0447\u0448\u0449\u044A\u044B\u044C\u044D\u044E\u044F\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[167].length; ++j)
        if (D[167][j].charCodeAt(0) !== 65533) {
          e[D[167][j]] = 42752 + j;
          d[42752 + j] = D[167][j];
        }
      D[168] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u0101\xE1\u01CE\xE0\u0113\xE9\u011B\xE8\u012B\xED\u01D0\xEC\u014D\xF3\u01D2\xF2\u016B\xFA\u01D4\xF9\u01D6\u01D8\u01DA\u01DC\xFC\xEA\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u3105\u3106\u3107\u3108\u3109\u310A\u310B\u310C\u310D\u310E\u310F\u3110\u3111\u3112\u3113\u3114\u3115\u3116\u3117\u3118\u3119\u311A\u311B\u311C\u311D\u311E\u311F\u3120\u3121\u3122\u3123\u3124\u3125\u3126\u3127\u3128\u3129\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[168].length; ++j)
        if (D[168][j].charCodeAt(0) !== 65533) {
          e[D[168][j]] = 43008 + j;
          d[43008 + j] = D[168][j];
        }
      D[169] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u2500\u2501\u2502\u2503\u2504\u2505\u2506\u2507\u2508\u2509\u250A\u250B\u250C\u250D\u250E\u250F\u2510\u2511\u2512\u2513\u2514\u2515\u2516\u2517\u2518\u2519\u251A\u251B\u251C\u251D\u251E\u251F\u2520\u2521\u2522\u2523\u2524\u2525\u2526\u2527\u2528\u2529\u252A\u252B\u252C\u252D\u252E\u252F\u2530\u2531\u2532\u2533\u2534\u2535\u2536\u2537\u2538\u2539\u253A\u253B\u253C\u253D\u253E\u253F\u2540\u2541\u2542\u2543\u2544\u2545\u2546\u2547\u2548\u2549\u254A\u254B\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[169].length; ++j)
        if (D[169][j].charCodeAt(0) !== 65533) {
          e[D[169][j]] = 43264 + j;
          d[43264 + j] = D[169][j];
        }
      D[176] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u554A\u963F\u57C3\u6328\u54CE\u5509\u54C0\u7691\u764C\u853C\u77EE\u827E\u788D\u7231\u9698\u978D\u6C28\u5B89\u4FFA\u6309\u6697\u5CB8\u80FA\u6848\u80AE\u6602\u76CE\u51F9\u6556\u71AC\u7FF1\u8884\u50B2\u5965\u61CA\u6FB3\u82AD\u634C\u6252\u53ED\u5427\u7B06\u516B\u75A4\u5DF4\u62D4\u8DCB\u9776\u628A\u8019\u575D\u9738\u7F62\u7238\u767D\u67CF\u767E\u6446\u4F70\u8D25\u62DC\u7A17\u6591\u73ED\u642C\u6273\u822C\u9881\u677F\u7248\u626E\u62CC\u4F34\u74E3\u534A\u529E\u7ECA\u90A6\u5E2E\u6886\u699C\u8180\u7ED1\u68D2\u78C5\u868C\u9551\u508D\u8C24\u82DE\u80DE\u5305\u8912\u5265\uFFFD".split("");
      for (j = 0; j != D[176].length; ++j)
        if (D[176][j].charCodeAt(0) !== 65533) {
          e[D[176][j]] = 45056 + j;
          d[45056 + j] = D[176][j];
        }
      D[177] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8584\u96F9\u4FDD\u5821\u9971\u5B9D\u62B1\u62A5\u66B4\u8C79\u9C8D\u7206\u676F\u7891\u60B2\u5351\u5317\u8F88\u80CC\u8D1D\u94A1\u500D\u72C8\u5907\u60EB\u7119\u88AB\u5954\u82EF\u672C\u7B28\u5D29\u7EF7\u752D\u6CF5\u8E66\u8FF8\u903C\u9F3B\u6BD4\u9119\u7B14\u5F7C\u78A7\u84D6\u853D\u6BD5\u6BD9\u6BD6\u5E01\u5E87\u75F9\u95ED\u655D\u5F0A\u5FC5\u8F9F\u58C1\u81C2\u907F\u965B\u97AD\u8FB9\u7F16\u8D2C\u6241\u4FBF\u53D8\u535E\u8FA8\u8FA9\u8FAB\u904D\u6807\u5F6A\u8198\u8868\u9CD6\u618B\u522B\u762A\u5F6C\u658C\u6FD2\u6EE8\u5BBE\u6448\u5175\u51B0\u67C4\u4E19\u79C9\u997C\u70B3\uFFFD".split("");
      for (j = 0; j != D[177].length; ++j)
        if (D[177][j].charCodeAt(0) !== 65533) {
          e[D[177][j]] = 45312 + j;
          d[45312 + j] = D[177][j];
        }
      D[178] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u75C5\u5E76\u73BB\u83E0\u64AD\u62E8\u94B5\u6CE2\u535A\u52C3\u640F\u94C2\u7B94\u4F2F\u5E1B\u8236\u8116\u818A\u6E24\u6CCA\u9A73\u6355\u535C\u54FA\u8865\u57E0\u4E0D\u5E03\u6B65\u7C3F\u90E8\u6016\u64E6\u731C\u88C1\u6750\u624D\u8D22\u776C\u8E29\u91C7\u5F69\u83DC\u8521\u9910\u53C2\u8695\u6B8B\u60ED\u60E8\u707F\u82CD\u8231\u4ED3\u6CA7\u85CF\u64CD\u7CD9\u69FD\u66F9\u8349\u5395\u7B56\u4FA7\u518C\u6D4B\u5C42\u8E6D\u63D2\u53C9\u832C\u8336\u67E5\u78B4\u643D\u5BDF\u5C94\u5DEE\u8BE7\u62C6\u67F4\u8C7A\u6400\u63BA\u8749\u998B\u8C17\u7F20\u94F2\u4EA7\u9610\u98A4\u660C\u7316\uFFFD".split("");
      for (j = 0; j != D[178].length; ++j)
        if (D[178][j].charCodeAt(0) !== 65533) {
          e[D[178][j]] = 45568 + j;
          d[45568 + j] = D[178][j];
        }
      D[179] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u573A\u5C1D\u5E38\u957F\u507F\u80A0\u5382\u655E\u7545\u5531\u5021\u8D85\u6284\u949E\u671D\u5632\u6F6E\u5DE2\u5435\u7092\u8F66\u626F\u64A4\u63A3\u5F7B\u6F88\u90F4\u81E3\u8FB0\u5C18\u6668\u5FF1\u6C89\u9648\u8D81\u886C\u6491\u79F0\u57CE\u6A59\u6210\u5448\u4E58\u7A0B\u60E9\u6F84\u8BDA\u627F\u901E\u9A8B\u79E4\u5403\u75F4\u6301\u5319\u6C60\u8FDF\u5F1B\u9A70\u803B\u9F7F\u4F88\u5C3A\u8D64\u7FC5\u65A5\u70BD\u5145\u51B2\u866B\u5D07\u5BA0\u62BD\u916C\u7574\u8E0C\u7A20\u6101\u7B79\u4EC7\u7EF8\u7785\u4E11\u81ED\u521D\u51FA\u6A71\u53A8\u8E87\u9504\u96CF\u6EC1\u9664\u695A\uFFFD".split("");
      for (j = 0; j != D[179].length; ++j)
        if (D[179][j].charCodeAt(0) !== 65533) {
          e[D[179][j]] = 45824 + j;
          d[45824 + j] = D[179][j];
        }
      D[180] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7840\u50A8\u77D7\u6410\u89E6\u5904\u63E3\u5DDD\u7A7F\u693D\u4F20\u8239\u5598\u4E32\u75AE\u7A97\u5E62\u5E8A\u95EF\u521B\u5439\u708A\u6376\u9524\u5782\u6625\u693F\u9187\u5507\u6DF3\u7EAF\u8822\u6233\u7EF0\u75B5\u8328\u78C1\u96CC\u8F9E\u6148\u74F7\u8BCD\u6B64\u523A\u8D50\u6B21\u806A\u8471\u56F1\u5306\u4ECE\u4E1B\u51D1\u7C97\u918B\u7C07\u4FC3\u8E7F\u7BE1\u7A9C\u6467\u5D14\u50AC\u8106\u7601\u7CB9\u6DEC\u7FE0\u6751\u5B58\u5BF8\u78CB\u64AE\u6413\u63AA\u632B\u9519\u642D\u8FBE\u7B54\u7629\u6253\u5927\u5446\u6B79\u50A3\u6234\u5E26\u6B86\u4EE3\u8D37\u888B\u5F85\u902E\uFFFD".split("");
      for (j = 0; j != D[180].length; ++j)
        if (D[180][j].charCodeAt(0) !== 65533) {
          e[D[180][j]] = 46080 + j;
          d[46080 + j] = D[180][j];
        }
      D[181] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6020\u803D\u62C5\u4E39\u5355\u90F8\u63B8\u80C6\u65E6\u6C2E\u4F46\u60EE\u6DE1\u8BDE\u5F39\u86CB\u5F53\u6321\u515A\u8361\u6863\u5200\u6363\u8E48\u5012\u5C9B\u7977\u5BFC\u5230\u7A3B\u60BC\u9053\u76D7\u5FB7\u5F97\u7684\u8E6C\u706F\u767B\u7B49\u77AA\u51F3\u9093\u5824\u4F4E\u6EF4\u8FEA\u654C\u7B1B\u72C4\u6DA4\u7FDF\u5AE1\u62B5\u5E95\u5730\u8482\u7B2C\u5E1D\u5F1F\u9012\u7F14\u98A0\u6382\u6EC7\u7898\u70B9\u5178\u975B\u57AB\u7535\u4F43\u7538\u5E97\u60E6\u5960\u6DC0\u6BBF\u7889\u53FC\u96D5\u51CB\u5201\u6389\u540A\u9493\u8C03\u8DCC\u7239\u789F\u8776\u8FED\u8C0D\u53E0\uFFFD".split("");
      for (j = 0; j != D[181].length; ++j)
        if (D[181][j].charCodeAt(0) !== 65533) {
          e[D[181][j]] = 46336 + j;
          d[46336 + j] = D[181][j];
        }
      D[182] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E01\u76EF\u53EE\u9489\u9876\u9F0E\u952D\u5B9A\u8BA2\u4E22\u4E1C\u51AC\u8463\u61C2\u52A8\u680B\u4F97\u606B\u51BB\u6D1E\u515C\u6296\u6597\u9661\u8C46\u9017\u75D8\u90FD\u7763\u6BD2\u728A\u72EC\u8BFB\u5835\u7779\u8D4C\u675C\u9540\u809A\u5EA6\u6E21\u5992\u7AEF\u77ED\u953B\u6BB5\u65AD\u7F0E\u5806\u5151\u961F\u5BF9\u58A9\u5428\u8E72\u6566\u987F\u56E4\u949D\u76FE\u9041\u6387\u54C6\u591A\u593A\u579B\u8EB2\u6735\u8DFA\u8235\u5241\u60F0\u5815\u86FE\u5CE8\u9E45\u4FC4\u989D\u8BB9\u5A25\u6076\u5384\u627C\u904F\u9102\u997F\u6069\u800C\u513F\u8033\u5C14\u9975\u6D31\u4E8C\uFFFD".split("");
      for (j = 0; j != D[182].length; ++j)
        if (D[182][j].charCodeAt(0) !== 65533) {
          e[D[182][j]] = 46592 + j;
          d[46592 + j] = D[182][j];
        }
      D[183] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8D30\u53D1\u7F5A\u7B4F\u4F10\u4E4F\u9600\u6CD5\u73D0\u85E9\u5E06\u756A\u7FFB\u6A0A\u77FE\u9492\u7E41\u51E1\u70E6\u53CD\u8FD4\u8303\u8D29\u72AF\u996D\u6CDB\u574A\u82B3\u65B9\u80AA\u623F\u9632\u59A8\u4EFF\u8BBF\u7EBA\u653E\u83F2\u975E\u5561\u98DE\u80A5\u532A\u8BFD\u5420\u80BA\u5E9F\u6CB8\u8D39\u82AC\u915A\u5429\u6C1B\u5206\u7EB7\u575F\u711A\u6C7E\u7C89\u594B\u4EFD\u5FFF\u6124\u7CAA\u4E30\u5C01\u67AB\u8702\u5CF0\u950B\u98CE\u75AF\u70FD\u9022\u51AF\u7F1D\u8BBD\u5949\u51E4\u4F5B\u5426\u592B\u6577\u80A4\u5B75\u6276\u62C2\u8F90\u5E45\u6C1F\u7B26\u4F0F\u4FD8\u670D\uFFFD".split("");
      for (j = 0; j != D[183].length; ++j)
        if (D[183][j].charCodeAt(0) !== 65533) {
          e[D[183][j]] = 46848 + j;
          d[46848 + j] = D[183][j];
        }
      D[184] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D6E\u6DAA\u798F\u88B1\u5F17\u752B\u629A\u8F85\u4FEF\u91DC\u65A7\u812F\u8151\u5E9C\u8150\u8D74\u526F\u8986\u8D4B\u590D\u5085\u4ED8\u961C\u7236\u8179\u8D1F\u5BCC\u8BA3\u9644\u5987\u7F1A\u5490\u5676\u560E\u8BE5\u6539\u6982\u9499\u76D6\u6E89\u5E72\u7518\u6746\u67D1\u7AFF\u809D\u8D76\u611F\u79C6\u6562\u8D63\u5188\u521A\u94A2\u7F38\u809B\u7EB2\u5C97\u6E2F\u6760\u7BD9\u768B\u9AD8\u818F\u7F94\u7CD5\u641E\u9550\u7A3F\u544A\u54E5\u6B4C\u6401\u6208\u9E3D\u80F3\u7599\u5272\u9769\u845B\u683C\u86E4\u9601\u9694\u94EC\u4E2A\u5404\u7ED9\u6839\u8DDF\u8015\u66F4\u5E9A\u7FB9\uFFFD".split("");
      for (j = 0; j != D[184].length; ++j)
        if (D[184][j].charCodeAt(0) !== 65533) {
          e[D[184][j]] = 47104 + j;
          d[47104 + j] = D[184][j];
        }
      D[185] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u57C2\u803F\u6897\u5DE5\u653B\u529F\u606D\u9F9A\u4F9B\u8EAC\u516C\u5BAB\u5F13\u5DE9\u6C5E\u62F1\u8D21\u5171\u94A9\u52FE\u6C9F\u82DF\u72D7\u57A2\u6784\u8D2D\u591F\u8F9C\u83C7\u5495\u7B8D\u4F30\u6CBD\u5B64\u59D1\u9F13\u53E4\u86CA\u9AA8\u8C37\u80A1\u6545\u987E\u56FA\u96C7\u522E\u74DC\u5250\u5BE1\u6302\u8902\u4E56\u62D0\u602A\u68FA\u5173\u5B98\u51A0\u89C2\u7BA1\u9986\u7F50\u60EF\u704C\u8D2F\u5149\u5E7F\u901B\u7470\u89C4\u572D\u7845\u5F52\u9F9F\u95FA\u8F68\u9B3C\u8BE1\u7678\u6842\u67DC\u8DEA\u8D35\u523D\u8F8A\u6EDA\u68CD\u9505\u90ED\u56FD\u679C\u88F9\u8FC7\u54C8\uFFFD".split("");
      for (j = 0; j != D[185].length; ++j)
        if (D[185][j].charCodeAt(0) !== 65533) {
          e[D[185][j]] = 47360 + j;
          d[47360 + j] = D[185][j];
        }
      D[186] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9AB8\u5B69\u6D77\u6C26\u4EA5\u5BB3\u9A87\u9163\u61A8\u90AF\u97E9\u542B\u6DB5\u5BD2\u51FD\u558A\u7F55\u7FF0\u64BC\u634D\u65F1\u61BE\u608D\u710A\u6C57\u6C49\u592F\u676D\u822A\u58D5\u568E\u8C6A\u6BEB\u90DD\u597D\u8017\u53F7\u6D69\u5475\u559D\u8377\u83CF\u6838\u79BE\u548C\u4F55\u5408\u76D2\u8C89\u9602\u6CB3\u6DB8\u8D6B\u8910\u9E64\u8D3A\u563F\u9ED1\u75D5\u5F88\u72E0\u6068\u54FC\u4EA8\u6A2A\u8861\u6052\u8F70\u54C4\u70D8\u8679\u9E3F\u6D2A\u5B8F\u5F18\u7EA2\u5589\u4FAF\u7334\u543C\u539A\u5019\u540E\u547C\u4E4E\u5FFD\u745A\u58F6\u846B\u80E1\u8774\u72D0\u7CCA\u6E56\uFFFD".split("");
      for (j = 0; j != D[186].length; ++j)
        if (D[186][j].charCodeAt(0) !== 65533) {
          e[D[186][j]] = 47616 + j;
          d[47616 + j] = D[186][j];
        }
      D[187] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5F27\u864E\u552C\u62A4\u4E92\u6CAA\u6237\u82B1\u54D7\u534E\u733E\u6ED1\u753B\u5212\u5316\u8BDD\u69D0\u5F8A\u6000\u6DEE\u574F\u6B22\u73AF\u6853\u8FD8\u7F13\u6362\u60A3\u5524\u75EA\u8C62\u7115\u6DA3\u5BA6\u5E7B\u8352\u614C\u9EC4\u78FA\u8757\u7C27\u7687\u51F0\u60F6\u714C\u6643\u5E4C\u604D\u8C0E\u7070\u6325\u8F89\u5FBD\u6062\u86D4\u56DE\u6BC1\u6094\u6167\u5349\u60E0\u6666\u8D3F\u79FD\u4F1A\u70E9\u6C47\u8BB3\u8BF2\u7ED8\u8364\u660F\u5A5A\u9B42\u6D51\u6DF7\u8C41\u6D3B\u4F19\u706B\u83B7\u6216\u60D1\u970D\u8D27\u7978\u51FB\u573E\u57FA\u673A\u7578\u7A3D\u79EF\u7B95\uFFFD".split("");
      for (j = 0; j != D[187].length; ++j)
        if (D[187][j].charCodeAt(0) !== 65533) {
          e[D[187][j]] = 47872 + j;
          d[47872 + j] = D[187][j];
        }
      D[188] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u808C\u9965\u8FF9\u6FC0\u8BA5\u9E21\u59EC\u7EE9\u7F09\u5409\u6781\u68D8\u8F91\u7C4D\u96C6\u53CA\u6025\u75BE\u6C72\u5373\u5AC9\u7EA7\u6324\u51E0\u810A\u5DF1\u84DF\u6280\u5180\u5B63\u4F0E\u796D\u5242\u60B8\u6D4E\u5BC4\u5BC2\u8BA1\u8BB0\u65E2\u5FCC\u9645\u5993\u7EE7\u7EAA\u5609\u67B7\u5939\u4F73\u5BB6\u52A0\u835A\u988A\u8D3E\u7532\u94BE\u5047\u7A3C\u4EF7\u67B6\u9A7E\u5AC1\u6B7C\u76D1\u575A\u5C16\u7B3A\u95F4\u714E\u517C\u80A9\u8270\u5978\u7F04\u8327\u68C0\u67EC\u78B1\u7877\u62E3\u6361\u7B80\u4FED\u526A\u51CF\u8350\u69DB\u9274\u8DF5\u8D31\u89C1\u952E\u7BAD\u4EF6\uFFFD".split("");
      for (j = 0; j != D[188].length; ++j)
        if (D[188][j].charCodeAt(0) !== 65533) {
          e[D[188][j]] = 48128 + j;
          d[48128 + j] = D[188][j];
        }
      D[189] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5065\u8230\u5251\u996F\u6E10\u6E85\u6DA7\u5EFA\u50F5\u59DC\u5C06\u6D46\u6C5F\u7586\u848B\u6868\u5956\u8BB2\u5320\u9171\u964D\u8549\u6912\u7901\u7126\u80F6\u4EA4\u90CA\u6D47\u9A84\u5A07\u56BC\u6405\u94F0\u77EB\u4FA5\u811A\u72E1\u89D2\u997A\u7F34\u7EDE\u527F\u6559\u9175\u8F7F\u8F83\u53EB\u7A96\u63ED\u63A5\u7686\u79F8\u8857\u9636\u622A\u52AB\u8282\u6854\u6770\u6377\u776B\u7AED\u6D01\u7ED3\u89E3\u59D0\u6212\u85C9\u82A5\u754C\u501F\u4ECB\u75A5\u8BEB\u5C4A\u5DFE\u7B4B\u65A4\u91D1\u4ECA\u6D25\u895F\u7D27\u9526\u4EC5\u8C28\u8FDB\u9773\u664B\u7981\u8FD1\u70EC\u6D78\uFFFD".split("");
      for (j = 0; j != D[189].length; ++j)
        if (D[189][j].charCodeAt(0) !== 65533) {
          e[D[189][j]] = 48384 + j;
          d[48384 + j] = D[189][j];
        }
      D[190] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5C3D\u52B2\u8346\u5162\u830E\u775B\u6676\u9CB8\u4EAC\u60CA\u7CBE\u7CB3\u7ECF\u4E95\u8B66\u666F\u9888\u9759\u5883\u656C\u955C\u5F84\u75C9\u9756\u7ADF\u7ADE\u51C0\u70AF\u7A98\u63EA\u7A76\u7EA0\u7396\u97ED\u4E45\u7078\u4E5D\u9152\u53A9\u6551\u65E7\u81FC\u8205\u548E\u5C31\u759A\u97A0\u62D8\u72D9\u75BD\u5C45\u9A79\u83CA\u5C40\u5480\u77E9\u4E3E\u6CAE\u805A\u62D2\u636E\u5DE8\u5177\u8DDD\u8E1E\u952F\u4FF1\u53E5\u60E7\u70AC\u5267\u6350\u9E43\u5A1F\u5026\u7737\u5377\u7EE2\u6485\u652B\u6289\u6398\u5014\u7235\u89C9\u51B3\u8BC0\u7EDD\u5747\u83CC\u94A7\u519B\u541B\u5CFB\uFFFD".split("");
      for (j = 0; j != D[190].length; ++j)
        if (D[190][j].charCodeAt(0) !== 65533) {
          e[D[190][j]] = 48640 + j;
          d[48640 + j] = D[190][j];
        }
      D[191] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4FCA\u7AE3\u6D5A\u90E1\u9A8F\u5580\u5496\u5361\u54AF\u5F00\u63E9\u6977\u51EF\u6168\u520A\u582A\u52D8\u574E\u780D\u770B\u5EB7\u6177\u7CE0\u625B\u6297\u4EA2\u7095\u8003\u62F7\u70E4\u9760\u5777\u82DB\u67EF\u68F5\u78D5\u9897\u79D1\u58F3\u54B3\u53EF\u6E34\u514B\u523B\u5BA2\u8BFE\u80AF\u5543\u57A6\u6073\u5751\u542D\u7A7A\u6050\u5B54\u63A7\u62A0\u53E3\u6263\u5BC7\u67AF\u54ED\u7A9F\u82E6\u9177\u5E93\u88E4\u5938\u57AE\u630E\u8DE8\u80EF\u5757\u7B77\u4FA9\u5FEB\u5BBD\u6B3E\u5321\u7B50\u72C2\u6846\u77FF\u7736\u65F7\u51B5\u4E8F\u76D4\u5CBF\u7AA5\u8475\u594E\u9B41\u5080\uFFFD".split("");
      for (j = 0; j != D[191].length; ++j)
        if (D[191][j].charCodeAt(0) !== 65533) {
          e[D[191][j]] = 48896 + j;
          d[48896 + j] = D[191][j];
        }
      D[192] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9988\u6127\u6E83\u5764\u6606\u6346\u56F0\u62EC\u6269\u5ED3\u9614\u5783\u62C9\u5587\u8721\u814A\u8FA3\u5566\u83B1\u6765\u8D56\u84DD\u5A6A\u680F\u62E6\u7BEE\u9611\u5170\u6F9C\u8C30\u63FD\u89C8\u61D2\u7F06\u70C2\u6EE5\u7405\u6994\u72FC\u5ECA\u90CE\u6717\u6D6A\u635E\u52B3\u7262\u8001\u4F6C\u59E5\u916A\u70D9\u6D9D\u52D2\u4E50\u96F7\u956D\u857E\u78CA\u7D2F\u5121\u5792\u64C2\u808B\u7C7B\u6CEA\u68F1\u695E\u51B7\u5398\u68A8\u7281\u9ECE\u7BF1\u72F8\u79BB\u6F13\u7406\u674E\u91CC\u9CA4\u793C\u8389\u8354\u540F\u6817\u4E3D\u5389\u52B1\u783E\u5386\u5229\u5088\u4F8B\u4FD0\uFFFD".split("");
      for (j = 0; j != D[192].length; ++j)
        if (D[192][j].charCodeAt(0) !== 65533) {
          e[D[192][j]] = 49152 + j;
          d[49152 + j] = D[192][j];
        }
      D[193] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u75E2\u7ACB\u7C92\u6CA5\u96B6\u529B\u7483\u54E9\u4FE9\u8054\u83B2\u8FDE\u9570\u5EC9\u601C\u6D9F\u5E18\u655B\u8138\u94FE\u604B\u70BC\u7EC3\u7CAE\u51C9\u6881\u7CB1\u826F\u4E24\u8F86\u91CF\u667E\u4EAE\u8C05\u64A9\u804A\u50DA\u7597\u71CE\u5BE5\u8FBD\u6F66\u4E86\u6482\u9563\u5ED6\u6599\u5217\u88C2\u70C8\u52A3\u730E\u7433\u6797\u78F7\u9716\u4E34\u90BB\u9CDE\u6DCB\u51DB\u8D41\u541D\u62CE\u73B2\u83F1\u96F6\u9F84\u94C3\u4F36\u7F9A\u51CC\u7075\u9675\u5CAD\u9886\u53E6\u4EE4\u6E9C\u7409\u69B4\u786B\u998F\u7559\u5218\u7624\u6D41\u67F3\u516D\u9F99\u804B\u5499\u7B3C\u7ABF\uFFFD".split("");
      for (j = 0; j != D[193].length; ++j)
        if (D[193][j].charCodeAt(0) !== 65533) {
          e[D[193][j]] = 49408 + j;
          d[49408 + j] = D[193][j];
        }
      D[194] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9686\u5784\u62E2\u9647\u697C\u5A04\u6402\u7BD3\u6F0F\u964B\u82A6\u5362\u9885\u5E90\u7089\u63B3\u5364\u864F\u9C81\u9E93\u788C\u9732\u8DEF\u8D42\u9E7F\u6F5E\u7984\u5F55\u9646\u622E\u9A74\u5415\u94DD\u4FA3\u65C5\u5C65\u5C61\u7F15\u8651\u6C2F\u5F8B\u7387\u6EE4\u7EFF\u5CE6\u631B\u5B6A\u6EE6\u5375\u4E71\u63A0\u7565\u62A1\u8F6E\u4F26\u4ED1\u6CA6\u7EB6\u8BBA\u841D\u87BA\u7F57\u903B\u9523\u7BA9\u9AA1\u88F8\u843D\u6D1B\u9A86\u7EDC\u5988\u9EBB\u739B\u7801\u8682\u9A6C\u9A82\u561B\u5417\u57CB\u4E70\u9EA6\u5356\u8FC8\u8109\u7792\u9992\u86EE\u6EE1\u8513\u66FC\u6162\u6F2B\uFFFD".split("");
      for (j = 0; j != D[194].length; ++j)
        if (D[194][j].charCodeAt(0) !== 65533) {
          e[D[194][j]] = 49664 + j;
          d[49664 + j] = D[194][j];
        }
      D[195] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8C29\u8292\u832B\u76F2\u6C13\u5FD9\u83BD\u732B\u8305\u951A\u6BDB\u77DB\u94C6\u536F\u8302\u5192\u5E3D\u8C8C\u8D38\u4E48\u73AB\u679A\u6885\u9176\u9709\u7164\u6CA1\u7709\u5A92\u9541\u6BCF\u7F8E\u6627\u5BD0\u59B9\u5A9A\u95E8\u95F7\u4EEC\u840C\u8499\u6AAC\u76DF\u9530\u731B\u68A6\u5B5F\u772F\u919A\u9761\u7CDC\u8FF7\u8C1C\u5F25\u7C73\u79D8\u89C5\u6CCC\u871C\u5BC6\u5E42\u68C9\u7720\u7EF5\u5195\u514D\u52C9\u5A29\u7F05\u9762\u82D7\u63CF\u7784\u85D0\u79D2\u6E3A\u5E99\u5999\u8511\u706D\u6C11\u62BF\u76BF\u654F\u60AF\u95FD\u660E\u879F\u9E23\u94ED\u540D\u547D\u8C2C\u6478\uFFFD".split("");
      for (j = 0; j != D[195].length; ++j)
        if (D[195][j].charCodeAt(0) !== 65533) {
          e[D[195][j]] = 49920 + j;
          d[49920 + j] = D[195][j];
        }
      D[196] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6479\u8611\u6A21\u819C\u78E8\u6469\u9B54\u62B9\u672B\u83AB\u58A8\u9ED8\u6CAB\u6F20\u5BDE\u964C\u8C0B\u725F\u67D0\u62C7\u7261\u4EA9\u59C6\u6BCD\u5893\u66AE\u5E55\u52DF\u6155\u6728\u76EE\u7766\u7267\u7A46\u62FF\u54EA\u5450\u94A0\u90A3\u5A1C\u7EB3\u6C16\u4E43\u5976\u8010\u5948\u5357\u7537\u96BE\u56CA\u6320\u8111\u607C\u95F9\u6DD6\u5462\u9981\u5185\u5AE9\u80FD\u59AE\u9713\u502A\u6CE5\u5C3C\u62DF\u4F60\u533F\u817B\u9006\u6EBA\u852B\u62C8\u5E74\u78BE\u64B5\u637B\u5FF5\u5A18\u917F\u9E1F\u5C3F\u634F\u8042\u5B7D\u556E\u954A\u954D\u6D85\u60A8\u67E0\u72DE\u51DD\u5B81\uFFFD".split("");
      for (j = 0; j != D[196].length; ++j)
        if (D[196][j].charCodeAt(0) !== 65533) {
          e[D[196][j]] = 50176 + j;
          d[50176 + j] = D[196][j];
        }
      D[197] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u62E7\u6CDE\u725B\u626D\u94AE\u7EBD\u8113\u6D53\u519C\u5F04\u5974\u52AA\u6012\u5973\u6696\u8650\u759F\u632A\u61E6\u7CEF\u8BFA\u54E6\u6B27\u9E25\u6BB4\u85D5\u5455\u5076\u6CA4\u556A\u8DB4\u722C\u5E15\u6015\u7436\u62CD\u6392\u724C\u5F98\u6E43\u6D3E\u6500\u6F58\u76D8\u78D0\u76FC\u7554\u5224\u53DB\u4E53\u5E9E\u65C1\u802A\u80D6\u629B\u5486\u5228\u70AE\u888D\u8DD1\u6CE1\u5478\u80DA\u57F9\u88F4\u8D54\u966A\u914D\u4F69\u6C9B\u55B7\u76C6\u7830\u62A8\u70F9\u6F8E\u5F6D\u84EC\u68DA\u787C\u7BF7\u81A8\u670B\u9E4F\u6367\u78B0\u576F\u7812\u9739\u6279\u62AB\u5288\u7435\u6BD7\uFFFD".split("");
      for (j = 0; j != D[197].length; ++j)
        if (D[197][j].charCodeAt(0) !== 65533) {
          e[D[197][j]] = 50432 + j;
          d[50432 + j] = D[197][j];
        }
      D[198] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5564\u813E\u75B2\u76AE\u5339\u75DE\u50FB\u5C41\u8B6C\u7BC7\u504F\u7247\u9A97\u98D8\u6F02\u74E2\u7968\u6487\u77A5\u62FC\u9891\u8D2B\u54C1\u8058\u4E52\u576A\u82F9\u840D\u5E73\u51ED\u74F6\u8BC4\u5C4F\u5761\u6CFC\u9887\u5A46\u7834\u9B44\u8FEB\u7C95\u5256\u6251\u94FA\u4EC6\u8386\u8461\u83E9\u84B2\u57D4\u6734\u5703\u666E\u6D66\u8C31\u66DD\u7011\u671F\u6B3A\u6816\u621A\u59BB\u4E03\u51C4\u6F06\u67D2\u6C8F\u5176\u68CB\u5947\u6B67\u7566\u5D0E\u8110\u9F50\u65D7\u7948\u7941\u9A91\u8D77\u5C82\u4E5E\u4F01\u542F\u5951\u780C\u5668\u6C14\u8FC4\u5F03\u6C7D\u6CE3\u8BAB\u6390\uFFFD".split("");
      for (j = 0; j != D[198].length; ++j)
        if (D[198][j].charCodeAt(0) !== 65533) {
          e[D[198][j]] = 50688 + j;
          d[50688 + j] = D[198][j];
        }
      D[199] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6070\u6D3D\u7275\u6266\u948E\u94C5\u5343\u8FC1\u7B7E\u4EDF\u8C26\u4E7E\u9ED4\u94B1\u94B3\u524D\u6F5C\u9063\u6D45\u8C34\u5811\u5D4C\u6B20\u6B49\u67AA\u545B\u8154\u7F8C\u5899\u8537\u5F3A\u62A2\u6A47\u9539\u6572\u6084\u6865\u77A7\u4E54\u4FA8\u5DE7\u9798\u64AC\u7FD8\u5CED\u4FCF\u7A8D\u5207\u8304\u4E14\u602F\u7A83\u94A6\u4FB5\u4EB2\u79E6\u7434\u52E4\u82B9\u64D2\u79BD\u5BDD\u6C81\u9752\u8F7B\u6C22\u503E\u537F\u6E05\u64CE\u6674\u6C30\u60C5\u9877\u8BF7\u5E86\u743C\u7A77\u79CB\u4E18\u90B1\u7403\u6C42\u56DA\u914B\u6CC5\u8D8B\u533A\u86C6\u66F2\u8EAF\u5C48\u9A71\u6E20\uFFFD".split("");
      for (j = 0; j != D[199].length; ++j)
        if (D[199][j].charCodeAt(0) !== 65533) {
          e[D[199][j]] = 50944 + j;
          d[50944 + j] = D[199][j];
        }
      D[200] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u53D6\u5A36\u9F8B\u8DA3\u53BB\u5708\u98A7\u6743\u919B\u6CC9\u5168\u75CA\u62F3\u72AC\u5238\u529D\u7F3A\u7094\u7638\u5374\u9E4A\u69B7\u786E\u96C0\u88D9\u7FA4\u7136\u71C3\u5189\u67D3\u74E4\u58E4\u6518\u56B7\u8BA9\u9976\u6270\u7ED5\u60F9\u70ED\u58EC\u4EC1\u4EBA\u5FCD\u97E7\u4EFB\u8BA4\u5203\u598A\u7EAB\u6254\u4ECD\u65E5\u620E\u8338\u84C9\u8363\u878D\u7194\u6EB6\u5BB9\u7ED2\u5197\u63C9\u67D4\u8089\u8339\u8815\u5112\u5B7A\u5982\u8FB1\u4E73\u6C5D\u5165\u8925\u8F6F\u962E\u854A\u745E\u9510\u95F0\u6DA6\u82E5\u5F31\u6492\u6D12\u8428\u816E\u9CC3\u585E\u8D5B\u4E09\u53C1\uFFFD".split("");
      for (j = 0; j != D[200].length; ++j)
        if (D[200][j].charCodeAt(0) !== 65533) {
          e[D[200][j]] = 51200 + j;
          d[51200 + j] = D[200][j];
        }
      D[201] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4F1E\u6563\u6851\u55D3\u4E27\u6414\u9A9A\u626B\u5AC2\u745F\u8272\u6DA9\u68EE\u50E7\u838E\u7802\u6740\u5239\u6C99\u7EB1\u50BB\u5565\u715E\u7B5B\u6652\u73CA\u82EB\u6749\u5C71\u5220\u717D\u886B\u95EA\u9655\u64C5\u8D61\u81B3\u5584\u6C55\u6247\u7F2E\u5892\u4F24\u5546\u8D4F\u664C\u4E0A\u5C1A\u88F3\u68A2\u634E\u7A0D\u70E7\u828D\u52FA\u97F6\u5C11\u54E8\u90B5\u7ECD\u5962\u8D4A\u86C7\u820C\u820D\u8D66\u6444\u5C04\u6151\u6D89\u793E\u8BBE\u7837\u7533\u547B\u4F38\u8EAB\u6DF1\u5A20\u7EC5\u795E\u6C88\u5BA1\u5A76\u751A\u80BE\u614E\u6E17\u58F0\u751F\u7525\u7272\u5347\u7EF3\uFFFD".split("");
      for (j = 0; j != D[201].length; ++j)
        if (D[201][j].charCodeAt(0) !== 65533) {
          e[D[201][j]] = 51456 + j;
          d[51456 + j] = D[201][j];
        }
      D[202] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7701\u76DB\u5269\u80DC\u5723\u5E08\u5931\u72EE\u65BD\u6E7F\u8BD7\u5C38\u8671\u5341\u77F3\u62FE\u65F6\u4EC0\u98DF\u8680\u5B9E\u8BC6\u53F2\u77E2\u4F7F\u5C4E\u9A76\u59CB\u5F0F\u793A\u58EB\u4E16\u67FF\u4E8B\u62ED\u8A93\u901D\u52BF\u662F\u55DC\u566C\u9002\u4ED5\u4F8D\u91CA\u9970\u6C0F\u5E02\u6043\u5BA4\u89C6\u8BD5\u6536\u624B\u9996\u5B88\u5BFF\u6388\u552E\u53D7\u7626\u517D\u852C\u67A2\u68B3\u6B8A\u6292\u8F93\u53D4\u8212\u6DD1\u758F\u4E66\u8D4E\u5B70\u719F\u85AF\u6691\u66D9\u7F72\u8700\u9ECD\u9F20\u5C5E\u672F\u8FF0\u6811\u675F\u620D\u7AD6\u5885\u5EB6\u6570\u6F31\uFFFD".split("");
      for (j = 0; j != D[202].length; ++j)
        if (D[202][j].charCodeAt(0) !== 65533) {
          e[D[202][j]] = 51712 + j;
          d[51712 + j] = D[202][j];
        }
      D[203] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6055\u5237\u800D\u6454\u8870\u7529\u5E05\u6813\u62F4\u971C\u53CC\u723D\u8C01\u6C34\u7761\u7A0E\u542E\u77AC\u987A\u821C\u8BF4\u7855\u6714\u70C1\u65AF\u6495\u5636\u601D\u79C1\u53F8\u4E1D\u6B7B\u8086\u5BFA\u55E3\u56DB\u4F3A\u4F3C\u9972\u5DF3\u677E\u8038\u6002\u9882\u9001\u5B8B\u8BBC\u8BF5\u641C\u8258\u64DE\u55FD\u82CF\u9165\u4FD7\u7D20\u901F\u7C9F\u50F3\u5851\u6EAF\u5BBF\u8BC9\u8083\u9178\u849C\u7B97\u867D\u968B\u968F\u7EE5\u9AD3\u788E\u5C81\u7A57\u9042\u96A7\u795F\u5B59\u635F\u7B0B\u84D1\u68AD\u5506\u7F29\u7410\u7D22\u9501\u6240\u584C\u4ED6\u5B83\u5979\u5854\uFFFD".split("");
      for (j = 0; j != D[203].length; ++j)
        if (D[203][j].charCodeAt(0) !== 65533) {
          e[D[203][j]] = 51968 + j;
          d[51968 + j] = D[203][j];
        }
      D[204] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u736D\u631E\u8E4B\u8E0F\u80CE\u82D4\u62AC\u53F0\u6CF0\u915E\u592A\u6001\u6C70\u574D\u644A\u8D2A\u762B\u6EE9\u575B\u6A80\u75F0\u6F6D\u8C2D\u8C08\u5766\u6BEF\u8892\u78B3\u63A2\u53F9\u70AD\u6C64\u5858\u642A\u5802\u68E0\u819B\u5510\u7CD6\u5018\u8EBA\u6DCC\u8D9F\u70EB\u638F\u6D9B\u6ED4\u7EE6\u8404\u6843\u9003\u6DD8\u9676\u8BA8\u5957\u7279\u85E4\u817E\u75BC\u8A8A\u68AF\u5254\u8E22\u9511\u63D0\u9898\u8E44\u557C\u4F53\u66FF\u568F\u60D5\u6D95\u5243\u5C49\u5929\u6DFB\u586B\u7530\u751C\u606C\u8214\u8146\u6311\u6761\u8FE2\u773A\u8DF3\u8D34\u94C1\u5E16\u5385\u542C\u70C3\uFFFD".split("");
      for (j = 0; j != D[204].length; ++j)
        if (D[204][j].charCodeAt(0) !== 65533) {
          e[D[204][j]] = 52224 + j;
          d[52224 + j] = D[204][j];
        }
      D[205] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6C40\u5EF7\u505C\u4EAD\u5EAD\u633A\u8247\u901A\u6850\u916E\u77B3\u540C\u94DC\u5F64\u7AE5\u6876\u6345\u7B52\u7EDF\u75DB\u5077\u6295\u5934\u900F\u51F8\u79C3\u7A81\u56FE\u5F92\u9014\u6D82\u5C60\u571F\u5410\u5154\u6E4D\u56E2\u63A8\u9893\u817F\u8715\u892A\u9000\u541E\u5C6F\u81C0\u62D6\u6258\u8131\u9E35\u9640\u9A6E\u9A7C\u692D\u59A5\u62D3\u553E\u6316\u54C7\u86D9\u6D3C\u5A03\u74E6\u889C\u6B6A\u5916\u8C4C\u5F2F\u6E7E\u73A9\u987D\u4E38\u70F7\u5B8C\u7897\u633D\u665A\u7696\u60CB\u5B9B\u5A49\u4E07\u8155\u6C6A\u738B\u4EA1\u6789\u7F51\u5F80\u65FA\u671B\u5FD8\u5984\u5A01\uFFFD".split("");
      for (j = 0; j != D[205].length; ++j)
        if (D[205][j].charCodeAt(0) !== 65533) {
          e[D[205][j]] = 52480 + j;
          d[52480 + j] = D[205][j];
        }
      D[206] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5DCD\u5FAE\u5371\u97E6\u8FDD\u6845\u56F4\u552F\u60DF\u4E3A\u6F4D\u7EF4\u82C7\u840E\u59D4\u4F1F\u4F2A\u5C3E\u7EAC\u672A\u851A\u5473\u754F\u80C3\u5582\u9B4F\u4F4D\u6E2D\u8C13\u5C09\u6170\u536B\u761F\u6E29\u868A\u6587\u95FB\u7EB9\u543B\u7A33\u7D0A\u95EE\u55E1\u7FC1\u74EE\u631D\u8717\u6DA1\u7A9D\u6211\u65A1\u5367\u63E1\u6C83\u5DEB\u545C\u94A8\u4E4C\u6C61\u8BEC\u5C4B\u65E0\u829C\u68A7\u543E\u5434\u6BCB\u6B66\u4E94\u6342\u5348\u821E\u4F0D\u4FAE\u575E\u620A\u96FE\u6664\u7269\u52FF\u52A1\u609F\u8BEF\u6614\u7199\u6790\u897F\u7852\u77FD\u6670\u563B\u5438\u9521\u727A\uFFFD".split("");
      for (j = 0; j != D[206].length; ++j)
        if (D[206][j].charCodeAt(0) !== 65533) {
          e[D[206][j]] = 52736 + j;
          d[52736 + j] = D[206][j];
        }
      D[207] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A00\u606F\u5E0C\u6089\u819D\u5915\u60DC\u7184\u70EF\u6EAA\u6C50\u7280\u6A84\u88AD\u5E2D\u4E60\u5AB3\u559C\u94E3\u6D17\u7CFB\u9699\u620F\u7EC6\u778E\u867E\u5323\u971E\u8F96\u6687\u5CE1\u4FA0\u72ED\u4E0B\u53A6\u590F\u5413\u6380\u9528\u5148\u4ED9\u9C9C\u7EA4\u54B8\u8D24\u8854\u8237\u95F2\u6D8E\u5F26\u5ACC\u663E\u9669\u73B0\u732E\u53BF\u817A\u9985\u7FA1\u5BAA\u9677\u9650\u7EBF\u76F8\u53A2\u9576\u9999\u7BB1\u8944\u6E58\u4E61\u7FD4\u7965\u8BE6\u60F3\u54CD\u4EAB\u9879\u5DF7\u6A61\u50CF\u5411\u8C61\u8427\u785D\u9704\u524A\u54EE\u56A3\u9500\u6D88\u5BB5\u6DC6\u6653\uFFFD".split("");
      for (j = 0; j != D[207].length; ++j)
        if (D[207][j].charCodeAt(0) !== 65533) {
          e[D[207][j]] = 52992 + j;
          d[52992 + j] = D[207][j];
        }
      D[208] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5C0F\u5B5D\u6821\u8096\u5578\u7B11\u6548\u6954\u4E9B\u6B47\u874E\u978B\u534F\u631F\u643A\u90AA\u659C\u80C1\u8C10\u5199\u68B0\u5378\u87F9\u61C8\u6CC4\u6CFB\u8C22\u5C51\u85AA\u82AF\u950C\u6B23\u8F9B\u65B0\u5FFB\u5FC3\u4FE1\u8845\u661F\u8165\u7329\u60FA\u5174\u5211\u578B\u5F62\u90A2\u884C\u9192\u5E78\u674F\u6027\u59D3\u5144\u51F6\u80F8\u5308\u6C79\u96C4\u718A\u4F11\u4FEE\u7F9E\u673D\u55C5\u9508\u79C0\u8896\u7EE3\u589F\u620C\u9700\u865A\u5618\u987B\u5F90\u8BB8\u84C4\u9157\u53D9\u65ED\u5E8F\u755C\u6064\u7D6E\u5A7F\u7EEA\u7EED\u8F69\u55A7\u5BA3\u60AC\u65CB\u7384\uFFFD".split("");
      for (j = 0; j != D[208].length; ++j)
        if (D[208][j].charCodeAt(0) !== 65533) {
          e[D[208][j]] = 53248 + j;
          d[53248 + j] = D[208][j];
        }
      D[209] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9009\u7663\u7729\u7EDA\u9774\u859B\u5B66\u7A74\u96EA\u8840\u52CB\u718F\u5FAA\u65EC\u8BE2\u5BFB\u9A6F\u5DE1\u6B89\u6C5B\u8BAD\u8BAF\u900A\u8FC5\u538B\u62BC\u9E26\u9E2D\u5440\u4E2B\u82BD\u7259\u869C\u5D16\u8859\u6DAF\u96C5\u54D1\u4E9A\u8BB6\u7109\u54BD\u9609\u70DF\u6DF9\u76D0\u4E25\u7814\u8712\u5CA9\u5EF6\u8A00\u989C\u960E\u708E\u6CBF\u5944\u63A9\u773C\u884D\u6F14\u8273\u5830\u71D5\u538C\u781A\u96C1\u5501\u5F66\u7130\u5BB4\u8C1A\u9A8C\u6B83\u592E\u9E2F\u79E7\u6768\u626C\u4F6F\u75A1\u7F8A\u6D0B\u9633\u6C27\u4EF0\u75D2\u517B\u6837\u6F3E\u9080\u8170\u5996\u7476\uFFFD".split("");
      for (j = 0; j != D[209].length; ++j)
        if (D[209][j].charCodeAt(0) !== 65533) {
          e[D[209][j]] = 53504 + j;
          d[53504 + j] = D[209][j];
        }
      D[210] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6447\u5C27\u9065\u7A91\u8C23\u59DA\u54AC\u8200\u836F\u8981\u8000\u6930\u564E\u8036\u7237\u91CE\u51B6\u4E5F\u9875\u6396\u4E1A\u53F6\u66F3\u814B\u591C\u6DB2\u4E00\u58F9\u533B\u63D6\u94F1\u4F9D\u4F0A\u8863\u9890\u5937\u9057\u79FB\u4EEA\u80F0\u7591\u6C82\u5B9C\u59E8\u5F5D\u6905\u8681\u501A\u5DF2\u4E59\u77E3\u4EE5\u827A\u6291\u6613\u9091\u5C79\u4EBF\u5F79\u81C6\u9038\u8084\u75AB\u4EA6\u88D4\u610F\u6BC5\u5FC6\u4E49\u76CA\u6EA2\u8BE3\u8BAE\u8C0A\u8BD1\u5F02\u7FFC\u7FCC\u7ECE\u8335\u836B\u56E0\u6BB7\u97F3\u9634\u59FB\u541F\u94F6\u6DEB\u5BC5\u996E\u5C39\u5F15\u9690\uFFFD".split("");
      for (j = 0; j != D[210].length; ++j)
        if (D[210][j].charCodeAt(0) !== 65533) {
          e[D[210][j]] = 53760 + j;
          d[53760 + j] = D[210][j];
        }
      D[211] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5370\u82F1\u6A31\u5A74\u9E70\u5E94\u7F28\u83B9\u8424\u8425\u8367\u8747\u8FCE\u8D62\u76C8\u5F71\u9896\u786C\u6620\u54DF\u62E5\u4F63\u81C3\u75C8\u5EB8\u96CD\u8E0A\u86F9\u548F\u6CF3\u6D8C\u6C38\u607F\u52C7\u7528\u5E7D\u4F18\u60A0\u5FE7\u5C24\u7531\u90AE\u94C0\u72B9\u6CB9\u6E38\u9149\u6709\u53CB\u53F3\u4F51\u91C9\u8BF1\u53C8\u5E7C\u8FC2\u6DE4\u4E8E\u76C2\u6986\u865E\u611A\u8206\u4F59\u4FDE\u903E\u9C7C\u6109\u6E1D\u6E14\u9685\u4E88\u5A31\u96E8\u4E0E\u5C7F\u79B9\u5B87\u8BED\u7FBD\u7389\u57DF\u828B\u90C1\u5401\u9047\u55BB\u5CEA\u5FA1\u6108\u6B32\u72F1\u80B2\u8A89\uFFFD".split("");
      for (j = 0; j != D[211].length; ++j)
        if (D[211][j].charCodeAt(0) !== 65533) {
          e[D[211][j]] = 54016 + j;
          d[54016 + j] = D[211][j];
        }
      D[212] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D74\u5BD3\u88D5\u9884\u8C6B\u9A6D\u9E33\u6E0A\u51A4\u5143\u57A3\u8881\u539F\u63F4\u8F95\u56ED\u5458\u5706\u733F\u6E90\u7F18\u8FDC\u82D1\u613F\u6028\u9662\u66F0\u7EA6\u8D8A\u8DC3\u94A5\u5CB3\u7CA4\u6708\u60A6\u9605\u8018\u4E91\u90E7\u5300\u9668\u5141\u8FD0\u8574\u915D\u6655\u97F5\u5B55\u531D\u7838\u6742\u683D\u54C9\u707E\u5BB0\u8F7D\u518D\u5728\u54B1\u6512\u6682\u8D5E\u8D43\u810F\u846C\u906D\u7CDF\u51FF\u85FB\u67A3\u65E9\u6FA1\u86A4\u8E81\u566A\u9020\u7682\u7076\u71E5\u8D23\u62E9\u5219\u6CFD\u8D3C\u600E\u589E\u618E\u66FE\u8D60\u624E\u55B3\u6E23\u672D\u8F67\uFFFD".split("");
      for (j = 0; j != D[212].length; ++j)
        if (D[212][j].charCodeAt(0) !== 65533) {
          e[D[212][j]] = 54272 + j;
          d[54272 + j] = D[212][j];
        }
      D[213] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u94E1\u95F8\u7728\u6805\u69A8\u548B\u4E4D\u70B8\u8BC8\u6458\u658B\u5B85\u7A84\u503A\u5BE8\u77BB\u6BE1\u8A79\u7C98\u6CBE\u76CF\u65A9\u8F97\u5D2D\u5C55\u8638\u6808\u5360\u6218\u7AD9\u6E5B\u7EFD\u6A1F\u7AE0\u5F70\u6F33\u5F20\u638C\u6DA8\u6756\u4E08\u5E10\u8D26\u4ED7\u80C0\u7634\u969C\u62DB\u662D\u627E\u6CBC\u8D75\u7167\u7F69\u5146\u8087\u53EC\u906E\u6298\u54F2\u86F0\u8F99\u8005\u9517\u8517\u8FD9\u6D59\u73CD\u659F\u771F\u7504\u7827\u81FB\u8D1E\u9488\u4FA6\u6795\u75B9\u8BCA\u9707\u632F\u9547\u9635\u84B8\u6323\u7741\u5F81\u72F0\u4E89\u6014\u6574\u62EF\u6B63\u653F\uFFFD".split("");
      for (j = 0; j != D[213].length; ++j)
        if (D[213][j].charCodeAt(0) !== 65533) {
          e[D[213][j]] = 54528 + j;
          d[54528 + j] = D[213][j];
        }
      D[214] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5E27\u75C7\u90D1\u8BC1\u829D\u679D\u652F\u5431\u8718\u77E5\u80A2\u8102\u6C41\u4E4B\u7EC7\u804C\u76F4\u690D\u6B96\u6267\u503C\u4F84\u5740\u6307\u6B62\u8DBE\u53EA\u65E8\u7EB8\u5FD7\u631A\u63B7\u81F3\u81F4\u7F6E\u5E1C\u5CD9\u5236\u667A\u79E9\u7A1A\u8D28\u7099\u75D4\u6EDE\u6CBB\u7A92\u4E2D\u76C5\u5FE0\u949F\u8877\u7EC8\u79CD\u80BF\u91CD\u4EF2\u4F17\u821F\u5468\u5DDE\u6D32\u8BCC\u7CA5\u8F74\u8098\u5E1A\u5492\u76B1\u5B99\u663C\u9AA4\u73E0\u682A\u86DB\u6731\u732A\u8BF8\u8BDB\u9010\u7AF9\u70DB\u716E\u62C4\u77A9\u5631\u4E3B\u8457\u67F1\u52A9\u86C0\u8D2E\u94F8\u7B51\uFFFD".split("");
      for (j = 0; j != D[214].length; ++j)
        if (D[214][j].charCodeAt(0) !== 65533) {
          e[D[214][j]] = 54784 + j;
          d[54784 + j] = D[214][j];
        }
      D[215] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4F4F\u6CE8\u795D\u9A7B\u6293\u722A\u62FD\u4E13\u7816\u8F6C\u64B0\u8D5A\u7BC6\u6869\u5E84\u88C5\u5986\u649E\u58EE\u72B6\u690E\u9525\u8FFD\u8D58\u5760\u7F00\u8C06\u51C6\u6349\u62D9\u5353\u684C\u7422\u8301\u914C\u5544\u7740\u707C\u6D4A\u5179\u54A8\u8D44\u59FF\u6ECB\u6DC4\u5B5C\u7D2B\u4ED4\u7C7D\u6ED3\u5B50\u81EA\u6E0D\u5B57\u9B03\u68D5\u8E2A\u5B97\u7EFC\u603B\u7EB5\u90B9\u8D70\u594F\u63CD\u79DF\u8DB3\u5352\u65CF\u7956\u8BC5\u963B\u7EC4\u94BB\u7E82\u5634\u9189\u6700\u7F6A\u5C0A\u9075\u6628\u5DE6\u4F50\u67DE\u505A\u4F5C\u5750\u5EA7\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD".split("");
      for (j = 0; j != D[215].length; ++j)
        if (D[215][j].charCodeAt(0) !== 65533) {
          e[D[215][j]] = 55040 + j;
          d[55040 + j] = D[215][j];
        }
      D[216] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4E8D\u4E0C\u5140\u4E10\u5EFF\u5345\u4E15\u4E98\u4E1E\u9B32\u5B6C\u5669\u4E28\u79BA\u4E3F\u5315\u4E47\u592D\u723B\u536E\u6C10\u56DF\u80E4\u9997\u6BD3\u777E\u9F17\u4E36\u4E9F\u9F10\u4E5C\u4E69\u4E93\u8288\u5B5B\u556C\u560F\u4EC4\u538D\u539D\u53A3\u53A5\u53AE\u9765\u8D5D\u531A\u53F5\u5326\u532E\u533E\u8D5C\u5366\u5363\u5202\u5208\u520E\u522D\u5233\u523F\u5240\u524C\u525E\u5261\u525C\u84AF\u527D\u5282\u5281\u5290\u5293\u5182\u7F54\u4EBB\u4EC3\u4EC9\u4EC2\u4EE8\u4EE1\u4EEB\u4EDE\u4F1B\u4EF3\u4F22\u4F64\u4EF5\u4F25\u4F27\u4F09\u4F2B\u4F5E\u4F67\u6538\u4F5A\u4F5D\uFFFD".split("");
      for (j = 0; j != D[216].length; ++j)
        if (D[216][j].charCodeAt(0) !== 65533) {
          e[D[216][j]] = 55296 + j;
          d[55296 + j] = D[216][j];
        }
      D[217] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u4F5F\u4F57\u4F32\u4F3D\u4F76\u4F74\u4F91\u4F89\u4F83\u4F8F\u4F7E\u4F7B\u4FAA\u4F7C\u4FAC\u4F94\u4FE6\u4FE8\u4FEA\u4FC5\u4FDA\u4FE3\u4FDC\u4FD1\u4FDF\u4FF8\u5029\u504C\u4FF3\u502C\u500F\u502E\u502D\u4FFE\u501C\u500C\u5025\u5028\u507E\u5043\u5055\u5048\u504E\u506C\u507B\u50A5\u50A7\u50A9\u50BA\u50D6\u5106\u50ED\u50EC\u50E6\u50EE\u5107\u510B\u4EDD\u6C3D\u4F58\u4F65\u4FCE\u9FA0\u6C46\u7C74\u516E\u5DFD\u9EC9\u9998\u5181\u5914\u52F9\u530D\u8A07\u5310\u51EB\u5919\u5155\u4EA0\u5156\u4EB3\u886E\u88A4\u4EB5\u8114\u88D2\u7980\u5B34\u8803\u7FB8\u51AB\u51B1\u51BD\u51BC\uFFFD".split("");
      for (j = 0; j != D[217].length; ++j)
        if (D[217][j].charCodeAt(0) !== 65533) {
          e[D[217][j]] = 55552 + j;
          d[55552 + j] = D[217][j];
        }
      D[218] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u51C7\u5196\u51A2\u51A5\u8BA0\u8BA6\u8BA7\u8BAA\u8BB4\u8BB5\u8BB7\u8BC2\u8BC3\u8BCB\u8BCF\u8BCE\u8BD2\u8BD3\u8BD4\u8BD6\u8BD8\u8BD9\u8BDC\u8BDF\u8BE0\u8BE4\u8BE8\u8BE9\u8BEE\u8BF0\u8BF3\u8BF6\u8BF9\u8BFC\u8BFF\u8C00\u8C02\u8C04\u8C07\u8C0C\u8C0F\u8C11\u8C12\u8C14\u8C15\u8C16\u8C19\u8C1B\u8C18\u8C1D\u8C1F\u8C20\u8C21\u8C25\u8C27\u8C2A\u8C2B\u8C2E\u8C2F\u8C32\u8C33\u8C35\u8C36\u5369\u537A\u961D\u9622\u9621\u9631\u962A\u963D\u963C\u9642\u9649\u9654\u965F\u9667\u966C\u9672\u9674\u9688\u968D\u9697\u96B0\u9097\u909B\u909D\u9099\u90AC\u90A1\u90B4\u90B3\u90B6\u90BA\uFFFD".split("");
      for (j = 0; j != D[218].length; ++j)
        if (D[218][j].charCodeAt(0) !== 65533) {
          e[D[218][j]] = 55808 + j;
          d[55808 + j] = D[218][j];
        }
      D[219] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u90B8\u90B0\u90CF\u90C5\u90BE\u90D0\u90C4\u90C7\u90D3\u90E6\u90E2\u90DC\u90D7\u90DB\u90EB\u90EF\u90FE\u9104\u9122\u911E\u9123\u9131\u912F\u9139\u9143\u9146\u520D\u5942\u52A2\u52AC\u52AD\u52BE\u54FF\u52D0\u52D6\u52F0\u53DF\u71EE\u77CD\u5EF4\u51F5\u51FC\u9B2F\u53B6\u5F01\u755A\u5DEF\u574C\u57A9\u57A1\u587E\u58BC\u58C5\u58D1\u5729\u572C\u572A\u5733\u5739\u572E\u572F\u575C\u573B\u5742\u5769\u5785\u576B\u5786\u577C\u577B\u5768\u576D\u5776\u5773\u57AD\u57A4\u578C\u57B2\u57CF\u57A7\u57B4\u5793\u57A0\u57D5\u57D8\u57DA\u57D9\u57D2\u57B8\u57F4\u57EF\u57F8\u57E4\u57DD\uFFFD".split("");
      for (j = 0; j != D[219].length; ++j)
        if (D[219][j].charCodeAt(0) !== 65533) {
          e[D[219][j]] = 56064 + j;
          d[56064 + j] = D[219][j];
        }
      D[220] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u580B\u580D\u57FD\u57ED\u5800\u581E\u5819\u5844\u5820\u5865\u586C\u5881\u5889\u589A\u5880\u99A8\u9F19\u61FF\u8279\u827D\u827F\u828F\u828A\u82A8\u8284\u828E\u8291\u8297\u8299\u82AB\u82B8\u82BE\u82B0\u82C8\u82CA\u82E3\u8298\u82B7\u82AE\u82CB\u82CC\u82C1\u82A9\u82B4\u82A1\u82AA\u829F\u82C4\u82CE\u82A4\u82E1\u8309\u82F7\u82E4\u830F\u8307\u82DC\u82F4\u82D2\u82D8\u830C\u82FB\u82D3\u8311\u831A\u8306\u8314\u8315\u82E0\u82D5\u831C\u8351\u835B\u835C\u8308\u8392\u833C\u8334\u8331\u839B\u835E\u832F\u834F\u8347\u8343\u835F\u8340\u8317\u8360\u832D\u833A\u8333\u8366\u8365\uFFFD".split("");
      for (j = 0; j != D[220].length; ++j)
        if (D[220][j].charCodeAt(0) !== 65533) {
          e[D[220][j]] = 56320 + j;
          d[56320 + j] = D[220][j];
        }
      D[221] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8368\u831B\u8369\u836C\u836A\u836D\u836E\u83B0\u8378\u83B3\u83B4\u83A0\u83AA\u8393\u839C\u8385\u837C\u83B6\u83A9\u837D\u83B8\u837B\u8398\u839E\u83A8\u83BA\u83BC\u83C1\u8401\u83E5\u83D8\u5807\u8418\u840B\u83DD\u83FD\u83D6\u841C\u8438\u8411\u8406\u83D4\u83DF\u840F\u8403\u83F8\u83F9\u83EA\u83C5\u83C0\u8426\u83F0\u83E1\u845C\u8451\u845A\u8459\u8473\u8487\u8488\u847A\u8489\u8478\u843C\u8446\u8469\u8476\u848C\u848E\u8431\u846D\u84C1\u84CD\u84D0\u84E6\u84BD\u84D3\u84CA\u84BF\u84BA\u84E0\u84A1\u84B9\u84B4\u8497\u84E5\u84E3\u850C\u750D\u8538\u84F0\u8539\u851F\u853A\uFFFD".split("");
      for (j = 0; j != D[221].length; ++j)
        if (D[221][j].charCodeAt(0) !== 65533) {
          e[D[221][j]] = 56576 + j;
          d[56576 + j] = D[221][j];
        }
      D[222] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8556\u853B\u84FF\u84FC\u8559\u8548\u8568\u8564\u855E\u857A\u77A2\u8543\u8572\u857B\u85A4\u85A8\u8587\u858F\u8579\u85AE\u859C\u8585\u85B9\u85B7\u85B0\u85D3\u85C1\u85DC\u85FF\u8627\u8605\u8629\u8616\u863C\u5EFE\u5F08\u593C\u5941\u8037\u5955\u595A\u5958\u530F\u5C22\u5C25\u5C2C\u5C34\u624C\u626A\u629F\u62BB\u62CA\u62DA\u62D7\u62EE\u6322\u62F6\u6339\u634B\u6343\u63AD\u63F6\u6371\u637A\u638E\u63B4\u636D\u63AC\u638A\u6369\u63AE\u63BC\u63F2\u63F8\u63E0\u63FF\u63C4\u63DE\u63CE\u6452\u63C6\u63BE\u6445\u6441\u640B\u641B\u6420\u640C\u6426\u6421\u645E\u6484\u646D\u6496\uFFFD".split("");
      for (j = 0; j != D[222].length; ++j)
        if (D[222][j].charCodeAt(0) !== 65533) {
          e[D[222][j]] = 56832 + j;
          d[56832 + j] = D[222][j];
        }
      D[223] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u647A\u64B7\u64B8\u6499\u64BA\u64C0\u64D0\u64D7\u64E4\u64E2\u6509\u6525\u652E\u5F0B\u5FD2\u7519\u5F11\u535F\u53F1\u53FD\u53E9\u53E8\u53FB\u5412\u5416\u5406\u544B\u5452\u5453\u5454\u5456\u5443\u5421\u5457\u5459\u5423\u5432\u5482\u5494\u5477\u5471\u5464\u549A\u549B\u5484\u5476\u5466\u549D\u54D0\u54AD\u54C2\u54B4\u54D2\u54A7\u54A6\u54D3\u54D4\u5472\u54A3\u54D5\u54BB\u54BF\u54CC\u54D9\u54DA\u54DC\u54A9\u54AA\u54A4\u54DD\u54CF\u54DE\u551B\u54E7\u5520\u54FD\u5514\u54F3\u5522\u5523\u550F\u5511\u5527\u552A\u5567\u558F\u55B5\u5549\u556D\u5541\u5555\u553F\u5550\u553C\uFFFD".split("");
      for (j = 0; j != D[223].length; ++j)
        if (D[223][j].charCodeAt(0) !== 65533) {
          e[D[223][j]] = 57088 + j;
          d[57088 + j] = D[223][j];
        }
      D[224] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5537\u5556\u5575\u5576\u5577\u5533\u5530\u555C\u558B\u55D2\u5583\u55B1\u55B9\u5588\u5581\u559F\u557E\u55D6\u5591\u557B\u55DF\u55BD\u55BE\u5594\u5599\u55EA\u55F7\u55C9\u561F\u55D1\u55EB\u55EC\u55D4\u55E6\u55DD\u55C4\u55EF\u55E5\u55F2\u55F3\u55CC\u55CD\u55E8\u55F5\u55E4\u8F94\u561E\u5608\u560C\u5601\u5624\u5623\u55FE\u5600\u5627\u562D\u5658\u5639\u5657\u562C\u564D\u5662\u5659\u565C\u564C\u5654\u5686\u5664\u5671\u566B\u567B\u567C\u5685\u5693\u56AF\u56D4\u56D7\u56DD\u56E1\u56F5\u56EB\u56F9\u56FF\u5704\u570A\u5709\u571C\u5E0F\u5E19\u5E14\u5E11\u5E31\u5E3B\u5E3C\uFFFD".split("");
      for (j = 0; j != D[224].length; ++j)
        if (D[224][j].charCodeAt(0) !== 65533) {
          e[D[224][j]] = 57344 + j;
          d[57344 + j] = D[224][j];
        }
      D[225] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5E37\u5E44\u5E54\u5E5B\u5E5E\u5E61\u5C8C\u5C7A\u5C8D\u5C90\u5C96\u5C88\u5C98\u5C99\u5C91\u5C9A\u5C9C\u5CB5\u5CA2\u5CBD\u5CAC\u5CAB\u5CB1\u5CA3\u5CC1\u5CB7\u5CC4\u5CD2\u5CE4\u5CCB\u5CE5\u5D02\u5D03\u5D27\u5D26\u5D2E\u5D24\u5D1E\u5D06\u5D1B\u5D58\u5D3E\u5D34\u5D3D\u5D6C\u5D5B\u5D6F\u5D5D\u5D6B\u5D4B\u5D4A\u5D69\u5D74\u5D82\u5D99\u5D9D\u8C73\u5DB7\u5DC5\u5F73\u5F77\u5F82\u5F87\u5F89\u5F8C\u5F95\u5F99\u5F9C\u5FA8\u5FAD\u5FB5\u5FBC\u8862\u5F61\u72AD\u72B0\u72B4\u72B7\u72B8\u72C3\u72C1\u72CE\u72CD\u72D2\u72E8\u72EF\u72E9\u72F2\u72F4\u72F7\u7301\u72F3\u7303\u72FA\uFFFD".split("");
      for (j = 0; j != D[225].length; ++j)
        if (D[225][j].charCodeAt(0) !== 65533) {
          e[D[225][j]] = 57600 + j;
          d[57600 + j] = D[225][j];
        }
      D[226] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u72FB\u7317\u7313\u7321\u730A\u731E\u731D\u7315\u7322\u7339\u7325\u732C\u7338\u7331\u7350\u734D\u7357\u7360\u736C\u736F\u737E\u821B\u5925\u98E7\u5924\u5902\u9963\u9967\u9968\u9969\u996A\u996B\u996C\u9974\u9977\u997D\u9980\u9984\u9987\u998A\u998D\u9990\u9991\u9993\u9994\u9995\u5E80\u5E91\u5E8B\u5E96\u5EA5\u5EA0\u5EB9\u5EB5\u5EBE\u5EB3\u8D53\u5ED2\u5ED1\u5EDB\u5EE8\u5EEA\u81BA\u5FC4\u5FC9\u5FD6\u5FCF\u6003\u5FEE\u6004\u5FE1\u5FE4\u5FFE\u6005\u6006\u5FEA\u5FED\u5FF8\u6019\u6035\u6026\u601B\u600F\u600D\u6029\u602B\u600A\u603F\u6021\u6078\u6079\u607B\u607A\u6042\uFFFD".split("");
      for (j = 0; j != D[226].length; ++j)
        if (D[226][j].charCodeAt(0) !== 65533) {
          e[D[226][j]] = 57856 + j;
          d[57856 + j] = D[226][j];
        }
      D[227] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u606A\u607D\u6096\u609A\u60AD\u609D\u6083\u6092\u608C\u609B\u60EC\u60BB\u60B1\u60DD\u60D8\u60C6\u60DA\u60B4\u6120\u6126\u6115\u6123\u60F4\u6100\u610E\u612B\u614A\u6175\u61AC\u6194\u61A7\u61B7\u61D4\u61F5\u5FDD\u96B3\u95E9\u95EB\u95F1\u95F3\u95F5\u95F6\u95FC\u95FE\u9603\u9604\u9606\u9608\u960A\u960B\u960C\u960D\u960F\u9612\u9615\u9616\u9617\u9619\u961A\u4E2C\u723F\u6215\u6C35\u6C54\u6C5C\u6C4A\u6CA3\u6C85\u6C90\u6C94\u6C8C\u6C68\u6C69\u6C74\u6C76\u6C86\u6CA9\u6CD0\u6CD4\u6CAD\u6CF7\u6CF8\u6CF1\u6CD7\u6CB2\u6CE0\u6CD6\u6CFA\u6CEB\u6CEE\u6CB1\u6CD3\u6CEF\u6CFE\uFFFD".split("");
      for (j = 0; j != D[227].length; ++j)
        if (D[227][j].charCodeAt(0) !== 65533) {
          e[D[227][j]] = 58112 + j;
          d[58112 + j] = D[227][j];
        }
      D[228] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6D39\u6D27\u6D0C\u6D43\u6D48\u6D07\u6D04\u6D19\u6D0E\u6D2B\u6D4D\u6D2E\u6D35\u6D1A\u6D4F\u6D52\u6D54\u6D33\u6D91\u6D6F\u6D9E\u6DA0\u6D5E\u6D93\u6D94\u6D5C\u6D60\u6D7C\u6D63\u6E1A\u6DC7\u6DC5\u6DDE\u6E0E\u6DBF\u6DE0\u6E11\u6DE6\u6DDD\u6DD9\u6E16\u6DAB\u6E0C\u6DAE\u6E2B\u6E6E\u6E4E\u6E6B\u6EB2\u6E5F\u6E86\u6E53\u6E54\u6E32\u6E25\u6E44\u6EDF\u6EB1\u6E98\u6EE0\u6F2D\u6EE2\u6EA5\u6EA7\u6EBD\u6EBB\u6EB7\u6ED7\u6EB4\u6ECF\u6E8F\u6EC2\u6E9F\u6F62\u6F46\u6F47\u6F24\u6F15\u6EF9\u6F2F\u6F36\u6F4B\u6F74\u6F2A\u6F09\u6F29\u6F89\u6F8D\u6F8C\u6F78\u6F72\u6F7C\u6F7A\u6FD1\uFFFD".split("");
      for (j = 0; j != D[228].length; ++j)
        if (D[228][j].charCodeAt(0) !== 65533) {
          e[D[228][j]] = 58368 + j;
          d[58368 + j] = D[228][j];
        }
      D[229] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6FC9\u6FA7\u6FB9\u6FB6\u6FC2\u6FE1\u6FEE\u6FDE\u6FE0\u6FEF\u701A\u7023\u701B\u7039\u7035\u704F\u705E\u5B80\u5B84\u5B95\u5B93\u5BA5\u5BB8\u752F\u9A9E\u6434\u5BE4\u5BEE\u8930\u5BF0\u8E47\u8B07\u8FB6\u8FD3\u8FD5\u8FE5\u8FEE\u8FE4\u8FE9\u8FE6\u8FF3\u8FE8\u9005\u9004\u900B\u9026\u9011\u900D\u9016\u9021\u9035\u9036\u902D\u902F\u9044\u9051\u9052\u9050\u9068\u9058\u9062\u905B\u66B9\u9074\u907D\u9082\u9088\u9083\u908B\u5F50\u5F57\u5F56\u5F58\u5C3B\u54AB\u5C50\u5C59\u5B71\u5C63\u5C66\u7FBC\u5F2A\u5F29\u5F2D\u8274\u5F3C\u9B3B\u5C6E\u5981\u5983\u598D\u59A9\u59AA\u59A3\uFFFD".split("");
      for (j = 0; j != D[229].length; ++j)
        if (D[229][j].charCodeAt(0) !== 65533) {
          e[D[229][j]] = 58624 + j;
          d[58624 + j] = D[229][j];
        }
      D[230] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u5997\u59CA\u59AB\u599E\u59A4\u59D2\u59B2\u59AF\u59D7\u59BE\u5A05\u5A06\u59DD\u5A08\u59E3\u59D8\u59F9\u5A0C\u5A09\u5A32\u5A34\u5A11\u5A23\u5A13\u5A40\u5A67\u5A4A\u5A55\u5A3C\u5A62\u5A75\u80EC\u5AAA\u5A9B\u5A77\u5A7A\u5ABE\u5AEB\u5AB2\u5AD2\u5AD4\u5AB8\u5AE0\u5AE3\u5AF1\u5AD6\u5AE6\u5AD8\u5ADC\u5B09\u5B17\u5B16\u5B32\u5B37\u5B40\u5C15\u5C1C\u5B5A\u5B65\u5B73\u5B51\u5B53\u5B62\u9A75\u9A77\u9A78\u9A7A\u9A7F\u9A7D\u9A80\u9A81\u9A85\u9A88\u9A8A\u9A90\u9A92\u9A93\u9A96\u9A98\u9A9B\u9A9C\u9A9D\u9A9F\u9AA0\u9AA2\u9AA3\u9AA5\u9AA7\u7E9F\u7EA1\u7EA3\u7EA5\u7EA8\u7EA9\uFFFD".split("");
      for (j = 0; j != D[230].length; ++j)
        if (D[230][j].charCodeAt(0) !== 65533) {
          e[D[230][j]] = 58880 + j;
          d[58880 + j] = D[230][j];
        }
      D[231] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7EAD\u7EB0\u7EBE\u7EC0\u7EC1\u7EC2\u7EC9\u7ECB\u7ECC\u7ED0\u7ED4\u7ED7\u7EDB\u7EE0\u7EE1\u7EE8\u7EEB\u7EEE\u7EEF\u7EF1\u7EF2\u7F0D\u7EF6\u7EFA\u7EFB\u7EFE\u7F01\u7F02\u7F03\u7F07\u7F08\u7F0B\u7F0C\u7F0F\u7F11\u7F12\u7F17\u7F19\u7F1C\u7F1B\u7F1F\u7F21\u7F22\u7F23\u7F24\u7F25\u7F26\u7F27\u7F2A\u7F2B\u7F2C\u7F2D\u7F2F\u7F30\u7F31\u7F32\u7F33\u7F35\u5E7A\u757F\u5DDB\u753E\u9095\u738E\u7391\u73AE\u73A2\u739F\u73CF\u73C2\u73D1\u73B7\u73B3\u73C0\u73C9\u73C8\u73E5\u73D9\u987C\u740A\u73E9\u73E7\u73DE\u73BA\u73F2\u740F\u742A\u745B\u7426\u7425\u7428\u7430\u742E\u742C\uFFFD".split("");
      for (j = 0; j != D[231].length; ++j)
        if (D[231][j].charCodeAt(0) !== 65533) {
          e[D[231][j]] = 59136 + j;
          d[59136 + j] = D[231][j];
        }
      D[232] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u741B\u741A\u7441\u745C\u7457\u7455\u7459\u7477\u746D\u747E\u749C\u748E\u7480\u7481\u7487\u748B\u749E\u74A8\u74A9\u7490\u74A7\u74D2\u74BA\u97EA\u97EB\u97EC\u674C\u6753\u675E\u6748\u6769\u67A5\u6787\u676A\u6773\u6798\u67A7\u6775\u67A8\u679E\u67AD\u678B\u6777\u677C\u67F0\u6809\u67D8\u680A\u67E9\u67B0\u680C\u67D9\u67B5\u67DA\u67B3\u67DD\u6800\u67C3\u67B8\u67E2\u680E\u67C1\u67FD\u6832\u6833\u6860\u6861\u684E\u6862\u6844\u6864\u6883\u681D\u6855\u6866\u6841\u6867\u6840\u683E\u684A\u6849\u6829\u68B5\u688F\u6874\u6877\u6893\u686B\u68C2\u696E\u68FC\u691F\u6920\u68F9\uFFFD".split("");
      for (j = 0; j != D[232].length; ++j)
        if (D[232][j].charCodeAt(0) !== 65533) {
          e[D[232][j]] = 59392 + j;
          d[59392 + j] = D[232][j];
        }
      D[233] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u6924\u68F0\u690B\u6901\u6957\u68E3\u6910\u6971\u6939\u6960\u6942\u695D\u6984\u696B\u6980\u6998\u6978\u6934\u69CC\u6987\u6988\u69CE\u6989\u6966\u6963\u6979\u699B\u69A7\u69BB\u69AB\u69AD\u69D4\u69B1\u69C1\u69CA\u69DF\u6995\u69E0\u698D\u69FF\u6A2F\u69ED\u6A17\u6A18\u6A65\u69F2\u6A44\u6A3E\u6AA0\u6A50\u6A5B\u6A35\u6A8E\u6A79\u6A3D\u6A28\u6A58\u6A7C\u6A91\u6A90\u6AA9\u6A97\u6AAB\u7337\u7352\u6B81\u6B82\u6B87\u6B84\u6B92\u6B93\u6B8D\u6B9A\u6B9B\u6BA1\u6BAA\u8F6B\u8F6D\u8F71\u8F72\u8F73\u8F75\u8F76\u8F78\u8F77\u8F79\u8F7A\u8F7C\u8F7E\u8F81\u8F82\u8F84\u8F87\u8F8B\uFFFD".split("");
      for (j = 0; j != D[233].length; ++j)
        if (D[233][j].charCodeAt(0) !== 65533) {
          e[D[233][j]] = 59648 + j;
          d[59648 + j] = D[233][j];
        }
      D[234] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u8F8D\u8F8E\u8F8F\u8F98\u8F9A\u8ECE\u620B\u6217\u621B\u621F\u6222\u6221\u6225\u6224\u622C\u81E7\u74EF\u74F4\u74FF\u750F\u7511\u7513\u6534\u65EE\u65EF\u65F0\u660A\u6619\u6772\u6603\u6615\u6600\u7085\u66F7\u661D\u6634\u6631\u6636\u6635\u8006\u665F\u6654\u6641\u664F\u6656\u6661\u6657\u6677\u6684\u668C\u66A7\u669D\u66BE\u66DB\u66DC\u66E6\u66E9\u8D32\u8D33\u8D36\u8D3B\u8D3D\u8D40\u8D45\u8D46\u8D48\u8D49\u8D47\u8D4D\u8D55\u8D59\u89C7\u89CA\u89CB\u89CC\u89CE\u89CF\u89D0\u89D1\u726E\u729F\u725D\u7266\u726F\u727E\u727F\u7284\u728B\u728D\u728F\u7292\u6308\u6332\u63B0\uFFFD".split("");
      for (j = 0; j != D[234].length; ++j)
        if (D[234][j].charCodeAt(0) !== 65533) {
          e[D[234][j]] = 59904 + j;
          d[59904 + j] = D[234][j];
        }
      D[235] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u643F\u64D8\u8004\u6BEA\u6BF3\u6BFD\u6BF5\u6BF9\u6C05\u6C07\u6C06\u6C0D\u6C15\u6C18\u6C19\u6C1A\u6C21\u6C29\u6C24\u6C2A\u6C32\u6535\u6555\u656B\u724D\u7252\u7256\u7230\u8662\u5216\u809F\u809C\u8093\u80BC\u670A\u80BD\u80B1\u80AB\u80AD\u80B4\u80B7\u80E7\u80E8\u80E9\u80EA\u80DB\u80C2\u80C4\u80D9\u80CD\u80D7\u6710\u80DD\u80EB\u80F1\u80F4\u80ED\u810D\u810E\u80F2\u80FC\u6715\u8112\u8C5A\u8136\u811E\u812C\u8118\u8132\u8148\u814C\u8153\u8174\u8159\u815A\u8171\u8160\u8169\u817C\u817D\u816D\u8167\u584D\u5AB5\u8188\u8182\u8191\u6ED5\u81A3\u81AA\u81CC\u6726\u81CA\u81BB\uFFFD".split("");
      for (j = 0; j != D[235].length; ++j)
        if (D[235][j].charCodeAt(0) !== 65533) {
          e[D[235][j]] = 60160 + j;
          d[60160 + j] = D[235][j];
        }
      D[236] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u81C1\u81A6\u6B24\u6B37\u6B39\u6B43\u6B46\u6B59\u98D1\u98D2\u98D3\u98D5\u98D9\u98DA\u6BB3\u5F40\u6BC2\u89F3\u6590\u9F51\u6593\u65BC\u65C6\u65C4\u65C3\u65CC\u65CE\u65D2\u65D6\u7080\u709C\u7096\u709D\u70BB\u70C0\u70B7\u70AB\u70B1\u70E8\u70CA\u7110\u7113\u7116\u712F\u7131\u7173\u715C\u7168\u7145\u7172\u714A\u7178\u717A\u7198\u71B3\u71B5\u71A8\u71A0\u71E0\u71D4\u71E7\u71F9\u721D\u7228\u706C\u7118\u7166\u71B9\u623E\u623D\u6243\u6248\u6249\u793B\u7940\u7946\u7949\u795B\u795C\u7953\u795A\u7962\u7957\u7960\u796F\u7967\u797A\u7985\u798A\u799A\u79A7\u79B3\u5FD1\u5FD0\uFFFD".split("");
      for (j = 0; j != D[236].length; ++j)
        if (D[236][j].charCodeAt(0) !== 65533) {
          e[D[236][j]] = 60416 + j;
          d[60416 + j] = D[236][j];
        }
      D[237] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u603C\u605D\u605A\u6067\u6041\u6059\u6063\u60AB\u6106\u610D\u615D\u61A9\u619D\u61CB\u61D1\u6206\u8080\u807F\u6C93\u6CF6\u6DFC\u77F6\u77F8\u7800\u7809\u7817\u7818\u7811\u65AB\u782D\u781C\u781D\u7839\u783A\u783B\u781F\u783C\u7825\u782C\u7823\u7829\u784E\u786D\u7856\u7857\u7826\u7850\u7847\u784C\u786A\u789B\u7893\u789A\u7887\u789C\u78A1\u78A3\u78B2\u78B9\u78A5\u78D4\u78D9\u78C9\u78EC\u78F2\u7905\u78F4\u7913\u7924\u791E\u7934\u9F9B\u9EF9\u9EFB\u9EFC\u76F1\u7704\u770D\u76F9\u7707\u7708\u771A\u7722\u7719\u772D\u7726\u7735\u7738\u7750\u7751\u7747\u7743\u775A\u7768\uFFFD".split("");
      for (j = 0; j != D[237].length; ++j)
        if (D[237][j].charCodeAt(0) !== 65533) {
          e[D[237][j]] = 60672 + j;
          d[60672 + j] = D[237][j];
        }
      D[238] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7762\u7765\u777F\u778D\u777D\u7780\u778C\u7791\u779F\u77A0\u77B0\u77B5\u77BD\u753A\u7540\u754E\u754B\u7548\u755B\u7572\u7579\u7583\u7F58\u7F61\u7F5F\u8A48\u7F68\u7F74\u7F71\u7F79\u7F81\u7F7E\u76CD\u76E5\u8832\u9485\u9486\u9487\u948B\u948A\u948C\u948D\u948F\u9490\u9494\u9497\u9495\u949A\u949B\u949C\u94A3\u94A4\u94AB\u94AA\u94AD\u94AC\u94AF\u94B0\u94B2\u94B4\u94B6\u94B7\u94B8\u94B9\u94BA\u94BC\u94BD\u94BF\u94C4\u94C8\u94C9\u94CA\u94CB\u94CC\u94CD\u94CE\u94D0\u94D1\u94D2\u94D5\u94D6\u94D7\u94D9\u94D8\u94DB\u94DE\u94DF\u94E0\u94E2\u94E4\u94E5\u94E7\u94E8\u94EA\uFFFD".split("");
      for (j = 0; j != D[238].length; ++j)
        if (D[238][j].charCodeAt(0) !== 65533) {
          e[D[238][j]] = 60928 + j;
          d[60928 + j] = D[238][j];
        }
      D[239] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u94E9\u94EB\u94EE\u94EF\u94F3\u94F4\u94F5\u94F7\u94F9\u94FC\u94FD\u94FF\u9503\u9502\u9506\u9507\u9509\u950A\u950D\u950E\u950F\u9512\u9513\u9514\u9515\u9516\u9518\u951B\u951D\u951E\u951F\u9522\u952A\u952B\u9529\u952C\u9531\u9532\u9534\u9536\u9537\u9538\u953C\u953E\u953F\u9542\u9535\u9544\u9545\u9546\u9549\u954C\u954E\u954F\u9552\u9553\u9554\u9556\u9557\u9558\u9559\u955B\u955E\u955F\u955D\u9561\u9562\u9564\u9565\u9566\u9567\u9568\u9569\u956A\u956B\u956C\u956F\u9571\u9572\u9573\u953A\u77E7\u77EC\u96C9\u79D5\u79ED\u79E3\u79EB\u7A06\u5D47\u7A03\u7A02\u7A1E\u7A14\uFFFD".split("");
      for (j = 0; j != D[239].length; ++j)
        if (D[239][j].charCodeAt(0) !== 65533) {
          e[D[239][j]] = 61184 + j;
          d[61184 + j] = D[239][j];
        }
      D[240] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7A39\u7A37\u7A51\u9ECF\u99A5\u7A70\u7688\u768E\u7693\u7699\u76A4\u74DE\u74E0\u752C\u9E20\u9E22\u9E28\u9E29\u9E2A\u9E2B\u9E2C\u9E32\u9E31\u9E36\u9E38\u9E37\u9E39\u9E3A\u9E3E\u9E41\u9E42\u9E44\u9E46\u9E47\u9E48\u9E49\u9E4B\u9E4C\u9E4E\u9E51\u9E55\u9E57\u9E5A\u9E5B\u9E5C\u9E5E\u9E63\u9E66\u9E67\u9E68\u9E69\u9E6A\u9E6B\u9E6C\u9E71\u9E6D\u9E73\u7592\u7594\u7596\u75A0\u759D\u75AC\u75A3\u75B3\u75B4\u75B8\u75C4\u75B1\u75B0\u75C3\u75C2\u75D6\u75CD\u75E3\u75E8\u75E6\u75E4\u75EB\u75E7\u7603\u75F1\u75FC\u75FF\u7610\u7600\u7605\u760C\u7617\u760A\u7625\u7618\u7615\u7619\uFFFD".split("");
      for (j = 0; j != D[240].length; ++j)
        if (D[240][j].charCodeAt(0) !== 65533) {
          e[D[240][j]] = 61440 + j;
          d[61440 + j] = D[240][j];
        }
      D[241] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u761B\u763C\u7622\u7620\u7640\u762D\u7630\u763F\u7635\u7643\u763E\u7633\u764D\u765E\u7654\u765C\u7656\u766B\u766F\u7FCA\u7AE6\u7A78\u7A79\u7A80\u7A86\u7A88\u7A95\u7AA6\u7AA0\u7AAC\u7AA8\u7AAD\u7AB3\u8864\u8869\u8872\u887D\u887F\u8882\u88A2\u88C6\u88B7\u88BC\u88C9\u88E2\u88CE\u88E3\u88E5\u88F1\u891A\u88FC\u88E8\u88FE\u88F0\u8921\u8919\u8913\u891B\u890A\u8934\u892B\u8936\u8941\u8966\u897B\u758B\u80E5\u76B2\u76B4\u77DC\u8012\u8014\u8016\u801C\u8020\u8022\u8025\u8026\u8027\u8029\u8028\u8031\u800B\u8035\u8043\u8046\u804D\u8052\u8069\u8071\u8983\u9878\u9880\u9883\uFFFD".split("");
      for (j = 0; j != D[241].length; ++j)
        if (D[241][j].charCodeAt(0) !== 65533) {
          e[D[241][j]] = 61696 + j;
          d[61696 + j] = D[241][j];
        }
      D[242] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9889\u988C\u988D\u988F\u9894\u989A\u989B\u989E\u989F\u98A1\u98A2\u98A5\u98A6\u864D\u8654\u866C\u866E\u867F\u867A\u867C\u867B\u86A8\u868D\u868B\u86AC\u869D\u86A7\u86A3\u86AA\u8693\u86A9\u86B6\u86C4\u86B5\u86CE\u86B0\u86BA\u86B1\u86AF\u86C9\u86CF\u86B4\u86E9\u86F1\u86F2\u86ED\u86F3\u86D0\u8713\u86DE\u86F4\u86DF\u86D8\u86D1\u8703\u8707\u86F8\u8708\u870A\u870D\u8709\u8723\u873B\u871E\u8725\u872E\u871A\u873E\u8748\u8734\u8731\u8729\u8737\u873F\u8782\u8722\u877D\u877E\u877B\u8760\u8770\u874C\u876E\u878B\u8753\u8763\u877C\u8764\u8759\u8765\u8793\u87AF\u87A8\u87D2\uFFFD".split("");
      for (j = 0; j != D[242].length; ++j)
        if (D[242][j].charCodeAt(0) !== 65533) {
          e[D[242][j]] = 61952 + j;
          d[61952 + j] = D[242][j];
        }
      D[243] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u87C6\u8788\u8785\u87AD\u8797\u8783\u87AB\u87E5\u87AC\u87B5\u87B3\u87CB\u87D3\u87BD\u87D1\u87C0\u87CA\u87DB\u87EA\u87E0\u87EE\u8816\u8813\u87FE\u880A\u881B\u8821\u8839\u883C\u7F36\u7F42\u7F44\u7F45\u8210\u7AFA\u7AFD\u7B08\u7B03\u7B04\u7B15\u7B0A\u7B2B\u7B0F\u7B47\u7B38\u7B2A\u7B19\u7B2E\u7B31\u7B20\u7B25\u7B24\u7B33\u7B3E\u7B1E\u7B58\u7B5A\u7B45\u7B75\u7B4C\u7B5D\u7B60\u7B6E\u7B7B\u7B62\u7B72\u7B71\u7B90\u7BA6\u7BA7\u7BB8\u7BAC\u7B9D\u7BA8\u7B85\u7BAA\u7B9C\u7BA2\u7BAB\u7BB4\u7BD1\u7BC1\u7BCC\u7BDD\u7BDA\u7BE5\u7BE6\u7BEA\u7C0C\u7BFE\u7BFC\u7C0F\u7C16\u7C0B\uFFFD".split("");
      for (j = 0; j != D[243].length; ++j)
        if (D[243][j].charCodeAt(0) !== 65533) {
          e[D[243][j]] = 62208 + j;
          d[62208 + j] = D[243][j];
        }
      D[244] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u7C1F\u7C2A\u7C26\u7C38\u7C41\u7C40\u81FE\u8201\u8202\u8204\u81EC\u8844\u8221\u8222\u8223\u822D\u822F\u8228\u822B\u8238\u823B\u8233\u8234\u823E\u8244\u8249\u824B\u824F\u825A\u825F\u8268\u887E\u8885\u8888\u88D8\u88DF\u895E\u7F9D\u7F9F\u7FA7\u7FAF\u7FB0\u7FB2\u7C7C\u6549\u7C91\u7C9D\u7C9C\u7C9E\u7CA2\u7CB2\u7CBC\u7CBD\u7CC1\u7CC7\u7CCC\u7CCD\u7CC8\u7CC5\u7CD7\u7CE8\u826E\u66A8\u7FBF\u7FCE\u7FD5\u7FE5\u7FE1\u7FE6\u7FE9\u7FEE\u7FF3\u7CF8\u7D77\u7DA6\u7DAE\u7E47\u7E9B\u9EB8\u9EB4\u8D73\u8D84\u8D94\u8D91\u8DB1\u8D67\u8D6D\u8C47\u8C49\u914A\u9150\u914E\u914F\u9164\uFFFD".split("");
      for (j = 0; j != D[244].length; ++j)
        if (D[244][j].charCodeAt(0) !== 65533) {
          e[D[244][j]] = 62464 + j;
          d[62464 + j] = D[244][j];
        }
      D[245] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9162\u9161\u9170\u9169\u916F\u917D\u917E\u9172\u9174\u9179\u918C\u9185\u9190\u918D\u9191\u91A2\u91A3\u91AA\u91AD\u91AE\u91AF\u91B5\u91B4\u91BA\u8C55\u9E7E\u8DB8\u8DEB\u8E05\u8E59\u8E69\u8DB5\u8DBF\u8DBC\u8DBA\u8DC4\u8DD6\u8DD7\u8DDA\u8DDE\u8DCE\u8DCF\u8DDB\u8DC6\u8DEC\u8DF7\u8DF8\u8DE3\u8DF9\u8DFB\u8DE4\u8E09\u8DFD\u8E14\u8E1D\u8E1F\u8E2C\u8E2E\u8E23\u8E2F\u8E3A\u8E40\u8E39\u8E35\u8E3D\u8E31\u8E49\u8E41\u8E42\u8E51\u8E52\u8E4A\u8E70\u8E76\u8E7C\u8E6F\u8E74\u8E85\u8E8F\u8E94\u8E90\u8E9C\u8E9E\u8C78\u8C82\u8C8A\u8C85\u8C98\u8C94\u659B\u89D6\u89DE\u89DA\u89DC\uFFFD".split("");
      for (j = 0; j != D[245].length; ++j)
        if (D[245][j].charCodeAt(0) !== 65533) {
          e[D[245][j]] = 62720 + j;
          d[62720 + j] = D[245][j];
        }
      D[246] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u89E5\u89EB\u89EF\u8A3E\u8B26\u9753\u96E9\u96F3\u96EF\u9706\u9701\u9708\u970F\u970E\u972A\u972D\u9730\u973E\u9F80\u9F83\u9F85\u9F86\u9F87\u9F88\u9F89\u9F8A\u9F8C\u9EFE\u9F0B\u9F0D\u96B9\u96BC\u96BD\u96CE\u96D2\u77BF\u96E0\u928E\u92AE\u92C8\u933E\u936A\u93CA\u938F\u943E\u946B\u9C7F\u9C82\u9C85\u9C86\u9C87\u9C88\u7A23\u9C8B\u9C8E\u9C90\u9C91\u9C92\u9C94\u9C95\u9C9A\u9C9B\u9C9E\u9C9F\u9CA0\u9CA1\u9CA2\u9CA3\u9CA5\u9CA6\u9CA7\u9CA8\u9CA9\u9CAB\u9CAD\u9CAE\u9CB0\u9CB1\u9CB2\u9CB3\u9CB4\u9CB5\u9CB6\u9CB7\u9CBA\u9CBB\u9CBC\u9CBD\u9CC4\u9CC5\u9CC6\u9CC7\u9CCA\u9CCB\uFFFD".split("");
      for (j = 0; j != D[246].length; ++j)
        if (D[246][j].charCodeAt(0) !== 65533) {
          e[D[246][j]] = 62976 + j;
          d[62976 + j] = D[246][j];
        }
      D[247] = "\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\uFFFD\u9CCC\u9CCD\u9CCE\u9CCF\u9CD0\u9CD3\u9CD4\u9CD5\u9CD7\u9CD8\u9CD9\u9CDC\u9CDD\u9CDF\u9CE2\u977C\u9785\u9791\u9792\u9794\u97AF\u97AB\u97A3\u97B2\u97B4\u9AB1\u9AB0\u9AB7\u9E58\u9AB6\u9ABA\u9ABC\u9AC1\u9AC0\u9AC5\u9AC2\u9ACB\u9ACC\u9AD1\u9B45\u9B43\u9B47\u9B49\u9B48\u9B4D\u9B51\u98E8\u990D\u992E\u9955\u9954\u9ADF\u9AE1\u9AE6\u9AEF\u9AEB\u9AFB\u9AED\u9AF9\u9B08\u9B0F\u9B13\u9B1F\u9B23\u9EBD\u9EBE\u7E3B\u9E82\u9E87\u9E88\u9E8B\u9E92\u93D6\u9E9D\u9E9F\u9EDB\u9EDC\u9EDD\u9EE0\u9EDF\u9EE2\u9EE9\u9EE7\u9EE5\u9EEA\u9EEF\u9F22\u9F2C\u9F2F\u9F39\u9F37\u9F3D\u9F3E\u9F44\uFFFD".split("");
      for (j = 0; j != D[247].length; ++j)
        if (D[247][j].charCodeAt(0) !== 65533) {
          e[D[247][j]] = 63232 + j;
          d[63232 + j] = D[247][j];
        }
      return { "enc": e, "dec": d };
    }();
    cptable2[10029] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC4\u0100\u0101\xC9\u0104\xD6\xDC\xE1\u0105\u010C\xE4\u010D\u0106\u0107\xE9\u0179\u017A\u010E\xED\u010F\u0112\u0113\u0116\xF3\u0117\xF4\xF6\xF5\xFA\u011A\u011B\xFC\u2020\xB0\u0118\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\u0119\xA8\u2260\u0123\u012E\u012F\u012A\u2264\u2265\u012B\u0136\u2202\u2211\u0142\u013B\u013C\u013D\u013E\u0139\u013A\u0145\u0146\u0143\xAC\u221A\u0144\u0147\u2206\xAB\xBB\u2026\xA0\u0148\u0150\xD5\u0151\u014C\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\u014D\u0154\u0155\u0158\u2039\u203A\u0159\u0156\u0157\u0160\u201A\u201E\u0161\u015A\u015B\xC1\u0164\u0165\xCD\u017D\u017E\u016A\xD3\xD4\u016B\u016E\xDA\u016F\u0170\u0171\u0172\u0173\xDD\xFD\u0137\u017B\u0141\u017C\u0122\u02C7", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[10079] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\xDD\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u2044\xA4\xD0\xF0\xDE\xFE\xFD\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\u0131\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[10081] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\xC4\xC5\xC7\xC9\xD1\xD6\xDC\xE1\xE0\xE2\xE4\xE3\xE5\xE7\xE9\xE8\xEA\xEB\xED\xEC\xEE\xEF\xF1\xF3\xF2\xF4\xF6\xF5\xFA\xF9\xFB\xFC\u2020\xB0\xA2\xA3\xA7\u2022\xB6\xDF\xAE\xA9\u2122\xB4\xA8\u2260\xC6\xD8\u221E\xB1\u2264\u2265\xA5\xB5\u2202\u2211\u220F\u03C0\u222B\xAA\xBA\u2126\xE6\xF8\xBF\xA1\xAC\u221A\u0192\u2248\u2206\xAB\xBB\u2026\xA0\xC0\xC3\xD5\u0152\u0153\u2013\u2014\u201C\u201D\u2018\u2019\xF7\u25CA\xFF\u0178\u011E\u011F\u0130\u0131\u015E\u015F\u2021\xB7\u201A\u201E\u2030\xC2\xCA\xC1\xCB\xC8\xCD\xCE\xCF\xCC\xD3\xD4\uFFFD\xD2\xDA\xDB\xD9\uFFFD\u02C6\u02DC\xAF\u02D8\u02D9\u02DA\xB8\u02DD\u02DB\u02C7", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    cptable2[28591] = function() {
      var d = "\0\x07\b	\n\v\f\r\x1B !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\x7F\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8A\x8B\x8C\x8D\x8E\x8F\x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9A\x9B\x9C\x9D\x9E\x9F\xA0\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC\xAD\xAE\xAF\xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF\xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF", D = [], e = {};
      for (var i = 0; i != d.length; ++i) {
        if (d.charCodeAt(i) !== 65533)
          e[d.charAt(i)] = i;
        D[i] = d.charAt(i);
      }
      return { "enc": e, "dec": D };
    }();
    if (typeof module2 !== "undefined" && module2.exports && typeof DO_NOT_EXPORT_CODEPAGE === "undefined")
      module2.exports = cptable2;
    (function(root2, factory) {
      "use strict";
      if (typeof cptable2 === "undefined") {
        if (typeof require !== "undefined") {
          var cpt = cptable2;
          if (typeof module2 !== "undefined" && module2.exports && typeof DO_NOT_EXPORT_CODEPAGE === "undefined")
            module2.exports = factory(cpt);
          else
            root2.cptable = factory(cpt);
        } else
          throw new Error("cptable not found");
      } else
        cptable2 = factory(cptable2);
    })(exports, function(cpt) {
      "use strict";
      var magic = {
        "1200": "utf16le",
        "1201": "utf16be",
        "12000": "utf32le",
        "12001": "utf32be",
        "16969": "utf64le",
        "20127": "ascii",
        "65000": "utf7",
        "65001": "utf8"
      };
      var sbcs_cache = [874, 1250, 1251, 1252, 1253, 1254, 1255, 1256, 1e4];
      var dbcs_cache = [932, 936, 949, 950];
      var magic_cache = [65001];
      var magic_decode = {};
      var magic_encode = {};
      var cpdcache = {};
      var cpecache = {};
      var sfcc = function sfcc2(x) {
        return String.fromCharCode(x);
      };
      var cca = function cca2(x) {
        return x.charCodeAt(0);
      };
      var has_buf = typeof Buffer !== "undefined";
      var Buffer_from = function() {
      };
      if (has_buf) {
        var nbfs = !Buffer.from;
        if (!nbfs)
          try {
            Buffer.from("foo", "utf8");
          } catch (e) {
            nbfs = true;
          }
        Buffer_from = nbfs ? function(buf, enc) {
          return enc ? new Buffer(buf, enc) : new Buffer(buf);
        } : Buffer.from.bind(Buffer);
        if (!Buffer.allocUnsafe)
          Buffer.allocUnsafe = function(n) {
            return new Buffer(n);
          };
        var mdl = 1024, mdb = Buffer.allocUnsafe(mdl);
        var make_EE = function make_EE2(E) {
          var EE = Buffer.allocUnsafe(65536);
          for (var i = 0; i < 65536; ++i)
            EE[i] = 0;
          var keys3 = Object.keys(E), len = keys3.length;
          for (var ee = 0, e = keys3[ee]; ee < len; ++ee) {
            if (!(e = keys3[ee]))
              continue;
            EE[e.charCodeAt(0)] = E[e];
          }
          return EE;
        };
        var sbcs_encode = function make_sbcs_encode(cp) {
          var EE = make_EE(cpt[cp].enc);
          return function sbcs_e(data, ofmt) {
            var len = data.length;
            var out, i = 0, j = 0, D = 0, w = 0;
            if (typeof data === "string") {
              out = Buffer.allocUnsafe(len);
              for (i = 0; i < len; ++i)
                out[i] = EE[data.charCodeAt(i)];
            } else if (Buffer.isBuffer(data)) {
              out = Buffer.allocUnsafe(2 * len);
              j = 0;
              for (i = 0; i < len; ++i) {
                D = data[i];
                if (D < 128)
                  out[j++] = EE[D];
                else if (D < 224) {
                  out[j++] = EE[((D & 31) << 6) + (data[i + 1] & 63)];
                  ++i;
                } else if (D < 240) {
                  out[j++] = EE[((D & 15) << 12) + ((data[i + 1] & 63) << 6) + (data[i + 2] & 63)];
                  i += 2;
                } else {
                  w = ((D & 7) << 18) + ((data[i + 1] & 63) << 12) + ((data[i + 2] & 63) << 6) + (data[i + 3] & 63);
                  i += 3;
                  if (w < 65536)
                    out[j++] = EE[w];
                  else {
                    w -= 65536;
                    out[j++] = EE[55296 + (w >> 10 & 1023)];
                    out[j++] = EE[56320 + (w & 1023)];
                  }
                }
              }
              out = out.slice(0, j);
            } else {
              out = Buffer.allocUnsafe(len);
              for (i = 0; i < len; ++i)
                out[i] = EE[data[i].charCodeAt(0)];
            }
            if (!ofmt || ofmt === "buf")
              return out;
            if (ofmt !== "arr")
              return out.toString("binary");
            return [].slice.call(out);
          };
        };
        var sbcs_decode = function make_sbcs_decode(cp) {
          var D = cpt[cp].dec;
          var DD = Buffer.allocUnsafe(131072), d = 0, c = "";
          for (d = 0; d < D.length; ++d) {
            if (!(c = D[d]))
              continue;
            var w = c.charCodeAt(0);
            DD[2 * d] = w & 255;
            DD[2 * d + 1] = w >> 8;
          }
          return function sbcs_d(data) {
            var len = data.length, i = 0, j = 0;
            if (2 * len > mdl) {
              mdl = 2 * len;
              mdb = Buffer.allocUnsafe(mdl);
            }
            if (Buffer.isBuffer(data)) {
              for (i = 0; i < len; i++) {
                j = 2 * data[i];
                mdb[2 * i] = DD[j];
                mdb[2 * i + 1] = DD[j + 1];
              }
            } else if (typeof data === "string") {
              for (i = 0; i < len; i++) {
                j = 2 * data.charCodeAt(i);
                mdb[2 * i] = DD[j];
                mdb[2 * i + 1] = DD[j + 1];
              }
            } else {
              for (i = 0; i < len; i++) {
                j = 2 * data[i];
                mdb[2 * i] = DD[j];
                mdb[2 * i + 1] = DD[j + 1];
              }
            }
            return mdb.slice(0, 2 * len).toString("ucs2");
          };
        };
        var dbcs_encode = function make_dbcs_encode(cp) {
          var E = cpt[cp].enc;
          var EE = Buffer.allocUnsafe(131072);
          for (var i = 0; i < 131072; ++i)
            EE[i] = 0;
          var keys3 = Object.keys(E);
          for (var ee = 0, e = keys3[ee]; ee < keys3.length; ++ee) {
            if (!(e = keys3[ee]))
              continue;
            var f = e.charCodeAt(0);
            EE[2 * f] = E[e] & 255;
            EE[2 * f + 1] = E[e] >> 8;
          }
          return function dbcs_e(data, ofmt) {
            var len = data.length, out = Buffer.allocUnsafe(2 * len), i2 = 0, j = 0, jj = 0, k = 0, D = 0;
            if (typeof data === "string") {
              for (i2 = k = 0; i2 < len; ++i2) {
                j = data.charCodeAt(i2) * 2;
                out[k++] = EE[j + 1] || EE[j];
                if (EE[j + 1] > 0)
                  out[k++] = EE[j];
              }
              out = out.slice(0, k);
            } else if (Buffer.isBuffer(data)) {
              for (i2 = k = 0; i2 < len; ++i2) {
                D = data[i2];
                if (D < 128)
                  j = D;
                else if (D < 224) {
                  j = ((D & 31) << 6) + (data[i2 + 1] & 63);
                  ++i2;
                } else if (D < 240) {
                  j = ((D & 15) << 12) + ((data[i2 + 1] & 63) << 6) + (data[i2 + 2] & 63);
                  i2 += 2;
                } else {
                  j = ((D & 7) << 18) + ((data[i2 + 1] & 63) << 12) + ((data[i2 + 2] & 63) << 6) + (data[i2 + 3] & 63);
                  i2 += 3;
                }
                if (j < 65536) {
                  j *= 2;
                  out[k++] = EE[j + 1] || EE[j];
                  if (EE[j + 1] > 0)
                    out[k++] = EE[j];
                } else {
                  jj = j - 65536;
                  j = 2 * (55296 + (jj >> 10 & 1023));
                  out[k++] = EE[j + 1] || EE[j];
                  if (EE[j + 1] > 0)
                    out[k++] = EE[j];
                  j = 2 * (56320 + (jj & 1023));
                  out[k++] = EE[j + 1] || EE[j];
                  if (EE[j + 1] > 0)
                    out[k++] = EE[j];
                }
              }
              out = out.slice(0, k);
            } else {
              for (i2 = k = 0; i2 < len; i2++) {
                j = data[i2].charCodeAt(0) * 2;
                out[k++] = EE[j + 1] || EE[j];
                if (EE[j + 1] > 0)
                  out[k++] = EE[j];
              }
            }
            if (!ofmt || ofmt === "buf")
              return out;
            if (ofmt !== "arr")
              return out.toString("binary");
            return [].slice.call(out);
          };
        };
        var dbcs_decode = function make_dbcs_decode(cp) {
          var D = cpt[cp].dec;
          var DD = Buffer.allocUnsafe(131072), d = 0, c, w = 0, j = 0, i = 0;
          for (i = 0; i < 65536; ++i) {
            DD[2 * i] = 255;
            DD[2 * i + 1] = 253;
          }
          for (d = 0; d < D.length; ++d) {
            if (!(c = D[d]))
              continue;
            w = c.charCodeAt(0);
            j = 2 * d;
            DD[j] = w & 255;
            DD[j + 1] = w >> 8;
          }
          return function dbcs_d(data) {
            var len = data.length, out = Buffer.allocUnsafe(2 * len), i2 = 0, j2 = 0, k = 0;
            if (Buffer.isBuffer(data)) {
              for (i2 = 0; i2 < len; i2++) {
                j2 = 2 * data[i2];
                if (DD[j2] === 255 && DD[j2 + 1] === 253) {
                  j2 = 2 * ((data[i2] << 8) + data[i2 + 1]);
                  ++i2;
                }
                out[k++] = DD[j2];
                out[k++] = DD[j2 + 1];
              }
            } else if (typeof data === "string") {
              for (i2 = 0; i2 < len; i2++) {
                j2 = 2 * data.charCodeAt(i2);
                if (DD[j2] === 255 && DD[j2 + 1] === 253) {
                  j2 = 2 * ((data.charCodeAt(i2) << 8) + data.charCodeAt(i2 + 1));
                  ++i2;
                }
                out[k++] = DD[j2];
                out[k++] = DD[j2 + 1];
              }
            } else {
              for (i2 = 0; i2 < len; i2++) {
                j2 = 2 * data[i2];
                if (DD[j2] === 255 && DD[j2 + 1] === 253) {
                  j2 = 2 * ((data[i2] << 8) + data[i2 + 1]);
                  ++i2;
                }
                out[k++] = DD[j2];
                out[k++] = DD[j2 + 1];
              }
            }
            return out.slice(0, k).toString("ucs2");
          };
        };
        magic_decode[65001] = function utf8_d(data) {
          if (typeof data === "string")
            return utf8_d(data.split("").map(cca));
          var len = data.length, w = 0, ww = 0;
          if (4 * len > mdl) {
            mdl = 4 * len;
            mdb = Buffer.allocUnsafe(mdl);
          }
          var i = 0;
          if (len >= 3 && data[0] == 239) {
            if (data[1] == 187 && data[2] == 191)
              i = 3;
          }
          for (var j = 1, k = 0, D = 0; i < len; i += j) {
            j = 1;
            D = data[i];
            if (D < 128)
              w = D;
            else if (D < 224) {
              w = (D & 31) * 64 + (data[i + 1] & 63);
              j = 2;
            } else if (D < 240) {
              w = ((D & 15) << 12) + (data[i + 1] & 63) * 64 + (data[i + 2] & 63);
              j = 3;
            } else {
              w = (D & 7) * 262144 + ((data[i + 1] & 63) << 12) + (data[i + 2] & 63) * 64 + (data[i + 3] & 63);
              j = 4;
            }
            if (w < 65536) {
              mdb[k++] = w & 255;
              mdb[k++] = w >> 8;
            } else {
              w -= 65536;
              ww = 55296 + (w >> 10 & 1023);
              w = 56320 + (w & 1023);
              mdb[k++] = ww & 255;
              mdb[k++] = ww >>> 8;
              mdb[k++] = w & 255;
              mdb[k++] = w >>> 8 & 255;
            }
          }
          return mdb.slice(0, k).toString("ucs2");
        };
        magic_encode[65001] = function utf8_e(data, ofmt) {
          if (has_buf && Buffer.isBuffer(data)) {
            if (!ofmt || ofmt === "buf")
              return data;
            if (ofmt !== "arr")
              return data.toString("binary");
            return [].slice.call(data);
          }
          var len = data.length, w = 0, ww = 0, j = 0;
          var direct = typeof data === "string";
          if (4 * len > mdl) {
            mdl = 4 * len;
            mdb = Buffer.allocUnsafe(mdl);
          }
          for (var i = 0; i < len; ++i) {
            w = direct ? data.charCodeAt(i) : data[i].charCodeAt(0);
            if (w <= 127)
              mdb[j++] = w;
            else if (w <= 2047) {
              mdb[j++] = 192 + (w >> 6);
              mdb[j++] = 128 + (w & 63);
            } else if (w >= 55296 && w <= 57343) {
              w -= 55296;
              ++i;
              ww = (direct ? data.charCodeAt(i) : data[i].charCodeAt(0)) - 56320 + (w << 10);
              mdb[j++] = 240 + (ww >>> 18 & 7);
              mdb[j++] = 144 + (ww >>> 12 & 63);
              mdb[j++] = 128 + (ww >>> 6 & 63);
              mdb[j++] = 128 + (ww & 63);
            } else {
              mdb[j++] = 224 + (w >> 12);
              mdb[j++] = 128 + (w >> 6 & 63);
              mdb[j++] = 128 + (w & 63);
            }
          }
          if (!ofmt || ofmt === "buf")
            return mdb.slice(0, j);
          if (ofmt !== "arr")
            return mdb.slice(0, j).toString("binary");
          return [].slice.call(mdb, 0, j);
        };
      }
      var encache = function encache2() {
        if (has_buf) {
          if (cpdcache[sbcs_cache[0]])
            return;
          var i = 0, s = 0;
          for (i = 0; i < sbcs_cache.length; ++i) {
            s = sbcs_cache[i];
            if (cpt[s]) {
              cpdcache[s] = sbcs_decode(s);
              cpecache[s] = sbcs_encode(s);
            }
          }
          for (i = 0; i < dbcs_cache.length; ++i) {
            s = dbcs_cache[i];
            if (cpt[s]) {
              cpdcache[s] = dbcs_decode(s);
              cpecache[s] = dbcs_encode(s);
            }
          }
          for (i = 0; i < magic_cache.length; ++i) {
            s = magic_cache[i];
            if (magic_decode[s])
              cpdcache[s] = magic_decode[s];
            if (magic_encode[s])
              cpecache[s] = magic_encode[s];
          }
        }
      };
      var null_enc = function(data, ofmt) {
        return "";
      };
      var cp_decache = function cp_decache2(cp) {
        delete cpdcache[cp];
        delete cpecache[cp];
      };
      var decache = function decache2() {
        if (has_buf) {
          if (!cpdcache[sbcs_cache[0]])
            return;
          sbcs_cache.forEach(cp_decache);
          dbcs_cache.forEach(cp_decache);
          magic_cache.forEach(cp_decache);
        }
        last_enc = null_enc;
        last_cp = 0;
      };
      var cache = {
        encache,
        decache,
        sbcs: sbcs_cache,
        dbcs: dbcs_cache
      };
      encache();
      var BM = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
      var SetD = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789'(),-./:?";
      var last_enc = null_enc, last_cp = 0;
      var encode = function encode2(cp, data, ofmt) {
        if (cp === last_cp && last_enc) {
          return last_enc(data, ofmt);
        }
        if (cpecache[cp]) {
          last_enc = cpecache[last_cp = cp];
          return last_enc(data, ofmt);
        }
        if (has_buf && Buffer.isBuffer(data))
          data = data.toString("utf8");
        var len = data.length;
        var out = has_buf ? Buffer.allocUnsafe(4 * len) : [], w = 0, i = 0, j = 0, ww = 0;
        var C = cpt[cp], E, M = "";
        var isstr = typeof data === "string";
        if (C && (E = C.enc))
          for (i = 0; i < len; ++i, ++j) {
            w = E[isstr ? data.charAt(i) : data[i]];
            if (w > 255) {
              out[j] = w >> 8;
              out[++j] = w & 255;
            } else
              out[j] = w & 255;
          }
        else if (M = magic[cp])
          switch (M) {
            case "utf8":
              if (has_buf && isstr) {
                out = Buffer_from(data, M);
                j = out.length;
                break;
              }
              for (i = 0; i < len; ++i, ++j) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                if (w <= 127)
                  out[j] = w;
                else if (w <= 2047) {
                  out[j] = 192 + (w >> 6);
                  out[++j] = 128 + (w & 63);
                } else if (w >= 55296 && w <= 57343) {
                  w -= 55296;
                  ww = (isstr ? data.charCodeAt(++i) : data[++i].charCodeAt(0)) - 56320 + (w << 10);
                  out[j] = 240 + (ww >>> 18 & 7);
                  out[++j] = 144 + (ww >>> 12 & 63);
                  out[++j] = 128 + (ww >>> 6 & 63);
                  out[++j] = 128 + (ww & 63);
                } else {
                  out[j] = 224 + (w >> 12);
                  out[++j] = 128 + (w >> 6 & 63);
                  out[++j] = 128 + (w & 63);
                }
              }
              break;
            case "ascii":
              if (has_buf && typeof data === "string") {
                out = Buffer_from(data, M);
                j = out.length;
                break;
              }
              for (i = 0; i < len; ++i, ++j) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                if (w <= 127)
                  out[j] = w;
                else
                  throw new Error("bad ascii " + w);
              }
              break;
            case "utf16le":
              if (has_buf && typeof data === "string") {
                out = Buffer_from(data, M);
                j = out.length;
                break;
              }
              for (i = 0; i < len; ++i) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                out[j++] = w & 255;
                out[j++] = w >> 8;
              }
              break;
            case "utf16be":
              for (i = 0; i < len; ++i) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                out[j++] = w >> 8;
                out[j++] = w & 255;
              }
              break;
            case "utf32le":
              for (i = 0; i < len; ++i) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                if (w >= 55296 && w <= 57343)
                  w = 65536 + (w - 55296 << 10) + (data[++i].charCodeAt(0) - 56320);
                out[j++] = w & 255;
                w >>= 8;
                out[j++] = w & 255;
                w >>= 8;
                out[j++] = w & 255;
                w >>= 8;
                out[j++] = w & 255;
              }
              break;
            case "utf32be":
              for (i = 0; i < len; ++i) {
                w = isstr ? data.charCodeAt(i) : data[i].charCodeAt(0);
                if (w >= 55296 && w <= 57343)
                  w = 65536 + (w - 55296 << 10) + (data[++i].charCodeAt(0) - 56320);
                out[j + 3] = w & 255;
                w >>= 8;
                out[j + 2] = w & 255;
                w >>= 8;
                out[j + 1] = w & 255;
                w >>= 8;
                out[j] = w & 255;
                j += 4;
              }
              break;
            case "utf7":
              for (i = 0; i < len; i++) {
                var c = isstr ? data.charAt(i) : data[i].charAt(0);
                if (c === "+") {
                  out[j++] = 43;
                  out[j++] = 45;
                  continue;
                }
                if (SetD.indexOf(c) > -1) {
                  out[j++] = c.charCodeAt(0);
                  continue;
                }
                var tt = encode2(1201, c);
                out[j++] = 43;
                out[j++] = BM.charCodeAt(tt[0] >> 2);
                out[j++] = BM.charCodeAt(((tt[0] & 3) << 4) + ((tt[1] || 0) >> 4));
                out[j++] = BM.charCodeAt(((tt[1] & 15) << 2) + ((tt[2] || 0) >> 6));
                out[j++] = 45;
              }
              break;
            default:
              throw new Error("Unsupported magic: " + cp + " " + magic[cp]);
          }
        else
          throw new Error("Unrecognized CP: " + cp);
        out = out.slice(0, j);
        if (!has_buf)
          return ofmt == "str" ? out.map(sfcc).join("") : out;
        if (!ofmt || ofmt === "buf")
          return out;
        if (ofmt !== "arr")
          return out.toString("binary");
        return [].slice.call(out);
      };
      var decode = function decode2(cp, data) {
        var F;
        if (F = cpdcache[cp])
          return F(data);
        if (typeof data === "string")
          return decode2(cp, data.split("").map(cca));
        var len = data.length, out = new Array(len), s = "", w = 0, i = 0, j = 1, k = 0, ww = 0;
        var C = cpt[cp], D, M = "";
        if (C && (D = C.dec)) {
          for (i = 0; i < len; i += j) {
            j = 2;
            s = D[(data[i] << 8) + data[i + 1]];
            if (!s) {
              j = 1;
              s = D[data[i]];
            }
            if (!s)
              throw new Error("Unrecognized code: " + data[i] + " " + data[i + j - 1] + " " + i + " " + j + " " + D[data[i]]);
            out[k++] = s;
          }
        } else if (M = magic[cp])
          switch (M) {
            case "utf8":
              if (len >= 3 && data[0] == 239) {
                if (data[1] == 187 && data[2] == 191)
                  i = 3;
              }
              for (; i < len; i += j) {
                j = 1;
                if (data[i] < 128)
                  w = data[i];
                else if (data[i] < 224) {
                  w = (data[i] & 31) * 64 + (data[i + 1] & 63);
                  j = 2;
                } else if (data[i] < 240) {
                  w = ((data[i] & 15) << 12) + (data[i + 1] & 63) * 64 + (data[i + 2] & 63);
                  j = 3;
                } else {
                  w = (data[i] & 7) * 262144 + ((data[i + 1] & 63) << 12) + (data[i + 2] & 63) * 64 + (data[i + 3] & 63);
                  j = 4;
                }
                if (w < 65536) {
                  out[k++] = String.fromCharCode(w);
                } else {
                  w -= 65536;
                  ww = 55296 + (w >> 10 & 1023);
                  w = 56320 + (w & 1023);
                  out[k++] = String.fromCharCode(ww);
                  out[k++] = String.fromCharCode(w);
                }
              }
              break;
            case "ascii":
              if (has_buf && Buffer.isBuffer(data))
                return data.toString(M);
              for (i = 0; i < len; i++)
                out[i] = String.fromCharCode(data[i]);
              k = len;
              break;
            case "utf16le":
              if (len >= 2 && data[0] == 255) {
                if (data[1] == 254)
                  i = 2;
              }
              if (has_buf && Buffer.isBuffer(data))
                return data.toString(M);
              j = 2;
              for (; i + 1 < len; i += j) {
                out[k++] = String.fromCharCode((data[i + 1] << 8) + data[i]);
              }
              break;
            case "utf16be":
              if (len >= 2 && data[0] == 254) {
                if (data[1] == 255)
                  i = 2;
              }
              j = 2;
              for (; i + 1 < len; i += j) {
                out[k++] = String.fromCharCode((data[i] << 8) + data[i + 1]);
              }
              break;
            case "utf32le":
              if (len >= 4 && data[0] == 255) {
                if (data[1] == 254 && data[2] === 0 && data[3] === 0)
                  i = 4;
              }
              j = 4;
              for (; i < len; i += j) {
                w = (data[i + 3] << 24) + (data[i + 2] << 16) + (data[i + 1] << 8) + data[i];
                if (w > 65535) {
                  w -= 65536;
                  out[k++] = String.fromCharCode(55296 + (w >> 10 & 1023));
                  out[k++] = String.fromCharCode(56320 + (w & 1023));
                } else
                  out[k++] = String.fromCharCode(w);
              }
              break;
            case "utf32be":
              if (len >= 4 && data[3] == 255) {
                if (data[2] == 254 && data[1] === 0 && data[0] === 0)
                  i = 4;
              }
              j = 4;
              for (; i < len; i += j) {
                w = (data[i] << 24) + (data[i + 1] << 16) + (data[i + 2] << 8) + data[i + 3];
                if (w > 65535) {
                  w -= 65536;
                  out[k++] = String.fromCharCode(55296 + (w >> 10 & 1023));
                  out[k++] = String.fromCharCode(56320 + (w & 1023));
                } else
                  out[k++] = String.fromCharCode(w);
              }
              break;
            case "utf7":
              if (len >= 4 && data[0] == 43 && data[1] == 47 && data[2] == 118) {
                if (len >= 5 && data[3] == 56 && data[4] == 45)
                  i = 5;
                else if (data[3] == 56 || data[3] == 57 || data[3] == 43 || data[3] == 47)
                  i = 4;
              }
              for (; i < len; i += j) {
                if (data[i] !== 43) {
                  j = 1;
                  out[k++] = String.fromCharCode(data[i]);
                  continue;
                }
                j = 1;
                if (data[i + 1] === 45) {
                  j = 2;
                  out[k++] = "+";
                  continue;
                }
                while (String.fromCharCode(data[i + j]).match(/[A-Za-z0-9+\/]/))
                  j++;
                var dash = 0;
                if (data[i + j] === 45) {
                  ++j;
                  dash = 1;
                }
                var tt = [];
                var o64 = "";
                var c1 = 0, c2 = 0, c3 = 0;
                var e1 = 0, e2 = 0, e3 = 0, e4 = 0;
                for (var l = 1; l < j - dash; ) {
                  e1 = BM.indexOf(String.fromCharCode(data[i + l++]));
                  e2 = BM.indexOf(String.fromCharCode(data[i + l++]));
                  c1 = e1 << 2 | e2 >> 4;
                  tt.push(c1);
                  e3 = BM.indexOf(String.fromCharCode(data[i + l++]));
                  if (e3 === -1)
                    break;
                  c2 = (e2 & 15) << 4 | e3 >> 2;
                  tt.push(c2);
                  e4 = BM.indexOf(String.fromCharCode(data[i + l++]));
                  if (e4 === -1)
                    break;
                  c3 = (e3 & 3) << 6 | e4;
                  if (e4 < 64)
                    tt.push(c3);
                }
                o64 = decode2(1201, tt);
                for (l = 0; l < o64.length; ++l)
                  out[k++] = o64.charAt(l);
              }
              break;
            default:
              throw new Error("Unsupported magic: " + cp + " " + magic[cp]);
          }
        else
          throw new Error("Unrecognized CP: " + cp);
        return out.slice(0, k).join("");
      };
      var hascp = function hascp2(cp) {
        return !!(cpt[cp] || magic[cp]);
      };
      cpt.utils = { decode, encode, hascp, magic, cache };
      return cpt;
    });
  }
});

// node_modules/xlsx/xlsx.js
var require_xlsx = __commonJS({
  "node_modules/xlsx/xlsx.js"(exports, module2) {
    var XLSX = {};
    function make_xlsx_lib(XLSX2) {
      XLSX2.version = "0.18.5";
      var current_codepage = 1200, current_ansi = 1252;
      var $cptable;
      if (typeof cptable !== "undefined")
        $cptable = cptable;
      else if (typeof module2 !== "undefined" && typeof require !== "undefined") {
        $cptable = require_cpexcel();
      }
      var VALID_ANSI = [874, 932, 936, 949, 950, 1250, 1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1e4];
      var CS2CP = {
        0: 1252,
        /* ANSI */
        1: 65001,
        /* DEFAULT */
        2: 65001,
        /* SYMBOL */
        77: 1e4,
        /* MAC */
        128: 932,
        /* SHIFTJIS */
        129: 949,
        /* HANGUL */
        130: 1361,
        /* JOHAB */
        134: 936,
        /* GB2312 */
        136: 950,
        /* CHINESEBIG5 */
        161: 1253,
        /* GREEK */
        162: 1254,
        /* TURKISH */
        163: 1258,
        /* VIETNAMESE */
        177: 1255,
        /* HEBREW */
        178: 1256,
        /* ARABIC */
        186: 1257,
        /* BALTIC */
        204: 1251,
        /* RUSSIAN */
        222: 874,
        /* THAI */
        238: 1250,
        /* EASTEUROPE */
        255: 1252,
        /* OEM */
        69: 6969
        /* MISC */
      };
      var set_ansi = function(cp) {
        if (VALID_ANSI.indexOf(cp) == -1)
          return;
        current_ansi = CS2CP[0] = cp;
      };
      function reset_ansi() {
        set_ansi(1252);
      }
      var set_cp = function(cp) {
        current_codepage = cp;
        set_ansi(cp);
      };
      function reset_cp() {
        set_cp(1200);
        reset_ansi();
      }
      function char_codes(data) {
        var o = [];
        for (var i = 0, len = data.length; i < len; ++i)
          o[i] = data.charCodeAt(i);
        return o;
      }
      function utf16leread(data) {
        var o = [];
        for (var i = 0; i < data.length >> 1; ++i)
          o[i] = String.fromCharCode(data.charCodeAt(2 * i) + (data.charCodeAt(2 * i + 1) << 8));
        return o.join("");
      }
      function utf16beread(data) {
        var o = [];
        for (var i = 0; i < data.length >> 1; ++i)
          o[i] = String.fromCharCode(data.charCodeAt(2 * i + 1) + (data.charCodeAt(2 * i) << 8));
        return o.join("");
      }
      var debom = function(data) {
        var c1 = data.charCodeAt(0), c2 = data.charCodeAt(1);
        if (c1 == 255 && c2 == 254)
          return utf16leread(data.slice(2));
        if (c1 == 254 && c2 == 255)
          return utf16beread(data.slice(2));
        if (c1 == 65279)
          return data.slice(1);
        return data;
      };
      var _getchar = function _gc1(x) {
        return String.fromCharCode(x);
      };
      var _getansi = function _ga1(x) {
        return String.fromCharCode(x);
      };
      if (typeof $cptable !== "undefined") {
        set_cp = function(cp) {
          current_codepage = cp;
          set_ansi(cp);
        };
        debom = function(data) {
          if (data.charCodeAt(0) === 255 && data.charCodeAt(1) === 254) {
            return $cptable.utils.decode(1200, char_codes(data.slice(2)));
          }
          return data;
        };
        _getchar = function _gc2(x) {
          if (current_codepage === 1200)
            return String.fromCharCode(x);
          return $cptable.utils.decode(current_codepage, [x & 255, x >> 8])[0];
        };
        _getansi = function _ga2(x) {
          return $cptable.utils.decode(current_ansi, [x])[0];
        };
      }
      var DENSE = null;
      var DIF_XL = true;
      var Base64_map = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
      function Base64_encode(input) {
        var o = "";
        var c1 = 0, c2 = 0, c3 = 0, e1 = 0, e2 = 0, e3 = 0, e4 = 0;
        for (var i = 0; i < input.length; ) {
          c1 = input.charCodeAt(i++);
          e1 = c1 >> 2;
          c2 = input.charCodeAt(i++);
          e2 = (c1 & 3) << 4 | c2 >> 4;
          c3 = input.charCodeAt(i++);
          e3 = (c2 & 15) << 2 | c3 >> 6;
          e4 = c3 & 63;
          if (isNaN(c2)) {
            e3 = e4 = 64;
          } else if (isNaN(c3)) {
            e4 = 64;
          }
          o += Base64_map.charAt(e1) + Base64_map.charAt(e2) + Base64_map.charAt(e3) + Base64_map.charAt(e4);
        }
        return o;
      }
      function Base64_decode(input) {
        var o = "";
        var c1 = 0, c2 = 0, c3 = 0, e1 = 0, e2 = 0, e3 = 0, e4 = 0;
        input = input.replace(/[^\w\+\/\=]/g, "");
        for (var i = 0; i < input.length; ) {
          e1 = Base64_map.indexOf(input.charAt(i++));
          e2 = Base64_map.indexOf(input.charAt(i++));
          c1 = e1 << 2 | e2 >> 4;
          o += String.fromCharCode(c1);
          e3 = Base64_map.indexOf(input.charAt(i++));
          c2 = (e2 & 15) << 4 | e3 >> 2;
          if (e3 !== 64) {
            o += String.fromCharCode(c2);
          }
          e4 = Base64_map.indexOf(input.charAt(i++));
          c3 = (e3 & 3) << 6 | e4;
          if (e4 !== 64) {
            o += String.fromCharCode(c3);
          }
        }
        return o;
      }
      var has_buf = function() {
        return typeof Buffer !== "undefined" && typeof process !== "undefined" && typeof process.versions !== "undefined" && !!process.versions.node;
      }();
      var Buffer_from = function() {
        if (typeof Buffer !== "undefined") {
          var nbfs = !Buffer.from;
          if (!nbfs)
            try {
              Buffer.from("foo", "utf8");
            } catch (e) {
              nbfs = true;
            }
          return nbfs ? function(buf, enc) {
            return enc ? new Buffer(buf, enc) : new Buffer(buf);
          } : Buffer.from.bind(Buffer);
        }
        return function() {
        };
      }();
      function new_raw_buf(len) {
        if (has_buf)
          return Buffer.alloc ? Buffer.alloc(len) : new Buffer(len);
        return typeof Uint8Array != "undefined" ? new Uint8Array(len) : new Array(len);
      }
      function new_unsafe_buf(len) {
        if (has_buf)
          return Buffer.allocUnsafe ? Buffer.allocUnsafe(len) : new Buffer(len);
        return typeof Uint8Array != "undefined" ? new Uint8Array(len) : new Array(len);
      }
      var s2a = function s2a2(s) {
        if (has_buf)
          return Buffer_from(s, "binary");
        return s.split("").map(function(x) {
          return x.charCodeAt(0) & 255;
        });
      };
      function s2ab(s) {
        if (typeof ArrayBuffer === "undefined")
          return s2a(s);
        var buf = new ArrayBuffer(s.length), view = new Uint8Array(buf);
        for (var i = 0; i != s.length; ++i)
          view[i] = s.charCodeAt(i) & 255;
        return buf;
      }
      function a2s(data) {
        if (Array.isArray(data))
          return data.map(function(c) {
            return String.fromCharCode(c);
          }).join("");
        var o = [];
        for (var i = 0; i < data.length; ++i)
          o[i] = String.fromCharCode(data[i]);
        return o.join("");
      }
      function a2u(data) {
        if (typeof Uint8Array === "undefined")
          throw new Error("Unsupported");
        return new Uint8Array(data);
      }
      function ab2a(data) {
        if (typeof ArrayBuffer == "undefined")
          throw new Error("Unsupported");
        if (data instanceof ArrayBuffer)
          return ab2a(new Uint8Array(data));
        var o = new Array(data.length);
        for (var i = 0; i < data.length; ++i)
          o[i] = data[i];
        return o;
      }
      var bconcat = has_buf ? function(bufs) {
        return Buffer.concat(bufs.map(function(buf) {
          return Buffer.isBuffer(buf) ? buf : Buffer_from(buf);
        }));
      } : function(bufs) {
        if (typeof Uint8Array !== "undefined") {
          var i = 0, maxlen = 0;
          for (i = 0; i < bufs.length; ++i)
            maxlen += bufs[i].length;
          var o = new Uint8Array(maxlen);
          var len = 0;
          for (i = 0, maxlen = 0; i < bufs.length; maxlen += len, ++i) {
            len = bufs[i].length;
            if (bufs[i] instanceof Uint8Array)
              o.set(bufs[i], maxlen);
            else if (typeof bufs[i] == "string") {
              throw "wtf";
            } else
              o.set(new Uint8Array(bufs[i]), maxlen);
          }
          return o;
        }
        return [].concat.apply([], bufs.map(function(buf) {
          return Array.isArray(buf) ? buf : [].slice.call(buf);
        }));
      };
      function utf8decode(content) {
        var out = [], widx = 0, L = content.length + 250;
        var o = new_raw_buf(content.length + 255);
        for (var ridx = 0; ridx < content.length; ++ridx) {
          var c = content.charCodeAt(ridx);
          if (c < 128)
            o[widx++] = c;
          else if (c < 2048) {
            o[widx++] = 192 | c >> 6 & 31;
            o[widx++] = 128 | c & 63;
          } else if (c >= 55296 && c < 57344) {
            c = (c & 1023) + 64;
            var d = content.charCodeAt(++ridx) & 1023;
            o[widx++] = 240 | c >> 8 & 7;
            o[widx++] = 128 | c >> 2 & 63;
            o[widx++] = 128 | d >> 6 & 15 | (c & 3) << 4;
            o[widx++] = 128 | d & 63;
          } else {
            o[widx++] = 224 | c >> 12 & 15;
            o[widx++] = 128 | c >> 6 & 63;
            o[widx++] = 128 | c & 63;
          }
          if (widx > L) {
            out.push(o.slice(0, widx));
            widx = 0;
            o = new_raw_buf(65535);
            L = 65530;
          }
        }
        out.push(o.slice(0, widx));
        return bconcat(out);
      }
      var chr0 = /\u0000/g, chr1 = /[\u0001-\u0006]/g;
      function _strrev(x) {
        var o = "", i = x.length - 1;
        while (i >= 0)
          o += x.charAt(i--);
        return o;
      }
      function pad0(v, d) {
        var t3 = "" + v;
        return t3.length >= d ? t3 : fill("0", d - t3.length) + t3;
      }
      function pad_(v, d) {
        var t3 = "" + v;
        return t3.length >= d ? t3 : fill(" ", d - t3.length) + t3;
      }
      function rpad_(v, d) {
        var t3 = "" + v;
        return t3.length >= d ? t3 : t3 + fill(" ", d - t3.length);
      }
      function pad0r1(v, d) {
        var t3 = "" + Math.round(v);
        return t3.length >= d ? t3 : fill("0", d - t3.length) + t3;
      }
      function pad0r2(v, d) {
        var t3 = "" + v;
        return t3.length >= d ? t3 : fill("0", d - t3.length) + t3;
      }
      var p2_32 = Math.pow(2, 32);
      function pad0r(v, d) {
        if (v > p2_32 || v < -p2_32)
          return pad0r1(v, d);
        var i = Math.round(v);
        return pad0r2(i, d);
      }
      function SSF_isgeneral(s, i) {
        i = i || 0;
        return s.length >= 7 + i && (s.charCodeAt(i) | 32) === 103 && (s.charCodeAt(i + 1) | 32) === 101 && (s.charCodeAt(i + 2) | 32) === 110 && (s.charCodeAt(i + 3) | 32) === 101 && (s.charCodeAt(i + 4) | 32) === 114 && (s.charCodeAt(i + 5) | 32) === 97 && (s.charCodeAt(i + 6) | 32) === 108;
      }
      var days = [
        ["Sun", "Sunday"],
        ["Mon", "Monday"],
        ["Tue", "Tuesday"],
        ["Wed", "Wednesday"],
        ["Thu", "Thursday"],
        ["Fri", "Friday"],
        ["Sat", "Saturday"]
      ];
      var months = [
        ["J", "Jan", "January"],
        ["F", "Feb", "February"],
        ["M", "Mar", "March"],
        ["A", "Apr", "April"],
        ["M", "May", "May"],
        ["J", "Jun", "June"],
        ["J", "Jul", "July"],
        ["A", "Aug", "August"],
        ["S", "Sep", "September"],
        ["O", "Oct", "October"],
        ["N", "Nov", "November"],
        ["D", "Dec", "December"]
      ];
      function SSF_init_table(t3) {
        if (!t3)
          t3 = {};
        t3[0] = "General";
        t3[1] = "0";
        t3[2] = "0.00";
        t3[3] = "#,##0";
        t3[4] = "#,##0.00";
        t3[9] = "0%";
        t3[10] = "0.00%";
        t3[11] = "0.00E+00";
        t3[12] = "# ?/?";
        t3[13] = "# ??/??";
        t3[14] = "m/d/yy";
        t3[15] = "d-mmm-yy";
        t3[16] = "d-mmm";
        t3[17] = "mmm-yy";
        t3[18] = "h:mm AM/PM";
        t3[19] = "h:mm:ss AM/PM";
        t3[20] = "h:mm";
        t3[21] = "h:mm:ss";
        t3[22] = "m/d/yy h:mm";
        t3[37] = "#,##0 ;(#,##0)";
        t3[38] = "#,##0 ;[Red](#,##0)";
        t3[39] = "#,##0.00;(#,##0.00)";
        t3[40] = "#,##0.00;[Red](#,##0.00)";
        t3[45] = "mm:ss";
        t3[46] = "[h]:mm:ss";
        t3[47] = "mmss.0";
        t3[48] = "##0.0E+0";
        t3[49] = "@";
        t3[56] = '"\u4E0A\u5348/\u4E0B\u5348 "hh"\u6642"mm"\u5206"ss"\u79D2 "';
        return t3;
      }
      var table_fmt = {
        0: "General",
        1: "0",
        2: "0.00",
        3: "#,##0",
        4: "#,##0.00",
        9: "0%",
        10: "0.00%",
        11: "0.00E+00",
        12: "# ?/?",
        13: "# ??/??",
        14: "m/d/yy",
        15: "d-mmm-yy",
        16: "d-mmm",
        17: "mmm-yy",
        18: "h:mm AM/PM",
        19: "h:mm:ss AM/PM",
        20: "h:mm",
        21: "h:mm:ss",
        22: "m/d/yy h:mm",
        37: "#,##0 ;(#,##0)",
        38: "#,##0 ;[Red](#,##0)",
        39: "#,##0.00;(#,##0.00)",
        40: "#,##0.00;[Red](#,##0.00)",
        45: "mm:ss",
        46: "[h]:mm:ss",
        47: "mmss.0",
        48: "##0.0E+0",
        49: "@",
        56: '"\u4E0A\u5348/\u4E0B\u5348 "hh"\u6642"mm"\u5206"ss"\u79D2 "'
      };
      var SSF_default_map = {
        5: 37,
        6: 38,
        7: 39,
        8: 40,
        //  5 -> 37 ...  8 -> 40
        23: 0,
        24: 0,
        25: 0,
        26: 0,
        // 23 ->  0 ... 26 ->  0
        27: 14,
        28: 14,
        29: 14,
        30: 14,
        31: 14,
        // 27 -> 14 ... 31 -> 14
        50: 14,
        51: 14,
        52: 14,
        53: 14,
        54: 14,
        // 50 -> 14 ... 58 -> 14
        55: 14,
        56: 14,
        57: 14,
        58: 14,
        59: 1,
        60: 2,
        61: 3,
        62: 4,
        // 59 ->  1 ... 62 ->  4
        67: 9,
        68: 10,
        // 67 ->  9 ... 68 -> 10
        69: 12,
        70: 13,
        71: 14,
        // 69 -> 12 ... 71 -> 14
        72: 14,
        73: 15,
        74: 16,
        75: 17,
        // 72 -> 14 ... 75 -> 17
        76: 20,
        77: 21,
        78: 22,
        // 76 -> 20 ... 78 -> 22
        79: 45,
        80: 46,
        81: 47,
        // 79 -> 45 ... 81 -> 47
        82: 0
        // 82 ->  0 ... 65536 -> 0 (omitted)
      };
      var SSF_default_str = {
        //  5 -- Currency,   0 decimal, black negative
        5: '"$"#,##0_);\\("$"#,##0\\)',
        63: '"$"#,##0_);\\("$"#,##0\\)',
        //  6 -- Currency,   0 decimal, red   negative
        6: '"$"#,##0_);[Red]\\("$"#,##0\\)',
        64: '"$"#,##0_);[Red]\\("$"#,##0\\)',
        //  7 -- Currency,   2 decimal, black negative
        7: '"$"#,##0.00_);\\("$"#,##0.00\\)',
        65: '"$"#,##0.00_);\\("$"#,##0.00\\)',
        //  8 -- Currency,   2 decimal, red   negative
        8: '"$"#,##0.00_);[Red]\\("$"#,##0.00\\)',
        66: '"$"#,##0.00_);[Red]\\("$"#,##0.00\\)',
        // 41 -- Accounting, 0 decimal, No Symbol
        41: '_(* #,##0_);_(* \\(#,##0\\);_(* "-"_);_(@_)',
        // 42 -- Accounting, 0 decimal, $  Symbol
        42: '_("$"* #,##0_);_("$"* \\(#,##0\\);_("$"* "-"_);_(@_)',
        // 43 -- Accounting, 2 decimal, No Symbol
        43: '_(* #,##0.00_);_(* \\(#,##0.00\\);_(* "-"??_);_(@_)',
        // 44 -- Accounting, 2 decimal, $  Symbol
        44: '_("$"* #,##0.00_);_("$"* \\(#,##0.00\\);_("$"* "-"??_);_(@_)'
      };
      function SSF_frac(x, D, mixed) {
        var sgn = x < 0 ? -1 : 1;
        var B = x * sgn;
        var P_2 = 0, P_1 = 1, P = 0;
        var Q_2 = 1, Q_1 = 0, Q = 0;
        var A = Math.floor(B);
        while (Q_1 < D) {
          A = Math.floor(B);
          P = A * P_1 + P_2;
          Q = A * Q_1 + Q_2;
          if (B - A < 5e-8)
            break;
          B = 1 / (B - A);
          P_2 = P_1;
          P_1 = P;
          Q_2 = Q_1;
          Q_1 = Q;
        }
        if (Q > D) {
          if (Q_1 > D) {
            Q = Q_2;
            P = P_2;
          } else {
            Q = Q_1;
            P = P_1;
          }
        }
        if (!mixed)
          return [0, sgn * P, Q];
        var q = Math.floor(sgn * P / Q);
        return [q, sgn * P - q * Q, Q];
      }
      function SSF_parse_date_code(v, opts, b2) {
        if (v > 2958465 || v < 0)
          return null;
        var date = v | 0, time = Math.floor(86400 * (v - date)), dow = 0;
        var dout = [];
        var out = { D: date, T: time, u: 86400 * (v - date) - time, y: 0, m: 0, d: 0, H: 0, M: 0, S: 0, q: 0 };
        if (Math.abs(out.u) < 1e-6)
          out.u = 0;
        if (opts && opts.date1904)
          date += 1462;
        if (out.u > 0.9999) {
          out.u = 0;
          if (++time == 86400) {
            out.T = time = 0;
            ++date;
            ++out.D;
          }
        }
        if (date === 60) {
          dout = b2 ? [1317, 10, 29] : [1900, 2, 29];
          dow = 3;
        } else if (date === 0) {
          dout = b2 ? [1317, 8, 29] : [1900, 1, 0];
          dow = 6;
        } else {
          if (date > 60)
            --date;
          var d = new Date(1900, 0, 1);
          d.setDate(d.getDate() + date - 1);
          dout = [d.getFullYear(), d.getMonth() + 1, d.getDate()];
          dow = d.getDay();
          if (date < 60)
            dow = (dow + 6) % 7;
          if (b2)
            dow = SSF_fix_hijri(d, dout);
        }
        out.y = dout[0];
        out.m = dout[1];
        out.d = dout[2];
        out.S = time % 60;
        time = Math.floor(time / 60);
        out.M = time % 60;
        time = Math.floor(time / 60);
        out.H = time;
        out.q = dow;
        return out;
      }
      var SSFbasedate = new Date(1899, 11, 31, 0, 0, 0);
      var SSFdnthresh = SSFbasedate.getTime();
      var SSFbase1904 = new Date(1900, 2, 1, 0, 0, 0);
      function datenum_local(v, date1904) {
        var epoch = v.getTime();
        if (date1904)
          epoch -= 1461 * 24 * 60 * 60 * 1e3;
        else if (v >= SSFbase1904)
          epoch += 24 * 60 * 60 * 1e3;
        return (epoch - (SSFdnthresh + (v.getTimezoneOffset() - SSFbasedate.getTimezoneOffset()) * 6e4)) / (24 * 60 * 60 * 1e3);
      }
      function SSF_strip_decimal(o) {
        return o.indexOf(".") == -1 ? o : o.replace(/(?:\.0*|(\.\d*[1-9])0+)$/, "$1");
      }
      function SSF_normalize_exp(o) {
        if (o.indexOf("E") == -1)
          return o;
        return o.replace(/(?:\.0*|(\.\d*[1-9])0+)[Ee]/, "$1E").replace(/(E[+-])(\d)$/, "$10$2");
      }
      function SSF_small_exp(v) {
        var w = v < 0 ? 12 : 11;
        var o = SSF_strip_decimal(v.toFixed(12));
        if (o.length <= w)
          return o;
        o = v.toPrecision(10);
        if (o.length <= w)
          return o;
        return v.toExponential(5);
      }
      function SSF_large_exp(v) {
        var o = SSF_strip_decimal(v.toFixed(11));
        return o.length > (v < 0 ? 12 : 11) || o === "0" || o === "-0" ? v.toPrecision(6) : o;
      }
      function SSF_general_num(v) {
        var V = Math.floor(Math.log(Math.abs(v)) * Math.LOG10E), o;
        if (V >= -4 && V <= -1)
          o = v.toPrecision(10 + V);
        else if (Math.abs(V) <= 9)
          o = SSF_small_exp(v);
        else if (V === 10)
          o = v.toFixed(10).substr(0, 12);
        else
          o = SSF_large_exp(v);
        return SSF_strip_decimal(SSF_normalize_exp(o.toUpperCase()));
      }
      function SSF_general(v, opts) {
        switch (typeof v) {
          case "string":
            return v;
          case "boolean":
            return v ? "TRUE" : "FALSE";
          case "number":
            return (v | 0) === v ? v.toString(10) : SSF_general_num(v);
          case "undefined":
            return "";
          case "object":
            if (v == null)
              return "";
            if (v instanceof Date)
              return SSF_format(14, datenum_local(v, opts && opts.date1904), opts);
        }
        throw new Error("unsupported value in General format: " + v);
      }
      function SSF_fix_hijri(date, o) {
        o[0] -= 581;
        var dow = date.getDay();
        if (date < 60)
          dow = (dow + 6) % 7;
        return dow;
      }
      function SSF_write_date(type, fmt, val, ss0) {
        var o = "", ss = 0, tt = 0, y = val.y, out, outl = 0;
        switch (type) {
          case 98:
            y = val.y + 543;
          case 121:
            switch (fmt.length) {
              case 1:
              case 2:
                out = y % 100;
                outl = 2;
                break;
              default:
                out = y % 1e4;
                outl = 4;
                break;
            }
            break;
          case 109:
            switch (fmt.length) {
              case 1:
              case 2:
                out = val.m;
                outl = fmt.length;
                break;
              case 3:
                return months[val.m - 1][1];
              case 5:
                return months[val.m - 1][0];
              default:
                return months[val.m - 1][2];
            }
            break;
          case 100:
            switch (fmt.length) {
              case 1:
              case 2:
                out = val.d;
                outl = fmt.length;
                break;
              case 3:
                return days[val.q][0];
              default:
                return days[val.q][1];
            }
            break;
          case 104:
            switch (fmt.length) {
              case 1:
              case 2:
                out = 1 + (val.H + 11) % 12;
                outl = fmt.length;
                break;
              default:
                throw "bad hour format: " + fmt;
            }
            break;
          case 72:
            switch (fmt.length) {
              case 1:
              case 2:
                out = val.H;
                outl = fmt.length;
                break;
              default:
                throw "bad hour format: " + fmt;
            }
            break;
          case 77:
            switch (fmt.length) {
              case 1:
              case 2:
                out = val.M;
                outl = fmt.length;
                break;
              default:
                throw "bad minute format: " + fmt;
            }
            break;
          case 115:
            if (fmt != "s" && fmt != "ss" && fmt != ".0" && fmt != ".00" && fmt != ".000")
              throw "bad second format: " + fmt;
            if (val.u === 0 && (fmt == "s" || fmt == "ss"))
              return pad0(val.S, fmt.length);
            if (ss0 >= 2)
              tt = ss0 === 3 ? 1e3 : 100;
            else
              tt = ss0 === 1 ? 10 : 1;
            ss = Math.round(tt * (val.S + val.u));
            if (ss >= 60 * tt)
              ss = 0;
            if (fmt === "s")
              return ss === 0 ? "0" : "" + ss / tt;
            o = pad0(ss, 2 + ss0);
            if (fmt === "ss")
              return o.substr(0, 2);
            return "." + o.substr(2, fmt.length - 1);
          case 90:
            switch (fmt) {
              case "[h]":
              case "[hh]":
                out = val.D * 24 + val.H;
                break;
              case "[m]":
              case "[mm]":
                out = (val.D * 24 + val.H) * 60 + val.M;
                break;
              case "[s]":
              case "[ss]":
                out = ((val.D * 24 + val.H) * 60 + val.M) * 60 + Math.round(val.S + val.u);
                break;
              default:
                throw "bad abstime format: " + fmt;
            }
            outl = fmt.length === 3 ? 1 : 2;
            break;
          case 101:
            out = y;
            outl = 1;
            break;
        }
        var outstr = outl > 0 ? pad0(out, outl) : "";
        return outstr;
      }
      function commaify(s) {
        var w = 3;
        if (s.length <= w)
          return s;
        var j = s.length % w, o = s.substr(0, j);
        for (; j != s.length; j += w)
          o += (o.length > 0 ? "," : "") + s.substr(j, w);
        return o;
      }
      var pct1 = /%/g;
      function write_num_pct(type, fmt, val) {
        var sfmt = fmt.replace(pct1, ""), mul = fmt.length - sfmt.length;
        return write_num(type, sfmt, val * Math.pow(10, 2 * mul)) + fill("%", mul);
      }
      function write_num_cm(type, fmt, val) {
        var idx = fmt.length - 1;
        while (fmt.charCodeAt(idx - 1) === 44)
          --idx;
        return write_num(type, fmt.substr(0, idx), val / Math.pow(10, 3 * (fmt.length - idx)));
      }
      function write_num_exp(fmt, val) {
        var o;
        var idx = fmt.indexOf("E") - fmt.indexOf(".") - 1;
        if (fmt.match(/^#+0.0E\+0$/)) {
          if (val == 0)
            return "0.0E+0";
          else if (val < 0)
            return "-" + write_num_exp(fmt, -val);
          var period = fmt.indexOf(".");
          if (period === -1)
            period = fmt.indexOf("E");
          var ee = Math.floor(Math.log(val) * Math.LOG10E) % period;
          if (ee < 0)
            ee += period;
          o = (val / Math.pow(10, ee)).toPrecision(idx + 1 + (period + ee) % period);
          if (o.indexOf("e") === -1) {
            var fakee = Math.floor(Math.log(val) * Math.LOG10E);
            if (o.indexOf(".") === -1)
              o = o.charAt(0) + "." + o.substr(1) + "E+" + (fakee - o.length + ee);
            else
              o += "E+" + (fakee - ee);
            while (o.substr(0, 2) === "0.") {
              o = o.charAt(0) + o.substr(2, period) + "." + o.substr(2 + period);
              o = o.replace(/^0+([1-9])/, "$1").replace(/^0+\./, "0.");
            }
            o = o.replace(/\+-/, "-");
          }
          o = o.replace(/^([+-]?)(\d*)\.(\d*)[Ee]/, function($$, $1, $2, $3) {
            return $1 + $2 + $3.substr(0, (period + ee) % period) + "." + $3.substr(ee) + "E";
          });
        } else
          o = val.toExponential(idx);
        if (fmt.match(/E\+00$/) && o.match(/e[+-]\d$/))
          o = o.substr(0, o.length - 1) + "0" + o.charAt(o.length - 1);
        if (fmt.match(/E\-/) && o.match(/e\+/))
          o = o.replace(/e\+/, "e");
        return o.replace("e", "E");
      }
      var frac1 = /# (\?+)( ?)\/( ?)(\d+)/;
      function write_num_f1(r, aval, sign) {
        var den = parseInt(r[4], 10), rr = Math.round(aval * den), base = Math.floor(rr / den);
        var myn = rr - base * den, myd = den;
        return sign + (base === 0 ? "" : "" + base) + " " + (myn === 0 ? fill(" ", r[1].length + 1 + r[4].length) : pad_(myn, r[1].length) + r[2] + "/" + r[3] + pad0(myd, r[4].length));
      }
      function write_num_f2(r, aval, sign) {
        return sign + (aval === 0 ? "" : "" + aval) + fill(" ", r[1].length + 2 + r[4].length);
      }
      var dec1 = /^#*0*\.([0#]+)/;
      var closeparen = /\).*[0#]/;
      var phone = /\(###\) ###\\?-####/;
      function hashq(str) {
        var o = "", cc;
        for (var i = 0; i != str.length; ++i)
          switch (cc = str.charCodeAt(i)) {
            case 35:
              break;
            case 63:
              o += " ";
              break;
            case 48:
              o += "0";
              break;
            default:
              o += String.fromCharCode(cc);
          }
        return o;
      }
      function rnd(val, d) {
        var dd = Math.pow(10, d);
        return "" + Math.round(val * dd) / dd;
      }
      function dec(val, d) {
        var _frac = val - Math.floor(val), dd = Math.pow(10, d);
        if (d < ("" + Math.round(_frac * dd)).length)
          return 0;
        return Math.round(_frac * dd);
      }
      function carry(val, d) {
        if (d < ("" + Math.round((val - Math.floor(val)) * Math.pow(10, d))).length) {
          return 1;
        }
        return 0;
      }
      function flr(val) {
        if (val < 2147483647 && val > -2147483648)
          return "" + (val >= 0 ? val | 0 : val - 1 | 0);
        return "" + Math.floor(val);
      }
      function write_num_flt(type, fmt, val) {
        if (type.charCodeAt(0) === 40 && !fmt.match(closeparen)) {
          var ffmt = fmt.replace(/\( */, "").replace(/ \)/, "").replace(/\)/, "");
          if (val >= 0)
            return write_num_flt("n", ffmt, val);
          return "(" + write_num_flt("n", ffmt, -val) + ")";
        }
        if (fmt.charCodeAt(fmt.length - 1) === 44)
          return write_num_cm(type, fmt, val);
        if (fmt.indexOf("%") !== -1)
          return write_num_pct(type, fmt, val);
        if (fmt.indexOf("E") !== -1)
          return write_num_exp(fmt, val);
        if (fmt.charCodeAt(0) === 36)
          return "$" + write_num_flt(type, fmt.substr(fmt.charAt(1) == " " ? 2 : 1), val);
        var o;
        var r, ri, ff, aval = Math.abs(val), sign = val < 0 ? "-" : "";
        if (fmt.match(/^00+$/))
          return sign + pad0r(aval, fmt.length);
        if (fmt.match(/^[#?]+$/)) {
          o = pad0r(val, 0);
          if (o === "0")
            o = "";
          return o.length > fmt.length ? o : hashq(fmt.substr(0, fmt.length - o.length)) + o;
        }
        if (r = fmt.match(frac1))
          return write_num_f1(r, aval, sign);
        if (fmt.match(/^#+0+$/))
          return sign + pad0r(aval, fmt.length - fmt.indexOf("0"));
        if (r = fmt.match(dec1)) {
          o = rnd(val, r[1].length).replace(/^([^\.]+)$/, "$1." + hashq(r[1])).replace(/\.$/, "." + hashq(r[1])).replace(/\.(\d*)$/, function($$, $1) {
            return "." + $1 + fill("0", hashq(r[1]).length - $1.length);
          });
          return fmt.indexOf("0.") !== -1 ? o : o.replace(/^0\./, ".");
        }
        fmt = fmt.replace(/^#+([0.])/, "$1");
        if (r = fmt.match(/^(0*)\.(#*)$/)) {
          return sign + rnd(aval, r[2].length).replace(/\.(\d*[1-9])0*$/, ".$1").replace(/^(-?\d*)$/, "$1.").replace(/^0\./, r[1].length ? "0." : ".");
        }
        if (r = fmt.match(/^#{1,3},##0(\.?)$/))
          return sign + commaify(pad0r(aval, 0));
        if (r = fmt.match(/^#,##0\.([#0]*0)$/)) {
          return val < 0 ? "-" + write_num_flt(type, fmt, -val) : commaify("" + (Math.floor(val) + carry(val, r[1].length))) + "." + pad0(dec(val, r[1].length), r[1].length);
        }
        if (r = fmt.match(/^#,#*,#0/))
          return write_num_flt(type, fmt.replace(/^#,#*,/, ""), val);
        if (r = fmt.match(/^([0#]+)(\\?-([0#]+))+$/)) {
          o = _strrev(write_num_flt(type, fmt.replace(/[\\-]/g, ""), val));
          ri = 0;
          return _strrev(_strrev(fmt.replace(/\\/g, "")).replace(/[0#]/g, function(x2) {
            return ri < o.length ? o.charAt(ri++) : x2 === "0" ? "0" : "";
          }));
        }
        if (fmt.match(phone)) {
          o = write_num_flt(type, "##########", val);
          return "(" + o.substr(0, 3) + ") " + o.substr(3, 3) + "-" + o.substr(6);
        }
        var oa = "";
        if (r = fmt.match(/^([#0?]+)( ?)\/( ?)([#0?]+)/)) {
          ri = Math.min(r[4].length, 7);
          ff = SSF_frac(aval, Math.pow(10, ri) - 1, false);
          o = "" + sign;
          oa = write_num("n", r[1], ff[1]);
          if (oa.charAt(oa.length - 1) == " ")
            oa = oa.substr(0, oa.length - 1) + "0";
          o += oa + r[2] + "/" + r[3];
          oa = rpad_(ff[2], ri);
          if (oa.length < r[4].length)
            oa = hashq(r[4].substr(r[4].length - oa.length)) + oa;
          o += oa;
          return o;
        }
        if (r = fmt.match(/^# ([#0?]+)( ?)\/( ?)([#0?]+)/)) {
          ri = Math.min(Math.max(r[1].length, r[4].length), 7);
          ff = SSF_frac(aval, Math.pow(10, ri) - 1, true);
          return sign + (ff[0] || (ff[1] ? "" : "0")) + " " + (ff[1] ? pad_(ff[1], ri) + r[2] + "/" + r[3] + rpad_(ff[2], ri) : fill(" ", 2 * ri + 1 + r[2].length + r[3].length));
        }
        if (r = fmt.match(/^[#0?]+$/)) {
          o = pad0r(val, 0);
          if (fmt.length <= o.length)
            return o;
          return hashq(fmt.substr(0, fmt.length - o.length)) + o;
        }
        if (r = fmt.match(/^([#0?]+)\.([#0]+)$/)) {
          o = "" + val.toFixed(Math.min(r[2].length, 10)).replace(/([^0])0+$/, "$1");
          ri = o.indexOf(".");
          var lres = fmt.indexOf(".") - ri, rres = fmt.length - o.length - lres;
          return hashq(fmt.substr(0, lres) + o + fmt.substr(fmt.length - rres));
        }
        if (r = fmt.match(/^00,000\.([#0]*0)$/)) {
          ri = dec(val, r[1].length);
          return val < 0 ? "-" + write_num_flt(type, fmt, -val) : commaify(flr(val)).replace(/^\d,\d{3}$/, "0$&").replace(/^\d*$/, function($$) {
            return "00," + ($$.length < 3 ? pad0(0, 3 - $$.length) : "") + $$;
          }) + "." + pad0(ri, r[1].length);
        }
        switch (fmt) {
          case "###,##0.00":
            return write_num_flt(type, "#,##0.00", val);
          case "###,###":
          case "##,###":
          case "#,###":
            var x = commaify(pad0r(aval, 0));
            return x !== "0" ? sign + x : "";
          case "###,###.00":
            return write_num_flt(type, "###,##0.00", val).replace(/^0\./, ".");
          case "#,###.00":
            return write_num_flt(type, "#,##0.00", val).replace(/^0\./, ".");
          default:
        }
        throw new Error("unsupported format |" + fmt + "|");
      }
      function write_num_cm2(type, fmt, val) {
        var idx = fmt.length - 1;
        while (fmt.charCodeAt(idx - 1) === 44)
          --idx;
        return write_num(type, fmt.substr(0, idx), val / Math.pow(10, 3 * (fmt.length - idx)));
      }
      function write_num_pct2(type, fmt, val) {
        var sfmt = fmt.replace(pct1, ""), mul = fmt.length - sfmt.length;
        return write_num(type, sfmt, val * Math.pow(10, 2 * mul)) + fill("%", mul);
      }
      function write_num_exp2(fmt, val) {
        var o;
        var idx = fmt.indexOf("E") - fmt.indexOf(".") - 1;
        if (fmt.match(/^#+0.0E\+0$/)) {
          if (val == 0)
            return "0.0E+0";
          else if (val < 0)
            return "-" + write_num_exp2(fmt, -val);
          var period = fmt.indexOf(".");
          if (period === -1)
            period = fmt.indexOf("E");
          var ee = Math.floor(Math.log(val) * Math.LOG10E) % period;
          if (ee < 0)
            ee += period;
          o = (val / Math.pow(10, ee)).toPrecision(idx + 1 + (period + ee) % period);
          if (!o.match(/[Ee]/)) {
            var fakee = Math.floor(Math.log(val) * Math.LOG10E);
            if (o.indexOf(".") === -1)
              o = o.charAt(0) + "." + o.substr(1) + "E+" + (fakee - o.length + ee);
            else
              o += "E+" + (fakee - ee);
            o = o.replace(/\+-/, "-");
          }
          o = o.replace(/^([+-]?)(\d*)\.(\d*)[Ee]/, function($$, $1, $2, $3) {
            return $1 + $2 + $3.substr(0, (period + ee) % period) + "." + $3.substr(ee) + "E";
          });
        } else
          o = val.toExponential(idx);
        if (fmt.match(/E\+00$/) && o.match(/e[+-]\d$/))
          o = o.substr(0, o.length - 1) + "0" + o.charAt(o.length - 1);
        if (fmt.match(/E\-/) && o.match(/e\+/))
          o = o.replace(/e\+/, "e");
        return o.replace("e", "E");
      }
      function write_num_int(type, fmt, val) {
        if (type.charCodeAt(0) === 40 && !fmt.match(closeparen)) {
          var ffmt = fmt.replace(/\( */, "").replace(/ \)/, "").replace(/\)/, "");
          if (val >= 0)
            return write_num_int("n", ffmt, val);
          return "(" + write_num_int("n", ffmt, -val) + ")";
        }
        if (fmt.charCodeAt(fmt.length - 1) === 44)
          return write_num_cm2(type, fmt, val);
        if (fmt.indexOf("%") !== -1)
          return write_num_pct2(type, fmt, val);
        if (fmt.indexOf("E") !== -1)
          return write_num_exp2(fmt, val);
        if (fmt.charCodeAt(0) === 36)
          return "$" + write_num_int(type, fmt.substr(fmt.charAt(1) == " " ? 2 : 1), val);
        var o;
        var r, ri, ff, aval = Math.abs(val), sign = val < 0 ? "-" : "";
        if (fmt.match(/^00+$/))
          return sign + pad0(aval, fmt.length);
        if (fmt.match(/^[#?]+$/)) {
          o = "" + val;
          if (val === 0)
            o = "";
          return o.length > fmt.length ? o : hashq(fmt.substr(0, fmt.length - o.length)) + o;
        }
        if (r = fmt.match(frac1))
          return write_num_f2(r, aval, sign);
        if (fmt.match(/^#+0+$/))
          return sign + pad0(aval, fmt.length - fmt.indexOf("0"));
        if (r = fmt.match(dec1)) {
          o = ("" + val).replace(/^([^\.]+)$/, "$1." + hashq(r[1])).replace(/\.$/, "." + hashq(r[1]));
          o = o.replace(/\.(\d*)$/, function($$, $1) {
            return "." + $1 + fill("0", hashq(r[1]).length - $1.length);
          });
          return fmt.indexOf("0.") !== -1 ? o : o.replace(/^0\./, ".");
        }
        fmt = fmt.replace(/^#+([0.])/, "$1");
        if (r = fmt.match(/^(0*)\.(#*)$/)) {
          return sign + ("" + aval).replace(/\.(\d*[1-9])0*$/, ".$1").replace(/^(-?\d*)$/, "$1.").replace(/^0\./, r[1].length ? "0." : ".");
        }
        if (r = fmt.match(/^#{1,3},##0(\.?)$/))
          return sign + commaify("" + aval);
        if (r = fmt.match(/^#,##0\.([#0]*0)$/)) {
          return val < 0 ? "-" + write_num_int(type, fmt, -val) : commaify("" + val) + "." + fill("0", r[1].length);
        }
        if (r = fmt.match(/^#,#*,#0/))
          return write_num_int(type, fmt.replace(/^#,#*,/, ""), val);
        if (r = fmt.match(/^([0#]+)(\\?-([0#]+))+$/)) {
          o = _strrev(write_num_int(type, fmt.replace(/[\\-]/g, ""), val));
          ri = 0;
          return _strrev(_strrev(fmt.replace(/\\/g, "")).replace(/[0#]/g, function(x2) {
            return ri < o.length ? o.charAt(ri++) : x2 === "0" ? "0" : "";
          }));
        }
        if (fmt.match(phone)) {
          o = write_num_int(type, "##########", val);
          return "(" + o.substr(0, 3) + ") " + o.substr(3, 3) + "-" + o.substr(6);
        }
        var oa = "";
        if (r = fmt.match(/^([#0?]+)( ?)\/( ?)([#0?]+)/)) {
          ri = Math.min(r[4].length, 7);
          ff = SSF_frac(aval, Math.pow(10, ri) - 1, false);
          o = "" + sign;
          oa = write_num("n", r[1], ff[1]);
          if (oa.charAt(oa.length - 1) == " ")
            oa = oa.substr(0, oa.length - 1) + "0";
          o += oa + r[2] + "/" + r[3];
          oa = rpad_(ff[2], ri);
          if (oa.length < r[4].length)
            oa = hashq(r[4].substr(r[4].length - oa.length)) + oa;
          o += oa;
          return o;
        }
        if (r = fmt.match(/^# ([#0?]+)( ?)\/( ?)([#0?]+)/)) {
          ri = Math.min(Math.max(r[1].length, r[4].length), 7);
          ff = SSF_frac(aval, Math.pow(10, ri) - 1, true);
          return sign + (ff[0] || (ff[1] ? "" : "0")) + " " + (ff[1] ? pad_(ff[1], ri) + r[2] + "/" + r[3] + rpad_(ff[2], ri) : fill(" ", 2 * ri + 1 + r[2].length + r[3].length));
        }
        if (r = fmt.match(/^[#0?]+$/)) {
          o = "" + val;
          if (fmt.length <= o.length)
            return o;
          return hashq(fmt.substr(0, fmt.length - o.length)) + o;
        }
        if (r = fmt.match(/^([#0]+)\.([#0]+)$/)) {
          o = "" + val.toFixed(Math.min(r[2].length, 10)).replace(/([^0])0+$/, "$1");
          ri = o.indexOf(".");
          var lres = fmt.indexOf(".") - ri, rres = fmt.length - o.length - lres;
          return hashq(fmt.substr(0, lres) + o + fmt.substr(fmt.length - rres));
        }
        if (r = fmt.match(/^00,000\.([#0]*0)$/)) {
          return val < 0 ? "-" + write_num_int(type, fmt, -val) : commaify("" + val).replace(/^\d,\d{3}$/, "0$&").replace(/^\d*$/, function($$) {
            return "00," + ($$.length < 3 ? pad0(0, 3 - $$.length) : "") + $$;
          }) + "." + pad0(0, r[1].length);
        }
        switch (fmt) {
          case "###,###":
          case "##,###":
          case "#,###":
            var x = commaify("" + aval);
            return x !== "0" ? sign + x : "";
          default:
            if (fmt.match(/\.[0#?]*$/))
              return write_num_int(type, fmt.slice(0, fmt.lastIndexOf(".")), val) + hashq(fmt.slice(fmt.lastIndexOf(".")));
        }
        throw new Error("unsupported format |" + fmt + "|");
      }
      function write_num(type, fmt, val) {
        return (val | 0) === val ? write_num_int(type, fmt, val) : write_num_flt(type, fmt, val);
      }
      function SSF_split_fmt(fmt) {
        var out = [];
        var in_str = false;
        for (var i = 0, j = 0; i < fmt.length; ++i)
          switch (
            /*cc=*/
            fmt.charCodeAt(i)
          ) {
            case 34:
              in_str = !in_str;
              break;
            case 95:
            case 42:
            case 92:
              ++i;
              break;
            case 59:
              out[out.length] = fmt.substr(j, i - j);
              j = i + 1;
          }
        out[out.length] = fmt.substr(j);
        if (in_str === true)
          throw new Error("Format |" + fmt + "| unterminated string ");
        return out;
      }
      var SSF_abstime = /\[[HhMmSs\u0E0A\u0E19\u0E17]*\]/;
      function fmt_is_date(fmt) {
        var i = 0, c = "", o = "";
        while (i < fmt.length) {
          switch (c = fmt.charAt(i)) {
            case "G":
              if (SSF_isgeneral(fmt, i))
                i += 6;
              i++;
              break;
            case '"':
              for (
                ;
                /*cc=*/
                fmt.charCodeAt(++i) !== 34 && i < fmt.length;
              ) {
              }
              ++i;
              break;
            case "\\":
              i += 2;
              break;
            case "_":
              i += 2;
              break;
            case "@":
              ++i;
              break;
            case "B":
            case "b":
              if (fmt.charAt(i + 1) === "1" || fmt.charAt(i + 1) === "2")
                return true;
            case "M":
            case "D":
            case "Y":
            case "H":
            case "S":
            case "E":
            case "m":
            case "d":
            case "y":
            case "h":
            case "s":
            case "e":
            case "g":
              return true;
            case "A":
            case "a":
            case "\u4E0A":
              if (fmt.substr(i, 3).toUpperCase() === "A/P")
                return true;
              if (fmt.substr(i, 5).toUpperCase() === "AM/PM")
                return true;
              if (fmt.substr(i, 5).toUpperCase() === "\u4E0A\u5348/\u4E0B\u5348")
                return true;
              ++i;
              break;
            case "[":
              o = c;
              while (fmt.charAt(i++) !== "]" && i < fmt.length)
                o += fmt.charAt(i);
              if (o.match(SSF_abstime))
                return true;
              break;
            case ".":
            case "0":
            case "#":
              while (i < fmt.length && ("0#?.,E+-%".indexOf(c = fmt.charAt(++i)) > -1 || c == "\\" && fmt.charAt(i + 1) == "-" && "0#".indexOf(fmt.charAt(i + 2)) > -1)) {
              }
              break;
            case "?":
              while (fmt.charAt(++i) === c) {
              }
              break;
            case "*":
              ++i;
              if (fmt.charAt(i) == " " || fmt.charAt(i) == "*")
                ++i;
              break;
            case "(":
            case ")":
              ++i;
              break;
            case "1":
            case "2":
            case "3":
            case "4":
            case "5":
            case "6":
            case "7":
            case "8":
            case "9":
              while (i < fmt.length && "0123456789".indexOf(fmt.charAt(++i)) > -1) {
              }
              break;
            case " ":
              ++i;
              break;
            default:
              ++i;
              break;
          }
        }
        return false;
      }
      function eval_fmt(fmt, v, opts, flen) {
        var out = [], o = "", i = 0, c = "", lst = "t", dt, j, cc;
        var hr = "H";
        while (i < fmt.length) {
          switch (c = fmt.charAt(i)) {
            case "G":
              if (!SSF_isgeneral(fmt, i))
                throw new Error("unrecognized character " + c + " in " + fmt);
              out[out.length] = { t: "G", v: "General" };
              i += 7;
              break;
            case '"':
              for (o = ""; (cc = fmt.charCodeAt(++i)) !== 34 && i < fmt.length; )
                o += String.fromCharCode(cc);
              out[out.length] = { t: "t", v: o };
              ++i;
              break;
            case "\\":
              var w = fmt.charAt(++i), t3 = w === "(" || w === ")" ? w : "t";
              out[out.length] = { t: t3, v: w };
              ++i;
              break;
            case "_":
              out[out.length] = { t: "t", v: " " };
              i += 2;
              break;
            case "@":
              out[out.length] = { t: "T", v };
              ++i;
              break;
            case "B":
            case "b":
              if (fmt.charAt(i + 1) === "1" || fmt.charAt(i + 1) === "2") {
                if (dt == null) {
                  dt = SSF_parse_date_code(v, opts, fmt.charAt(i + 1) === "2");
                  if (dt == null)
                    return "";
                }
                out[out.length] = { t: "X", v: fmt.substr(i, 2) };
                lst = c;
                i += 2;
                break;
              }
            case "M":
            case "D":
            case "Y":
            case "H":
            case "S":
            case "E":
              c = c.toLowerCase();
            case "m":
            case "d":
            case "y":
            case "h":
            case "s":
            case "e":
            case "g":
              if (v < 0)
                return "";
              if (dt == null) {
                dt = SSF_parse_date_code(v, opts);
                if (dt == null)
                  return "";
              }
              o = c;
              while (++i < fmt.length && fmt.charAt(i).toLowerCase() === c)
                o += c;
              if (c === "m" && lst.toLowerCase() === "h")
                c = "M";
              if (c === "h")
                c = hr;
              out[out.length] = { t: c, v: o };
              lst = c;
              break;
            case "A":
            case "a":
            case "\u4E0A":
              var q = { t: c, v: c };
              if (dt == null)
                dt = SSF_parse_date_code(v, opts);
              if (fmt.substr(i, 3).toUpperCase() === "A/P") {
                if (dt != null)
                  q.v = dt.H >= 12 ? "P" : "A";
                q.t = "T";
                hr = "h";
                i += 3;
              } else if (fmt.substr(i, 5).toUpperCase() === "AM/PM") {
                if (dt != null)
                  q.v = dt.H >= 12 ? "PM" : "AM";
                q.t = "T";
                i += 5;
                hr = "h";
              } else if (fmt.substr(i, 5).toUpperCase() === "\u4E0A\u5348/\u4E0B\u5348") {
                if (dt != null)
                  q.v = dt.H >= 12 ? "\u4E0B\u5348" : "\u4E0A\u5348";
                q.t = "T";
                i += 5;
                hr = "h";
              } else {
                q.t = "t";
                ++i;
              }
              if (dt == null && q.t === "T")
                return "";
              out[out.length] = q;
              lst = c;
              break;
            case "[":
              o = c;
              while (fmt.charAt(i++) !== "]" && i < fmt.length)
                o += fmt.charAt(i);
              if (o.slice(-1) !== "]")
                throw 'unterminated "[" block: |' + o + "|";
              if (o.match(SSF_abstime)) {
                if (dt == null) {
                  dt = SSF_parse_date_code(v, opts);
                  if (dt == null)
                    return "";
                }
                out[out.length] = { t: "Z", v: o.toLowerCase() };
                lst = o.charAt(1);
              } else if (o.indexOf("$") > -1) {
                o = (o.match(/\$([^-\[\]]*)/) || [])[1] || "$";
                if (!fmt_is_date(fmt))
                  out[out.length] = { t: "t", v: o };
              }
              break;
            case ".":
              if (dt != null) {
                o = c;
                while (++i < fmt.length && (c = fmt.charAt(i)) === "0")
                  o += c;
                out[out.length] = { t: "s", v: o };
                break;
              }
            case "0":
            case "#":
              o = c;
              while (++i < fmt.length && "0#?.,E+-%".indexOf(c = fmt.charAt(i)) > -1)
                o += c;
              out[out.length] = { t: "n", v: o };
              break;
            case "?":
              o = c;
              while (fmt.charAt(++i) === c)
                o += c;
              out[out.length] = { t: c, v: o };
              lst = c;
              break;
            case "*":
              ++i;
              if (fmt.charAt(i) == " " || fmt.charAt(i) == "*")
                ++i;
              break;
            case "(":
            case ")":
              out[out.length] = { t: flen === 1 ? "t" : c, v: c };
              ++i;
              break;
            case "1":
            case "2":
            case "3":
            case "4":
            case "5":
            case "6":
            case "7":
            case "8":
            case "9":
              o = c;
              while (i < fmt.length && "0123456789".indexOf(fmt.charAt(++i)) > -1)
                o += fmt.charAt(i);
              out[out.length] = { t: "D", v: o };
              break;
            case " ":
              out[out.length] = { t: c, v: c };
              ++i;
              break;
            case "$":
              out[out.length] = { t: "t", v: "$" };
              ++i;
              break;
            default:
              if (",$-+/():!^&'~{}<>=\u20ACacfijklopqrtuvwxzP".indexOf(c) === -1)
                throw new Error("unrecognized character " + c + " in " + fmt);
              out[out.length] = { t: "t", v: c };
              ++i;
              break;
          }
        }
        var bt = 0, ss0 = 0, ssm;
        for (i = out.length - 1, lst = "t"; i >= 0; --i) {
          switch (out[i].t) {
            case "h":
            case "H":
              out[i].t = hr;
              lst = "h";
              if (bt < 1)
                bt = 1;
              break;
            case "s":
              if (ssm = out[i].v.match(/\.0+$/))
                ss0 = Math.max(ss0, ssm[0].length - 1);
              if (bt < 3)
                bt = 3;
            case "d":
            case "y":
            case "M":
            case "e":
              lst = out[i].t;
              break;
            case "m":
              if (lst === "s") {
                out[i].t = "M";
                if (bt < 2)
                  bt = 2;
              }
              break;
            case "X":
              break;
            case "Z":
              if (bt < 1 && out[i].v.match(/[Hh]/))
                bt = 1;
              if (bt < 2 && out[i].v.match(/[Mm]/))
                bt = 2;
              if (bt < 3 && out[i].v.match(/[Ss]/))
                bt = 3;
          }
        }
        switch (bt) {
          case 0:
            break;
          case 1:
            if (dt.u >= 0.5) {
              dt.u = 0;
              ++dt.S;
            }
            if (dt.S >= 60) {
              dt.S = 0;
              ++dt.M;
            }
            if (dt.M >= 60) {
              dt.M = 0;
              ++dt.H;
            }
            break;
          case 2:
            if (dt.u >= 0.5) {
              dt.u = 0;
              ++dt.S;
            }
            if (dt.S >= 60) {
              dt.S = 0;
              ++dt.M;
            }
            break;
        }
        var nstr = "", jj;
        for (i = 0; i < out.length; ++i) {
          switch (out[i].t) {
            case "t":
            case "T":
            case " ":
            case "D":
              break;
            case "X":
              out[i].v = "";
              out[i].t = ";";
              break;
            case "d":
            case "m":
            case "y":
            case "h":
            case "H":
            case "M":
            case "s":
            case "e":
            case "b":
            case "Z":
              out[i].v = SSF_write_date(out[i].t.charCodeAt(0), out[i].v, dt, ss0);
              out[i].t = "t";
              break;
            case "n":
            case "?":
              jj = i + 1;
              while (out[jj] != null && ((c = out[jj].t) === "?" || c === "D" || (c === " " || c === "t") && out[jj + 1] != null && (out[jj + 1].t === "?" || out[jj + 1].t === "t" && out[jj + 1].v === "/") || out[i].t === "(" && (c === " " || c === "n" || c === ")") || c === "t" && (out[jj].v === "/" || out[jj].v === " " && out[jj + 1] != null && out[jj + 1].t == "?"))) {
                out[i].v += out[jj].v;
                out[jj] = { v: "", t: ";" };
                ++jj;
              }
              nstr += out[i].v;
              i = jj - 1;
              break;
            case "G":
              out[i].t = "t";
              out[i].v = SSF_general(v, opts);
              break;
          }
        }
        var vv = "", myv, ostr;
        if (nstr.length > 0) {
          if (nstr.charCodeAt(0) == 40) {
            myv = v < 0 && nstr.charCodeAt(0) === 45 ? -v : v;
            ostr = write_num("n", nstr, myv);
          } else {
            myv = v < 0 && flen > 1 ? -v : v;
            ostr = write_num("n", nstr, myv);
            if (myv < 0 && out[0] && out[0].t == "t") {
              ostr = ostr.substr(1);
              out[0].v = "-" + out[0].v;
            }
          }
          jj = ostr.length - 1;
          var decpt = out.length;
          for (i = 0; i < out.length; ++i)
            if (out[i] != null && out[i].t != "t" && out[i].v.indexOf(".") > -1) {
              decpt = i;
              break;
            }
          var lasti = out.length;
          if (decpt === out.length && ostr.indexOf("E") === -1) {
            for (i = out.length - 1; i >= 0; --i) {
              if (out[i] == null || "n?".indexOf(out[i].t) === -1)
                continue;
              if (jj >= out[i].v.length - 1) {
                jj -= out[i].v.length;
                out[i].v = ostr.substr(jj + 1, out[i].v.length);
              } else if (jj < 0)
                out[i].v = "";
              else {
                out[i].v = ostr.substr(0, jj + 1);
                jj = -1;
              }
              out[i].t = "t";
              lasti = i;
            }
            if (jj >= 0 && lasti < out.length)
              out[lasti].v = ostr.substr(0, jj + 1) + out[lasti].v;
          } else if (decpt !== out.length && ostr.indexOf("E") === -1) {
            jj = ostr.indexOf(".") - 1;
            for (i = decpt; i >= 0; --i) {
              if (out[i] == null || "n?".indexOf(out[i].t) === -1)
                continue;
              j = out[i].v.indexOf(".") > -1 && i === decpt ? out[i].v.indexOf(".") - 1 : out[i].v.length - 1;
              vv = out[i].v.substr(j + 1);
              for (; j >= 0; --j) {
                if (jj >= 0 && (out[i].v.charAt(j) === "0" || out[i].v.charAt(j) === "#"))
                  vv = ostr.charAt(jj--) + vv;
              }
              out[i].v = vv;
              out[i].t = "t";
              lasti = i;
            }
            if (jj >= 0 && lasti < out.length)
              out[lasti].v = ostr.substr(0, jj + 1) + out[lasti].v;
            jj = ostr.indexOf(".") + 1;
            for (i = decpt; i < out.length; ++i) {
              if (out[i] == null || "n?(".indexOf(out[i].t) === -1 && i !== decpt)
                continue;
              j = out[i].v.indexOf(".") > -1 && i === decpt ? out[i].v.indexOf(".") + 1 : 0;
              vv = out[i].v.substr(0, j);
              for (; j < out[i].v.length; ++j) {
                if (jj < ostr.length)
                  vv += ostr.charAt(jj++);
              }
              out[i].v = vv;
              out[i].t = "t";
              lasti = i;
            }
          }
        }
        for (i = 0; i < out.length; ++i)
          if (out[i] != null && "n?".indexOf(out[i].t) > -1) {
            myv = flen > 1 && v < 0 && i > 0 && out[i - 1].v === "-" ? -v : v;
            out[i].v = write_num(out[i].t, out[i].v, myv);
            out[i].t = "t";
          }
        var retval = "";
        for (i = 0; i !== out.length; ++i)
          if (out[i] != null)
            retval += out[i].v;
        return retval;
      }
      var cfregex2 = /\[(=|>[=]?|<[>=]?)(-?\d+(?:\.\d*)?)\]/;
      function chkcond(v, rr) {
        if (rr == null)
          return false;
        var thresh = parseFloat(rr[2]);
        switch (rr[1]) {
          case "=":
            if (v == thresh)
              return true;
            break;
          case ">":
            if (v > thresh)
              return true;
            break;
          case "<":
            if (v < thresh)
              return true;
            break;
          case "<>":
            if (v != thresh)
              return true;
            break;
          case ">=":
            if (v >= thresh)
              return true;
            break;
          case "<=":
            if (v <= thresh)
              return true;
            break;
        }
        return false;
      }
      function choose_fmt(f, v) {
        var fmt = SSF_split_fmt(f);
        var l = fmt.length, lat = fmt[l - 1].indexOf("@");
        if (l < 4 && lat > -1)
          --l;
        if (fmt.length > 4)
          throw new Error("cannot find right format for |" + fmt.join("|") + "|");
        if (typeof v !== "number")
          return [4, fmt.length === 4 || lat > -1 ? fmt[fmt.length - 1] : "@"];
        switch (fmt.length) {
          case 1:
            fmt = lat > -1 ? ["General", "General", "General", fmt[0]] : [fmt[0], fmt[0], fmt[0], "@"];
            break;
          case 2:
            fmt = lat > -1 ? [fmt[0], fmt[0], fmt[0], fmt[1]] : [fmt[0], fmt[1], fmt[0], "@"];
            break;
          case 3:
            fmt = lat > -1 ? [fmt[0], fmt[1], fmt[0], fmt[2]] : [fmt[0], fmt[1], fmt[2], "@"];
            break;
          case 4:
            break;
        }
        var ff = v > 0 ? fmt[0] : v < 0 ? fmt[1] : fmt[2];
        if (fmt[0].indexOf("[") === -1 && fmt[1].indexOf("[") === -1)
          return [l, ff];
        if (fmt[0].match(/\[[=<>]/) != null || fmt[1].match(/\[[=<>]/) != null) {
          var m1 = fmt[0].match(cfregex2);
          var m2 = fmt[1].match(cfregex2);
          return chkcond(v, m1) ? [l, fmt[0]] : chkcond(v, m2) ? [l, fmt[1]] : [l, fmt[m1 != null && m2 != null ? 2 : 1]];
        }
        return [l, ff];
      }
      function SSF_format(fmt, v, o) {
        if (o == null)
          o = {};
        var sfmt = "";
        switch (typeof fmt) {
          case "string":
            if (fmt == "m/d/yy" && o.dateNF)
              sfmt = o.dateNF;
            else
              sfmt = fmt;
            break;
          case "number":
            if (fmt == 14 && o.dateNF)
              sfmt = o.dateNF;
            else
              sfmt = (o.table != null ? o.table : table_fmt)[fmt];
            if (sfmt == null)
              sfmt = o.table && o.table[SSF_default_map[fmt]] || table_fmt[SSF_default_map[fmt]];
            if (sfmt == null)
              sfmt = SSF_default_str[fmt] || "General";
            break;
        }
        if (SSF_isgeneral(sfmt, 0))
          return SSF_general(v, o);
        if (v instanceof Date)
          v = datenum_local(v, o.date1904);
        var f = choose_fmt(sfmt, v);
        if (SSF_isgeneral(f[1]))
          return SSF_general(v, o);
        if (v === true)
          v = "TRUE";
        else if (v === false)
          v = "FALSE";
        else if (v === "" || v == null)
          return "";
        return eval_fmt(f[1], v, o, f[0]);
      }
      function SSF_load(fmt, idx) {
        if (typeof idx != "number") {
          idx = +idx || -1;
          for (var i = 0; i < 392; ++i) {
            if (table_fmt[i] == void 0) {
              if (idx < 0)
                idx = i;
              continue;
            }
            if (table_fmt[i] == fmt) {
              idx = i;
              break;
            }
          }
          if (idx < 0)
            idx = 391;
        }
        table_fmt[idx] = fmt;
        return idx;
      }
      function SSF_load_table(tbl) {
        for (var i = 0; i != 392; ++i)
          if (tbl[i] !== void 0)
            SSF_load(tbl[i], i);
      }
      function make_ssf() {
        table_fmt = SSF_init_table();
      }
      var SSF = {
        format: SSF_format,
        load: SSF_load,
        _table: table_fmt,
        load_table: SSF_load_table,
        parse_date_code: SSF_parse_date_code,
        is_date: fmt_is_date,
        get_table: function get_table() {
          return SSF._table = table_fmt;
        }
      };
      var SSFImplicit = {
        "5": '"$"#,##0_);\\("$"#,##0\\)',
        "6": '"$"#,##0_);[Red]\\("$"#,##0\\)',
        "7": '"$"#,##0.00_);\\("$"#,##0.00\\)',
        "8": '"$"#,##0.00_);[Red]\\("$"#,##0.00\\)',
        "23": "General",
        "24": "General",
        "25": "General",
        "26": "General",
        "27": "m/d/yy",
        "28": "m/d/yy",
        "29": "m/d/yy",
        "30": "m/d/yy",
        "31": "m/d/yy",
        "32": "h:mm:ss",
        "33": "h:mm:ss",
        "34": "h:mm:ss",
        "35": "h:mm:ss",
        "36": "m/d/yy",
        "41": '_(* #,##0_);_(* (#,##0);_(* "-"_);_(@_)',
        "42": '_("$"* #,##0_);_("$"* (#,##0);_("$"* "-"_);_(@_)',
        "43": '_(* #,##0.00_);_(* (#,##0.00);_(* "-"??_);_(@_)',
        "44": '_("$"* #,##0.00_);_("$"* (#,##0.00);_("$"* "-"??_);_(@_)',
        "50": "m/d/yy",
        "51": "m/d/yy",
        "52": "m/d/yy",
        "53": "m/d/yy",
        "54": "m/d/yy",
        "55": "m/d/yy",
        "56": "m/d/yy",
        "57": "m/d/yy",
        "58": "m/d/yy",
        "59": "0",
        "60": "0.00",
        "61": "#,##0",
        "62": "#,##0.00",
        "63": '"$"#,##0_);\\("$"#,##0\\)',
        "64": '"$"#,##0_);[Red]\\("$"#,##0\\)',
        "65": '"$"#,##0.00_);\\("$"#,##0.00\\)',
        "66": '"$"#,##0.00_);[Red]\\("$"#,##0.00\\)',
        "67": "0%",
        "68": "0.00%",
        "69": "# ?/?",
        "70": "# ??/??",
        "71": "m/d/yy",
        "72": "m/d/yy",
        "73": "d-mmm-yy",
        "74": "d-mmm",
        "75": "mmm-yy",
        "76": "h:mm",
        "77": "h:mm:ss",
        "78": "m/d/yy h:mm",
        "79": "mm:ss",
        "80": "[h]:mm:ss",
        "81": "mmss.0"
      };
      var dateNFregex = /[dD]+|[mM]+|[yYeE]+|[Hh]+|[Ss]+/g;
      function dateNF_regex(dateNF) {
        var fmt = typeof dateNF == "number" ? table_fmt[dateNF] : dateNF;
        fmt = fmt.replace(dateNFregex, "(\\d+)");
        return new RegExp("^" + fmt + "$");
      }
      function dateNF_fix(str, dateNF, match) {
        var Y = -1, m = -1, d = -1, H = -1, M = -1, S = -1;
        (dateNF.match(dateNFregex) || []).forEach(function(n, i) {
          var v = parseInt(match[i + 1], 10);
          switch (n.toLowerCase().charAt(0)) {
            case "y":
              Y = v;
              break;
            case "d":
              d = v;
              break;
            case "h":
              H = v;
              break;
            case "s":
              S = v;
              break;
            case "m":
              if (H >= 0)
                M = v;
              else
                m = v;
              break;
          }
        });
        if (S >= 0 && M == -1 && m >= 0) {
          M = m;
          m = -1;
        }
        var datestr = ("" + (Y >= 0 ? Y : (/* @__PURE__ */ new Date()).getFullYear())).slice(-4) + "-" + ("00" + (m >= 1 ? m : 1)).slice(-2) + "-" + ("00" + (d >= 1 ? d : 1)).slice(-2);
        if (datestr.length == 7)
          datestr = "0" + datestr;
        if (datestr.length == 8)
          datestr = "20" + datestr;
        var timestr = ("00" + (H >= 0 ? H : 0)).slice(-2) + ":" + ("00" + (M >= 0 ? M : 0)).slice(-2) + ":" + ("00" + (S >= 0 ? S : 0)).slice(-2);
        if (H == -1 && M == -1 && S == -1)
          return datestr;
        if (Y == -1 && m == -1 && d == -1)
          return timestr;
        return datestr + "T" + timestr;
      }
      var CRC32 = function() {
        var CRC322 = {};
        CRC322.version = "1.2.0";
        function signed_crc_table() {
          var c = 0, table = new Array(256);
          for (var n = 0; n != 256; ++n) {
            c = n;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            c = c & 1 ? -306674912 ^ c >>> 1 : c >>> 1;
            table[n] = c;
          }
          return typeof Int32Array !== "undefined" ? new Int32Array(table) : table;
        }
        var T0 = signed_crc_table();
        function slice_by_16_tables(T) {
          var c = 0, v = 0, n = 0, table = typeof Int32Array !== "undefined" ? new Int32Array(4096) : new Array(4096);
          for (n = 0; n != 256; ++n)
            table[n] = T[n];
          for (n = 0; n != 256; ++n) {
            v = T[n];
            for (c = 256 + n; c < 4096; c += 256)
              v = table[c] = v >>> 8 ^ T[v & 255];
          }
          var out = [];
          for (n = 1; n != 16; ++n)
            out[n - 1] = typeof Int32Array !== "undefined" ? table.subarray(n * 256, n * 256 + 256) : table.slice(n * 256, n * 256 + 256);
          return out;
        }
        var TT = slice_by_16_tables(T0);
        var T1 = TT[0], T2 = TT[1], T3 = TT[2], T4 = TT[3], T5 = TT[4];
        var T6 = TT[5], T7 = TT[6], T8 = TT[7], T9 = TT[8], Ta = TT[9];
        var Tb = TT[10], Tc = TT[11], Td = TT[12], Te = TT[13], Tf = TT[14];
        function crc32_bstr(bstr, seed) {
          var C = seed ^ -1;
          for (var i = 0, L = bstr.length; i < L; )
            C = C >>> 8 ^ T0[(C ^ bstr.charCodeAt(i++)) & 255];
          return ~C;
        }
        function crc32_buf(B, seed) {
          var C = seed ^ -1, L = B.length - 15, i = 0;
          for (; i < L; )
            C = Tf[B[i++] ^ C & 255] ^ Te[B[i++] ^ C >> 8 & 255] ^ Td[B[i++] ^ C >> 16 & 255] ^ Tc[B[i++] ^ C >>> 24] ^ Tb[B[i++]] ^ Ta[B[i++]] ^ T9[B[i++]] ^ T8[B[i++]] ^ T7[B[i++]] ^ T6[B[i++]] ^ T5[B[i++]] ^ T4[B[i++]] ^ T3[B[i++]] ^ T2[B[i++]] ^ T1[B[i++]] ^ T0[B[i++]];
          L += 15;
          while (i < L)
            C = C >>> 8 ^ T0[(C ^ B[i++]) & 255];
          return ~C;
        }
        function crc32_str(str, seed) {
          var C = seed ^ -1;
          for (var i = 0, L = str.length, c = 0, d = 0; i < L; ) {
            c = str.charCodeAt(i++);
            if (c < 128) {
              C = C >>> 8 ^ T0[(C ^ c) & 255];
            } else if (c < 2048) {
              C = C >>> 8 ^ T0[(C ^ (192 | c >> 6 & 31)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | c & 63)) & 255];
            } else if (c >= 55296 && c < 57344) {
              c = (c & 1023) + 64;
              d = str.charCodeAt(i++) & 1023;
              C = C >>> 8 ^ T0[(C ^ (240 | c >> 8 & 7)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | c >> 2 & 63)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | d >> 6 & 15 | (c & 3) << 4)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | d & 63)) & 255];
            } else {
              C = C >>> 8 ^ T0[(C ^ (224 | c >> 12 & 15)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | c >> 6 & 63)) & 255];
              C = C >>> 8 ^ T0[(C ^ (128 | c & 63)) & 255];
            }
          }
          return ~C;
        }
        CRC322.table = T0;
        CRC322.bstr = crc32_bstr;
        CRC322.buf = crc32_buf;
        CRC322.str = crc32_str;
        return CRC322;
      }();
      var CFB = function _CFB() {
        var exports2 = {};
        exports2.version = "1.2.1";
        function namecmp(l, r) {
          var L = l.split("/"), R = r.split("/");
          for (var i2 = 0, c = 0, Z = Math.min(L.length, R.length); i2 < Z; ++i2) {
            if (c = L[i2].length - R[i2].length)
              return c;
            if (L[i2] != R[i2])
              return L[i2] < R[i2] ? -1 : 1;
          }
          return L.length - R.length;
        }
        function dirname(p) {
          if (p.charAt(p.length - 1) == "/")
            return p.slice(0, -1).indexOf("/") === -1 ? p : dirname(p.slice(0, -1));
          var c = p.lastIndexOf("/");
          return c === -1 ? p : p.slice(0, c + 1);
        }
        function filename(p) {
          if (p.charAt(p.length - 1) == "/")
            return filename(p.slice(0, -1));
          var c = p.lastIndexOf("/");
          return c === -1 ? p : p.slice(c + 1);
        }
        function write_dos_date(buf, date) {
          if (typeof date === "string")
            date = new Date(date);
          var hms = date.getHours();
          hms = hms << 6 | date.getMinutes();
          hms = hms << 5 | date.getSeconds() >>> 1;
          buf.write_shift(2, hms);
          var ymd = date.getFullYear() - 1980;
          ymd = ymd << 4 | date.getMonth() + 1;
          ymd = ymd << 5 | date.getDate();
          buf.write_shift(2, ymd);
        }
        function parse_dos_date(buf) {
          var hms = buf.read_shift(2) & 65535;
          var ymd = buf.read_shift(2) & 65535;
          var val = /* @__PURE__ */ new Date();
          var d = ymd & 31;
          ymd >>>= 5;
          var m = ymd & 15;
          ymd >>>= 4;
          val.setMilliseconds(0);
          val.setFullYear(ymd + 1980);
          val.setMonth(m - 1);
          val.setDate(d);
          var S = hms & 31;
          hms >>>= 5;
          var M = hms & 63;
          hms >>>= 6;
          val.setHours(hms);
          val.setMinutes(M);
          val.setSeconds(S << 1);
          return val;
        }
        function parse_extra_field(blob) {
          prep_blob(blob, 0);
          var o = {};
          var flags = 0;
          while (blob.l <= blob.length - 4) {
            var type = blob.read_shift(2);
            var sz = blob.read_shift(2), tgt = blob.l + sz;
            var p = {};
            switch (type) {
              case 21589:
                {
                  flags = blob.read_shift(1);
                  if (flags & 1)
                    p.mtime = blob.read_shift(4);
                  if (sz > 5) {
                    if (flags & 2)
                      p.atime = blob.read_shift(4);
                    if (flags & 4)
                      p.ctime = blob.read_shift(4);
                  }
                  if (p.mtime)
                    p.mt = new Date(p.mtime * 1e3);
                }
                break;
            }
            blob.l = tgt;
            o[type] = p;
          }
          return o;
        }
        var fs2;
        function get_fs() {
          return fs2 || (fs2 = require("fs"));
        }
        function parse3(file, options) {
          if (file[0] == 80 && file[1] == 75)
            return parse_zip2(file, options);
          if ((file[0] | 32) == 109 && (file[1] | 32) == 105)
            return parse_mad(file, options);
          if (file.length < 512)
            throw new Error("CFB file size " + file.length + " < 512");
          var mver = 3;
          var ssz = 512;
          var nmfs = 0;
          var difat_sec_cnt = 0;
          var dir_start = 0;
          var minifat_start = 0;
          var difat_start = 0;
          var fat_addrs = [];
          var blob = file.slice(0, 512);
          prep_blob(blob, 0);
          var mv = check_get_mver(blob);
          mver = mv[0];
          switch (mver) {
            case 3:
              ssz = 512;
              break;
            case 4:
              ssz = 4096;
              break;
            case 0:
              if (mv[1] == 0)
                return parse_zip2(file, options);
            default:
              throw new Error("Major Version: Expected 3 or 4 saw " + mver);
          }
          if (ssz !== 512) {
            blob = file.slice(0, ssz);
            prep_blob(
              blob,
              28
              /* blob.l */
            );
          }
          var header = file.slice(0, ssz);
          check_shifts(blob, mver);
          var dir_cnt = blob.read_shift(4, "i");
          if (mver === 3 && dir_cnt !== 0)
            throw new Error("# Directory Sectors: Expected 0 saw " + dir_cnt);
          blob.l += 4;
          dir_start = blob.read_shift(4, "i");
          blob.l += 4;
          blob.chk("00100000", "Mini Stream Cutoff Size: ");
          minifat_start = blob.read_shift(4, "i");
          nmfs = blob.read_shift(4, "i");
          difat_start = blob.read_shift(4, "i");
          difat_sec_cnt = blob.read_shift(4, "i");
          for (var q2 = -1, j = 0; j < 109; ++j) {
            q2 = blob.read_shift(4, "i");
            if (q2 < 0)
              break;
            fat_addrs[j] = q2;
          }
          var sectors = sectorify(file, ssz);
          sleuth_fat(difat_start, difat_sec_cnt, sectors, ssz, fat_addrs);
          var sector_list = make_sector_list(sectors, dir_start, fat_addrs, ssz);
          sector_list[dir_start].name = "!Directory";
          if (nmfs > 0 && minifat_start !== ENDOFCHAIN)
            sector_list[minifat_start].name = "!MiniFAT";
          sector_list[fat_addrs[0]].name = "!FAT";
          sector_list.fat_addrs = fat_addrs;
          sector_list.ssz = ssz;
          var files = {}, Paths = [], FileIndex = [], FullPaths = [];
          read_directory(dir_start, sector_list, sectors, Paths, nmfs, files, FileIndex, minifat_start);
          build_full_paths(FileIndex, FullPaths, Paths);
          Paths.shift();
          var o = {
            FileIndex,
            FullPaths
          };
          if (options && options.raw)
            o.raw = { header, sectors };
          return o;
        }
        function check_get_mver(blob) {
          if (blob[blob.l] == 80 && blob[blob.l + 1] == 75)
            return [0, 0];
          blob.chk(HEADER_SIGNATURE, "Header Signature: ");
          blob.l += 16;
          var mver = blob.read_shift(2, "u");
          return [blob.read_shift(2, "u"), mver];
        }
        function check_shifts(blob, mver) {
          var shift = 9;
          blob.l += 2;
          switch (shift = blob.read_shift(2)) {
            case 9:
              if (mver != 3)
                throw new Error("Sector Shift: Expected 9 saw " + shift);
              break;
            case 12:
              if (mver != 4)
                throw new Error("Sector Shift: Expected 12 saw " + shift);
              break;
            default:
              throw new Error("Sector Shift: Expected 9 or 12 saw " + shift);
          }
          blob.chk("0600", "Mini Sector Shift: ");
          blob.chk("000000000000", "Reserved: ");
        }
        function sectorify(file, ssz) {
          var nsectors = Math.ceil(file.length / ssz) - 1;
          var sectors = [];
          for (var i2 = 1; i2 < nsectors; ++i2)
            sectors[i2 - 1] = file.slice(i2 * ssz, (i2 + 1) * ssz);
          sectors[nsectors - 1] = file.slice(nsectors * ssz);
          return sectors;
        }
        function build_full_paths(FI, FP, Paths) {
          var i2 = 0, L = 0, R = 0, C = 0, j = 0, pl = Paths.length;
          var dad = [], q2 = [];
          for (; i2 < pl; ++i2) {
            dad[i2] = q2[i2] = i2;
            FP[i2] = Paths[i2];
          }
          for (; j < q2.length; ++j) {
            i2 = q2[j];
            L = FI[i2].L;
            R = FI[i2].R;
            C = FI[i2].C;
            if (dad[i2] === i2) {
              if (L !== -1 && dad[L] !== L)
                dad[i2] = dad[L];
              if (R !== -1 && dad[R] !== R)
                dad[i2] = dad[R];
            }
            if (C !== -1)
              dad[C] = i2;
            if (L !== -1 && i2 != dad[i2]) {
              dad[L] = dad[i2];
              if (q2.lastIndexOf(L) < j)
                q2.push(L);
            }
            if (R !== -1 && i2 != dad[i2]) {
              dad[R] = dad[i2];
              if (q2.lastIndexOf(R) < j)
                q2.push(R);
            }
          }
          for (i2 = 1; i2 < pl; ++i2)
            if (dad[i2] === i2) {
              if (R !== -1 && dad[R] !== R)
                dad[i2] = dad[R];
              else if (L !== -1 && dad[L] !== L)
                dad[i2] = dad[L];
            }
          for (i2 = 1; i2 < pl; ++i2) {
            if (FI[i2].type === 0)
              continue;
            j = i2;
            if (j != dad[j])
              do {
                j = dad[j];
                FP[i2] = FP[j] + "/" + FP[i2];
              } while (j !== 0 && -1 !== dad[j] && j != dad[j]);
            dad[i2] = -1;
          }
          FP[0] += "/";
          for (i2 = 1; i2 < pl; ++i2) {
            if (FI[i2].type !== 2)
              FP[i2] += "/";
          }
        }
        function get_mfat_entry(entry, payload, mini) {
          var start = entry.start, size = entry.size;
          var o = [];
          var idx = start;
          while (mini && size > 0 && idx >= 0) {
            o.push(payload.slice(idx * MSSZ, idx * MSSZ + MSSZ));
            size -= MSSZ;
            idx = __readInt32LE(mini, idx * 4);
          }
          if (o.length === 0)
            return new_buf(0);
          return bconcat(o).slice(0, entry.size);
        }
        function sleuth_fat(idx, cnt, sectors, ssz, fat_addrs) {
          var q2 = ENDOFCHAIN;
          if (idx === ENDOFCHAIN) {
            if (cnt !== 0)
              throw new Error("DIFAT chain shorter than expected");
          } else if (idx !== -1) {
            var sector = sectors[idx], m = (ssz >>> 2) - 1;
            if (!sector)
              return;
            for (var i2 = 0; i2 < m; ++i2) {
              if ((q2 = __readInt32LE(sector, i2 * 4)) === ENDOFCHAIN)
                break;
              fat_addrs.push(q2);
            }
            sleuth_fat(__readInt32LE(sector, ssz - 4), cnt - 1, sectors, ssz, fat_addrs);
          }
        }
        function get_sector_list(sectors, start, fat_addrs, ssz, chkd) {
          var buf = [], buf_chain = [];
          if (!chkd)
            chkd = [];
          var modulus = ssz - 1, j = 0, jj = 0;
          for (j = start; j >= 0; ) {
            chkd[j] = true;
            buf[buf.length] = j;
            buf_chain.push(sectors[j]);
            var addr = fat_addrs[Math.floor(j * 4 / ssz)];
            jj = j * 4 & modulus;
            if (ssz < 4 + jj)
              throw new Error("FAT boundary crossed: " + j + " 4 " + ssz);
            if (!sectors[addr])
              break;
            j = __readInt32LE(sectors[addr], jj);
          }
          return { nodes: buf, data: __toBuffer([buf_chain]) };
        }
        function make_sector_list(sectors, dir_start, fat_addrs, ssz) {
          var sl = sectors.length, sector_list = [];
          var chkd = [], buf = [], buf_chain = [];
          var modulus = ssz - 1, i2 = 0, j = 0, k = 0, jj = 0;
          for (i2 = 0; i2 < sl; ++i2) {
            buf = [];
            k = i2 + dir_start;
            if (k >= sl)
              k -= sl;
            if (chkd[k])
              continue;
            buf_chain = [];
            var seen = [];
            for (j = k; j >= 0; ) {
              seen[j] = true;
              chkd[j] = true;
              buf[buf.length] = j;
              buf_chain.push(sectors[j]);
              var addr = fat_addrs[Math.floor(j * 4 / ssz)];
              jj = j * 4 & modulus;
              if (ssz < 4 + jj)
                throw new Error("FAT boundary crossed: " + j + " 4 " + ssz);
              if (!sectors[addr])
                break;
              j = __readInt32LE(sectors[addr], jj);
              if (seen[j])
                break;
            }
            sector_list[k] = { nodes: buf, data: __toBuffer([buf_chain]) };
          }
          return sector_list;
        }
        function read_directory(dir_start, sector_list, sectors, Paths, nmfs, files, FileIndex, mini) {
          var minifat_store = 0, pl = Paths.length ? 2 : 0;
          var sector = sector_list[dir_start].data;
          var i2 = 0, namelen = 0, name;
          for (; i2 < sector.length; i2 += 128) {
            var blob = sector.slice(i2, i2 + 128);
            prep_blob(blob, 64);
            namelen = blob.read_shift(2);
            name = __utf16le(blob, 0, namelen - pl);
            Paths.push(name);
            var o = {
              name,
              type: blob.read_shift(1),
              color: blob.read_shift(1),
              L: blob.read_shift(4, "i"),
              R: blob.read_shift(4, "i"),
              C: blob.read_shift(4, "i"),
              clsid: blob.read_shift(16),
              state: blob.read_shift(4, "i"),
              start: 0,
              size: 0
            };
            var ctime = blob.read_shift(2) + blob.read_shift(2) + blob.read_shift(2) + blob.read_shift(2);
            if (ctime !== 0)
              o.ct = read_date(blob, blob.l - 8);
            var mtime = blob.read_shift(2) + blob.read_shift(2) + blob.read_shift(2) + blob.read_shift(2);
            if (mtime !== 0)
              o.mt = read_date(blob, blob.l - 8);
            o.start = blob.read_shift(4, "i");
            o.size = blob.read_shift(4, "i");
            if (o.size < 0 && o.start < 0) {
              o.size = o.type = 0;
              o.start = ENDOFCHAIN;
              o.name = "";
            }
            if (o.type === 5) {
              minifat_store = o.start;
              if (nmfs > 0 && minifat_store !== ENDOFCHAIN)
                sector_list[minifat_store].name = "!StreamData";
            } else if (o.size >= 4096) {
              o.storage = "fat";
              if (sector_list[o.start] === void 0)
                sector_list[o.start] = get_sector_list(sectors, o.start, sector_list.fat_addrs, sector_list.ssz);
              sector_list[o.start].name = o.name;
              o.content = sector_list[o.start].data.slice(0, o.size);
            } else {
              o.storage = "minifat";
              if (o.size < 0)
                o.size = 0;
              else if (minifat_store !== ENDOFCHAIN && o.start !== ENDOFCHAIN && sector_list[minifat_store]) {
                o.content = get_mfat_entry(o, sector_list[minifat_store].data, (sector_list[mini] || {}).data);
              }
            }
            if (o.content)
              prep_blob(o.content, 0);
            files[name] = o;
            FileIndex.push(o);
          }
        }
        function read_date(blob, offset) {
          return new Date((__readUInt32LE(blob, offset + 4) / 1e7 * Math.pow(2, 32) + __readUInt32LE(blob, offset) / 1e7 - 11644473600) * 1e3);
        }
        function read_file(filename2, options) {
          get_fs();
          return parse3(fs2.readFileSync(filename2), options);
        }
        function read(blob, options) {
          var type = options && options.type;
          if (!type) {
            if (has_buf && Buffer.isBuffer(blob))
              type = "buffer";
          }
          switch (type || "base64") {
            case "file":
              return read_file(blob, options);
            case "base64":
              return parse3(s2a(Base64_decode(blob)), options);
            case "binary":
              return parse3(s2a(blob), options);
          }
          return parse3(blob, options);
        }
        function init_cfb(cfb, opts) {
          var o = opts || {}, root2 = o.root || "Root Entry";
          if (!cfb.FullPaths)
            cfb.FullPaths = [];
          if (!cfb.FileIndex)
            cfb.FileIndex = [];
          if (cfb.FullPaths.length !== cfb.FileIndex.length)
            throw new Error("inconsistent CFB structure");
          if (cfb.FullPaths.length === 0) {
            cfb.FullPaths[0] = root2 + "/";
            cfb.FileIndex[0] = { name: root2, type: 5 };
          }
          if (o.CLSID)
            cfb.FileIndex[0].clsid = o.CLSID;
          seed_cfb(cfb);
        }
        function seed_cfb(cfb) {
          var nm = "Sh33tJ5";
          if (CFB.find(cfb, "/" + nm))
            return;
          var p = new_buf(4);
          p[0] = 55;
          p[1] = p[3] = 50;
          p[2] = 54;
          cfb.FileIndex.push({ name: nm, type: 2, content: p, size: 4, L: 69, R: 69, C: 69 });
          cfb.FullPaths.push(cfb.FullPaths[0] + nm);
          rebuild_cfb(cfb);
        }
        function rebuild_cfb(cfb, f) {
          init_cfb(cfb);
          var gc = false, s = false;
          for (var i2 = cfb.FullPaths.length - 1; i2 >= 0; --i2) {
            var _file = cfb.FileIndex[i2];
            switch (_file.type) {
              case 0:
                if (s)
                  gc = true;
                else {
                  cfb.FileIndex.pop();
                  cfb.FullPaths.pop();
                }
                break;
              case 1:
              case 2:
              case 5:
                s = true;
                if (isNaN(_file.R * _file.L * _file.C))
                  gc = true;
                if (_file.R > -1 && _file.L > -1 && _file.R == _file.L)
                  gc = true;
                break;
              default:
                gc = true;
                break;
            }
          }
          if (!gc && !f)
            return;
          var now = new Date(1987, 1, 19), j = 0;
          var fullPaths = Object.create ? /* @__PURE__ */ Object.create(null) : {};
          var data = [];
          for (i2 = 0; i2 < cfb.FullPaths.length; ++i2) {
            fullPaths[cfb.FullPaths[i2]] = true;
            if (cfb.FileIndex[i2].type === 0)
              continue;
            data.push([cfb.FullPaths[i2], cfb.FileIndex[i2]]);
          }
          for (i2 = 0; i2 < data.length; ++i2) {
            var dad = dirname(data[i2][0]);
            s = fullPaths[dad];
            if (!s) {
              data.push([dad, {
                name: filename(dad).replace("/", ""),
                type: 1,
                clsid: HEADER_CLSID,
                ct: now,
                mt: now,
                content: null
              }]);
              fullPaths[dad] = true;
            }
          }
          data.sort(function(x, y) {
            return namecmp(x[0], y[0]);
          });
          cfb.FullPaths = [];
          cfb.FileIndex = [];
          for (i2 = 0; i2 < data.length; ++i2) {
            cfb.FullPaths[i2] = data[i2][0];
            cfb.FileIndex[i2] = data[i2][1];
          }
          for (i2 = 0; i2 < data.length; ++i2) {
            var elt = cfb.FileIndex[i2];
            var nm = cfb.FullPaths[i2];
            elt.name = filename(nm).replace("/", "");
            elt.L = elt.R = elt.C = -(elt.color = 1);
            elt.size = elt.content ? elt.content.length : 0;
            elt.start = 0;
            elt.clsid = elt.clsid || HEADER_CLSID;
            if (i2 === 0) {
              elt.C = data.length > 1 ? 1 : -1;
              elt.size = 0;
              elt.type = 5;
            } else if (nm.slice(-1) == "/") {
              for (j = i2 + 1; j < data.length; ++j)
                if (dirname(cfb.FullPaths[j]) == nm)
                  break;
              elt.C = j >= data.length ? -1 : j;
              for (j = i2 + 1; j < data.length; ++j)
                if (dirname(cfb.FullPaths[j]) == dirname(nm))
                  break;
              elt.R = j >= data.length ? -1 : j;
              elt.type = 1;
            } else {
              if (dirname(cfb.FullPaths[i2 + 1] || "") == dirname(nm))
                elt.R = i2 + 1;
              elt.type = 2;
            }
          }
        }
        function _write(cfb, options) {
          var _opts = options || {};
          if (_opts.fileType == "mad")
            return write_mad(cfb, _opts);
          rebuild_cfb(cfb);
          switch (_opts.fileType) {
            case "zip":
              return write_zip2(cfb, _opts);
          }
          var L = function(cfb2) {
            var mini_size = 0, fat_size = 0;
            for (var i3 = 0; i3 < cfb2.FileIndex.length; ++i3) {
              var file2 = cfb2.FileIndex[i3];
              if (!file2.content)
                continue;
              var flen2 = file2.content.length;
              if (flen2 > 0) {
                if (flen2 < 4096)
                  mini_size += flen2 + 63 >> 6;
                else
                  fat_size += flen2 + 511 >> 9;
              }
            }
            var dir_cnt = cfb2.FullPaths.length + 3 >> 2;
            var mini_cnt = mini_size + 7 >> 3;
            var mfat_cnt = mini_size + 127 >> 7;
            var fat_base = mini_cnt + fat_size + dir_cnt + mfat_cnt;
            var fat_cnt = fat_base + 127 >> 7;
            var difat_cnt = fat_cnt <= 109 ? 0 : Math.ceil((fat_cnt - 109) / 127);
            while (fat_base + fat_cnt + difat_cnt + 127 >> 7 > fat_cnt)
              difat_cnt = ++fat_cnt <= 109 ? 0 : Math.ceil((fat_cnt - 109) / 127);
            var L2 = [1, difat_cnt, fat_cnt, mfat_cnt, dir_cnt, fat_size, mini_size, 0];
            cfb2.FileIndex[0].size = mini_size << 6;
            L2[7] = (cfb2.FileIndex[0].start = L2[0] + L2[1] + L2[2] + L2[3] + L2[4] + L2[5]) + (L2[6] + 7 >> 3);
            return L2;
          }(cfb);
          var o = new_buf(L[7] << 9);
          var i2 = 0, T = 0;
          {
            for (i2 = 0; i2 < 8; ++i2)
              o.write_shift(1, HEADER_SIG[i2]);
            for (i2 = 0; i2 < 8; ++i2)
              o.write_shift(2, 0);
            o.write_shift(2, 62);
            o.write_shift(2, 3);
            o.write_shift(2, 65534);
            o.write_shift(2, 9);
            o.write_shift(2, 6);
            for (i2 = 0; i2 < 3; ++i2)
              o.write_shift(2, 0);
            o.write_shift(4, 0);
            o.write_shift(4, L[2]);
            o.write_shift(4, L[0] + L[1] + L[2] + L[3] - 1);
            o.write_shift(4, 0);
            o.write_shift(4, 1 << 12);
            o.write_shift(4, L[3] ? L[0] + L[1] + L[2] - 1 : ENDOFCHAIN);
            o.write_shift(4, L[3]);
            o.write_shift(-4, L[1] ? L[0] - 1 : ENDOFCHAIN);
            o.write_shift(4, L[1]);
            for (i2 = 0; i2 < 109; ++i2)
              o.write_shift(-4, i2 < L[2] ? L[1] + i2 : -1);
          }
          if (L[1]) {
            for (T = 0; T < L[1]; ++T) {
              for (; i2 < 236 + T * 127; ++i2)
                o.write_shift(-4, i2 < L[2] ? L[1] + i2 : -1);
              o.write_shift(-4, T === L[1] - 1 ? ENDOFCHAIN : T + 1);
            }
          }
          var chainit = function(w) {
            for (T += w; i2 < T - 1; ++i2)
              o.write_shift(-4, i2 + 1);
            if (w) {
              ++i2;
              o.write_shift(-4, ENDOFCHAIN);
            }
          };
          T = i2 = 0;
          for (T += L[1]; i2 < T; ++i2)
            o.write_shift(-4, consts.DIFSECT);
          for (T += L[2]; i2 < T; ++i2)
            o.write_shift(-4, consts.FATSECT);
          chainit(L[3]);
          chainit(L[4]);
          var j = 0, flen = 0;
          var file = cfb.FileIndex[0];
          for (; j < cfb.FileIndex.length; ++j) {
            file = cfb.FileIndex[j];
            if (!file.content)
              continue;
            flen = file.content.length;
            if (flen < 4096)
              continue;
            file.start = T;
            chainit(flen + 511 >> 9);
          }
          chainit(L[6] + 7 >> 3);
          while (o.l & 511)
            o.write_shift(-4, consts.ENDOFCHAIN);
          T = i2 = 0;
          for (j = 0; j < cfb.FileIndex.length; ++j) {
            file = cfb.FileIndex[j];
            if (!file.content)
              continue;
            flen = file.content.length;
            if (!flen || flen >= 4096)
              continue;
            file.start = T;
            chainit(flen + 63 >> 6);
          }
          while (o.l & 511)
            o.write_shift(-4, consts.ENDOFCHAIN);
          for (i2 = 0; i2 < L[4] << 2; ++i2) {
            var nm = cfb.FullPaths[i2];
            if (!nm || nm.length === 0) {
              for (j = 0; j < 17; ++j)
                o.write_shift(4, 0);
              for (j = 0; j < 3; ++j)
                o.write_shift(4, -1);
              for (j = 0; j < 12; ++j)
                o.write_shift(4, 0);
              continue;
            }
            file = cfb.FileIndex[i2];
            if (i2 === 0)
              file.start = file.size ? file.start - 1 : ENDOFCHAIN;
            var _nm = i2 === 0 && _opts.root || file.name;
            flen = 2 * (_nm.length + 1);
            o.write_shift(64, _nm, "utf16le");
            o.write_shift(2, flen);
            o.write_shift(1, file.type);
            o.write_shift(1, file.color);
            o.write_shift(-4, file.L);
            o.write_shift(-4, file.R);
            o.write_shift(-4, file.C);
            if (!file.clsid)
              for (j = 0; j < 4; ++j)
                o.write_shift(4, 0);
            else
              o.write_shift(16, file.clsid, "hex");
            o.write_shift(4, file.state || 0);
            o.write_shift(4, 0);
            o.write_shift(4, 0);
            o.write_shift(4, 0);
            o.write_shift(4, 0);
            o.write_shift(4, file.start);
            o.write_shift(4, file.size);
            o.write_shift(4, 0);
          }
          for (i2 = 1; i2 < cfb.FileIndex.length; ++i2) {
            file = cfb.FileIndex[i2];
            if (file.size >= 4096) {
              o.l = file.start + 1 << 9;
              if (has_buf && Buffer.isBuffer(file.content)) {
                file.content.copy(o, o.l, 0, file.size);
                o.l += file.size + 511 & -512;
              } else {
                for (j = 0; j < file.size; ++j)
                  o.write_shift(1, file.content[j]);
                for (; j & 511; ++j)
                  o.write_shift(1, 0);
              }
            }
          }
          for (i2 = 1; i2 < cfb.FileIndex.length; ++i2) {
            file = cfb.FileIndex[i2];
            if (file.size > 0 && file.size < 4096) {
              if (has_buf && Buffer.isBuffer(file.content)) {
                file.content.copy(o, o.l, 0, file.size);
                o.l += file.size + 63 & -64;
              } else {
                for (j = 0; j < file.size; ++j)
                  o.write_shift(1, file.content[j]);
                for (; j & 63; ++j)
                  o.write_shift(1, 0);
              }
            }
          }
          if (has_buf) {
            o.l = o.length;
          } else {
            while (o.l < o.length)
              o.write_shift(1, 0);
          }
          return o;
        }
        function find(cfb, path2) {
          var UCFullPaths = cfb.FullPaths.map(function(x) {
            return x.toUpperCase();
          });
          var UCPaths = UCFullPaths.map(function(x) {
            var y = x.split("/");
            return y[y.length - (x.slice(-1) == "/" ? 2 : 1)];
          });
          var k = false;
          if (path2.charCodeAt(0) === 47) {
            k = true;
            path2 = UCFullPaths[0].slice(0, -1) + path2;
          } else
            k = path2.indexOf("/") !== -1;
          var UCPath = path2.toUpperCase();
          var w = k === true ? UCFullPaths.indexOf(UCPath) : UCPaths.indexOf(UCPath);
          if (w !== -1)
            return cfb.FileIndex[w];
          var m = !UCPath.match(chr1);
          UCPath = UCPath.replace(chr0, "");
          if (m)
            UCPath = UCPath.replace(chr1, "!");
          for (w = 0; w < UCFullPaths.length; ++w) {
            if ((m ? UCFullPaths[w].replace(chr1, "!") : UCFullPaths[w]).replace(chr0, "") == UCPath)
              return cfb.FileIndex[w];
            if ((m ? UCPaths[w].replace(chr1, "!") : UCPaths[w]).replace(chr0, "") == UCPath)
              return cfb.FileIndex[w];
          }
          return null;
        }
        var MSSZ = 64;
        var ENDOFCHAIN = -2;
        var HEADER_SIGNATURE = "d0cf11e0a1b11ae1";
        var HEADER_SIG = [208, 207, 17, 224, 161, 177, 26, 225];
        var HEADER_CLSID = "00000000000000000000000000000000";
        var consts = {
          /* 2.1 Compund File Sector Numbers and Types */
          MAXREGSECT: -6,
          DIFSECT: -4,
          FATSECT: -3,
          ENDOFCHAIN,
          FREESECT: -1,
          /* 2.2 Compound File Header */
          HEADER_SIGNATURE,
          HEADER_MINOR_VERSION: "3e00",
          MAXREGSID: -6,
          NOSTREAM: -1,
          HEADER_CLSID,
          /* 2.6.1 Compound File Directory Entry */
          EntryTypes: ["unknown", "storage", "stream", "lockbytes", "property", "root"]
        };
        function write_file(cfb, filename2, options) {
          get_fs();
          var o = _write(cfb, options);
          fs2.writeFileSync(filename2, o);
        }
        function a2s2(o) {
          var out = new Array(o.length);
          for (var i2 = 0; i2 < o.length; ++i2)
            out[i2] = String.fromCharCode(o[i2]);
          return out.join("");
        }
        function write(cfb, options) {
          var o = _write(cfb, options);
          switch (options && options.type || "buffer") {
            case "file":
              get_fs();
              fs2.writeFileSync(options.filename, o);
              return o;
            case "binary":
              return typeof o == "string" ? o : a2s2(o);
            case "base64":
              return Base64_encode(typeof o == "string" ? o : a2s2(o));
            case "buffer":
              if (has_buf)
                return Buffer.isBuffer(o) ? o : Buffer_from(o);
            case "array":
              return typeof o == "string" ? s2a(o) : o;
          }
          return o;
        }
        var _zlib;
        function use_zlib(zlib) {
          try {
            var InflateRaw = zlib.InflateRaw;
            var InflRaw = new InflateRaw();
            InflRaw._processChunk(new Uint8Array([3, 0]), InflRaw._finishFlushFlag);
            if (InflRaw.bytesRead)
              _zlib = zlib;
            else
              throw new Error("zlib does not expose bytesRead");
          } catch (e) {
            console.error("cannot use native zlib: " + (e.message || e));
          }
        }
        function _inflateRawSync(payload, usz) {
          if (!_zlib)
            return _inflate(payload, usz);
          var InflateRaw = _zlib.InflateRaw;
          var InflRaw = new InflateRaw();
          var out = InflRaw._processChunk(payload.slice(payload.l), InflRaw._finishFlushFlag);
          payload.l += InflRaw.bytesRead;
          return out;
        }
        function _deflateRawSync(payload) {
          return _zlib ? _zlib.deflateRawSync(payload) : _deflate(payload);
        }
        var CLEN_ORDER = [16, 17, 18, 0, 8, 7, 9, 6, 10, 5, 11, 4, 12, 3, 13, 2, 14, 1, 15];
        var LEN_LN = [3, 4, 5, 6, 7, 8, 9, 10, 11, 13, 15, 17, 19, 23, 27, 31, 35, 43, 51, 59, 67, 83, 99, 115, 131, 163, 195, 227, 258];
        var DST_LN = [1, 2, 3, 4, 5, 7, 9, 13, 17, 25, 33, 49, 65, 97, 129, 193, 257, 385, 513, 769, 1025, 1537, 2049, 3073, 4097, 6145, 8193, 12289, 16385, 24577];
        function bit_swap_8(n) {
          var t3 = (n << 1 | n << 11) & 139536 | (n << 5 | n << 15) & 558144;
          return (t3 >> 16 | t3 >> 8 | t3) & 255;
        }
        var use_typed_arrays = typeof Uint8Array !== "undefined";
        var bitswap8 = use_typed_arrays ? new Uint8Array(1 << 8) : [];
        for (var q = 0; q < 1 << 8; ++q)
          bitswap8[q] = bit_swap_8(q);
        function bit_swap_n(n, b) {
          var rev = bitswap8[n & 255];
          if (b <= 8)
            return rev >>> 8 - b;
          rev = rev << 8 | bitswap8[n >> 8 & 255];
          if (b <= 16)
            return rev >>> 16 - b;
          rev = rev << 8 | bitswap8[n >> 16 & 255];
          return rev >>> 24 - b;
        }
        function read_bits_2(buf, bl) {
          var w = bl & 7, h = bl >>> 3;
          return (buf[h] | (w <= 6 ? 0 : buf[h + 1] << 8)) >>> w & 3;
        }
        function read_bits_3(buf, bl) {
          var w = bl & 7, h = bl >>> 3;
          return (buf[h] | (w <= 5 ? 0 : buf[h + 1] << 8)) >>> w & 7;
        }
        function read_bits_4(buf, bl) {
          var w = bl & 7, h = bl >>> 3;
          return (buf[h] | (w <= 4 ? 0 : buf[h + 1] << 8)) >>> w & 15;
        }
        function read_bits_5(buf, bl) {
          var w = bl & 7, h = bl >>> 3;
          return (buf[h] | (w <= 3 ? 0 : buf[h + 1] << 8)) >>> w & 31;
        }
        function read_bits_7(buf, bl) {
          var w = bl & 7, h = bl >>> 3;
          return (buf[h] | (w <= 1 ? 0 : buf[h + 1] << 8)) >>> w & 127;
        }
        function read_bits_n(buf, bl, n) {
          var w = bl & 7, h = bl >>> 3, f = (1 << n) - 1;
          var v = buf[h] >>> w;
          if (n < 8 - w)
            return v & f;
          v |= buf[h + 1] << 8 - w;
          if (n < 16 - w)
            return v & f;
          v |= buf[h + 2] << 16 - w;
          if (n < 24 - w)
            return v & f;
          v |= buf[h + 3] << 24 - w;
          return v & f;
        }
        function write_bits_3(buf, bl, v) {
          var w = bl & 7, h = bl >>> 3;
          if (w <= 5)
            buf[h] |= (v & 7) << w;
          else {
            buf[h] |= v << w & 255;
            buf[h + 1] = (v & 7) >> 8 - w;
          }
          return bl + 3;
        }
        function write_bits_1(buf, bl, v) {
          var w = bl & 7, h = bl >>> 3;
          v = (v & 1) << w;
          buf[h] |= v;
          return bl + 1;
        }
        function write_bits_8(buf, bl, v) {
          var w = bl & 7, h = bl >>> 3;
          v <<= w;
          buf[h] |= v & 255;
          v >>>= 8;
          buf[h + 1] = v;
          return bl + 8;
        }
        function write_bits_16(buf, bl, v) {
          var w = bl & 7, h = bl >>> 3;
          v <<= w;
          buf[h] |= v & 255;
          v >>>= 8;
          buf[h + 1] = v & 255;
          buf[h + 2] = v >>> 8;
          return bl + 16;
        }
        function realloc(b, sz) {
          var L = b.length, M = 2 * L > sz ? 2 * L : sz + 5, i2 = 0;
          if (L >= sz)
            return b;
          if (has_buf) {
            var o = new_unsafe_buf(M);
            if (b.copy)
              b.copy(o);
            else
              for (; i2 < b.length; ++i2)
                o[i2] = b[i2];
            return o;
          } else if (use_typed_arrays) {
            var a = new Uint8Array(M);
            if (a.set)
              a.set(b);
            else
              for (; i2 < L; ++i2)
                a[i2] = b[i2];
            return a;
          }
          b.length = M;
          return b;
        }
        function zero_fill_array(n) {
          var o = new Array(n);
          for (var i2 = 0; i2 < n; ++i2)
            o[i2] = 0;
          return o;
        }
        function build_tree(clens, cmap, MAX) {
          var maxlen = 1, w = 0, i2 = 0, j = 0, ccode = 0, L = clens.length;
          var bl_count = use_typed_arrays ? new Uint16Array(32) : zero_fill_array(32);
          for (i2 = 0; i2 < 32; ++i2)
            bl_count[i2] = 0;
          for (i2 = L; i2 < MAX; ++i2)
            clens[i2] = 0;
          L = clens.length;
          var ctree = use_typed_arrays ? new Uint16Array(L) : zero_fill_array(L);
          for (i2 = 0; i2 < L; ++i2) {
            bl_count[w = clens[i2]]++;
            if (maxlen < w)
              maxlen = w;
            ctree[i2] = 0;
          }
          bl_count[0] = 0;
          for (i2 = 1; i2 <= maxlen; ++i2)
            bl_count[i2 + 16] = ccode = ccode + bl_count[i2 - 1] << 1;
          for (i2 = 0; i2 < L; ++i2) {
            ccode = clens[i2];
            if (ccode != 0)
              ctree[i2] = bl_count[ccode + 16]++;
          }
          var cleni = 0;
          for (i2 = 0; i2 < L; ++i2) {
            cleni = clens[i2];
            if (cleni != 0) {
              ccode = bit_swap_n(ctree[i2], maxlen) >> maxlen - cleni;
              for (j = (1 << maxlen + 4 - cleni) - 1; j >= 0; --j)
                cmap[ccode | j << cleni] = cleni & 15 | i2 << 4;
            }
          }
          return maxlen;
        }
        var fix_lmap = use_typed_arrays ? new Uint16Array(512) : zero_fill_array(512);
        var fix_dmap = use_typed_arrays ? new Uint16Array(32) : zero_fill_array(32);
        if (!use_typed_arrays) {
          for (var i = 0; i < 512; ++i)
            fix_lmap[i] = 0;
          for (i = 0; i < 32; ++i)
            fix_dmap[i] = 0;
        }
        (function() {
          var dlens = [];
          var i2 = 0;
          for (; i2 < 32; i2++)
            dlens.push(5);
          build_tree(dlens, fix_dmap, 32);
          var clens = [];
          i2 = 0;
          for (; i2 <= 143; i2++)
            clens.push(8);
          for (; i2 <= 255; i2++)
            clens.push(9);
          for (; i2 <= 279; i2++)
            clens.push(7);
          for (; i2 <= 287; i2++)
            clens.push(8);
          build_tree(clens, fix_lmap, 288);
        })();
        var _deflateRaw = function _deflateRawIIFE() {
          var DST_LN_RE = use_typed_arrays ? new Uint8Array(32768) : [];
          var j = 0, k = 0;
          for (; j < DST_LN.length - 1; ++j) {
            for (; k < DST_LN[j + 1]; ++k)
              DST_LN_RE[k] = j;
          }
          for (; k < 32768; ++k)
            DST_LN_RE[k] = 29;
          var LEN_LN_RE = use_typed_arrays ? new Uint8Array(259) : [];
          for (j = 0, k = 0; j < LEN_LN.length - 1; ++j) {
            for (; k < LEN_LN[j + 1]; ++k)
              LEN_LN_RE[k] = j;
          }
          function write_stored(data, out) {
            var boff = 0;
            while (boff < data.length) {
              var L = Math.min(65535, data.length - boff);
              var h = boff + L == data.length;
              out.write_shift(1, +h);
              out.write_shift(2, L);
              out.write_shift(2, ~L & 65535);
              while (L-- > 0)
                out[out.l++] = data[boff++];
            }
            return out.l;
          }
          function write_huff_fixed(data, out) {
            var bl = 0;
            var boff = 0;
            var addrs = use_typed_arrays ? new Uint16Array(32768) : [];
            while (boff < data.length) {
              var L = (
                /* data.length - boff; */
                Math.min(65535, data.length - boff)
              );
              if (L < 10) {
                bl = write_bits_3(out, bl, +!!(boff + L == data.length));
                if (bl & 7)
                  bl += 8 - (bl & 7);
                out.l = bl / 8 | 0;
                out.write_shift(2, L);
                out.write_shift(2, ~L & 65535);
                while (L-- > 0)
                  out[out.l++] = data[boff++];
                bl = out.l * 8;
                continue;
              }
              bl = write_bits_3(out, bl, +!!(boff + L == data.length) + 2);
              var hash = 0;
              while (L-- > 0) {
                var d = data[boff];
                hash = (hash << 5 ^ d) & 32767;
                var match = -1, mlen = 0;
                if (match = addrs[hash]) {
                  match |= boff & ~32767;
                  if (match > boff)
                    match -= 32768;
                  if (match < boff)
                    while (data[match + mlen] == data[boff + mlen] && mlen < 250)
                      ++mlen;
                }
                if (mlen > 2) {
                  d = LEN_LN_RE[mlen];
                  if (d <= 22)
                    bl = write_bits_8(out, bl, bitswap8[d + 1] >> 1) - 1;
                  else {
                    write_bits_8(out, bl, 3);
                    bl += 5;
                    write_bits_8(out, bl, bitswap8[d - 23] >> 5);
                    bl += 3;
                  }
                  var len_eb = d < 8 ? 0 : d - 4 >> 2;
                  if (len_eb > 0) {
                    write_bits_16(out, bl, mlen - LEN_LN[d]);
                    bl += len_eb;
                  }
                  d = DST_LN_RE[boff - match];
                  bl = write_bits_8(out, bl, bitswap8[d] >> 3);
                  bl -= 3;
                  var dst_eb = d < 4 ? 0 : d - 2 >> 1;
                  if (dst_eb > 0) {
                    write_bits_16(out, bl, boff - match - DST_LN[d]);
                    bl += dst_eb;
                  }
                  for (var q2 = 0; q2 < mlen; ++q2) {
                    addrs[hash] = boff & 32767;
                    hash = (hash << 5 ^ data[boff]) & 32767;
                    ++boff;
                  }
                  L -= mlen - 1;
                } else {
                  if (d <= 143)
                    d = d + 48;
                  else
                    bl = write_bits_1(out, bl, 1);
                  bl = write_bits_8(out, bl, bitswap8[d]);
                  addrs[hash] = boff & 32767;
                  ++boff;
                }
              }
              bl = write_bits_8(out, bl, 0) - 1;
            }
            out.l = (bl + 7) / 8 | 0;
            return out.l;
          }
          return function _deflateRaw2(data, out) {
            if (data.length < 8)
              return write_stored(data, out);
            return write_huff_fixed(data, out);
          };
        }();
        function _deflate(data) {
          var buf = new_buf(50 + Math.floor(data.length * 1.1));
          var off = _deflateRaw(data, buf);
          return buf.slice(0, off);
        }
        var dyn_lmap = use_typed_arrays ? new Uint16Array(32768) : zero_fill_array(32768);
        var dyn_dmap = use_typed_arrays ? new Uint16Array(32768) : zero_fill_array(32768);
        var dyn_cmap = use_typed_arrays ? new Uint16Array(128) : zero_fill_array(128);
        var dyn_len_1 = 1, dyn_len_2 = 1;
        function dyn(data, boff) {
          var _HLIT = read_bits_5(data, boff) + 257;
          boff += 5;
          var _HDIST = read_bits_5(data, boff) + 1;
          boff += 5;
          var _HCLEN = read_bits_4(data, boff) + 4;
          boff += 4;
          var w = 0;
          var clens = use_typed_arrays ? new Uint8Array(19) : zero_fill_array(19);
          var ctree = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
          var maxlen = 1;
          var bl_count = use_typed_arrays ? new Uint8Array(8) : zero_fill_array(8);
          var next_code = use_typed_arrays ? new Uint8Array(8) : zero_fill_array(8);
          var L = clens.length;
          for (var i2 = 0; i2 < _HCLEN; ++i2) {
            clens[CLEN_ORDER[i2]] = w = read_bits_3(data, boff);
            if (maxlen < w)
              maxlen = w;
            bl_count[w]++;
            boff += 3;
          }
          var ccode = 0;
          bl_count[0] = 0;
          for (i2 = 1; i2 <= maxlen; ++i2)
            next_code[i2] = ccode = ccode + bl_count[i2 - 1] << 1;
          for (i2 = 0; i2 < L; ++i2)
            if ((ccode = clens[i2]) != 0)
              ctree[i2] = next_code[ccode]++;
          var cleni = 0;
          for (i2 = 0; i2 < L; ++i2) {
            cleni = clens[i2];
            if (cleni != 0) {
              ccode = bitswap8[ctree[i2]] >> 8 - cleni;
              for (var j = (1 << 7 - cleni) - 1; j >= 0; --j)
                dyn_cmap[ccode | j << cleni] = cleni & 7 | i2 << 3;
            }
          }
          var hcodes = [];
          maxlen = 1;
          for (; hcodes.length < _HLIT + _HDIST; ) {
            ccode = dyn_cmap[read_bits_7(data, boff)];
            boff += ccode & 7;
            switch (ccode >>>= 3) {
              case 16:
                w = 3 + read_bits_2(data, boff);
                boff += 2;
                ccode = hcodes[hcodes.length - 1];
                while (w-- > 0)
                  hcodes.push(ccode);
                break;
              case 17:
                w = 3 + read_bits_3(data, boff);
                boff += 3;
                while (w-- > 0)
                  hcodes.push(0);
                break;
              case 18:
                w = 11 + read_bits_7(data, boff);
                boff += 7;
                while (w-- > 0)
                  hcodes.push(0);
                break;
              default:
                hcodes.push(ccode);
                if (maxlen < ccode)
                  maxlen = ccode;
                break;
            }
          }
          var h1 = hcodes.slice(0, _HLIT), h2 = hcodes.slice(_HLIT);
          for (i2 = _HLIT; i2 < 286; ++i2)
            h1[i2] = 0;
          for (i2 = _HDIST; i2 < 30; ++i2)
            h2[i2] = 0;
          dyn_len_1 = build_tree(h1, dyn_lmap, 286);
          dyn_len_2 = build_tree(h2, dyn_dmap, 30);
          return boff;
        }
        function inflate(data, usz) {
          if (data[0] == 3 && !(data[1] & 3)) {
            return [new_raw_buf(usz), 2];
          }
          var boff = 0;
          var header = 0;
          var outbuf = new_unsafe_buf(usz ? usz : 1 << 18);
          var woff = 0;
          var OL = outbuf.length >>> 0;
          var max_len_1 = 0, max_len_2 = 0;
          while ((header & 1) == 0) {
            header = read_bits_3(data, boff);
            boff += 3;
            if (header >>> 1 == 0) {
              if (boff & 7)
                boff += 8 - (boff & 7);
              var sz = data[boff >>> 3] | data[(boff >>> 3) + 1] << 8;
              boff += 32;
              if (sz > 0) {
                if (!usz && OL < woff + sz) {
                  outbuf = realloc(outbuf, woff + sz);
                  OL = outbuf.length;
                }
                while (sz-- > 0) {
                  outbuf[woff++] = data[boff >>> 3];
                  boff += 8;
                }
              }
              continue;
            } else if (header >> 1 == 1) {
              max_len_1 = 9;
              max_len_2 = 5;
            } else {
              boff = dyn(data, boff);
              max_len_1 = dyn_len_1;
              max_len_2 = dyn_len_2;
            }
            for (; ; ) {
              if (!usz && OL < woff + 32767) {
                outbuf = realloc(outbuf, woff + 32767);
                OL = outbuf.length;
              }
              var bits = read_bits_n(data, boff, max_len_1);
              var code = header >>> 1 == 1 ? fix_lmap[bits] : dyn_lmap[bits];
              boff += code & 15;
              code >>>= 4;
              if ((code >>> 8 & 255) === 0)
                outbuf[woff++] = code;
              else if (code == 256)
                break;
              else {
                code -= 257;
                var len_eb = code < 8 ? 0 : code - 4 >> 2;
                if (len_eb > 5)
                  len_eb = 0;
                var tgt = woff + LEN_LN[code];
                if (len_eb > 0) {
                  tgt += read_bits_n(data, boff, len_eb);
                  boff += len_eb;
                }
                bits = read_bits_n(data, boff, max_len_2);
                code = header >>> 1 == 1 ? fix_dmap[bits] : dyn_dmap[bits];
                boff += code & 15;
                code >>>= 4;
                var dst_eb = code < 4 ? 0 : code - 2 >> 1;
                var dst = DST_LN[code];
                if (dst_eb > 0) {
                  dst += read_bits_n(data, boff, dst_eb);
                  boff += dst_eb;
                }
                if (!usz && OL < tgt) {
                  outbuf = realloc(outbuf, tgt + 100);
                  OL = outbuf.length;
                }
                while (woff < tgt) {
                  outbuf[woff] = outbuf[woff - dst];
                  ++woff;
                }
              }
            }
          }
          if (usz)
            return [outbuf, boff + 7 >>> 3];
          return [outbuf.slice(0, woff), boff + 7 >>> 3];
        }
        function _inflate(payload, usz) {
          var data = payload.slice(payload.l || 0);
          var out = inflate(data, usz);
          payload.l += out[1];
          return out[0];
        }
        function warn_or_throw(wrn, msg) {
          if (wrn) {
            if (typeof console !== "undefined")
              console.error(msg);
          } else
            throw new Error(msg);
        }
        function parse_zip2(file, options) {
          var blob = file;
          prep_blob(blob, 0);
          var FileIndex = [], FullPaths = [];
          var o = {
            FileIndex,
            FullPaths
          };
          init_cfb(o, { root: options.root });
          var i2 = blob.length - 4;
          while ((blob[i2] != 80 || blob[i2 + 1] != 75 || blob[i2 + 2] != 5 || blob[i2 + 3] != 6) && i2 >= 0)
            --i2;
          blob.l = i2 + 4;
          blob.l += 4;
          var fcnt = blob.read_shift(2);
          blob.l += 6;
          var start_cd = blob.read_shift(4);
          blob.l = start_cd;
          for (i2 = 0; i2 < fcnt; ++i2) {
            blob.l += 20;
            var csz = blob.read_shift(4);
            var usz = blob.read_shift(4);
            var namelen = blob.read_shift(2);
            var efsz = blob.read_shift(2);
            var fcsz = blob.read_shift(2);
            blob.l += 8;
            var offset = blob.read_shift(4);
            var EF = parse_extra_field(blob.slice(blob.l + namelen, blob.l + namelen + efsz));
            blob.l += namelen + efsz + fcsz;
            var L = blob.l;
            blob.l = offset + 4;
            parse_local_file(blob, csz, usz, o, EF);
            blob.l = L;
          }
          return o;
        }
        function parse_local_file(blob, csz, usz, o, EF) {
          blob.l += 2;
          var flags = blob.read_shift(2);
          var meth = blob.read_shift(2);
          var date = parse_dos_date(blob);
          if (flags & 8257)
            throw new Error("Unsupported ZIP encryption");
          var crc32 = blob.read_shift(4);
          var _csz = blob.read_shift(4);
          var _usz = blob.read_shift(4);
          var namelen = blob.read_shift(2);
          var efsz = blob.read_shift(2);
          var name = "";
          for (var i2 = 0; i2 < namelen; ++i2)
            name += String.fromCharCode(blob[blob.l++]);
          if (efsz) {
            var ef = parse_extra_field(blob.slice(blob.l, blob.l + efsz));
            if ((ef[21589] || {}).mt)
              date = ef[21589].mt;
            if (((EF || {})[21589] || {}).mt)
              date = EF[21589].mt;
          }
          blob.l += efsz;
          var data = blob.slice(blob.l, blob.l + _csz);
          switch (meth) {
            case 8:
              data = _inflateRawSync(blob, _usz);
              break;
            case 0:
              break;
            default:
              throw new Error("Unsupported ZIP Compression method " + meth);
          }
          var wrn = false;
          if (flags & 8) {
            crc32 = blob.read_shift(4);
            if (crc32 == 134695760) {
              crc32 = blob.read_shift(4);
              wrn = true;
            }
            _csz = blob.read_shift(4);
            _usz = blob.read_shift(4);
          }
          if (_csz != csz)
            warn_or_throw(wrn, "Bad compressed size: " + csz + " != " + _csz);
          if (_usz != usz)
            warn_or_throw(wrn, "Bad uncompressed size: " + usz + " != " + _usz);
          cfb_add(o, name, data, { unsafe: true, mt: date });
        }
        function write_zip2(cfb, options) {
          var _opts = options || {};
          var out = [], cdirs = [];
          var o = new_buf(1);
          var method = _opts.compression ? 8 : 0, flags = 0;
          var desc = false;
          if (desc)
            flags |= 8;
          var i2 = 0, j = 0;
          var start_cd = 0, fcnt = 0;
          var root2 = cfb.FullPaths[0], fp = root2, fi = cfb.FileIndex[0];
          var crcs = [];
          var sz_cd = 0;
          for (i2 = 1; i2 < cfb.FullPaths.length; ++i2) {
            fp = cfb.FullPaths[i2].slice(root2.length);
            fi = cfb.FileIndex[i2];
            if (!fi.size || !fi.content || fp == "Sh33tJ5")
              continue;
            var start = start_cd;
            var namebuf = new_buf(fp.length);
            for (j = 0; j < fp.length; ++j)
              namebuf.write_shift(1, fp.charCodeAt(j) & 127);
            namebuf = namebuf.slice(0, namebuf.l);
            crcs[fcnt] = CRC32.buf(fi.content, 0);
            var outbuf = fi.content;
            if (method == 8)
              outbuf = _deflateRawSync(outbuf);
            o = new_buf(30);
            o.write_shift(4, 67324752);
            o.write_shift(2, 20);
            o.write_shift(2, flags);
            o.write_shift(2, method);
            if (fi.mt)
              write_dos_date(o, fi.mt);
            else
              o.write_shift(4, 0);
            o.write_shift(-4, flags & 8 ? 0 : crcs[fcnt]);
            o.write_shift(4, flags & 8 ? 0 : outbuf.length);
            o.write_shift(4, flags & 8 ? 0 : fi.content.length);
            o.write_shift(2, namebuf.length);
            o.write_shift(2, 0);
            start_cd += o.length;
            out.push(o);
            start_cd += namebuf.length;
            out.push(namebuf);
            start_cd += outbuf.length;
            out.push(outbuf);
            if (flags & 8) {
              o = new_buf(12);
              o.write_shift(-4, crcs[fcnt]);
              o.write_shift(4, outbuf.length);
              o.write_shift(4, fi.content.length);
              start_cd += o.l;
              out.push(o);
            }
            o = new_buf(46);
            o.write_shift(4, 33639248);
            o.write_shift(2, 0);
            o.write_shift(2, 20);
            o.write_shift(2, flags);
            o.write_shift(2, method);
            o.write_shift(4, 0);
            o.write_shift(-4, crcs[fcnt]);
            o.write_shift(4, outbuf.length);
            o.write_shift(4, fi.content.length);
            o.write_shift(2, namebuf.length);
            o.write_shift(2, 0);
            o.write_shift(2, 0);
            o.write_shift(2, 0);
            o.write_shift(2, 0);
            o.write_shift(4, 0);
            o.write_shift(4, start);
            sz_cd += o.l;
            cdirs.push(o);
            sz_cd += namebuf.length;
            cdirs.push(namebuf);
            ++fcnt;
          }
          o = new_buf(22);
          o.write_shift(4, 101010256);
          o.write_shift(2, 0);
          o.write_shift(2, 0);
          o.write_shift(2, fcnt);
          o.write_shift(2, fcnt);
          o.write_shift(4, sz_cd);
          o.write_shift(4, start_cd);
          o.write_shift(2, 0);
          return bconcat([bconcat(out), bconcat(cdirs), o]);
        }
        var ContentTypeMap = {
          "htm": "text/html",
          "xml": "text/xml",
          "gif": "image/gif",
          "jpg": "image/jpeg",
          "png": "image/png",
          "mso": "application/x-mso",
          "thmx": "application/vnd.ms-officetheme",
          "sh33tj5": "application/octet-stream"
        };
        function get_content_type(fi, fp) {
          if (fi.ctype)
            return fi.ctype;
          var ext = fi.name || "", m = ext.match(/\.([^\.]+)$/);
          if (m && ContentTypeMap[m[1]])
            return ContentTypeMap[m[1]];
          if (fp) {
            m = (ext = fp).match(/[\.\\]([^\.\\])+$/);
            if (m && ContentTypeMap[m[1]])
              return ContentTypeMap[m[1]];
          }
          return "application/octet-stream";
        }
        function write_base64_76(bstr) {
          var data = Base64_encode(bstr);
          var o = [];
          for (var i2 = 0; i2 < data.length; i2 += 76)
            o.push(data.slice(i2, i2 + 76));
          return o.join("\r\n") + "\r\n";
        }
        function write_quoted_printable(text) {
          var encoded = text.replace(/[\x00-\x08\x0B\x0C\x0E-\x1F\x7E-\xFF=]/g, function(c) {
            var w = c.charCodeAt(0).toString(16).toUpperCase();
            return "=" + (w.length == 1 ? "0" + w : w);
          });
          encoded = encoded.replace(/ $/mg, "=20").replace(/\t$/mg, "=09");
          if (encoded.charAt(0) == "\n")
            encoded = "=0D" + encoded.slice(1);
          encoded = encoded.replace(/\r(?!\n)/mg, "=0D").replace(/\n\n/mg, "\n=0A").replace(/([^\r\n])\n/mg, "$1=0A");
          var o = [], split = encoded.split("\r\n");
          for (var si = 0; si < split.length; ++si) {
            var str = split[si];
            if (str.length == 0) {
              o.push("");
              continue;
            }
            for (var i2 = 0; i2 < str.length; ) {
              var end = 76;
              var tmp = str.slice(i2, i2 + end);
              if (tmp.charAt(end - 1) == "=")
                end--;
              else if (tmp.charAt(end - 2) == "=")
                end -= 2;
              else if (tmp.charAt(end - 3) == "=")
                end -= 3;
              tmp = str.slice(i2, i2 + end);
              i2 += end;
              if (i2 < str.length)
                tmp += "=";
              o.push(tmp);
            }
          }
          return o.join("\r\n");
        }
        function parse_quoted_printable(data) {
          var o = [];
          for (var di = 0; di < data.length; ++di) {
            var line = data[di];
            while (di <= data.length && line.charAt(line.length - 1) == "=")
              line = line.slice(0, line.length - 1) + data[++di];
            o.push(line);
          }
          for (var oi = 0; oi < o.length; ++oi)
            o[oi] = o[oi].replace(/[=][0-9A-Fa-f]{2}/g, function($$) {
              return String.fromCharCode(parseInt($$.slice(1), 16));
            });
          return s2a(o.join("\r\n"));
        }
        function parse_mime(cfb, data, root2) {
          var fname = "", cte = "", ctype = "", fdata;
          var di = 0;
          for (; di < 10; ++di) {
            var line = data[di];
            if (!line || line.match(/^\s*$/))
              break;
            var m = line.match(/^(.*?):\s*([^\s].*)$/);
            if (m)
              switch (m[1].toLowerCase()) {
                case "content-location":
                  fname = m[2].trim();
                  break;
                case "content-type":
                  ctype = m[2].trim();
                  break;
                case "content-transfer-encoding":
                  cte = m[2].trim();
                  break;
              }
          }
          ++di;
          switch (cte.toLowerCase()) {
            case "base64":
              fdata = s2a(Base64_decode(data.slice(di).join("")));
              break;
            case "quoted-printable":
              fdata = parse_quoted_printable(data.slice(di));
              break;
            default:
              throw new Error("Unsupported Content-Transfer-Encoding " + cte);
          }
          var file = cfb_add(cfb, fname.slice(root2.length), fdata, { unsafe: true });
          if (ctype)
            file.ctype = ctype;
        }
        function parse_mad(file, options) {
          if (a2s2(file.slice(0, 13)).toLowerCase() != "mime-version:")
            throw new Error("Unsupported MAD header");
          var root2 = options && options.root || "";
          var data = (has_buf && Buffer.isBuffer(file) ? file.toString("binary") : a2s2(file)).split("\r\n");
          var di = 0, row = "";
          for (di = 0; di < data.length; ++di) {
            row = data[di];
            if (!/^Content-Location:/i.test(row))
              continue;
            row = row.slice(row.indexOf("file"));
            if (!root2)
              root2 = row.slice(0, row.lastIndexOf("/") + 1);
            if (row.slice(0, root2.length) == root2)
              continue;
            while (root2.length > 0) {
              root2 = root2.slice(0, root2.length - 1);
              root2 = root2.slice(0, root2.lastIndexOf("/") + 1);
              if (row.slice(0, root2.length) == root2)
                break;
            }
          }
          var mboundary = (data[1] || "").match(/boundary="(.*?)"/);
          if (!mboundary)
            throw new Error("MAD cannot find boundary");
          var boundary = "--" + (mboundary[1] || "");
          var FileIndex = [], FullPaths = [];
          var o = {
            FileIndex,
            FullPaths
          };
          init_cfb(o);
          var start_di, fcnt = 0;
          for (di = 0; di < data.length; ++di) {
            var line = data[di];
            if (line !== boundary && line !== boundary + "--")
              continue;
            if (fcnt++)
              parse_mime(o, data.slice(start_di, di), root2);
            start_di = di;
          }
          return o;
        }
        function write_mad(cfb, options) {
          var opts = options || {};
          var boundary = opts.boundary || "SheetJS";
          boundary = "------=" + boundary;
          var out = [
            "MIME-Version: 1.0",
            'Content-Type: multipart/related; boundary="' + boundary.slice(2) + '"',
            "",
            "",
            ""
          ];
          var root2 = cfb.FullPaths[0], fp = root2, fi = cfb.FileIndex[0];
          for (var i2 = 1; i2 < cfb.FullPaths.length; ++i2) {
            fp = cfb.FullPaths[i2].slice(root2.length);
            fi = cfb.FileIndex[i2];
            if (!fi.size || !fi.content || fp == "Sh33tJ5")
              continue;
            fp = fp.replace(/[\x00-\x08\x0B\x0C\x0E-\x1F\x7E-\xFF]/g, function(c) {
              return "_x" + c.charCodeAt(0).toString(16) + "_";
            }).replace(/[\u0080-\uFFFF]/g, function(u) {
              return "_u" + u.charCodeAt(0).toString(16) + "_";
            });
            var ca = fi.content;
            var cstr = has_buf && Buffer.isBuffer(ca) ? ca.toString("binary") : a2s2(ca);
            var dispcnt = 0, L = Math.min(1024, cstr.length), cc = 0;
            for (var csl = 0; csl <= L; ++csl)
              if ((cc = cstr.charCodeAt(csl)) >= 32 && cc < 128)
                ++dispcnt;
            var qp = dispcnt >= L * 4 / 5;
            out.push(boundary);
            out.push("Content-Location: " + (opts.root || "file:///C:/SheetJS/") + fp);
            out.push("Content-Transfer-Encoding: " + (qp ? "quoted-printable" : "base64"));
            out.push("Content-Type: " + get_content_type(fi, fp));
            out.push("");
            out.push(qp ? write_quoted_printable(cstr) : write_base64_76(cstr));
          }
          out.push(boundary + "--\r\n");
          return out.join("\r\n");
        }
        function cfb_new(opts) {
          var o = {};
          init_cfb(o, opts);
          return o;
        }
        function cfb_add(cfb, name, content, opts) {
          var unsafe = opts && opts.unsafe;
          if (!unsafe)
            init_cfb(cfb);
          var file = !unsafe && CFB.find(cfb, name);
          if (!file) {
            var fpath = cfb.FullPaths[0];
            if (name.slice(0, fpath.length) == fpath)
              fpath = name;
            else {
              if (fpath.slice(-1) != "/")
                fpath += "/";
              fpath = (fpath + name).replace("//", "/");
            }
            file = { name: filename(name), type: 2 };
            cfb.FileIndex.push(file);
            cfb.FullPaths.push(fpath);
            if (!unsafe)
              CFB.utils.cfb_gc(cfb);
          }
          file.content = content;
          file.size = content ? content.length : 0;
          if (opts) {
            if (opts.CLSID)
              file.clsid = opts.CLSID;
            if (opts.mt)
              file.mt = opts.mt;
            if (opts.ct)
              file.ct = opts.ct;
          }
          return file;
        }
        function cfb_del(cfb, name) {
          init_cfb(cfb);
          var file = CFB.find(cfb, name);
          if (file) {
            for (var j = 0; j < cfb.FileIndex.length; ++j)
              if (cfb.FileIndex[j] == file) {
                cfb.FileIndex.splice(j, 1);
                cfb.FullPaths.splice(j, 1);
                return true;
              }
          }
          return false;
        }
        function cfb_mov(cfb, old_name, new_name) {
          init_cfb(cfb);
          var file = CFB.find(cfb, old_name);
          if (file) {
            for (var j = 0; j < cfb.FileIndex.length; ++j)
              if (cfb.FileIndex[j] == file) {
                cfb.FileIndex[j].name = filename(new_name);
                cfb.FullPaths[j] = new_name;
                return true;
              }
          }
          return false;
        }
        function cfb_gc(cfb) {
          rebuild_cfb(cfb, true);
        }
        exports2.find = find;
        exports2.read = read;
        exports2.parse = parse3;
        exports2.write = write;
        exports2.writeFile = write_file;
        exports2.utils = {
          cfb_new,
          cfb_add,
          cfb_del,
          cfb_mov,
          cfb_gc,
          ReadShift,
          CheckField,
          prep_blob,
          bconcat,
          use_zlib,
          _deflateRaw: _deflate,
          _inflateRaw: _inflate,
          consts
        };
        return exports2;
      }();
      var _fs;
      if (typeof require !== "undefined")
        try {
          _fs = require("fs");
        } catch (e) {
        }
      function blobify(data) {
        if (typeof data === "string")
          return s2ab(data);
        if (Array.isArray(data))
          return a2u(data);
        return data;
      }
      function write_dl(fname, payload, enc) {
        if (typeof _fs !== "undefined" && _fs.writeFileSync)
          return enc ? _fs.writeFileSync(fname, payload, enc) : _fs.writeFileSync(fname, payload);
        if (typeof Deno !== "undefined") {
          if (enc && typeof payload == "string")
            switch (enc) {
              case "utf8":
                payload = new TextEncoder(enc).encode(payload);
                break;
              case "binary":
                payload = s2ab(payload);
                break;
              default:
                throw new Error("Unsupported encoding " + enc);
            }
          return Deno.writeFileSync(fname, payload);
        }
        var data = enc == "utf8" ? utf8write(payload) : payload;
        if (typeof IE_SaveFile !== "undefined")
          return IE_SaveFile(data, fname);
        if (typeof Blob !== "undefined") {
          var blob = new Blob([blobify(data)], { type: "application/octet-stream" });
          if (typeof navigator !== "undefined" && navigator.msSaveBlob)
            return navigator.msSaveBlob(blob, fname);
          if (typeof saveAs !== "undefined")
            return saveAs(blob, fname);
          if (typeof URL !== "undefined" && typeof document !== "undefined" && document.createElement && URL.createObjectURL) {
            var url = URL.createObjectURL(blob);
            if (typeof chrome === "object" && typeof (chrome.downloads || {}).download == "function") {
              if (URL.revokeObjectURL && typeof setTimeout !== "undefined")
                setTimeout(function() {
                  URL.revokeObjectURL(url);
                }, 6e4);
              return chrome.downloads.download({ url, filename: fname, saveAs: true });
            }
            var a = document.createElement("a");
            if (a.download != null) {
              a.download = fname;
              a.href = url;
              document.body.appendChild(a);
              a.click();
              document.body.removeChild(a);
              if (URL.revokeObjectURL && typeof setTimeout !== "undefined")
                setTimeout(function() {
                  URL.revokeObjectURL(url);
                }, 6e4);
              return url;
            }
          }
        }
        if (typeof $ !== "undefined" && typeof File !== "undefined" && typeof Folder !== "undefined")
          try {
            var out = File(fname);
            out.open("w");
            out.encoding = "binary";
            if (Array.isArray(payload))
              payload = a2s(payload);
            out.write(payload);
            out.close();
            return payload;
          } catch (e) {
            if (!e.message || !e.message.match(/onstruct/))
              throw e;
          }
        throw new Error("cannot save file " + fname);
      }
      function read_binary(path2) {
        if (typeof _fs !== "undefined")
          return _fs.readFileSync(path2);
        if (typeof Deno !== "undefined")
          return Deno.readFileSync(path2);
        if (typeof $ !== "undefined" && typeof File !== "undefined" && typeof Folder !== "undefined")
          try {
            var infile = File(path2);
            infile.open("r");
            infile.encoding = "binary";
            var data = infile.read();
            infile.close();
            return data;
          } catch (e) {
            if (!e.message || !e.message.match(/onstruct/))
              throw e;
          }
        throw new Error("Cannot access file " + path2);
      }
      function keys3(o) {
        var ks = Object.keys(o), o2 = [];
        for (var i = 0; i < ks.length; ++i)
          if (Object.prototype.hasOwnProperty.call(o, ks[i]))
            o2.push(ks[i]);
        return o2;
      }
      function evert_key(obj, key) {
        var o = [], K = keys3(obj);
        for (var i = 0; i !== K.length; ++i)
          if (o[obj[K[i]][key]] == null)
            o[obj[K[i]][key]] = K[i];
        return o;
      }
      function evert(obj) {
        var o = [], K = keys3(obj);
        for (var i = 0; i !== K.length; ++i)
          o[obj[K[i]]] = K[i];
        return o;
      }
      function evert_num(obj) {
        var o = [], K = keys3(obj);
        for (var i = 0; i !== K.length; ++i)
          o[obj[K[i]]] = parseInt(K[i], 10);
        return o;
      }
      function evert_arr(obj) {
        var o = [], K = keys3(obj);
        for (var i = 0; i !== K.length; ++i) {
          if (o[obj[K[i]]] == null)
            o[obj[K[i]]] = [];
          o[obj[K[i]]].push(K[i]);
        }
        return o;
      }
      var basedate = new Date(1899, 11, 30, 0, 0, 0);
      function datenum(v, date1904) {
        var epoch = v.getTime();
        if (date1904)
          epoch -= 1462 * 24 * 60 * 60 * 1e3;
        var dnthresh2 = basedate.getTime() + (v.getTimezoneOffset() - basedate.getTimezoneOffset()) * 6e4;
        return (epoch - dnthresh2) / (24 * 60 * 60 * 1e3);
      }
      var refdate = /* @__PURE__ */ new Date();
      var dnthresh = basedate.getTime() + (refdate.getTimezoneOffset() - basedate.getTimezoneOffset()) * 6e4;
      var refoffset = refdate.getTimezoneOffset();
      function numdate(v) {
        var out = /* @__PURE__ */ new Date();
        out.setTime(v * 24 * 60 * 60 * 1e3 + dnthresh);
        if (out.getTimezoneOffset() !== refoffset) {
          out.setTime(out.getTime() + (out.getTimezoneOffset() - refoffset) * 6e4);
        }
        return out;
      }
      function parse_isodur(s) {
        var sec = 0, mt = 0, time = false;
        var m = s.match(/P([0-9\.]+Y)?([0-9\.]+M)?([0-9\.]+D)?T([0-9\.]+H)?([0-9\.]+M)?([0-9\.]+S)?/);
        if (!m)
          throw new Error("|" + s + "| is not an ISO8601 Duration");
        for (var i = 1; i != m.length; ++i) {
          if (!m[i])
            continue;
          mt = 1;
          if (i > 3)
            time = true;
          switch (m[i].slice(m[i].length - 1)) {
            case "Y":
              throw new Error("Unsupported ISO Duration Field: " + m[i].slice(m[i].length - 1));
            case "D":
              mt *= 24;
            case "H":
              mt *= 60;
            case "M":
              if (!time)
                throw new Error("Unsupported ISO Duration Field: M");
              else
                mt *= 60;
            case "S":
              break;
          }
          sec += mt * parseInt(m[i], 10);
        }
        return sec;
      }
      var good_pd_date_1 = /* @__PURE__ */ new Date("2017-02-19T19:06:09.000Z");
      var good_pd_date = isNaN(good_pd_date_1.getFullYear()) ? /* @__PURE__ */ new Date("2/19/17") : good_pd_date_1;
      var good_pd = good_pd_date.getFullYear() == 2017;
      function parseDate(str, fixdate) {
        var d = new Date(str);
        if (good_pd) {
          if (fixdate > 0)
            d.setTime(d.getTime() + d.getTimezoneOffset() * 60 * 1e3);
          else if (fixdate < 0)
            d.setTime(d.getTime() - d.getTimezoneOffset() * 60 * 1e3);
          return d;
        }
        if (str instanceof Date)
          return str;
        if (good_pd_date.getFullYear() == 1917 && !isNaN(d.getFullYear())) {
          var s = d.getFullYear();
          if (str.indexOf("" + s) > -1)
            return d;
          d.setFullYear(d.getFullYear() + 100);
          return d;
        }
        var n = str.match(/\d+/g) || ["2017", "2", "19", "0", "0", "0"];
        var out = new Date(+n[0], +n[1] - 1, +n[2], +n[3] || 0, +n[4] || 0, +n[5] || 0);
        if (str.indexOf("Z") > -1)
          out = new Date(out.getTime() - out.getTimezoneOffset() * 60 * 1e3);
        return out;
      }
      function cc2str(arr, debomit) {
        if (has_buf && Buffer.isBuffer(arr)) {
          if (debomit) {
            if (arr[0] == 255 && arr[1] == 254)
              return utf8write(arr.slice(2).toString("utf16le"));
            if (arr[1] == 254 && arr[2] == 255)
              return utf8write(utf16beread(arr.slice(2).toString("binary")));
          }
          return arr.toString("binary");
        }
        if (typeof TextDecoder !== "undefined")
          try {
            if (debomit) {
              if (arr[0] == 255 && arr[1] == 254)
                return utf8write(new TextDecoder("utf-16le").decode(arr.slice(2)));
              if (arr[0] == 254 && arr[1] == 255)
                return utf8write(new TextDecoder("utf-16be").decode(arr.slice(2)));
            }
            var rev = {
              "\u20AC": "\x80",
              "\u201A": "\x82",
              "\u0192": "\x83",
              "\u201E": "\x84",
              "\u2026": "\x85",
              "\u2020": "\x86",
              "\u2021": "\x87",
              "\u02C6": "\x88",
              "\u2030": "\x89",
              "\u0160": "\x8A",
              "\u2039": "\x8B",
              "\u0152": "\x8C",
              "\u017D": "\x8E",
              "\u2018": "\x91",
              "\u2019": "\x92",
              "\u201C": "\x93",
              "\u201D": "\x94",
              "\u2022": "\x95",
              "\u2013": "\x96",
              "\u2014": "\x97",
              "\u02DC": "\x98",
              "\u2122": "\x99",
              "\u0161": "\x9A",
              "\u203A": "\x9B",
              "\u0153": "\x9C",
              "\u017E": "\x9E",
              "\u0178": "\x9F"
            };
            if (Array.isArray(arr))
              arr = new Uint8Array(arr);
            return new TextDecoder("latin1").decode(arr).replace(/[€‚ƒ„…†‡ˆ‰Š‹ŒŽ‘’“”•–—˜™š›œžŸ]/g, function(c) {
              return rev[c] || c;
            });
          } catch (e) {
          }
        var o = [];
        for (var i = 0; i != arr.length; ++i)
          o.push(String.fromCharCode(arr[i]));
        return o.join("");
      }
      function dup(o) {
        if (typeof JSON != "undefined" && !Array.isArray(o))
          return JSON.parse(JSON.stringify(o));
        if (typeof o != "object" || o == null)
          return o;
        if (o instanceof Date)
          return new Date(o.getTime());
        var out = {};
        for (var k in o)
          if (Object.prototype.hasOwnProperty.call(o, k))
            out[k] = dup(o[k]);
        return out;
      }
      function fill(c, l) {
        var o = "";
        while (o.length < l)
          o += c;
        return o;
      }
      function fuzzynum(s) {
        var v = Number(s);
        if (!isNaN(v))
          return isFinite(v) ? v : NaN;
        if (!/\d/.test(s))
          return v;
        var wt = 1;
        var ss = s.replace(/([\d]),([\d])/g, "$1$2").replace(/[$]/g, "").replace(/[%]/g, function() {
          wt *= 100;
          return "";
        });
        if (!isNaN(v = Number(ss)))
          return v / wt;
        ss = ss.replace(/[(](.*)[)]/, function($$, $1) {
          wt = -wt;
          return $1;
        });
        if (!isNaN(v = Number(ss)))
          return v / wt;
        return v;
      }
      var lower_months = ["january", "february", "march", "april", "may", "june", "july", "august", "september", "october", "november", "december"];
      function fuzzydate(s) {
        var o = new Date(s), n = /* @__PURE__ */ new Date(NaN);
        var y = o.getYear(), m = o.getMonth(), d = o.getDate();
        if (isNaN(d))
          return n;
        var lower = s.toLowerCase();
        if (lower.match(/jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec/)) {
          lower = lower.replace(/[^a-z]/g, "").replace(/([^a-z]|^)[ap]m?([^a-z]|$)/, "");
          if (lower.length > 3 && lower_months.indexOf(lower) == -1)
            return n;
        } else if (lower.match(/[a-z]/))
          return n;
        if (y < 0 || y > 8099)
          return n;
        if ((m > 0 || d > 1) && y != 101)
          return o;
        if (s.match(/[^-0-9:,\/\\]/))
          return n;
        return o;
      }
      var split_regex = function() {
        var safe_split_regex = "abacaba".split(/(:?b)/i).length == 5;
        return function split_regex2(str, re, def) {
          if (safe_split_regex || typeof re == "string")
            return str.split(re);
          var p = str.split(re), o = [p[0]];
          for (var i = 1; i < p.length; ++i) {
            o.push(def);
            o.push(p[i]);
          }
          return o;
        };
      }();
      function getdatastr(data) {
        if (!data)
          return null;
        if (data.content && data.type)
          return cc2str(data.content, true);
        if (data.data)
          return debom(data.data);
        if (data.asNodeBuffer && has_buf)
          return debom(data.asNodeBuffer().toString("binary"));
        if (data.asBinary)
          return debom(data.asBinary());
        if (data._data && data._data.getContent)
          return debom(cc2str(Array.prototype.slice.call(data._data.getContent(), 0)));
        return null;
      }
      function getdatabin(data) {
        if (!data)
          return null;
        if (data.data)
          return char_codes(data.data);
        if (data.asNodeBuffer && has_buf)
          return data.asNodeBuffer();
        if (data._data && data._data.getContent) {
          var o = data._data.getContent();
          if (typeof o == "string")
            return char_codes(o);
          return Array.prototype.slice.call(o);
        }
        if (data.content && data.type)
          return data.content;
        return null;
      }
      function getdata(data) {
        return data && data.name.slice(-4) === ".bin" ? getdatabin(data) : getdatastr(data);
      }
      function safegetzipfile(zip, file) {
        var k = zip.FullPaths || keys3(zip.files);
        var f = file.toLowerCase().replace(/[\/]/g, "\\"), g = f.replace(/\\/g, "/");
        for (var i = 0; i < k.length; ++i) {
          var n = k[i].replace(/^Root Entry[\/]/, "").toLowerCase();
          if (f == n || g == n)
            return zip.files ? zip.files[k[i]] : zip.FileIndex[i];
        }
        return null;
      }
      function getzipfile(zip, file) {
        var o = safegetzipfile(zip, file);
        if (o == null)
          throw new Error("Cannot find file " + file + " in zip");
        return o;
      }
      function getzipdata(zip, file, safe) {
        if (!safe)
          return getdata(getzipfile(zip, file));
        if (!file)
          return null;
        try {
          return getzipdata(zip, file);
        } catch (e) {
          return null;
        }
      }
      function getzipstr(zip, file, safe) {
        if (!safe)
          return getdatastr(getzipfile(zip, file));
        if (!file)
          return null;
        try {
          return getzipstr(zip, file);
        } catch (e) {
          return null;
        }
      }
      function getzipbin(zip, file, safe) {
        if (!safe)
          return getdatabin(getzipfile(zip, file));
        if (!file)
          return null;
        try {
          return getzipbin(zip, file);
        } catch (e) {
          return null;
        }
      }
      function zipentries(zip) {
        var k = zip.FullPaths || keys3(zip.files), o = [];
        for (var i = 0; i < k.length; ++i)
          if (k[i].slice(-1) != "/")
            o.push(k[i].replace(/^Root Entry[\/]/, ""));
        return o.sort();
      }
      function zip_add_file(zip, path2, content) {
        if (zip.FullPaths) {
          if (typeof content == "string") {
            var res;
            if (has_buf)
              res = Buffer_from(content);
            else
              res = utf8decode(content);
            return CFB.utils.cfb_add(zip, path2, res);
          }
          CFB.utils.cfb_add(zip, path2, content);
        } else
          zip.file(path2, content);
      }
      function zip_new() {
        return CFB.utils.cfb_new();
      }
      function zip_read(d, o) {
        switch (o.type) {
          case "base64":
            return CFB.read(d, { type: "base64" });
          case "binary":
            return CFB.read(d, { type: "binary" });
          case "buffer":
          case "array":
            return CFB.read(d, { type: "buffer" });
        }
        throw new Error("Unrecognized type " + o.type);
      }
      function resolve_path(path2, base) {
        if (path2.charAt(0) == "/")
          return path2.slice(1);
        var result = base.split("/");
        if (base.slice(-1) != "/")
          result.pop();
        var target = path2.split("/");
        while (target.length !== 0) {
          var step = target.shift();
          if (step === "..")
            result.pop();
          else if (step !== ".")
            result.push(step);
        }
        return result.join("/");
      }
      var XML_HEADER = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>\r\n';
      var attregexg = /([^"\s?>\/]+)\s*=\s*((?:")([^"]*)(?:")|(?:')([^']*)(?:')|([^'">\s]+))/g;
      var tagregex1 = /<[\/\?]?[a-zA-Z0-9:_-]+(?:\s+[^"\s?>\/]+\s*=\s*(?:"[^"]*"|'[^']*'|[^'">\s=]+))*\s*[\/\?]?>/mg, tagregex2 = /<[^>]*>/g;
      var tagregex = XML_HEADER.match(tagregex1) ? tagregex1 : tagregex2;
      var nsregex = /<\w*:/, nsregex2 = /<(\/?)\w+:/;
      function parsexmltag(tag, skip_root, skip_LC) {
        var z = {};
        var eq = 0, c = 0;
        for (; eq !== tag.length; ++eq)
          if ((c = tag.charCodeAt(eq)) === 32 || c === 10 || c === 13)
            break;
        if (!skip_root)
          z[0] = tag.slice(0, eq);
        if (eq === tag.length)
          return z;
        var m = tag.match(attregexg), j = 0, v = "", i = 0, q = "", cc = "", quot = 1;
        if (m)
          for (i = 0; i != m.length; ++i) {
            cc = m[i];
            for (c = 0; c != cc.length; ++c)
              if (cc.charCodeAt(c) === 61)
                break;
            q = cc.slice(0, c).trim();
            while (cc.charCodeAt(c + 1) == 32)
              ++c;
            quot = (eq = cc.charCodeAt(c + 1)) == 34 || eq == 39 ? 1 : 0;
            v = cc.slice(c + 1 + quot, cc.length - quot);
            for (j = 0; j != q.length; ++j)
              if (q.charCodeAt(j) === 58)
                break;
            if (j === q.length) {
              if (q.indexOf("_") > 0)
                q = q.slice(0, q.indexOf("_"));
              z[q] = v;
              if (!skip_LC)
                z[q.toLowerCase()] = v;
            } else {
              var k = (j === 5 && q.slice(0, 5) === "xmlns" ? "xmlns" : "") + q.slice(j + 1);
              if (z[k] && q.slice(j - 3, j) == "ext")
                continue;
              z[k] = v;
              if (!skip_LC)
                z[k.toLowerCase()] = v;
            }
          }
        return z;
      }
      function strip_ns(x) {
        return x.replace(nsregex2, "<$1");
      }
      var encodings = {
        "&quot;": '"',
        "&apos;": "'",
        "&gt;": ">",
        "&lt;": "<",
        "&amp;": "&"
      };
      var rencoding = evert(encodings);
      var unescapexml = function() {
        var encregex = /&(?:quot|apos|gt|lt|amp|#x?([\da-fA-F]+));/ig, coderegex = /_x([\da-fA-F]{4})_/ig;
        return function unescapexml2(text) {
          var s = text + "", i = s.indexOf("<![CDATA[");
          if (i == -1)
            return s.replace(encregex, function($$, $1) {
              return encodings[$$] || String.fromCharCode(parseInt($1, $$.indexOf("x") > -1 ? 16 : 10)) || $$;
            }).replace(coderegex, function(m, c) {
              return String.fromCharCode(parseInt(c, 16));
            });
          var j = s.indexOf("]]>");
          return unescapexml2(s.slice(0, i)) + s.slice(i + 9, j) + unescapexml2(s.slice(j + 3));
        };
      }();
      var decregex = /[&<>'"]/g, charegex = /[\u0000-\u0008\u000b-\u001f]/g;
      function escapexml(text) {
        var s = text + "";
        return s.replace(decregex, function(y) {
          return rencoding[y];
        }).replace(charegex, function(s2) {
          return "_x" + ("000" + s2.charCodeAt(0).toString(16)).slice(-4) + "_";
        });
      }
      function escapexmltag(text) {
        return escapexml(text).replace(/ /g, "_x0020_");
      }
      var htmlcharegex = /[\u0000-\u001f]/g;
      function escapehtml(text) {
        var s = text + "";
        return s.replace(decregex, function(y) {
          return rencoding[y];
        }).replace(/\n/g, "<br/>").replace(htmlcharegex, function(s2) {
          return "&#x" + ("000" + s2.charCodeAt(0).toString(16)).slice(-4) + ";";
        });
      }
      function escapexlml(text) {
        var s = text + "";
        return s.replace(decregex, function(y) {
          return rencoding[y];
        }).replace(htmlcharegex, function(s2) {
          return "&#x" + s2.charCodeAt(0).toString(16).toUpperCase() + ";";
        });
      }
      var xlml_fixstr = function() {
        var entregex = /&#(\d+);/g;
        function entrepl($$, $1) {
          return String.fromCharCode(parseInt($1, 10));
        }
        return function xlml_fixstr2(str) {
          return str.replace(entregex, entrepl);
        };
      }();
      function xlml_unfixstr(str) {
        return str.replace(/(\r\n|[\r\n])/g, "&#10;");
      }
      function parsexmlbool(value2) {
        switch (value2) {
          case 1:
          case true:
          case "1":
          case "true":
          case "TRUE":
            return true;
          default:
            return false;
        }
      }
      function utf8reada(orig) {
        var out = "", i = 0, c = 0, d = 0, e = 0, f = 0, w = 0;
        while (i < orig.length) {
          c = orig.charCodeAt(i++);
          if (c < 128) {
            out += String.fromCharCode(c);
            continue;
          }
          d = orig.charCodeAt(i++);
          if (c > 191 && c < 224) {
            f = (c & 31) << 6;
            f |= d & 63;
            out += String.fromCharCode(f);
            continue;
          }
          e = orig.charCodeAt(i++);
          if (c < 240) {
            out += String.fromCharCode((c & 15) << 12 | (d & 63) << 6 | e & 63);
            continue;
          }
          f = orig.charCodeAt(i++);
          w = ((c & 7) << 18 | (d & 63) << 12 | (e & 63) << 6 | f & 63) - 65536;
          out += String.fromCharCode(55296 + (w >>> 10 & 1023));
          out += String.fromCharCode(56320 + (w & 1023));
        }
        return out;
      }
      function utf8readb(data) {
        var out = new_raw_buf(2 * data.length), w, i, j = 1, k = 0, ww = 0, c;
        for (i = 0; i < data.length; i += j) {
          j = 1;
          if ((c = data.charCodeAt(i)) < 128)
            w = c;
          else if (c < 224) {
            w = (c & 31) * 64 + (data.charCodeAt(i + 1) & 63);
            j = 2;
          } else if (c < 240) {
            w = (c & 15) * 4096 + (data.charCodeAt(i + 1) & 63) * 64 + (data.charCodeAt(i + 2) & 63);
            j = 3;
          } else {
            j = 4;
            w = (c & 7) * 262144 + (data.charCodeAt(i + 1) & 63) * 4096 + (data.charCodeAt(i + 2) & 63) * 64 + (data.charCodeAt(i + 3) & 63);
            w -= 65536;
            ww = 55296 + (w >>> 10 & 1023);
            w = 56320 + (w & 1023);
          }
          if (ww !== 0) {
            out[k++] = ww & 255;
            out[k++] = ww >>> 8;
            ww = 0;
          }
          out[k++] = w % 256;
          out[k++] = w >>> 8;
        }
        return out.slice(0, k).toString("ucs2");
      }
      function utf8readc(data) {
        return Buffer_from(data, "binary").toString("utf8");
      }
      var utf8corpus = "foo bar baz\xE2\x98\x83\xF0\x9F\x8D\xA3";
      var utf8read = has_buf && (utf8readc(utf8corpus) == utf8reada(utf8corpus) && utf8readc || utf8readb(utf8corpus) == utf8reada(utf8corpus) && utf8readb) || utf8reada;
      var utf8write = has_buf ? function(data) {
        return Buffer_from(data, "utf8").toString("binary");
      } : function(orig) {
        var out = [], i = 0, c = 0, d = 0;
        while (i < orig.length) {
          c = orig.charCodeAt(i++);
          switch (true) {
            case c < 128:
              out.push(String.fromCharCode(c));
              break;
            case c < 2048:
              out.push(String.fromCharCode(192 + (c >> 6)));
              out.push(String.fromCharCode(128 + (c & 63)));
              break;
            case (c >= 55296 && c < 57344):
              c -= 55296;
              d = orig.charCodeAt(i++) - 56320 + (c << 10);
              out.push(String.fromCharCode(240 + (d >> 18 & 7)));
              out.push(String.fromCharCode(144 + (d >> 12 & 63)));
              out.push(String.fromCharCode(128 + (d >> 6 & 63)));
              out.push(String.fromCharCode(128 + (d & 63)));
              break;
            default:
              out.push(String.fromCharCode(224 + (c >> 12)));
              out.push(String.fromCharCode(128 + (c >> 6 & 63)));
              out.push(String.fromCharCode(128 + (c & 63)));
          }
        }
        return out.join("");
      };
      var matchtag = function() {
        var mtcache = {};
        return function matchtag2(f, g) {
          var t3 = f + "|" + (g || "");
          if (mtcache[t3])
            return mtcache[t3];
          return mtcache[t3] = new RegExp("<(?:\\w+:)?" + f + '(?: xml:space="preserve")?(?:[^>]*)>([\\s\\S]*?)</(?:\\w+:)?' + f + ">", g || "");
        };
      }();
      var htmldecode = function() {
        var entities = [
          ["nbsp", " "],
          ["middot", "\xB7"],
          ["quot", '"'],
          ["apos", "'"],
          ["gt", ">"],
          ["lt", "<"],
          ["amp", "&"]
        ].map(function(x) {
          return [new RegExp("&" + x[0] + ";", "ig"), x[1]];
        });
        return function htmldecode2(str) {
          var o = str.replace(/^[\t\n\r ]+/, "").replace(/[\t\n\r ]+$/, "").replace(/>\s+/g, ">").replace(/\s+</g, "<").replace(/[\t\n\r ]+/g, " ").replace(/<\s*[bB][rR]\s*\/?>/g, "\n").replace(/<[^>]*>/g, "");
          for (var i = 0; i < entities.length; ++i)
            o = o.replace(entities[i][0], entities[i][1]);
          return o;
        };
      }();
      var vtregex = function() {
        var vt_cache = {};
        return function vt_regex(bt) {
          if (vt_cache[bt] !== void 0)
            return vt_cache[bt];
          return vt_cache[bt] = new RegExp("<(?:vt:)?" + bt + ">([\\s\\S]*?)</(?:vt:)?" + bt + ">", "g");
        };
      }();
      var vtvregex = /<\/?(?:vt:)?variant>/g, vtmregex = /<(?:vt:)([^>]*)>([\s\S]*)</;
      function parseVector(data, opts) {
        var h = parsexmltag(data);
        var matches = data.match(vtregex(h.baseType)) || [];
        var res = [];
        if (matches.length != h.size) {
          if (opts.WTF)
            throw new Error("unexpected vector length " + matches.length + " != " + h.size);
          return res;
        }
        matches.forEach(function(x) {
          var v = x.replace(vtvregex, "").match(vtmregex);
          if (v)
            res.push({ v: utf8read(v[2]), t: v[1] });
        });
        return res;
      }
      var wtregex = /(^\s|\s$|\n)/;
      function writetag(f, g) {
        return "<" + f + (g.match(wtregex) ? ' xml:space="preserve"' : "") + ">" + g + "</" + f + ">";
      }
      function wxt_helper(h) {
        return keys3(h).map(function(k) {
          return " " + k + '="' + h[k] + '"';
        }).join("");
      }
      function writextag(f, g, h) {
        return "<" + f + (h != null ? wxt_helper(h) : "") + (g != null ? (g.match(wtregex) ? ' xml:space="preserve"' : "") + ">" + g + "</" + f : "/") + ">";
      }
      function write_w3cdtf(d, t3) {
        try {
          return d.toISOString().replace(/\.\d*/, "");
        } catch (e) {
          if (t3)
            throw e;
        }
        return "";
      }
      function write_vt(s, xlsx) {
        switch (typeof s) {
          case "string":
            var o = writextag("vt:lpwstr", escapexml(s));
            if (xlsx)
              o = o.replace(/&quot;/g, "_x0022_");
            return o;
          case "number":
            return writextag((s | 0) == s ? "vt:i4" : "vt:r8", escapexml(String(s)));
          case "boolean":
            return writextag("vt:bool", s ? "true" : "false");
        }
        if (s instanceof Date)
          return writextag("vt:filetime", write_w3cdtf(s));
        throw new Error("Unable to serialize " + s);
      }
      function xlml_normalize(d) {
        if (has_buf && Buffer.isBuffer(d))
          return d.toString("utf8");
        if (typeof d === "string")
          return d;
        if (typeof Uint8Array !== "undefined" && d instanceof Uint8Array)
          return utf8read(a2s(ab2a(d)));
        throw new Error("Bad input format: expected Buffer or string");
      }
      var xlmlregex = /<(\/?)([^\s?><!\/:]*:|)([^\s?<>:\/]+)(?:[\s?:\/][^>]*)?>/mg;
      var XMLNS = {
        CORE_PROPS: "http://schemas.openxmlformats.org/package/2006/metadata/core-properties",
        CUST_PROPS: "http://schemas.openxmlformats.org/officeDocument/2006/custom-properties",
        EXT_PROPS: "http://schemas.openxmlformats.org/officeDocument/2006/extended-properties",
        CT: "http://schemas.openxmlformats.org/package/2006/content-types",
        RELS: "http://schemas.openxmlformats.org/package/2006/relationships",
        TCMNT: "http://schemas.microsoft.com/office/spreadsheetml/2018/threadedcomments",
        "dc": "http://purl.org/dc/elements/1.1/",
        "dcterms": "http://purl.org/dc/terms/",
        "dcmitype": "http://purl.org/dc/dcmitype/",
        "mx": "http://schemas.microsoft.com/office/mac/excel/2008/main",
        "r": "http://schemas.openxmlformats.org/officeDocument/2006/relationships",
        "sjs": "http://schemas.openxmlformats.org/package/2006/sheetjs/core-properties",
        "vt": "http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes",
        "xsi": "http://www.w3.org/2001/XMLSchema-instance",
        "xsd": "http://www.w3.org/2001/XMLSchema"
      };
      var XMLNS_main = [
        "http://schemas.openxmlformats.org/spreadsheetml/2006/main",
        "http://purl.oclc.org/ooxml/spreadsheetml/main",
        "http://schemas.microsoft.com/office/excel/2006/main",
        "http://schemas.microsoft.com/office/excel/2006/2"
      ];
      var XLMLNS = {
        "o": "urn:schemas-microsoft-com:office:office",
        "x": "urn:schemas-microsoft-com:office:excel",
        "ss": "urn:schemas-microsoft-com:office:spreadsheet",
        "dt": "uuid:C2F41010-65B3-11d1-A29F-00AA00C14882",
        "mv": "http://macVmlSchemaUri",
        "v": "urn:schemas-microsoft-com:vml",
        "html": "http://www.w3.org/TR/REC-html40"
      };
      function read_double_le(b, idx) {
        var s = 1 - 2 * (b[idx + 7] >>> 7);
        var e = ((b[idx + 7] & 127) << 4) + (b[idx + 6] >>> 4 & 15);
        var m = b[idx + 6] & 15;
        for (var i = 5; i >= 0; --i)
          m = m * 256 + b[idx + i];
        if (e == 2047)
          return m == 0 ? s * Infinity : NaN;
        if (e == 0)
          e = -1022;
        else {
          e -= 1023;
          m += Math.pow(2, 52);
        }
        return s * Math.pow(2, e - 52) * m;
      }
      function write_double_le(b, v, idx) {
        var bs = (v < 0 || 1 / v == -Infinity ? 1 : 0) << 7, e = 0, m = 0;
        var av = bs ? -v : v;
        if (!isFinite(av)) {
          e = 2047;
          m = isNaN(v) ? 26985 : 0;
        } else if (av == 0)
          e = m = 0;
        else {
          e = Math.floor(Math.log(av) / Math.LN2);
          m = av * Math.pow(2, 52 - e);
          if (e <= -1023 && (!isFinite(m) || m < Math.pow(2, 52))) {
            e = -1022;
          } else {
            m -= Math.pow(2, 52);
            e += 1023;
          }
        }
        for (var i = 0; i <= 5; ++i, m /= 256)
          b[idx + i] = m & 255;
        b[idx + 6] = (e & 15) << 4 | m & 15;
        b[idx + 7] = e >> 4 | bs;
      }
      var ___toBuffer = function(bufs) {
        var x = [], w = 10240;
        for (var i = 0; i < bufs[0].length; ++i)
          if (bufs[0][i])
            for (var j = 0, L = bufs[0][i].length; j < L; j += w)
              x.push.apply(x, bufs[0][i].slice(j, j + w));
        return x;
      };
      var __toBuffer = has_buf ? function(bufs) {
        return bufs[0].length > 0 && Buffer.isBuffer(bufs[0][0]) ? Buffer.concat(bufs[0].map(function(x) {
          return Buffer.isBuffer(x) ? x : Buffer_from(x);
        })) : ___toBuffer(bufs);
      } : ___toBuffer;
      var ___utf16le = function(b, s, e) {
        var ss = [];
        for (var i = s; i < e; i += 2)
          ss.push(String.fromCharCode(__readUInt16LE(b, i)));
        return ss.join("").replace(chr0, "");
      };
      var __utf16le = has_buf ? function(b, s, e) {
        if (!Buffer.isBuffer(b))
          return ___utf16le(b, s, e);
        return b.toString("utf16le", s, e).replace(chr0, "");
      } : ___utf16le;
      var ___hexlify = function(b, s, l) {
        var ss = [];
        for (var i = s; i < s + l; ++i)
          ss.push(("0" + b[i].toString(16)).slice(-2));
        return ss.join("");
      };
      var __hexlify = has_buf ? function(b, s, l) {
        return Buffer.isBuffer(b) ? b.toString("hex", s, s + l) : ___hexlify(b, s, l);
      } : ___hexlify;
      var ___utf8 = function(b, s, e) {
        var ss = [];
        for (var i = s; i < e; i++)
          ss.push(String.fromCharCode(__readUInt8(b, i)));
        return ss.join("");
      };
      var __utf8 = has_buf ? function utf8_b(b, s, e) {
        return Buffer.isBuffer(b) ? b.toString("utf8", s, e) : ___utf8(b, s, e);
      } : ___utf8;
      var ___lpstr = function(b, i) {
        var len = __readUInt32LE(b, i);
        return len > 0 ? __utf8(b, i + 4, i + 4 + len - 1) : "";
      };
      var __lpstr = ___lpstr;
      var ___cpstr = function(b, i) {
        var len = __readUInt32LE(b, i);
        return len > 0 ? __utf8(b, i + 4, i + 4 + len - 1) : "";
      };
      var __cpstr = ___cpstr;
      var ___lpwstr = function(b, i) {
        var len = 2 * __readUInt32LE(b, i);
        return len > 0 ? __utf8(b, i + 4, i + 4 + len - 1) : "";
      };
      var __lpwstr = ___lpwstr;
      var ___lpp4 = function lpp4_(b, i) {
        var len = __readUInt32LE(b, i);
        return len > 0 ? __utf16le(b, i + 4, i + 4 + len) : "";
      };
      var __lpp4 = ___lpp4;
      var ___8lpp4 = function(b, i) {
        var len = __readUInt32LE(b, i);
        return len > 0 ? __utf8(b, i + 4, i + 4 + len) : "";
      };
      var __8lpp4 = ___8lpp4;
      var ___double = function(b, idx) {
        return read_double_le(b, idx);
      };
      var __double = ___double;
      var is_buf = function is_buf_a(a) {
        return Array.isArray(a) || typeof Uint8Array !== "undefined" && a instanceof Uint8Array;
      };
      if (has_buf) {
        __lpstr = function lpstr_b(b, i) {
          if (!Buffer.isBuffer(b))
            return ___lpstr(b, i);
          var len = b.readUInt32LE(i);
          return len > 0 ? b.toString("utf8", i + 4, i + 4 + len - 1) : "";
        };
        __cpstr = function cpstr_b(b, i) {
          if (!Buffer.isBuffer(b))
            return ___cpstr(b, i);
          var len = b.readUInt32LE(i);
          return len > 0 ? b.toString("utf8", i + 4, i + 4 + len - 1) : "";
        };
        __lpwstr = function lpwstr_b(b, i) {
          if (!Buffer.isBuffer(b))
            return ___lpwstr(b, i);
          var len = 2 * b.readUInt32LE(i);
          return b.toString("utf16le", i + 4, i + 4 + len - 1);
        };
        __lpp4 = function lpp4_b(b, i) {
          if (!Buffer.isBuffer(b))
            return ___lpp4(b, i);
          var len = b.readUInt32LE(i);
          return b.toString("utf16le", i + 4, i + 4 + len);
        };
        __8lpp4 = function lpp4_8b(b, i) {
          if (!Buffer.isBuffer(b))
            return ___8lpp4(b, i);
          var len = b.readUInt32LE(i);
          return b.toString("utf8", i + 4, i + 4 + len);
        };
        __double = function double_(b, i) {
          if (Buffer.isBuffer(b))
            return b.readDoubleLE(i);
          return ___double(b, i);
        };
        is_buf = function is_buf_b(a) {
          return Buffer.isBuffer(a) || Array.isArray(a) || typeof Uint8Array !== "undefined" && a instanceof Uint8Array;
        };
      }
      function cpdoit() {
        __utf16le = function(b, s, e) {
          return $cptable.utils.decode(1200, b.slice(s, e)).replace(chr0, "");
        };
        __utf8 = function(b, s, e) {
          return $cptable.utils.decode(65001, b.slice(s, e));
        };
        __lpstr = function(b, i) {
          var len = __readUInt32LE(b, i);
          return len > 0 ? $cptable.utils.decode(current_ansi, b.slice(i + 4, i + 4 + len - 1)) : "";
        };
        __cpstr = function(b, i) {
          var len = __readUInt32LE(b, i);
          return len > 0 ? $cptable.utils.decode(current_codepage, b.slice(i + 4, i + 4 + len - 1)) : "";
        };
        __lpwstr = function(b, i) {
          var len = 2 * __readUInt32LE(b, i);
          return len > 0 ? $cptable.utils.decode(1200, b.slice(i + 4, i + 4 + len - 1)) : "";
        };
        __lpp4 = function(b, i) {
          var len = __readUInt32LE(b, i);
          return len > 0 ? $cptable.utils.decode(1200, b.slice(i + 4, i + 4 + len)) : "";
        };
        __8lpp4 = function(b, i) {
          var len = __readUInt32LE(b, i);
          return len > 0 ? $cptable.utils.decode(65001, b.slice(i + 4, i + 4 + len)) : "";
        };
      }
      if (typeof $cptable !== "undefined")
        cpdoit();
      var __readUInt8 = function(b, idx) {
        return b[idx];
      };
      var __readUInt16LE = function(b, idx) {
        return b[idx + 1] * (1 << 8) + b[idx];
      };
      var __readInt16LE = function(b, idx) {
        var u = b[idx + 1] * (1 << 8) + b[idx];
        return u < 32768 ? u : (65535 - u + 1) * -1;
      };
      var __readUInt32LE = function(b, idx) {
        return b[idx + 3] * (1 << 24) + (b[idx + 2] << 16) + (b[idx + 1] << 8) + b[idx];
      };
      var __readInt32LE = function(b, idx) {
        return b[idx + 3] << 24 | b[idx + 2] << 16 | b[idx + 1] << 8 | b[idx];
      };
      var __readInt32BE = function(b, idx) {
        return b[idx] << 24 | b[idx + 1] << 16 | b[idx + 2] << 8 | b[idx + 3];
      };
      function ReadShift(size, t3) {
        var o = "", oI, oR, oo = [], w, vv, i, loc;
        switch (t3) {
          case "dbcs":
            loc = this.l;
            if (has_buf && Buffer.isBuffer(this))
              o = this.slice(this.l, this.l + 2 * size).toString("utf16le");
            else
              for (i = 0; i < size; ++i) {
                o += String.fromCharCode(__readUInt16LE(this, loc));
                loc += 2;
              }
            size *= 2;
            break;
          case "utf8":
            o = __utf8(this, this.l, this.l + size);
            break;
          case "utf16le":
            size *= 2;
            o = __utf16le(this, this.l, this.l + size);
            break;
          case "wstr":
            if (typeof $cptable !== "undefined")
              o = $cptable.utils.decode(current_codepage, this.slice(this.l, this.l + 2 * size));
            else
              return ReadShift.call(this, size, "dbcs");
            size = 2 * size;
            break;
          case "lpstr-ansi":
            o = __lpstr(this, this.l);
            size = 4 + __readUInt32LE(this, this.l);
            break;
          case "lpstr-cp":
            o = __cpstr(this, this.l);
            size = 4 + __readUInt32LE(this, this.l);
            break;
          case "lpwstr":
            o = __lpwstr(this, this.l);
            size = 4 + 2 * __readUInt32LE(this, this.l);
            break;
          case "lpp4":
            size = 4 + __readUInt32LE(this, this.l);
            o = __lpp4(this, this.l);
            if (size & 2)
              size += 2;
            break;
          case "8lpp4":
            size = 4 + __readUInt32LE(this, this.l);
            o = __8lpp4(this, this.l);
            if (size & 3)
              size += 4 - (size & 3);
            break;
          case "cstr":
            size = 0;
            o = "";
            while ((w = __readUInt8(this, this.l + size++)) !== 0)
              oo.push(_getchar(w));
            o = oo.join("");
            break;
          case "_wstr":
            size = 0;
            o = "";
            while ((w = __readUInt16LE(this, this.l + size)) !== 0) {
              oo.push(_getchar(w));
              size += 2;
            }
            size += 2;
            o = oo.join("");
            break;
          case "dbcs-cont":
            o = "";
            loc = this.l;
            for (i = 0; i < size; ++i) {
              if (this.lens && this.lens.indexOf(loc) !== -1) {
                w = __readUInt8(this, loc);
                this.l = loc + 1;
                vv = ReadShift.call(this, size - i, w ? "dbcs-cont" : "sbcs-cont");
                return oo.join("") + vv;
              }
              oo.push(_getchar(__readUInt16LE(this, loc)));
              loc += 2;
            }
            o = oo.join("");
            size *= 2;
            break;
          case "cpstr":
            if (typeof $cptable !== "undefined") {
              o = $cptable.utils.decode(current_codepage, this.slice(this.l, this.l + size));
              break;
            }
          case "sbcs-cont":
            o = "";
            loc = this.l;
            for (i = 0; i != size; ++i) {
              if (this.lens && this.lens.indexOf(loc) !== -1) {
                w = __readUInt8(this, loc);
                this.l = loc + 1;
                vv = ReadShift.call(this, size - i, w ? "dbcs-cont" : "sbcs-cont");
                return oo.join("") + vv;
              }
              oo.push(_getchar(__readUInt8(this, loc)));
              loc += 1;
            }
            o = oo.join("");
            break;
          default:
            switch (size) {
              case 1:
                oI = __readUInt8(this, this.l);
                this.l++;
                return oI;
              case 2:
                oI = (t3 === "i" ? __readInt16LE : __readUInt16LE)(this, this.l);
                this.l += 2;
                return oI;
              case 4:
              case -4:
                if (t3 === "i" || (this[this.l + 3] & 128) === 0) {
                  oI = (size > 0 ? __readInt32LE : __readInt32BE)(this, this.l);
                  this.l += 4;
                  return oI;
                } else {
                  oR = __readUInt32LE(this, this.l);
                  this.l += 4;
                }
                return oR;
              case 8:
              case -8:
                if (t3 === "f") {
                  if (size == 8)
                    oR = __double(this, this.l);
                  else
                    oR = __double([this[this.l + 7], this[this.l + 6], this[this.l + 5], this[this.l + 4], this[this.l + 3], this[this.l + 2], this[this.l + 1], this[this.l + 0]], 0);
                  this.l += 8;
                  return oR;
                } else
                  size = 8;
              case 16:
                o = __hexlify(this, this.l, size);
                break;
            }
        }
        this.l += size;
        return o;
      }
      var __writeUInt32LE = function(b, val, idx) {
        b[idx] = val & 255;
        b[idx + 1] = val >>> 8 & 255;
        b[idx + 2] = val >>> 16 & 255;
        b[idx + 3] = val >>> 24 & 255;
      };
      var __writeInt32LE = function(b, val, idx) {
        b[idx] = val & 255;
        b[idx + 1] = val >> 8 & 255;
        b[idx + 2] = val >> 16 & 255;
        b[idx + 3] = val >> 24 & 255;
      };
      var __writeUInt16LE = function(b, val, idx) {
        b[idx] = val & 255;
        b[idx + 1] = val >>> 8 & 255;
      };
      function WriteShift(t3, val, f) {
        var size = 0, i = 0;
        if (f === "dbcs") {
          for (i = 0; i != val.length; ++i)
            __writeUInt16LE(this, val.charCodeAt(i), this.l + 2 * i);
          size = 2 * val.length;
        } else if (f === "sbcs") {
          if (typeof $cptable !== "undefined" && current_ansi == 874) {
            for (i = 0; i != val.length; ++i) {
              var cppayload = $cptable.utils.encode(current_ansi, val.charAt(i));
              this[this.l + i] = cppayload[0];
            }
          } else {
            val = val.replace(/[^\x00-\x7F]/g, "_");
            for (i = 0; i != val.length; ++i)
              this[this.l + i] = val.charCodeAt(i) & 255;
          }
          size = val.length;
        } else if (f === "hex") {
          for (; i < t3; ++i) {
            this[this.l++] = parseInt(val.slice(2 * i, 2 * i + 2), 16) || 0;
          }
          return this;
        } else if (f === "utf16le") {
          var end = Math.min(this.l + t3, this.length);
          for (i = 0; i < Math.min(val.length, t3); ++i) {
            var cc = val.charCodeAt(i);
            this[this.l++] = cc & 255;
            this[this.l++] = cc >> 8;
          }
          while (this.l < end)
            this[this.l++] = 0;
          return this;
        } else
          switch (t3) {
            case 1:
              size = 1;
              this[this.l] = val & 255;
              break;
            case 2:
              size = 2;
              this[this.l] = val & 255;
              val >>>= 8;
              this[this.l + 1] = val & 255;
              break;
            case 3:
              size = 3;
              this[this.l] = val & 255;
              val >>>= 8;
              this[this.l + 1] = val & 255;
              val >>>= 8;
              this[this.l + 2] = val & 255;
              break;
            case 4:
              size = 4;
              __writeUInt32LE(this, val, this.l);
              break;
            case 8:
              size = 8;
              if (f === "f") {
                write_double_le(this, val, this.l);
                break;
              }
            case 16:
              break;
            case -4:
              size = 4;
              __writeInt32LE(this, val, this.l);
              break;
          }
        this.l += size;
        return this;
      }
      function CheckField(hexstr, fld) {
        var m = __hexlify(this, this.l, hexstr.length >> 1);
        if (m !== hexstr)
          throw new Error(fld + "Expected " + hexstr + " saw " + m);
        this.l += hexstr.length >> 1;
      }
      function prep_blob(blob, pos) {
        blob.l = pos;
        blob.read_shift = ReadShift;
        blob.chk = CheckField;
        blob.write_shift = WriteShift;
      }
      function parsenoop(blob, length) {
        blob.l += length;
      }
      function new_buf(sz) {
        var o = new_raw_buf(sz);
        prep_blob(o, 0);
        return o;
      }
      function recordhopper(data, cb, opts) {
        if (!data)
          return;
        var tmpbyte, cntbyte, length;
        prep_blob(data, data.l || 0);
        var L = data.length, RT = 0, tgt = 0;
        while (data.l < L) {
          RT = data.read_shift(1);
          if (RT & 128)
            RT = (RT & 127) + ((data.read_shift(1) & 127) << 7);
          var R = XLSBRecordEnum[RT] || XLSBRecordEnum[65535];
          tmpbyte = data.read_shift(1);
          length = tmpbyte & 127;
          for (cntbyte = 1; cntbyte < 4 && tmpbyte & 128; ++cntbyte)
            length += ((tmpbyte = data.read_shift(1)) & 127) << 7 * cntbyte;
          tgt = data.l + length;
          var d = R.f && R.f(data, length, opts);
          data.l = tgt;
          if (cb(d, R, RT))
            return;
        }
      }
      function buf_array() {
        var bufs = [], blksz = has_buf ? 256 : 2048;
        var newblk = function ba_newblk(sz) {
          var o = new_buf(sz);
          prep_blob(o, 0);
          return o;
        };
        var curbuf = newblk(blksz);
        var endbuf = function ba_endbuf() {
          if (!curbuf)
            return;
          if (curbuf.length > curbuf.l) {
            curbuf = curbuf.slice(0, curbuf.l);
            curbuf.l = curbuf.length;
          }
          if (curbuf.length > 0)
            bufs.push(curbuf);
          curbuf = null;
        };
        var next = function ba_next(sz) {
          if (curbuf && sz < curbuf.length - curbuf.l)
            return curbuf;
          endbuf();
          return curbuf = newblk(Math.max(sz + 1, blksz));
        };
        var end = function ba_end() {
          endbuf();
          return bconcat(bufs);
        };
        var push = function ba_push(buf) {
          endbuf();
          curbuf = buf;
          if (curbuf.l == null)
            curbuf.l = curbuf.length;
          next(blksz);
        };
        return { next, push, end, _bufs: bufs };
      }
      function write_record(ba, type, payload, length) {
        var t3 = +type, l;
        if (isNaN(t3))
          return;
        if (!length)
          length = XLSBRecordEnum[t3].p || (payload || []).length || 0;
        l = 1 + (t3 >= 128 ? 1 : 0) + 1;
        if (length >= 128)
          ++l;
        if (length >= 16384)
          ++l;
        if (length >= 2097152)
          ++l;
        var o = ba.next(l);
        if (t3 <= 127)
          o.write_shift(1, t3);
        else {
          o.write_shift(1, (t3 & 127) + 128);
          o.write_shift(1, t3 >> 7);
        }
        for (var i = 0; i != 4; ++i) {
          if (length >= 128) {
            o.write_shift(1, (length & 127) + 128);
            length >>= 7;
          } else {
            o.write_shift(1, length);
            break;
          }
        }
        if (length > 0 && is_buf(payload))
          ba.push(payload);
      }
      function shift_cell_xls(cell, tgt, opts) {
        var out = dup(cell);
        if (tgt.s) {
          if (out.cRel)
            out.c += tgt.s.c;
          if (out.rRel)
            out.r += tgt.s.r;
        } else {
          if (out.cRel)
            out.c += tgt.c;
          if (out.rRel)
            out.r += tgt.r;
        }
        if (!opts || opts.biff < 12) {
          while (out.c >= 256)
            out.c -= 256;
          while (out.r >= 65536)
            out.r -= 65536;
        }
        return out;
      }
      function shift_range_xls(cell, range, opts) {
        var out = dup(cell);
        out.s = shift_cell_xls(out.s, range.s, opts);
        out.e = shift_cell_xls(out.e, range.s, opts);
        return out;
      }
      function encode_cell_xls(c, biff) {
        if (c.cRel && c.c < 0) {
          c = dup(c);
          while (c.c < 0)
            c.c += biff > 8 ? 16384 : 256;
        }
        if (c.rRel && c.r < 0) {
          c = dup(c);
          while (c.r < 0)
            c.r += biff > 8 ? 1048576 : biff > 5 ? 65536 : 16384;
        }
        var s = encode_cell(c);
        if (!c.cRel && c.cRel != null)
          s = fix_col(s);
        if (!c.rRel && c.rRel != null)
          s = fix_row(s);
        return s;
      }
      function encode_range_xls(r, opts) {
        if (r.s.r == 0 && !r.s.rRel) {
          if (r.e.r == (opts.biff >= 12 ? 1048575 : opts.biff >= 8 ? 65536 : 16384) && !r.e.rRel) {
            return (r.s.cRel ? "" : "$") + encode_col(r.s.c) + ":" + (r.e.cRel ? "" : "$") + encode_col(r.e.c);
          }
        }
        if (r.s.c == 0 && !r.s.cRel) {
          if (r.e.c == (opts.biff >= 12 ? 16383 : 255) && !r.e.cRel) {
            return (r.s.rRel ? "" : "$") + encode_row(r.s.r) + ":" + (r.e.rRel ? "" : "$") + encode_row(r.e.r);
          }
        }
        return encode_cell_xls(r.s, opts.biff) + ":" + encode_cell_xls(r.e, opts.biff);
      }
      function decode_row(rowstr) {
        return parseInt(unfix_row(rowstr), 10) - 1;
      }
      function encode_row(row) {
        return "" + (row + 1);
      }
      function fix_row(cstr) {
        return cstr.replace(/([A-Z]|^)(\d+)$/, "$1$$$2");
      }
      function unfix_row(cstr) {
        return cstr.replace(/\$(\d+)$/, "$1");
      }
      function decode_col(colstr) {
        var c = unfix_col(colstr), d = 0, i = 0;
        for (; i !== c.length; ++i)
          d = 26 * d + c.charCodeAt(i) - 64;
        return d - 1;
      }
      function encode_col(col) {
        if (col < 0)
          throw new Error("invalid column " + col);
        var s = "";
        for (++col; col; col = Math.floor((col - 1) / 26))
          s = String.fromCharCode((col - 1) % 26 + 65) + s;
        return s;
      }
      function fix_col(cstr) {
        return cstr.replace(/^([A-Z])/, "$$$1");
      }
      function unfix_col(cstr) {
        return cstr.replace(/^\$([A-Z])/, "$1");
      }
      function split_cell(cstr) {
        return cstr.replace(/(\$?[A-Z]*)(\$?\d*)/, "$1,$2").split(",");
      }
      function decode_cell(cstr) {
        var R = 0, C = 0;
        for (var i = 0; i < cstr.length; ++i) {
          var cc = cstr.charCodeAt(i);
          if (cc >= 48 && cc <= 57)
            R = 10 * R + (cc - 48);
          else if (cc >= 65 && cc <= 90)
            C = 26 * C + (cc - 64);
        }
        return { c: C - 1, r: R - 1 };
      }
      function encode_cell(cell) {
        var col = cell.c + 1;
        var s = "";
        for (; col; col = (col - 1) / 26 | 0)
          s = String.fromCharCode((col - 1) % 26 + 65) + s;
        return s + (cell.r + 1);
      }
      function decode_range(range) {
        var idx = range.indexOf(":");
        if (idx == -1)
          return { s: decode_cell(range), e: decode_cell(range) };
        return { s: decode_cell(range.slice(0, idx)), e: decode_cell(range.slice(idx + 1)) };
      }
      function encode_range(cs, ce) {
        if (typeof ce === "undefined" || typeof ce === "number") {
          return encode_range(cs.s, cs.e);
        }
        if (typeof cs !== "string")
          cs = encode_cell(cs);
        if (typeof ce !== "string")
          ce = encode_cell(ce);
        return cs == ce ? cs : cs + ":" + ce;
      }
      function safe_decode_range(range) {
        var o = { s: { c: 0, r: 0 }, e: { c: 0, r: 0 } };
        var idx = 0, i = 0, cc = 0;
        var len = range.length;
        for (idx = 0; i < len; ++i) {
          if ((cc = range.charCodeAt(i) - 64) < 1 || cc > 26)
            break;
          idx = 26 * idx + cc;
        }
        o.s.c = --idx;
        for (idx = 0; i < len; ++i) {
          if ((cc = range.charCodeAt(i) - 48) < 0 || cc > 9)
            break;
          idx = 10 * idx + cc;
        }
        o.s.r = --idx;
        if (i === len || cc != 10) {
          o.e.c = o.s.c;
          o.e.r = o.s.r;
          return o;
        }
        ++i;
        for (idx = 0; i != len; ++i) {
          if ((cc = range.charCodeAt(i) - 64) < 1 || cc > 26)
            break;
          idx = 26 * idx + cc;
        }
        o.e.c = --idx;
        for (idx = 0; i != len; ++i) {
          if ((cc = range.charCodeAt(i) - 48) < 0 || cc > 9)
            break;
          idx = 10 * idx + cc;
        }
        o.e.r = --idx;
        return o;
      }
      function safe_format_cell(cell, v) {
        var q = cell.t == "d" && v instanceof Date;
        if (cell.z != null)
          try {
            return cell.w = SSF_format(cell.z, q ? datenum(v) : v);
          } catch (e) {
          }
        try {
          return cell.w = SSF_format((cell.XF || {}).numFmtId || (q ? 14 : 0), q ? datenum(v) : v);
        } catch (e) {
          return "" + v;
        }
      }
      function format_cell(cell, v, o) {
        if (cell == null || cell.t == null || cell.t == "z")
          return "";
        if (cell.w !== void 0)
          return cell.w;
        if (cell.t == "d" && !cell.z && o && o.dateNF)
          cell.z = o.dateNF;
        if (cell.t == "e")
          return BErr[cell.v] || cell.v;
        if (v == void 0)
          return safe_format_cell(cell, cell.v);
        return safe_format_cell(cell, v);
      }
      function sheet_to_workbook(sheet, opts) {
        var n = opts && opts.sheet ? opts.sheet : "Sheet1";
        var sheets = {};
        sheets[n] = sheet;
        return { SheetNames: [n], Sheets: sheets };
      }
      function sheet_add_aoa(_ws, data, opts) {
        var o = opts || {};
        var dense = _ws ? Array.isArray(_ws) : o.dense;
        if (DENSE != null && dense == null)
          dense = DENSE;
        var ws = _ws || (dense ? [] : {});
        var _R = 0, _C = 0;
        if (ws && o.origin != null) {
          if (typeof o.origin == "number")
            _R = o.origin;
          else {
            var _origin = typeof o.origin == "string" ? decode_cell(o.origin) : o.origin;
            _R = _origin.r;
            _C = _origin.c;
          }
          if (!ws["!ref"])
            ws["!ref"] = "A1:A1";
        }
        var range = { s: { c: 1e7, r: 1e7 }, e: { c: 0, r: 0 } };
        if (ws["!ref"]) {
          var _range = safe_decode_range(ws["!ref"]);
          range.s.c = _range.s.c;
          range.s.r = _range.s.r;
          range.e.c = Math.max(range.e.c, _range.e.c);
          range.e.r = Math.max(range.e.r, _range.e.r);
          if (_R == -1)
            range.e.r = _R = _range.e.r + 1;
        }
        for (var R = 0; R != data.length; ++R) {
          if (!data[R])
            continue;
          if (!Array.isArray(data[R]))
            throw new Error("aoa_to_sheet expects an array of arrays");
          for (var C = 0; C != data[R].length; ++C) {
            if (typeof data[R][C] === "undefined")
              continue;
            var cell = { v: data[R][C] };
            var __R = _R + R, __C = _C + C;
            if (range.s.r > __R)
              range.s.r = __R;
            if (range.s.c > __C)
              range.s.c = __C;
            if (range.e.r < __R)
              range.e.r = __R;
            if (range.e.c < __C)
              range.e.c = __C;
            if (data[R][C] && typeof data[R][C] === "object" && !Array.isArray(data[R][C]) && !(data[R][C] instanceof Date))
              cell = data[R][C];
            else {
              if (Array.isArray(cell.v)) {
                cell.f = data[R][C][1];
                cell.v = cell.v[0];
              }
              if (cell.v === null) {
                if (cell.f)
                  cell.t = "n";
                else if (o.nullError) {
                  cell.t = "e";
                  cell.v = 0;
                } else if (!o.sheetStubs)
                  continue;
                else
                  cell.t = "z";
              } else if (typeof cell.v === "number")
                cell.t = "n";
              else if (typeof cell.v === "boolean")
                cell.t = "b";
              else if (cell.v instanceof Date) {
                cell.z = o.dateNF || table_fmt[14];
                if (o.cellDates) {
                  cell.t = "d";
                  cell.w = SSF_format(cell.z, datenum(cell.v));
                } else {
                  cell.t = "n";
                  cell.v = datenum(cell.v);
                  cell.w = SSF_format(cell.z, cell.v);
                }
              } else
                cell.t = "s";
            }
            if (dense) {
              if (!ws[__R])
                ws[__R] = [];
              if (ws[__R][__C] && ws[__R][__C].z)
                cell.z = ws[__R][__C].z;
              ws[__R][__C] = cell;
            } else {
              var cell_ref = encode_cell({ c: __C, r: __R });
              if (ws[cell_ref] && ws[cell_ref].z)
                cell.z = ws[cell_ref].z;
              ws[cell_ref] = cell;
            }
          }
        }
        if (range.s.c < 1e7)
          ws["!ref"] = encode_range(range);
        return ws;
      }
      function aoa_to_sheet(data, opts) {
        return sheet_add_aoa(null, data, opts);
      }
      function parse_Int32LE(data) {
        return data.read_shift(4, "i");
      }
      function write_UInt32LE(x, o) {
        if (!o)
          o = new_buf(4);
        o.write_shift(4, x);
        return o;
      }
      function parse_XLWideString(data) {
        var cchCharacters = data.read_shift(4);
        return cchCharacters === 0 ? "" : data.read_shift(cchCharacters, "dbcs");
      }
      function write_XLWideString(data, o) {
        var _null = false;
        if (o == null) {
          _null = true;
          o = new_buf(4 + 2 * data.length);
        }
        o.write_shift(4, data.length);
        if (data.length > 0)
          o.write_shift(0, data, "dbcs");
        return _null ? o.slice(0, o.l) : o;
      }
      function parse_StrRun(data) {
        return { ich: data.read_shift(2), ifnt: data.read_shift(2) };
      }
      function write_StrRun(run, o) {
        if (!o)
          o = new_buf(4);
        o.write_shift(2, run.ich || 0);
        o.write_shift(2, run.ifnt || 0);
        return o;
      }
      function parse_RichStr(data, length) {
        var start = data.l;
        var flags = data.read_shift(1);
        var str = parse_XLWideString(data);
        var rgsStrRun = [];
        var z = { t: str, h: str };
        if ((flags & 1) !== 0) {
          var dwSizeStrRun = data.read_shift(4);
          for (var i = 0; i != dwSizeStrRun; ++i)
            rgsStrRun.push(parse_StrRun(data));
          z.r = rgsStrRun;
        } else
          z.r = [{ ich: 0, ifnt: 0 }];
        data.l = start + length;
        return z;
      }
      function write_RichStr(str, o) {
        var _null = false;
        if (o == null) {
          _null = true;
          o = new_buf(15 + 4 * str.t.length);
        }
        o.write_shift(1, 0);
        write_XLWideString(str.t, o);
        return _null ? o.slice(0, o.l) : o;
      }
      var parse_BrtCommentText = parse_RichStr;
      function write_BrtCommentText(str, o) {
        var _null = false;
        if (o == null) {
          _null = true;
          o = new_buf(23 + 4 * str.t.length);
        }
        o.write_shift(1, 1);
        write_XLWideString(str.t, o);
        o.write_shift(4, 1);
        write_StrRun({ ich: 0, ifnt: 0 }, o);
        return _null ? o.slice(0, o.l) : o;
      }
      function parse_XLSBCell(data) {
        var col = data.read_shift(4);
        var iStyleRef = data.read_shift(2);
        iStyleRef += data.read_shift(1) << 16;
        data.l++;
        return { c: col, iStyleRef };
      }
      function write_XLSBCell(cell, o) {
        if (o == null)
          o = new_buf(8);
        o.write_shift(-4, cell.c);
        o.write_shift(3, cell.iStyleRef || cell.s);
        o.write_shift(1, 0);
        return o;
      }
      function parse_XLSBShortCell(data) {
        var iStyleRef = data.read_shift(2);
        iStyleRef += data.read_shift(1) << 16;
        data.l++;
        return { c: -1, iStyleRef };
      }
      function write_XLSBShortCell(cell, o) {
        if (o == null)
          o = new_buf(4);
        o.write_shift(3, cell.iStyleRef || cell.s);
        o.write_shift(1, 0);
        return o;
      }
      var parse_XLSBCodeName = parse_XLWideString;
      var write_XLSBCodeName = write_XLWideString;
      function parse_XLNullableWideString(data) {
        var cchCharacters = data.read_shift(4);
        return cchCharacters === 0 || cchCharacters === 4294967295 ? "" : data.read_shift(cchCharacters, "dbcs");
      }
      function write_XLNullableWideString(data, o) {
        var _null = false;
        if (o == null) {
          _null = true;
          o = new_buf(127);
        }
        o.write_shift(4, data.length > 0 ? data.length : 4294967295);
        if (data.length > 0)
          o.write_shift(0, data, "dbcs");
        return _null ? o.slice(0, o.l) : o;
      }
      var parse_XLNameWideString = parse_XLWideString;
      var parse_RelID = parse_XLNullableWideString;
      var write_RelID = write_XLNullableWideString;
      function parse_RkNumber(data) {
        var b = data.slice(data.l, data.l + 4);
        var fX100 = b[0] & 1, fInt = b[0] & 2;
        data.l += 4;
        var RK = fInt === 0 ? __double([0, 0, 0, 0, b[0] & 252, b[1], b[2], b[3]], 0) : __readInt32LE(b, 0) >> 2;
        return fX100 ? RK / 100 : RK;
      }
      function write_RkNumber(data, o) {
        if (o == null)
          o = new_buf(4);
        var fX100 = 0, fInt = 0, d100 = data * 100;
        if (data == (data | 0) && data >= -(1 << 29) && data < 1 << 29) {
          fInt = 1;
        } else if (d100 == (d100 | 0) && d100 >= -(1 << 29) && d100 < 1 << 29) {
          fInt = 1;
          fX100 = 1;
        }
        if (fInt)
          o.write_shift(-4, ((fX100 ? d100 : data) << 2) + (fX100 + 2));
        else
          throw new Error("unsupported RkNumber " + data);
      }
      function parse_RfX(data) {
        var cell = { s: {}, e: {} };
        cell.s.r = data.read_shift(4);
        cell.e.r = data.read_shift(4);
        cell.s.c = data.read_shift(4);
        cell.e.c = data.read_shift(4);
        return cell;
      }
      function write_RfX(r, o) {
        if (!o)
          o = new_buf(16);
        o.write_shift(4, r.s.r);
        o.write_shift(4, r.e.r);
        o.write_shift(4, r.s.c);
        o.write_shift(4, r.e.c);
        return o;
      }
      var parse_UncheckedRfX = parse_RfX;
      var write_UncheckedRfX = write_RfX;
      function parse_Xnum(data) {
        if (data.length - data.l < 8)
          throw "XLS Xnum Buffer underflow";
        return data.read_shift(8, "f");
      }
      function write_Xnum(data, o) {
        return (o || new_buf(8)).write_shift(8, data, "f");
      }
      function parse_BrtColor(data) {
        var out = {};
        var d = data.read_shift(1);
        var xColorType = d >>> 1;
        var index = data.read_shift(1);
        var nTS = data.read_shift(2, "i");
        var bR = data.read_shift(1);
        var bG = data.read_shift(1);
        var bB = data.read_shift(1);
        data.l++;
        switch (xColorType) {
          case 0:
            out.auto = 1;
            break;
          case 1:
            out.index = index;
            var icv = XLSIcv[index];
            if (icv)
              out.rgb = rgb2Hex(icv);
            break;
          case 2:
            out.rgb = rgb2Hex([bR, bG, bB]);
            break;
          case 3:
            out.theme = index;
            break;
        }
        if (nTS != 0)
          out.tint = nTS > 0 ? nTS / 32767 : nTS / 32768;
        return out;
      }
      function write_BrtColor(color, o) {
        if (!o)
          o = new_buf(8);
        if (!color || color.auto) {
          o.write_shift(4, 0);
          o.write_shift(4, 0);
          return o;
        }
        if (color.index != null) {
          o.write_shift(1, 2);
          o.write_shift(1, color.index);
        } else if (color.theme != null) {
          o.write_shift(1, 6);
          o.write_shift(1, color.theme);
        } else {
          o.write_shift(1, 5);
          o.write_shift(1, 0);
        }
        var nTS = color.tint || 0;
        if (nTS > 0)
          nTS *= 32767;
        else if (nTS < 0)
          nTS *= 32768;
        o.write_shift(2, nTS);
        if (!color.rgb || color.theme != null) {
          o.write_shift(2, 0);
          o.write_shift(1, 0);
          o.write_shift(1, 0);
        } else {
          var rgb = color.rgb || "FFFFFF";
          if (typeof rgb == "number")
            rgb = ("000000" + rgb.toString(16)).slice(-6);
          o.write_shift(1, parseInt(rgb.slice(0, 2), 16));
          o.write_shift(1, parseInt(rgb.slice(2, 4), 16));
          o.write_shift(1, parseInt(rgb.slice(4, 6), 16));
          o.write_shift(1, 255);
        }
        return o;
      }
      function parse_FontFlags(data) {
        var d = data.read_shift(1);
        data.l++;
        var out = {
          fBold: d & 1,
          fItalic: d & 2,
          fUnderline: d & 4,
          fStrikeout: d & 8,
          fOutline: d & 16,
          fShadow: d & 32,
          fCondense: d & 64,
          fExtend: d & 128
        };
        return out;
      }
      function write_FontFlags(font, o) {
        if (!o)
          o = new_buf(2);
        var grbit = (font.italic ? 2 : 0) | (font.strike ? 8 : 0) | (font.outline ? 16 : 0) | (font.shadow ? 32 : 0) | (font.condense ? 64 : 0) | (font.extend ? 128 : 0);
        o.write_shift(1, grbit);
        o.write_shift(1, 0);
        return o;
      }
      function parse_ClipboardFormatOrString(o, w) {
        var ClipFmt = { 2: "BITMAP", 3: "METAFILEPICT", 8: "DIB", 14: "ENHMETAFILE" };
        var m = o.read_shift(4);
        switch (m) {
          case 0:
            return "";
          case 4294967295:
          case 4294967294:
            return ClipFmt[o.read_shift(4)] || "";
        }
        if (m > 400)
          throw new Error("Unsupported Clipboard: " + m.toString(16));
        o.l -= 4;
        return o.read_shift(0, w == 1 ? "lpstr" : "lpwstr");
      }
      function parse_ClipboardFormatOrAnsiString(o) {
        return parse_ClipboardFormatOrString(o, 1);
      }
      function parse_ClipboardFormatOrUnicodeString(o) {
        return parse_ClipboardFormatOrString(o, 2);
      }
      var VT_I2 = 2;
      var VT_I4 = 3;
      var VT_BOOL = 11;
      var VT_VARIANT = 12;
      var VT_UI4 = 19;
      var VT_LPSTR = 30;
      var VT_FILETIME = 64;
      var VT_BLOB = 65;
      var VT_CF = 71;
      var VT_VECTOR = 4096;
      var VT_VECTOR_VARIANT = 4108;
      var VT_VECTOR_LPSTR = 4126;
      var VT_STRING = 80;
      var VT_USTR = 81;
      var VT_CUSTOM = [VT_STRING, VT_USTR];
      var DocSummaryPIDDSI = {
        1: { n: "CodePage", t: VT_I2 },
        2: { n: "Category", t: VT_STRING },
        3: { n: "PresentationFormat", t: VT_STRING },
        4: { n: "ByteCount", t: VT_I4 },
        5: { n: "LineCount", t: VT_I4 },
        6: { n: "ParagraphCount", t: VT_I4 },
        7: { n: "SlideCount", t: VT_I4 },
        8: { n: "NoteCount", t: VT_I4 },
        9: { n: "HiddenCount", t: VT_I4 },
        10: { n: "MultimediaClipCount", t: VT_I4 },
        11: { n: "ScaleCrop", t: VT_BOOL },
        12: {
          n: "HeadingPairs",
          t: VT_VECTOR_VARIANT
          /* VT_VECTOR | VT_VARIANT */
        },
        13: {
          n: "TitlesOfParts",
          t: VT_VECTOR_LPSTR
          /* VT_VECTOR | VT_LPSTR */
        },
        14: { n: "Manager", t: VT_STRING },
        15: { n: "Company", t: VT_STRING },
        16: { n: "LinksUpToDate", t: VT_BOOL },
        17: { n: "CharacterCount", t: VT_I4 },
        19: { n: "SharedDoc", t: VT_BOOL },
        22: { n: "HyperlinksChanged", t: VT_BOOL },
        23: { n: "AppVersion", t: VT_I4, p: "version" },
        24: { n: "DigSig", t: VT_BLOB },
        26: { n: "ContentType", t: VT_STRING },
        27: { n: "ContentStatus", t: VT_STRING },
        28: { n: "Language", t: VT_STRING },
        29: { n: "Version", t: VT_STRING },
        255: {},
        /* [MS-OLEPS] 2.18 */
        2147483648: { n: "Locale", t: VT_UI4 },
        2147483651: { n: "Behavior", t: VT_UI4 },
        1919054434: {}
      };
      var SummaryPIDSI = {
        1: { n: "CodePage", t: VT_I2 },
        2: { n: "Title", t: VT_STRING },
        3: { n: "Subject", t: VT_STRING },
        4: { n: "Author", t: VT_STRING },
        5: { n: "Keywords", t: VT_STRING },
        6: { n: "Comments", t: VT_STRING },
        7: { n: "Template", t: VT_STRING },
        8: { n: "LastAuthor", t: VT_STRING },
        9: { n: "RevNumber", t: VT_STRING },
        10: { n: "EditTime", t: VT_FILETIME },
        11: { n: "LastPrinted", t: VT_FILETIME },
        12: { n: "CreatedDate", t: VT_FILETIME },
        13: { n: "ModifiedDate", t: VT_FILETIME },
        14: { n: "PageCount", t: VT_I4 },
        15: { n: "WordCount", t: VT_I4 },
        16: { n: "CharCount", t: VT_I4 },
        17: { n: "Thumbnail", t: VT_CF },
        18: { n: "Application", t: VT_STRING },
        19: { n: "DocSecurity", t: VT_I4 },
        255: {},
        /* [MS-OLEPS] 2.18 */
        2147483648: { n: "Locale", t: VT_UI4 },
        2147483651: { n: "Behavior", t: VT_UI4 },
        1919054434: {}
      };
      var CountryEnum = {
        1: "US",
        // United States
        2: "CA",
        // Canada
        3: "",
        // Latin America (except Brazil)
        7: "RU",
        // Russia
        20: "EG",
        // Egypt
        30: "GR",
        // Greece
        31: "NL",
        // Netherlands
        32: "BE",
        // Belgium
        33: "FR",
        // France
        34: "ES",
        // Spain
        36: "HU",
        // Hungary
        39: "IT",
        // Italy
        41: "CH",
        // Switzerland
        43: "AT",
        // Austria
        44: "GB",
        // United Kingdom
        45: "DK",
        // Denmark
        46: "SE",
        // Sweden
        47: "NO",
        // Norway
        48: "PL",
        // Poland
        49: "DE",
        // Germany
        52: "MX",
        // Mexico
        55: "BR",
        // Brazil
        61: "AU",
        // Australia
        64: "NZ",
        // New Zealand
        66: "TH",
        // Thailand
        81: "JP",
        // Japan
        82: "KR",
        // Korea
        84: "VN",
        // Viet Nam
        86: "CN",
        // China
        90: "TR",
        // Turkey
        105: "JS",
        // Ramastan
        213: "DZ",
        // Algeria
        216: "MA",
        // Morocco
        218: "LY",
        // Libya
        351: "PT",
        // Portugal
        354: "IS",
        // Iceland
        358: "FI",
        // Finland
        420: "CZ",
        // Czech Republic
        886: "TW",
        // Taiwan
        961: "LB",
        // Lebanon
        962: "JO",
        // Jordan
        963: "SY",
        // Syria
        964: "IQ",
        // Iraq
        965: "KW",
        // Kuwait
        966: "SA",
        // Saudi Arabia
        971: "AE",
        // United Arab Emirates
        972: "IL",
        // Israel
        974: "QA",
        // Qatar
        981: "IR",
        // Iran
        65535: "US"
        // United States
      };
      var XLSFillPattern = [
        null,
        "solid",
        "mediumGray",
        "darkGray",
        "lightGray",
        "darkHorizontal",
        "darkVertical",
        "darkDown",
        "darkUp",
        "darkGrid",
        "darkTrellis",
        "lightHorizontal",
        "lightVertical",
        "lightDown",
        "lightUp",
        "lightGrid",
        "lightTrellis",
        "gray125",
        "gray0625"
      ];
      function rgbify(arr) {
        return arr.map(function(x) {
          return [x >> 16 & 255, x >> 8 & 255, x & 255];
        });
      }
      var _XLSIcv = rgbify([
        /* Color Constants */
        0,
        16777215,
        16711680,
        65280,
        255,
        16776960,
        16711935,
        65535,
        /* Overridable Defaults */
        0,
        16777215,
        16711680,
        65280,
        255,
        16776960,
        16711935,
        65535,
        8388608,
        32768,
        128,
        8421376,
        8388736,
        32896,
        12632256,
        8421504,
        10066431,
        10040166,
        16777164,
        13434879,
        6684774,
        16744576,
        26316,
        13421823,
        128,
        16711935,
        16776960,
        65535,
        8388736,
        8388608,
        32896,
        255,
        52479,
        13434879,
        13434828,
        16777113,
        10079487,
        16751052,
        13408767,
        16764057,
        3368703,
        3394764,
        10079232,
        16763904,
        16750848,
        16737792,
        6710937,
        9868950,
        13158,
        3381606,
        13056,
        3355392,
        10040064,
        10040166,
        3355545,
        3355443,
        /* Other entries to appease BIFF8/12 */
        16777215,
        /* 0x40 icvForeground ?? */
        0,
        /* 0x41 icvBackground ?? */
        0,
        /* 0x42 icvFrame ?? */
        0,
        /* 0x43 icv3D ?? */
        0,
        /* 0x44 icv3DText ?? */
        0,
        /* 0x45 icv3DHilite ?? */
        0,
        /* 0x46 icv3DShadow ?? */
        0,
        /* 0x47 icvHilite ?? */
        0,
        /* 0x48 icvCtlText ?? */
        0,
        /* 0x49 icvCtlScrl ?? */
        0,
        /* 0x4A icvCtlInv ?? */
        0,
        /* 0x4B icvCtlBody ?? */
        0,
        /* 0x4C icvCtlFrame ?? */
        0,
        /* 0x4D icvCtlFore ?? */
        0,
        /* 0x4E icvCtlBack ?? */
        0,
        /* 0x4F icvCtlNeutral */
        0,
        /* 0x50 icvInfoBk ?? */
        0
        /* 0x51 icvInfoText ?? */
      ]);
      var XLSIcv = dup(_XLSIcv);
      var BErr = {
        0: "#NULL!",
        7: "#DIV/0!",
        15: "#VALUE!",
        23: "#REF!",
        29: "#NAME?",
        36: "#NUM!",
        42: "#N/A",
        43: "#GETTING_DATA",
        255: "#WTF?"
      };
      var RBErr = {
        "#NULL!": 0,
        "#DIV/0!": 7,
        "#VALUE!": 15,
        "#REF!": 23,
        "#NAME?": 29,
        "#NUM!": 36,
        "#N/A": 42,
        "#GETTING_DATA": 43,
        "#WTF?": 255
      };
      var ct2type = {
        /* Workbook */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml": "workbooks",
        "application/vnd.ms-excel.sheet.macroEnabled.main+xml": "workbooks",
        "application/vnd.ms-excel.sheet.binary.macroEnabled.main": "workbooks",
        "application/vnd.ms-excel.addin.macroEnabled.main+xml": "workbooks",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml": "workbooks",
        /* Worksheet */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml": "sheets",
        "application/vnd.ms-excel.worksheet": "sheets",
        "application/vnd.ms-excel.binIndexWs": "TODO",
        /* Binary Index */
        /* Chartsheet */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.chartsheet+xml": "charts",
        "application/vnd.ms-excel.chartsheet": "charts",
        /* Macrosheet */
        "application/vnd.ms-excel.macrosheet+xml": "macros",
        "application/vnd.ms-excel.macrosheet": "macros",
        "application/vnd.ms-excel.intlmacrosheet": "TODO",
        "application/vnd.ms-excel.binIndexMs": "TODO",
        /* Binary Index */
        /* Dialogsheet */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.dialogsheet+xml": "dialogs",
        "application/vnd.ms-excel.dialogsheet": "dialogs",
        /* Shared Strings */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml": "strs",
        "application/vnd.ms-excel.sharedStrings": "strs",
        /* Styles */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml": "styles",
        "application/vnd.ms-excel.styles": "styles",
        /* File Properties */
        "application/vnd.openxmlformats-package.core-properties+xml": "coreprops",
        "application/vnd.openxmlformats-officedocument.custom-properties+xml": "custprops",
        "application/vnd.openxmlformats-officedocument.extended-properties+xml": "extprops",
        /* Custom Data Properties */
        "application/vnd.openxmlformats-officedocument.customXmlProperties+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.customProperty": "TODO",
        /* Comments */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml": "comments",
        "application/vnd.ms-excel.comments": "comments",
        "application/vnd.ms-excel.threadedcomments+xml": "threadedcomments",
        "application/vnd.ms-excel.person+xml": "people",
        /* Metadata (Stock/Geography and Dynamic Array) */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheetMetadata+xml": "metadata",
        "application/vnd.ms-excel.sheetMetadata": "metadata",
        /* PivotTable */
        "application/vnd.ms-excel.pivotTable": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotTable+xml": "TODO",
        /* Chart Objects */
        "application/vnd.openxmlformats-officedocument.drawingml.chart+xml": "TODO",
        /* Chart Colors */
        "application/vnd.ms-office.chartcolorstyle+xml": "TODO",
        /* Chart Style */
        "application/vnd.ms-office.chartstyle+xml": "TODO",
        /* Chart Advanced */
        "application/vnd.ms-office.chartex+xml": "TODO",
        /* Calculation Chain */
        "application/vnd.ms-excel.calcChain": "calcchains",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.calcChain+xml": "calcchains",
        /* Printer Settings */
        "application/vnd.openxmlformats-officedocument.spreadsheetml.printerSettings": "TODO",
        /* ActiveX */
        "application/vnd.ms-office.activeX": "TODO",
        "application/vnd.ms-office.activeX+xml": "TODO",
        /* Custom Toolbars */
        "application/vnd.ms-excel.attachedToolbars": "TODO",
        /* External Data Connections */
        "application/vnd.ms-excel.connections": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.connections+xml": "TODO",
        /* External Links */
        "application/vnd.ms-excel.externalLink": "links",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.externalLink+xml": "links",
        /* PivotCache */
        "application/vnd.ms-excel.pivotCacheDefinition": "TODO",
        "application/vnd.ms-excel.pivotCacheRecords": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheDefinition+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheRecords+xml": "TODO",
        /* Query Table */
        "application/vnd.ms-excel.queryTable": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.queryTable+xml": "TODO",
        /* Shared Workbook */
        "application/vnd.ms-excel.userNames": "TODO",
        "application/vnd.ms-excel.revisionHeaders": "TODO",
        "application/vnd.ms-excel.revisionLog": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.revisionHeaders+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.revisionLog+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.userNames+xml": "TODO",
        /* Single Cell Table */
        "application/vnd.ms-excel.tableSingleCells": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.tableSingleCells+xml": "TODO",
        /* Slicer */
        "application/vnd.ms-excel.slicer": "TODO",
        "application/vnd.ms-excel.slicerCache": "TODO",
        "application/vnd.ms-excel.slicer+xml": "TODO",
        "application/vnd.ms-excel.slicerCache+xml": "TODO",
        /* Sort Map */
        "application/vnd.ms-excel.wsSortMap": "TODO",
        /* Table */
        "application/vnd.ms-excel.table": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.table+xml": "TODO",
        /* Themes */
        "application/vnd.openxmlformats-officedocument.theme+xml": "themes",
        /* Theme Override */
        "application/vnd.openxmlformats-officedocument.themeOverride+xml": "TODO",
        /* Timeline */
        "application/vnd.ms-excel.Timeline+xml": "TODO",
        /* verify */
        "application/vnd.ms-excel.TimelineCache+xml": "TODO",
        /* verify */
        /* VBA */
        "application/vnd.ms-office.vbaProject": "vba",
        "application/vnd.ms-office.vbaProjectSignature": "TODO",
        /* Volatile Dependencies */
        "application/vnd.ms-office.volatileDependencies": "TODO",
        "application/vnd.openxmlformats-officedocument.spreadsheetml.volatileDependencies+xml": "TODO",
        /* Control Properties */
        "application/vnd.ms-excel.controlproperties+xml": "TODO",
        /* Data Model */
        "application/vnd.openxmlformats-officedocument.model+data": "TODO",
        /* Survey */
        "application/vnd.ms-excel.Survey+xml": "TODO",
        /* Drawing */
        "application/vnd.openxmlformats-officedocument.drawing+xml": "drawings",
        "application/vnd.openxmlformats-officedocument.drawingml.chartshapes+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.drawingml.diagramColors+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.drawingml.diagramData+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.drawingml.diagramLayout+xml": "TODO",
        "application/vnd.openxmlformats-officedocument.drawingml.diagramStyle+xml": "TODO",
        /* VML */
        "application/vnd.openxmlformats-officedocument.vmlDrawing": "TODO",
        "application/vnd.openxmlformats-package.relationships+xml": "rels",
        "application/vnd.openxmlformats-officedocument.oleObject": "TODO",
        /* Image */
        "image/png": "TODO",
        "sheet": "js"
      };
      var CT_LIST = {
        workbooks: {
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml",
          xlsm: "application/vnd.ms-excel.sheet.macroEnabled.main+xml",
          xlsb: "application/vnd.ms-excel.sheet.binary.macroEnabled.main",
          xlam: "application/vnd.ms-excel.addin.macroEnabled.main+xml",
          xltx: "application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml"
        },
        strs: {
          /* Shared Strings */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml",
          xlsb: "application/vnd.ms-excel.sharedStrings"
        },
        comments: {
          /* Comments */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml",
          xlsb: "application/vnd.ms-excel.comments"
        },
        sheets: {
          /* Worksheet */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml",
          xlsb: "application/vnd.ms-excel.worksheet"
        },
        charts: {
          /* Chartsheet */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.chartsheet+xml",
          xlsb: "application/vnd.ms-excel.chartsheet"
        },
        dialogs: {
          /* Dialogsheet */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.dialogsheet+xml",
          xlsb: "application/vnd.ms-excel.dialogsheet"
        },
        macros: {
          /* Macrosheet (Excel 4.0 Macros) */
          xlsx: "application/vnd.ms-excel.macrosheet+xml",
          xlsb: "application/vnd.ms-excel.macrosheet"
        },
        metadata: {
          /* Metadata (Stock/Geography and Dynamic Array) */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.sheetMetadata+xml",
          xlsb: "application/vnd.ms-excel.sheetMetadata"
        },
        styles: {
          /* Styles */
          xlsx: "application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml",
          xlsb: "application/vnd.ms-excel.styles"
        }
      };
      function new_ct() {
        return {
          workbooks: [],
          sheets: [],
          charts: [],
          dialogs: [],
          macros: [],
          rels: [],
          strs: [],
          comments: [],
          threadedcomments: [],
          links: [],
          coreprops: [],
          extprops: [],
          custprops: [],
          themes: [],
          styles: [],
          calcchains: [],
          vba: [],
          drawings: [],
          metadata: [],
          people: [],
          TODO: [],
          xmlns: ""
        };
      }
      function parse_ct(data) {
        var ct = new_ct();
        if (!data || !data.match)
          return ct;
        var ctext = {};
        (data.match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (y[0].replace(nsregex, "<")) {
            case "<?xml":
              break;
            case "<Types":
              ct.xmlns = y["xmlns" + (y[0].match(/<(\w+):/) || ["", ""])[1]];
              break;
            case "<Default":
              ctext[y.Extension] = y.ContentType;
              break;
            case "<Override":
              if (ct[ct2type[y.ContentType]] !== void 0)
                ct[ct2type[y.ContentType]].push(y.PartName);
              break;
          }
        });
        if (ct.xmlns !== XMLNS.CT)
          throw new Error("Unknown Namespace: " + ct.xmlns);
        ct.calcchain = ct.calcchains.length > 0 ? ct.calcchains[0] : "";
        ct.sst = ct.strs.length > 0 ? ct.strs[0] : "";
        ct.style = ct.styles.length > 0 ? ct.styles[0] : "";
        ct.defaults = ctext;
        delete ct.calcchains;
        return ct;
      }
      function write_ct(ct, opts) {
        var type2ct = evert_arr(ct2type);
        var o = [], v;
        o[o.length] = XML_HEADER;
        o[o.length] = writextag("Types", null, {
          "xmlns": XMLNS.CT,
          "xmlns:xsd": XMLNS.xsd,
          "xmlns:xsi": XMLNS.xsi
        });
        o = o.concat([
          ["xml", "application/xml"],
          ["bin", "application/vnd.ms-excel.sheet.binary.macroEnabled.main"],
          ["vml", "application/vnd.openxmlformats-officedocument.vmlDrawing"],
          ["data", "application/vnd.openxmlformats-officedocument.model+data"],
          /* from test files */
          ["bmp", "image/bmp"],
          ["png", "image/png"],
          ["gif", "image/gif"],
          ["emf", "image/x-emf"],
          ["wmf", "image/x-wmf"],
          ["jpg", "image/jpeg"],
          ["jpeg", "image/jpeg"],
          ["tif", "image/tiff"],
          ["tiff", "image/tiff"],
          ["pdf", "application/pdf"],
          ["rels", "application/vnd.openxmlformats-package.relationships+xml"]
        ].map(function(x) {
          return writextag("Default", null, { "Extension": x[0], "ContentType": x[1] });
        }));
        var f1 = function(w) {
          if (ct[w] && ct[w].length > 0) {
            v = ct[w][0];
            o[o.length] = writextag("Override", null, {
              "PartName": (v[0] == "/" ? "" : "/") + v,
              "ContentType": CT_LIST[w][opts.bookType] || CT_LIST[w]["xlsx"]
            });
          }
        };
        var f2 = function(w) {
          (ct[w] || []).forEach(function(v2) {
            o[o.length] = writextag("Override", null, {
              "PartName": (v2[0] == "/" ? "" : "/") + v2,
              "ContentType": CT_LIST[w][opts.bookType] || CT_LIST[w]["xlsx"]
            });
          });
        };
        var f3 = function(t3) {
          (ct[t3] || []).forEach(function(v2) {
            o[o.length] = writextag("Override", null, {
              "PartName": (v2[0] == "/" ? "" : "/") + v2,
              "ContentType": type2ct[t3][0]
            });
          });
        };
        f1("workbooks");
        f2("sheets");
        f2("charts");
        f3("themes");
        ["strs", "styles"].forEach(f1);
        ["coreprops", "extprops", "custprops"].forEach(f3);
        f3("vba");
        f3("comments");
        f3("threadedcomments");
        f3("drawings");
        f2("metadata");
        f3("people");
        if (o.length > 2) {
          o[o.length] = "</Types>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      var RELS = {
        WB: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument",
        SHEET: "http://sheetjs.openxmlformats.org/officeDocument/2006/relationships/officeDocument",
        HLINK: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink",
        VML: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing",
        XPATH: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLinkPath",
        XMISS: "http://schemas.microsoft.com/office/2006/relationships/xlExternalLinkPath/xlPathMissing",
        XLINK: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLink",
        CXML: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXml",
        CXMLP: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXmlProps",
        CMNT: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments",
        CORE_PROPS: "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties",
        EXT_PROPS: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties",
        CUST_PROPS: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/custom-properties",
        SST: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings",
        STY: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles",
        THEME: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme",
        CHART: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart",
        CHARTEX: "http://schemas.microsoft.com/office/2014/relationships/chartEx",
        CS: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chartsheet",
        WS: [
          "http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet",
          "http://purl.oclc.org/ooxml/officeDocument/relationships/worksheet"
        ],
        DS: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/dialogsheet",
        MS: "http://schemas.microsoft.com/office/2006/relationships/xlMacrosheet",
        IMG: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",
        DRAW: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing",
        XLMETA: "http://schemas.openxmlformats.org/officeDocument/2006/relationships/sheetMetadata",
        TCMNT: "http://schemas.microsoft.com/office/2017/10/relationships/threadedComment",
        PEOPLE: "http://schemas.microsoft.com/office/2017/10/relationships/person",
        VBA: "http://schemas.microsoft.com/office/2006/relationships/vbaProject"
      };
      function get_rels_path(file) {
        var n = file.lastIndexOf("/");
        return file.slice(0, n + 1) + "_rels/" + file.slice(n + 1) + ".rels";
      }
      function parse_rels(data, currentFilePath) {
        var rels = { "!id": {} };
        if (!data)
          return rels;
        if (currentFilePath.charAt(0) !== "/") {
          currentFilePath = "/" + currentFilePath;
        }
        var hash = {};
        (data.match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          if (y[0] === "<Relationship") {
            var rel = {};
            rel.Type = y.Type;
            rel.Target = y.Target;
            rel.Id = y.Id;
            if (y.TargetMode)
              rel.TargetMode = y.TargetMode;
            var canonictarget = y.TargetMode === "External" ? y.Target : resolve_path(y.Target, currentFilePath);
            rels[canonictarget] = rel;
            hash[y.Id] = rel;
          }
        });
        rels["!id"] = hash;
        return rels;
      }
      function write_rels(rels) {
        var o = [XML_HEADER, writextag("Relationships", null, {
          //'xmlns:ns0': XMLNS.RELS,
          "xmlns": XMLNS.RELS
        })];
        keys3(rels["!id"]).forEach(function(rid) {
          o[o.length] = writextag("Relationship", null, rels["!id"][rid]);
        });
        if (o.length > 2) {
          o[o.length] = "</Relationships>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function add_rels(rels, rId, f, type, relobj, targetmode) {
        if (!relobj)
          relobj = {};
        if (!rels["!id"])
          rels["!id"] = {};
        if (!rels["!idx"])
          rels["!idx"] = 1;
        if (rId < 0)
          for (rId = rels["!idx"]; rels["!id"]["rId" + rId]; ++rId) {
          }
        rels["!idx"] = rId + 1;
        relobj.Id = "rId" + rId;
        relobj.Type = type;
        relobj.Target = f;
        if (targetmode)
          relobj.TargetMode = targetmode;
        else if ([RELS.HLINK, RELS.XPATH, RELS.XMISS].indexOf(relobj.Type) > -1)
          relobj.TargetMode = "External";
        if (rels["!id"][relobj.Id])
          throw new Error("Cannot rewrite rId " + rId);
        rels["!id"][relobj.Id] = relobj;
        rels[("/" + relobj.Target).replace("//", "/")] = relobj;
        return rId;
      }
      var CT_ODS = "application/vnd.oasis.opendocument.spreadsheet";
      function parse_manifest(d, opts) {
        var str = xlml_normalize(d);
        var Rn;
        var FEtag;
        while (Rn = xlmlregex.exec(str))
          switch (Rn[3]) {
            case "manifest":
              break;
            case "file-entry":
              FEtag = parsexmltag(Rn[0], false);
              if (FEtag.path == "/" && FEtag.type !== CT_ODS)
                throw new Error("This OpenDocument is not a spreadsheet");
              break;
            case "encryption-data":
            case "algorithm":
            case "start-key-generation":
            case "key-derivation":
              throw new Error("Unsupported ODS Encryption");
            default:
              if (opts && opts.WTF)
                throw Rn;
          }
      }
      function write_manifest(manifest) {
        var o = [XML_HEADER];
        o.push('<manifest:manifest xmlns:manifest="urn:oasis:names:tc:opendocument:xmlns:manifest:1.0" manifest:version="1.2">\n');
        o.push('  <manifest:file-entry manifest:full-path="/" manifest:version="1.2" manifest:media-type="application/vnd.oasis.opendocument.spreadsheet"/>\n');
        for (var i = 0; i < manifest.length; ++i)
          o.push('  <manifest:file-entry manifest:full-path="' + manifest[i][0] + '" manifest:media-type="' + manifest[i][1] + '"/>\n');
        o.push("</manifest:manifest>");
        return o.join("");
      }
      function write_rdf_type(file, res, tag) {
        return [
          '  <rdf:Description rdf:about="' + file + '">\n',
          '    <rdf:type rdf:resource="http://docs.oasis-open.org/ns/office/1.2/meta/' + (tag || "odf") + "#" + res + '"/>\n',
          "  </rdf:Description>\n"
        ].join("");
      }
      function write_rdf_has(base, file) {
        return [
          '  <rdf:Description rdf:about="' + base + '">\n',
          '    <ns0:hasPart xmlns:ns0="http://docs.oasis-open.org/ns/office/1.2/meta/pkg#" rdf:resource="' + file + '"/>\n',
          "  </rdf:Description>\n"
        ].join("");
      }
      function write_rdf(rdf) {
        var o = [XML_HEADER];
        o.push('<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n');
        for (var i = 0; i != rdf.length; ++i) {
          o.push(write_rdf_type(rdf[i][0], rdf[i][1]));
          o.push(write_rdf_has("", rdf[i][0]));
        }
        o.push(write_rdf_type("", "Document", "pkg"));
        o.push("</rdf:RDF>");
        return o.join("");
      }
      function write_meta_ods() {
        return '<office:document-meta xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0" xmlns:meta="urn:oasis:names:tc:opendocument:xmlns:meta:1.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:xlink="http://www.w3.org/1999/xlink" office:version="1.2"><office:meta><meta:generator>SheetJS ' + XLSX2.version + "</meta:generator></office:meta></office:document-meta>";
      }
      var CORE_PROPS = [
        ["cp:category", "Category"],
        ["cp:contentStatus", "ContentStatus"],
        ["cp:keywords", "Keywords"],
        ["cp:lastModifiedBy", "LastAuthor"],
        ["cp:lastPrinted", "LastPrinted"],
        ["cp:revision", "RevNumber"],
        ["cp:version", "Version"],
        ["dc:creator", "Author"],
        ["dc:description", "Comments"],
        ["dc:identifier", "Identifier"],
        ["dc:language", "Language"],
        ["dc:subject", "Subject"],
        ["dc:title", "Title"],
        ["dcterms:created", "CreatedDate", "date"],
        ["dcterms:modified", "ModifiedDate", "date"]
      ];
      var CORE_PROPS_REGEX = function() {
        var r = new Array(CORE_PROPS.length);
        for (var i = 0; i < CORE_PROPS.length; ++i) {
          var f = CORE_PROPS[i];
          var g = "(?:" + f[0].slice(0, f[0].indexOf(":")) + ":)" + f[0].slice(f[0].indexOf(":") + 1);
          r[i] = new RegExp("<" + g + "[^>]*>([\\s\\S]*?)</" + g + ">");
        }
        return r;
      }();
      function parse_core_props(data) {
        var p = {};
        data = utf8read(data);
        for (var i = 0; i < CORE_PROPS.length; ++i) {
          var f = CORE_PROPS[i], cur = data.match(CORE_PROPS_REGEX[i]);
          if (cur != null && cur.length > 0)
            p[f[1]] = unescapexml(cur[1]);
          if (f[2] === "date" && p[f[1]])
            p[f[1]] = parseDate(p[f[1]]);
        }
        return p;
      }
      function cp_doit(f, g, h, o, p) {
        if (p[f] != null || g == null || g === "")
          return;
        p[f] = g;
        g = escapexml(g);
        o[o.length] = h ? writextag(f, g, h) : writetag(f, g);
      }
      function write_core_props(cp, _opts) {
        var opts = _opts || {};
        var o = [XML_HEADER, writextag("cp:coreProperties", null, {
          //'xmlns': XMLNS.CORE_PROPS,
          "xmlns:cp": XMLNS.CORE_PROPS,
          "xmlns:dc": XMLNS.dc,
          "xmlns:dcterms": XMLNS.dcterms,
          "xmlns:dcmitype": XMLNS.dcmitype,
          "xmlns:xsi": XMLNS.xsi
        })], p = {};
        if (!cp && !opts.Props)
          return o.join("");
        if (cp) {
          if (cp.CreatedDate != null)
            cp_doit("dcterms:created", typeof cp.CreatedDate === "string" ? cp.CreatedDate : write_w3cdtf(cp.CreatedDate, opts.WTF), { "xsi:type": "dcterms:W3CDTF" }, o, p);
          if (cp.ModifiedDate != null)
            cp_doit("dcterms:modified", typeof cp.ModifiedDate === "string" ? cp.ModifiedDate : write_w3cdtf(cp.ModifiedDate, opts.WTF), { "xsi:type": "dcterms:W3CDTF" }, o, p);
        }
        for (var i = 0; i != CORE_PROPS.length; ++i) {
          var f = CORE_PROPS[i];
          var v = opts.Props && opts.Props[f[1]] != null ? opts.Props[f[1]] : cp ? cp[f[1]] : null;
          if (v === true)
            v = "1";
          else if (v === false)
            v = "0";
          else if (typeof v == "number")
            v = String(v);
          if (v != null)
            cp_doit(f[0], v, null, o, p);
        }
        if (o.length > 2) {
          o[o.length] = "</cp:coreProperties>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      var EXT_PROPS = [
        ["Application", "Application", "string"],
        ["AppVersion", "AppVersion", "string"],
        ["Company", "Company", "string"],
        ["DocSecurity", "DocSecurity", "string"],
        ["Manager", "Manager", "string"],
        ["HyperlinksChanged", "HyperlinksChanged", "bool"],
        ["SharedDoc", "SharedDoc", "bool"],
        ["LinksUpToDate", "LinksUpToDate", "bool"],
        ["ScaleCrop", "ScaleCrop", "bool"],
        ["HeadingPairs", "HeadingPairs", "raw"],
        ["TitlesOfParts", "TitlesOfParts", "raw"]
      ];
      var PseudoPropsPairs = [
        "Worksheets",
        "SheetNames",
        "NamedRanges",
        "DefinedNames",
        "Chartsheets",
        "ChartNames"
      ];
      function load_props_pairs(HP, TOP, props, opts) {
        var v = [];
        if (typeof HP == "string")
          v = parseVector(HP, opts);
        else
          for (var j = 0; j < HP.length; ++j)
            v = v.concat(HP[j].map(function(hp) {
              return { v: hp };
            }));
        var parts = typeof TOP == "string" ? parseVector(TOP, opts).map(function(x) {
          return x.v;
        }) : TOP;
        var idx = 0, len = 0;
        if (parts.length > 0)
          for (var i = 0; i !== v.length; i += 2) {
            len = +v[i + 1].v;
            switch (v[i].v) {
              case "Worksheets":
              case "\u5DE5\u4F5C\u8868":
              case "\u041B\u0438\u0441\u0442\u044B":
              case "\u0623\u0648\u0631\u0627\u0642 \u0627\u0644\u0639\u0645\u0644":
              case "\u30EF\u30FC\u30AF\u30B7\u30FC\u30C8":
              case "\u05D2\u05DC\u05D9\u05D5\u05E0\u05D5\u05EA \u05E2\u05D1\u05D5\u05D3\u05D4":
              case "Arbeitsbl\xE4tter":
              case "\xC7al\u0131\u015Fma Sayfalar\u0131":
              case "Feuilles de calcul":
              case "Fogli di lavoro":
              case "Folhas de c\xE1lculo":
              case "Planilhas":
              case "Regneark":
              case "Hojas de c\xE1lculo":
              case "Werkbladen":
                props.Worksheets = len;
                props.SheetNames = parts.slice(idx, idx + len);
                break;
              case "Named Ranges":
              case "Rangos con nombre":
              case "\u540D\u524D\u4ED8\u304D\u4E00\u89A7":
              case "Benannte Bereiche":
              case "Navngivne omr\xE5der":
                props.NamedRanges = len;
                props.DefinedNames = parts.slice(idx, idx + len);
                break;
              case "Charts":
              case "Diagramme":
                props.Chartsheets = len;
                props.ChartNames = parts.slice(idx, idx + len);
                break;
            }
            idx += len;
          }
      }
      function parse_ext_props(data, p, opts) {
        var q = {};
        if (!p)
          p = {};
        data = utf8read(data);
        EXT_PROPS.forEach(function(f) {
          var xml = (data.match(matchtag(f[0])) || [])[1];
          switch (f[2]) {
            case "string":
              if (xml)
                p[f[1]] = unescapexml(xml);
              break;
            case "bool":
              p[f[1]] = xml === "true";
              break;
            case "raw":
              var cur = data.match(new RegExp("<" + f[0] + "[^>]*>([\\s\\S]*?)</" + f[0] + ">"));
              if (cur && cur.length > 0)
                q[f[1]] = cur[1];
              break;
          }
        });
        if (q.HeadingPairs && q.TitlesOfParts)
          load_props_pairs(q.HeadingPairs, q.TitlesOfParts, p, opts);
        return p;
      }
      function write_ext_props(cp) {
        var o = [], W = writextag;
        if (!cp)
          cp = {};
        cp.Application = "SheetJS";
        o[o.length] = XML_HEADER;
        o[o.length] = writextag("Properties", null, {
          "xmlns": XMLNS.EXT_PROPS,
          "xmlns:vt": XMLNS.vt
        });
        EXT_PROPS.forEach(function(f) {
          if (cp[f[1]] === void 0)
            return;
          var v;
          switch (f[2]) {
            case "string":
              v = escapexml(String(cp[f[1]]));
              break;
            case "bool":
              v = cp[f[1]] ? "true" : "false";
              break;
          }
          if (v !== void 0)
            o[o.length] = W(f[0], v);
        });
        o[o.length] = W("HeadingPairs", W("vt:vector", W("vt:variant", "<vt:lpstr>Worksheets</vt:lpstr>") + W("vt:variant", W("vt:i4", String(cp.Worksheets))), { size: 2, baseType: "variant" }));
        o[o.length] = W("TitlesOfParts", W("vt:vector", cp.SheetNames.map(function(s) {
          return "<vt:lpstr>" + escapexml(s) + "</vt:lpstr>";
        }).join(""), { size: cp.Worksheets, baseType: "lpstr" }));
        if (o.length > 2) {
          o[o.length] = "</Properties>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      var custregex = /<[^>]+>[^<]*/g;
      function parse_cust_props(data, opts) {
        var p = {}, name = "";
        var m = data.match(custregex);
        if (m)
          for (var i = 0; i != m.length; ++i) {
            var x = m[i], y = parsexmltag(x);
            switch (y[0]) {
              case "<?xml":
                break;
              case "<Properties":
                break;
              case "<property":
                name = unescapexml(y.name);
                break;
              case "</property>":
                name = null;
                break;
              default:
                if (x.indexOf("<vt:") === 0) {
                  var toks = x.split(">");
                  var type = toks[0].slice(4), text = toks[1];
                  switch (type) {
                    case "lpstr":
                    case "bstr":
                    case "lpwstr":
                      p[name] = unescapexml(text);
                      break;
                    case "bool":
                      p[name] = parsexmlbool(text);
                      break;
                    case "i1":
                    case "i2":
                    case "i4":
                    case "i8":
                    case "int":
                    case "uint":
                      p[name] = parseInt(text, 10);
                      break;
                    case "r4":
                    case "r8":
                    case "decimal":
                      p[name] = parseFloat(text);
                      break;
                    case "filetime":
                    case "date":
                      p[name] = parseDate(text);
                      break;
                    case "cy":
                    case "error":
                      p[name] = unescapexml(text);
                      break;
                    default:
                      if (type.slice(-1) == "/")
                        break;
                      if (opts.WTF && typeof console !== "undefined")
                        console.warn("Unexpected", x, type, toks);
                  }
                } else if (x.slice(0, 2) === "</") {
                } else if (opts.WTF)
                  throw new Error(x);
            }
          }
        return p;
      }
      function write_cust_props(cp) {
        var o = [XML_HEADER, writextag("Properties", null, {
          "xmlns": XMLNS.CUST_PROPS,
          "xmlns:vt": XMLNS.vt
        })];
        if (!cp)
          return o.join("");
        var pid = 1;
        keys3(cp).forEach(function custprop(k) {
          ++pid;
          o[o.length] = writextag("property", write_vt(cp[k], true), {
            "fmtid": "{D5CDD505-2E9C-101B-9397-08002B2CF9AE}",
            "pid": pid,
            "name": escapexml(k)
          });
        });
        if (o.length > 2) {
          o[o.length] = "</Properties>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      var XLMLDocPropsMap = {
        Title: "Title",
        Subject: "Subject",
        Author: "Author",
        Keywords: "Keywords",
        Comments: "Description",
        LastAuthor: "LastAuthor",
        RevNumber: "Revision",
        Application: "AppName",
        /* TotalTime: 'TotalTime', */
        LastPrinted: "LastPrinted",
        CreatedDate: "Created",
        ModifiedDate: "LastSaved",
        /* Pages */
        /* Words */
        /* Characters */
        Category: "Category",
        /* PresentationFormat */
        Manager: "Manager",
        Company: "Company",
        /* Guid */
        /* HyperlinkBase */
        /* Bytes */
        /* Lines */
        /* Paragraphs */
        /* CharactersWithSpaces */
        AppVersion: "Version",
        ContentStatus: "ContentStatus",
        /* NOTE: missing from schema */
        Identifier: "Identifier",
        /* NOTE: missing from schema */
        Language: "Language"
        /* NOTE: missing from schema */
      };
      var evert_XLMLDPM;
      function xlml_set_prop(Props, tag, val) {
        if (!evert_XLMLDPM)
          evert_XLMLDPM = evert(XLMLDocPropsMap);
        tag = evert_XLMLDPM[tag] || tag;
        Props[tag] = val;
      }
      function xlml_write_docprops(Props, opts) {
        var o = [];
        keys3(XLMLDocPropsMap).map(function(m) {
          for (var i = 0; i < CORE_PROPS.length; ++i)
            if (CORE_PROPS[i][1] == m)
              return CORE_PROPS[i];
          for (i = 0; i < EXT_PROPS.length; ++i)
            if (EXT_PROPS[i][1] == m)
              return EXT_PROPS[i];
          throw m;
        }).forEach(function(p) {
          if (Props[p[1]] == null)
            return;
          var m = opts && opts.Props && opts.Props[p[1]] != null ? opts.Props[p[1]] : Props[p[1]];
          switch (p[2]) {
            case "date":
              m = new Date(m).toISOString().replace(/\.\d*Z/, "Z");
              break;
          }
          if (typeof m == "number")
            m = String(m);
          else if (m === true || m === false) {
            m = m ? "1" : "0";
          } else if (m instanceof Date)
            m = new Date(m).toISOString().replace(/\.\d*Z/, "");
          o.push(writetag(XLMLDocPropsMap[p[1]] || p[1], m));
        });
        return writextag("DocumentProperties", o.join(""), { xmlns: XLMLNS.o });
      }
      function xlml_write_custprops(Props, Custprops) {
        var BLACKLIST = ["Worksheets", "SheetNames"];
        var T = "CustomDocumentProperties";
        var o = [];
        if (Props)
          keys3(Props).forEach(function(k) {
            if (!Object.prototype.hasOwnProperty.call(Props, k))
              return;
            for (var i = 0; i < CORE_PROPS.length; ++i)
              if (k == CORE_PROPS[i][1])
                return;
            for (i = 0; i < EXT_PROPS.length; ++i)
              if (k == EXT_PROPS[i][1])
                return;
            for (i = 0; i < BLACKLIST.length; ++i)
              if (k == BLACKLIST[i])
                return;
            var m = Props[k];
            var t3 = "string";
            if (typeof m == "number") {
              t3 = "float";
              m = String(m);
            } else if (m === true || m === false) {
              t3 = "boolean";
              m = m ? "1" : "0";
            } else
              m = String(m);
            o.push(writextag(escapexmltag(k), m, { "dt:dt": t3 }));
          });
        if (Custprops)
          keys3(Custprops).forEach(function(k) {
            if (!Object.prototype.hasOwnProperty.call(Custprops, k))
              return;
            if (Props && Object.prototype.hasOwnProperty.call(Props, k))
              return;
            var m = Custprops[k];
            var t3 = "string";
            if (typeof m == "number") {
              t3 = "float";
              m = String(m);
            } else if (m === true || m === false) {
              t3 = "boolean";
              m = m ? "1" : "0";
            } else if (m instanceof Date) {
              t3 = "dateTime.tz";
              m = m.toISOString();
            } else
              m = String(m);
            o.push(writextag(escapexmltag(k), m, { "dt:dt": t3 }));
          });
        return "<" + T + ' xmlns="' + XLMLNS.o + '">' + o.join("") + "</" + T + ">";
      }
      function parse_FILETIME(blob) {
        var dwLowDateTime = blob.read_shift(4), dwHighDateTime = blob.read_shift(4);
        return new Date((dwHighDateTime / 1e7 * Math.pow(2, 32) + dwLowDateTime / 1e7 - 11644473600) * 1e3).toISOString().replace(/\.000/, "");
      }
      function write_FILETIME(time) {
        var date = typeof time == "string" ? new Date(Date.parse(time)) : time;
        var t3 = date.getTime() / 1e3 + 11644473600;
        var l = t3 % Math.pow(2, 32), h = (t3 - l) / Math.pow(2, 32);
        l *= 1e7;
        h *= 1e7;
        var w = l / Math.pow(2, 32) | 0;
        if (w > 0) {
          l = l % Math.pow(2, 32);
          h += w;
        }
        var o = new_buf(8);
        o.write_shift(4, l);
        o.write_shift(4, h);
        return o;
      }
      function parse_lpstr(blob, type, pad) {
        var start = blob.l;
        var str = blob.read_shift(0, "lpstr-cp");
        if (pad)
          while (blob.l - start & 3)
            ++blob.l;
        return str;
      }
      function parse_lpwstr(blob, type, pad) {
        var str = blob.read_shift(0, "lpwstr");
        if (pad)
          blob.l += 4 - (str.length + 1 & 3) & 3;
        return str;
      }
      function parse_VtStringBase(blob, stringType, pad) {
        if (stringType === 31)
          return parse_lpwstr(blob);
        return parse_lpstr(blob, stringType, pad);
      }
      function parse_VtString(blob, t3, pad) {
        return parse_VtStringBase(blob, t3, pad === false ? 0 : 4);
      }
      function parse_VtUnalignedString(blob, t3) {
        if (!t3)
          throw new Error("VtUnalignedString must have positive length");
        return parse_VtStringBase(blob, t3, 0);
      }
      function parse_VtVecLpwstrValue(blob) {
        var length = blob.read_shift(4);
        var ret = [];
        for (var i = 0; i != length; ++i) {
          var start = blob.l;
          ret[i] = blob.read_shift(0, "lpwstr").replace(chr0, "");
          if (blob.l - start & 2)
            blob.l += 2;
        }
        return ret;
      }
      function parse_VtVecUnalignedLpstrValue(blob) {
        var length = blob.read_shift(4);
        var ret = [];
        for (var i = 0; i != length; ++i)
          ret[i] = blob.read_shift(0, "lpstr-cp").replace(chr0, "");
        return ret;
      }
      function parse_VtHeadingPair(blob) {
        var start = blob.l;
        var headingString = parse_TypedPropertyValue(blob, VT_USTR);
        if (blob[blob.l] == 0 && blob[blob.l + 1] == 0 && blob.l - start & 2)
          blob.l += 2;
        var headerParts = parse_TypedPropertyValue(blob, VT_I4);
        return [headingString, headerParts];
      }
      function parse_VtVecHeadingPairValue(blob) {
        var cElements = blob.read_shift(4);
        var out = [];
        for (var i = 0; i < cElements / 2; ++i)
          out.push(parse_VtHeadingPair(blob));
        return out;
      }
      function parse_dictionary(blob, CodePage) {
        var cnt = blob.read_shift(4);
        var dict = {};
        for (var j = 0; j != cnt; ++j) {
          var pid = blob.read_shift(4);
          var len = blob.read_shift(4);
          dict[pid] = blob.read_shift(len, CodePage === 1200 ? "utf16le" : "utf8").replace(chr0, "").replace(chr1, "!");
          if (CodePage === 1200 && len % 2)
            blob.l += 2;
        }
        if (blob.l & 3)
          blob.l = blob.l >> 2 + 1 << 2;
        return dict;
      }
      function parse_BLOB(blob) {
        var size = blob.read_shift(4);
        var bytes = blob.slice(blob.l, blob.l + size);
        blob.l += size;
        if ((size & 3) > 0)
          blob.l += 4 - (size & 3) & 3;
        return bytes;
      }
      function parse_ClipboardData(blob) {
        var o = {};
        o.Size = blob.read_shift(4);
        blob.l += o.Size + 3 - (o.Size - 1) % 4;
        return o;
      }
      function parse_TypedPropertyValue(blob, type, _opts) {
        var t3 = blob.read_shift(2), ret, opts = _opts || {};
        blob.l += 2;
        if (type !== VT_VARIANT) {
          if (t3 !== type && VT_CUSTOM.indexOf(type) === -1 && !((type & 65534) == 4126 && (t3 & 65534) == 4126))
            throw new Error("Expected type " + type + " saw " + t3);
        }
        switch (type === VT_VARIANT ? t3 : type) {
          case 2:
            ret = blob.read_shift(2, "i");
            if (!opts.raw)
              blob.l += 2;
            return ret;
          case 3:
            ret = blob.read_shift(4, "i");
            return ret;
          case 11:
            return blob.read_shift(4) !== 0;
          case 19:
            ret = blob.read_shift(4);
            return ret;
          case 30:
            return parse_lpstr(blob, t3, 4).replace(chr0, "");
          case 31:
            return parse_lpwstr(blob);
          case 64:
            return parse_FILETIME(blob);
          case 65:
            return parse_BLOB(blob);
          case 71:
            return parse_ClipboardData(blob);
          case 80:
            return parse_VtString(blob, t3, !opts.raw).replace(chr0, "");
          case 81:
            return parse_VtUnalignedString(
              blob,
              t3
              /*, 4*/
            ).replace(chr0, "");
          case 4108:
            return parse_VtVecHeadingPairValue(blob);
          case 4126:
          case 4127:
            return t3 == 4127 ? parse_VtVecLpwstrValue(blob) : parse_VtVecUnalignedLpstrValue(blob);
          default:
            throw new Error("TypedPropertyValue unrecognized type " + type + " " + t3);
        }
      }
      function write_TypedPropertyValue(type, value2) {
        var o = new_buf(4), p = new_buf(4);
        o.write_shift(4, type == 80 ? 31 : type);
        switch (type) {
          case 3:
            p.write_shift(-4, value2);
            break;
          case 5:
            p = new_buf(8);
            p.write_shift(8, value2, "f");
            break;
          case 11:
            p.write_shift(4, value2 ? 1 : 0);
            break;
          case 64:
            p = write_FILETIME(value2);
            break;
          case 31:
          case 80:
            p = new_buf(4 + 2 * (value2.length + 1) + (value2.length % 2 ? 0 : 2));
            p.write_shift(4, value2.length + 1);
            p.write_shift(0, value2, "dbcs");
            while (p.l != p.length)
              p.write_shift(1, 0);
            break;
          default:
            throw new Error("TypedPropertyValue unrecognized type " + type + " " + value2);
        }
        return bconcat([o, p]);
      }
      function parse_PropertySet(blob, PIDSI) {
        var start_addr = blob.l;
        var size = blob.read_shift(4);
        var NumProps = blob.read_shift(4);
        var Props = [], i = 0;
        var CodePage = 0;
        var Dictionary = -1, DictObj = {};
        for (i = 0; i != NumProps; ++i) {
          var PropID = blob.read_shift(4);
          var Offset = blob.read_shift(4);
          Props[i] = [PropID, Offset + start_addr];
        }
        Props.sort(function(x, y) {
          return x[1] - y[1];
        });
        var PropH = {};
        for (i = 0; i != NumProps; ++i) {
          if (blob.l !== Props[i][1]) {
            var fail = true;
            if (i > 0 && PIDSI)
              switch (PIDSI[Props[i - 1][0]].t) {
                case 2:
                  if (blob.l + 2 === Props[i][1]) {
                    blob.l += 2;
                    fail = false;
                  }
                  break;
                case 80:
                  if (blob.l <= Props[i][1]) {
                    blob.l = Props[i][1];
                    fail = false;
                  }
                  break;
                case 4108:
                  if (blob.l <= Props[i][1]) {
                    blob.l = Props[i][1];
                    fail = false;
                  }
                  break;
              }
            if ((!PIDSI || i == 0) && blob.l <= Props[i][1]) {
              fail = false;
              blob.l = Props[i][1];
            }
            if (fail)
              throw new Error("Read Error: Expected address " + Props[i][1] + " at " + blob.l + " :" + i);
          }
          if (PIDSI) {
            var piddsi = PIDSI[Props[i][0]];
            PropH[piddsi.n] = parse_TypedPropertyValue(blob, piddsi.t, { raw: true });
            if (piddsi.p === "version")
              PropH[piddsi.n] = String(PropH[piddsi.n] >> 16) + "." + ("0000" + String(PropH[piddsi.n] & 65535)).slice(-4);
            if (piddsi.n == "CodePage")
              switch (PropH[piddsi.n]) {
                case 0:
                  PropH[piddsi.n] = 1252;
                case 874:
                case 932:
                case 936:
                case 949:
                case 950:
                case 1250:
                case 1251:
                case 1253:
                case 1254:
                case 1255:
                case 1256:
                case 1257:
                case 1258:
                case 1e4:
                case 1200:
                case 1201:
                case 1252:
                case 65e3:
                case -536:
                case 65001:
                case -535:
                  set_cp(CodePage = PropH[piddsi.n] >>> 0 & 65535);
                  break;
                default:
                  throw new Error("Unsupported CodePage: " + PropH[piddsi.n]);
              }
          } else {
            if (Props[i][0] === 1) {
              CodePage = PropH.CodePage = parse_TypedPropertyValue(blob, VT_I2);
              set_cp(CodePage);
              if (Dictionary !== -1) {
                var oldpos = blob.l;
                blob.l = Props[Dictionary][1];
                DictObj = parse_dictionary(blob, CodePage);
                blob.l = oldpos;
              }
            } else if (Props[i][0] === 0) {
              if (CodePage === 0) {
                Dictionary = i;
                blob.l = Props[i + 1][1];
                continue;
              }
              DictObj = parse_dictionary(blob, CodePage);
            } else {
              var name = DictObj[Props[i][0]];
              var val;
              switch (blob[blob.l]) {
                case 65:
                  blob.l += 4;
                  val = parse_BLOB(blob);
                  break;
                case 30:
                  blob.l += 4;
                  val = parse_VtString(blob, blob[blob.l - 4]).replace(/\u0000+$/, "");
                  break;
                case 31:
                  blob.l += 4;
                  val = parse_VtString(blob, blob[blob.l - 4]).replace(/\u0000+$/, "");
                  break;
                case 3:
                  blob.l += 4;
                  val = blob.read_shift(4, "i");
                  break;
                case 19:
                  blob.l += 4;
                  val = blob.read_shift(4);
                  break;
                case 5:
                  blob.l += 4;
                  val = blob.read_shift(8, "f");
                  break;
                case 11:
                  blob.l += 4;
                  val = parsebool(blob, 4);
                  break;
                case 64:
                  blob.l += 4;
                  val = parseDate(parse_FILETIME(blob));
                  break;
                default:
                  throw new Error("unparsed value: " + blob[blob.l]);
              }
              PropH[name] = val;
            }
          }
        }
        blob.l = start_addr + size;
        return PropH;
      }
      var XLSPSSkip = ["CodePage", "Thumbnail", "_PID_LINKBASE", "_PID_HLINKS", "SystemIdentifier", "FMTID"];
      function guess_property_type(val) {
        switch (typeof val) {
          case "boolean":
            return 11;
          case "number":
            return (val | 0) == val ? 3 : 5;
          case "string":
            return 31;
          case "object":
            if (val instanceof Date)
              return 64;
            break;
        }
        return -1;
      }
      function write_PropertySet(entries, RE, PIDSI) {
        var hdr = new_buf(8), piao = [], prop = [];
        var sz = 8, i = 0;
        var pr = new_buf(8), pio = new_buf(8);
        pr.write_shift(4, 2);
        pr.write_shift(4, 1200);
        pio.write_shift(4, 1);
        prop.push(pr);
        piao.push(pio);
        sz += 8 + pr.length;
        if (!RE) {
          pio = new_buf(8);
          pio.write_shift(4, 0);
          piao.unshift(pio);
          var bufs = [new_buf(4)];
          bufs[0].write_shift(4, entries.length);
          for (i = 0; i < entries.length; ++i) {
            var value2 = entries[i][0];
            pr = new_buf(4 + 4 + 2 * (value2.length + 1) + (value2.length % 2 ? 0 : 2));
            pr.write_shift(4, i + 2);
            pr.write_shift(4, value2.length + 1);
            pr.write_shift(0, value2, "dbcs");
            while (pr.l != pr.length)
              pr.write_shift(1, 0);
            bufs.push(pr);
          }
          pr = bconcat(bufs);
          prop.unshift(pr);
          sz += 8 + pr.length;
        }
        for (i = 0; i < entries.length; ++i) {
          if (RE && !RE[entries[i][0]])
            continue;
          if (XLSPSSkip.indexOf(entries[i][0]) > -1 || PseudoPropsPairs.indexOf(entries[i][0]) > -1)
            continue;
          if (entries[i][1] == null)
            continue;
          var val = entries[i][1], idx = 0;
          if (RE) {
            idx = +RE[entries[i][0]];
            var pinfo = PIDSI[idx];
            if (pinfo.p == "version" && typeof val == "string") {
              var arr = val.split(".");
              val = (+arr[0] << 16) + (+arr[1] || 0);
            }
            pr = write_TypedPropertyValue(pinfo.t, val);
          } else {
            var T = guess_property_type(val);
            if (T == -1) {
              T = 31;
              val = String(val);
            }
            pr = write_TypedPropertyValue(T, val);
          }
          prop.push(pr);
          pio = new_buf(8);
          pio.write_shift(4, !RE ? 2 + i : idx);
          piao.push(pio);
          sz += 8 + pr.length;
        }
        var w = 8 * (prop.length + 1);
        for (i = 0; i < prop.length; ++i) {
          piao[i].write_shift(4, w);
          w += prop[i].length;
        }
        hdr.write_shift(4, sz);
        hdr.write_shift(4, prop.length);
        return bconcat([hdr].concat(piao).concat(prop));
      }
      function parse_PropertySetStream(file, PIDSI, clsid) {
        var blob = file.content;
        if (!blob)
          return {};
        prep_blob(blob, 0);
        var NumSets, FMTID0, FMTID1, Offset0, Offset1 = 0;
        blob.chk("feff", "Byte Order: ");
        blob.read_shift(2);
        var SystemIdentifier = blob.read_shift(4);
        var CLSID = blob.read_shift(16);
        if (CLSID !== CFB.utils.consts.HEADER_CLSID && CLSID !== clsid)
          throw new Error("Bad PropertySet CLSID " + CLSID);
        NumSets = blob.read_shift(4);
        if (NumSets !== 1 && NumSets !== 2)
          throw new Error("Unrecognized #Sets: " + NumSets);
        FMTID0 = blob.read_shift(16);
        Offset0 = blob.read_shift(4);
        if (NumSets === 1 && Offset0 !== blob.l)
          throw new Error("Length mismatch: " + Offset0 + " !== " + blob.l);
        else if (NumSets === 2) {
          FMTID1 = blob.read_shift(16);
          Offset1 = blob.read_shift(4);
        }
        var PSet0 = parse_PropertySet(blob, PIDSI);
        var rval = { SystemIdentifier };
        for (var y in PSet0)
          rval[y] = PSet0[y];
        rval.FMTID = FMTID0;
        if (NumSets === 1)
          return rval;
        if (Offset1 - blob.l == 2)
          blob.l += 2;
        if (blob.l !== Offset1)
          throw new Error("Length mismatch 2: " + blob.l + " !== " + Offset1);
        var PSet1;
        try {
          PSet1 = parse_PropertySet(blob, null);
        } catch (e) {
        }
        for (y in PSet1)
          rval[y] = PSet1[y];
        rval.FMTID = [FMTID0, FMTID1];
        return rval;
      }
      function write_PropertySetStream(entries, clsid, RE, PIDSI, entries2, clsid2) {
        var hdr = new_buf(entries2 ? 68 : 48);
        var bufs = [hdr];
        hdr.write_shift(2, 65534);
        hdr.write_shift(2, 0);
        hdr.write_shift(4, 842412599);
        hdr.write_shift(16, CFB.utils.consts.HEADER_CLSID, "hex");
        hdr.write_shift(4, entries2 ? 2 : 1);
        hdr.write_shift(16, clsid, "hex");
        hdr.write_shift(4, entries2 ? 68 : 48);
        var ps0 = write_PropertySet(entries, RE, PIDSI);
        bufs.push(ps0);
        if (entries2) {
          var ps1 = write_PropertySet(entries2, null, null);
          hdr.write_shift(16, clsid2, "hex");
          hdr.write_shift(4, 68 + ps0.length);
          bufs.push(ps1);
        }
        return bconcat(bufs);
      }
      function parsenoop2(blob, length) {
        blob.read_shift(length);
        return null;
      }
      function writezeroes(n, o) {
        if (!o)
          o = new_buf(n);
        for (var j = 0; j < n; ++j)
          o.write_shift(1, 0);
        return o;
      }
      function parslurp(blob, length, cb) {
        var arr = [], target = blob.l + length;
        while (blob.l < target)
          arr.push(cb(blob, target - blob.l));
        if (target !== blob.l)
          throw new Error("Slurp error");
        return arr;
      }
      function parsebool(blob, length) {
        return blob.read_shift(length) === 1;
      }
      function writebool(v, o) {
        if (!o)
          o = new_buf(2);
        o.write_shift(2, +!!v);
        return o;
      }
      function parseuint16(blob) {
        return blob.read_shift(2, "u");
      }
      function writeuint16(v, o) {
        if (!o)
          o = new_buf(2);
        o.write_shift(2, v);
        return o;
      }
      function parseuint16a(blob, length) {
        return parslurp(blob, length, parseuint16);
      }
      function parse_Bes(blob) {
        var v = blob.read_shift(1), t3 = blob.read_shift(1);
        return t3 === 1 ? v : v === 1;
      }
      function write_Bes(v, t3, o) {
        if (!o)
          o = new_buf(2);
        o.write_shift(1, t3 == "e" ? +v : +!!v);
        o.write_shift(1, t3 == "e" ? 1 : 0);
        return o;
      }
      function parse_ShortXLUnicodeString(blob, length, opts) {
        var cch = blob.read_shift(opts && opts.biff >= 12 ? 2 : 1);
        var encoding = "sbcs-cont";
        var cp = current_codepage;
        if (opts && opts.biff >= 8)
          current_codepage = 1200;
        if (!opts || opts.biff == 8) {
          var fHighByte = blob.read_shift(1);
          if (fHighByte) {
            encoding = "dbcs-cont";
          }
        } else if (opts.biff == 12) {
          encoding = "wstr";
        }
        if (opts.biff >= 2 && opts.biff <= 5)
          encoding = "cpstr";
        var o = cch ? blob.read_shift(cch, encoding) : "";
        current_codepage = cp;
        return o;
      }
      function parse_XLUnicodeRichExtendedString(blob) {
        var cp = current_codepage;
        current_codepage = 1200;
        var cch = blob.read_shift(2), flags = blob.read_shift(1);
        var fExtSt = flags & 4, fRichSt = flags & 8;
        var width = 1 + (flags & 1);
        var cRun = 0, cbExtRst;
        var z = {};
        if (fRichSt)
          cRun = blob.read_shift(2);
        if (fExtSt)
          cbExtRst = blob.read_shift(4);
        var encoding = width == 2 ? "dbcs-cont" : "sbcs-cont";
        var msg = cch === 0 ? "" : blob.read_shift(cch, encoding);
        if (fRichSt)
          blob.l += 4 * cRun;
        if (fExtSt)
          blob.l += cbExtRst;
        z.t = msg;
        if (!fRichSt) {
          z.raw = "<t>" + z.t + "</t>";
          z.r = z.t;
        }
        current_codepage = cp;
        return z;
      }
      function write_XLUnicodeRichExtendedString(xlstr) {
        var str = xlstr.t || "", nfmts = 1;
        var hdr = new_buf(3 + (nfmts > 1 ? 2 : 0));
        hdr.write_shift(2, str.length);
        hdr.write_shift(1, (nfmts > 1 ? 8 : 0) | 1);
        if (nfmts > 1)
          hdr.write_shift(2, nfmts);
        var otext = new_buf(2 * str.length);
        otext.write_shift(2 * str.length, str, "utf16le");
        var out = [hdr, otext];
        return bconcat(out);
      }
      function parse_XLUnicodeStringNoCch(blob, cch, opts) {
        var retval;
        if (opts) {
          if (opts.biff >= 2 && opts.biff <= 5)
            return blob.read_shift(cch, "cpstr");
          if (opts.biff >= 12)
            return blob.read_shift(cch, "dbcs-cont");
        }
        var fHighByte = blob.read_shift(1);
        if (fHighByte === 0) {
          retval = blob.read_shift(cch, "sbcs-cont");
        } else {
          retval = blob.read_shift(cch, "dbcs-cont");
        }
        return retval;
      }
      function parse_XLUnicodeString(blob, length, opts) {
        var cch = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        if (cch === 0) {
          blob.l++;
          return "";
        }
        return parse_XLUnicodeStringNoCch(blob, cch, opts);
      }
      function parse_XLUnicodeString2(blob, length, opts) {
        if (opts.biff > 5)
          return parse_XLUnicodeString(blob, length, opts);
        var cch = blob.read_shift(1);
        if (cch === 0) {
          blob.l++;
          return "";
        }
        return blob.read_shift(cch, opts.biff <= 4 || !blob.lens ? "cpstr" : "sbcs-cont");
      }
      function write_XLUnicodeString(str, opts, o) {
        if (!o)
          o = new_buf(3 + 2 * str.length);
        o.write_shift(2, str.length);
        o.write_shift(1, 1);
        o.write_shift(31, str, "utf16le");
        return o;
      }
      function parse_ControlInfo(blob) {
        var flags = blob.read_shift(1);
        blob.l++;
        var accel = blob.read_shift(2);
        blob.l += 2;
        return [flags, accel];
      }
      function parse_URLMoniker(blob) {
        var len = blob.read_shift(4), start = blob.l;
        var extra = false;
        if (len > 24) {
          blob.l += len - 24;
          if (blob.read_shift(16) === "795881f43b1d7f48af2c825dc4852763")
            extra = true;
          blob.l = start;
        }
        var url = blob.read_shift((extra ? len - 24 : len) >> 1, "utf16le").replace(chr0, "");
        if (extra)
          blob.l += 24;
        return url;
      }
      function parse_FileMoniker(blob) {
        var cAnti = blob.read_shift(2);
        var preamble = "";
        while (cAnti-- > 0)
          preamble += "../";
        var ansiPath = blob.read_shift(0, "lpstr-ansi");
        blob.l += 2;
        if (blob.read_shift(2) != 57005)
          throw new Error("Bad FileMoniker");
        var sz = blob.read_shift(4);
        if (sz === 0)
          return preamble + ansiPath.replace(/\\/g, "/");
        var bytes = blob.read_shift(4);
        if (blob.read_shift(2) != 3)
          throw new Error("Bad FileMoniker");
        var unicodePath = blob.read_shift(bytes >> 1, "utf16le").replace(chr0, "");
        return preamble + unicodePath;
      }
      function parse_HyperlinkMoniker(blob, length) {
        var clsid = blob.read_shift(16);
        length -= 16;
        switch (clsid) {
          case "e0c9ea79f9bace118c8200aa004ba90b":
            return parse_URLMoniker(blob, length);
          case "0303000000000000c000000000000046":
            return parse_FileMoniker(blob, length);
          default:
            throw new Error("Unsupported Moniker " + clsid);
        }
      }
      function parse_HyperlinkString(blob) {
        var len = blob.read_shift(4);
        var o = len > 0 ? blob.read_shift(len, "utf16le").replace(chr0, "") : "";
        return o;
      }
      function write_HyperlinkString(str, o) {
        if (!o)
          o = new_buf(6 + str.length * 2);
        o.write_shift(4, 1 + str.length);
        for (var i = 0; i < str.length; ++i)
          o.write_shift(2, str.charCodeAt(i));
        o.write_shift(2, 0);
        return o;
      }
      function parse_Hyperlink(blob, length) {
        var end = blob.l + length;
        var sVer = blob.read_shift(4);
        if (sVer !== 2)
          throw new Error("Unrecognized streamVersion: " + sVer);
        var flags = blob.read_shift(2);
        blob.l += 2;
        var displayName, targetFrameName, moniker, oleMoniker, Loc = "", guid, fileTime;
        if (flags & 16)
          displayName = parse_HyperlinkString(blob, end - blob.l);
        if (flags & 128)
          targetFrameName = parse_HyperlinkString(blob, end - blob.l);
        if ((flags & 257) === 257)
          moniker = parse_HyperlinkString(blob, end - blob.l);
        if ((flags & 257) === 1)
          oleMoniker = parse_HyperlinkMoniker(blob, end - blob.l);
        if (flags & 8)
          Loc = parse_HyperlinkString(blob, end - blob.l);
        if (flags & 32)
          guid = blob.read_shift(16);
        if (flags & 64)
          fileTime = parse_FILETIME(
            blob
            /*, 8*/
          );
        blob.l = end;
        var target = targetFrameName || moniker || oleMoniker || "";
        if (target && Loc)
          target += "#" + Loc;
        if (!target)
          target = "#" + Loc;
        if (flags & 2 && target.charAt(0) == "/" && target.charAt(1) != "/")
          target = "file://" + target;
        var out = { Target: target };
        if (guid)
          out.guid = guid;
        if (fileTime)
          out.time = fileTime;
        if (displayName)
          out.Tooltip = displayName;
        return out;
      }
      function write_Hyperlink(hl) {
        var out = new_buf(512), i = 0;
        var Target = hl.Target;
        if (Target.slice(0, 7) == "file://")
          Target = Target.slice(7);
        var hashidx = Target.indexOf("#");
        var F = hashidx > -1 ? 31 : 23;
        switch (Target.charAt(0)) {
          case "#":
            F = 28;
            break;
          case ".":
            F &= ~2;
            break;
        }
        out.write_shift(4, 2);
        out.write_shift(4, F);
        var data = [8, 6815827, 6619237, 4849780, 83];
        for (i = 0; i < data.length; ++i)
          out.write_shift(4, data[i]);
        if (F == 28) {
          Target = Target.slice(1);
          write_HyperlinkString(Target, out);
        } else if (F & 2) {
          data = "e0 c9 ea 79 f9 ba ce 11 8c 82 00 aa 00 4b a9 0b".split(" ");
          for (i = 0; i < data.length; ++i)
            out.write_shift(1, parseInt(data[i], 16));
          var Pretarget = hashidx > -1 ? Target.slice(0, hashidx) : Target;
          out.write_shift(4, 2 * (Pretarget.length + 1));
          for (i = 0; i < Pretarget.length; ++i)
            out.write_shift(2, Pretarget.charCodeAt(i));
          out.write_shift(2, 0);
          if (F & 8)
            write_HyperlinkString(hashidx > -1 ? Target.slice(hashidx + 1) : "", out);
        } else {
          data = "03 03 00 00 00 00 00 00 c0 00 00 00 00 00 00 46".split(" ");
          for (i = 0; i < data.length; ++i)
            out.write_shift(1, parseInt(data[i], 16));
          var P = 0;
          while (Target.slice(P * 3, P * 3 + 3) == "../" || Target.slice(P * 3, P * 3 + 3) == "..\\")
            ++P;
          out.write_shift(2, P);
          out.write_shift(4, Target.length - 3 * P + 1);
          for (i = 0; i < Target.length - 3 * P; ++i)
            out.write_shift(1, Target.charCodeAt(i + 3 * P) & 255);
          out.write_shift(1, 0);
          out.write_shift(2, 65535);
          out.write_shift(2, 57005);
          for (i = 0; i < 6; ++i)
            out.write_shift(4, 0);
        }
        return out.slice(0, out.l);
      }
      function parse_LongRGBA(blob) {
        var r = blob.read_shift(1), g = blob.read_shift(1), b = blob.read_shift(1), a = blob.read_shift(1);
        return [r, g, b, a];
      }
      function parse_LongRGB(blob, length) {
        var x = parse_LongRGBA(blob, length);
        x[3] = 0;
        return x;
      }
      function parse_XLSCell(blob) {
        var rw = blob.read_shift(2);
        var col = blob.read_shift(2);
        var ixfe = blob.read_shift(2);
        return { r: rw, c: col, ixfe };
      }
      function write_XLSCell(R, C, ixfe, o) {
        if (!o)
          o = new_buf(6);
        o.write_shift(2, R);
        o.write_shift(2, C);
        o.write_shift(2, ixfe || 0);
        return o;
      }
      function parse_frtHeader(blob) {
        var rt = blob.read_shift(2);
        var flags = blob.read_shift(2);
        blob.l += 8;
        return { type: rt, flags };
      }
      function parse_OptXLUnicodeString(blob, length, opts) {
        return length === 0 ? "" : parse_XLUnicodeString2(blob, length, opts);
      }
      function parse_XTI(blob, length, opts) {
        var w = opts.biff > 8 ? 4 : 2;
        var iSupBook = blob.read_shift(w), itabFirst = blob.read_shift(w, "i"), itabLast = blob.read_shift(w, "i");
        return [iSupBook, itabFirst, itabLast];
      }
      function parse_RkRec(blob) {
        var ixfe = blob.read_shift(2);
        var RK = parse_RkNumber(blob);
        return [ixfe, RK];
      }
      function parse_AddinUdf(blob, length, opts) {
        blob.l += 4;
        length -= 4;
        var l = blob.l + length;
        var udfName = parse_ShortXLUnicodeString(blob, length, opts);
        var cb = blob.read_shift(2);
        l -= blob.l;
        if (cb !== l)
          throw new Error("Malformed AddinUdf: padding = " + l + " != " + cb);
        blob.l += cb;
        return udfName;
      }
      function parse_Ref8U(blob) {
        var rwFirst = blob.read_shift(2);
        var rwLast = blob.read_shift(2);
        var colFirst = blob.read_shift(2);
        var colLast = blob.read_shift(2);
        return { s: { c: colFirst, r: rwFirst }, e: { c: colLast, r: rwLast } };
      }
      function write_Ref8U(r, o) {
        if (!o)
          o = new_buf(8);
        o.write_shift(2, r.s.r);
        o.write_shift(2, r.e.r);
        o.write_shift(2, r.s.c);
        o.write_shift(2, r.e.c);
        return o;
      }
      function parse_RefU(blob) {
        var rwFirst = blob.read_shift(2);
        var rwLast = blob.read_shift(2);
        var colFirst = blob.read_shift(1);
        var colLast = blob.read_shift(1);
        return { s: { c: colFirst, r: rwFirst }, e: { c: colLast, r: rwLast } };
      }
      var parse_Ref = parse_RefU;
      function parse_FtCmo(blob) {
        blob.l += 4;
        var ot = blob.read_shift(2);
        var id = blob.read_shift(2);
        var flags = blob.read_shift(2);
        blob.l += 12;
        return [id, ot, flags];
      }
      function parse_FtNts(blob) {
        var out = {};
        blob.l += 4;
        blob.l += 16;
        out.fSharedNote = blob.read_shift(2);
        blob.l += 4;
        return out;
      }
      function parse_FtCf(blob) {
        var out = {};
        blob.l += 4;
        blob.cf = blob.read_shift(2);
        return out;
      }
      function parse_FtSkip(blob) {
        blob.l += 2;
        blob.l += blob.read_shift(2);
      }
      var FtTab = {
        0: parse_FtSkip,
        /* FtEnd */
        4: parse_FtSkip,
        /* FtMacro */
        5: parse_FtSkip,
        /* FtButton */
        6: parse_FtSkip,
        /* FtGmo */
        7: parse_FtCf,
        /* FtCf */
        8: parse_FtSkip,
        /* FtPioGrbit */
        9: parse_FtSkip,
        /* FtPictFmla */
        10: parse_FtSkip,
        /* FtCbls */
        11: parse_FtSkip,
        /* FtRbo */
        12: parse_FtSkip,
        /* FtSbs */
        13: parse_FtNts,
        /* FtNts */
        14: parse_FtSkip,
        /* FtSbsFmla */
        15: parse_FtSkip,
        /* FtGboData */
        16: parse_FtSkip,
        /* FtEdoData */
        17: parse_FtSkip,
        /* FtRboData */
        18: parse_FtSkip,
        /* FtCblsData */
        19: parse_FtSkip,
        /* FtLbsData */
        20: parse_FtSkip,
        /* FtCblsFmla */
        21: parse_FtCmo
      };
      function parse_FtArray(blob, length) {
        var tgt = blob.l + length;
        var fts = [];
        while (blob.l < tgt) {
          var ft = blob.read_shift(2);
          blob.l -= 2;
          try {
            fts.push(FtTab[ft](blob, tgt - blob.l));
          } catch (e) {
            blob.l = tgt;
            return fts;
          }
        }
        if (blob.l != tgt)
          blob.l = tgt;
        return fts;
      }
      function parse_BOF(blob, length) {
        var o = { BIFFVer: 0, dt: 0 };
        o.BIFFVer = blob.read_shift(2);
        length -= 2;
        if (length >= 2) {
          o.dt = blob.read_shift(2);
          blob.l -= 2;
        }
        switch (o.BIFFVer) {
          case 1536:
          case 1280:
          case 1024:
          case 768:
          case 512:
          case 2:
          case 7:
            break;
          default:
            if (length > 6)
              throw new Error("Unexpected BIFF Ver " + o.BIFFVer);
        }
        blob.read_shift(length);
        return o;
      }
      function write_BOF(wb, t3, o) {
        var h = 1536, w = 16;
        switch (o.bookType) {
          case "biff8":
            break;
          case "biff5":
            h = 1280;
            w = 8;
            break;
          case "biff4":
            h = 4;
            w = 6;
            break;
          case "biff3":
            h = 3;
            w = 6;
            break;
          case "biff2":
            h = 2;
            w = 4;
            break;
          case "xla":
            break;
          default:
            throw new Error("unsupported BIFF version");
        }
        var out = new_buf(w);
        out.write_shift(2, h);
        out.write_shift(2, t3);
        if (w > 4)
          out.write_shift(2, 29282);
        if (w > 6)
          out.write_shift(2, 1997);
        if (w > 8) {
          out.write_shift(2, 49161);
          out.write_shift(2, 1);
          out.write_shift(2, 1798);
          out.write_shift(2, 0);
        }
        return out;
      }
      function parse_InterfaceHdr(blob, length) {
        if (length === 0)
          return 1200;
        if (blob.read_shift(2) !== 1200) {
        }
        return 1200;
      }
      function parse_WriteAccess(blob, length, opts) {
        if (opts.enc) {
          blob.l += length;
          return "";
        }
        var l = blob.l;
        var UserName = parse_XLUnicodeString2(blob, 0, opts);
        blob.read_shift(length + l - blob.l);
        return UserName;
      }
      function write_WriteAccess(s, opts) {
        var b8 = !opts || opts.biff == 8;
        var o = new_buf(b8 ? 112 : 54);
        o.write_shift(opts.biff == 8 ? 2 : 1, 7);
        if (b8)
          o.write_shift(1, 0);
        o.write_shift(4, 859007059);
        o.write_shift(4, 5458548 | (b8 ? 0 : 536870912));
        while (o.l < o.length)
          o.write_shift(1, b8 ? 0 : 32);
        return o;
      }
      function parse_WsBool(blob, length, opts) {
        var flags = opts && opts.biff == 8 || length == 2 ? blob.read_shift(2) : (blob.l += length, 0);
        return { fDialog: flags & 16, fBelow: flags & 64, fRight: flags & 128 };
      }
      function parse_BoundSheet8(blob, length, opts) {
        var pos = blob.read_shift(4);
        var hidden = blob.read_shift(1) & 3;
        var dt = blob.read_shift(1);
        switch (dt) {
          case 0:
            dt = "Worksheet";
            break;
          case 1:
            dt = "Macrosheet";
            break;
          case 2:
            dt = "Chartsheet";
            break;
          case 6:
            dt = "VBAModule";
            break;
        }
        var name = parse_ShortXLUnicodeString(blob, 0, opts);
        if (name.length === 0)
          name = "Sheet1";
        return { pos, hs: hidden, dt, name };
      }
      function write_BoundSheet8(data, opts) {
        var w = !opts || opts.biff >= 8 ? 2 : 1;
        var o = new_buf(8 + w * data.name.length);
        o.write_shift(4, data.pos);
        o.write_shift(1, data.hs || 0);
        o.write_shift(1, data.dt);
        o.write_shift(1, data.name.length);
        if (opts.biff >= 8)
          o.write_shift(1, 1);
        o.write_shift(w * data.name.length, data.name, opts.biff < 8 ? "sbcs" : "utf16le");
        var out = o.slice(0, o.l);
        out.l = o.l;
        return out;
      }
      function parse_SST(blob, length) {
        var end = blob.l + length;
        var cnt = blob.read_shift(4);
        var ucnt = blob.read_shift(4);
        var strs2 = [];
        for (var i = 0; i != ucnt && blob.l < end; ++i) {
          strs2.push(parse_XLUnicodeRichExtendedString(blob));
        }
        strs2.Count = cnt;
        strs2.Unique = ucnt;
        return strs2;
      }
      function write_SST(sst, opts) {
        var header = new_buf(8);
        header.write_shift(4, sst.Count);
        header.write_shift(4, sst.Unique);
        var strs2 = [];
        for (var j = 0; j < sst.length; ++j)
          strs2[j] = write_XLUnicodeRichExtendedString(sst[j], opts);
        var o = bconcat([header].concat(strs2));
        o.parts = [header.length].concat(strs2.map(function(str) {
          return str.length;
        }));
        return o;
      }
      function parse_ExtSST(blob, length) {
        var extsst = {};
        extsst.dsst = blob.read_shift(2);
        blob.l += length - 2;
        return extsst;
      }
      function parse_Row(blob) {
        var z = {};
        z.r = blob.read_shift(2);
        z.c = blob.read_shift(2);
        z.cnt = blob.read_shift(2) - z.c;
        var miyRw = blob.read_shift(2);
        blob.l += 4;
        var flags = blob.read_shift(1);
        blob.l += 3;
        if (flags & 7)
          z.level = flags & 7;
        if (flags & 32)
          z.hidden = true;
        if (flags & 64)
          z.hpt = miyRw / 20;
        return z;
      }
      function parse_ForceFullCalculation(blob) {
        var header = parse_frtHeader(blob);
        if (header.type != 2211)
          throw new Error("Invalid Future Record " + header.type);
        var fullcalc = blob.read_shift(4);
        return fullcalc !== 0;
      }
      function parse_RecalcId(blob) {
        blob.read_shift(2);
        return blob.read_shift(4);
      }
      function parse_DefaultRowHeight(blob, length, opts) {
        var f = 0;
        if (!(opts && opts.biff == 2)) {
          f = blob.read_shift(2);
        }
        var miyRw = blob.read_shift(2);
        if (opts && opts.biff == 2) {
          f = 1 - (miyRw >> 15);
          miyRw &= 32767;
        }
        var fl = { Unsynced: f & 1, DyZero: (f & 2) >> 1, ExAsc: (f & 4) >> 2, ExDsc: (f & 8) >> 3 };
        return [fl, miyRw];
      }
      function parse_Window1(blob) {
        var xWn = blob.read_shift(2), yWn = blob.read_shift(2), dxWn = blob.read_shift(2), dyWn = blob.read_shift(2);
        var flags = blob.read_shift(2), iTabCur = blob.read_shift(2), iTabFirst = blob.read_shift(2);
        var ctabSel = blob.read_shift(2), wTabRatio = blob.read_shift(2);
        return {
          Pos: [xWn, yWn],
          Dim: [dxWn, dyWn],
          Flags: flags,
          CurTab: iTabCur,
          FirstTab: iTabFirst,
          Selected: ctabSel,
          TabRatio: wTabRatio
        };
      }
      function write_Window1() {
        var o = new_buf(18);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(2, 29280);
        o.write_shift(2, 17600);
        o.write_shift(2, 56);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(2, 1);
        o.write_shift(2, 500);
        return o;
      }
      function parse_Window2(blob, length, opts) {
        if (opts && opts.biff >= 2 && opts.biff < 5)
          return {};
        var f = blob.read_shift(2);
        return { RTL: f & 64 };
      }
      function write_Window2(view) {
        var o = new_buf(18), f = 1718;
        if (view && view.RTL)
          f |= 64;
        o.write_shift(2, f);
        o.write_shift(4, 0);
        o.write_shift(4, 64);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        return o;
      }
      function parse_Pane() {
      }
      function parse_Font(blob, length, opts) {
        var o = {
          dyHeight: blob.read_shift(2),
          fl: blob.read_shift(2)
        };
        switch (opts && opts.biff || 8) {
          case 2:
            break;
          case 3:
          case 4:
            blob.l += 2;
            break;
          default:
            blob.l += 10;
            break;
        }
        o.name = parse_ShortXLUnicodeString(blob, 0, opts);
        return o;
      }
      function write_Font(data, opts) {
        var name = data.name || "Arial";
        var b5 = opts && opts.biff == 5, w = b5 ? 15 + name.length : 16 + 2 * name.length;
        var o = new_buf(w);
        o.write_shift(2, (data.sz || 12) * 20);
        o.write_shift(4, 0);
        o.write_shift(2, 400);
        o.write_shift(4, 0);
        o.write_shift(2, 0);
        o.write_shift(1, name.length);
        if (!b5)
          o.write_shift(1, 1);
        o.write_shift((b5 ? 1 : 2) * name.length, name, b5 ? "sbcs" : "utf16le");
        return o;
      }
      function parse_LabelSst(blob) {
        var cell = parse_XLSCell(blob);
        cell.isst = blob.read_shift(4);
        return cell;
      }
      function write_LabelSst(R, C, v, os) {
        var o = new_buf(10);
        write_XLSCell(R, C, os, o);
        o.write_shift(4, v);
        return o;
      }
      function parse_Label(blob, length, opts) {
        if (opts.biffguess && opts.biff == 2)
          opts.biff = 5;
        var target = blob.l + length;
        var cell = parse_XLSCell(blob, 6);
        if (opts.biff == 2)
          blob.l++;
        var str = parse_XLUnicodeString(blob, target - blob.l, opts);
        cell.val = str;
        return cell;
      }
      function write_Label(R, C, v, os, opts) {
        var b8 = !opts || opts.biff == 8;
        var o = new_buf(6 + 2 + +b8 + (1 + b8) * v.length);
        write_XLSCell(R, C, os, o);
        o.write_shift(2, v.length);
        if (b8)
          o.write_shift(1, 1);
        o.write_shift((1 + b8) * v.length, v, b8 ? "utf16le" : "sbcs");
        return o;
      }
      function parse_Format(blob, length, opts) {
        var numFmtId = blob.read_shift(2);
        var fmtstr = parse_XLUnicodeString2(blob, 0, opts);
        return [numFmtId, fmtstr];
      }
      function write_Format(i, f, opts, o) {
        var b5 = opts && opts.biff == 5;
        if (!o)
          o = new_buf(b5 ? 3 + f.length : 5 + 2 * f.length);
        o.write_shift(2, i);
        o.write_shift(b5 ? 1 : 2, f.length);
        if (!b5)
          o.write_shift(1, 1);
        o.write_shift((b5 ? 1 : 2) * f.length, f, b5 ? "sbcs" : "utf16le");
        var out = o.length > o.l ? o.slice(0, o.l) : o;
        if (out.l == null)
          out.l = out.length;
        return out;
      }
      var parse_BIFF2Format = parse_XLUnicodeString2;
      function parse_Dimensions(blob, length, opts) {
        var end = blob.l + length;
        var w = opts.biff == 8 || !opts.biff ? 4 : 2;
        var r = blob.read_shift(w), R = blob.read_shift(w);
        var c = blob.read_shift(2), C = blob.read_shift(2);
        blob.l = end;
        return { s: { r, c }, e: { r: R, c: C } };
      }
      function write_Dimensions(range, opts) {
        var w = opts.biff == 8 || !opts.biff ? 4 : 2;
        var o = new_buf(2 * w + 6);
        o.write_shift(w, range.s.r);
        o.write_shift(w, range.e.r + 1);
        o.write_shift(2, range.s.c);
        o.write_shift(2, range.e.c + 1);
        o.write_shift(2, 0);
        return o;
      }
      function parse_RK(blob) {
        var rw = blob.read_shift(2), col = blob.read_shift(2);
        var rkrec = parse_RkRec(blob);
        return { r: rw, c: col, ixfe: rkrec[0], rknum: rkrec[1] };
      }
      function parse_MulRk(blob, length) {
        var target = blob.l + length - 2;
        var rw = blob.read_shift(2), col = blob.read_shift(2);
        var rkrecs = [];
        while (blob.l < target)
          rkrecs.push(parse_RkRec(blob));
        if (blob.l !== target)
          throw new Error("MulRK read error");
        var lastcol = blob.read_shift(2);
        if (rkrecs.length != lastcol - col + 1)
          throw new Error("MulRK length mismatch");
        return { r: rw, c: col, C: lastcol, rkrec: rkrecs };
      }
      function parse_MulBlank(blob, length) {
        var target = blob.l + length - 2;
        var rw = blob.read_shift(2), col = blob.read_shift(2);
        var ixfes = [];
        while (blob.l < target)
          ixfes.push(blob.read_shift(2));
        if (blob.l !== target)
          throw new Error("MulBlank read error");
        var lastcol = blob.read_shift(2);
        if (ixfes.length != lastcol - col + 1)
          throw new Error("MulBlank length mismatch");
        return { r: rw, c: col, C: lastcol, ixfe: ixfes };
      }
      function parse_CellStyleXF(blob, length, style, opts) {
        var o = {};
        var a = blob.read_shift(4), b = blob.read_shift(4);
        var c = blob.read_shift(4), d = blob.read_shift(2);
        o.patternType = XLSFillPattern[c >> 26];
        if (!opts.cellStyles)
          return o;
        o.alc = a & 7;
        o.fWrap = a >> 3 & 1;
        o.alcV = a >> 4 & 7;
        o.fJustLast = a >> 7 & 1;
        o.trot = a >> 8 & 255;
        o.cIndent = a >> 16 & 15;
        o.fShrinkToFit = a >> 20 & 1;
        o.iReadOrder = a >> 22 & 2;
        o.fAtrNum = a >> 26 & 1;
        o.fAtrFnt = a >> 27 & 1;
        o.fAtrAlc = a >> 28 & 1;
        o.fAtrBdr = a >> 29 & 1;
        o.fAtrPat = a >> 30 & 1;
        o.fAtrProt = a >> 31 & 1;
        o.dgLeft = b & 15;
        o.dgRight = b >> 4 & 15;
        o.dgTop = b >> 8 & 15;
        o.dgBottom = b >> 12 & 15;
        o.icvLeft = b >> 16 & 127;
        o.icvRight = b >> 23 & 127;
        o.grbitDiag = b >> 30 & 3;
        o.icvTop = c & 127;
        o.icvBottom = c >> 7 & 127;
        o.icvDiag = c >> 14 & 127;
        o.dgDiag = c >> 21 & 15;
        o.icvFore = d & 127;
        o.icvBack = d >> 7 & 127;
        o.fsxButton = d >> 14 & 1;
        return o;
      }
      function parse_XF(blob, length, opts) {
        var o = {};
        o.ifnt = blob.read_shift(2);
        o.numFmtId = blob.read_shift(2);
        o.flags = blob.read_shift(2);
        o.fStyle = o.flags >> 2 & 1;
        length -= 6;
        o.data = parse_CellStyleXF(blob, length, o.fStyle, opts);
        return o;
      }
      function write_XF(data, ixfeP, opts, o) {
        var b5 = opts && opts.biff == 5;
        if (!o)
          o = new_buf(b5 ? 16 : 20);
        o.write_shift(2, 0);
        if (data.style) {
          o.write_shift(2, data.numFmtId || 0);
          o.write_shift(2, 65524);
        } else {
          o.write_shift(2, data.numFmtId || 0);
          o.write_shift(2, ixfeP << 4);
        }
        var f = 0;
        if (data.numFmtId > 0 && b5)
          f |= 1024;
        o.write_shift(4, f);
        o.write_shift(4, 0);
        if (!b5)
          o.write_shift(4, 0);
        o.write_shift(2, 0);
        return o;
      }
      function parse_Guts(blob) {
        blob.l += 4;
        var out = [blob.read_shift(2), blob.read_shift(2)];
        if (out[0] !== 0)
          out[0]--;
        if (out[1] !== 0)
          out[1]--;
        if (out[0] > 7 || out[1] > 7)
          throw new Error("Bad Gutters: " + out.join("|"));
        return out;
      }
      function write_Guts(guts) {
        var o = new_buf(8);
        o.write_shift(4, 0);
        o.write_shift(2, guts[0] ? guts[0] + 1 : 0);
        o.write_shift(2, guts[1] ? guts[1] + 1 : 0);
        return o;
      }
      function parse_BoolErr(blob, length, opts) {
        var cell = parse_XLSCell(blob, 6);
        if (opts.biff == 2 || length == 9)
          ++blob.l;
        var val = parse_Bes(blob, 2);
        cell.val = val;
        cell.t = val === true || val === false ? "b" : "e";
        return cell;
      }
      function write_BoolErr(R, C, v, os, opts, t3) {
        var o = new_buf(8);
        write_XLSCell(R, C, os, o);
        write_Bes(v, t3, o);
        return o;
      }
      function parse_Number(blob, length, opts) {
        if (opts.biffguess && opts.biff == 2)
          opts.biff = 5;
        var cell = parse_XLSCell(blob, 6);
        var xnum = parse_Xnum(blob, 8);
        cell.val = xnum;
        return cell;
      }
      function write_Number(R, C, v, os) {
        var o = new_buf(14);
        write_XLSCell(R, C, os, o);
        write_Xnum(v, o);
        return o;
      }
      var parse_XLHeaderFooter = parse_OptXLUnicodeString;
      function parse_SupBook(blob, length, opts) {
        var end = blob.l + length;
        var ctab = blob.read_shift(2);
        var cch = blob.read_shift(2);
        opts.sbcch = cch;
        if (cch == 1025 || cch == 14849)
          return [cch, ctab];
        if (cch < 1 || cch > 255)
          throw new Error("Unexpected SupBook type: " + cch);
        var virtPath = parse_XLUnicodeStringNoCch(blob, cch);
        var rgst = [];
        while (end > blob.l)
          rgst.push(parse_XLUnicodeString(blob));
        return [cch, ctab, virtPath, rgst];
      }
      function parse_ExternName(blob, length, opts) {
        var flags = blob.read_shift(2);
        var body;
        var o = {
          fBuiltIn: flags & 1,
          fWantAdvise: flags >>> 1 & 1,
          fWantPict: flags >>> 2 & 1,
          fOle: flags >>> 3 & 1,
          fOleLink: flags >>> 4 & 1,
          cf: flags >>> 5 & 1023,
          fIcon: flags >>> 15 & 1
        };
        if (opts.sbcch === 14849)
          body = parse_AddinUdf(blob, length - 2, opts);
        o.body = body || blob.read_shift(length - 2);
        if (typeof body === "string")
          o.Name = body;
        return o;
      }
      var XLSLblBuiltIn = [
        "_xlnm.Consolidate_Area",
        "_xlnm.Auto_Open",
        "_xlnm.Auto_Close",
        "_xlnm.Extract",
        "_xlnm.Database",
        "_xlnm.Criteria",
        "_xlnm.Print_Area",
        "_xlnm.Print_Titles",
        "_xlnm.Recorder",
        "_xlnm.Data_Form",
        "_xlnm.Auto_Activate",
        "_xlnm.Auto_Deactivate",
        "_xlnm.Sheet_Title",
        "_xlnm._FilterDatabase"
      ];
      function parse_Lbl(blob, length, opts) {
        var target = blob.l + length;
        var flags = blob.read_shift(2);
        var chKey = blob.read_shift(1);
        var cch = blob.read_shift(1);
        var cce = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        var itab = 0;
        if (!opts || opts.biff >= 5) {
          if (opts.biff != 5)
            blob.l += 2;
          itab = blob.read_shift(2);
          if (opts.biff == 5)
            blob.l += 2;
          blob.l += 4;
        }
        var name = parse_XLUnicodeStringNoCch(blob, cch, opts);
        if (flags & 32)
          name = XLSLblBuiltIn[name.charCodeAt(0)];
        var npflen = target - blob.l;
        if (opts && opts.biff == 2)
          --npflen;
        var rgce = target == blob.l || cce === 0 || !(npflen > 0) ? [] : parse_NameParsedFormula(blob, npflen, opts, cce);
        return {
          chKey,
          Name: name,
          itab,
          rgce
        };
      }
      function parse_ExternSheet(blob, length, opts) {
        if (opts.biff < 8)
          return parse_BIFF5ExternSheet(blob, length, opts);
        var o = [], target = blob.l + length, len = blob.read_shift(opts.biff > 8 ? 4 : 2);
        while (len-- !== 0)
          o.push(parse_XTI(blob, opts.biff > 8 ? 12 : 6, opts));
        if (blob.l != target)
          throw new Error("Bad ExternSheet: " + blob.l + " != " + target);
        return o;
      }
      function parse_BIFF5ExternSheet(blob, length, opts) {
        if (blob[blob.l + 1] == 3)
          blob[blob.l]++;
        var o = parse_ShortXLUnicodeString(blob, length, opts);
        return o.charCodeAt(0) == 3 ? o.slice(1) : o;
      }
      function parse_NameCmt(blob, length, opts) {
        if (opts.biff < 8) {
          blob.l += length;
          return;
        }
        var cchName = blob.read_shift(2);
        var cchComment = blob.read_shift(2);
        var name = parse_XLUnicodeStringNoCch(blob, cchName, opts);
        var comment = parse_XLUnicodeStringNoCch(blob, cchComment, opts);
        return [name, comment];
      }
      function parse_ShrFmla(blob, length, opts) {
        var ref = parse_RefU(blob, 6);
        blob.l++;
        var cUse = blob.read_shift(1);
        length -= 8;
        return [parse_SharedParsedFormula(blob, length, opts), cUse, ref];
      }
      function parse_Array(blob, length, opts) {
        var ref = parse_Ref(blob, 6);
        switch (opts.biff) {
          case 2:
            blob.l++;
            length -= 7;
            break;
          case 3:
          case 4:
            blob.l += 2;
            length -= 8;
            break;
          default:
            blob.l += 6;
            length -= 12;
        }
        return [ref, parse_ArrayParsedFormula(blob, length, opts, ref)];
      }
      function parse_MTRSettings(blob) {
        var fMTREnabled = blob.read_shift(4) !== 0;
        var fUserSetThreadCount = blob.read_shift(4) !== 0;
        var cUserThreadCount = blob.read_shift(4);
        return [fMTREnabled, fUserSetThreadCount, cUserThreadCount];
      }
      function parse_NoteSh(blob, length, opts) {
        if (opts.biff < 8)
          return;
        var row = blob.read_shift(2), col = blob.read_shift(2);
        var flags = blob.read_shift(2), idObj = blob.read_shift(2);
        var stAuthor = parse_XLUnicodeString2(blob, 0, opts);
        if (opts.biff < 8)
          blob.read_shift(1);
        return [{ r: row, c: col }, stAuthor, idObj, flags];
      }
      function parse_Note(blob, length, opts) {
        return parse_NoteSh(blob, length, opts);
      }
      function parse_MergeCells(blob, length) {
        var merges = [];
        var cmcs = blob.read_shift(2);
        while (cmcs--)
          merges.push(parse_Ref8U(blob, length));
        return merges;
      }
      function write_MergeCells(merges) {
        var o = new_buf(2 + merges.length * 8);
        o.write_shift(2, merges.length);
        for (var i = 0; i < merges.length; ++i)
          write_Ref8U(merges[i], o);
        return o;
      }
      function parse_Obj(blob, length, opts) {
        if (opts && opts.biff < 8)
          return parse_BIFF5Obj(blob, length, opts);
        var cmo = parse_FtCmo(blob, 22);
        var fts = parse_FtArray(blob, length - 22, cmo[1]);
        return { cmo, ft: fts };
      }
      var parse_BIFF5OT = {
        8: function(blob, length) {
          var tgt = blob.l + length;
          blob.l += 10;
          var cf = blob.read_shift(2);
          blob.l += 4;
          blob.l += 2;
          blob.l += 2;
          blob.l += 2;
          blob.l += 4;
          var cchName = blob.read_shift(1);
          blob.l += cchName;
          blob.l = tgt;
          return { fmt: cf };
        }
      };
      function parse_BIFF5Obj(blob, length, opts) {
        blob.l += 4;
        var ot = blob.read_shift(2);
        var id = blob.read_shift(2);
        var grbit = blob.read_shift(2);
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 2;
        blob.l += 6;
        length -= 36;
        var fts = [];
        fts.push((parse_BIFF5OT[ot] || parsenoop)(blob, length, opts));
        return { cmo: [id, ot, grbit], ft: fts };
      }
      function parse_TxO(blob, length, opts) {
        var s = blob.l;
        var texts = "";
        try {
          blob.l += 4;
          var ot = (opts.lastobj || { cmo: [0, 0] }).cmo[1];
          var controlInfo;
          if ([0, 5, 7, 11, 12, 14].indexOf(ot) == -1)
            blob.l += 6;
          else
            controlInfo = parse_ControlInfo(blob, 6, opts);
          var cchText = blob.read_shift(2);
          blob.read_shift(2);
          parseuint16(blob, 2);
          var len = blob.read_shift(2);
          blob.l += len;
          for (var i = 1; i < blob.lens.length - 1; ++i) {
            if (blob.l - s != blob.lens[i])
              throw new Error("TxO: bad continue record");
            var hdr = blob[blob.l];
            var t3 = parse_XLUnicodeStringNoCch(blob, blob.lens[i + 1] - blob.lens[i] - 1);
            texts += t3;
            if (texts.length >= (hdr ? cchText : 2 * cchText))
              break;
          }
          if (texts.length !== cchText && texts.length !== cchText * 2) {
            throw new Error("cchText: " + cchText + " != " + texts.length);
          }
          blob.l = s + length;
          return { t: texts };
        } catch (e) {
          blob.l = s + length;
          return { t: texts };
        }
      }
      function parse_HLink(blob, length) {
        var ref = parse_Ref8U(blob, 8);
        blob.l += 16;
        var hlink = parse_Hyperlink(blob, length - 24);
        return [ref, hlink];
      }
      function write_HLink(hl) {
        var O = new_buf(24);
        var ref = decode_cell(hl[0]);
        O.write_shift(2, ref.r);
        O.write_shift(2, ref.r);
        O.write_shift(2, ref.c);
        O.write_shift(2, ref.c);
        var clsid = "d0 c9 ea 79 f9 ba ce 11 8c 82 00 aa 00 4b a9 0b".split(" ");
        for (var i = 0; i < 16; ++i)
          O.write_shift(1, parseInt(clsid[i], 16));
        return bconcat([O, write_Hyperlink(hl[1])]);
      }
      function parse_HLinkTooltip(blob, length) {
        blob.read_shift(2);
        var ref = parse_Ref8U(blob, 8);
        var wzTooltip = blob.read_shift((length - 10) / 2, "dbcs-cont");
        wzTooltip = wzTooltip.replace(chr0, "");
        return [ref, wzTooltip];
      }
      function write_HLinkTooltip(hl) {
        var TT = hl[1].Tooltip;
        var O = new_buf(10 + 2 * (TT.length + 1));
        O.write_shift(2, 2048);
        var ref = decode_cell(hl[0]);
        O.write_shift(2, ref.r);
        O.write_shift(2, ref.r);
        O.write_shift(2, ref.c);
        O.write_shift(2, ref.c);
        for (var i = 0; i < TT.length; ++i)
          O.write_shift(2, TT.charCodeAt(i));
        O.write_shift(2, 0);
        return O;
      }
      function parse_Country(blob) {
        var o = [0, 0], d;
        d = blob.read_shift(2);
        o[0] = CountryEnum[d] || d;
        d = blob.read_shift(2);
        o[1] = CountryEnum[d] || d;
        return o;
      }
      function write_Country(o) {
        if (!o)
          o = new_buf(4);
        o.write_shift(2, 1);
        o.write_shift(2, 1);
        return o;
      }
      function parse_ClrtClient(blob) {
        var ccv = blob.read_shift(2);
        var o = [];
        while (ccv-- > 0)
          o.push(parse_LongRGB(blob, 8));
        return o;
      }
      function parse_Palette(blob) {
        var ccv = blob.read_shift(2);
        var o = [];
        while (ccv-- > 0)
          o.push(parse_LongRGB(blob, 8));
        return o;
      }
      function parse_XFCRC(blob) {
        blob.l += 2;
        var o = { cxfs: 0, crc: 0 };
        o.cxfs = blob.read_shift(2);
        o.crc = blob.read_shift(4);
        return o;
      }
      function parse_ColInfo(blob, length, opts) {
        if (!opts.cellStyles)
          return parsenoop(blob, length);
        var w = opts && opts.biff >= 12 ? 4 : 2;
        var colFirst = blob.read_shift(w);
        var colLast = blob.read_shift(w);
        var coldx = blob.read_shift(w);
        var ixfe = blob.read_shift(w);
        var flags = blob.read_shift(2);
        if (w == 2)
          blob.l += 2;
        var o = { s: colFirst, e: colLast, w: coldx, ixfe, flags };
        if (opts.biff >= 5 || !opts.biff)
          o.level = flags >> 8 & 7;
        return o;
      }
      function write_ColInfo(col, idx) {
        var o = new_buf(12);
        o.write_shift(2, idx);
        o.write_shift(2, idx);
        o.write_shift(2, col.width * 256);
        o.write_shift(2, 0);
        var f = 0;
        if (col.hidden)
          f |= 1;
        o.write_shift(1, f);
        f = col.level || 0;
        o.write_shift(1, f);
        o.write_shift(2, 0);
        return o;
      }
      function parse_Setup(blob, length) {
        var o = {};
        if (length < 32)
          return o;
        blob.l += 16;
        o.header = parse_Xnum(blob, 8);
        o.footer = parse_Xnum(blob, 8);
        blob.l += 2;
        return o;
      }
      function parse_ShtProps(blob, length, opts) {
        var def = { area: false };
        if (opts.biff != 5) {
          blob.l += length;
          return def;
        }
        var d = blob.read_shift(1);
        blob.l += 3;
        if (d & 16)
          def.area = true;
        return def;
      }
      function write_RRTabId(n) {
        var out = new_buf(2 * n);
        for (var i = 0; i < n; ++i)
          out.write_shift(2, i + 1);
        return out;
      }
      var parse_Blank = parse_XLSCell;
      var parse_Scl = parseuint16a;
      var parse_String = parse_XLUnicodeString;
      function parse_ImData(blob) {
        var cf = blob.read_shift(2);
        var env = blob.read_shift(2);
        var lcb = blob.read_shift(4);
        var o = { fmt: cf, env, len: lcb, data: blob.slice(blob.l, blob.l + lcb) };
        blob.l += lcb;
        return o;
      }
      function parse_BIFF2STR(blob, length, opts) {
        if (opts.biffguess && opts.biff == 5)
          opts.biff = 2;
        var cell = parse_XLSCell(blob, 6);
        ++blob.l;
        var str = parse_XLUnicodeString2(blob, length - 7, opts);
        cell.t = "str";
        cell.val = str;
        return cell;
      }
      function parse_BIFF2NUM(blob) {
        var cell = parse_XLSCell(blob, 6);
        ++blob.l;
        var num = parse_Xnum(blob, 8);
        cell.t = "n";
        cell.val = num;
        return cell;
      }
      function write_BIFF2NUM(r, c, val) {
        var out = new_buf(15);
        write_BIFF2Cell(out, r, c);
        out.write_shift(8, val, "f");
        return out;
      }
      function parse_BIFF2INT(blob) {
        var cell = parse_XLSCell(blob, 6);
        ++blob.l;
        var num = blob.read_shift(2);
        cell.t = "n";
        cell.val = num;
        return cell;
      }
      function write_BIFF2INT(r, c, val) {
        var out = new_buf(9);
        write_BIFF2Cell(out, r, c);
        out.write_shift(2, val);
        return out;
      }
      function parse_BIFF2STRING(blob) {
        var cch = blob.read_shift(1);
        if (cch === 0) {
          blob.l++;
          return "";
        }
        return blob.read_shift(cch, "sbcs-cont");
      }
      function parse_BIFF2FONTXTRA(blob, length) {
        blob.l += 6;
        blob.l += 2;
        blob.l += 1;
        blob.l += 3;
        blob.l += 1;
        blob.l += length - 13;
      }
      function parse_RString(blob, length, opts) {
        var end = blob.l + length;
        var cell = parse_XLSCell(blob, 6);
        var cch = blob.read_shift(2);
        var str = parse_XLUnicodeStringNoCch(blob, cch, opts);
        blob.l = end;
        cell.t = "str";
        cell.val = str;
        return cell;
      }
      var DBF_SUPPORTED_VERSIONS = [2, 3, 48, 49, 131, 139, 140, 245];
      var DBF = function() {
        var dbf_codepage_map = {
          /* Code Pages Supported by Visual FoxPro */
          1: 437,
          2: 850,
          3: 1252,
          4: 1e4,
          100: 852,
          101: 866,
          102: 865,
          103: 861,
          104: 895,
          105: 620,
          106: 737,
          107: 857,
          120: 950,
          121: 949,
          122: 936,
          123: 932,
          124: 874,
          125: 1255,
          126: 1256,
          150: 10007,
          151: 10029,
          152: 10006,
          200: 1250,
          201: 1251,
          202: 1254,
          203: 1253,
          /* shapefile DBF extension */
          0: 20127,
          8: 865,
          9: 437,
          10: 850,
          11: 437,
          13: 437,
          14: 850,
          15: 437,
          16: 850,
          17: 437,
          18: 850,
          19: 932,
          20: 850,
          21: 437,
          22: 850,
          23: 865,
          24: 437,
          25: 437,
          26: 850,
          27: 437,
          28: 863,
          29: 850,
          31: 852,
          34: 852,
          35: 852,
          36: 860,
          37: 850,
          38: 866,
          55: 850,
          64: 852,
          77: 936,
          78: 949,
          79: 950,
          80: 874,
          87: 1252,
          88: 1252,
          89: 1252,
          108: 863,
          134: 737,
          135: 852,
          136: 857,
          204: 1257,
          255: 16969
        };
        var dbf_reverse_map = evert({
          1: 437,
          2: 850,
          3: 1252,
          4: 1e4,
          100: 852,
          101: 866,
          102: 865,
          103: 861,
          104: 895,
          105: 620,
          106: 737,
          107: 857,
          120: 950,
          121: 949,
          122: 936,
          123: 932,
          124: 874,
          125: 1255,
          126: 1256,
          150: 10007,
          151: 10029,
          152: 10006,
          200: 1250,
          201: 1251,
          202: 1254,
          203: 1253,
          0: 20127
        });
        function dbf_to_aoa(buf, opts) {
          var out = [];
          var d = new_raw_buf(1);
          switch (opts.type) {
            case "base64":
              d = s2a(Base64_decode(buf));
              break;
            case "binary":
              d = s2a(buf);
              break;
            case "buffer":
            case "array":
              d = buf;
              break;
          }
          prep_blob(d, 0);
          var ft = d.read_shift(1);
          var memo = !!(ft & 136);
          var vfp = false, l7 = false;
          switch (ft) {
            case 2:
              break;
            case 3:
              break;
            case 48:
              vfp = true;
              memo = true;
              break;
            case 49:
              vfp = true;
              memo = true;
              break;
            case 131:
              break;
            case 139:
              break;
            case 140:
              l7 = true;
              break;
            case 245:
              break;
            default:
              throw new Error("DBF Unsupported Version: " + ft.toString(16));
          }
          var nrow = 0, fpos = 521;
          if (ft == 2)
            nrow = d.read_shift(2);
          d.l += 3;
          if (ft != 2)
            nrow = d.read_shift(4);
          if (nrow > 1048576)
            nrow = 1e6;
          if (ft != 2)
            fpos = d.read_shift(2);
          var rlen = d.read_shift(2);
          var current_cp = opts.codepage || 1252;
          if (ft != 2) {
            d.l += 16;
            d.read_shift(1);
            if (d[d.l] !== 0)
              current_cp = dbf_codepage_map[d[d.l]];
            d.l += 1;
            d.l += 2;
          }
          if (l7)
            d.l += 36;
          var fields = [], field = {};
          var hend = Math.min(d.length, ft == 2 ? 521 : fpos - 10 - (vfp ? 264 : 0));
          var ww = l7 ? 32 : 11;
          while (d.l < hend && d[d.l] != 13) {
            field = {};
            field.name = $cptable.utils.decode(current_cp, d.slice(d.l, d.l + ww)).replace(/[\u0000\r\n].*$/g, "");
            d.l += ww;
            field.type = String.fromCharCode(d.read_shift(1));
            if (ft != 2 && !l7)
              field.offset = d.read_shift(4);
            field.len = d.read_shift(1);
            if (ft == 2)
              field.offset = d.read_shift(2);
            field.dec = d.read_shift(1);
            if (field.name.length)
              fields.push(field);
            if (ft != 2)
              d.l += l7 ? 13 : 14;
            switch (field.type) {
              case "B":
                if ((!vfp || field.len != 8) && opts.WTF)
                  console.log("Skipping " + field.name + ":" + field.type);
                break;
              case "G":
              case "P":
                if (opts.WTF)
                  console.log("Skipping " + field.name + ":" + field.type);
                break;
              case "+":
              case "0":
              case "@":
              case "C":
              case "D":
              case "F":
              case "I":
              case "L":
              case "M":
              case "N":
              case "O":
              case "T":
              case "Y":
                break;
              default:
                throw new Error("Unknown Field Type: " + field.type);
            }
          }
          if (d[d.l] !== 13)
            d.l = fpos - 1;
          if (d.read_shift(1) !== 13)
            throw new Error("DBF Terminator not found " + d.l + " " + d[d.l]);
          d.l = fpos;
          var R = 0, C = 0;
          out[0] = [];
          for (C = 0; C != fields.length; ++C)
            out[0][C] = fields[C].name;
          while (nrow-- > 0) {
            if (d[d.l] === 42) {
              d.l += rlen;
              continue;
            }
            ++d.l;
            out[++R] = [];
            C = 0;
            for (C = 0; C != fields.length; ++C) {
              var dd = d.slice(d.l, d.l + fields[C].len);
              d.l += fields[C].len;
              prep_blob(dd, 0);
              var s = $cptable.utils.decode(current_cp, dd);
              switch (fields[C].type) {
                case "C":
                  if (s.trim().length)
                    out[R][C] = s.replace(/\s+$/, "");
                  break;
                case "D":
                  if (s.length === 8)
                    out[R][C] = new Date(+s.slice(0, 4), +s.slice(4, 6) - 1, +s.slice(6, 8));
                  else
                    out[R][C] = s;
                  break;
                case "F":
                  out[R][C] = parseFloat(s.trim());
                  break;
                case "+":
                case "I":
                  out[R][C] = l7 ? dd.read_shift(-4, "i") ^ 2147483648 : dd.read_shift(4, "i");
                  break;
                case "L":
                  switch (s.trim().toUpperCase()) {
                    case "Y":
                    case "T":
                      out[R][C] = true;
                      break;
                    case "N":
                    case "F":
                      out[R][C] = false;
                      break;
                    case "":
                    case "?":
                      break;
                    default:
                      throw new Error("DBF Unrecognized L:|" + s + "|");
                  }
                  break;
                case "M":
                  if (!memo)
                    throw new Error("DBF Unexpected MEMO for type " + ft.toString(16));
                  out[R][C] = "##MEMO##" + (l7 ? parseInt(s.trim(), 10) : dd.read_shift(4));
                  break;
                case "N":
                  s = s.replace(/\u0000/g, "").trim();
                  if (s && s != ".")
                    out[R][C] = +s || 0;
                  break;
                case "@":
                  out[R][C] = new Date(dd.read_shift(-8, "f") - 621356832e5);
                  break;
                case "T":
                  out[R][C] = new Date((dd.read_shift(4) - 2440588) * 864e5 + dd.read_shift(4));
                  break;
                case "Y":
                  out[R][C] = dd.read_shift(4, "i") / 1e4 + dd.read_shift(4, "i") / 1e4 * Math.pow(2, 32);
                  break;
                case "O":
                  out[R][C] = -dd.read_shift(-8, "f");
                  break;
                case "B":
                  if (vfp && fields[C].len == 8) {
                    out[R][C] = dd.read_shift(8, "f");
                    break;
                  }
                case "G":
                case "P":
                  dd.l += fields[C].len;
                  break;
                case "0":
                  if (fields[C].name === "_NullFlags")
                    break;
                default:
                  throw new Error("DBF Unsupported data type " + fields[C].type);
              }
            }
          }
          if (ft != 2) {
            if (d.l < d.length && d[d.l++] != 26)
              throw new Error("DBF EOF Marker missing " + (d.l - 1) + " of " + d.length + " " + d[d.l - 1].toString(16));
          }
          if (opts && opts.sheetRows)
            out = out.slice(0, opts.sheetRows);
          opts.DBF = fields;
          return out;
        }
        function dbf_to_sheet(buf, opts) {
          var o = opts || {};
          if (!o.dateNF)
            o.dateNF = "yyyymmdd";
          var ws = aoa_to_sheet(dbf_to_aoa(buf, o), o);
          ws["!cols"] = o.DBF.map(function(field) {
            return {
              wch: field.len,
              DBF: field
            };
          });
          delete o.DBF;
          return ws;
        }
        function dbf_to_workbook(buf, opts) {
          try {
            return sheet_to_workbook(dbf_to_sheet(buf, opts), opts);
          } catch (e) {
            if (opts && opts.WTF)
              throw e;
          }
          return { SheetNames: [], Sheets: {} };
        }
        var _RLEN = { "B": 8, "C": 250, "L": 1, "D": 8, "?": 0, "": 0 };
        function sheet_to_dbf(ws, opts) {
          var o = opts || {};
          if (+o.codepage >= 0)
            set_cp(+o.codepage);
          if (o.type == "string")
            throw new Error("Cannot write DBF to JS string");
          var ba = buf_array();
          var aoa = sheet_to_json(ws, { header: 1, raw: true, cellDates: true });
          var headers = aoa[0], data = aoa.slice(1), cols = ws["!cols"] || [];
          var i = 0, j = 0, hcnt = 0, rlen = 1;
          for (i = 0; i < headers.length; ++i) {
            if (((cols[i] || {}).DBF || {}).name) {
              headers[i] = cols[i].DBF.name;
              ++hcnt;
              continue;
            }
            if (headers[i] == null)
              continue;
            ++hcnt;
            if (typeof headers[i] === "number")
              headers[i] = headers[i].toString(10);
            if (typeof headers[i] !== "string")
              throw new Error("DBF Invalid column name " + headers[i] + " |" + typeof headers[i] + "|");
            if (headers.indexOf(headers[i]) !== i) {
              for (j = 0; j < 1024; ++j)
                if (headers.indexOf(headers[i] + "_" + j) == -1) {
                  headers[i] += "_" + j;
                  break;
                }
            }
          }
          var range = safe_decode_range(ws["!ref"]);
          var coltypes = [];
          var colwidths = [];
          var coldecimals = [];
          for (i = 0; i <= range.e.c - range.s.c; ++i) {
            var guess = "", _guess = "", maxlen = 0;
            var col = [];
            for (j = 0; j < data.length; ++j) {
              if (data[j][i] != null)
                col.push(data[j][i]);
            }
            if (col.length == 0 || headers[i] == null) {
              coltypes[i] = "?";
              continue;
            }
            for (j = 0; j < col.length; ++j) {
              switch (typeof col[j]) {
                case "number":
                  _guess = "B";
                  break;
                case "string":
                  _guess = "C";
                  break;
                case "boolean":
                  _guess = "L";
                  break;
                case "object":
                  _guess = col[j] instanceof Date ? "D" : "C";
                  break;
                default:
                  _guess = "C";
              }
              maxlen = Math.max(maxlen, String(col[j]).length);
              guess = guess && guess != _guess ? "C" : _guess;
            }
            if (maxlen > 250)
              maxlen = 250;
            _guess = ((cols[i] || {}).DBF || {}).type;
            if (_guess == "C") {
              if (cols[i].DBF.len > maxlen)
                maxlen = cols[i].DBF.len;
            }
            if (guess == "B" && _guess == "N") {
              guess = "N";
              coldecimals[i] = cols[i].DBF.dec;
              maxlen = cols[i].DBF.len;
            }
            colwidths[i] = guess == "C" || _guess == "N" ? maxlen : _RLEN[guess] || 0;
            rlen += colwidths[i];
            coltypes[i] = guess;
          }
          var h = ba.next(32);
          h.write_shift(4, 318902576);
          h.write_shift(4, data.length);
          h.write_shift(2, 296 + 32 * hcnt);
          h.write_shift(2, rlen);
          for (i = 0; i < 4; ++i)
            h.write_shift(4, 0);
          h.write_shift(4, 0 | (+dbf_reverse_map[current_ansi] || 3) << 8);
          for (i = 0, j = 0; i < headers.length; ++i) {
            if (headers[i] == null)
              continue;
            var hf = ba.next(32);
            var _f = (headers[i].slice(-10) + "\0\0\0\0\0\0\0\0\0\0\0").slice(0, 11);
            hf.write_shift(1, _f, "sbcs");
            hf.write_shift(1, coltypes[i] == "?" ? "C" : coltypes[i], "sbcs");
            hf.write_shift(4, j);
            hf.write_shift(1, colwidths[i] || _RLEN[coltypes[i]] || 0);
            hf.write_shift(1, coldecimals[i] || 0);
            hf.write_shift(1, 2);
            hf.write_shift(4, 0);
            hf.write_shift(1, 0);
            hf.write_shift(4, 0);
            hf.write_shift(4, 0);
            j += colwidths[i] || _RLEN[coltypes[i]] || 0;
          }
          var hb = ba.next(264);
          hb.write_shift(4, 13);
          for (i = 0; i < 65; ++i)
            hb.write_shift(4, 0);
          for (i = 0; i < data.length; ++i) {
            var rout = ba.next(rlen);
            rout.write_shift(1, 0);
            for (j = 0; j < headers.length; ++j) {
              if (headers[j] == null)
                continue;
              switch (coltypes[j]) {
                case "L":
                  rout.write_shift(1, data[i][j] == null ? 63 : data[i][j] ? 84 : 70);
                  break;
                case "B":
                  rout.write_shift(8, data[i][j] || 0, "f");
                  break;
                case "N":
                  var _n = "0";
                  if (typeof data[i][j] == "number")
                    _n = data[i][j].toFixed(coldecimals[j] || 0);
                  for (hcnt = 0; hcnt < colwidths[j] - _n.length; ++hcnt)
                    rout.write_shift(1, 32);
                  rout.write_shift(1, _n, "sbcs");
                  break;
                case "D":
                  if (!data[i][j])
                    rout.write_shift(8, "00000000", "sbcs");
                  else {
                    rout.write_shift(4, ("0000" + data[i][j].getFullYear()).slice(-4), "sbcs");
                    rout.write_shift(2, ("00" + (data[i][j].getMonth() + 1)).slice(-2), "sbcs");
                    rout.write_shift(2, ("00" + data[i][j].getDate()).slice(-2), "sbcs");
                  }
                  break;
                case "C":
                  var _s = String(data[i][j] != null ? data[i][j] : "").slice(0, colwidths[j]);
                  rout.write_shift(1, _s, "sbcs");
                  for (hcnt = 0; hcnt < colwidths[j] - _s.length; ++hcnt)
                    rout.write_shift(1, 32);
                  break;
              }
            }
          }
          ba.next(1).write_shift(1, 26);
          return ba.end();
        }
        return {
          to_workbook: dbf_to_workbook,
          to_sheet: dbf_to_sheet,
          from_sheet: sheet_to_dbf
        };
      }();
      var SYLK = function() {
        var sylk_escapes = {
          AA: "\xC0",
          BA: "\xC1",
          CA: "\xC2",
          DA: 195,
          HA: "\xC4",
          JA: 197,
          AE: "\xC8",
          BE: "\xC9",
          CE: "\xCA",
          HE: "\xCB",
          AI: "\xCC",
          BI: "\xCD",
          CI: "\xCE",
          HI: "\xCF",
          AO: "\xD2",
          BO: "\xD3",
          CO: "\xD4",
          DO: 213,
          HO: "\xD6",
          AU: "\xD9",
          BU: "\xDA",
          CU: "\xDB",
          HU: "\xDC",
          Aa: "\xE0",
          Ba: "\xE1",
          Ca: "\xE2",
          Da: 227,
          Ha: "\xE4",
          Ja: 229,
          Ae: "\xE8",
          Be: "\xE9",
          Ce: "\xEA",
          He: "\xEB",
          Ai: "\xEC",
          Bi: "\xED",
          Ci: "\xEE",
          Hi: "\xEF",
          Ao: "\xF2",
          Bo: "\xF3",
          Co: "\xF4",
          Do: 245,
          Ho: "\xF6",
          Au: "\xF9",
          Bu: "\xFA",
          Cu: "\xFB",
          Hu: "\xFC",
          KC: "\xC7",
          Kc: "\xE7",
          q: "\xE6",
          z: "\u0153",
          a: "\xC6",
          j: "\u0152",
          DN: 209,
          Dn: 241,
          Hy: 255,
          S: 169,
          c: 170,
          R: 174,
          "B ": 180,
          0: 176,
          1: 177,
          2: 178,
          3: 179,
          5: 181,
          6: 182,
          7: 183,
          Q: 185,
          k: 186,
          b: 208,
          i: 216,
          l: 222,
          s: 240,
          y: 248,
          "!": 161,
          '"': 162,
          "#": 163,
          "(": 164,
          "%": 165,
          "'": 167,
          "H ": 168,
          "+": 171,
          ";": 187,
          "<": 188,
          "=": 189,
          ">": 190,
          "?": 191,
          "{": 223
        };
        var sylk_char_regex = new RegExp("\x1BN(" + keys3(sylk_escapes).join("|").replace(/\|\|\|/, "|\\||").replace(/([?()+])/g, "\\$1") + "|\\|)", "gm");
        var sylk_char_fn = function(_, $1) {
          var o = sylk_escapes[$1];
          return typeof o == "number" ? _getansi(o) : o;
        };
        var decode_sylk_char = function($$, $1, $2) {
          var newcc = $1.charCodeAt(0) - 32 << 4 | $2.charCodeAt(0) - 48;
          return newcc == 59 ? $$ : _getansi(newcc);
        };
        sylk_escapes["|"] = 254;
        function sylk_to_aoa(d, opts) {
          switch (opts.type) {
            case "base64":
              return sylk_to_aoa_str(Base64_decode(d), opts);
            case "binary":
              return sylk_to_aoa_str(d, opts);
            case "buffer":
              return sylk_to_aoa_str(has_buf && Buffer.isBuffer(d) ? d.toString("binary") : a2s(d), opts);
            case "array":
              return sylk_to_aoa_str(cc2str(d), opts);
          }
          throw new Error("Unrecognized type " + opts.type);
        }
        function sylk_to_aoa_str(str, opts) {
          var records = str.split(/[\n\r]+/), R = -1, C = -1, ri = 0, rj = 0, arr = [];
          var formats = [];
          var next_cell_format = null;
          var sht = {}, rowinfo = [], colinfo = [], cw = [];
          var Mval = 0, j;
          if (+opts.codepage >= 0)
            set_cp(+opts.codepage);
          for (; ri !== records.length; ++ri) {
            Mval = 0;
            var rstr = records[ri].trim().replace(/\x1B([\x20-\x2F])([\x30-\x3F])/g, decode_sylk_char).replace(sylk_char_regex, sylk_char_fn);
            var record = rstr.replace(/;;/g, "\0").split(";").map(function(x) {
              return x.replace(/\u0000/g, ";");
            });
            var RT = record[0], val;
            if (rstr.length > 0)
              switch (RT) {
                case "ID":
                  break;
                case "E":
                  break;
                case "B":
                  break;
                case "O":
                  break;
                case "W":
                  break;
                case "P":
                  if (record[1].charAt(0) == "P")
                    formats.push(rstr.slice(3).replace(/;;/g, ";"));
                  break;
                case "C":
                  var C_seen_K = false, C_seen_X = false, C_seen_S = false, C_seen_E = false, _R = -1, _C = -1;
                  for (rj = 1; rj < record.length; ++rj)
                    switch (record[rj].charAt(0)) {
                      case "A":
                        break;
                      case "X":
                        C = parseInt(record[rj].slice(1)) - 1;
                        C_seen_X = true;
                        break;
                      case "Y":
                        R = parseInt(record[rj].slice(1)) - 1;
                        if (!C_seen_X)
                          C = 0;
                        for (j = arr.length; j <= R; ++j)
                          arr[j] = [];
                        break;
                      case "K":
                        val = record[rj].slice(1);
                        if (val.charAt(0) === '"')
                          val = val.slice(1, val.length - 1);
                        else if (val === "TRUE")
                          val = true;
                        else if (val === "FALSE")
                          val = false;
                        else if (!isNaN(fuzzynum(val))) {
                          val = fuzzynum(val);
                          if (next_cell_format !== null && fmt_is_date(next_cell_format))
                            val = numdate(val);
                        } else if (!isNaN(fuzzydate(val).getDate())) {
                          val = parseDate(val);
                        }
                        if (typeof $cptable !== "undefined" && typeof val == "string" && (opts || {}).type != "string" && (opts || {}).codepage)
                          val = $cptable.utils.decode(opts.codepage, val);
                        C_seen_K = true;
                        break;
                      case "E":
                        C_seen_E = true;
                        var formula = rc_to_a1(record[rj].slice(1), { r: R, c: C });
                        arr[R][C] = [arr[R][C], formula];
                        break;
                      case "S":
                        C_seen_S = true;
                        arr[R][C] = [arr[R][C], "S5S"];
                        break;
                      case "G":
                        break;
                      case "R":
                        _R = parseInt(record[rj].slice(1)) - 1;
                        break;
                      case "C":
                        _C = parseInt(record[rj].slice(1)) - 1;
                        break;
                      default:
                        if (opts && opts.WTF)
                          throw new Error("SYLK bad record " + rstr);
                    }
                  if (C_seen_K) {
                    if (arr[R][C] && arr[R][C].length == 2)
                      arr[R][C][0] = val;
                    else
                      arr[R][C] = val;
                    next_cell_format = null;
                  }
                  if (C_seen_S) {
                    if (C_seen_E)
                      throw new Error("SYLK shared formula cannot have own formula");
                    var shrbase = _R > -1 && arr[_R][_C];
                    if (!shrbase || !shrbase[1])
                      throw new Error("SYLK shared formula cannot find base");
                    arr[R][C][1] = shift_formula_str(shrbase[1], { r: R - _R, c: C - _C });
                  }
                  break;
                case "F":
                  var F_seen = 0;
                  for (rj = 1; rj < record.length; ++rj)
                    switch (record[rj].charAt(0)) {
                      case "X":
                        C = parseInt(record[rj].slice(1)) - 1;
                        ++F_seen;
                        break;
                      case "Y":
                        R = parseInt(record[rj].slice(1)) - 1;
                        for (j = arr.length; j <= R; ++j)
                          arr[j] = [];
                        break;
                      case "M":
                        Mval = parseInt(record[rj].slice(1)) / 20;
                        break;
                      case "F":
                        break;
                      case "G":
                        break;
                      case "P":
                        next_cell_format = formats[parseInt(record[rj].slice(1))];
                        break;
                      case "S":
                        break;
                      case "D":
                        break;
                      case "N":
                        break;
                      case "W":
                        cw = record[rj].slice(1).split(" ");
                        for (j = parseInt(cw[0], 10); j <= parseInt(cw[1], 10); ++j) {
                          Mval = parseInt(cw[2], 10);
                          colinfo[j - 1] = Mval === 0 ? { hidden: true } : { wch: Mval };
                          process_col(colinfo[j - 1]);
                        }
                        break;
                      case "C":
                        C = parseInt(record[rj].slice(1)) - 1;
                        if (!colinfo[C])
                          colinfo[C] = {};
                        break;
                      case "R":
                        R = parseInt(record[rj].slice(1)) - 1;
                        if (!rowinfo[R])
                          rowinfo[R] = {};
                        if (Mval > 0) {
                          rowinfo[R].hpt = Mval;
                          rowinfo[R].hpx = pt2px(Mval);
                        } else if (Mval === 0)
                          rowinfo[R].hidden = true;
                        break;
                      default:
                        if (opts && opts.WTF)
                          throw new Error("SYLK bad record " + rstr);
                    }
                  if (F_seen < 1)
                    next_cell_format = null;
                  break;
                default:
                  if (opts && opts.WTF)
                    throw new Error("SYLK bad record " + rstr);
              }
          }
          if (rowinfo.length > 0)
            sht["!rows"] = rowinfo;
          if (colinfo.length > 0)
            sht["!cols"] = colinfo;
          if (opts && opts.sheetRows)
            arr = arr.slice(0, opts.sheetRows);
          return [arr, sht];
        }
        function sylk_to_sheet(d, opts) {
          var aoasht = sylk_to_aoa(d, opts);
          var aoa = aoasht[0], ws = aoasht[1];
          var o = aoa_to_sheet(aoa, opts);
          keys3(ws).forEach(function(k) {
            o[k] = ws[k];
          });
          return o;
        }
        function sylk_to_workbook(d, opts) {
          return sheet_to_workbook(sylk_to_sheet(d, opts), opts);
        }
        function write_ws_cell_sylk(cell, ws, R, C) {
          var o = "C;Y" + (R + 1) + ";X" + (C + 1) + ";K";
          switch (cell.t) {
            case "n":
              o += cell.v || 0;
              if (cell.f && !cell.F)
                o += ";E" + a1_to_rc(cell.f, { r: R, c: C });
              break;
            case "b":
              o += cell.v ? "TRUE" : "FALSE";
              break;
            case "e":
              o += cell.w || cell.v;
              break;
            case "d":
              o += '"' + (cell.w || cell.v) + '"';
              break;
            case "s":
              o += '"' + cell.v.replace(/"/g, "").replace(/;/g, ";;") + '"';
              break;
          }
          return o;
        }
        function write_ws_cols_sylk(out, cols) {
          cols.forEach(function(col, i) {
            var rec = "F;W" + (i + 1) + " " + (i + 1) + " ";
            if (col.hidden)
              rec += "0";
            else {
              if (typeof col.width == "number" && !col.wpx)
                col.wpx = width2px(col.width);
              if (typeof col.wpx == "number" && !col.wch)
                col.wch = px2char(col.wpx);
              if (typeof col.wch == "number")
                rec += Math.round(col.wch);
            }
            if (rec.charAt(rec.length - 1) != " ")
              out.push(rec);
          });
        }
        function write_ws_rows_sylk(out, rows) {
          rows.forEach(function(row, i) {
            var rec = "F;";
            if (row.hidden)
              rec += "M0;";
            else if (row.hpt)
              rec += "M" + 20 * row.hpt + ";";
            else if (row.hpx)
              rec += "M" + 20 * px2pt(row.hpx) + ";";
            if (rec.length > 2)
              out.push(rec + "R" + (i + 1));
          });
        }
        function sheet_to_sylk(ws, opts) {
          var preamble = ["ID;PWXL;N;E"], o = [];
          var r = safe_decode_range(ws["!ref"]), cell;
          var dense = Array.isArray(ws);
          var RS = "\r\n";
          preamble.push("P;PGeneral");
          preamble.push("F;P0;DG0G8;M255");
          if (ws["!cols"])
            write_ws_cols_sylk(preamble, ws["!cols"]);
          if (ws["!rows"])
            write_ws_rows_sylk(preamble, ws["!rows"]);
          preamble.push("B;Y" + (r.e.r - r.s.r + 1) + ";X" + (r.e.c - r.s.c + 1) + ";D" + [r.s.c, r.s.r, r.e.c, r.e.r].join(" "));
          for (var R = r.s.r; R <= r.e.r; ++R) {
            for (var C = r.s.c; C <= r.e.c; ++C) {
              var coord = encode_cell({ r: R, c: C });
              cell = dense ? (ws[R] || [])[C] : ws[coord];
              if (!cell || cell.v == null && (!cell.f || cell.F))
                continue;
              o.push(write_ws_cell_sylk(cell, ws, R, C, opts));
            }
          }
          return preamble.join(RS) + RS + o.join(RS) + RS + "E" + RS;
        }
        return {
          to_workbook: sylk_to_workbook,
          to_sheet: sylk_to_sheet,
          from_sheet: sheet_to_sylk
        };
      }();
      var DIF = function() {
        function dif_to_aoa(d, opts) {
          switch (opts.type) {
            case "base64":
              return dif_to_aoa_str(Base64_decode(d), opts);
            case "binary":
              return dif_to_aoa_str(d, opts);
            case "buffer":
              return dif_to_aoa_str(has_buf && Buffer.isBuffer(d) ? d.toString("binary") : a2s(d), opts);
            case "array":
              return dif_to_aoa_str(cc2str(d), opts);
          }
          throw new Error("Unrecognized type " + opts.type);
        }
        function dif_to_aoa_str(str, opts) {
          var records = str.split("\n"), R = -1, C = -1, ri = 0, arr = [];
          for (; ri !== records.length; ++ri) {
            if (records[ri].trim() === "BOT") {
              arr[++R] = [];
              C = 0;
              continue;
            }
            if (R < 0)
              continue;
            var metadata = records[ri].trim().split(",");
            var type = metadata[0], value2 = metadata[1];
            ++ri;
            var data = records[ri] || "";
            while ((data.match(/["]/g) || []).length & 1 && ri < records.length - 1)
              data += "\n" + records[++ri];
            data = data.trim();
            switch (+type) {
              case -1:
                if (data === "BOT") {
                  arr[++R] = [];
                  C = 0;
                  continue;
                } else if (data !== "EOD")
                  throw new Error("Unrecognized DIF special command " + data);
                break;
              case 0:
                if (data === "TRUE")
                  arr[R][C] = true;
                else if (data === "FALSE")
                  arr[R][C] = false;
                else if (!isNaN(fuzzynum(value2)))
                  arr[R][C] = fuzzynum(value2);
                else if (!isNaN(fuzzydate(value2).getDate()))
                  arr[R][C] = parseDate(value2);
                else
                  arr[R][C] = value2;
                ++C;
                break;
              case 1:
                data = data.slice(1, data.length - 1);
                data = data.replace(/""/g, '"');
                if (DIF_XL && data && data.match(/^=".*"$/))
                  data = data.slice(2, -1);
                arr[R][C++] = data !== "" ? data : null;
                break;
            }
            if (data === "EOD")
              break;
          }
          if (opts && opts.sheetRows)
            arr = arr.slice(0, opts.sheetRows);
          return arr;
        }
        function dif_to_sheet(str, opts) {
          return aoa_to_sheet(dif_to_aoa(str, opts), opts);
        }
        function dif_to_workbook(str, opts) {
          return sheet_to_workbook(dif_to_sheet(str, opts), opts);
        }
        var sheet_to_dif = function() {
          var push_field = function pf(o, topic, v, n, s) {
            o.push(topic);
            o.push(v + "," + n);
            o.push('"' + s.replace(/"/g, '""') + '"');
          };
          var push_value = function po(o, type, v, s) {
            o.push(type + "," + v);
            o.push(type == 1 ? '"' + s.replace(/"/g, '""') + '"' : s);
          };
          return function sheet_to_dif2(ws) {
            var o = [];
            var r = safe_decode_range(ws["!ref"]), cell;
            var dense = Array.isArray(ws);
            push_field(o, "TABLE", 0, 1, "sheetjs");
            push_field(o, "VECTORS", 0, r.e.r - r.s.r + 1, "");
            push_field(o, "TUPLES", 0, r.e.c - r.s.c + 1, "");
            push_field(o, "DATA", 0, 0, "");
            for (var R = r.s.r; R <= r.e.r; ++R) {
              push_value(o, -1, 0, "BOT");
              for (var C = r.s.c; C <= r.e.c; ++C) {
                var coord = encode_cell({ r: R, c: C });
                cell = dense ? (ws[R] || [])[C] : ws[coord];
                if (!cell) {
                  push_value(o, 1, 0, "");
                  continue;
                }
                switch (cell.t) {
                  case "n":
                    var val = DIF_XL ? cell.w : cell.v;
                    if (!val && cell.v != null)
                      val = cell.v;
                    if (val == null) {
                      if (DIF_XL && cell.f && !cell.F)
                        push_value(o, 1, 0, "=" + cell.f);
                      else
                        push_value(o, 1, 0, "");
                    } else
                      push_value(o, 0, val, "V");
                    break;
                  case "b":
                    push_value(o, 0, cell.v ? 1 : 0, cell.v ? "TRUE" : "FALSE");
                    break;
                  case "s":
                    push_value(o, 1, 0, !DIF_XL || isNaN(cell.v) ? cell.v : '="' + cell.v + '"');
                    break;
                  case "d":
                    if (!cell.w)
                      cell.w = SSF_format(cell.z || table_fmt[14], datenum(parseDate(cell.v)));
                    if (DIF_XL)
                      push_value(o, 0, cell.w, "V");
                    else
                      push_value(o, 1, 0, cell.w);
                    break;
                  default:
                    push_value(o, 1, 0, "");
                }
              }
            }
            push_value(o, -1, 0, "EOD");
            var RS = "\r\n";
            var oo = o.join(RS);
            return oo;
          };
        }();
        return {
          to_workbook: dif_to_workbook,
          to_sheet: dif_to_sheet,
          from_sheet: sheet_to_dif
        };
      }();
      var ETH = function() {
        function decode(s) {
          return s.replace(/\\b/g, "\\").replace(/\\c/g, ":").replace(/\\n/g, "\n");
        }
        function encode(s) {
          return s.replace(/\\/g, "\\b").replace(/:/g, "\\c").replace(/\n/g, "\\n");
        }
        function eth_to_aoa(str, opts) {
          var records = str.split("\n"), R = -1, C = -1, ri = 0, arr = [];
          for (; ri !== records.length; ++ri) {
            var record = records[ri].trim().split(":");
            if (record[0] !== "cell")
              continue;
            var addr = decode_cell(record[1]);
            if (arr.length <= addr.r) {
              for (R = arr.length; R <= addr.r; ++R)
                if (!arr[R])
                  arr[R] = [];
            }
            R = addr.r;
            C = addr.c;
            switch (record[2]) {
              case "t":
                arr[R][C] = decode(record[3]);
                break;
              case "v":
                arr[R][C] = +record[3];
                break;
              case "vtf":
                var _f = record[record.length - 1];
              case "vtc":
                switch (record[3]) {
                  case "nl":
                    arr[R][C] = +record[4] ? true : false;
                    break;
                  default:
                    arr[R][C] = +record[4];
                    break;
                }
                if (record[2] == "vtf")
                  arr[R][C] = [arr[R][C], _f];
            }
          }
          if (opts && opts.sheetRows)
            arr = arr.slice(0, opts.sheetRows);
          return arr;
        }
        function eth_to_sheet(d, opts) {
          return aoa_to_sheet(eth_to_aoa(d, opts), opts);
        }
        function eth_to_workbook(d, opts) {
          return sheet_to_workbook(eth_to_sheet(d, opts), opts);
        }
        var header = [
          "socialcalc:version:1.5",
          "MIME-Version: 1.0",
          "Content-Type: multipart/mixed; boundary=SocialCalcSpreadsheetControlSave"
        ].join("\n");
        var sep = [
          "--SocialCalcSpreadsheetControlSave",
          "Content-type: text/plain; charset=UTF-8"
        ].join("\n") + "\n";
        var meta = [
          "# SocialCalc Spreadsheet Control Save",
          "part:sheet"
        ].join("\n");
        var end = "--SocialCalcSpreadsheetControlSave--";
        function sheet_to_eth_data(ws) {
          if (!ws || !ws["!ref"])
            return "";
          var o = [], oo = [], cell, coord = "";
          var r = decode_range(ws["!ref"]);
          var dense = Array.isArray(ws);
          for (var R = r.s.r; R <= r.e.r; ++R) {
            for (var C = r.s.c; C <= r.e.c; ++C) {
              coord = encode_cell({ r: R, c: C });
              cell = dense ? (ws[R] || [])[C] : ws[coord];
              if (!cell || cell.v == null || cell.t === "z")
                continue;
              oo = ["cell", coord, "t"];
              switch (cell.t) {
                case "s":
                case "str":
                  oo.push(encode(cell.v));
                  break;
                case "n":
                  if (!cell.f) {
                    oo[2] = "v";
                    oo[3] = cell.v;
                  } else {
                    oo[2] = "vtf";
                    oo[3] = "n";
                    oo[4] = cell.v;
                    oo[5] = encode(cell.f);
                  }
                  break;
                case "b":
                  oo[2] = "vt" + (cell.f ? "f" : "c");
                  oo[3] = "nl";
                  oo[4] = cell.v ? "1" : "0";
                  oo[5] = encode(cell.f || (cell.v ? "TRUE" : "FALSE"));
                  break;
                case "d":
                  var t3 = datenum(parseDate(cell.v));
                  oo[2] = "vtc";
                  oo[3] = "nd";
                  oo[4] = "" + t3;
                  oo[5] = cell.w || SSF_format(cell.z || table_fmt[14], t3);
                  break;
                case "e":
                  continue;
              }
              o.push(oo.join(":"));
            }
          }
          o.push("sheet:c:" + (r.e.c - r.s.c + 1) + ":r:" + (r.e.r - r.s.r + 1) + ":tvf:1");
          o.push("valueformat:1:text-wiki");
          return o.join("\n");
        }
        function sheet_to_eth(ws) {
          return [header, sep, meta, sep, sheet_to_eth_data(ws), end].join("\n");
        }
        return {
          to_workbook: eth_to_workbook,
          to_sheet: eth_to_sheet,
          from_sheet: sheet_to_eth
        };
      }();
      var PRN = function() {
        function set_text_arr(data, arr, R, C, o) {
          if (o.raw)
            arr[R][C] = data;
          else if (data === "") {
          } else if (data === "TRUE")
            arr[R][C] = true;
          else if (data === "FALSE")
            arr[R][C] = false;
          else if (!isNaN(fuzzynum(data)))
            arr[R][C] = fuzzynum(data);
          else if (!isNaN(fuzzydate(data).getDate()))
            arr[R][C] = parseDate(data);
          else
            arr[R][C] = data;
        }
        function prn_to_aoa_str(f, opts) {
          var o = opts || {};
          var arr = [];
          if (!f || f.length === 0)
            return arr;
          var lines = f.split(/[\r\n]/);
          var L = lines.length - 1;
          while (L >= 0 && lines[L].length === 0)
            --L;
          var start = 10, idx = 0;
          var R = 0;
          for (; R <= L; ++R) {
            idx = lines[R].indexOf(" ");
            if (idx == -1)
              idx = lines[R].length;
            else
              idx++;
            start = Math.max(start, idx);
          }
          for (R = 0; R <= L; ++R) {
            arr[R] = [];
            var C = 0;
            set_text_arr(lines[R].slice(0, start).trim(), arr, R, C, o);
            for (C = 1; C <= (lines[R].length - start) / 10 + 1; ++C)
              set_text_arr(lines[R].slice(start + (C - 1) * 10, start + C * 10).trim(), arr, R, C, o);
          }
          if (o.sheetRows)
            arr = arr.slice(0, o.sheetRows);
          return arr;
        }
        var guess_seps = {
          44: ",",
          9: "	",
          59: ";",
          124: "|"
        };
        var guess_sep_weights = {
          44: 3,
          9: 2,
          59: 1,
          124: 0
        };
        function guess_sep(str) {
          var cnt = {}, instr = false, end = 0, cc = 0;
          for (; end < str.length; ++end) {
            if ((cc = str.charCodeAt(end)) == 34)
              instr = !instr;
            else if (!instr && cc in guess_seps)
              cnt[cc] = (cnt[cc] || 0) + 1;
          }
          cc = [];
          for (end in cnt)
            if (Object.prototype.hasOwnProperty.call(cnt, end)) {
              cc.push([cnt[end], end]);
            }
          if (!cc.length) {
            cnt = guess_sep_weights;
            for (end in cnt)
              if (Object.prototype.hasOwnProperty.call(cnt, end)) {
                cc.push([cnt[end], end]);
              }
          }
          cc.sort(function(a, b) {
            return a[0] - b[0] || guess_sep_weights[a[1]] - guess_sep_weights[b[1]];
          });
          return guess_seps[cc.pop()[1]] || 44;
        }
        function dsv_to_sheet_str(str, opts) {
          var o = opts || {};
          var sep = "";
          if (DENSE != null && o.dense == null)
            o.dense = DENSE;
          var ws = o.dense ? [] : {};
          var range = { s: { c: 0, r: 0 }, e: { c: 0, r: 0 } };
          if (str.slice(0, 4) == "sep=") {
            if (str.charCodeAt(5) == 13 && str.charCodeAt(6) == 10) {
              sep = str.charAt(4);
              str = str.slice(7);
            } else if (str.charCodeAt(5) == 13 || str.charCodeAt(5) == 10) {
              sep = str.charAt(4);
              str = str.slice(6);
            } else
              sep = guess_sep(str.slice(0, 1024));
          } else if (o && o.FS)
            sep = o.FS;
          else
            sep = guess_sep(str.slice(0, 1024));
          var R = 0, C = 0, v = 0;
          var start = 0, end = 0, sepcc = sep.charCodeAt(0), instr = false, cc = 0, startcc = str.charCodeAt(0);
          str = str.replace(/\r\n/mg, "\n");
          var _re = o.dateNF != null ? dateNF_regex(o.dateNF) : null;
          function finish_cell() {
            var s = str.slice(start, end);
            var cell = {};
            if (s.charAt(0) == '"' && s.charAt(s.length - 1) == '"')
              s = s.slice(1, -1).replace(/""/g, '"');
            if (s.length === 0)
              cell.t = "z";
            else if (o.raw) {
              cell.t = "s";
              cell.v = s;
            } else if (s.trim().length === 0) {
              cell.t = "s";
              cell.v = s;
            } else if (s.charCodeAt(0) == 61) {
              if (s.charCodeAt(1) == 34 && s.charCodeAt(s.length - 1) == 34) {
                cell.t = "s";
                cell.v = s.slice(2, -1).replace(/""/g, '"');
              } else if (fuzzyfmla(s)) {
                cell.t = "n";
                cell.f = s.slice(1);
              } else {
                cell.t = "s";
                cell.v = s;
              }
            } else if (s == "TRUE") {
              cell.t = "b";
              cell.v = true;
            } else if (s == "FALSE") {
              cell.t = "b";
              cell.v = false;
            } else if (!isNaN(v = fuzzynum(s))) {
              cell.t = "n";
              if (o.cellText !== false)
                cell.w = s;
              cell.v = v;
            } else if (!isNaN(fuzzydate(s).getDate()) || _re && s.match(_re)) {
              cell.z = o.dateNF || table_fmt[14];
              var k = 0;
              if (_re && s.match(_re)) {
                s = dateNF_fix(s, o.dateNF, s.match(_re) || []);
                k = 1;
              }
              if (o.cellDates) {
                cell.t = "d";
                cell.v = parseDate(s, k);
              } else {
                cell.t = "n";
                cell.v = datenum(parseDate(s, k));
              }
              if (o.cellText !== false)
                cell.w = SSF_format(cell.z, cell.v instanceof Date ? datenum(cell.v) : cell.v);
              if (!o.cellNF)
                delete cell.z;
            } else {
              cell.t = "s";
              cell.v = s;
            }
            if (cell.t == "z") {
            } else if (o.dense) {
              if (!ws[R])
                ws[R] = [];
              ws[R][C] = cell;
            } else
              ws[encode_cell({ c: C, r: R })] = cell;
            start = end + 1;
            startcc = str.charCodeAt(start);
            if (range.e.c < C)
              range.e.c = C;
            if (range.e.r < R)
              range.e.r = R;
            if (cc == sepcc)
              ++C;
            else {
              C = 0;
              ++R;
              if (o.sheetRows && o.sheetRows <= R)
                return true;
            }
          }
          outer:
            for (; end < str.length; ++end)
              switch (cc = str.charCodeAt(end)) {
                case 34:
                  if (startcc === 34)
                    instr = !instr;
                  break;
                case sepcc:
                case 10:
                case 13:
                  if (!instr && finish_cell())
                    break outer;
                  break;
                default:
                  break;
              }
          if (end - start > 0)
            finish_cell();
          ws["!ref"] = encode_range(range);
          return ws;
        }
        function prn_to_sheet_str(str, opts) {
          if (!(opts && opts.PRN))
            return dsv_to_sheet_str(str, opts);
          if (opts.FS)
            return dsv_to_sheet_str(str, opts);
          if (str.slice(0, 4) == "sep=")
            return dsv_to_sheet_str(str, opts);
          if (str.indexOf("	") >= 0 || str.indexOf(",") >= 0 || str.indexOf(";") >= 0)
            return dsv_to_sheet_str(str, opts);
          return aoa_to_sheet(prn_to_aoa_str(str, opts), opts);
        }
        function prn_to_sheet(d, opts) {
          var str = "", bytes = opts.type == "string" ? [0, 0, 0, 0] : firstbyte(d, opts);
          switch (opts.type) {
            case "base64":
              str = Base64_decode(d);
              break;
            case "binary":
              str = d;
              break;
            case "buffer":
              if (opts.codepage == 65001)
                str = d.toString("utf8");
              else if (opts.codepage && typeof $cptable !== "undefined")
                str = $cptable.utils.decode(opts.codepage, d);
              else
                str = has_buf && Buffer.isBuffer(d) ? d.toString("binary") : a2s(d);
              break;
            case "array":
              str = cc2str(d);
              break;
            case "string":
              str = d;
              break;
            default:
              throw new Error("Unrecognized type " + opts.type);
          }
          if (bytes[0] == 239 && bytes[1] == 187 && bytes[2] == 191)
            str = utf8read(str.slice(3));
          else if (opts.type != "string" && opts.type != "buffer" && opts.codepage == 65001)
            str = utf8read(str);
          else if (opts.type == "binary" && typeof $cptable !== "undefined" && opts.codepage)
            str = $cptable.utils.decode(opts.codepage, $cptable.utils.encode(28591, str));
          if (str.slice(0, 19) == "socialcalc:version:")
            return ETH.to_sheet(opts.type == "string" ? str : utf8read(str), opts);
          return prn_to_sheet_str(str, opts);
        }
        function prn_to_workbook(d, opts) {
          return sheet_to_workbook(prn_to_sheet(d, opts), opts);
        }
        function sheet_to_prn(ws) {
          var o = [];
          var r = safe_decode_range(ws["!ref"]), cell;
          var dense = Array.isArray(ws);
          for (var R = r.s.r; R <= r.e.r; ++R) {
            var oo = [];
            for (var C = r.s.c; C <= r.e.c; ++C) {
              var coord = encode_cell({ r: R, c: C });
              cell = dense ? (ws[R] || [])[C] : ws[coord];
              if (!cell || cell.v == null) {
                oo.push("          ");
                continue;
              }
              var w = (cell.w || (format_cell(cell), cell.w) || "").slice(0, 10);
              while (w.length < 10)
                w += " ";
              oo.push(w + (C === 0 ? " " : ""));
            }
            o.push(oo.join(""));
          }
          return o.join("\n");
        }
        return {
          to_workbook: prn_to_workbook,
          to_sheet: prn_to_sheet,
          from_sheet: sheet_to_prn
        };
      }();
      function read_wb_ID(d, opts) {
        var o = opts || {}, OLD_WTF = !!o.WTF;
        o.WTF = true;
        try {
          var out = SYLK.to_workbook(d, o);
          o.WTF = OLD_WTF;
          return out;
        } catch (e) {
          o.WTF = OLD_WTF;
          if (!e.message.match(/SYLK bad record ID/) && OLD_WTF)
            throw e;
          return PRN.to_workbook(d, opts);
        }
      }
      var WK_ = function() {
        function lotushopper(data, cb, opts) {
          if (!data)
            return;
          prep_blob(data, data.l || 0);
          var Enum = opts.Enum || WK1Enum;
          while (data.l < data.length) {
            var RT = data.read_shift(2);
            var R = Enum[RT] || Enum[65535];
            var length = data.read_shift(2);
            var tgt = data.l + length;
            var d = R.f && R.f(data, length, opts);
            data.l = tgt;
            if (cb(d, R, RT))
              return;
          }
        }
        function lotus_to_workbook(d, opts) {
          switch (opts.type) {
            case "base64":
              return lotus_to_workbook_buf(s2a(Base64_decode(d)), opts);
            case "binary":
              return lotus_to_workbook_buf(s2a(d), opts);
            case "buffer":
            case "array":
              return lotus_to_workbook_buf(d, opts);
          }
          throw "Unsupported type " + opts.type;
        }
        function lotus_to_workbook_buf(d, opts) {
          if (!d)
            return d;
          var o = opts || {};
          if (DENSE != null && o.dense == null)
            o.dense = DENSE;
          var s = o.dense ? [] : {}, n = "Sheet1", next_n = "", sidx = 0;
          var sheets = {}, snames = [], realnames = [];
          var refguess = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
          var sheetRows = o.sheetRows || 0;
          if (d[2] == 0) {
            if (d[3] == 8 || d[3] == 9) {
              if (d.length >= 16 && d[14] == 5 && d[15] === 108)
                throw new Error("Unsupported Works 3 for Mac file");
            }
          }
          if (d[2] == 2) {
            o.Enum = WK1Enum;
            lotushopper(d, function(val, R, RT) {
              switch (RT) {
                case 0:
                  o.vers = val;
                  if (val >= 4096)
                    o.qpro = true;
                  break;
                case 6:
                  refguess = val;
                  break;
                case 204:
                  if (val)
                    next_n = val;
                  break;
                case 222:
                  next_n = val;
                  break;
                case 15:
                case 51:
                  if (!o.qpro)
                    val[1].v = val[1].v.slice(1);
                case 13:
                case 14:
                case 16:
                  if (RT == 14 && (val[2] & 112) == 112 && (val[2] & 15) > 1 && (val[2] & 15) < 15) {
                    val[1].z = o.dateNF || table_fmt[14];
                    if (o.cellDates) {
                      val[1].t = "d";
                      val[1].v = numdate(val[1].v);
                    }
                  }
                  if (o.qpro) {
                    if (val[3] > sidx) {
                      s["!ref"] = encode_range(refguess);
                      sheets[n] = s;
                      snames.push(n);
                      s = o.dense ? [] : {};
                      refguess = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
                      sidx = val[3];
                      n = next_n || "Sheet" + (sidx + 1);
                      next_n = "";
                    }
                  }
                  var tmpcell = o.dense ? (s[val[0].r] || [])[val[0].c] : s[encode_cell(val[0])];
                  if (tmpcell) {
                    tmpcell.t = val[1].t;
                    tmpcell.v = val[1].v;
                    if (val[1].z != null)
                      tmpcell.z = val[1].z;
                    if (val[1].f != null)
                      tmpcell.f = val[1].f;
                    break;
                  }
                  if (o.dense) {
                    if (!s[val[0].r])
                      s[val[0].r] = [];
                    s[val[0].r][val[0].c] = val[1];
                  } else
                    s[encode_cell(val[0])] = val[1];
                  break;
                default:
              }
            }, o);
          } else if (d[2] == 26 || d[2] == 14) {
            o.Enum = WK3Enum;
            if (d[2] == 14) {
              o.qpro = true;
              d.l = 0;
            }
            lotushopper(d, function(val, R, RT) {
              switch (RT) {
                case 204:
                  n = val;
                  break;
                case 22:
                  val[1].v = val[1].v.slice(1);
                case 23:
                case 24:
                case 25:
                case 37:
                case 39:
                case 40:
                  if (val[3] > sidx) {
                    s["!ref"] = encode_range(refguess);
                    sheets[n] = s;
                    snames.push(n);
                    s = o.dense ? [] : {};
                    refguess = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
                    sidx = val[3];
                    n = "Sheet" + (sidx + 1);
                  }
                  if (sheetRows > 0 && val[0].r >= sheetRows)
                    break;
                  if (o.dense) {
                    if (!s[val[0].r])
                      s[val[0].r] = [];
                    s[val[0].r][val[0].c] = val[1];
                  } else
                    s[encode_cell(val[0])] = val[1];
                  if (refguess.e.c < val[0].c)
                    refguess.e.c = val[0].c;
                  if (refguess.e.r < val[0].r)
                    refguess.e.r = val[0].r;
                  break;
                case 27:
                  if (val[14e3])
                    realnames[val[14e3][0]] = val[14e3][1];
                  break;
                case 1537:
                  realnames[val[0]] = val[1];
                  if (val[0] == sidx)
                    n = val[1];
                  break;
                default:
                  break;
              }
            }, o);
          } else
            throw new Error("Unrecognized LOTUS BOF " + d[2]);
          s["!ref"] = encode_range(refguess);
          sheets[next_n || n] = s;
          snames.push(next_n || n);
          if (!realnames.length)
            return { SheetNames: snames, Sheets: sheets };
          var osheets = {}, rnames = [];
          for (var i = 0; i < realnames.length; ++i)
            if (sheets[snames[i]]) {
              rnames.push(realnames[i] || snames[i]);
              osheets[realnames[i]] = sheets[realnames[i]] || sheets[snames[i]];
            } else {
              rnames.push(realnames[i]);
              osheets[realnames[i]] = { "!ref": "A1" };
            }
          return { SheetNames: rnames, Sheets: osheets };
        }
        function sheet_to_wk1(ws, opts) {
          var o = opts || {};
          if (+o.codepage >= 0)
            set_cp(+o.codepage);
          if (o.type == "string")
            throw new Error("Cannot write WK1 to JS string");
          var ba = buf_array();
          var range = safe_decode_range(ws["!ref"]);
          var dense = Array.isArray(ws);
          var cols = [];
          write_biff_rec(ba, 0, write_BOF_WK1(1030));
          write_biff_rec(ba, 6, write_RANGE(range));
          var max_R = Math.min(range.e.r, 8191);
          for (var R = range.s.r; R <= max_R; ++R) {
            var rr = encode_row(R);
            for (var C = range.s.c; C <= range.e.c; ++C) {
              if (R === range.s.r)
                cols[C] = encode_col(C);
              var ref = cols[C] + rr;
              var cell = dense ? (ws[R] || [])[C] : ws[ref];
              if (!cell || cell.t == "z")
                continue;
              if (cell.t == "n") {
                if ((cell.v | 0) == cell.v && cell.v >= -32768 && cell.v <= 32767)
                  write_biff_rec(ba, 13, write_INTEGER(R, C, cell.v));
                else
                  write_biff_rec(ba, 14, write_NUMBER(R, C, cell.v));
              } else {
                var str = format_cell(cell);
                write_biff_rec(ba, 15, write_LABEL(R, C, str.slice(0, 239)));
              }
            }
          }
          write_biff_rec(ba, 1);
          return ba.end();
        }
        function book_to_wk3(wb, opts) {
          var o = opts || {};
          if (+o.codepage >= 0)
            set_cp(+o.codepage);
          if (o.type == "string")
            throw new Error("Cannot write WK3 to JS string");
          var ba = buf_array();
          write_biff_rec(ba, 0, write_BOF_WK3(wb));
          for (var i = 0, cnt = 0; i < wb.SheetNames.length; ++i)
            if ((wb.Sheets[wb.SheetNames[i]] || {})["!ref"])
              write_biff_rec(ba, 27, write_XFORMAT_SHEETNAME(wb.SheetNames[i], cnt++));
          var wsidx = 0;
          for (i = 0; i < wb.SheetNames.length; ++i) {
            var ws = wb.Sheets[wb.SheetNames[i]];
            if (!ws || !ws["!ref"])
              continue;
            var range = safe_decode_range(ws["!ref"]);
            var dense = Array.isArray(ws);
            var cols = [];
            var max_R = Math.min(range.e.r, 8191);
            for (var R = range.s.r; R <= max_R; ++R) {
              var rr = encode_row(R);
              for (var C = range.s.c; C <= range.e.c; ++C) {
                if (R === range.s.r)
                  cols[C] = encode_col(C);
                var ref = cols[C] + rr;
                var cell = dense ? (ws[R] || [])[C] : ws[ref];
                if (!cell || cell.t == "z")
                  continue;
                if (cell.t == "n") {
                  write_biff_rec(ba, 23, write_NUMBER_17(R, C, wsidx, cell.v));
                } else {
                  var str = format_cell(cell);
                  write_biff_rec(ba, 22, write_LABEL_16(R, C, wsidx, str.slice(0, 239)));
                }
              }
            }
            ++wsidx;
          }
          write_biff_rec(ba, 1);
          return ba.end();
        }
        function write_BOF_WK1(v) {
          var out = new_buf(2);
          out.write_shift(2, v);
          return out;
        }
        function write_BOF_WK3(wb) {
          var out = new_buf(26);
          out.write_shift(2, 4096);
          out.write_shift(2, 4);
          out.write_shift(4, 0);
          var rows = 0, cols = 0, wscnt = 0;
          for (var i = 0; i < wb.SheetNames.length; ++i) {
            var name = wb.SheetNames[i];
            var ws = wb.Sheets[name];
            if (!ws || !ws["!ref"])
              continue;
            ++wscnt;
            var range = decode_range(ws["!ref"]);
            if (rows < range.e.r)
              rows = range.e.r;
            if (cols < range.e.c)
              cols = range.e.c;
          }
          if (rows > 8191)
            rows = 8191;
          out.write_shift(2, rows);
          out.write_shift(1, wscnt);
          out.write_shift(1, cols);
          out.write_shift(2, 0);
          out.write_shift(2, 0);
          out.write_shift(1, 1);
          out.write_shift(1, 2);
          out.write_shift(4, 0);
          out.write_shift(4, 0);
          return out;
        }
        function parse_RANGE(blob, length, opts) {
          var o = { s: { c: 0, r: 0 }, e: { c: 0, r: 0 } };
          if (length == 8 && opts.qpro) {
            o.s.c = blob.read_shift(1);
            blob.l++;
            o.s.r = blob.read_shift(2);
            o.e.c = blob.read_shift(1);
            blob.l++;
            o.e.r = blob.read_shift(2);
            return o;
          }
          o.s.c = blob.read_shift(2);
          o.s.r = blob.read_shift(2);
          if (length == 12 && opts.qpro)
            blob.l += 2;
          o.e.c = blob.read_shift(2);
          o.e.r = blob.read_shift(2);
          if (length == 12 && opts.qpro)
            blob.l += 2;
          if (o.s.c == 65535)
            o.s.c = o.e.c = o.s.r = o.e.r = 0;
          return o;
        }
        function write_RANGE(range) {
          var out = new_buf(8);
          out.write_shift(2, range.s.c);
          out.write_shift(2, range.s.r);
          out.write_shift(2, range.e.c);
          out.write_shift(2, range.e.r);
          return out;
        }
        function parse_cell(blob, length, opts) {
          var o = [{ c: 0, r: 0 }, { t: "n", v: 0 }, 0, 0];
          if (opts.qpro && opts.vers != 20768) {
            o[0].c = blob.read_shift(1);
            o[3] = blob.read_shift(1);
            o[0].r = blob.read_shift(2);
            blob.l += 2;
          } else {
            o[2] = blob.read_shift(1);
            o[0].c = blob.read_shift(2);
            o[0].r = blob.read_shift(2);
          }
          return o;
        }
        function parse_LABEL(blob, length, opts) {
          var tgt = blob.l + length;
          var o = parse_cell(blob, length, opts);
          o[1].t = "s";
          if (opts.vers == 20768) {
            blob.l++;
            var len = blob.read_shift(1);
            o[1].v = blob.read_shift(len, "utf8");
            return o;
          }
          if (opts.qpro)
            blob.l++;
          o[1].v = blob.read_shift(tgt - blob.l, "cstr");
          return o;
        }
        function write_LABEL(R, C, s) {
          var o = new_buf(7 + s.length);
          o.write_shift(1, 255);
          o.write_shift(2, C);
          o.write_shift(2, R);
          o.write_shift(1, 39);
          for (var i = 0; i < o.length; ++i) {
            var cc = s.charCodeAt(i);
            o.write_shift(1, cc >= 128 ? 95 : cc);
          }
          o.write_shift(1, 0);
          return o;
        }
        function parse_INTEGER(blob, length, opts) {
          var o = parse_cell(blob, length, opts);
          o[1].v = blob.read_shift(2, "i");
          return o;
        }
        function write_INTEGER(R, C, v) {
          var o = new_buf(7);
          o.write_shift(1, 255);
          o.write_shift(2, C);
          o.write_shift(2, R);
          o.write_shift(2, v, "i");
          return o;
        }
        function parse_NUMBER(blob, length, opts) {
          var o = parse_cell(blob, length, opts);
          o[1].v = blob.read_shift(8, "f");
          return o;
        }
        function write_NUMBER(R, C, v) {
          var o = new_buf(13);
          o.write_shift(1, 255);
          o.write_shift(2, C);
          o.write_shift(2, R);
          o.write_shift(8, v, "f");
          return o;
        }
        function parse_FORMULA(blob, length, opts) {
          var tgt = blob.l + length;
          var o = parse_cell(blob, length, opts);
          o[1].v = blob.read_shift(8, "f");
          if (opts.qpro)
            blob.l = tgt;
          else {
            var flen = blob.read_shift(2);
            wk1_fmla_to_csf(blob.slice(blob.l, blob.l + flen), o);
            blob.l += flen;
          }
          return o;
        }
        function wk1_parse_rc(B, V, col) {
          var rel = V & 32768;
          V &= ~32768;
          V = (rel ? B : 0) + (V >= 8192 ? V - 16384 : V);
          return (rel ? "" : "$") + (col ? encode_col(V) : encode_row(V));
        }
        var FuncTab = {
          51: ["FALSE", 0],
          52: ["TRUE", 0],
          70: ["LEN", 1],
          80: ["SUM", 69],
          81: ["AVERAGEA", 69],
          82: ["COUNTA", 69],
          83: ["MINA", 69],
          84: ["MAXA", 69],
          111: ["T", 1]
        };
        var BinOpTab = [
          "",
          "",
          "",
          "",
          "",
          "",
          "",
          "",
          // eslint-disable-line no-mixed-spaces-and-tabs
          "",
          "+",
          "-",
          "*",
          "/",
          "^",
          "=",
          "<>",
          // eslint-disable-line no-mixed-spaces-and-tabs
          "<=",
          ">=",
          "<",
          ">",
          "",
          "",
          "",
          "",
          // eslint-disable-line no-mixed-spaces-and-tabs
          "&",
          "",
          "",
          "",
          "",
          "",
          "",
          ""
          // eslint-disable-line no-mixed-spaces-and-tabs
        ];
        function wk1_fmla_to_csf(blob, o) {
          prep_blob(blob, 0);
          var out = [], argc = 0, R = "", C = "", argL = "", argR = "";
          while (blob.l < blob.length) {
            var cc = blob[blob.l++];
            switch (cc) {
              case 0:
                out.push(blob.read_shift(8, "f"));
                break;
              case 1:
                {
                  C = wk1_parse_rc(o[0].c, blob.read_shift(2), true);
                  R = wk1_parse_rc(o[0].r, blob.read_shift(2), false);
                  out.push(C + R);
                }
                break;
              case 2:
                {
                  var c = wk1_parse_rc(o[0].c, blob.read_shift(2), true);
                  var r = wk1_parse_rc(o[0].r, blob.read_shift(2), false);
                  C = wk1_parse_rc(o[0].c, blob.read_shift(2), true);
                  R = wk1_parse_rc(o[0].r, blob.read_shift(2), false);
                  out.push(c + r + ":" + C + R);
                }
                break;
              case 3:
                if (blob.l < blob.length) {
                  console.error("WK1 premature formula end");
                  return;
                }
                break;
              case 4:
                out.push("(" + out.pop() + ")");
                break;
              case 5:
                out.push(blob.read_shift(2));
                break;
              case 6:
                {
                  var Z = "";
                  while (cc = blob[blob.l++])
                    Z += String.fromCharCode(cc);
                  out.push('"' + Z.replace(/"/g, '""') + '"');
                }
                break;
              case 8:
                out.push("-" + out.pop());
                break;
              case 23:
                out.push("+" + out.pop());
                break;
              case 22:
                out.push("NOT(" + out.pop() + ")");
                break;
              case 20:
              case 21:
                {
                  argR = out.pop();
                  argL = out.pop();
                  out.push(["AND", "OR"][cc - 20] + "(" + argL + "," + argR + ")");
                }
                break;
              default:
                if (cc < 32 && BinOpTab[cc]) {
                  argR = out.pop();
                  argL = out.pop();
                  out.push(argL + BinOpTab[cc] + argR);
                } else if (FuncTab[cc]) {
                  argc = FuncTab[cc][1];
                  if (argc == 69)
                    argc = blob[blob.l++];
                  if (argc > out.length) {
                    console.error("WK1 bad formula parse 0x" + cc.toString(16) + ":|" + out.join("|") + "|");
                    return;
                  }
                  var args = out.slice(-argc);
                  out.length -= argc;
                  out.push(FuncTab[cc][0] + "(" + args.join(",") + ")");
                } else if (cc <= 7)
                  return console.error("WK1 invalid opcode " + cc.toString(16));
                else if (cc <= 24)
                  return console.error("WK1 unsupported op " + cc.toString(16));
                else if (cc <= 30)
                  return console.error("WK1 invalid opcode " + cc.toString(16));
                else if (cc <= 115)
                  return console.error("WK1 unsupported function opcode " + cc.toString(16));
                else
                  return console.error("WK1 unrecognized opcode " + cc.toString(16));
            }
          }
          if (out.length == 1)
            o[1].f = "" + out[0];
          else
            console.error("WK1 bad formula parse |" + out.join("|") + "|");
        }
        function parse_cell_3(blob) {
          var o = [{ c: 0, r: 0 }, { t: "n", v: 0 }, 0];
          o[0].r = blob.read_shift(2);
          o[3] = blob[blob.l++];
          o[0].c = blob[blob.l++];
          return o;
        }
        function parse_LABEL_16(blob, length) {
          var o = parse_cell_3(blob, length);
          o[1].t = "s";
          o[1].v = blob.read_shift(length - 4, "cstr");
          return o;
        }
        function write_LABEL_16(R, C, wsidx, s) {
          var o = new_buf(6 + s.length);
          o.write_shift(2, R);
          o.write_shift(1, wsidx);
          o.write_shift(1, C);
          o.write_shift(1, 39);
          for (var i = 0; i < s.length; ++i) {
            var cc = s.charCodeAt(i);
            o.write_shift(1, cc >= 128 ? 95 : cc);
          }
          o.write_shift(1, 0);
          return o;
        }
        function parse_NUMBER_18(blob, length) {
          var o = parse_cell_3(blob, length);
          o[1].v = blob.read_shift(2);
          var v = o[1].v >> 1;
          if (o[1].v & 1) {
            switch (v & 7) {
              case 0:
                v = (v >> 3) * 5e3;
                break;
              case 1:
                v = (v >> 3) * 500;
                break;
              case 2:
                v = (v >> 3) / 20;
                break;
              case 3:
                v = (v >> 3) / 200;
                break;
              case 4:
                v = (v >> 3) / 2e3;
                break;
              case 5:
                v = (v >> 3) / 2e4;
                break;
              case 6:
                v = (v >> 3) / 16;
                break;
              case 7:
                v = (v >> 3) / 64;
                break;
            }
          }
          o[1].v = v;
          return o;
        }
        function parse_NUMBER_17(blob, length) {
          var o = parse_cell_3(blob, length);
          var v1 = blob.read_shift(4);
          var v2 = blob.read_shift(4);
          var e = blob.read_shift(2);
          if (e == 65535) {
            if (v1 === 0 && v2 === 3221225472) {
              o[1].t = "e";
              o[1].v = 15;
            } else if (v1 === 0 && v2 === 3489660928) {
              o[1].t = "e";
              o[1].v = 42;
            } else
              o[1].v = 0;
            return o;
          }
          var s = e & 32768;
          e = (e & 32767) - 16446;
          o[1].v = (1 - s * 2) * (v2 * Math.pow(2, e + 32) + v1 * Math.pow(2, e));
          return o;
        }
        function write_NUMBER_17(R, C, wsidx, v) {
          var o = new_buf(14);
          o.write_shift(2, R);
          o.write_shift(1, wsidx);
          o.write_shift(1, C);
          if (v == 0) {
            o.write_shift(4, 0);
            o.write_shift(4, 0);
            o.write_shift(2, 65535);
            return o;
          }
          var s = 0, e = 0, v1 = 0, v2 = 0;
          if (v < 0) {
            s = 1;
            v = -v;
          }
          e = Math.log2(v) | 0;
          v /= Math.pow(2, e - 31);
          v2 = v >>> 0;
          if ((v2 & 2147483648) == 0) {
            v /= 2;
            ++e;
            v2 = v >>> 0;
          }
          v -= v2;
          v2 |= 2147483648;
          v2 >>>= 0;
          v *= Math.pow(2, 32);
          v1 = v >>> 0;
          o.write_shift(4, v1);
          o.write_shift(4, v2);
          e += 16383 + (s ? 32768 : 0);
          o.write_shift(2, e);
          return o;
        }
        function parse_FORMULA_19(blob, length) {
          var o = parse_NUMBER_17(blob, 14);
          blob.l += length - 14;
          return o;
        }
        function parse_NUMBER_25(blob, length) {
          var o = parse_cell_3(blob, length);
          var v1 = blob.read_shift(4);
          o[1].v = v1 >> 6;
          return o;
        }
        function parse_NUMBER_27(blob, length) {
          var o = parse_cell_3(blob, length);
          var v1 = blob.read_shift(8, "f");
          o[1].v = v1;
          return o;
        }
        function parse_FORMULA_28(blob, length) {
          var o = parse_NUMBER_27(blob, 14);
          blob.l += length - 10;
          return o;
        }
        function parse_SHEETNAMECS(blob, length) {
          return blob[blob.l + length - 1] == 0 ? blob.read_shift(length, "cstr") : "";
        }
        function parse_SHEETNAMELP(blob, length) {
          var len = blob[blob.l++];
          if (len > length - 1)
            len = length - 1;
          var o = "";
          while (o.length < len)
            o += String.fromCharCode(blob[blob.l++]);
          return o;
        }
        function parse_SHEETINFOQP(blob, length, opts) {
          if (!opts.qpro || length < 21)
            return;
          var id = blob.read_shift(1);
          blob.l += 17;
          blob.l += 1;
          blob.l += 2;
          var nm = blob.read_shift(length - 21, "cstr");
          return [id, nm];
        }
        function parse_XFORMAT(blob, length) {
          var o = {}, tgt = blob.l + length;
          while (blob.l < tgt) {
            var dt = blob.read_shift(2);
            if (dt == 14e3) {
              o[dt] = [0, ""];
              o[dt][0] = blob.read_shift(2);
              while (blob[blob.l]) {
                o[dt][1] += String.fromCharCode(blob[blob.l]);
                blob.l++;
              }
              blob.l++;
            }
          }
          return o;
        }
        function write_XFORMAT_SHEETNAME(name, wsidx) {
          var out = new_buf(5 + name.length);
          out.write_shift(2, 14e3);
          out.write_shift(2, wsidx);
          for (var i = 0; i < name.length; ++i) {
            var cc = name.charCodeAt(i);
            out[out.l++] = cc > 127 ? 95 : cc;
          }
          out[out.l++] = 0;
          return out;
        }
        var WK1Enum = {
          0: { n: "BOF", f: parseuint16 },
          1: { n: "EOF" },
          2: { n: "CALCMODE" },
          3: { n: "CALCORDER" },
          4: { n: "SPLIT" },
          5: { n: "SYNC" },
          6: { n: "RANGE", f: parse_RANGE },
          7: { n: "WINDOW1" },
          8: { n: "COLW1" },
          9: { n: "WINTWO" },
          10: { n: "COLW2" },
          11: { n: "NAME" },
          12: { n: "BLANK" },
          13: { n: "INTEGER", f: parse_INTEGER },
          14: { n: "NUMBER", f: parse_NUMBER },
          15: { n: "LABEL", f: parse_LABEL },
          16: { n: "FORMULA", f: parse_FORMULA },
          24: { n: "TABLE" },
          25: { n: "ORANGE" },
          26: { n: "PRANGE" },
          27: { n: "SRANGE" },
          28: { n: "FRANGE" },
          29: { n: "KRANGE1" },
          32: { n: "HRANGE" },
          35: { n: "KRANGE2" },
          36: { n: "PROTEC" },
          37: { n: "FOOTER" },
          38: { n: "HEADER" },
          39: { n: "SETUP" },
          40: { n: "MARGINS" },
          41: { n: "LABELFMT" },
          42: { n: "TITLES" },
          43: { n: "SHEETJS" },
          45: { n: "GRAPH" },
          46: { n: "NGRAPH" },
          47: { n: "CALCCOUNT" },
          48: { n: "UNFORMATTED" },
          49: { n: "CURSORW12" },
          50: { n: "WINDOW" },
          51: { n: "STRING", f: parse_LABEL },
          55: { n: "PASSWORD" },
          56: { n: "LOCKED" },
          60: { n: "QUERY" },
          61: { n: "QUERYNAME" },
          62: { n: "PRINT" },
          63: { n: "PRINTNAME" },
          64: { n: "GRAPH2" },
          65: { n: "GRAPHNAME" },
          66: { n: "ZOOM" },
          67: { n: "SYMSPLIT" },
          68: { n: "NSROWS" },
          69: { n: "NSCOLS" },
          70: { n: "RULER" },
          71: { n: "NNAME" },
          72: { n: "ACOMM" },
          73: { n: "AMACRO" },
          74: { n: "PARSE" },
          102: { n: "PRANGES??" },
          103: { n: "RRANGES??" },
          104: { n: "FNAME??" },
          105: { n: "MRANGES??" },
          204: { n: "SHEETNAMECS", f: parse_SHEETNAMECS },
          222: { n: "SHEETNAMELP", f: parse_SHEETNAMELP },
          65535: { n: "" }
        };
        var WK3Enum = {
          0: { n: "BOF" },
          1: { n: "EOF" },
          2: { n: "PASSWORD" },
          3: { n: "CALCSET" },
          4: { n: "WINDOWSET" },
          5: { n: "SHEETCELLPTR" },
          6: { n: "SHEETLAYOUT" },
          7: { n: "COLUMNWIDTH" },
          8: { n: "HIDDENCOLUMN" },
          9: { n: "USERRANGE" },
          10: { n: "SYSTEMRANGE" },
          11: { n: "ZEROFORCE" },
          12: { n: "SORTKEYDIR" },
          13: { n: "FILESEAL" },
          14: { n: "DATAFILLNUMS" },
          15: { n: "PRINTMAIN" },
          16: { n: "PRINTSTRING" },
          17: { n: "GRAPHMAIN" },
          18: { n: "GRAPHSTRING" },
          19: { n: "??" },
          20: { n: "ERRCELL" },
          21: { n: "NACELL" },
          22: { n: "LABEL16", f: parse_LABEL_16 },
          23: { n: "NUMBER17", f: parse_NUMBER_17 },
          24: { n: "NUMBER18", f: parse_NUMBER_18 },
          25: { n: "FORMULA19", f: parse_FORMULA_19 },
          26: { n: "FORMULA1A" },
          27: { n: "XFORMAT", f: parse_XFORMAT },
          28: { n: "DTLABELMISC" },
          29: { n: "DTLABELCELL" },
          30: { n: "GRAPHWINDOW" },
          31: { n: "CPA" },
          32: { n: "LPLAUTO" },
          33: { n: "QUERY" },
          34: { n: "HIDDENSHEET" },
          35: { n: "??" },
          37: { n: "NUMBER25", f: parse_NUMBER_25 },
          38: { n: "??" },
          39: { n: "NUMBER27", f: parse_NUMBER_27 },
          40: { n: "FORMULA28", f: parse_FORMULA_28 },
          142: { n: "??" },
          147: { n: "??" },
          150: { n: "??" },
          151: { n: "??" },
          152: { n: "??" },
          153: { n: "??" },
          154: { n: "??" },
          155: { n: "??" },
          156: { n: "??" },
          163: { n: "??" },
          174: { n: "??" },
          175: { n: "??" },
          176: { n: "??" },
          177: { n: "??" },
          184: { n: "??" },
          185: { n: "??" },
          186: { n: "??" },
          187: { n: "??" },
          188: { n: "??" },
          195: { n: "??" },
          201: { n: "??" },
          204: { n: "SHEETNAMECS", f: parse_SHEETNAMECS },
          205: { n: "??" },
          206: { n: "??" },
          207: { n: "??" },
          208: { n: "??" },
          256: { n: "??" },
          259: { n: "??" },
          260: { n: "??" },
          261: { n: "??" },
          262: { n: "??" },
          263: { n: "??" },
          265: { n: "??" },
          266: { n: "??" },
          267: { n: "??" },
          268: { n: "??" },
          270: { n: "??" },
          271: { n: "??" },
          384: { n: "??" },
          389: { n: "??" },
          390: { n: "??" },
          393: { n: "??" },
          396: { n: "??" },
          512: { n: "??" },
          514: { n: "??" },
          513: { n: "??" },
          516: { n: "??" },
          517: { n: "??" },
          640: { n: "??" },
          641: { n: "??" },
          642: { n: "??" },
          643: { n: "??" },
          644: { n: "??" },
          645: { n: "??" },
          646: { n: "??" },
          647: { n: "??" },
          648: { n: "??" },
          658: { n: "??" },
          659: { n: "??" },
          660: { n: "??" },
          661: { n: "??" },
          662: { n: "??" },
          665: { n: "??" },
          666: { n: "??" },
          768: { n: "??" },
          772: { n: "??" },
          1537: { n: "SHEETINFOQP", f: parse_SHEETINFOQP },
          1600: { n: "??" },
          1602: { n: "??" },
          1793: { n: "??" },
          1794: { n: "??" },
          1795: { n: "??" },
          1796: { n: "??" },
          1920: { n: "??" },
          2048: { n: "??" },
          2049: { n: "??" },
          2052: { n: "??" },
          2688: { n: "??" },
          10998: { n: "??" },
          12849: { n: "??" },
          28233: { n: "??" },
          28484: { n: "??" },
          65535: { n: "" }
        };
        return {
          sheet_to_wk1,
          book_to_wk3,
          to_workbook: lotus_to_workbook
        };
      }();
      function parse_rpr(rpr) {
        var font = {}, m = rpr.match(tagregex), i = 0;
        var pass = false;
        if (m)
          for (; i != m.length; ++i) {
            var y = parsexmltag(m[i]);
            switch (y[0].replace(/\w*:/g, "")) {
              case "<condense":
                break;
              case "<extend":
                break;
              case "<shadow":
                if (!y.val)
                  break;
              case "<shadow>":
              case "<shadow/>":
                font.shadow = 1;
                break;
              case "</shadow>":
                break;
              case "<charset":
                if (y.val == "1")
                  break;
                font.cp = CS2CP[parseInt(y.val, 10)];
                break;
              case "<outline":
                if (!y.val)
                  break;
              case "<outline>":
              case "<outline/>":
                font.outline = 1;
                break;
              case "</outline>":
                break;
              case "<rFont":
                font.name = y.val;
                break;
              case "<sz":
                font.sz = y.val;
                break;
              case "<strike":
                if (!y.val)
                  break;
              case "<strike>":
              case "<strike/>":
                font.strike = 1;
                break;
              case "</strike>":
                break;
              case "<u":
                if (!y.val)
                  break;
                switch (y.val) {
                  case "double":
                    font.uval = "double";
                    break;
                  case "singleAccounting":
                    font.uval = "single-accounting";
                    break;
                  case "doubleAccounting":
                    font.uval = "double-accounting";
                    break;
                }
              case "<u>":
              case "<u/>":
                font.u = 1;
                break;
              case "</u>":
                break;
              case "<b":
                if (y.val == "0")
                  break;
              case "<b>":
              case "<b/>":
                font.b = 1;
                break;
              case "</b>":
                break;
              case "<i":
                if (y.val == "0")
                  break;
              case "<i>":
              case "<i/>":
                font.i = 1;
                break;
              case "</i>":
                break;
              case "<color":
                if (y.rgb)
                  font.color = y.rgb.slice(2, 8);
                break;
              case "<color>":
              case "<color/>":
              case "</color>":
                break;
              case "<family":
                font.family = y.val;
                break;
              case "<family>":
              case "<family/>":
              case "</family>":
                break;
              case "<vertAlign":
                font.valign = y.val;
                break;
              case "<vertAlign>":
              case "<vertAlign/>":
              case "</vertAlign>":
                break;
              case "<scheme":
                break;
              case "<scheme>":
              case "<scheme/>":
              case "</scheme>":
                break;
              case "<extLst":
              case "<extLst>":
              case "</extLst>":
                break;
              case "<ext":
                pass = true;
                break;
              case "</ext>":
                pass = false;
                break;
              default:
                if (y[0].charCodeAt(1) !== 47 && !pass)
                  throw new Error("Unrecognized rich format " + y[0]);
            }
          }
        return font;
      }
      var parse_rs = function() {
        var tregex = matchtag("t"), rpregex = matchtag("rPr");
        function parse_r(r) {
          var t3 = r.match(tregex);
          if (!t3)
            return { t: "s", v: "" };
          var o = { t: "s", v: unescapexml(t3[1]) };
          var rpr = r.match(rpregex);
          if (rpr)
            o.s = parse_rpr(rpr[1]);
          return o;
        }
        var rregex = /<(?:\w+:)?r>/g, rend = /<\/(?:\w+:)?r>/;
        return function parse_rs2(rs) {
          return rs.replace(rregex, "").split(rend).map(parse_r).filter(function(r) {
            return r.v;
          });
        };
      }();
      var rs_to_html = function parse_rs_factory() {
        var nlregex = /(\r\n|\n)/g;
        function parse_rpr2(font, intro, outro) {
          var style = [];
          if (font.u)
            style.push("text-decoration: underline;");
          if (font.uval)
            style.push("text-underline-style:" + font.uval + ";");
          if (font.sz)
            style.push("font-size:" + font.sz + "pt;");
          if (font.outline)
            style.push("text-effect: outline;");
          if (font.shadow)
            style.push("text-shadow: auto;");
          intro.push('<span style="' + style.join("") + '">');
          if (font.b) {
            intro.push("<b>");
            outro.push("</b>");
          }
          if (font.i) {
            intro.push("<i>");
            outro.push("</i>");
          }
          if (font.strike) {
            intro.push("<s>");
            outro.push("</s>");
          }
          var align = font.valign || "";
          if (align == "superscript" || align == "super")
            align = "sup";
          else if (align == "subscript")
            align = "sub";
          if (align != "") {
            intro.push("<" + align + ">");
            outro.push("</" + align + ">");
          }
          outro.push("</span>");
          return font;
        }
        function r_to_html(r) {
          var terms = [[], r.v, []];
          if (!r.v)
            return "";
          if (r.s)
            parse_rpr2(r.s, terms[0], terms[2]);
          return terms[0].join("") + terms[1].replace(nlregex, "<br/>") + terms[2].join("");
        }
        return function parse_rs2(rs) {
          return rs.map(r_to_html).join("");
        };
      }();
      var sitregex = /<(?:\w+:)?t[^>]*>([^<]*)<\/(?:\w+:)?t>/g, sirregex = /<(?:\w+:)?r>/;
      var sirphregex = /<(?:\w+:)?rPh.*?>([\s\S]*?)<\/(?:\w+:)?rPh>/g;
      function parse_si(x, opts) {
        var html = opts ? opts.cellHTML : true;
        var z = {};
        if (!x)
          return { t: "" };
        if (x.match(/^\s*<(?:\w+:)?t[^>]*>/)) {
          z.t = unescapexml(utf8read(x.slice(x.indexOf(">") + 1).split(/<\/(?:\w+:)?t>/)[0] || ""));
          z.r = utf8read(x);
          if (html)
            z.h = escapehtml(z.t);
        } else if (
          /*y = */
          x.match(sirregex)
        ) {
          z.r = utf8read(x);
          z.t = unescapexml(utf8read((x.replace(sirphregex, "").match(sitregex) || []).join("").replace(tagregex, "")));
          if (html)
            z.h = rs_to_html(parse_rs(z.r));
        }
        return z;
      }
      var sstr0 = /<(?:\w+:)?sst([^>]*)>([\s\S]*)<\/(?:\w+:)?sst>/;
      var sstr1 = /<(?:\w+:)?(?:si|sstItem)>/g;
      var sstr2 = /<\/(?:\w+:)?(?:si|sstItem)>/;
      function parse_sst_xml(data, opts) {
        var s = [], ss = "";
        if (!data)
          return s;
        var sst = data.match(sstr0);
        if (sst) {
          ss = sst[2].replace(sstr1, "").split(sstr2);
          for (var i = 0; i != ss.length; ++i) {
            var o = parse_si(ss[i].trim(), opts);
            if (o != null)
              s[s.length] = o;
          }
          sst = parsexmltag(sst[1]);
          s.Count = sst.count;
          s.Unique = sst.uniqueCount;
        }
        return s;
      }
      var straywsregex = /^\s|\s$|[\t\n\r]/;
      function write_sst_xml(sst, opts) {
        if (!opts.bookSST)
          return "";
        var o = [XML_HEADER];
        o[o.length] = writextag("sst", null, {
          xmlns: XMLNS_main[0],
          count: sst.Count,
          uniqueCount: sst.Unique
        });
        for (var i = 0; i != sst.length; ++i) {
          if (sst[i] == null)
            continue;
          var s = sst[i];
          var sitag = "<si>";
          if (s.r)
            sitag += s.r;
          else {
            sitag += "<t";
            if (!s.t)
              s.t = "";
            if (s.t.match(straywsregex))
              sitag += ' xml:space="preserve"';
            sitag += ">" + escapexml(s.t) + "</t>";
          }
          sitag += "</si>";
          o[o.length] = sitag;
        }
        if (o.length > 2) {
          o[o.length] = "</sst>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_BrtBeginSst(data) {
        return [data.read_shift(4), data.read_shift(4)];
      }
      function parse_sst_bin(data, opts) {
        var s = [];
        var pass = false;
        recordhopper(data, function hopper_sst(val, R, RT) {
          switch (RT) {
            case 159:
              s.Count = val[0];
              s.Unique = val[1];
              break;
            case 19:
              s.push(val);
              break;
            case 160:
              return true;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            default:
              if (R.T) {
              }
              if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        });
        return s;
      }
      function write_BrtBeginSst(sst, o) {
        if (!o)
          o = new_buf(8);
        o.write_shift(4, sst.Count);
        o.write_shift(4, sst.Unique);
        return o;
      }
      var write_BrtSSTItem = write_RichStr;
      function write_sst_bin(sst) {
        var ba = buf_array();
        write_record(ba, 159, write_BrtBeginSst(sst));
        for (var i = 0; i < sst.length; ++i)
          write_record(ba, 19, write_BrtSSTItem(sst[i]));
        write_record(
          ba,
          160
          /* BrtEndSst */
        );
        return ba.end();
      }
      function _JS2ANSI(str) {
        if (typeof $cptable !== "undefined")
          return $cptable.utils.encode(current_ansi, str);
        var o = [], oo = str.split("");
        for (var i = 0; i < oo.length; ++i)
          o[i] = oo[i].charCodeAt(0);
        return o;
      }
      function parse_CRYPTOVersion(blob, length) {
        var o = {};
        o.Major = blob.read_shift(2);
        o.Minor = blob.read_shift(2);
        if (length >= 4)
          blob.l += length - 4;
        return o;
      }
      function parse_DataSpaceVersionInfo(blob) {
        var o = {};
        o.id = blob.read_shift(0, "lpp4");
        o.R = parse_CRYPTOVersion(blob, 4);
        o.U = parse_CRYPTOVersion(blob, 4);
        o.W = parse_CRYPTOVersion(blob, 4);
        return o;
      }
      function parse_DataSpaceMapEntry(blob) {
        var len = blob.read_shift(4);
        var end = blob.l + len - 4;
        var o = {};
        var cnt = blob.read_shift(4);
        var comps = [];
        while (cnt-- > 0)
          comps.push({ t: blob.read_shift(4), v: blob.read_shift(0, "lpp4") });
        o.name = blob.read_shift(0, "lpp4");
        o.comps = comps;
        if (blob.l != end)
          throw new Error("Bad DataSpaceMapEntry: " + blob.l + " != " + end);
        return o;
      }
      function parse_DataSpaceMap(blob) {
        var o = [];
        blob.l += 4;
        var cnt = blob.read_shift(4);
        while (cnt-- > 0)
          o.push(parse_DataSpaceMapEntry(blob));
        return o;
      }
      function parse_DataSpaceDefinition(blob) {
        var o = [];
        blob.l += 4;
        var cnt = blob.read_shift(4);
        while (cnt-- > 0)
          o.push(blob.read_shift(0, "lpp4"));
        return o;
      }
      function parse_TransformInfoHeader(blob) {
        var o = {};
        blob.read_shift(4);
        blob.l += 4;
        o.id = blob.read_shift(0, "lpp4");
        o.name = blob.read_shift(0, "lpp4");
        o.R = parse_CRYPTOVersion(blob, 4);
        o.U = parse_CRYPTOVersion(blob, 4);
        o.W = parse_CRYPTOVersion(blob, 4);
        return o;
      }
      function parse_Primary(blob) {
        var hdr = parse_TransformInfoHeader(blob);
        hdr.ename = blob.read_shift(0, "8lpp4");
        hdr.blksz = blob.read_shift(4);
        hdr.cmode = blob.read_shift(4);
        if (blob.read_shift(4) != 4)
          throw new Error("Bad !Primary record");
        return hdr;
      }
      function parse_EncryptionHeader(blob, length) {
        var tgt = blob.l + length;
        var o = {};
        o.Flags = blob.read_shift(4) & 63;
        blob.l += 4;
        o.AlgID = blob.read_shift(4);
        var valid = false;
        switch (o.AlgID) {
          case 26126:
          case 26127:
          case 26128:
            valid = o.Flags == 36;
            break;
          case 26625:
            valid = o.Flags == 4;
            break;
          case 0:
            valid = o.Flags == 16 || o.Flags == 4 || o.Flags == 36;
            break;
          default:
            throw "Unrecognized encryption algorithm: " + o.AlgID;
        }
        if (!valid)
          throw new Error("Encryption Flags/AlgID mismatch");
        o.AlgIDHash = blob.read_shift(4);
        o.KeySize = blob.read_shift(4);
        o.ProviderType = blob.read_shift(4);
        blob.l += 8;
        o.CSPName = blob.read_shift(tgt - blob.l >> 1, "utf16le");
        blob.l = tgt;
        return o;
      }
      function parse_EncryptionVerifier(blob, length) {
        var o = {}, tgt = blob.l + length;
        blob.l += 4;
        o.Salt = blob.slice(blob.l, blob.l + 16);
        blob.l += 16;
        o.Verifier = blob.slice(blob.l, blob.l + 16);
        blob.l += 16;
        blob.read_shift(4);
        o.VerifierHash = blob.slice(blob.l, tgt);
        blob.l = tgt;
        return o;
      }
      function parse_EncryptionInfo(blob) {
        var vers = parse_CRYPTOVersion(blob);
        switch (vers.Minor) {
          case 2:
            return [vers.Minor, parse_EncInfoStd(blob, vers)];
          case 3:
            return [vers.Minor, parse_EncInfoExt(blob, vers)];
          case 4:
            return [vers.Minor, parse_EncInfoAgl(blob, vers)];
        }
        throw new Error("ECMA-376 Encrypted file unrecognized Version: " + vers.Minor);
      }
      function parse_EncInfoStd(blob) {
        var flags = blob.read_shift(4);
        if ((flags & 63) != 36)
          throw new Error("EncryptionInfo mismatch");
        var sz = blob.read_shift(4);
        var hdr = parse_EncryptionHeader(blob, sz);
        var verifier = parse_EncryptionVerifier(blob, blob.length - blob.l);
        return { t: "Std", h: hdr, v: verifier };
      }
      function parse_EncInfoExt() {
        throw new Error("File is password-protected: ECMA-376 Extensible");
      }
      function parse_EncInfoAgl(blob) {
        var KeyData = ["saltSize", "blockSize", "keyBits", "hashSize", "cipherAlgorithm", "cipherChaining", "hashAlgorithm", "saltValue"];
        blob.l += 4;
        var xml = blob.read_shift(blob.length - blob.l, "utf8");
        var o = {};
        xml.replace(tagregex, function xml_agile(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<?xml":
              break;
            case "<encryption":
            case "</encryption>":
              break;
            case "<keyData":
              KeyData.forEach(function(k) {
                o[k] = y[k];
              });
              break;
            case "<dataIntegrity":
              o.encryptedHmacKey = y.encryptedHmacKey;
              o.encryptedHmacValue = y.encryptedHmacValue;
              break;
            case "<keyEncryptors>":
            case "<keyEncryptors":
              o.encs = [];
              break;
            case "</keyEncryptors>":
              break;
            case "<keyEncryptor":
              o.uri = y.uri;
              break;
            case "</keyEncryptor>":
              break;
            case "<encryptedKey":
              o.encs.push(y);
              break;
            default:
              throw y[0];
          }
        });
        return o;
      }
      function parse_RC4CryptoHeader(blob, length) {
        var o = {};
        var vers = o.EncryptionVersionInfo = parse_CRYPTOVersion(blob, 4);
        length -= 4;
        if (vers.Minor != 2)
          throw new Error("unrecognized minor version code: " + vers.Minor);
        if (vers.Major > 4 || vers.Major < 2)
          throw new Error("unrecognized major version code: " + vers.Major);
        o.Flags = blob.read_shift(4);
        length -= 4;
        var sz = blob.read_shift(4);
        length -= 4;
        o.EncryptionHeader = parse_EncryptionHeader(blob, sz);
        length -= sz;
        o.EncryptionVerifier = parse_EncryptionVerifier(blob, length);
        return o;
      }
      function parse_RC4Header(blob) {
        var o = {};
        var vers = o.EncryptionVersionInfo = parse_CRYPTOVersion(blob, 4);
        if (vers.Major != 1 || vers.Minor != 1)
          throw "unrecognized version code " + vers.Major + " : " + vers.Minor;
        o.Salt = blob.read_shift(16);
        o.EncryptedVerifier = blob.read_shift(16);
        o.EncryptedVerifierHash = blob.read_shift(16);
        return o;
      }
      function crypto_CreatePasswordVerifier_Method1(Password) {
        var Verifier = 0, PasswordArray;
        var PasswordDecoded = _JS2ANSI(Password);
        var len = PasswordDecoded.length + 1, i, PasswordByte;
        var Intermediate1, Intermediate2, Intermediate3;
        PasswordArray = new_raw_buf(len);
        PasswordArray[0] = PasswordDecoded.length;
        for (i = 1; i != len; ++i)
          PasswordArray[i] = PasswordDecoded[i - 1];
        for (i = len - 1; i >= 0; --i) {
          PasswordByte = PasswordArray[i];
          Intermediate1 = (Verifier & 16384) === 0 ? 0 : 1;
          Intermediate2 = Verifier << 1 & 32767;
          Intermediate3 = Intermediate1 | Intermediate2;
          Verifier = Intermediate3 ^ PasswordByte;
        }
        return Verifier ^ 52811;
      }
      var crypto_CreateXorArray_Method1 = function() {
        var PadArray = [187, 255, 255, 186, 255, 255, 185, 128, 0, 190, 15, 0, 191, 15, 0];
        var InitialCode = [57840, 7439, 52380, 33984, 4364, 3600, 61902, 12606, 6258, 57657, 54287, 34041, 10252, 43370, 20163];
        var XorMatrix = [44796, 19929, 39858, 10053, 20106, 40212, 10761, 31585, 63170, 64933, 60267, 50935, 40399, 11199, 17763, 35526, 1453, 2906, 5812, 11624, 23248, 885, 1770, 3540, 7080, 14160, 28320, 56640, 55369, 41139, 20807, 41614, 21821, 43642, 17621, 28485, 56970, 44341, 19019, 38038, 14605, 29210, 60195, 50791, 40175, 10751, 21502, 43004, 24537, 18387, 36774, 3949, 7898, 15796, 31592, 63184, 47201, 24803, 49606, 37805, 14203, 28406, 56812, 17824, 35648, 1697, 3394, 6788, 13576, 27152, 43601, 17539, 35078, 557, 1114, 2228, 4456, 30388, 60776, 51953, 34243, 7079, 14158, 28316, 14128, 28256, 56512, 43425, 17251, 34502, 7597, 13105, 26210, 52420, 35241, 883, 1766, 3532, 4129, 8258, 16516, 33032, 4657, 9314, 18628];
        var Ror = function(Byte) {
          return (Byte / 2 | Byte * 128) & 255;
        };
        var XorRor = function(byte1, byte2) {
          return Ror(byte1 ^ byte2);
        };
        var CreateXorKey_Method1 = function(Password) {
          var XorKey = InitialCode[Password.length - 1];
          var CurrentElement = 104;
          for (var i = Password.length - 1; i >= 0; --i) {
            var Char = Password[i];
            for (var j = 0; j != 7; ++j) {
              if (Char & 64)
                XorKey ^= XorMatrix[CurrentElement];
              Char *= 2;
              --CurrentElement;
            }
          }
          return XorKey;
        };
        return function(password) {
          var Password = _JS2ANSI(password);
          var XorKey = CreateXorKey_Method1(Password);
          var Index = Password.length;
          var ObfuscationArray = new_raw_buf(16);
          for (var i = 0; i != 16; ++i)
            ObfuscationArray[i] = 0;
          var Temp, PasswordLastChar, PadIndex;
          if ((Index & 1) === 1) {
            Temp = XorKey >> 8;
            ObfuscationArray[Index] = XorRor(PadArray[0], Temp);
            --Index;
            Temp = XorKey & 255;
            PasswordLastChar = Password[Password.length - 1];
            ObfuscationArray[Index] = XorRor(PasswordLastChar, Temp);
          }
          while (Index > 0) {
            --Index;
            Temp = XorKey >> 8;
            ObfuscationArray[Index] = XorRor(Password[Index], Temp);
            --Index;
            Temp = XorKey & 255;
            ObfuscationArray[Index] = XorRor(Password[Index], Temp);
          }
          Index = 15;
          PadIndex = 15 - Password.length;
          while (PadIndex > 0) {
            Temp = XorKey >> 8;
            ObfuscationArray[Index] = XorRor(PadArray[PadIndex], Temp);
            --Index;
            --PadIndex;
            Temp = XorKey & 255;
            ObfuscationArray[Index] = XorRor(Password[Index], Temp);
            --Index;
            --PadIndex;
          }
          return ObfuscationArray;
        };
      }();
      var crypto_DecryptData_Method1 = function(password, Data, XorArrayIndex, XorArray, O) {
        if (!O)
          O = Data;
        if (!XorArray)
          XorArray = crypto_CreateXorArray_Method1(password);
        var Index, Value;
        for (Index = 0; Index != Data.length; ++Index) {
          Value = Data[Index];
          Value ^= XorArray[XorArrayIndex];
          Value = (Value >> 5 | Value << 3) & 255;
          O[Index] = Value;
          ++XorArrayIndex;
        }
        return [O, XorArrayIndex, XorArray];
      };
      var crypto_MakeXorDecryptor = function(password) {
        var XorArrayIndex = 0, XorArray = crypto_CreateXorArray_Method1(password);
        return function(Data) {
          var O = crypto_DecryptData_Method1("", Data, XorArrayIndex, XorArray);
          XorArrayIndex = O[1];
          return O[0];
        };
      };
      function parse_XORObfuscation(blob, length, opts, out) {
        var o = { key: parseuint16(blob), verificationBytes: parseuint16(blob) };
        if (opts.password)
          o.verifier = crypto_CreatePasswordVerifier_Method1(opts.password);
        out.valid = o.verificationBytes === o.verifier;
        if (out.valid)
          out.insitu = crypto_MakeXorDecryptor(opts.password);
        return o;
      }
      function parse_FilePassHeader(blob, length, oo) {
        var o = oo || {};
        o.Info = blob.read_shift(2);
        blob.l -= 2;
        if (o.Info === 1)
          o.Data = parse_RC4Header(blob, length);
        else
          o.Data = parse_RC4CryptoHeader(blob, length);
        return o;
      }
      function parse_FilePass(blob, length, opts) {
        var o = { Type: opts.biff >= 8 ? blob.read_shift(2) : 0 };
        if (o.Type)
          parse_FilePassHeader(blob, length - 2, o);
        else
          parse_XORObfuscation(blob, opts.biff >= 8 ? length : length - 2, opts, o);
        return o;
      }
      var RTF = function() {
        function rtf_to_sheet(d, opts) {
          switch (opts.type) {
            case "base64":
              return rtf_to_sheet_str(Base64_decode(d), opts);
            case "binary":
              return rtf_to_sheet_str(d, opts);
            case "buffer":
              return rtf_to_sheet_str(has_buf && Buffer.isBuffer(d) ? d.toString("binary") : a2s(d), opts);
            case "array":
              return rtf_to_sheet_str(cc2str(d), opts);
          }
          throw new Error("Unrecognized type " + opts.type);
        }
        function rtf_to_sheet_str(str, opts) {
          var o = opts || {};
          var ws = o.dense ? [] : {};
          var rows = str.match(/\\trowd.*?\\row\b/g);
          if (!rows.length)
            throw new Error("RTF missing table");
          var range = { s: { c: 0, r: 0 }, e: { c: 0, r: rows.length - 1 } };
          rows.forEach(function(rowtf, R) {
            if (Array.isArray(ws))
              ws[R] = [];
            var rtfre = /\\\w+\b/g;
            var last_index = 0;
            var res;
            var C = -1;
            while (res = rtfre.exec(rowtf)) {
              switch (res[0]) {
                case "\\cell":
                  var data = rowtf.slice(last_index, rtfre.lastIndex - res[0].length);
                  if (data[0] == " ")
                    data = data.slice(1);
                  ++C;
                  if (data.length) {
                    var cell = { v: data, t: "s" };
                    if (Array.isArray(ws))
                      ws[R][C] = cell;
                    else
                      ws[encode_cell({ r: R, c: C })] = cell;
                  }
                  break;
              }
              last_index = rtfre.lastIndex;
            }
            if (C > range.e.c)
              range.e.c = C;
          });
          ws["!ref"] = encode_range(range);
          return ws;
        }
        function rtf_to_workbook(d, opts) {
          return sheet_to_workbook(rtf_to_sheet(d, opts), opts);
        }
        function sheet_to_rtf(ws) {
          var o = ["{\\rtf1\\ansi"];
          var r = safe_decode_range(ws["!ref"]), cell;
          var dense = Array.isArray(ws);
          for (var R = r.s.r; R <= r.e.r; ++R) {
            o.push("\\trowd\\trautofit1");
            for (var C = r.s.c; C <= r.e.c; ++C)
              o.push("\\cellx" + (C + 1));
            o.push("\\pard\\intbl");
            for (C = r.s.c; C <= r.e.c; ++C) {
              var coord = encode_cell({ r: R, c: C });
              cell = dense ? (ws[R] || [])[C] : ws[coord];
              if (!cell || cell.v == null && (!cell.f || cell.F))
                continue;
              o.push(" " + (cell.w || (format_cell(cell), cell.w)));
              o.push("\\cell");
            }
            o.push("\\pard\\intbl\\row");
          }
          return o.join("") + "}";
        }
        return {
          to_workbook: rtf_to_workbook,
          to_sheet: rtf_to_sheet,
          from_sheet: sheet_to_rtf
        };
      }();
      function hex2RGB(h) {
        var o = h.slice(h[0] === "#" ? 1 : 0).slice(0, 6);
        return [parseInt(o.slice(0, 2), 16), parseInt(o.slice(2, 4), 16), parseInt(o.slice(4, 6), 16)];
      }
      function rgb2Hex(rgb) {
        for (var i = 0, o = 1; i != 3; ++i)
          o = o * 256 + (rgb[i] > 255 ? 255 : rgb[i] < 0 ? 0 : rgb[i]);
        return o.toString(16).toUpperCase().slice(1);
      }
      function rgb2HSL(rgb) {
        var R = rgb[0] / 255, G = rgb[1] / 255, B = rgb[2] / 255;
        var M = Math.max(R, G, B), m = Math.min(R, G, B), C = M - m;
        if (C === 0)
          return [0, 0, R];
        var H6 = 0, S = 0, L2 = M + m;
        S = C / (L2 > 1 ? 2 - L2 : L2);
        switch (M) {
          case R:
            H6 = ((G - B) / C + 6) % 6;
            break;
          case G:
            H6 = (B - R) / C + 2;
            break;
          case B:
            H6 = (R - G) / C + 4;
            break;
        }
        return [H6 / 6, S, L2 / 2];
      }
      function hsl2RGB(hsl) {
        var H = hsl[0], S = hsl[1], L = hsl[2];
        var C = S * 2 * (L < 0.5 ? L : 1 - L), m = L - C / 2;
        var rgb = [m, m, m], h6 = 6 * H;
        var X;
        if (S !== 0)
          switch (h6 | 0) {
            case 0:
            case 6:
              X = C * h6;
              rgb[0] += C;
              rgb[1] += X;
              break;
            case 1:
              X = C * (2 - h6);
              rgb[0] += X;
              rgb[1] += C;
              break;
            case 2:
              X = C * (h6 - 2);
              rgb[1] += C;
              rgb[2] += X;
              break;
            case 3:
              X = C * (4 - h6);
              rgb[1] += X;
              rgb[2] += C;
              break;
            case 4:
              X = C * (h6 - 4);
              rgb[2] += C;
              rgb[0] += X;
              break;
            case 5:
              X = C * (6 - h6);
              rgb[2] += X;
              rgb[0] += C;
              break;
          }
        for (var i = 0; i != 3; ++i)
          rgb[i] = Math.round(rgb[i] * 255);
        return rgb;
      }
      function rgb_tint(hex, tint) {
        if (tint === 0)
          return hex;
        var hsl = rgb2HSL(hex2RGB(hex));
        if (tint < 0)
          hsl[2] = hsl[2] * (1 + tint);
        else
          hsl[2] = 1 - (1 - hsl[2]) * (1 - tint);
        return rgb2Hex(hsl2RGB(hsl));
      }
      var DEF_MDW = 6, MAX_MDW = 15, MIN_MDW = 1, MDW = DEF_MDW;
      function width2px(width) {
        return Math.floor((width + Math.round(128 / MDW) / 256) * MDW);
      }
      function px2char(px) {
        return Math.floor((px - 5) / MDW * 100 + 0.5) / 100;
      }
      function char2width(chr) {
        return Math.round((chr * MDW + 5) / MDW * 256) / 256;
      }
      function cycle_width(collw) {
        return char2width(px2char(width2px(collw)));
      }
      function find_mdw_colw(collw) {
        var delta = Math.abs(collw - cycle_width(collw)), _MDW = MDW;
        if (delta > 5e-3) {
          for (MDW = MIN_MDW; MDW < MAX_MDW; ++MDW)
            if (Math.abs(collw - cycle_width(collw)) <= delta) {
              delta = Math.abs(collw - cycle_width(collw));
              _MDW = MDW;
            }
        }
        MDW = _MDW;
      }
      function process_col(coll) {
        if (coll.width) {
          coll.wpx = width2px(coll.width);
          coll.wch = px2char(coll.wpx);
          coll.MDW = MDW;
        } else if (coll.wpx) {
          coll.wch = px2char(coll.wpx);
          coll.width = char2width(coll.wch);
          coll.MDW = MDW;
        } else if (typeof coll.wch == "number") {
          coll.width = char2width(coll.wch);
          coll.wpx = width2px(coll.width);
          coll.MDW = MDW;
        }
        if (coll.customWidth)
          delete coll.customWidth;
      }
      var DEF_PPI = 96, PPI = DEF_PPI;
      function px2pt(px) {
        return px * 96 / PPI;
      }
      function pt2px(pt) {
        return pt * PPI / 96;
      }
      var XLMLPatternTypeMap = {
        "None": "none",
        "Solid": "solid",
        "Gray50": "mediumGray",
        "Gray75": "darkGray",
        "Gray25": "lightGray",
        "HorzStripe": "darkHorizontal",
        "VertStripe": "darkVertical",
        "ReverseDiagStripe": "darkDown",
        "DiagStripe": "darkUp",
        "DiagCross": "darkGrid",
        "ThickDiagCross": "darkTrellis",
        "ThinHorzStripe": "lightHorizontal",
        "ThinVertStripe": "lightVertical",
        "ThinReverseDiagStripe": "lightDown",
        "ThinHorzCross": "lightGrid"
      };
      function parse_borders(t3, styles, themes, opts) {
        styles.Borders = [];
        var border = {};
        var pass = false;
        (t3[0].match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<borders":
            case "<borders>":
            case "</borders>":
              break;
            case "<border":
            case "<border>":
            case "<border/>":
              border = {};
              if (y.diagonalUp)
                border.diagonalUp = parsexmlbool(y.diagonalUp);
              if (y.diagonalDown)
                border.diagonalDown = parsexmlbool(y.diagonalDown);
              styles.Borders.push(border);
              break;
            case "</border>":
              break;
            case "<left/>":
              break;
            case "<left":
            case "<left>":
              break;
            case "</left>":
              break;
            case "<right/>":
              break;
            case "<right":
            case "<right>":
              break;
            case "</right>":
              break;
            case "<top/>":
              break;
            case "<top":
            case "<top>":
              break;
            case "</top>":
              break;
            case "<bottom/>":
              break;
            case "<bottom":
            case "<bottom>":
              break;
            case "</bottom>":
              break;
            case "<diagonal":
            case "<diagonal>":
            case "<diagonal/>":
              break;
            case "</diagonal>":
              break;
            case "<horizontal":
            case "<horizontal>":
            case "<horizontal/>":
              break;
            case "</horizontal>":
              break;
            case "<vertical":
            case "<vertical>":
            case "<vertical/>":
              break;
            case "</vertical>":
              break;
            case "<start":
            case "<start>":
            case "<start/>":
              break;
            case "</start>":
              break;
            case "<end":
            case "<end>":
            case "<end/>":
              break;
            case "</end>":
              break;
            case "<color":
            case "<color>":
              break;
            case "<color/>":
            case "</color>":
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (opts && opts.WTF) {
                if (!pass)
                  throw new Error("unrecognized " + y[0] + " in borders");
              }
          }
        });
      }
      function parse_fills(t3, styles, themes, opts) {
        styles.Fills = [];
        var fill2 = {};
        var pass = false;
        (t3[0].match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<fills":
            case "<fills>":
            case "</fills>":
              break;
            case "<fill>":
            case "<fill":
            case "<fill/>":
              fill2 = {};
              styles.Fills.push(fill2);
              break;
            case "</fill>":
              break;
            case "<gradientFill>":
              break;
            case "<gradientFill":
            case "</gradientFill>":
              styles.Fills.push(fill2);
              fill2 = {};
              break;
            case "<patternFill":
            case "<patternFill>":
              if (y.patternType)
                fill2.patternType = y.patternType;
              break;
            case "<patternFill/>":
            case "</patternFill>":
              break;
            case "<bgColor":
              if (!fill2.bgColor)
                fill2.bgColor = {};
              if (y.indexed)
                fill2.bgColor.indexed = parseInt(y.indexed, 10);
              if (y.theme)
                fill2.bgColor.theme = parseInt(y.theme, 10);
              if (y.tint)
                fill2.bgColor.tint = parseFloat(y.tint);
              if (y.rgb)
                fill2.bgColor.rgb = y.rgb.slice(-6);
              break;
            case "<bgColor/>":
            case "</bgColor>":
              break;
            case "<fgColor":
              if (!fill2.fgColor)
                fill2.fgColor = {};
              if (y.theme)
                fill2.fgColor.theme = parseInt(y.theme, 10);
              if (y.tint)
                fill2.fgColor.tint = parseFloat(y.tint);
              if (y.rgb != null)
                fill2.fgColor.rgb = y.rgb.slice(-6);
              break;
            case "<fgColor/>":
            case "</fgColor>":
              break;
            case "<stop":
            case "<stop/>":
              break;
            case "</stop>":
              break;
            case "<color":
            case "<color/>":
              break;
            case "</color>":
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (opts && opts.WTF) {
                if (!pass)
                  throw new Error("unrecognized " + y[0] + " in fills");
              }
          }
        });
      }
      function parse_fonts(t3, styles, themes, opts) {
        styles.Fonts = [];
        var font = {};
        var pass = false;
        (t3[0].match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<fonts":
            case "<fonts>":
            case "</fonts>":
              break;
            case "<font":
            case "<font>":
              break;
            case "</font>":
            case "<font/>":
              styles.Fonts.push(font);
              font = {};
              break;
            case "<name":
              if (y.val)
                font.name = utf8read(y.val);
              break;
            case "<name/>":
            case "</name>":
              break;
            case "<b":
              font.bold = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<b/>":
              font.bold = 1;
              break;
            case "<i":
              font.italic = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<i/>":
              font.italic = 1;
              break;
            case "<u":
              switch (y.val) {
                case "none":
                  font.underline = 0;
                  break;
                case "single":
                  font.underline = 1;
                  break;
                case "double":
                  font.underline = 2;
                  break;
                case "singleAccounting":
                  font.underline = 33;
                  break;
                case "doubleAccounting":
                  font.underline = 34;
                  break;
              }
              break;
            case "<u/>":
              font.underline = 1;
              break;
            case "<strike":
              font.strike = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<strike/>":
              font.strike = 1;
              break;
            case "<outline":
              font.outline = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<outline/>":
              font.outline = 1;
              break;
            case "<shadow":
              font.shadow = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<shadow/>":
              font.shadow = 1;
              break;
            case "<condense":
              font.condense = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<condense/>":
              font.condense = 1;
              break;
            case "<extend":
              font.extend = y.val ? parsexmlbool(y.val) : 1;
              break;
            case "<extend/>":
              font.extend = 1;
              break;
            case "<sz":
              if (y.val)
                font.sz = +y.val;
              break;
            case "<sz/>":
            case "</sz>":
              break;
            case "<vertAlign":
              if (y.val)
                font.vertAlign = y.val;
              break;
            case "<vertAlign/>":
            case "</vertAlign>":
              break;
            case "<family":
              if (y.val)
                font.family = parseInt(y.val, 10);
              break;
            case "<family/>":
            case "</family>":
              break;
            case "<scheme":
              if (y.val)
                font.scheme = y.val;
              break;
            case "<scheme/>":
            case "</scheme>":
              break;
            case "<charset":
              if (y.val == "1")
                break;
              y.codepage = CS2CP[parseInt(y.val, 10)];
              break;
            case "<color":
              if (!font.color)
                font.color = {};
              if (y.auto)
                font.color.auto = parsexmlbool(y.auto);
              if (y.rgb)
                font.color.rgb = y.rgb.slice(-6);
              else if (y.indexed) {
                font.color.index = parseInt(y.indexed, 10);
                var icv = XLSIcv[font.color.index];
                if (font.color.index == 81)
                  icv = XLSIcv[1];
                if (!icv)
                  icv = XLSIcv[1];
                font.color.rgb = icv[0].toString(16) + icv[1].toString(16) + icv[2].toString(16);
              } else if (y.theme) {
                font.color.theme = parseInt(y.theme, 10);
                if (y.tint)
                  font.color.tint = parseFloat(y.tint);
                if (y.theme && themes.themeElements && themes.themeElements.clrScheme) {
                  font.color.rgb = rgb_tint(themes.themeElements.clrScheme[font.color.theme].rgb, font.color.tint || 0);
                }
              }
              break;
            case "<color/>":
            case "</color>":
              break;
            case "<AlternateContent":
              pass = true;
              break;
            case "</AlternateContent>":
              pass = false;
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (opts && opts.WTF) {
                if (!pass)
                  throw new Error("unrecognized " + y[0] + " in fonts");
              }
          }
        });
      }
      function parse_numFmts(t3, styles, opts) {
        styles.NumberFmt = [];
        var k = keys3(table_fmt);
        for (var i = 0; i < k.length; ++i)
          styles.NumberFmt[k[i]] = table_fmt[k[i]];
        var m = t3[0].match(tagregex);
        if (!m)
          return;
        for (i = 0; i < m.length; ++i) {
          var y = parsexmltag(m[i]);
          switch (strip_ns(y[0])) {
            case "<numFmts":
            case "</numFmts>":
            case "<numFmts/>":
            case "<numFmts>":
              break;
            case "<numFmt":
              {
                var f = unescapexml(utf8read(y.formatCode)), j = parseInt(y.numFmtId, 10);
                styles.NumberFmt[j] = f;
                if (j > 0) {
                  if (j > 392) {
                    for (j = 392; j > 60; --j)
                      if (styles.NumberFmt[j] == null)
                        break;
                    styles.NumberFmt[j] = f;
                  }
                  SSF_load(f, j);
                }
              }
              break;
            case "</numFmt>":
              break;
            default:
              if (opts.WTF)
                throw new Error("unrecognized " + y[0] + " in numFmts");
          }
        }
      }
      function write_numFmts(NF) {
        var o = ["<numFmts>"];
        [[5, 8], [23, 26], [41, 44], [
          /*63*/
          50,
          /*66],[164,*/
          392
        ]].forEach(function(r) {
          for (var i = r[0]; i <= r[1]; ++i)
            if (NF[i] != null)
              o[o.length] = writextag("numFmt", null, { numFmtId: i, formatCode: escapexml(NF[i]) });
        });
        if (o.length === 1)
          return "";
        o[o.length] = "</numFmts>";
        o[0] = writextag("numFmts", null, { count: o.length - 2 }).replace("/>", ">");
        return o.join("");
      }
      var cellXF_uint = ["numFmtId", "fillId", "fontId", "borderId", "xfId"];
      var cellXF_bool = ["applyAlignment", "applyBorder", "applyFill", "applyFont", "applyNumberFormat", "applyProtection", "pivotButton", "quotePrefix"];
      function parse_cellXfs(t3, styles, opts) {
        styles.CellXf = [];
        var xf;
        var pass = false;
        (t3[0].match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x), i = 0;
          switch (strip_ns(y[0])) {
            case "<cellXfs":
            case "<cellXfs>":
            case "<cellXfs/>":
            case "</cellXfs>":
              break;
            case "<xf":
            case "<xf/>":
              xf = y;
              delete xf[0];
              for (i = 0; i < cellXF_uint.length; ++i)
                if (xf[cellXF_uint[i]])
                  xf[cellXF_uint[i]] = parseInt(xf[cellXF_uint[i]], 10);
              for (i = 0; i < cellXF_bool.length; ++i)
                if (xf[cellXF_bool[i]])
                  xf[cellXF_bool[i]] = parsexmlbool(xf[cellXF_bool[i]]);
              if (styles.NumberFmt && xf.numFmtId > 392) {
                for (i = 392; i > 60; --i)
                  if (styles.NumberFmt[xf.numFmtId] == styles.NumberFmt[i]) {
                    xf.numFmtId = i;
                    break;
                  }
              }
              styles.CellXf.push(xf);
              break;
            case "</xf>":
              break;
            case "<alignment":
            case "<alignment/>":
              var alignment = {};
              if (y.vertical)
                alignment.vertical = y.vertical;
              if (y.horizontal)
                alignment.horizontal = y.horizontal;
              if (y.textRotation != null)
                alignment.textRotation = y.textRotation;
              if (y.indent)
                alignment.indent = y.indent;
              if (y.wrapText)
                alignment.wrapText = parsexmlbool(y.wrapText);
              xf.alignment = alignment;
              break;
            case "</alignment>":
              break;
            case "<protection":
              break;
            case "</protection>":
            case "<protection/>":
              break;
            case "<AlternateContent":
              pass = true;
              break;
            case "</AlternateContent>":
              pass = false;
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (opts && opts.WTF) {
                if (!pass)
                  throw new Error("unrecognized " + y[0] + " in cellXfs");
              }
          }
        });
      }
      function write_cellXfs(cellXfs) {
        var o = [];
        o[o.length] = writextag("cellXfs", null);
        cellXfs.forEach(function(c) {
          o[o.length] = writextag("xf", null, c);
        });
        o[o.length] = "</cellXfs>";
        if (o.length === 2)
          return "";
        o[0] = writextag("cellXfs", null, { count: o.length - 2 }).replace("/>", ">");
        return o.join("");
      }
      var parse_sty_xml = function make_pstyx() {
        var numFmtRegex = /<(?:\w+:)?numFmts([^>]*)>[\S\s]*?<\/(?:\w+:)?numFmts>/;
        var cellXfRegex = /<(?:\w+:)?cellXfs([^>]*)>[\S\s]*?<\/(?:\w+:)?cellXfs>/;
        var fillsRegex = /<(?:\w+:)?fills([^>]*)>[\S\s]*?<\/(?:\w+:)?fills>/;
        var fontsRegex = /<(?:\w+:)?fonts([^>]*)>[\S\s]*?<\/(?:\w+:)?fonts>/;
        var bordersRegex = /<(?:\w+:)?borders([^>]*)>[\S\s]*?<\/(?:\w+:)?borders>/;
        return function parse_sty_xml2(data, themes, opts) {
          var styles = {};
          if (!data)
            return styles;
          data = data.replace(/<!--([\s\S]*?)-->/mg, "").replace(/<!DOCTYPE[^\[]*\[[^\]]*\]>/gm, "");
          var t3;
          if (t3 = data.match(numFmtRegex))
            parse_numFmts(t3, styles, opts);
          if (t3 = data.match(fontsRegex))
            parse_fonts(t3, styles, themes, opts);
          if (t3 = data.match(fillsRegex))
            parse_fills(t3, styles, themes, opts);
          if (t3 = data.match(bordersRegex))
            parse_borders(t3, styles, themes, opts);
          if (t3 = data.match(cellXfRegex))
            parse_cellXfs(t3, styles, opts);
          return styles;
        };
      }();
      function write_sty_xml(wb, opts) {
        var o = [XML_HEADER, writextag("styleSheet", null, {
          "xmlns": XMLNS_main[0],
          "xmlns:vt": XMLNS.vt
        })], w;
        if (wb.SSF && (w = write_numFmts(wb.SSF)) != null)
          o[o.length] = w;
        o[o.length] = '<fonts count="1"><font><sz val="12"/><color theme="1"/><name val="Calibri"/><family val="2"/><scheme val="minor"/></font></fonts>';
        o[o.length] = '<fills count="2"><fill><patternFill patternType="none"/></fill><fill><patternFill patternType="gray125"/></fill></fills>';
        o[o.length] = '<borders count="1"><border><left/><right/><top/><bottom/><diagonal/></border></borders>';
        o[o.length] = '<cellStyleXfs count="1"><xf numFmtId="0" fontId="0" fillId="0" borderId="0"/></cellStyleXfs>';
        if (w = write_cellXfs(opts.cellXfs))
          o[o.length] = w;
        o[o.length] = '<cellStyles count="1"><cellStyle name="Normal" xfId="0" builtinId="0"/></cellStyles>';
        o[o.length] = '<dxfs count="0"/>';
        o[o.length] = '<tableStyles count="0" defaultTableStyle="TableStyleMedium9" defaultPivotStyle="PivotStyleMedium4"/>';
        if (o.length > 2) {
          o[o.length] = "</styleSheet>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_BrtFmt(data, length) {
        var numFmtId = data.read_shift(2);
        var stFmtCode = parse_XLWideString(data, length - 2);
        return [numFmtId, stFmtCode];
      }
      function write_BrtFmt(i, f, o) {
        if (!o)
          o = new_buf(6 + 4 * f.length);
        o.write_shift(2, i);
        write_XLWideString(f, o);
        var out = o.length > o.l ? o.slice(0, o.l) : o;
        if (o.l == null)
          o.l = o.length;
        return out;
      }
      function parse_BrtFont(data, length, opts) {
        var out = {};
        out.sz = data.read_shift(2) / 20;
        var grbit = parse_FontFlags(data, 2, opts);
        if (grbit.fItalic)
          out.italic = 1;
        if (grbit.fCondense)
          out.condense = 1;
        if (grbit.fExtend)
          out.extend = 1;
        if (grbit.fShadow)
          out.shadow = 1;
        if (grbit.fOutline)
          out.outline = 1;
        if (grbit.fStrikeout)
          out.strike = 1;
        var bls = data.read_shift(2);
        if (bls === 700)
          out.bold = 1;
        switch (data.read_shift(2)) {
          case 1:
            out.vertAlign = "superscript";
            break;
          case 2:
            out.vertAlign = "subscript";
            break;
        }
        var underline = data.read_shift(1);
        if (underline != 0)
          out.underline = underline;
        var family = data.read_shift(1);
        if (family > 0)
          out.family = family;
        var bCharSet = data.read_shift(1);
        if (bCharSet > 0)
          out.charset = bCharSet;
        data.l++;
        out.color = parse_BrtColor(data, 8);
        switch (data.read_shift(1)) {
          case 1:
            out.scheme = "major";
            break;
          case 2:
            out.scheme = "minor";
            break;
        }
        out.name = parse_XLWideString(data, length - 21);
        return out;
      }
      function write_BrtFont(font, o) {
        if (!o)
          o = new_buf(25 + 4 * 32);
        o.write_shift(2, font.sz * 20);
        write_FontFlags(font, o);
        o.write_shift(2, font.bold ? 700 : 400);
        var sss = 0;
        if (font.vertAlign == "superscript")
          sss = 1;
        else if (font.vertAlign == "subscript")
          sss = 2;
        o.write_shift(2, sss);
        o.write_shift(1, font.underline || 0);
        o.write_shift(1, font.family || 0);
        o.write_shift(1, font.charset || 0);
        o.write_shift(1, 0);
        write_BrtColor(font.color, o);
        var scheme = 0;
        if (font.scheme == "major")
          scheme = 1;
        if (font.scheme == "minor")
          scheme = 2;
        o.write_shift(1, scheme);
        write_XLWideString(font.name, o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      var XLSBFillPTNames = [
        "none",
        "solid",
        "mediumGray",
        "darkGray",
        "lightGray",
        "darkHorizontal",
        "darkVertical",
        "darkDown",
        "darkUp",
        "darkGrid",
        "darkTrellis",
        "lightHorizontal",
        "lightVertical",
        "lightDown",
        "lightUp",
        "lightGrid",
        "lightTrellis",
        "gray125",
        "gray0625"
      ];
      var rev_XLSBFillPTNames;
      var parse_BrtFill = parsenoop;
      function write_BrtFill(fill2, o) {
        if (!o)
          o = new_buf(4 * 3 + 8 * 7 + 16 * 1);
        if (!rev_XLSBFillPTNames)
          rev_XLSBFillPTNames = evert(XLSBFillPTNames);
        var fls = rev_XLSBFillPTNames[fill2.patternType];
        if (fls == null)
          fls = 40;
        o.write_shift(4, fls);
        var j = 0;
        if (fls != 40) {
          write_BrtColor({ auto: 1 }, o);
          write_BrtColor({ auto: 1 }, o);
          for (; j < 12; ++j)
            o.write_shift(4, 0);
        } else {
          for (; j < 4; ++j)
            o.write_shift(4, 0);
          for (; j < 12; ++j)
            o.write_shift(4, 0);
        }
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function parse_BrtXF(data, length) {
        var tgt = data.l + length;
        var ixfeParent = data.read_shift(2);
        var ifmt = data.read_shift(2);
        data.l = tgt;
        return { ixfe: ixfeParent, numFmtId: ifmt };
      }
      function write_BrtXF(data, ixfeP, o) {
        if (!o)
          o = new_buf(16);
        o.write_shift(2, ixfeP || 0);
        o.write_shift(2, data.numFmtId || 0);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(1, 0);
        o.write_shift(1, 0);
        var flow = 0;
        o.write_shift(1, flow);
        o.write_shift(1, 0);
        o.write_shift(1, 0);
        o.write_shift(1, 0);
        return o;
      }
      function write_Blxf(data, o) {
        if (!o)
          o = new_buf(10);
        o.write_shift(1, 0);
        o.write_shift(1, 0);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        return o;
      }
      var parse_BrtBorder = parsenoop;
      function write_BrtBorder(border, o) {
        if (!o)
          o = new_buf(51);
        o.write_shift(1, 0);
        write_Blxf(null, o);
        write_Blxf(null, o);
        write_Blxf(null, o);
        write_Blxf(null, o);
        write_Blxf(null, o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function write_BrtStyle(style, o) {
        if (!o)
          o = new_buf(12 + 4 * 10);
        o.write_shift(4, style.xfId);
        o.write_shift(2, 1);
        o.write_shift(1, +style.builtinId);
        o.write_shift(1, 0);
        write_XLNullableWideString(style.name || "", o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function write_BrtBeginTableStyles(cnt, defTableStyle, defPivotStyle) {
        var o = new_buf(4 + 256 * 2 * 4);
        o.write_shift(4, cnt);
        write_XLNullableWideString(defTableStyle, o);
        write_XLNullableWideString(defPivotStyle, o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function parse_sty_bin(data, themes, opts) {
        var styles = {};
        styles.NumberFmt = [];
        for (var y in table_fmt)
          styles.NumberFmt[y] = table_fmt[y];
        styles.CellXf = [];
        styles.Fonts = [];
        var state = [];
        var pass = false;
        recordhopper(data, function hopper_sty(val, R, RT) {
          switch (RT) {
            case 44:
              styles.NumberFmt[val[0]] = val[1];
              SSF_load(val[1], val[0]);
              break;
            case 43:
              styles.Fonts.push(val);
              if (val.color.theme != null && themes && themes.themeElements && themes.themeElements.clrScheme) {
                val.color.rgb = rgb_tint(themes.themeElements.clrScheme[val.color.theme].rgb, val.color.tint || 0);
              }
              break;
            case 1025:
              break;
            case 45:
              break;
            case 46:
              break;
            case 47:
              if (state[state.length - 1] == 617) {
                styles.CellXf.push(val);
              }
              break;
            case 48:
            case 507:
            case 572:
            case 475:
              break;
            case 1171:
            case 2102:
            case 1130:
            case 512:
            case 2095:
            case 3072:
              break;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            case 37:
              state.push(RT);
              pass = true;
              break;
            case 38:
              state.pop();
              pass = false;
              break;
            default:
              if (R.T > 0)
                state.push(RT);
              else if (R.T < 0)
                state.pop();
              else if (!pass || opts.WTF && state[state.length - 1] != 37)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        });
        return styles;
      }
      function write_FMTS_bin(ba, NF) {
        if (!NF)
          return;
        var cnt = 0;
        [[5, 8], [23, 26], [41, 44], [
          /*63*/
          50,
          /*66],[164,*/
          392
        ]].forEach(function(r) {
          for (var i = r[0]; i <= r[1]; ++i)
            if (NF[i] != null)
              ++cnt;
        });
        if (cnt == 0)
          return;
        write_record(ba, 615, write_UInt32LE(cnt));
        [[5, 8], [23, 26], [41, 44], [
          /*63*/
          50,
          /*66],[164,*/
          392
        ]].forEach(function(r) {
          for (var i = r[0]; i <= r[1]; ++i)
            if (NF[i] != null)
              write_record(ba, 44, write_BrtFmt(i, NF[i]));
        });
        write_record(
          ba,
          616
          /* BrtEndFmts */
        );
      }
      function write_FONTS_bin(ba) {
        var cnt = 1;
        if (cnt == 0)
          return;
        write_record(ba, 611, write_UInt32LE(cnt));
        write_record(ba, 43, write_BrtFont({
          sz: 12,
          color: { theme: 1 },
          name: "Calibri",
          family: 2,
          scheme: "minor"
        }));
        write_record(
          ba,
          612
          /* BrtEndFonts */
        );
      }
      function write_FILLS_bin(ba) {
        var cnt = 2;
        if (cnt == 0)
          return;
        write_record(ba, 603, write_UInt32LE(cnt));
        write_record(ba, 45, write_BrtFill({ patternType: "none" }));
        write_record(ba, 45, write_BrtFill({ patternType: "gray125" }));
        write_record(
          ba,
          604
          /* BrtEndFills */
        );
      }
      function write_BORDERS_bin(ba) {
        var cnt = 1;
        if (cnt == 0)
          return;
        write_record(ba, 613, write_UInt32LE(cnt));
        write_record(ba, 46, write_BrtBorder({}));
        write_record(
          ba,
          614
          /* BrtEndBorders */
        );
      }
      function write_CELLSTYLEXFS_bin(ba) {
        var cnt = 1;
        write_record(ba, 626, write_UInt32LE(cnt));
        write_record(ba, 47, write_BrtXF({
          numFmtId: 0,
          fontId: 0,
          fillId: 0,
          borderId: 0
        }, 65535));
        write_record(
          ba,
          627
          /* BrtEndCellStyleXFs */
        );
      }
      function write_CELLXFS_bin(ba, data) {
        write_record(ba, 617, write_UInt32LE(data.length));
        data.forEach(function(c) {
          write_record(ba, 47, write_BrtXF(c, 0));
        });
        write_record(
          ba,
          618
          /* BrtEndCellXFs */
        );
      }
      function write_STYLES_bin(ba) {
        var cnt = 1;
        write_record(ba, 619, write_UInt32LE(cnt));
        write_record(ba, 48, write_BrtStyle({
          xfId: 0,
          builtinId: 0,
          name: "Normal"
        }));
        write_record(
          ba,
          620
          /* BrtEndStyles */
        );
      }
      function write_DXFS_bin(ba) {
        var cnt = 0;
        write_record(ba, 505, write_UInt32LE(cnt));
        write_record(
          ba,
          506
          /* BrtEndDXFs */
        );
      }
      function write_TABLESTYLES_bin(ba) {
        var cnt = 0;
        write_record(ba, 508, write_BrtBeginTableStyles(cnt, "TableStyleMedium9", "PivotStyleMedium4"));
        write_record(
          ba,
          509
          /* BrtEndTableStyles */
        );
      }
      function write_COLORPALETTE_bin() {
        return;
      }
      function write_sty_bin(wb, opts) {
        var ba = buf_array();
        write_record(
          ba,
          278
          /* BrtBeginStyleSheet */
        );
        write_FMTS_bin(ba, wb.SSF);
        write_FONTS_bin(ba, wb);
        write_FILLS_bin(ba, wb);
        write_BORDERS_bin(ba, wb);
        write_CELLSTYLEXFS_bin(ba, wb);
        write_CELLXFS_bin(ba, opts.cellXfs);
        write_STYLES_bin(ba, wb);
        write_DXFS_bin(ba, wb);
        write_TABLESTYLES_bin(ba, wb);
        write_COLORPALETTE_bin(ba, wb);
        write_record(
          ba,
          279
          /* BrtEndStyleSheet */
        );
        return ba.end();
      }
      var XLSXThemeClrScheme = [
        "</a:lt1>",
        "</a:dk1>",
        "</a:lt2>",
        "</a:dk2>",
        "</a:accent1>",
        "</a:accent2>",
        "</a:accent3>",
        "</a:accent4>",
        "</a:accent5>",
        "</a:accent6>",
        "</a:hlink>",
        "</a:folHlink>"
      ];
      function parse_clrScheme(t3, themes, opts) {
        themes.themeElements.clrScheme = [];
        var color = {};
        (t3[0].match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (y[0]) {
            case "<a:clrScheme":
            case "</a:clrScheme>":
              break;
            case "<a:srgbClr":
              color.rgb = y.val;
              break;
            case "<a:sysClr":
              color.rgb = y.lastClr;
              break;
            case "<a:dk1>":
            case "</a:dk1>":
            case "<a:lt1>":
            case "</a:lt1>":
            case "<a:dk2>":
            case "</a:dk2>":
            case "<a:lt2>":
            case "</a:lt2>":
            case "<a:accent1>":
            case "</a:accent1>":
            case "<a:accent2>":
            case "</a:accent2>":
            case "<a:accent3>":
            case "</a:accent3>":
            case "<a:accent4>":
            case "</a:accent4>":
            case "<a:accent5>":
            case "</a:accent5>":
            case "<a:accent6>":
            case "</a:accent6>":
            case "<a:hlink>":
            case "</a:hlink>":
            case "<a:folHlink>":
            case "</a:folHlink>":
              if (y[0].charAt(1) === "/") {
                themes.themeElements.clrScheme[XLSXThemeClrScheme.indexOf(y[0])] = color;
                color = {};
              } else {
                color.name = y[0].slice(3, y[0].length - 1);
              }
              break;
            default:
              if (opts && opts.WTF)
                throw new Error("Unrecognized " + y[0] + " in clrScheme");
          }
        });
      }
      function parse_fontScheme() {
      }
      function parse_fmtScheme() {
      }
      var clrsregex = /<a:clrScheme([^>]*)>[\s\S]*<\/a:clrScheme>/;
      var fntsregex = /<a:fontScheme([^>]*)>[\s\S]*<\/a:fontScheme>/;
      var fmtsregex = /<a:fmtScheme([^>]*)>[\s\S]*<\/a:fmtScheme>/;
      function parse_themeElements(data, themes, opts) {
        themes.themeElements = {};
        var t3;
        [
          /* clrScheme CT_ColorScheme */
          ["clrScheme", clrsregex, parse_clrScheme],
          /* fontScheme CT_FontScheme */
          ["fontScheme", fntsregex, parse_fontScheme],
          /* fmtScheme CT_StyleMatrix */
          ["fmtScheme", fmtsregex, parse_fmtScheme]
        ].forEach(function(m) {
          if (!(t3 = data.match(m[1])))
            throw new Error(m[0] + " not found in themeElements");
          m[2](t3, themes, opts);
        });
      }
      var themeltregex = /<a:themeElements([^>]*)>[\s\S]*<\/a:themeElements>/;
      function parse_theme_xml(data, opts) {
        if (!data || data.length === 0)
          data = write_theme();
        var t3;
        var themes = {};
        if (!(t3 = data.match(themeltregex)))
          throw new Error("themeElements not found in theme");
        parse_themeElements(t3[0], themes, opts);
        themes.raw = data;
        return themes;
      }
      function write_theme(Themes, opts) {
        if (opts && opts.themeXLSX)
          return opts.themeXLSX;
        if (Themes && typeof Themes.raw == "string")
          return Themes.raw;
        var o = [XML_HEADER];
        o[o.length] = '<a:theme xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" name="Office Theme">';
        o[o.length] = "<a:themeElements>";
        o[o.length] = '<a:clrScheme name="Office">';
        o[o.length] = '<a:dk1><a:sysClr val="windowText" lastClr="000000"/></a:dk1>';
        o[o.length] = '<a:lt1><a:sysClr val="window" lastClr="FFFFFF"/></a:lt1>';
        o[o.length] = '<a:dk2><a:srgbClr val="1F497D"/></a:dk2>';
        o[o.length] = '<a:lt2><a:srgbClr val="EEECE1"/></a:lt2>';
        o[o.length] = '<a:accent1><a:srgbClr val="4F81BD"/></a:accent1>';
        o[o.length] = '<a:accent2><a:srgbClr val="C0504D"/></a:accent2>';
        o[o.length] = '<a:accent3><a:srgbClr val="9BBB59"/></a:accent3>';
        o[o.length] = '<a:accent4><a:srgbClr val="8064A2"/></a:accent4>';
        o[o.length] = '<a:accent5><a:srgbClr val="4BACC6"/></a:accent5>';
        o[o.length] = '<a:accent6><a:srgbClr val="F79646"/></a:accent6>';
        o[o.length] = '<a:hlink><a:srgbClr val="0000FF"/></a:hlink>';
        o[o.length] = '<a:folHlink><a:srgbClr val="800080"/></a:folHlink>';
        o[o.length] = "</a:clrScheme>";
        o[o.length] = '<a:fontScheme name="Office">';
        o[o.length] = "<a:majorFont>";
        o[o.length] = '<a:latin typeface="Cambria"/>';
        o[o.length] = '<a:ea typeface=""/>';
        o[o.length] = '<a:cs typeface=""/>';
        o[o.length] = '<a:font script="Jpan" typeface="\uFF2D\uFF33 \uFF30\u30B4\u30B7\u30C3\u30AF"/>';
        o[o.length] = '<a:font script="Hang" typeface="\uB9D1\uC740 \uACE0\uB515"/>';
        o[o.length] = '<a:font script="Hans" typeface="\u5B8B\u4F53"/>';
        o[o.length] = '<a:font script="Hant" typeface="\u65B0\u7D30\u660E\u9AD4"/>';
        o[o.length] = '<a:font script="Arab" typeface="Times New Roman"/>';
        o[o.length] = '<a:font script="Hebr" typeface="Times New Roman"/>';
        o[o.length] = '<a:font script="Thai" typeface="Tahoma"/>';
        o[o.length] = '<a:font script="Ethi" typeface="Nyala"/>';
        o[o.length] = '<a:font script="Beng" typeface="Vrinda"/>';
        o[o.length] = '<a:font script="Gujr" typeface="Shruti"/>';
        o[o.length] = '<a:font script="Khmr" typeface="MoolBoran"/>';
        o[o.length] = '<a:font script="Knda" typeface="Tunga"/>';
        o[o.length] = '<a:font script="Guru" typeface="Raavi"/>';
        o[o.length] = '<a:font script="Cans" typeface="Euphemia"/>';
        o[o.length] = '<a:font script="Cher" typeface="Plantagenet Cherokee"/>';
        o[o.length] = '<a:font script="Yiii" typeface="Microsoft Yi Baiti"/>';
        o[o.length] = '<a:font script="Tibt" typeface="Microsoft Himalaya"/>';
        o[o.length] = '<a:font script="Thaa" typeface="MV Boli"/>';
        o[o.length] = '<a:font script="Deva" typeface="Mangal"/>';
        o[o.length] = '<a:font script="Telu" typeface="Gautami"/>';
        o[o.length] = '<a:font script="Taml" typeface="Latha"/>';
        o[o.length] = '<a:font script="Syrc" typeface="Estrangelo Edessa"/>';
        o[o.length] = '<a:font script="Orya" typeface="Kalinga"/>';
        o[o.length] = '<a:font script="Mlym" typeface="Kartika"/>';
        o[o.length] = '<a:font script="Laoo" typeface="DokChampa"/>';
        o[o.length] = '<a:font script="Sinh" typeface="Iskoola Pota"/>';
        o[o.length] = '<a:font script="Mong" typeface="Mongolian Baiti"/>';
        o[o.length] = '<a:font script="Viet" typeface="Times New Roman"/>';
        o[o.length] = '<a:font script="Uigh" typeface="Microsoft Uighur"/>';
        o[o.length] = '<a:font script="Geor" typeface="Sylfaen"/>';
        o[o.length] = "</a:majorFont>";
        o[o.length] = "<a:minorFont>";
        o[o.length] = '<a:latin typeface="Calibri"/>';
        o[o.length] = '<a:ea typeface=""/>';
        o[o.length] = '<a:cs typeface=""/>';
        o[o.length] = '<a:font script="Jpan" typeface="\uFF2D\uFF33 \uFF30\u30B4\u30B7\u30C3\u30AF"/>';
        o[o.length] = '<a:font script="Hang" typeface="\uB9D1\uC740 \uACE0\uB515"/>';
        o[o.length] = '<a:font script="Hans" typeface="\u5B8B\u4F53"/>';
        o[o.length] = '<a:font script="Hant" typeface="\u65B0\u7D30\u660E\u9AD4"/>';
        o[o.length] = '<a:font script="Arab" typeface="Arial"/>';
        o[o.length] = '<a:font script="Hebr" typeface="Arial"/>';
        o[o.length] = '<a:font script="Thai" typeface="Tahoma"/>';
        o[o.length] = '<a:font script="Ethi" typeface="Nyala"/>';
        o[o.length] = '<a:font script="Beng" typeface="Vrinda"/>';
        o[o.length] = '<a:font script="Gujr" typeface="Shruti"/>';
        o[o.length] = '<a:font script="Khmr" typeface="DaunPenh"/>';
        o[o.length] = '<a:font script="Knda" typeface="Tunga"/>';
        o[o.length] = '<a:font script="Guru" typeface="Raavi"/>';
        o[o.length] = '<a:font script="Cans" typeface="Euphemia"/>';
        o[o.length] = '<a:font script="Cher" typeface="Plantagenet Cherokee"/>';
        o[o.length] = '<a:font script="Yiii" typeface="Microsoft Yi Baiti"/>';
        o[o.length] = '<a:font script="Tibt" typeface="Microsoft Himalaya"/>';
        o[o.length] = '<a:font script="Thaa" typeface="MV Boli"/>';
        o[o.length] = '<a:font script="Deva" typeface="Mangal"/>';
        o[o.length] = '<a:font script="Telu" typeface="Gautami"/>';
        o[o.length] = '<a:font script="Taml" typeface="Latha"/>';
        o[o.length] = '<a:font script="Syrc" typeface="Estrangelo Edessa"/>';
        o[o.length] = '<a:font script="Orya" typeface="Kalinga"/>';
        o[o.length] = '<a:font script="Mlym" typeface="Kartika"/>';
        o[o.length] = '<a:font script="Laoo" typeface="DokChampa"/>';
        o[o.length] = '<a:font script="Sinh" typeface="Iskoola Pota"/>';
        o[o.length] = '<a:font script="Mong" typeface="Mongolian Baiti"/>';
        o[o.length] = '<a:font script="Viet" typeface="Arial"/>';
        o[o.length] = '<a:font script="Uigh" typeface="Microsoft Uighur"/>';
        o[o.length] = '<a:font script="Geor" typeface="Sylfaen"/>';
        o[o.length] = "</a:minorFont>";
        o[o.length] = "</a:fontScheme>";
        o[o.length] = '<a:fmtScheme name="Office">';
        o[o.length] = "<a:fillStyleLst>";
        o[o.length] = '<a:solidFill><a:schemeClr val="phClr"/></a:solidFill>';
        o[o.length] = '<a:gradFill rotWithShape="1">';
        o[o.length] = "<a:gsLst>";
        o[o.length] = '<a:gs pos="0"><a:schemeClr val="phClr"><a:tint val="50000"/><a:satMod val="300000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="35000"><a:schemeClr val="phClr"><a:tint val="37000"/><a:satMod val="300000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="100000"><a:schemeClr val="phClr"><a:tint val="15000"/><a:satMod val="350000"/></a:schemeClr></a:gs>';
        o[o.length] = "</a:gsLst>";
        o[o.length] = '<a:lin ang="16200000" scaled="1"/>';
        o[o.length] = "</a:gradFill>";
        o[o.length] = '<a:gradFill rotWithShape="1">';
        o[o.length] = "<a:gsLst>";
        o[o.length] = '<a:gs pos="0"><a:schemeClr val="phClr"><a:tint val="100000"/><a:shade val="100000"/><a:satMod val="130000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="100000"><a:schemeClr val="phClr"><a:tint val="50000"/><a:shade val="100000"/><a:satMod val="350000"/></a:schemeClr></a:gs>';
        o[o.length] = "</a:gsLst>";
        o[o.length] = '<a:lin ang="16200000" scaled="0"/>';
        o[o.length] = "</a:gradFill>";
        o[o.length] = "</a:fillStyleLst>";
        o[o.length] = "<a:lnStyleLst>";
        o[o.length] = '<a:ln w="9525" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"><a:shade val="95000"/><a:satMod val="105000"/></a:schemeClr></a:solidFill><a:prstDash val="solid"/></a:ln>';
        o[o.length] = '<a:ln w="25400" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:prstDash val="solid"/></a:ln>';
        o[o.length] = '<a:ln w="38100" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:prstDash val="solid"/></a:ln>';
        o[o.length] = "</a:lnStyleLst>";
        o[o.length] = "<a:effectStyleLst>";
        o[o.length] = "<a:effectStyle>";
        o[o.length] = "<a:effectLst>";
        o[o.length] = '<a:outerShdw blurRad="40000" dist="20000" dir="5400000" rotWithShape="0"><a:srgbClr val="000000"><a:alpha val="38000"/></a:srgbClr></a:outerShdw>';
        o[o.length] = "</a:effectLst>";
        o[o.length] = "</a:effectStyle>";
        o[o.length] = "<a:effectStyle>";
        o[o.length] = "<a:effectLst>";
        o[o.length] = '<a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0"><a:srgbClr val="000000"><a:alpha val="35000"/></a:srgbClr></a:outerShdw>';
        o[o.length] = "</a:effectLst>";
        o[o.length] = "</a:effectStyle>";
        o[o.length] = "<a:effectStyle>";
        o[o.length] = "<a:effectLst>";
        o[o.length] = '<a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0"><a:srgbClr val="000000"><a:alpha val="35000"/></a:srgbClr></a:outerShdw>';
        o[o.length] = "</a:effectLst>";
        o[o.length] = '<a:scene3d><a:camera prst="orthographicFront"><a:rot lat="0" lon="0" rev="0"/></a:camera><a:lightRig rig="threePt" dir="t"><a:rot lat="0" lon="0" rev="1200000"/></a:lightRig></a:scene3d>';
        o[o.length] = '<a:sp3d><a:bevelT w="63500" h="25400"/></a:sp3d>';
        o[o.length] = "</a:effectStyle>";
        o[o.length] = "</a:effectStyleLst>";
        o[o.length] = "<a:bgFillStyleLst>";
        o[o.length] = '<a:solidFill><a:schemeClr val="phClr"/></a:solidFill>';
        o[o.length] = '<a:gradFill rotWithShape="1">';
        o[o.length] = "<a:gsLst>";
        o[o.length] = '<a:gs pos="0"><a:schemeClr val="phClr"><a:tint val="40000"/><a:satMod val="350000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="40000"><a:schemeClr val="phClr"><a:tint val="45000"/><a:shade val="99000"/><a:satMod val="350000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="100000"><a:schemeClr val="phClr"><a:shade val="20000"/><a:satMod val="255000"/></a:schemeClr></a:gs>';
        o[o.length] = "</a:gsLst>";
        o[o.length] = '<a:path path="circle"><a:fillToRect l="50000" t="-80000" r="50000" b="180000"/></a:path>';
        o[o.length] = "</a:gradFill>";
        o[o.length] = '<a:gradFill rotWithShape="1">';
        o[o.length] = "<a:gsLst>";
        o[o.length] = '<a:gs pos="0"><a:schemeClr val="phClr"><a:tint val="80000"/><a:satMod val="300000"/></a:schemeClr></a:gs>';
        o[o.length] = '<a:gs pos="100000"><a:schemeClr val="phClr"><a:shade val="30000"/><a:satMod val="200000"/></a:schemeClr></a:gs>';
        o[o.length] = "</a:gsLst>";
        o[o.length] = '<a:path path="circle"><a:fillToRect l="50000" t="50000" r="50000" b="50000"/></a:path>';
        o[o.length] = "</a:gradFill>";
        o[o.length] = "</a:bgFillStyleLst>";
        o[o.length] = "</a:fmtScheme>";
        o[o.length] = "</a:themeElements>";
        o[o.length] = "<a:objectDefaults>";
        o[o.length] = "<a:spDef>";
        o[o.length] = '<a:spPr/><a:bodyPr/><a:lstStyle/><a:style><a:lnRef idx="1"><a:schemeClr val="accent1"/></a:lnRef><a:fillRef idx="3"><a:schemeClr val="accent1"/></a:fillRef><a:effectRef idx="2"><a:schemeClr val="accent1"/></a:effectRef><a:fontRef idx="minor"><a:schemeClr val="lt1"/></a:fontRef></a:style>';
        o[o.length] = "</a:spDef>";
        o[o.length] = "<a:lnDef>";
        o[o.length] = '<a:spPr/><a:bodyPr/><a:lstStyle/><a:style><a:lnRef idx="2"><a:schemeClr val="accent1"/></a:lnRef><a:fillRef idx="0"><a:schemeClr val="accent1"/></a:fillRef><a:effectRef idx="1"><a:schemeClr val="accent1"/></a:effectRef><a:fontRef idx="minor"><a:schemeClr val="tx1"/></a:fontRef></a:style>';
        o[o.length] = "</a:lnDef>";
        o[o.length] = "</a:objectDefaults>";
        o[o.length] = "<a:extraClrSchemeLst/>";
        o[o.length] = "</a:theme>";
        return o.join("");
      }
      function parse_Theme(blob, length, opts) {
        var end = blob.l + length;
        var dwThemeVersion = blob.read_shift(4);
        if (dwThemeVersion === 124226)
          return;
        if (!opts.cellStyles) {
          blob.l = end;
          return;
        }
        var data = blob.slice(blob.l);
        blob.l = end;
        var zip;
        try {
          zip = zip_read(data, { type: "array" });
        } catch (e) {
          return;
        }
        var themeXML = getzipstr(zip, "theme/theme/theme1.xml", true);
        if (!themeXML)
          return;
        return parse_theme_xml(themeXML, opts);
      }
      function parse_ColorTheme(blob) {
        return blob.read_shift(4);
      }
      function parse_FullColorExt(blob) {
        var o = {};
        o.xclrType = blob.read_shift(2);
        o.nTintShade = blob.read_shift(2);
        switch (o.xclrType) {
          case 0:
            blob.l += 4;
            break;
          case 1:
            o.xclrValue = parse_IcvXF(blob, 4);
            break;
          case 2:
            o.xclrValue = parse_LongRGBA(blob, 4);
            break;
          case 3:
            o.xclrValue = parse_ColorTheme(blob, 4);
            break;
          case 4:
            blob.l += 4;
            break;
        }
        blob.l += 8;
        return o;
      }
      function parse_IcvXF(blob, length) {
        return parsenoop(blob, length);
      }
      function parse_XFExtGradient(blob, length) {
        return parsenoop(blob, length);
      }
      function parse_ExtProp(blob) {
        var extType = blob.read_shift(2);
        var cb = blob.read_shift(2) - 4;
        var o = [extType];
        switch (extType) {
          case 4:
          case 5:
          case 7:
          case 8:
          case 9:
          case 10:
          case 11:
          case 13:
            o[1] = parse_FullColorExt(blob, cb);
            break;
          case 6:
            o[1] = parse_XFExtGradient(blob, cb);
            break;
          case 14:
          case 15:
            o[1] = blob.read_shift(cb === 1 ? 1 : 2);
            break;
          default:
            throw new Error("Unrecognized ExtProp type: " + extType + " " + cb);
        }
        return o;
      }
      function parse_XFExt(blob, length) {
        var end = blob.l + length;
        blob.l += 2;
        var ixfe = blob.read_shift(2);
        blob.l += 2;
        var cexts = blob.read_shift(2);
        var ext = [];
        while (cexts-- > 0)
          ext.push(parse_ExtProp(blob, end - blob.l));
        return { ixfe, ext };
      }
      function update_xfext(xf, xfext) {
        xfext.forEach(function(xfe) {
          switch (xfe[0]) {
            case 4:
              break;
            case 5:
              break;
            case 6:
              break;
            case 7:
              break;
            case 8:
              break;
            case 9:
              break;
            case 10:
              break;
            case 11:
              break;
            case 13:
              break;
            case 14:
              break;
            case 15:
              break;
          }
        });
      }
      function parse_BrtMdtinfo(data, length) {
        return {
          flags: data.read_shift(4),
          version: data.read_shift(4),
          name: parse_XLWideString(data, length - 8)
        };
      }
      function write_BrtMdtinfo(data) {
        var o = new_buf(12 + 2 * data.name.length);
        o.write_shift(4, data.flags);
        o.write_shift(4, data.version);
        write_XLWideString(data.name, o);
        return o.slice(0, o.l);
      }
      function parse_BrtMdb(data) {
        var out = [];
        var cnt = data.read_shift(4);
        while (cnt-- > 0)
          out.push([data.read_shift(4), data.read_shift(4)]);
        return out;
      }
      function write_BrtMdb(mdb) {
        var o = new_buf(4 + 8 * mdb.length);
        o.write_shift(4, mdb.length);
        for (var i = 0; i < mdb.length; ++i) {
          o.write_shift(4, mdb[i][0]);
          o.write_shift(4, mdb[i][1]);
        }
        return o;
      }
      function write_BrtBeginEsfmd(cnt, name) {
        var o = new_buf(8 + 2 * name.length);
        o.write_shift(4, cnt);
        write_XLWideString(name, o);
        return o.slice(0, o.l);
      }
      function parse_BrtBeginEsmdb(data) {
        data.l += 4;
        return data.read_shift(4) != 0;
      }
      function write_BrtBeginEsmdb(cnt, cm) {
        var o = new_buf(8);
        o.write_shift(4, cnt);
        o.write_shift(4, cm ? 1 : 0);
        return o;
      }
      function parse_xlmeta_bin(data, name, _opts) {
        var out = { Types: [], Cell: [], Value: [] };
        var opts = _opts || {};
        var state = [];
        var pass = false;
        var metatype = 2;
        recordhopper(data, function(val, R, RT) {
          switch (RT) {
            case 335:
              out.Types.push({ name: val.name });
              break;
            case 51:
              val.forEach(function(r) {
                if (metatype == 1)
                  out.Cell.push({ type: out.Types[r[0] - 1].name, index: r[1] });
                else if (metatype == 0)
                  out.Value.push({ type: out.Types[r[0] - 1].name, index: r[1] });
              });
              break;
            case 337:
              metatype = val ? 1 : 0;
              break;
            case 338:
              metatype = 2;
              break;
            case 35:
              state.push(RT);
              pass = true;
              break;
            case 36:
              state.pop();
              pass = false;
              break;
            default:
              if (R.T) {
              } else if (!pass || opts.WTF && state[state.length - 1] != 35)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        });
        return out;
      }
      function write_xlmeta_bin() {
        var ba = buf_array();
        write_record(ba, 332);
        write_record(ba, 334, write_UInt32LE(1));
        write_record(ba, 335, write_BrtMdtinfo({
          name: "XLDAPR",
          version: 12e4,
          flags: 3496657072
        }));
        write_record(ba, 336);
        write_record(ba, 339, write_BrtBeginEsfmd(1, "XLDAPR"));
        write_record(ba, 52);
        write_record(ba, 35, write_UInt32LE(514));
        write_record(ba, 4096, write_UInt32LE(0));
        write_record(ba, 4097, writeuint16(1));
        write_record(ba, 36);
        write_record(ba, 53);
        write_record(ba, 340);
        write_record(ba, 337, write_BrtBeginEsmdb(1, true));
        write_record(ba, 51, write_BrtMdb([[1, 0]]));
        write_record(ba, 338);
        write_record(ba, 333);
        return ba.end();
      }
      function parse_xlmeta_xml(data, name, opts) {
        var out = { Types: [], Cell: [], Value: [] };
        if (!data)
          return out;
        var pass = false;
        var metatype = 2;
        var lastmeta;
        data.replace(tagregex, function(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<?xml":
              break;
            case "<metadata":
            case "</metadata>":
              break;
            case "<metadataTypes":
            case "</metadataTypes>":
              break;
            case "<metadataType":
              out.Types.push({ name: y.name });
              break;
            case "</metadataType>":
              break;
            case "<futureMetadata":
              for (var j = 0; j < out.Types.length; ++j)
                if (out.Types[j].name == y.name)
                  lastmeta = out.Types[j];
              break;
            case "</futureMetadata>":
              break;
            case "<bk>":
              break;
            case "</bk>":
              break;
            case "<rc":
              if (metatype == 1)
                out.Cell.push({ type: out.Types[y.t - 1].name, index: +y.v });
              else if (metatype == 0)
                out.Value.push({ type: out.Types[y.t - 1].name, index: +y.v });
              break;
            case "</rc>":
              break;
            case "<cellMetadata":
              metatype = 1;
              break;
            case "</cellMetadata>":
              metatype = 2;
              break;
            case "<valueMetadata":
              metatype = 0;
              break;
            case "</valueMetadata>":
              metatype = 2;
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
            case "<extLst/>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            case "<rvb":
              if (!lastmeta)
                break;
              if (!lastmeta.offsets)
                lastmeta.offsets = [];
              lastmeta.offsets.push(+y.i);
              break;
            default:
              if (!pass && opts.WTF)
                throw new Error("unrecognized " + y[0] + " in metadata");
          }
          return x;
        });
        return out;
      }
      function write_xlmeta_xml() {
        var o = [XML_HEADER];
        o.push('<metadata xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:xlrd="http://schemas.microsoft.com/office/spreadsheetml/2017/richdata" xmlns:xda="http://schemas.microsoft.com/office/spreadsheetml/2017/dynamicarray">\n  <metadataTypes count="1">\n    <metadataType name="XLDAPR" minSupportedVersion="120000" copy="1" pasteAll="1" pasteValues="1" merge="1" splitFirst="1" rowColShift="1" clearFormats="1" clearComments="1" assign="1" coerce="1" cellMeta="1"/>\n  </metadataTypes>\n  <futureMetadata name="XLDAPR" count="1">\n    <bk>\n      <extLst>\n        <ext uri="{bdbb8cdc-fa1e-496e-a857-3c3f30c029c3}">\n          <xda:dynamicArrayProperties fDynamic="1" fCollapsed="0"/>\n        </ext>\n      </extLst>\n    </bk>\n  </futureMetadata>\n  <cellMetadata count="1">\n    <bk>\n      <rc t="1" v="0"/>\n    </bk>\n  </cellMetadata>\n</metadata>');
        return o.join("");
      }
      function parse_cc_xml(data) {
        var d = [];
        if (!data)
          return d;
        var i = 1;
        (data.match(tagregex) || []).forEach(function(x) {
          var y = parsexmltag(x);
          switch (y[0]) {
            case "<?xml":
              break;
            case "<calcChain":
            case "<calcChain>":
            case "</calcChain>":
              break;
            case "<c":
              delete y[0];
              if (y.i)
                i = y.i;
              else
                y.i = i;
              d.push(y);
              break;
          }
        });
        return d;
      }
      function parse_BrtCalcChainItem$(data) {
        var out = {};
        out.i = data.read_shift(4);
        var cell = {};
        cell.r = data.read_shift(4);
        cell.c = data.read_shift(4);
        out.r = encode_cell(cell);
        var flags = data.read_shift(1);
        if (flags & 2)
          out.l = "1";
        if (flags & 8)
          out.a = "1";
        return out;
      }
      function parse_cc_bin(data, name, opts) {
        var out = [];
        var pass = false;
        recordhopper(data, function hopper_cc(val, R, RT) {
          switch (RT) {
            case 63:
              out.push(val);
              break;
            default:
              if (R.T) {
              } else if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        });
        return out;
      }
      function parse_xlink_xml() {
      }
      function parse_xlink_bin(data, rel, name, _opts) {
        if (!data)
          return data;
        var opts = _opts || {};
        var pass = false, end = false;
        recordhopper(data, function xlink_parse(val, R, RT) {
          if (end)
            return;
          switch (RT) {
            case 359:
            case 363:
            case 364:
            case 366:
            case 367:
            case 368:
            case 369:
            case 370:
            case 371:
            case 472:
            case 577:
            case 578:
            case 579:
            case 580:
            case 581:
            case 582:
            case 583:
            case 584:
            case 585:
            case 586:
            case 587:
              break;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            default:
              if (R.T) {
              } else if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        }, opts);
      }
      function parse_drawing(data, rels) {
        if (!data)
          return "??";
        var id = (data.match(/<c:chart [^>]*r:id="([^"]*)"/) || ["", ""])[1];
        return rels["!id"][id].Target;
      }
      var _shapeid = 1024;
      function write_comments_vml(rId, comments) {
        var csize = [21600, 21600];
        var bbox = ["m0,0l0", csize[1], csize[0], csize[1], csize[0], "0xe"].join(",");
        var o = [
          writextag("xml", null, { "xmlns:v": XLMLNS.v, "xmlns:o": XLMLNS.o, "xmlns:x": XLMLNS.x, "xmlns:mv": XLMLNS.mv }).replace(/\/>/, ">"),
          writextag("o:shapelayout", writextag("o:idmap", null, { "v:ext": "edit", "data": rId }), { "v:ext": "edit" }),
          writextag("v:shapetype", [
            writextag("v:stroke", null, { joinstyle: "miter" }),
            writextag("v:path", null, { gradientshapeok: "t", "o:connecttype": "rect" })
          ].join(""), { id: "_x0000_t202", "o:spt": 202, coordsize: csize.join(","), path: bbox })
        ];
        while (_shapeid < rId * 1e3)
          _shapeid += 1e3;
        comments.forEach(function(x) {
          var c = decode_cell(x[0]);
          var fillopts = { "color2": "#BEFF82", "type": "gradient" };
          if (fillopts.type == "gradient")
            fillopts.angle = "-180";
          var fillparm = fillopts.type == "gradient" ? writextag("o:fill", null, { type: "gradientUnscaled", "v:ext": "view" }) : null;
          var fillxml = writextag("v:fill", fillparm, fillopts);
          var shadata = { on: "t", "obscured": "t" };
          ++_shapeid;
          o = o.concat([
            "<v:shape" + wxt_helper({
              id: "_x0000_s" + _shapeid,
              type: "#_x0000_t202",
              style: "position:absolute; margin-left:80pt;margin-top:5pt;width:104pt;height:64pt;z-index:10" + (x[1].hidden ? ";visibility:hidden" : ""),
              fillcolor: "#ECFAD4",
              strokecolor: "#edeaa1"
            }) + ">",
            fillxml,
            writextag("v:shadow", null, shadata),
            writextag("v:path", null, { "o:connecttype": "none" }),
            '<v:textbox><div style="text-align:left"></div></v:textbox>',
            '<x:ClientData ObjectType="Note">',
            "<x:MoveWithCells/>",
            "<x:SizeWithCells/>",
            /* Part 4 19.4.2.3 Anchor (Anchor) */
            writetag("x:Anchor", [c.c + 1, 0, c.r + 1, 0, c.c + 3, 20, c.r + 5, 20].join(",")),
            writetag("x:AutoFill", "False"),
            writetag("x:Row", String(c.r)),
            writetag("x:Column", String(c.c)),
            x[1].hidden ? "" : "<x:Visible/>",
            "</x:ClientData>",
            "</v:shape>"
          ]);
        });
        o.push("</xml>");
        return o.join("");
      }
      function sheet_insert_comments(sheet, comments, threaded, people) {
        var dense = Array.isArray(sheet);
        var cell;
        comments.forEach(function(comment) {
          var r = decode_cell(comment.ref);
          if (dense) {
            if (!sheet[r.r])
              sheet[r.r] = [];
            cell = sheet[r.r][r.c];
          } else
            cell = sheet[comment.ref];
          if (!cell) {
            cell = { t: "z" };
            if (dense)
              sheet[r.r][r.c] = cell;
            else
              sheet[comment.ref] = cell;
            var range = safe_decode_range(sheet["!ref"] || "BDWGO1000001:A1");
            if (range.s.r > r.r)
              range.s.r = r.r;
            if (range.e.r < r.r)
              range.e.r = r.r;
            if (range.s.c > r.c)
              range.s.c = r.c;
            if (range.e.c < r.c)
              range.e.c = r.c;
            var encoded = encode_range(range);
            if (encoded !== sheet["!ref"])
              sheet["!ref"] = encoded;
          }
          if (!cell.c)
            cell.c = [];
          var o = { a: comment.author, t: comment.t, r: comment.r, T: threaded };
          if (comment.h)
            o.h = comment.h;
          for (var i = cell.c.length - 1; i >= 0; --i) {
            if (!threaded && cell.c[i].T)
              return;
            if (threaded && !cell.c[i].T)
              cell.c.splice(i, 1);
          }
          if (threaded && people)
            for (i = 0; i < people.length; ++i) {
              if (o.a == people[i].id) {
                o.a = people[i].name || o.a;
                break;
              }
            }
          cell.c.push(o);
        });
      }
      function parse_comments_xml(data, opts) {
        if (data.match(/<(?:\w+:)?comments *\/>/))
          return [];
        var authors = [];
        var commentList = [];
        var authtag = data.match(/<(?:\w+:)?authors>([\s\S]*)<\/(?:\w+:)?authors>/);
        if (authtag && authtag[1])
          authtag[1].split(/<\/\w*:?author>/).forEach(function(x) {
            if (x === "" || x.trim() === "")
              return;
            var a = x.match(/<(?:\w+:)?author[^>]*>(.*)/);
            if (a)
              authors.push(a[1]);
          });
        var cmnttag = data.match(/<(?:\w+:)?commentList>([\s\S]*)<\/(?:\w+:)?commentList>/);
        if (cmnttag && cmnttag[1])
          cmnttag[1].split(/<\/\w*:?comment>/).forEach(function(x) {
            if (x === "" || x.trim() === "")
              return;
            var cm = x.match(/<(?:\w+:)?comment[^>]*>/);
            if (!cm)
              return;
            var y = parsexmltag(cm[0]);
            var comment = { author: y.authorId && authors[y.authorId] || "sheetjsghost", ref: y.ref, guid: y.guid };
            var cell = decode_cell(y.ref);
            if (opts.sheetRows && opts.sheetRows <= cell.r)
              return;
            var textMatch = x.match(/<(?:\w+:)?text>([\s\S]*)<\/(?:\w+:)?text>/);
            var rt = !!textMatch && !!textMatch[1] && parse_si(textMatch[1]) || { r: "", t: "", h: "" };
            comment.r = rt.r;
            if (rt.r == "<t></t>")
              rt.t = rt.h = "";
            comment.t = (rt.t || "").replace(/\r\n/g, "\n").replace(/\r/g, "\n");
            if (opts.cellHTML)
              comment.h = rt.h;
            commentList.push(comment);
          });
        return commentList;
      }
      function write_comments_xml(data) {
        var o = [XML_HEADER, writextag("comments", null, { "xmlns": XMLNS_main[0] })];
        var iauthor = [];
        o.push("<authors>");
        data.forEach(function(x) {
          x[1].forEach(function(w) {
            var a = escapexml(w.a);
            if (iauthor.indexOf(a) == -1) {
              iauthor.push(a);
              o.push("<author>" + a + "</author>");
            }
            if (w.T && w.ID && iauthor.indexOf("tc=" + w.ID) == -1) {
              iauthor.push("tc=" + w.ID);
              o.push("<author>tc=" + w.ID + "</author>");
            }
          });
        });
        if (iauthor.length == 0) {
          iauthor.push("SheetJ5");
          o.push("<author>SheetJ5</author>");
        }
        o.push("</authors>");
        o.push("<commentList>");
        data.forEach(function(d) {
          var lastauthor = 0, ts = [];
          if (d[1][0] && d[1][0].T && d[1][0].ID)
            lastauthor = iauthor.indexOf("tc=" + d[1][0].ID);
          else
            d[1].forEach(function(c) {
              if (c.a)
                lastauthor = iauthor.indexOf(escapexml(c.a));
              ts.push(c.t || "");
            });
          o.push('<comment ref="' + d[0] + '" authorId="' + lastauthor + '"><text>');
          if (ts.length <= 1)
            o.push(writetag("t", escapexml(ts[0] || "")));
          else {
            var t3 = "Comment:\n    " + ts[0] + "\n";
            for (var i = 1; i < ts.length; ++i)
              t3 += "Reply:\n    " + ts[i] + "\n";
            o.push(writetag("t", escapexml(t3)));
          }
          o.push("</text></comment>");
        });
        o.push("</commentList>");
        if (o.length > 2) {
          o[o.length] = "</comments>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_tcmnt_xml(data, opts) {
        var out = [];
        var pass = false, comment = {}, tidx = 0;
        data.replace(tagregex, function xml_tcmnt(x, idx) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<?xml":
              break;
            case "<ThreadedComments":
              break;
            case "</ThreadedComments>":
              break;
            case "<threadedComment":
              comment = { author: y.personId, guid: y.id, ref: y.ref, T: 1 };
              break;
            case "</threadedComment>":
              if (comment.t != null)
                out.push(comment);
              break;
            case "<text>":
            case "<text":
              tidx = idx + x.length;
              break;
            case "</text>":
              comment.t = data.slice(tidx, idx).replace(/\r\n/g, "\n").replace(/\r/g, "\n");
              break;
            case "<mentions":
            case "<mentions>":
              pass = true;
              break;
            case "</mentions>":
              pass = false;
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
            case "<extLst/>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (!pass && opts.WTF)
                throw new Error("unrecognized " + y[0] + " in threaded comments");
          }
          return x;
        });
        return out;
      }
      function write_tcmnt_xml(comments, people, opts) {
        var o = [XML_HEADER, writextag("ThreadedComments", null, { "xmlns": XMLNS.TCMNT }).replace(/[\/]>/, ">")];
        comments.forEach(function(carr) {
          var rootid = "";
          (carr[1] || []).forEach(function(c, idx) {
            if (!c.T) {
              delete c.ID;
              return;
            }
            if (c.a && people.indexOf(c.a) == -1)
              people.push(c.a);
            var tcopts = {
              ref: carr[0],
              id: "{54EE7951-7262-4200-6969-" + ("000000000000" + opts.tcid++).slice(-12) + "}"
            };
            if (idx == 0)
              rootid = tcopts.id;
            else
              tcopts.parentId = rootid;
            c.ID = tcopts.id;
            if (c.a)
              tcopts.personId = "{54EE7950-7262-4200-6969-" + ("000000000000" + people.indexOf(c.a)).slice(-12) + "}";
            o.push(writextag("threadedComment", writetag("text", c.t || ""), tcopts));
          });
        });
        o.push("</ThreadedComments>");
        return o.join("");
      }
      function parse_people_xml(data, opts) {
        var out = [];
        var pass = false;
        data.replace(tagregex, function xml_tcmnt(x) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<?xml":
              break;
            case "<personList":
              break;
            case "</personList>":
              break;
            case "<person":
              out.push({ name: y.displayname, id: y.id });
              break;
            case "</person>":
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
            case "<extLst/>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            default:
              if (!pass && opts.WTF)
                throw new Error("unrecognized " + y[0] + " in threaded comments");
          }
          return x;
        });
        return out;
      }
      function write_people_xml(people) {
        var o = [XML_HEADER, writextag("personList", null, {
          "xmlns": XMLNS.TCMNT,
          "xmlns:x": XMLNS_main[0]
        }).replace(/[\/]>/, ">")];
        people.forEach(function(person, idx) {
          o.push(writextag("person", null, {
            displayName: person,
            id: "{54EE7950-7262-4200-6969-" + ("000000000000" + idx).slice(-12) + "}",
            userId: person,
            providerId: "None"
          }));
        });
        o.push("</personList>");
        return o.join("");
      }
      function parse_BrtBeginComment(data) {
        var out = {};
        out.iauthor = data.read_shift(4);
        var rfx = parse_UncheckedRfX(data, 16);
        out.rfx = rfx.s;
        out.ref = encode_cell(rfx.s);
        data.l += 16;
        return out;
      }
      function write_BrtBeginComment(data, o) {
        if (o == null)
          o = new_buf(36);
        o.write_shift(4, data[1].iauthor);
        write_UncheckedRfX(data[0], o);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        return o;
      }
      var parse_BrtCommentAuthor = parse_XLWideString;
      function write_BrtCommentAuthor(data) {
        return write_XLWideString(data.slice(0, 54));
      }
      function parse_comments_bin(data, opts) {
        var out = [];
        var authors = [];
        var c = {};
        var pass = false;
        recordhopper(data, function hopper_cmnt(val, R, RT) {
          switch (RT) {
            case 632:
              authors.push(val);
              break;
            case 635:
              c = val;
              break;
            case 637:
              c.t = val.t;
              c.h = val.h;
              c.r = val.r;
              break;
            case 636:
              c.author = authors[c.iauthor];
              delete c.iauthor;
              if (opts.sheetRows && c.rfx && opts.sheetRows <= c.rfx.r)
                break;
              if (!c.t)
                c.t = "";
              delete c.rfx;
              out.push(c);
              break;
            case 3072:
              break;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            case 37:
              break;
            case 38:
              break;
            default:
              if (R.T) {
              } else if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        });
        return out;
      }
      function write_comments_bin(data) {
        var ba = buf_array();
        var iauthor = [];
        write_record(
          ba,
          628
          /* BrtBeginComments */
        );
        write_record(
          ba,
          630
          /* BrtBeginCommentAuthors */
        );
        data.forEach(function(comment) {
          comment[1].forEach(function(c) {
            if (iauthor.indexOf(c.a) > -1)
              return;
            iauthor.push(c.a.slice(0, 54));
            write_record(ba, 632, write_BrtCommentAuthor(c.a));
          });
        });
        write_record(
          ba,
          631
          /* BrtEndCommentAuthors */
        );
        write_record(
          ba,
          633
          /* BrtBeginCommentList */
        );
        data.forEach(function(comment) {
          comment[1].forEach(function(c) {
            c.iauthor = iauthor.indexOf(c.a);
            var range = { s: decode_cell(comment[0]), e: decode_cell(comment[0]) };
            write_record(ba, 635, write_BrtBeginComment([range, c]));
            if (c.t && c.t.length > 0)
              write_record(ba, 637, write_BrtCommentText(c));
            write_record(
              ba,
              636
              /* BrtEndComment */
            );
            delete c.iauthor;
          });
        });
        write_record(
          ba,
          634
          /* BrtEndCommentList */
        );
        write_record(
          ba,
          629
          /* BrtEndComments */
        );
        return ba.end();
      }
      var CT_VBA = "application/vnd.ms-office.vbaProject";
      function make_vba_xls(cfb) {
        var newcfb = CFB.utils.cfb_new({ root: "R" });
        cfb.FullPaths.forEach(function(p, i) {
          if (p.slice(-1) === "/" || !p.match(/_VBA_PROJECT_CUR/))
            return;
          var newpath = p.replace(/^[^\/]*/, "R").replace(/\/_VBA_PROJECT_CUR\u0000*/, "");
          CFB.utils.cfb_add(newcfb, newpath, cfb.FileIndex[i].content);
        });
        return CFB.write(newcfb);
      }
      function fill_vba_xls(cfb, vba) {
        vba.FullPaths.forEach(function(p, i) {
          if (i == 0)
            return;
          var newpath = p.replace(/[^\/]*[\/]/, "/_VBA_PROJECT_CUR/");
          if (newpath.slice(-1) !== "/")
            CFB.utils.cfb_add(cfb, newpath, vba.FileIndex[i].content);
        });
      }
      var VBAFMTS = ["xlsb", "xlsm", "xlam", "biff8", "xla"];
      function parse_ds_bin() {
        return { "!type": "dialog" };
      }
      function parse_ds_xml() {
        return { "!type": "dialog" };
      }
      function parse_ms_bin() {
        return { "!type": "macro" };
      }
      function parse_ms_xml() {
        return { "!type": "macro" };
      }
      var rc_to_a1 = function() {
        var rcregex = /(^|[^A-Za-z_])R(\[?-?\d+\]|[1-9]\d*|)C(\[?-?\d+\]|[1-9]\d*|)(?![A-Za-z0-9_])/g;
        var rcbase = { r: 0, c: 0 };
        function rcfunc($$, $1, $2, $3) {
          var cRel = false, rRel = false;
          if ($2.length == 0)
            rRel = true;
          else if ($2.charAt(0) == "[") {
            rRel = true;
            $2 = $2.slice(1, -1);
          }
          if ($3.length == 0)
            cRel = true;
          else if ($3.charAt(0) == "[") {
            cRel = true;
            $3 = $3.slice(1, -1);
          }
          var R = $2.length > 0 ? parseInt($2, 10) | 0 : 0, C = $3.length > 0 ? parseInt($3, 10) | 0 : 0;
          if (cRel)
            C += rcbase.c;
          else
            --C;
          if (rRel)
            R += rcbase.r;
          else
            --R;
          return $1 + (cRel ? "" : "$") + encode_col(C) + (rRel ? "" : "$") + encode_row(R);
        }
        return function rc_to_a12(fstr, base) {
          rcbase = base;
          return fstr.replace(rcregex, rcfunc);
        };
      }();
      var crefregex = /(^|[^._A-Z0-9])([$]?)([A-Z]{1,2}|[A-W][A-Z]{2}|X[A-E][A-Z]|XF[A-D])([$]?)(10[0-3]\d{4}|104[0-7]\d{3}|1048[0-4]\d{2}|10485[0-6]\d|104857[0-6]|[1-9]\d{0,5})(?![_.\(A-Za-z0-9])/g;
      var a1_to_rc = function() {
        return function a1_to_rc2(fstr, base) {
          return fstr.replace(crefregex, function($0, $1, $2, $3, $4, $5) {
            var c = decode_col($3) - ($2 ? 0 : base.c);
            var r = decode_row($5) - ($4 ? 0 : base.r);
            var R = r == 0 ? "" : !$4 ? "[" + r + "]" : r + 1;
            var C = c == 0 ? "" : !$2 ? "[" + c + "]" : c + 1;
            return $1 + "R" + R + "C" + C;
          });
        };
      }();
      function shift_formula_str(f, delta) {
        return f.replace(crefregex, function($0, $1, $2, $3, $4, $5) {
          return $1 + ($2 == "$" ? $2 + $3 : encode_col(decode_col($3) + delta.c)) + ($4 == "$" ? $4 + $5 : encode_row(decode_row($5) + delta.r));
        });
      }
      function shift_formula_xlsx(f, range, cell) {
        var r = decode_range(range), s = r.s, c = decode_cell(cell);
        var delta = { r: c.r - s.r, c: c.c - s.c };
        return shift_formula_str(f, delta);
      }
      function fuzzyfmla(f) {
        if (f.length == 1)
          return false;
        return true;
      }
      function _xlfn(f) {
        return f.replace(/_xlfn\./g, "");
      }
      function parseread1(blob) {
        blob.l += 1;
        return;
      }
      function parse_ColRelU(blob, length) {
        var c = blob.read_shift(length == 1 ? 1 : 2);
        return [c & 16383, c >> 14 & 1, c >> 15 & 1];
      }
      function parse_RgceArea(blob, length, opts) {
        var w = 2;
        if (opts) {
          if (opts.biff >= 2 && opts.biff <= 5)
            return parse_RgceArea_BIFF2(blob, length, opts);
          else if (opts.biff == 12)
            w = 4;
        }
        var r = blob.read_shift(w), R = blob.read_shift(w);
        var c = parse_ColRelU(blob, 2);
        var C = parse_ColRelU(blob, 2);
        return { s: { r, c: c[0], cRel: c[1], rRel: c[2] }, e: { r: R, c: C[0], cRel: C[1], rRel: C[2] } };
      }
      function parse_RgceArea_BIFF2(blob) {
        var r = parse_ColRelU(blob, 2), R = parse_ColRelU(blob, 2);
        var c = blob.read_shift(1);
        var C = blob.read_shift(1);
        return { s: { r: r[0], c, cRel: r[1], rRel: r[2] }, e: { r: R[0], c: C, cRel: R[1], rRel: R[2] } };
      }
      function parse_RgceAreaRel(blob, length, opts) {
        if (opts.biff < 8)
          return parse_RgceArea_BIFF2(blob, length, opts);
        var r = blob.read_shift(opts.biff == 12 ? 4 : 2), R = blob.read_shift(opts.biff == 12 ? 4 : 2);
        var c = parse_ColRelU(blob, 2);
        var C = parse_ColRelU(blob, 2);
        return { s: { r, c: c[0], cRel: c[1], rRel: c[2] }, e: { r: R, c: C[0], cRel: C[1], rRel: C[2] } };
      }
      function parse_RgceLoc(blob, length, opts) {
        if (opts && opts.biff >= 2 && opts.biff <= 5)
          return parse_RgceLoc_BIFF2(blob, length, opts);
        var r = blob.read_shift(opts && opts.biff == 12 ? 4 : 2);
        var c = parse_ColRelU(blob, 2);
        return { r, c: c[0], cRel: c[1], rRel: c[2] };
      }
      function parse_RgceLoc_BIFF2(blob) {
        var r = parse_ColRelU(blob, 2);
        var c = blob.read_shift(1);
        return { r: r[0], c, cRel: r[1], rRel: r[2] };
      }
      function parse_RgceElfLoc(blob) {
        var r = blob.read_shift(2);
        var c = blob.read_shift(2);
        return { r, c: c & 255, fQuoted: !!(c & 16384), cRel: c >> 15, rRel: c >> 15 };
      }
      function parse_RgceLocRel(blob, length, opts) {
        var biff = opts && opts.biff ? opts.biff : 8;
        if (biff >= 2 && biff <= 5)
          return parse_RgceLocRel_BIFF2(blob, length, opts);
        var r = blob.read_shift(biff >= 12 ? 4 : 2);
        var cl = blob.read_shift(2);
        var cRel = (cl & 16384) >> 14, rRel = (cl & 32768) >> 15;
        cl &= 16383;
        if (rRel == 1)
          while (r > 524287)
            r -= 1048576;
        if (cRel == 1)
          while (cl > 8191)
            cl = cl - 16384;
        return { r, c: cl, cRel, rRel };
      }
      function parse_RgceLocRel_BIFF2(blob) {
        var rl = blob.read_shift(2);
        var c = blob.read_shift(1);
        var rRel = (rl & 32768) >> 15, cRel = (rl & 16384) >> 14;
        rl &= 16383;
        if (rRel == 1 && rl >= 8192)
          rl = rl - 16384;
        if (cRel == 1 && c >= 128)
          c = c - 256;
        return { r: rl, c, cRel, rRel };
      }
      function parse_PtgArea(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        var area = parse_RgceArea(blob, opts.biff >= 2 && opts.biff <= 5 ? 6 : 8, opts);
        return [type, area];
      }
      function parse_PtgArea3d(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        var ixti = blob.read_shift(2, "i");
        var w = 8;
        if (opts)
          switch (opts.biff) {
            case 5:
              blob.l += 12;
              w = 6;
              break;
            case 12:
              w = 12;
              break;
          }
        var area = parse_RgceArea(blob, w, opts);
        return [type, ixti, area];
      }
      function parse_PtgAreaErr(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        blob.l += opts && opts.biff > 8 ? 12 : opts.biff < 8 ? 6 : 8;
        return [type];
      }
      function parse_PtgAreaErr3d(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        var ixti = blob.read_shift(2);
        var w = 8;
        if (opts)
          switch (opts.biff) {
            case 5:
              blob.l += 12;
              w = 6;
              break;
            case 12:
              w = 12;
              break;
          }
        blob.l += w;
        return [type, ixti];
      }
      function parse_PtgAreaN(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        var area = parse_RgceAreaRel(blob, length - 1, opts);
        return [type, area];
      }
      function parse_PtgArray(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        blob.l += opts.biff == 2 ? 6 : opts.biff == 12 ? 14 : 7;
        return [type];
      }
      function parse_PtgAttrBaxcel(blob) {
        var bitSemi = blob[blob.l + 1] & 1;
        var bitBaxcel = 1;
        blob.l += 4;
        return [bitSemi, bitBaxcel];
      }
      function parse_PtgAttrChoose(blob, length, opts) {
        blob.l += 2;
        var offset = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        var o = [];
        for (var i = 0; i <= offset; ++i)
          o.push(blob.read_shift(opts && opts.biff == 2 ? 1 : 2));
        return o;
      }
      function parse_PtgAttrGoto(blob, length, opts) {
        var bitGoto = blob[blob.l + 1] & 255 ? 1 : 0;
        blob.l += 2;
        return [bitGoto, blob.read_shift(opts && opts.biff == 2 ? 1 : 2)];
      }
      function parse_PtgAttrIf(blob, length, opts) {
        var bitIf = blob[blob.l + 1] & 255 ? 1 : 0;
        blob.l += 2;
        return [bitIf, blob.read_shift(opts && opts.biff == 2 ? 1 : 2)];
      }
      function parse_PtgAttrIfError(blob) {
        var bitIf = blob[blob.l + 1] & 255 ? 1 : 0;
        blob.l += 2;
        return [bitIf, blob.read_shift(2)];
      }
      function parse_PtgAttrSemi(blob, length, opts) {
        var bitSemi = blob[blob.l + 1] & 255 ? 1 : 0;
        blob.l += opts && opts.biff == 2 ? 3 : 4;
        return [bitSemi];
      }
      function parse_PtgAttrSpaceType(blob) {
        var type = blob.read_shift(1), cch = blob.read_shift(1);
        return [type, cch];
      }
      function parse_PtgAttrSpace(blob) {
        blob.read_shift(2);
        return parse_PtgAttrSpaceType(blob, 2);
      }
      function parse_PtgAttrSpaceSemi(blob) {
        blob.read_shift(2);
        return parse_PtgAttrSpaceType(blob, 2);
      }
      function parse_PtgRef(blob, length, opts) {
        var type = (blob[blob.l] & 96) >> 5;
        blob.l += 1;
        var loc = parse_RgceLoc(blob, 0, opts);
        return [type, loc];
      }
      function parse_PtgRefN(blob, length, opts) {
        var type = (blob[blob.l] & 96) >> 5;
        blob.l += 1;
        var loc = parse_RgceLocRel(blob, 0, opts);
        return [type, loc];
      }
      function parse_PtgRef3d(blob, length, opts) {
        var type = (blob[blob.l] & 96) >> 5;
        blob.l += 1;
        var ixti = blob.read_shift(2);
        if (opts && opts.biff == 5)
          blob.l += 12;
        var loc = parse_RgceLoc(blob, 0, opts);
        return [type, ixti, loc];
      }
      function parse_PtgFunc(blob, length, opts) {
        var type = (blob[blob.l] & 96) >> 5;
        blob.l += 1;
        var iftab = blob.read_shift(opts && opts.biff <= 3 ? 1 : 2);
        return [FtabArgc[iftab], Ftab[iftab], type];
      }
      function parse_PtgFuncVar(blob, length, opts) {
        var type = blob[blob.l++];
        var cparams = blob.read_shift(1), tab = opts && opts.biff <= 3 ? [type == 88 ? -1 : 0, blob.read_shift(1)] : parsetab(blob);
        return [cparams, (tab[0] === 0 ? Ftab : Cetab)[tab[1]]];
      }
      function parsetab(blob) {
        return [blob[blob.l + 1] >> 7, blob.read_shift(2) & 32767];
      }
      function parse_PtgAttrSum(blob, length, opts) {
        blob.l += opts && opts.biff == 2 ? 3 : 4;
        return;
      }
      function parse_PtgExp(blob, length, opts) {
        blob.l++;
        if (opts && opts.biff == 12)
          return [blob.read_shift(4, "i"), 0];
        var row = blob.read_shift(2);
        var col = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        return [row, col];
      }
      function parse_PtgErr(blob) {
        blob.l++;
        return BErr[blob.read_shift(1)];
      }
      function parse_PtgInt(blob) {
        blob.l++;
        return blob.read_shift(2);
      }
      function parse_PtgBool(blob) {
        blob.l++;
        return blob.read_shift(1) !== 0;
      }
      function parse_PtgNum(blob) {
        blob.l++;
        return parse_Xnum(blob, 8);
      }
      function parse_PtgStr(blob, length, opts) {
        blob.l++;
        return parse_ShortXLUnicodeString(blob, length - 1, opts);
      }
      function parse_SerAr(blob, biff) {
        var val = [blob.read_shift(1)];
        if (biff == 12)
          switch (val[0]) {
            case 2:
              val[0] = 4;
              break;
            case 4:
              val[0] = 16;
              break;
            case 0:
              val[0] = 1;
              break;
            case 1:
              val[0] = 2;
              break;
          }
        switch (val[0]) {
          case 4:
            val[1] = parsebool(blob, 1) ? "TRUE" : "FALSE";
            if (biff != 12)
              blob.l += 7;
            break;
          case 37:
          case 16:
            val[1] = BErr[blob[blob.l]];
            blob.l += biff == 12 ? 4 : 8;
            break;
          case 0:
            blob.l += 8;
            break;
          case 1:
            val[1] = parse_Xnum(blob, 8);
            break;
          case 2:
            val[1] = parse_XLUnicodeString2(blob, 0, { biff: biff > 0 && biff < 8 ? 2 : biff });
            break;
          default:
            throw new Error("Bad SerAr: " + val[0]);
        }
        return val;
      }
      function parse_PtgExtraMem(blob, cce, opts) {
        var count = blob.read_shift(opts.biff == 12 ? 4 : 2);
        var out = [];
        for (var i = 0; i != count; ++i)
          out.push((opts.biff == 12 ? parse_UncheckedRfX : parse_Ref8U)(blob, 8));
        return out;
      }
      function parse_PtgExtraArray(blob, length, opts) {
        var rows = 0, cols = 0;
        if (opts.biff == 12) {
          rows = blob.read_shift(4);
          cols = blob.read_shift(4);
        } else {
          cols = 1 + blob.read_shift(1);
          rows = 1 + blob.read_shift(2);
        }
        if (opts.biff >= 2 && opts.biff < 8) {
          --rows;
          if (--cols == 0)
            cols = 256;
        }
        for (var i = 0, o = []; i != rows && (o[i] = []); ++i)
          for (var j = 0; j != cols; ++j)
            o[i][j] = parse_SerAr(blob, opts.biff);
        return o;
      }
      function parse_PtgName(blob, length, opts) {
        var type = blob.read_shift(1) >>> 5 & 3;
        var w = !opts || opts.biff >= 8 ? 4 : 2;
        var nameindex = blob.read_shift(w);
        switch (opts.biff) {
          case 2:
            blob.l += 5;
            break;
          case 3:
          case 4:
            blob.l += 8;
            break;
          case 5:
            blob.l += 12;
            break;
        }
        return [type, 0, nameindex];
      }
      function parse_PtgNameX(blob, length, opts) {
        if (opts.biff == 5)
          return parse_PtgNameX_BIFF5(blob, length, opts);
        var type = blob.read_shift(1) >>> 5 & 3;
        var ixti = blob.read_shift(2);
        var nameindex = blob.read_shift(4);
        return [type, ixti, nameindex];
      }
      function parse_PtgNameX_BIFF5(blob) {
        var type = blob.read_shift(1) >>> 5 & 3;
        var ixti = blob.read_shift(2, "i");
        blob.l += 8;
        var nameindex = blob.read_shift(2);
        blob.l += 12;
        return [type, ixti, nameindex];
      }
      function parse_PtgMemArea(blob, length, opts) {
        var type = blob.read_shift(1) >>> 5 & 3;
        blob.l += opts && opts.biff == 2 ? 3 : 4;
        var cce = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        return [type, cce];
      }
      function parse_PtgMemFunc(blob, length, opts) {
        var type = blob.read_shift(1) >>> 5 & 3;
        var cce = blob.read_shift(opts && opts.biff == 2 ? 1 : 2);
        return [type, cce];
      }
      function parse_PtgRefErr(blob, length, opts) {
        var type = blob.read_shift(1) >>> 5 & 3;
        blob.l += 4;
        if (opts.biff < 8)
          blob.l--;
        if (opts.biff == 12)
          blob.l += 2;
        return [type];
      }
      function parse_PtgRefErr3d(blob, length, opts) {
        var type = (blob[blob.l++] & 96) >> 5;
        var ixti = blob.read_shift(2);
        var w = 4;
        if (opts)
          switch (opts.biff) {
            case 5:
              w = 15;
              break;
            case 12:
              w = 6;
              break;
          }
        blob.l += w;
        return [type, ixti];
      }
      var parse_PtgMemErr = parsenoop;
      var parse_PtgMemNoMem = parsenoop;
      var parse_PtgTbl = parsenoop;
      function parse_PtgElfLoc(blob, length, opts) {
        blob.l += 2;
        return [parse_RgceElfLoc(blob, 4, opts)];
      }
      function parse_PtgElfNoop(blob) {
        blob.l += 6;
        return [];
      }
      var parse_PtgElfCol = parse_PtgElfLoc;
      var parse_PtgElfColS = parse_PtgElfNoop;
      var parse_PtgElfColSV = parse_PtgElfNoop;
      var parse_PtgElfColV = parse_PtgElfLoc;
      function parse_PtgElfLel(blob) {
        blob.l += 2;
        return [parseuint16(blob), blob.read_shift(2) & 1];
      }
      var parse_PtgElfRadical = parse_PtgElfLoc;
      var parse_PtgElfRadicalLel = parse_PtgElfLel;
      var parse_PtgElfRadicalS = parse_PtgElfNoop;
      var parse_PtgElfRw = parse_PtgElfLoc;
      var parse_PtgElfRwV = parse_PtgElfLoc;
      var PtgListRT = [
        "Data",
        "All",
        "Headers",
        "??",
        "?Data2",
        "??",
        "?DataHeaders",
        "??",
        "Totals",
        "??",
        "??",
        "??",
        "?DataTotals",
        "??",
        "??",
        "??",
        "?Current"
      ];
      function parse_PtgList(blob) {
        blob.l += 2;
        var ixti = blob.read_shift(2);
        var flags = blob.read_shift(2);
        var idx = blob.read_shift(4);
        var c = blob.read_shift(2);
        var C = blob.read_shift(2);
        var rt = PtgListRT[flags >> 2 & 31];
        return { ixti, coltype: flags & 3, rt, idx, c, C };
      }
      function parse_PtgSxName(blob) {
        blob.l += 2;
        return [blob.read_shift(4)];
      }
      function parse_PtgSheet(blob, length, opts) {
        blob.l += 5;
        blob.l += 2;
        blob.l += opts.biff == 2 ? 1 : 4;
        return ["PTGSHEET"];
      }
      function parse_PtgEndSheet(blob, length, opts) {
        blob.l += opts.biff == 2 ? 4 : 5;
        return ["PTGENDSHEET"];
      }
      function parse_PtgMemAreaN(blob) {
        var type = blob.read_shift(1) >>> 5 & 3;
        var cce = blob.read_shift(2);
        return [type, cce];
      }
      function parse_PtgMemNoMemN(blob) {
        var type = blob.read_shift(1) >>> 5 & 3;
        var cce = blob.read_shift(2);
        return [type, cce];
      }
      function parse_PtgAttrNoop(blob) {
        blob.l += 4;
        return [0, 0];
      }
      var PtgTypes = {
        1: { n: "PtgExp", f: parse_PtgExp },
        2: { n: "PtgTbl", f: parse_PtgTbl },
        3: { n: "PtgAdd", f: parseread1 },
        4: { n: "PtgSub", f: parseread1 },
        5: { n: "PtgMul", f: parseread1 },
        6: { n: "PtgDiv", f: parseread1 },
        7: { n: "PtgPower", f: parseread1 },
        8: { n: "PtgConcat", f: parseread1 },
        9: { n: "PtgLt", f: parseread1 },
        10: { n: "PtgLe", f: parseread1 },
        11: { n: "PtgEq", f: parseread1 },
        12: { n: "PtgGe", f: parseread1 },
        13: { n: "PtgGt", f: parseread1 },
        14: { n: "PtgNe", f: parseread1 },
        15: { n: "PtgIsect", f: parseread1 },
        16: { n: "PtgUnion", f: parseread1 },
        17: { n: "PtgRange", f: parseread1 },
        18: { n: "PtgUplus", f: parseread1 },
        19: { n: "PtgUminus", f: parseread1 },
        20: { n: "PtgPercent", f: parseread1 },
        21: { n: "PtgParen", f: parseread1 },
        22: { n: "PtgMissArg", f: parseread1 },
        23: { n: "PtgStr", f: parse_PtgStr },
        26: { n: "PtgSheet", f: parse_PtgSheet },
        27: { n: "PtgEndSheet", f: parse_PtgEndSheet },
        28: { n: "PtgErr", f: parse_PtgErr },
        29: { n: "PtgBool", f: parse_PtgBool },
        30: { n: "PtgInt", f: parse_PtgInt },
        31: { n: "PtgNum", f: parse_PtgNum },
        32: { n: "PtgArray", f: parse_PtgArray },
        33: { n: "PtgFunc", f: parse_PtgFunc },
        34: { n: "PtgFuncVar", f: parse_PtgFuncVar },
        35: { n: "PtgName", f: parse_PtgName },
        36: { n: "PtgRef", f: parse_PtgRef },
        37: { n: "PtgArea", f: parse_PtgArea },
        38: { n: "PtgMemArea", f: parse_PtgMemArea },
        39: { n: "PtgMemErr", f: parse_PtgMemErr },
        40: { n: "PtgMemNoMem", f: parse_PtgMemNoMem },
        41: { n: "PtgMemFunc", f: parse_PtgMemFunc },
        42: { n: "PtgRefErr", f: parse_PtgRefErr },
        43: { n: "PtgAreaErr", f: parse_PtgAreaErr },
        44: { n: "PtgRefN", f: parse_PtgRefN },
        45: { n: "PtgAreaN", f: parse_PtgAreaN },
        46: { n: "PtgMemAreaN", f: parse_PtgMemAreaN },
        47: { n: "PtgMemNoMemN", f: parse_PtgMemNoMemN },
        57: { n: "PtgNameX", f: parse_PtgNameX },
        58: { n: "PtgRef3d", f: parse_PtgRef3d },
        59: { n: "PtgArea3d", f: parse_PtgArea3d },
        60: { n: "PtgRefErr3d", f: parse_PtgRefErr3d },
        61: { n: "PtgAreaErr3d", f: parse_PtgAreaErr3d },
        255: {}
      };
      var PtgDupes = {
        64: 32,
        96: 32,
        65: 33,
        97: 33,
        66: 34,
        98: 34,
        67: 35,
        99: 35,
        68: 36,
        100: 36,
        69: 37,
        101: 37,
        70: 38,
        102: 38,
        71: 39,
        103: 39,
        72: 40,
        104: 40,
        73: 41,
        105: 41,
        74: 42,
        106: 42,
        75: 43,
        107: 43,
        76: 44,
        108: 44,
        77: 45,
        109: 45,
        78: 46,
        110: 46,
        79: 47,
        111: 47,
        88: 34,
        120: 34,
        89: 57,
        121: 57,
        90: 58,
        122: 58,
        91: 59,
        123: 59,
        92: 60,
        124: 60,
        93: 61,
        125: 61
      };
      var Ptg18 = {
        1: { n: "PtgElfLel", f: parse_PtgElfLel },
        2: { n: "PtgElfRw", f: parse_PtgElfRw },
        3: { n: "PtgElfCol", f: parse_PtgElfCol },
        6: { n: "PtgElfRwV", f: parse_PtgElfRwV },
        7: { n: "PtgElfColV", f: parse_PtgElfColV },
        10: { n: "PtgElfRadical", f: parse_PtgElfRadical },
        11: { n: "PtgElfRadicalS", f: parse_PtgElfRadicalS },
        13: { n: "PtgElfColS", f: parse_PtgElfColS },
        15: { n: "PtgElfColSV", f: parse_PtgElfColSV },
        16: { n: "PtgElfRadicalLel", f: parse_PtgElfRadicalLel },
        25: { n: "PtgList", f: parse_PtgList },
        29: { n: "PtgSxName", f: parse_PtgSxName },
        255: {}
      };
      var Ptg19 = {
        0: { n: "PtgAttrNoop", f: parse_PtgAttrNoop },
        1: { n: "PtgAttrSemi", f: parse_PtgAttrSemi },
        2: { n: "PtgAttrIf", f: parse_PtgAttrIf },
        4: { n: "PtgAttrChoose", f: parse_PtgAttrChoose },
        8: { n: "PtgAttrGoto", f: parse_PtgAttrGoto },
        16: { n: "PtgAttrSum", f: parse_PtgAttrSum },
        32: { n: "PtgAttrBaxcel", f: parse_PtgAttrBaxcel },
        33: { n: "PtgAttrBaxcel", f: parse_PtgAttrBaxcel },
        64: { n: "PtgAttrSpace", f: parse_PtgAttrSpace },
        65: { n: "PtgAttrSpaceSemi", f: parse_PtgAttrSpaceSemi },
        128: { n: "PtgAttrIfError", f: parse_PtgAttrIfError },
        255: {}
      };
      function parse_RgbExtra(blob, length, rgce, opts) {
        if (opts.biff < 8)
          return parsenoop(blob, length);
        var target = blob.l + length;
        var o = [];
        for (var i = 0; i !== rgce.length; ++i) {
          switch (rgce[i][0]) {
            case "PtgArray":
              rgce[i][1] = parse_PtgExtraArray(blob, 0, opts);
              o.push(rgce[i][1]);
              break;
            case "PtgMemArea":
              rgce[i][2] = parse_PtgExtraMem(blob, rgce[i][1], opts);
              o.push(rgce[i][2]);
              break;
            case "PtgExp":
              if (opts && opts.biff == 12) {
                rgce[i][1][1] = blob.read_shift(4);
                o.push(rgce[i][1]);
              }
              break;
            case "PtgList":
            case "PtgElfRadicalS":
            case "PtgElfColS":
            case "PtgElfColSV":
              throw "Unsupported " + rgce[i][0];
            default:
              break;
          }
        }
        length = target - blob.l;
        if (length !== 0)
          o.push(parsenoop(blob, length));
        return o;
      }
      function parse_Rgce(blob, length, opts) {
        var target = blob.l + length;
        var R, id, ptgs = [];
        while (target != blob.l) {
          length = target - blob.l;
          id = blob[blob.l];
          R = PtgTypes[id] || PtgTypes[PtgDupes[id]];
          if (id === 24 || id === 25)
            R = (id === 24 ? Ptg18 : Ptg19)[blob[blob.l + 1]];
          if (!R || !R.f) {
            parsenoop(blob, length);
          } else {
            ptgs.push([R.n, R.f(blob, length, opts)]);
          }
        }
        return ptgs;
      }
      function stringify_array(f) {
        var o = [];
        for (var i = 0; i < f.length; ++i) {
          var x = f[i], r = [];
          for (var j = 0; j < x.length; ++j) {
            var y = x[j];
            if (y)
              switch (y[0]) {
                case 2:
                  r.push('"' + y[1].replace(/"/g, '""') + '"');
                  break;
                default:
                  r.push(y[1]);
              }
            else
              r.push("");
          }
          o.push(r.join(","));
        }
        return o.join(";");
      }
      var PtgBinOp = {
        PtgAdd: "+",
        PtgConcat: "&",
        PtgDiv: "/",
        PtgEq: "=",
        PtgGe: ">=",
        PtgGt: ">",
        PtgLe: "<=",
        PtgLt: "<",
        PtgMul: "*",
        PtgNe: "<>",
        PtgPower: "^",
        PtgSub: "-"
      };
      function formula_quote_sheet_name(sname, opts) {
        if (!sname && !(opts && opts.biff <= 5 && opts.biff >= 2))
          throw new Error("empty sheet name");
        if (/[^\w\u4E00-\u9FFF\u3040-\u30FF]/.test(sname))
          return "'" + sname + "'";
        return sname;
      }
      function get_ixti_raw(supbooks, ixti, opts) {
        if (!supbooks)
          return "SH33TJSERR0";
        if (opts.biff > 8 && (!supbooks.XTI || !supbooks.XTI[ixti]))
          return supbooks.SheetNames[ixti];
        if (!supbooks.XTI)
          return "SH33TJSERR6";
        var XTI = supbooks.XTI[ixti];
        if (opts.biff < 8) {
          if (ixti > 1e4)
            ixti -= 65536;
          if (ixti < 0)
            ixti = -ixti;
          return ixti == 0 ? "" : supbooks.XTI[ixti - 1];
        }
        if (!XTI)
          return "SH33TJSERR1";
        var o = "";
        if (opts.biff > 8)
          switch (supbooks[XTI[0]][0]) {
            case 357:
              o = XTI[1] == -1 ? "#REF" : supbooks.SheetNames[XTI[1]];
              return XTI[1] == XTI[2] ? o : o + ":" + supbooks.SheetNames[XTI[2]];
            case 358:
              if (opts.SID != null)
                return supbooks.SheetNames[opts.SID];
              return "SH33TJSSAME" + supbooks[XTI[0]][0];
            case 355:
            default:
              return "SH33TJSSRC" + supbooks[XTI[0]][0];
          }
        switch (supbooks[XTI[0]][0][0]) {
          case 1025:
            o = XTI[1] == -1 ? "#REF" : supbooks.SheetNames[XTI[1]] || "SH33TJSERR3";
            return XTI[1] == XTI[2] ? o : o + ":" + supbooks.SheetNames[XTI[2]];
          case 14849:
            return supbooks[XTI[0]].slice(1).map(function(name) {
              return name.Name;
            }).join(";;");
          default:
            if (!supbooks[XTI[0]][0][3])
              return "SH33TJSERR2";
            o = XTI[1] == -1 ? "#REF" : supbooks[XTI[0]][0][3][XTI[1]] || "SH33TJSERR4";
            return XTI[1] == XTI[2] ? o : o + ":" + supbooks[XTI[0]][0][3][XTI[2]];
        }
      }
      function get_ixti(supbooks, ixti, opts) {
        var ixtiraw = get_ixti_raw(supbooks, ixti, opts);
        return ixtiraw == "#REF" ? ixtiraw : formula_quote_sheet_name(ixtiraw, opts);
      }
      function stringify_formula(formula, range, cell, supbooks, opts) {
        var biff = opts && opts.biff || 8;
        var _range = (
          /*range != null ? range :*/
          { s: { c: 0, r: 0 }, e: { c: 0, r: 0 } }
        );
        var stack = [], e1, e2, c, ixti = 0, nameidx = 0, r, sname = "";
        if (!formula[0] || !formula[0][0])
          return "";
        var last_sp = -1, sp = "";
        for (var ff = 0, fflen = formula[0].length; ff < fflen; ++ff) {
          var f = formula[0][ff];
          switch (f[0]) {
            case "PtgUminus":
              stack.push("-" + stack.pop());
              break;
            case "PtgUplus":
              stack.push("+" + stack.pop());
              break;
            case "PtgPercent":
              stack.push(stack.pop() + "%");
              break;
            case "PtgAdd":
            case "PtgConcat":
            case "PtgDiv":
            case "PtgEq":
            case "PtgGe":
            case "PtgGt":
            case "PtgLe":
            case "PtgLt":
            case "PtgMul":
            case "PtgNe":
            case "PtgPower":
            case "PtgSub":
              e1 = stack.pop();
              e2 = stack.pop();
              if (last_sp >= 0) {
                switch (formula[0][last_sp][1][0]) {
                  case 0:
                    sp = fill(" ", formula[0][last_sp][1][1]);
                    break;
                  case 1:
                    sp = fill("\r", formula[0][last_sp][1][1]);
                    break;
                  default:
                    sp = "";
                    if (opts.WTF)
                      throw new Error("Unexpected PtgAttrSpaceType " + formula[0][last_sp][1][0]);
                }
                e2 = e2 + sp;
                last_sp = -1;
              }
              stack.push(e2 + PtgBinOp[f[0]] + e1);
              break;
            case "PtgIsect":
              e1 = stack.pop();
              e2 = stack.pop();
              stack.push(e2 + " " + e1);
              break;
            case "PtgUnion":
              e1 = stack.pop();
              e2 = stack.pop();
              stack.push(e2 + "," + e1);
              break;
            case "PtgRange":
              e1 = stack.pop();
              e2 = stack.pop();
              stack.push(e2 + ":" + e1);
              break;
            case "PtgAttrChoose":
              break;
            case "PtgAttrGoto":
              break;
            case "PtgAttrIf":
              break;
            case "PtgAttrIfError":
              break;
            case "PtgRef":
              c = shift_cell_xls(f[1][1], _range, opts);
              stack.push(encode_cell_xls(c, biff));
              break;
            case "PtgRefN":
              c = cell ? shift_cell_xls(f[1][1], cell, opts) : f[1][1];
              stack.push(encode_cell_xls(c, biff));
              break;
            case "PtgRef3d":
              ixti = f[1][1];
              c = shift_cell_xls(f[1][2], _range, opts);
              sname = get_ixti(supbooks, ixti, opts);
              var w = sname;
              stack.push(sname + "!" + encode_cell_xls(c, biff));
              break;
            case "PtgFunc":
            case "PtgFuncVar":
              var argc = f[1][0], func = f[1][1];
              if (!argc)
                argc = 0;
              argc &= 127;
              var args = argc == 0 ? [] : stack.slice(-argc);
              stack.length -= argc;
              if (func === "User")
                func = args.shift();
              stack.push(func + "(" + args.join(",") + ")");
              break;
            case "PtgBool":
              stack.push(f[1] ? "TRUE" : "FALSE");
              break;
            case "PtgInt":
              stack.push(f[1]);
              break;
            case "PtgNum":
              stack.push(String(f[1]));
              break;
            case "PtgStr":
              stack.push('"' + f[1].replace(/"/g, '""') + '"');
              break;
            case "PtgErr":
              stack.push(f[1]);
              break;
            case "PtgAreaN":
              r = shift_range_xls(f[1][1], cell ? { s: cell } : _range, opts);
              stack.push(encode_range_xls(r, opts));
              break;
            case "PtgArea":
              r = shift_range_xls(f[1][1], _range, opts);
              stack.push(encode_range_xls(r, opts));
              break;
            case "PtgArea3d":
              ixti = f[1][1];
              r = f[1][2];
              sname = get_ixti(supbooks, ixti, opts);
              stack.push(sname + "!" + encode_range_xls(r, opts));
              break;
            case "PtgAttrSum":
              stack.push("SUM(" + stack.pop() + ")");
              break;
            case "PtgAttrBaxcel":
            case "PtgAttrSemi":
              break;
            case "PtgName":
              nameidx = f[1][2];
              var lbl = (supbooks.names || [])[nameidx - 1] || (supbooks[0] || [])[nameidx];
              var name = lbl ? lbl.Name : "SH33TJSNAME" + String(nameidx);
              if (name && name.slice(0, 6) == "_xlfn." && !opts.xlfn)
                name = name.slice(6);
              stack.push(name);
              break;
            case "PtgNameX":
              var bookidx = f[1][1];
              nameidx = f[1][2];
              var externbook;
              if (opts.biff <= 5) {
                if (bookidx < 0)
                  bookidx = -bookidx;
                if (supbooks[bookidx])
                  externbook = supbooks[bookidx][nameidx];
              } else {
                var o = "";
                if (((supbooks[bookidx] || [])[0] || [])[0] == 14849) {
                } else if (((supbooks[bookidx] || [])[0] || [])[0] == 1025) {
                  if (supbooks[bookidx][nameidx] && supbooks[bookidx][nameidx].itab > 0) {
                    o = supbooks.SheetNames[supbooks[bookidx][nameidx].itab - 1] + "!";
                  }
                } else
                  o = supbooks.SheetNames[nameidx - 1] + "!";
                if (supbooks[bookidx] && supbooks[bookidx][nameidx])
                  o += supbooks[bookidx][nameidx].Name;
                else if (supbooks[0] && supbooks[0][nameidx])
                  o += supbooks[0][nameidx].Name;
                else {
                  var ixtidata = (get_ixti_raw(supbooks, bookidx, opts) || "").split(";;");
                  if (ixtidata[nameidx - 1])
                    o = ixtidata[nameidx - 1];
                  else
                    o += "SH33TJSERRX";
                }
                stack.push(o);
                break;
              }
              if (!externbook)
                externbook = { Name: "SH33TJSERRY" };
              stack.push(externbook.Name);
              break;
            case "PtgParen":
              var lp = "(", rp = ")";
              if (last_sp >= 0) {
                sp = "";
                switch (formula[0][last_sp][1][0]) {
                  case 2:
                    lp = fill(" ", formula[0][last_sp][1][1]) + lp;
                    break;
                  case 3:
                    lp = fill("\r", formula[0][last_sp][1][1]) + lp;
                    break;
                  case 4:
                    rp = fill(" ", formula[0][last_sp][1][1]) + rp;
                    break;
                  case 5:
                    rp = fill("\r", formula[0][last_sp][1][1]) + rp;
                    break;
                  default:
                    if (opts.WTF)
                      throw new Error("Unexpected PtgAttrSpaceType " + formula[0][last_sp][1][0]);
                }
                last_sp = -1;
              }
              stack.push(lp + stack.pop() + rp);
              break;
            case "PtgRefErr":
              stack.push("#REF!");
              break;
            case "PtgRefErr3d":
              stack.push("#REF!");
              break;
            case "PtgExp":
              c = { c: f[1][1], r: f[1][0] };
              var q = { c: cell.c, r: cell.r };
              if (supbooks.sharedf[encode_cell(c)]) {
                var parsedf = supbooks.sharedf[encode_cell(c)];
                stack.push(stringify_formula(parsedf, _range, q, supbooks, opts));
              } else {
                var fnd = false;
                for (e1 = 0; e1 != supbooks.arrayf.length; ++e1) {
                  e2 = supbooks.arrayf[e1];
                  if (c.c < e2[0].s.c || c.c > e2[0].e.c)
                    continue;
                  if (c.r < e2[0].s.r || c.r > e2[0].e.r)
                    continue;
                  stack.push(stringify_formula(e2[1], _range, q, supbooks, opts));
                  fnd = true;
                  break;
                }
                if (!fnd)
                  stack.push(f[1]);
              }
              break;
            case "PtgArray":
              stack.push("{" + stringify_array(f[1]) + "}");
              break;
            case "PtgMemArea":
              break;
            case "PtgAttrSpace":
            case "PtgAttrSpaceSemi":
              last_sp = ff;
              break;
            case "PtgTbl":
              break;
            case "PtgMemErr":
              break;
            case "PtgMissArg":
              stack.push("");
              break;
            case "PtgAreaErr":
              stack.push("#REF!");
              break;
            case "PtgAreaErr3d":
              stack.push("#REF!");
              break;
            case "PtgList":
              stack.push("Table" + f[1].idx + "[#" + f[1].rt + "]");
              break;
            case "PtgMemAreaN":
            case "PtgMemNoMemN":
            case "PtgAttrNoop":
            case "PtgSheet":
            case "PtgEndSheet":
              break;
            case "PtgMemFunc":
              break;
            case "PtgMemNoMem":
              break;
            case "PtgElfCol":
            case "PtgElfColS":
            case "PtgElfColSV":
            case "PtgElfColV":
            case "PtgElfLel":
            case "PtgElfRadical":
            case "PtgElfRadicalLel":
            case "PtgElfRadicalS":
            case "PtgElfRw":
            case "PtgElfRwV":
              throw new Error("Unsupported ELFs");
            case "PtgSxName":
              throw new Error("Unrecognized Formula Token: " + String(f));
            default:
              throw new Error("Unrecognized Formula Token: " + String(f));
          }
          var PtgNonDisp = ["PtgAttrSpace", "PtgAttrSpaceSemi", "PtgAttrGoto"];
          if (opts.biff != 3) {
            if (last_sp >= 0 && PtgNonDisp.indexOf(formula[0][ff][0]) == -1) {
              f = formula[0][last_sp];
              var _left = true;
              switch (f[1][0]) {
                case 4:
                  _left = false;
                case 0:
                  sp = fill(" ", f[1][1]);
                  break;
                case 5:
                  _left = false;
                case 1:
                  sp = fill("\r", f[1][1]);
                  break;
                default:
                  sp = "";
                  if (opts.WTF)
                    throw new Error("Unexpected PtgAttrSpaceType " + f[1][0]);
              }
              stack.push((_left ? sp : "") + stack.pop() + (_left ? "" : sp));
              last_sp = -1;
            }
          }
        }
        if (stack.length > 1 && opts.WTF)
          throw new Error("bad formula stack");
        return stack[0];
      }
      function parse_ArrayParsedFormula(blob, length, opts) {
        var target = blob.l + length, len = opts.biff == 2 ? 1 : 2;
        var rgcb, cce = blob.read_shift(len);
        if (cce == 65535)
          return [[], parsenoop(blob, length - 2)];
        var rgce = parse_Rgce(blob, cce, opts);
        if (length !== cce + len)
          rgcb = parse_RgbExtra(blob, length - cce - len, rgce, opts);
        blob.l = target;
        return [rgce, rgcb];
      }
      function parse_XLSCellParsedFormula(blob, length, opts) {
        var target = blob.l + length, len = opts.biff == 2 ? 1 : 2;
        var rgcb, cce = blob.read_shift(len);
        if (cce == 65535)
          return [[], parsenoop(blob, length - 2)];
        var rgce = parse_Rgce(blob, cce, opts);
        if (length !== cce + len)
          rgcb = parse_RgbExtra(blob, length - cce - len, rgce, opts);
        blob.l = target;
        return [rgce, rgcb];
      }
      function parse_NameParsedFormula(blob, length, opts, cce) {
        var target = blob.l + length;
        var rgce = parse_Rgce(blob, cce, opts);
        var rgcb;
        if (target !== blob.l)
          rgcb = parse_RgbExtra(blob, target - blob.l, rgce, opts);
        return [rgce, rgcb];
      }
      function parse_SharedParsedFormula(blob, length, opts) {
        var target = blob.l + length;
        var rgcb, cce = blob.read_shift(2);
        var rgce = parse_Rgce(blob, cce, opts);
        if (cce == 65535)
          return [[], parsenoop(blob, length - 2)];
        if (length !== cce + 2)
          rgcb = parse_RgbExtra(blob, target - cce - 2, rgce, opts);
        return [rgce, rgcb];
      }
      function parse_FormulaValue(blob) {
        var b;
        if (__readUInt16LE(blob, blob.l + 6) !== 65535)
          return [parse_Xnum(blob), "n"];
        switch (blob[blob.l]) {
          case 0:
            blob.l += 8;
            return ["String", "s"];
          case 1:
            b = blob[blob.l + 2] === 1;
            blob.l += 8;
            return [b, "b"];
          case 2:
            b = blob[blob.l + 2];
            blob.l += 8;
            return [b, "e"];
          case 3:
            blob.l += 8;
            return ["", "s"];
        }
        return [];
      }
      function write_FormulaValue(value2) {
        if (value2 == null) {
          var o = new_buf(8);
          o.write_shift(1, 3);
          o.write_shift(1, 0);
          o.write_shift(2, 0);
          o.write_shift(2, 0);
          o.write_shift(2, 65535);
          return o;
        } else if (typeof value2 == "number")
          return write_Xnum(value2);
        return write_Xnum(0);
      }
      function parse_Formula(blob, length, opts) {
        var end = blob.l + length;
        var cell = parse_XLSCell(blob, 6);
        if (opts.biff == 2)
          ++blob.l;
        var val = parse_FormulaValue(blob, 8);
        var flags = blob.read_shift(1);
        if (opts.biff != 2) {
          blob.read_shift(1);
          if (opts.biff >= 5) {
            blob.read_shift(4);
          }
        }
        var cbf = parse_XLSCellParsedFormula(blob, end - blob.l, opts);
        return { cell, val: val[0], formula: cbf, shared: flags >> 3 & 1, tt: val[1] };
      }
      function write_Formula(cell, R, C, opts, os) {
        var o1 = write_XLSCell(R, C, os);
        var o2 = write_FormulaValue(cell.v);
        var o3 = new_buf(6);
        var flags = 1 | 32;
        o3.write_shift(2, flags);
        o3.write_shift(4, 0);
        var bf = new_buf(cell.bf.length);
        for (var i = 0; i < cell.bf.length; ++i)
          bf[i] = cell.bf[i];
        var out = bconcat([o1, o2, o3, bf]);
        return out;
      }
      function parse_XLSBParsedFormula(data, length, opts) {
        var cce = data.read_shift(4);
        var rgce = parse_Rgce(data, cce, opts);
        var cb = data.read_shift(4);
        var rgcb = cb > 0 ? parse_RgbExtra(data, cb, rgce, opts) : null;
        return [rgce, rgcb];
      }
      var parse_XLSBArrayParsedFormula = parse_XLSBParsedFormula;
      var parse_XLSBCellParsedFormula = parse_XLSBParsedFormula;
      var parse_XLSBNameParsedFormula = parse_XLSBParsedFormula;
      var parse_XLSBSharedParsedFormula = parse_XLSBParsedFormula;
      var Cetab = {
        0: "BEEP",
        1: "OPEN",
        2: "OPEN.LINKS",
        3: "CLOSE.ALL",
        4: "SAVE",
        5: "SAVE.AS",
        6: "FILE.DELETE",
        7: "PAGE.SETUP",
        8: "PRINT",
        9: "PRINTER.SETUP",
        10: "QUIT",
        11: "NEW.WINDOW",
        12: "ARRANGE.ALL",
        13: "WINDOW.SIZE",
        14: "WINDOW.MOVE",
        15: "FULL",
        16: "CLOSE",
        17: "RUN",
        22: "SET.PRINT.AREA",
        23: "SET.PRINT.TITLES",
        24: "SET.PAGE.BREAK",
        25: "REMOVE.PAGE.BREAK",
        26: "FONT",
        27: "DISPLAY",
        28: "PROTECT.DOCUMENT",
        29: "PRECISION",
        30: "A1.R1C1",
        31: "CALCULATE.NOW",
        32: "CALCULATION",
        34: "DATA.FIND",
        35: "EXTRACT",
        36: "DATA.DELETE",
        37: "SET.DATABASE",
        38: "SET.CRITERIA",
        39: "SORT",
        40: "DATA.SERIES",
        41: "TABLE",
        42: "FORMAT.NUMBER",
        43: "ALIGNMENT",
        44: "STYLE",
        45: "BORDER",
        46: "CELL.PROTECTION",
        47: "COLUMN.WIDTH",
        48: "UNDO",
        49: "CUT",
        50: "COPY",
        51: "PASTE",
        52: "CLEAR",
        53: "PASTE.SPECIAL",
        54: "EDIT.DELETE",
        55: "INSERT",
        56: "FILL.RIGHT",
        57: "FILL.DOWN",
        61: "DEFINE.NAME",
        62: "CREATE.NAMES",
        63: "FORMULA.GOTO",
        64: "FORMULA.FIND",
        65: "SELECT.LAST.CELL",
        66: "SHOW.ACTIVE.CELL",
        67: "GALLERY.AREA",
        68: "GALLERY.BAR",
        69: "GALLERY.COLUMN",
        70: "GALLERY.LINE",
        71: "GALLERY.PIE",
        72: "GALLERY.SCATTER",
        73: "COMBINATION",
        74: "PREFERRED",
        75: "ADD.OVERLAY",
        76: "GRIDLINES",
        77: "SET.PREFERRED",
        78: "AXES",
        79: "LEGEND",
        80: "ATTACH.TEXT",
        81: "ADD.ARROW",
        82: "SELECT.CHART",
        83: "SELECT.PLOT.AREA",
        84: "PATTERNS",
        85: "MAIN.CHART",
        86: "OVERLAY",
        87: "SCALE",
        88: "FORMAT.LEGEND",
        89: "FORMAT.TEXT",
        90: "EDIT.REPEAT",
        91: "PARSE",
        92: "JUSTIFY",
        93: "HIDE",
        94: "UNHIDE",
        95: "WORKSPACE",
        96: "FORMULA",
        97: "FORMULA.FILL",
        98: "FORMULA.ARRAY",
        99: "DATA.FIND.NEXT",
        100: "DATA.FIND.PREV",
        101: "FORMULA.FIND.NEXT",
        102: "FORMULA.FIND.PREV",
        103: "ACTIVATE",
        104: "ACTIVATE.NEXT",
        105: "ACTIVATE.PREV",
        106: "UNLOCKED.NEXT",
        107: "UNLOCKED.PREV",
        108: "COPY.PICTURE",
        109: "SELECT",
        110: "DELETE.NAME",
        111: "DELETE.FORMAT",
        112: "VLINE",
        113: "HLINE",
        114: "VPAGE",
        115: "HPAGE",
        116: "VSCROLL",
        117: "HSCROLL",
        118: "ALERT",
        119: "NEW",
        120: "CANCEL.COPY",
        121: "SHOW.CLIPBOARD",
        122: "MESSAGE",
        124: "PASTE.LINK",
        125: "APP.ACTIVATE",
        126: "DELETE.ARROW",
        127: "ROW.HEIGHT",
        128: "FORMAT.MOVE",
        129: "FORMAT.SIZE",
        130: "FORMULA.REPLACE",
        131: "SEND.KEYS",
        132: "SELECT.SPECIAL",
        133: "APPLY.NAMES",
        134: "REPLACE.FONT",
        135: "FREEZE.PANES",
        136: "SHOW.INFO",
        137: "SPLIT",
        138: "ON.WINDOW",
        139: "ON.DATA",
        140: "DISABLE.INPUT",
        142: "OUTLINE",
        143: "LIST.NAMES",
        144: "FILE.CLOSE",
        145: "SAVE.WORKBOOK",
        146: "DATA.FORM",
        147: "COPY.CHART",
        148: "ON.TIME",
        149: "WAIT",
        150: "FORMAT.FONT",
        151: "FILL.UP",
        152: "FILL.LEFT",
        153: "DELETE.OVERLAY",
        155: "SHORT.MENUS",
        159: "SET.UPDATE.STATUS",
        161: "COLOR.PALETTE",
        162: "DELETE.STYLE",
        163: "WINDOW.RESTORE",
        164: "WINDOW.MAXIMIZE",
        166: "CHANGE.LINK",
        167: "CALCULATE.DOCUMENT",
        168: "ON.KEY",
        169: "APP.RESTORE",
        170: "APP.MOVE",
        171: "APP.SIZE",
        172: "APP.MINIMIZE",
        173: "APP.MAXIMIZE",
        174: "BRING.TO.FRONT",
        175: "SEND.TO.BACK",
        185: "MAIN.CHART.TYPE",
        186: "OVERLAY.CHART.TYPE",
        187: "SELECT.END",
        188: "OPEN.MAIL",
        189: "SEND.MAIL",
        190: "STANDARD.FONT",
        191: "CONSOLIDATE",
        192: "SORT.SPECIAL",
        193: "GALLERY.3D.AREA",
        194: "GALLERY.3D.COLUMN",
        195: "GALLERY.3D.LINE",
        196: "GALLERY.3D.PIE",
        197: "VIEW.3D",
        198: "GOAL.SEEK",
        199: "WORKGROUP",
        200: "FILL.GROUP",
        201: "UPDATE.LINK",
        202: "PROMOTE",
        203: "DEMOTE",
        204: "SHOW.DETAIL",
        206: "UNGROUP",
        207: "OBJECT.PROPERTIES",
        208: "SAVE.NEW.OBJECT",
        209: "SHARE",
        210: "SHARE.NAME",
        211: "DUPLICATE",
        212: "APPLY.STYLE",
        213: "ASSIGN.TO.OBJECT",
        214: "OBJECT.PROTECTION",
        215: "HIDE.OBJECT",
        216: "SET.EXTRACT",
        217: "CREATE.PUBLISHER",
        218: "SUBSCRIBE.TO",
        219: "ATTRIBUTES",
        220: "SHOW.TOOLBAR",
        222: "PRINT.PREVIEW",
        223: "EDIT.COLOR",
        224: "SHOW.LEVELS",
        225: "FORMAT.MAIN",
        226: "FORMAT.OVERLAY",
        227: "ON.RECALC",
        228: "EDIT.SERIES",
        229: "DEFINE.STYLE",
        240: "LINE.PRINT",
        243: "ENTER.DATA",
        249: "GALLERY.RADAR",
        250: "MERGE.STYLES",
        251: "EDITION.OPTIONS",
        252: "PASTE.PICTURE",
        253: "PASTE.PICTURE.LINK",
        254: "SPELLING",
        256: "ZOOM",
        259: "INSERT.OBJECT",
        260: "WINDOW.MINIMIZE",
        265: "SOUND.NOTE",
        266: "SOUND.PLAY",
        267: "FORMAT.SHAPE",
        268: "EXTEND.POLYGON",
        269: "FORMAT.AUTO",
        272: "GALLERY.3D.BAR",
        273: "GALLERY.3D.SURFACE",
        274: "FILL.AUTO",
        276: "CUSTOMIZE.TOOLBAR",
        277: "ADD.TOOL",
        278: "EDIT.OBJECT",
        279: "ON.DOUBLECLICK",
        280: "ON.ENTRY",
        281: "WORKBOOK.ADD",
        282: "WORKBOOK.MOVE",
        283: "WORKBOOK.COPY",
        284: "WORKBOOK.OPTIONS",
        285: "SAVE.WORKSPACE",
        288: "CHART.WIZARD",
        289: "DELETE.TOOL",
        290: "MOVE.TOOL",
        291: "WORKBOOK.SELECT",
        292: "WORKBOOK.ACTIVATE",
        293: "ASSIGN.TO.TOOL",
        295: "COPY.TOOL",
        296: "RESET.TOOL",
        297: "CONSTRAIN.NUMERIC",
        298: "PASTE.TOOL",
        302: "WORKBOOK.NEW",
        305: "SCENARIO.CELLS",
        306: "SCENARIO.DELETE",
        307: "SCENARIO.ADD",
        308: "SCENARIO.EDIT",
        309: "SCENARIO.SHOW",
        310: "SCENARIO.SHOW.NEXT",
        311: "SCENARIO.SUMMARY",
        312: "PIVOT.TABLE.WIZARD",
        313: "PIVOT.FIELD.PROPERTIES",
        314: "PIVOT.FIELD",
        315: "PIVOT.ITEM",
        316: "PIVOT.ADD.FIELDS",
        318: "OPTIONS.CALCULATION",
        319: "OPTIONS.EDIT",
        320: "OPTIONS.VIEW",
        321: "ADDIN.MANAGER",
        322: "MENU.EDITOR",
        323: "ATTACH.TOOLBARS",
        324: "VBAActivate",
        325: "OPTIONS.CHART",
        328: "VBA.INSERT.FILE",
        330: "VBA.PROCEDURE.DEFINITION",
        336: "ROUTING.SLIP",
        338: "ROUTE.DOCUMENT",
        339: "MAIL.LOGON",
        342: "INSERT.PICTURE",
        343: "EDIT.TOOL",
        344: "GALLERY.DOUGHNUT",
        350: "CHART.TREND",
        352: "PIVOT.ITEM.PROPERTIES",
        354: "WORKBOOK.INSERT",
        355: "OPTIONS.TRANSITION",
        356: "OPTIONS.GENERAL",
        370: "FILTER.ADVANCED",
        373: "MAIL.ADD.MAILER",
        374: "MAIL.DELETE.MAILER",
        375: "MAIL.REPLY",
        376: "MAIL.REPLY.ALL",
        377: "MAIL.FORWARD",
        378: "MAIL.NEXT.LETTER",
        379: "DATA.LABEL",
        380: "INSERT.TITLE",
        381: "FONT.PROPERTIES",
        382: "MACRO.OPTIONS",
        383: "WORKBOOK.HIDE",
        384: "WORKBOOK.UNHIDE",
        385: "WORKBOOK.DELETE",
        386: "WORKBOOK.NAME",
        388: "GALLERY.CUSTOM",
        390: "ADD.CHART.AUTOFORMAT",
        391: "DELETE.CHART.AUTOFORMAT",
        392: "CHART.ADD.DATA",
        393: "AUTO.OUTLINE",
        394: "TAB.ORDER",
        395: "SHOW.DIALOG",
        396: "SELECT.ALL",
        397: "UNGROUP.SHEETS",
        398: "SUBTOTAL.CREATE",
        399: "SUBTOTAL.REMOVE",
        400: "RENAME.OBJECT",
        412: "WORKBOOK.SCROLL",
        413: "WORKBOOK.NEXT",
        414: "WORKBOOK.PREV",
        415: "WORKBOOK.TAB.SPLIT",
        416: "FULL.SCREEN",
        417: "WORKBOOK.PROTECT",
        420: "SCROLLBAR.PROPERTIES",
        421: "PIVOT.SHOW.PAGES",
        422: "TEXT.TO.COLUMNS",
        423: "FORMAT.CHARTTYPE",
        424: "LINK.FORMAT",
        425: "TRACER.DISPLAY",
        430: "TRACER.NAVIGATE",
        431: "TRACER.CLEAR",
        432: "TRACER.ERROR",
        433: "PIVOT.FIELD.GROUP",
        434: "PIVOT.FIELD.UNGROUP",
        435: "CHECKBOX.PROPERTIES",
        436: "LABEL.PROPERTIES",
        437: "LISTBOX.PROPERTIES",
        438: "EDITBOX.PROPERTIES",
        439: "PIVOT.REFRESH",
        440: "LINK.COMBO",
        441: "OPEN.TEXT",
        442: "HIDE.DIALOG",
        443: "SET.DIALOG.FOCUS",
        444: "ENABLE.OBJECT",
        445: "PUSHBUTTON.PROPERTIES",
        446: "SET.DIALOG.DEFAULT",
        447: "FILTER",
        448: "FILTER.SHOW.ALL",
        449: "CLEAR.OUTLINE",
        450: "FUNCTION.WIZARD",
        451: "ADD.LIST.ITEM",
        452: "SET.LIST.ITEM",
        453: "REMOVE.LIST.ITEM",
        454: "SELECT.LIST.ITEM",
        455: "SET.CONTROL.VALUE",
        456: "SAVE.COPY.AS",
        458: "OPTIONS.LISTS.ADD",
        459: "OPTIONS.LISTS.DELETE",
        460: "SERIES.AXES",
        461: "SERIES.X",
        462: "SERIES.Y",
        463: "ERRORBAR.X",
        464: "ERRORBAR.Y",
        465: "FORMAT.CHART",
        466: "SERIES.ORDER",
        467: "MAIL.LOGOFF",
        468: "CLEAR.ROUTING.SLIP",
        469: "APP.ACTIVATE.MICROSOFT",
        470: "MAIL.EDIT.MAILER",
        471: "ON.SHEET",
        472: "STANDARD.WIDTH",
        473: "SCENARIO.MERGE",
        474: "SUMMARY.INFO",
        475: "FIND.FILE",
        476: "ACTIVE.CELL.FONT",
        477: "ENABLE.TIPWIZARD",
        478: "VBA.MAKE.ADDIN",
        480: "INSERTDATATABLE",
        481: "WORKGROUP.OPTIONS",
        482: "MAIL.SEND.MAILER",
        485: "AUTOCORRECT",
        489: "POST.DOCUMENT",
        491: "PICKLIST",
        493: "VIEW.SHOW",
        494: "VIEW.DEFINE",
        495: "VIEW.DELETE",
        509: "SHEET.BACKGROUND",
        510: "INSERT.MAP.OBJECT",
        511: "OPTIONS.MENONO",
        517: "MSOCHECKS",
        518: "NORMAL",
        519: "LAYOUT",
        520: "RM.PRINT.AREA",
        521: "CLEAR.PRINT.AREA",
        522: "ADD.PRINT.AREA",
        523: "MOVE.BRK",
        545: "HIDECURR.NOTE",
        546: "HIDEALL.NOTES",
        547: "DELETE.NOTE",
        548: "TRAVERSE.NOTES",
        549: "ACTIVATE.NOTES",
        620: "PROTECT.REVISIONS",
        621: "UNPROTECT.REVISIONS",
        647: "OPTIONS.ME",
        653: "WEB.PUBLISH",
        667: "NEWWEBQUERY",
        673: "PIVOT.TABLE.CHART",
        753: "OPTIONS.SAVE",
        755: "OPTIONS.SPELL",
        808: "HIDEALL.INKANNOTS"
      };
      var Ftab = {
        0: "COUNT",
        1: "IF",
        2: "ISNA",
        3: "ISERROR",
        4: "SUM",
        5: "AVERAGE",
        6: "MIN",
        7: "MAX",
        8: "ROW",
        9: "COLUMN",
        10: "NA",
        11: "NPV",
        12: "STDEV",
        13: "DOLLAR",
        14: "FIXED",
        15: "SIN",
        16: "COS",
        17: "TAN",
        18: "ATAN",
        19: "PI",
        20: "SQRT",
        21: "EXP",
        22: "LN",
        23: "LOG10",
        24: "ABS",
        25: "INT",
        26: "SIGN",
        27: "ROUND",
        28: "LOOKUP",
        29: "INDEX",
        30: "REPT",
        31: "MID",
        32: "LEN",
        33: "VALUE",
        34: "TRUE",
        35: "FALSE",
        36: "AND",
        37: "OR",
        38: "NOT",
        39: "MOD",
        40: "DCOUNT",
        41: "DSUM",
        42: "DAVERAGE",
        43: "DMIN",
        44: "DMAX",
        45: "DSTDEV",
        46: "VAR",
        47: "DVAR",
        48: "TEXT",
        49: "LINEST",
        50: "TREND",
        51: "LOGEST",
        52: "GROWTH",
        53: "GOTO",
        54: "HALT",
        55: "RETURN",
        56: "PV",
        57: "FV",
        58: "NPER",
        59: "PMT",
        60: "RATE",
        61: "MIRR",
        62: "IRR",
        63: "RAND",
        64: "MATCH",
        65: "DATE",
        66: "TIME",
        67: "DAY",
        68: "MONTH",
        69: "YEAR",
        70: "WEEKDAY",
        71: "HOUR",
        72: "MINUTE",
        73: "SECOND",
        74: "NOW",
        75: "AREAS",
        76: "ROWS",
        77: "COLUMNS",
        78: "OFFSET",
        79: "ABSREF",
        80: "RELREF",
        81: "ARGUMENT",
        82: "SEARCH",
        83: "TRANSPOSE",
        84: "ERROR",
        85: "STEP",
        86: "TYPE",
        87: "ECHO",
        88: "SET.NAME",
        89: "CALLER",
        90: "DEREF",
        91: "WINDOWS",
        92: "SERIES",
        93: "DOCUMENTS",
        94: "ACTIVE.CELL",
        95: "SELECTION",
        96: "RESULT",
        97: "ATAN2",
        98: "ASIN",
        99: "ACOS",
        100: "CHOOSE",
        101: "HLOOKUP",
        102: "VLOOKUP",
        103: "LINKS",
        104: "INPUT",
        105: "ISREF",
        106: "GET.FORMULA",
        107: "GET.NAME",
        108: "SET.VALUE",
        109: "LOG",
        110: "EXEC",
        111: "CHAR",
        112: "LOWER",
        113: "UPPER",
        114: "PROPER",
        115: "LEFT",
        116: "RIGHT",
        117: "EXACT",
        118: "TRIM",
        119: "REPLACE",
        120: "SUBSTITUTE",
        121: "CODE",
        122: "NAMES",
        123: "DIRECTORY",
        124: "FIND",
        125: "CELL",
        126: "ISERR",
        127: "ISTEXT",
        128: "ISNUMBER",
        129: "ISBLANK",
        130: "T",
        131: "N",
        132: "FOPEN",
        133: "FCLOSE",
        134: "FSIZE",
        135: "FREADLN",
        136: "FREAD",
        137: "FWRITELN",
        138: "FWRITE",
        139: "FPOS",
        140: "DATEVALUE",
        141: "TIMEVALUE",
        142: "SLN",
        143: "SYD",
        144: "DDB",
        145: "GET.DEF",
        146: "REFTEXT",
        147: "TEXTREF",
        148: "INDIRECT",
        149: "REGISTER",
        150: "CALL",
        151: "ADD.BAR",
        152: "ADD.MENU",
        153: "ADD.COMMAND",
        154: "ENABLE.COMMAND",
        155: "CHECK.COMMAND",
        156: "RENAME.COMMAND",
        157: "SHOW.BAR",
        158: "DELETE.MENU",
        159: "DELETE.COMMAND",
        160: "GET.CHART.ITEM",
        161: "DIALOG.BOX",
        162: "CLEAN",
        163: "MDETERM",
        164: "MINVERSE",
        165: "MMULT",
        166: "FILES",
        167: "IPMT",
        168: "PPMT",
        169: "COUNTA",
        170: "CANCEL.KEY",
        171: "FOR",
        172: "WHILE",
        173: "BREAK",
        174: "NEXT",
        175: "INITIATE",
        176: "REQUEST",
        177: "POKE",
        178: "EXECUTE",
        179: "TERMINATE",
        180: "RESTART",
        181: "HELP",
        182: "GET.BAR",
        183: "PRODUCT",
        184: "FACT",
        185: "GET.CELL",
        186: "GET.WORKSPACE",
        187: "GET.WINDOW",
        188: "GET.DOCUMENT",
        189: "DPRODUCT",
        190: "ISNONTEXT",
        191: "GET.NOTE",
        192: "NOTE",
        193: "STDEVP",
        194: "VARP",
        195: "DSTDEVP",
        196: "DVARP",
        197: "TRUNC",
        198: "ISLOGICAL",
        199: "DCOUNTA",
        200: "DELETE.BAR",
        201: "UNREGISTER",
        204: "USDOLLAR",
        205: "FINDB",
        206: "SEARCHB",
        207: "REPLACEB",
        208: "LEFTB",
        209: "RIGHTB",
        210: "MIDB",
        211: "LENB",
        212: "ROUNDUP",
        213: "ROUNDDOWN",
        214: "ASC",
        215: "DBCS",
        216: "RANK",
        219: "ADDRESS",
        220: "DAYS360",
        221: "TODAY",
        222: "VDB",
        223: "ELSE",
        224: "ELSE.IF",
        225: "END.IF",
        226: "FOR.CELL",
        227: "MEDIAN",
        228: "SUMPRODUCT",
        229: "SINH",
        230: "COSH",
        231: "TANH",
        232: "ASINH",
        233: "ACOSH",
        234: "ATANH",
        235: "DGET",
        236: "CREATE.OBJECT",
        237: "VOLATILE",
        238: "LAST.ERROR",
        239: "CUSTOM.UNDO",
        240: "CUSTOM.REPEAT",
        241: "FORMULA.CONVERT",
        242: "GET.LINK.INFO",
        243: "TEXT.BOX",
        244: "INFO",
        245: "GROUP",
        246: "GET.OBJECT",
        247: "DB",
        248: "PAUSE",
        251: "RESUME",
        252: "FREQUENCY",
        253: "ADD.TOOLBAR",
        254: "DELETE.TOOLBAR",
        255: "User",
        256: "RESET.TOOLBAR",
        257: "EVALUATE",
        258: "GET.TOOLBAR",
        259: "GET.TOOL",
        260: "SPELLING.CHECK",
        261: "ERROR.TYPE",
        262: "APP.TITLE",
        263: "WINDOW.TITLE",
        264: "SAVE.TOOLBAR",
        265: "ENABLE.TOOL",
        266: "PRESS.TOOL",
        267: "REGISTER.ID",
        268: "GET.WORKBOOK",
        269: "AVEDEV",
        270: "BETADIST",
        271: "GAMMALN",
        272: "BETAINV",
        273: "BINOMDIST",
        274: "CHIDIST",
        275: "CHIINV",
        276: "COMBIN",
        277: "CONFIDENCE",
        278: "CRITBINOM",
        279: "EVEN",
        280: "EXPONDIST",
        281: "FDIST",
        282: "FINV",
        283: "FISHER",
        284: "FISHERINV",
        285: "FLOOR",
        286: "GAMMADIST",
        287: "GAMMAINV",
        288: "CEILING",
        289: "HYPGEOMDIST",
        290: "LOGNORMDIST",
        291: "LOGINV",
        292: "NEGBINOMDIST",
        293: "NORMDIST",
        294: "NORMSDIST",
        295: "NORMINV",
        296: "NORMSINV",
        297: "STANDARDIZE",
        298: "ODD",
        299: "PERMUT",
        300: "POISSON",
        301: "TDIST",
        302: "WEIBULL",
        303: "SUMXMY2",
        304: "SUMX2MY2",
        305: "SUMX2PY2",
        306: "CHITEST",
        307: "CORREL",
        308: "COVAR",
        309: "FORECAST",
        310: "FTEST",
        311: "INTERCEPT",
        312: "PEARSON",
        313: "RSQ",
        314: "STEYX",
        315: "SLOPE",
        316: "TTEST",
        317: "PROB",
        318: "DEVSQ",
        319: "GEOMEAN",
        320: "HARMEAN",
        321: "SUMSQ",
        322: "KURT",
        323: "SKEW",
        324: "ZTEST",
        325: "LARGE",
        326: "SMALL",
        327: "QUARTILE",
        328: "PERCENTILE",
        329: "PERCENTRANK",
        330: "MODE",
        331: "TRIMMEAN",
        332: "TINV",
        334: "MOVIE.COMMAND",
        335: "GET.MOVIE",
        336: "CONCATENATE",
        337: "POWER",
        338: "PIVOT.ADD.DATA",
        339: "GET.PIVOT.TABLE",
        340: "GET.PIVOT.FIELD",
        341: "GET.PIVOT.ITEM",
        342: "RADIANS",
        343: "DEGREES",
        344: "SUBTOTAL",
        345: "SUMIF",
        346: "COUNTIF",
        347: "COUNTBLANK",
        348: "SCENARIO.GET",
        349: "OPTIONS.LISTS.GET",
        350: "ISPMT",
        351: "DATEDIF",
        352: "DATESTRING",
        353: "NUMBERSTRING",
        354: "ROMAN",
        355: "OPEN.DIALOG",
        356: "SAVE.DIALOG",
        357: "VIEW.GET",
        358: "GETPIVOTDATA",
        359: "HYPERLINK",
        360: "PHONETIC",
        361: "AVERAGEA",
        362: "MAXA",
        363: "MINA",
        364: "STDEVPA",
        365: "VARPA",
        366: "STDEVA",
        367: "VARA",
        368: "BAHTTEXT",
        369: "THAIDAYOFWEEK",
        370: "THAIDIGIT",
        371: "THAIMONTHOFYEAR",
        372: "THAINUMSOUND",
        373: "THAINUMSTRING",
        374: "THAISTRINGLENGTH",
        375: "ISTHAIDIGIT",
        376: "ROUNDBAHTDOWN",
        377: "ROUNDBAHTUP",
        378: "THAIYEAR",
        379: "RTD",
        380: "CUBEVALUE",
        381: "CUBEMEMBER",
        382: "CUBEMEMBERPROPERTY",
        383: "CUBERANKEDMEMBER",
        384: "HEX2BIN",
        385: "HEX2DEC",
        386: "HEX2OCT",
        387: "DEC2BIN",
        388: "DEC2HEX",
        389: "DEC2OCT",
        390: "OCT2BIN",
        391: "OCT2HEX",
        392: "OCT2DEC",
        393: "BIN2DEC",
        394: "BIN2OCT",
        395: "BIN2HEX",
        396: "IMSUB",
        397: "IMDIV",
        398: "IMPOWER",
        399: "IMABS",
        400: "IMSQRT",
        401: "IMLN",
        402: "IMLOG2",
        403: "IMLOG10",
        404: "IMSIN",
        405: "IMCOS",
        406: "IMEXP",
        407: "IMARGUMENT",
        408: "IMCONJUGATE",
        409: "IMAGINARY",
        410: "IMREAL",
        411: "COMPLEX",
        412: "IMSUM",
        413: "IMPRODUCT",
        414: "SERIESSUM",
        415: "FACTDOUBLE",
        416: "SQRTPI",
        417: "QUOTIENT",
        418: "DELTA",
        419: "GESTEP",
        420: "ISEVEN",
        421: "ISODD",
        422: "MROUND",
        423: "ERF",
        424: "ERFC",
        425: "BESSELJ",
        426: "BESSELK",
        427: "BESSELY",
        428: "BESSELI",
        429: "XIRR",
        430: "XNPV",
        431: "PRICEMAT",
        432: "YIELDMAT",
        433: "INTRATE",
        434: "RECEIVED",
        435: "DISC",
        436: "PRICEDISC",
        437: "YIELDDISC",
        438: "TBILLEQ",
        439: "TBILLPRICE",
        440: "TBILLYIELD",
        441: "PRICE",
        442: "YIELD",
        443: "DOLLARDE",
        444: "DOLLARFR",
        445: "NOMINAL",
        446: "EFFECT",
        447: "CUMPRINC",
        448: "CUMIPMT",
        449: "EDATE",
        450: "EOMONTH",
        451: "YEARFRAC",
        452: "COUPDAYBS",
        453: "COUPDAYS",
        454: "COUPDAYSNC",
        455: "COUPNCD",
        456: "COUPNUM",
        457: "COUPPCD",
        458: "DURATION",
        459: "MDURATION",
        460: "ODDLPRICE",
        461: "ODDLYIELD",
        462: "ODDFPRICE",
        463: "ODDFYIELD",
        464: "RANDBETWEEN",
        465: "WEEKNUM",
        466: "AMORDEGRC",
        467: "AMORLINC",
        468: "CONVERT",
        724: "SHEETJS",
        469: "ACCRINT",
        470: "ACCRINTM",
        471: "WORKDAY",
        472: "NETWORKDAYS",
        473: "GCD",
        474: "MULTINOMIAL",
        475: "LCM",
        476: "FVSCHEDULE",
        477: "CUBEKPIMEMBER",
        478: "CUBESET",
        479: "CUBESETCOUNT",
        480: "IFERROR",
        481: "COUNTIFS",
        482: "SUMIFS",
        483: "AVERAGEIF",
        484: "AVERAGEIFS"
      };
      var FtabArgc = {
        2: 1,
        3: 1,
        10: 0,
        15: 1,
        16: 1,
        17: 1,
        18: 1,
        19: 0,
        20: 1,
        21: 1,
        22: 1,
        23: 1,
        24: 1,
        25: 1,
        26: 1,
        27: 2,
        30: 2,
        31: 3,
        32: 1,
        33: 1,
        34: 0,
        35: 0,
        38: 1,
        39: 2,
        40: 3,
        41: 3,
        42: 3,
        43: 3,
        44: 3,
        45: 3,
        47: 3,
        48: 2,
        53: 1,
        61: 3,
        63: 0,
        65: 3,
        66: 3,
        67: 1,
        68: 1,
        69: 1,
        70: 1,
        71: 1,
        72: 1,
        73: 1,
        74: 0,
        75: 1,
        76: 1,
        77: 1,
        79: 2,
        80: 2,
        83: 1,
        85: 0,
        86: 1,
        89: 0,
        90: 1,
        94: 0,
        95: 0,
        97: 2,
        98: 1,
        99: 1,
        101: 3,
        102: 3,
        105: 1,
        106: 1,
        108: 2,
        111: 1,
        112: 1,
        113: 1,
        114: 1,
        117: 2,
        118: 1,
        119: 4,
        121: 1,
        126: 1,
        127: 1,
        128: 1,
        129: 1,
        130: 1,
        131: 1,
        133: 1,
        134: 1,
        135: 1,
        136: 2,
        137: 2,
        138: 2,
        140: 1,
        141: 1,
        142: 3,
        143: 4,
        144: 4,
        161: 1,
        162: 1,
        163: 1,
        164: 1,
        165: 2,
        172: 1,
        175: 2,
        176: 2,
        177: 3,
        178: 2,
        179: 1,
        184: 1,
        186: 1,
        189: 3,
        190: 1,
        195: 3,
        196: 3,
        197: 1,
        198: 1,
        199: 3,
        201: 1,
        207: 4,
        210: 3,
        211: 1,
        212: 2,
        213: 2,
        214: 1,
        215: 1,
        225: 0,
        229: 1,
        230: 1,
        231: 1,
        232: 1,
        233: 1,
        234: 1,
        235: 3,
        244: 1,
        247: 4,
        252: 2,
        257: 1,
        261: 1,
        271: 1,
        273: 4,
        274: 2,
        275: 2,
        276: 2,
        277: 3,
        278: 3,
        279: 1,
        280: 3,
        281: 3,
        282: 3,
        283: 1,
        284: 1,
        285: 2,
        286: 4,
        287: 3,
        288: 2,
        289: 4,
        290: 3,
        291: 3,
        292: 3,
        293: 4,
        294: 1,
        295: 3,
        296: 1,
        297: 3,
        298: 1,
        299: 2,
        300: 3,
        301: 3,
        302: 4,
        303: 2,
        304: 2,
        305: 2,
        306: 2,
        307: 2,
        308: 2,
        309: 3,
        310: 2,
        311: 2,
        312: 2,
        313: 2,
        314: 2,
        315: 2,
        316: 4,
        325: 2,
        326: 2,
        327: 2,
        328: 2,
        331: 2,
        332: 2,
        337: 2,
        342: 1,
        343: 1,
        346: 2,
        347: 1,
        350: 4,
        351: 3,
        352: 1,
        353: 2,
        360: 1,
        368: 1,
        369: 1,
        370: 1,
        371: 1,
        372: 1,
        373: 1,
        374: 1,
        375: 1,
        376: 1,
        377: 1,
        378: 1,
        382: 3,
        385: 1,
        392: 1,
        393: 1,
        396: 2,
        397: 2,
        398: 2,
        399: 1,
        400: 1,
        401: 1,
        402: 1,
        403: 1,
        404: 1,
        405: 1,
        406: 1,
        407: 1,
        408: 1,
        409: 1,
        410: 1,
        414: 4,
        415: 1,
        416: 1,
        417: 2,
        420: 1,
        421: 1,
        422: 2,
        424: 1,
        425: 2,
        426: 2,
        427: 2,
        428: 2,
        430: 3,
        438: 3,
        439: 3,
        440: 3,
        443: 2,
        444: 2,
        445: 2,
        446: 2,
        447: 6,
        448: 6,
        449: 2,
        450: 2,
        464: 2,
        468: 3,
        476: 2,
        479: 1,
        480: 2,
        65535: 0
      };
      function ods_to_csf_formula(f) {
        if (f.slice(0, 3) == "of:")
          f = f.slice(3);
        if (f.charCodeAt(0) == 61) {
          f = f.slice(1);
          if (f.charCodeAt(0) == 61)
            f = f.slice(1);
        }
        f = f.replace(/COM\.MICROSOFT\./g, "");
        f = f.replace(/\[((?:\.[A-Z]+[0-9]+)(?::\.[A-Z]+[0-9]+)?)\]/g, function($$, $1) {
          return $1.replace(/\./g, "");
        });
        f = f.replace(/\[.(#[A-Z]*[?!])\]/g, "$1");
        return f.replace(/[;~]/g, ",").replace(/\|/g, ";");
      }
      function csf_to_ods_formula(f) {
        var o = "of:=" + f.replace(crefregex, "$1[.$2$3$4$5]").replace(/\]:\[/g, ":");
        return o.replace(/;/g, "|").replace(/,/g, ";");
      }
      function ods_to_csf_3D(r) {
        var a = r.split(":");
        var s = a[0].split(".")[0];
        return [s, a[0].split(".")[1] + (a.length > 1 ? ":" + (a[1].split(".")[1] || a[1].split(".")[0]) : "")];
      }
      function csf_to_ods_3D(r) {
        return r.replace(/\./, "!");
      }
      var strs = {};
      var _ssfopts = {};
      var browser_has_Map = typeof Map !== "undefined";
      function get_sst_id(sst, str, rev) {
        var i = 0, len = sst.length;
        if (rev) {
          if (browser_has_Map ? rev.has(str) : Object.prototype.hasOwnProperty.call(rev, str)) {
            var revarr = browser_has_Map ? rev.get(str) : rev[str];
            for (; i < revarr.length; ++i) {
              if (sst[revarr[i]].t === str) {
                sst.Count++;
                return revarr[i];
              }
            }
          }
        } else
          for (; i < len; ++i) {
            if (sst[i].t === str) {
              sst.Count++;
              return i;
            }
          }
        sst[len] = { t: str };
        sst.Count++;
        sst.Unique++;
        if (rev) {
          if (browser_has_Map) {
            if (!rev.has(str))
              rev.set(str, []);
            rev.get(str).push(len);
          } else {
            if (!Object.prototype.hasOwnProperty.call(rev, str))
              rev[str] = [];
            rev[str].push(len);
          }
        }
        return len;
      }
      function col_obj_w(C, col) {
        var p = { min: C + 1, max: C + 1 };
        var wch = -1;
        if (col.MDW)
          MDW = col.MDW;
        if (col.width != null)
          p.customWidth = 1;
        else if (col.wpx != null)
          wch = px2char(col.wpx);
        else if (col.wch != null)
          wch = col.wch;
        if (wch > -1) {
          p.width = char2width(wch);
          p.customWidth = 1;
        } else if (col.width != null)
          p.width = col.width;
        if (col.hidden)
          p.hidden = true;
        if (col.level != null) {
          p.outlineLevel = p.level = col.level;
        }
        return p;
      }
      function default_margins(margins, mode) {
        if (!margins)
          return;
        var defs = [0.7, 0.7, 0.75, 0.75, 0.3, 0.3];
        if (mode == "xlml")
          defs = [1, 1, 1, 1, 0.5, 0.5];
        if (margins.left == null)
          margins.left = defs[0];
        if (margins.right == null)
          margins.right = defs[1];
        if (margins.top == null)
          margins.top = defs[2];
        if (margins.bottom == null)
          margins.bottom = defs[3];
        if (margins.header == null)
          margins.header = defs[4];
        if (margins.footer == null)
          margins.footer = defs[5];
      }
      function get_cell_style(styles, cell, opts) {
        var z = opts.revssf[cell.z != null ? cell.z : "General"];
        var i = 60, len = styles.length;
        if (z == null && opts.ssf) {
          for (; i < 392; ++i)
            if (opts.ssf[i] == null) {
              SSF_load(cell.z, i);
              opts.ssf[i] = cell.z;
              opts.revssf[cell.z] = z = i;
              break;
            }
        }
        for (i = 0; i != len; ++i)
          if (styles[i].numFmtId === z)
            return i;
        styles[len] = {
          numFmtId: z,
          fontId: 0,
          fillId: 0,
          borderId: 0,
          xfId: 0,
          applyNumberFormat: 1
        };
        return len;
      }
      function safe_format(p, fmtid, fillid, opts, themes, styles) {
        try {
          if (opts.cellNF)
            p.z = table_fmt[fmtid];
        } catch (e) {
          if (opts.WTF)
            throw e;
        }
        if (p.t === "z" && !opts.cellStyles)
          return;
        if (p.t === "d" && typeof p.v === "string")
          p.v = parseDate(p.v);
        if ((!opts || opts.cellText !== false) && p.t !== "z")
          try {
            if (table_fmt[fmtid] == null)
              SSF_load(SSFImplicit[fmtid] || "General", fmtid);
            if (p.t === "e")
              p.w = p.w || BErr[p.v];
            else if (fmtid === 0) {
              if (p.t === "n") {
                if ((p.v | 0) === p.v)
                  p.w = p.v.toString(10);
                else
                  p.w = SSF_general_num(p.v);
              } else if (p.t === "d") {
                var dd = datenum(p.v);
                if ((dd | 0) === dd)
                  p.w = dd.toString(10);
                else
                  p.w = SSF_general_num(dd);
              } else if (p.v === void 0)
                return "";
              else
                p.w = SSF_general(p.v, _ssfopts);
            } else if (p.t === "d")
              p.w = SSF_format(fmtid, datenum(p.v), _ssfopts);
            else
              p.w = SSF_format(fmtid, p.v, _ssfopts);
          } catch (e) {
            if (opts.WTF)
              throw e;
          }
        if (!opts.cellStyles)
          return;
        if (fillid != null)
          try {
            p.s = styles.Fills[fillid];
            if (p.s.fgColor && p.s.fgColor.theme && !p.s.fgColor.rgb) {
              p.s.fgColor.rgb = rgb_tint(themes.themeElements.clrScheme[p.s.fgColor.theme].rgb, p.s.fgColor.tint || 0);
              if (opts.WTF)
                p.s.fgColor.raw_rgb = themes.themeElements.clrScheme[p.s.fgColor.theme].rgb;
            }
            if (p.s.bgColor && p.s.bgColor.theme) {
              p.s.bgColor.rgb = rgb_tint(themes.themeElements.clrScheme[p.s.bgColor.theme].rgb, p.s.bgColor.tint || 0);
              if (opts.WTF)
                p.s.bgColor.raw_rgb = themes.themeElements.clrScheme[p.s.bgColor.theme].rgb;
            }
          } catch (e) {
            if (opts.WTF && styles.Fills)
              throw e;
          }
      }
      function check_ws(ws, sname, i) {
        if (ws && ws["!ref"]) {
          var range = safe_decode_range(ws["!ref"]);
          if (range.e.c < range.s.c || range.e.r < range.s.r)
            throw new Error("Bad range (" + i + "): " + ws["!ref"]);
        }
      }
      function parse_ws_xml_dim(ws, s) {
        var d = safe_decode_range(s);
        if (d.s.r <= d.e.r && d.s.c <= d.e.c && d.s.r >= 0 && d.s.c >= 0)
          ws["!ref"] = encode_range(d);
      }
      var mergecregex = /<(?:\w:)?mergeCell ref="[A-Z0-9:]+"\s*[\/]?>/g;
      var sheetdataregex = /<(?:\w+:)?sheetData[^>]*>([\s\S]*)<\/(?:\w+:)?sheetData>/;
      var hlinkregex = /<(?:\w:)?hyperlink [^>]*>/mg;
      var dimregex = /"(\w*:\w*)"/;
      var colregex = /<(?:\w:)?col\b[^>]*[\/]?>/g;
      var afregex = /<(?:\w:)?autoFilter[^>]*([\/]|>([\s\S]*)<\/(?:\w:)?autoFilter)>/g;
      var marginregex = /<(?:\w:)?pageMargins[^>]*\/>/g;
      var sheetprregex = /<(?:\w:)?sheetPr\b(?:[^>a-z][^>]*)?\/>/;
      var sheetprregex2 = /<(?:\w:)?sheetPr[^>]*(?:[\/]|>([\s\S]*)<\/(?:\w:)?sheetPr)>/;
      var svsregex = /<(?:\w:)?sheetViews[^>]*(?:[\/]|>([\s\S]*)<\/(?:\w:)?sheetViews)>/;
      function parse_ws_xml(data, opts, idx, rels, wb, themes, styles) {
        if (!data)
          return data;
        if (!rels)
          rels = { "!id": {} };
        if (DENSE != null && opts.dense == null)
          opts.dense = DENSE;
        var s = opts.dense ? [] : {};
        var refguess = { s: { r: 2e6, c: 2e6 }, e: { r: 0, c: 0 } };
        var data1 = "", data2 = "";
        var mtch = data.match(sheetdataregex);
        if (mtch) {
          data1 = data.slice(0, mtch.index);
          data2 = data.slice(mtch.index + mtch[0].length);
        } else
          data1 = data2 = data;
        var sheetPr = data1.match(sheetprregex);
        if (sheetPr)
          parse_ws_xml_sheetpr(sheetPr[0], s, wb, idx);
        else if (sheetPr = data1.match(sheetprregex2))
          parse_ws_xml_sheetpr2(sheetPr[0], sheetPr[1] || "", s, wb, idx, styles, themes);
        var ridx = (data1.match(/<(?:\w*:)?dimension/) || { index: -1 }).index;
        if (ridx > 0) {
          var ref = data1.slice(ridx, ridx + 50).match(dimregex);
          if (ref)
            parse_ws_xml_dim(s, ref[1]);
        }
        var svs = data1.match(svsregex);
        if (svs && svs[1])
          parse_ws_xml_sheetviews(svs[1], wb);
        var columns = [];
        if (opts.cellStyles) {
          var cols = data1.match(colregex);
          if (cols)
            parse_ws_xml_cols(columns, cols);
        }
        if (mtch)
          parse_ws_xml_data(mtch[1], s, opts, refguess, themes, styles);
        var afilter = data2.match(afregex);
        if (afilter)
          s["!autofilter"] = parse_ws_xml_autofilter(afilter[0]);
        var merges = [];
        var _merge = data2.match(mergecregex);
        if (_merge)
          for (ridx = 0; ridx != _merge.length; ++ridx)
            merges[ridx] = safe_decode_range(_merge[ridx].slice(_merge[ridx].indexOf('"') + 1));
        var hlink = data2.match(hlinkregex);
        if (hlink)
          parse_ws_xml_hlinks(s, hlink, rels);
        var margins = data2.match(marginregex);
        if (margins)
          s["!margins"] = parse_ws_xml_margins(parsexmltag(margins[0]));
        if (!s["!ref"] && refguess.e.c >= refguess.s.c && refguess.e.r >= refguess.s.r)
          s["!ref"] = encode_range(refguess);
        if (opts.sheetRows > 0 && s["!ref"]) {
          var tmpref = safe_decode_range(s["!ref"]);
          if (opts.sheetRows <= +tmpref.e.r) {
            tmpref.e.r = opts.sheetRows - 1;
            if (tmpref.e.r > refguess.e.r)
              tmpref.e.r = refguess.e.r;
            if (tmpref.e.r < tmpref.s.r)
              tmpref.s.r = tmpref.e.r;
            if (tmpref.e.c > refguess.e.c)
              tmpref.e.c = refguess.e.c;
            if (tmpref.e.c < tmpref.s.c)
              tmpref.s.c = tmpref.e.c;
            s["!fullref"] = s["!ref"];
            s["!ref"] = encode_range(tmpref);
          }
        }
        if (columns.length > 0)
          s["!cols"] = columns;
        if (merges.length > 0)
          s["!merges"] = merges;
        return s;
      }
      function write_ws_xml_merges(merges) {
        if (merges.length === 0)
          return "";
        var o = '<mergeCells count="' + merges.length + '">';
        for (var i = 0; i != merges.length; ++i)
          o += '<mergeCell ref="' + encode_range(merges[i]) + '"/>';
        return o + "</mergeCells>";
      }
      function parse_ws_xml_sheetpr(sheetPr, s, wb, idx) {
        var data = parsexmltag(sheetPr);
        if (!wb.Sheets[idx])
          wb.Sheets[idx] = {};
        if (data.codeName)
          wb.Sheets[idx].CodeName = unescapexml(utf8read(data.codeName));
      }
      function parse_ws_xml_sheetpr2(sheetPr, body, s, wb, idx) {
        parse_ws_xml_sheetpr(sheetPr.slice(0, sheetPr.indexOf(">")), s, wb, idx);
      }
      function write_ws_xml_sheetpr(ws, wb, idx, opts, o) {
        var needed = false;
        var props = {}, payload = null;
        if (opts.bookType !== "xlsx" && wb.vbaraw) {
          var cname = wb.SheetNames[idx];
          try {
            if (wb.Workbook)
              cname = wb.Workbook.Sheets[idx].CodeName || cname;
          } catch (e) {
          }
          needed = true;
          props.codeName = utf8write(escapexml(cname));
        }
        if (ws && ws["!outline"]) {
          var outlineprops = { summaryBelow: 1, summaryRight: 1 };
          if (ws["!outline"].above)
            outlineprops.summaryBelow = 0;
          if (ws["!outline"].left)
            outlineprops.summaryRight = 0;
          payload = (payload || "") + writextag("outlinePr", null, outlineprops);
        }
        if (!needed && !payload)
          return;
        o[o.length] = writextag("sheetPr", payload, props);
      }
      var sheetprot_deffalse = ["objects", "scenarios", "selectLockedCells", "selectUnlockedCells"];
      var sheetprot_deftrue = [
        "formatColumns",
        "formatRows",
        "formatCells",
        "insertColumns",
        "insertRows",
        "insertHyperlinks",
        "deleteColumns",
        "deleteRows",
        "sort",
        "autoFilter",
        "pivotTables"
      ];
      function write_ws_xml_protection(sp) {
        var o = { sheet: 1 };
        sheetprot_deffalse.forEach(function(n) {
          if (sp[n] != null && sp[n])
            o[n] = "1";
        });
        sheetprot_deftrue.forEach(function(n) {
          if (sp[n] != null && !sp[n])
            o[n] = "0";
        });
        if (sp.password)
          o.password = crypto_CreatePasswordVerifier_Method1(sp.password).toString(16).toUpperCase();
        return writextag("sheetProtection", null, o);
      }
      function parse_ws_xml_hlinks(s, data, rels) {
        var dense = Array.isArray(s);
        for (var i = 0; i != data.length; ++i) {
          var val = parsexmltag(utf8read(data[i]), true);
          if (!val.ref)
            return;
          var rel = ((rels || {})["!id"] || [])[val.id];
          if (rel) {
            val.Target = rel.Target;
            if (val.location)
              val.Target += "#" + unescapexml(val.location);
          } else {
            val.Target = "#" + unescapexml(val.location);
            rel = { Target: val.Target, TargetMode: "Internal" };
          }
          val.Rel = rel;
          if (val.tooltip) {
            val.Tooltip = val.tooltip;
            delete val.tooltip;
          }
          var rng = safe_decode_range(val.ref);
          for (var R = rng.s.r; R <= rng.e.r; ++R)
            for (var C = rng.s.c; C <= rng.e.c; ++C) {
              var addr = encode_cell({ c: C, r: R });
              if (dense) {
                if (!s[R])
                  s[R] = [];
                if (!s[R][C])
                  s[R][C] = { t: "z", v: void 0 };
                s[R][C].l = val;
              } else {
                if (!s[addr])
                  s[addr] = { t: "z", v: void 0 };
                s[addr].l = val;
              }
            }
        }
      }
      function parse_ws_xml_margins(margin) {
        var o = {};
        ["left", "right", "top", "bottom", "header", "footer"].forEach(function(k) {
          if (margin[k])
            o[k] = parseFloat(margin[k]);
        });
        return o;
      }
      function write_ws_xml_margins(margin) {
        default_margins(margin);
        return writextag("pageMargins", null, margin);
      }
      function parse_ws_xml_cols(columns, cols) {
        var seencol = false;
        for (var coli = 0; coli != cols.length; ++coli) {
          var coll = parsexmltag(cols[coli], true);
          if (coll.hidden)
            coll.hidden = parsexmlbool(coll.hidden);
          var colm = parseInt(coll.min, 10) - 1, colM = parseInt(coll.max, 10) - 1;
          if (coll.outlineLevel)
            coll.level = +coll.outlineLevel || 0;
          delete coll.min;
          delete coll.max;
          coll.width = +coll.width;
          if (!seencol && coll.width) {
            seencol = true;
            find_mdw_colw(coll.width);
          }
          process_col(coll);
          while (colm <= colM)
            columns[colm++] = dup(coll);
        }
      }
      function write_ws_xml_cols(ws, cols) {
        var o = ["<cols>"], col;
        for (var i = 0; i != cols.length; ++i) {
          if (!(col = cols[i]))
            continue;
          o[o.length] = writextag("col", null, col_obj_w(i, col));
        }
        o[o.length] = "</cols>";
        return o.join("");
      }
      function parse_ws_xml_autofilter(data) {
        var o = { ref: (data.match(/ref="([^"]*)"/) || [])[1] };
        return o;
      }
      function write_ws_xml_autofilter(data, ws, wb, idx) {
        var ref = typeof data.ref == "string" ? data.ref : encode_range(data.ref);
        if (!wb.Workbook)
          wb.Workbook = { Sheets: [] };
        if (!wb.Workbook.Names)
          wb.Workbook.Names = [];
        var names = wb.Workbook.Names;
        var range = decode_range(ref);
        if (range.s.r == range.e.r) {
          range.e.r = decode_range(ws["!ref"]).e.r;
          ref = encode_range(range);
        }
        for (var i = 0; i < names.length; ++i) {
          var name = names[i];
          if (name.Name != "_xlnm._FilterDatabase")
            continue;
          if (name.Sheet != idx)
            continue;
          name.Ref = "'" + wb.SheetNames[idx] + "'!" + ref;
          break;
        }
        if (i == names.length)
          names.push({ Name: "_xlnm._FilterDatabase", Sheet: idx, Ref: "'" + wb.SheetNames[idx] + "'!" + ref });
        return writextag("autoFilter", null, { ref });
      }
      var sviewregex = /<(?:\w:)?sheetView(?:[^>a-z][^>]*)?\/?>/;
      function parse_ws_xml_sheetviews(data, wb) {
        if (!wb.Views)
          wb.Views = [{}];
        (data.match(sviewregex) || []).forEach(function(r, i) {
          var tag = parsexmltag(r);
          if (!wb.Views[i])
            wb.Views[i] = {};
          if (+tag.zoomScale)
            wb.Views[i].zoom = +tag.zoomScale;
          if (parsexmlbool(tag.rightToLeft))
            wb.Views[i].RTL = true;
        });
      }
      function write_ws_xml_sheetviews(ws, opts, idx, wb) {
        var sview = { workbookViewId: "0" };
        if ((((wb || {}).Workbook || {}).Views || [])[0])
          sview.rightToLeft = wb.Workbook.Views[0].RTL ? "1" : "0";
        return writextag("sheetViews", writextag("sheetView", null, sview), {});
      }
      function write_ws_xml_cell(cell, ref, ws, opts) {
        if (cell.c)
          ws["!comments"].push([ref, cell.c]);
        if (cell.v === void 0 && typeof cell.f !== "string" || cell.t === "z" && !cell.f)
          return "";
        var vv = "";
        var oldt = cell.t, oldv = cell.v;
        if (cell.t !== "z")
          switch (cell.t) {
            case "b":
              vv = cell.v ? "1" : "0";
              break;
            case "n":
              vv = "" + cell.v;
              break;
            case "e":
              vv = BErr[cell.v];
              break;
            case "d":
              if (opts && opts.cellDates)
                vv = parseDate(cell.v, -1).toISOString();
              else {
                cell = dup(cell);
                cell.t = "n";
                vv = "" + (cell.v = datenum(parseDate(cell.v)));
              }
              if (typeof cell.z === "undefined")
                cell.z = table_fmt[14];
              break;
            default:
              vv = cell.v;
              break;
          }
        var v = writetag("v", escapexml(vv)), o = { r: ref };
        var os = get_cell_style(opts.cellXfs, cell, opts);
        if (os !== 0)
          o.s = os;
        switch (cell.t) {
          case "n":
            break;
          case "d":
            o.t = "d";
            break;
          case "b":
            o.t = "b";
            break;
          case "e":
            o.t = "e";
            break;
          case "z":
            break;
          default:
            if (cell.v == null) {
              delete cell.t;
              break;
            }
            if (cell.v.length > 32767)
              throw new Error("Text length must not exceed 32767 characters");
            if (opts && opts.bookSST) {
              v = writetag("v", "" + get_sst_id(opts.Strings, cell.v, opts.revStrings));
              o.t = "s";
              break;
            }
            o.t = "str";
            break;
        }
        if (cell.t != oldt) {
          cell.t = oldt;
          cell.v = oldv;
        }
        if (typeof cell.f == "string" && cell.f) {
          var ff = cell.F && cell.F.slice(0, ref.length) == ref ? { t: "array", ref: cell.F } : null;
          v = writextag("f", escapexml(cell.f), ff) + (cell.v != null ? v : "");
        }
        if (cell.l)
          ws["!links"].push([ref, cell.l]);
        if (cell.D)
          o.cm = 1;
        return writextag("c", v, o);
      }
      var parse_ws_xml_data = function() {
        var cellregex = /<(?:\w+:)?c[ \/>]/, rowregex = /<\/(?:\w+:)?row>/;
        var rregex = /r=["']([^"']*)["']/, isregex = /<(?:\w+:)?is>([\S\s]*?)<\/(?:\w+:)?is>/;
        var refregex = /ref=["']([^"']*)["']/;
        var match_v = matchtag("v"), match_f = matchtag("f");
        return function parse_ws_xml_data2(sdata, s, opts, guess, themes, styles) {
          var ri = 0, x = "", cells = [], cref = [], idx = 0, i = 0, cc = 0, d = "", p;
          var tag, tagr = 0, tagc = 0;
          var sstr, ftag;
          var fmtid = 0, fillid = 0;
          var do_format = Array.isArray(styles.CellXf), cf;
          var arrayf = [];
          var sharedf = [];
          var dense = Array.isArray(s);
          var rows = [], rowobj = {}, rowrite = false;
          var sheetStubs = !!opts.sheetStubs;
          for (var marr = sdata.split(rowregex), mt = 0, marrlen = marr.length; mt != marrlen; ++mt) {
            x = marr[mt].trim();
            var xlen = x.length;
            if (xlen === 0)
              continue;
            var rstarti = 0;
            outa:
              for (ri = 0; ri < xlen; ++ri)
                switch (
                  /*x.charCodeAt(ri)*/
                  x[ri]
                ) {
                  case ">":
                    if (
                      /*x.charCodeAt(ri-1) != 47*/
                      x[ri - 1] != "/"
                    ) {
                      ++ri;
                      break outa;
                    }
                    if (opts && opts.cellStyles) {
                      tag = parsexmltag(x.slice(rstarti, ri), true);
                      tagr = tag.r != null ? parseInt(tag.r, 10) : tagr + 1;
                      tagc = -1;
                      if (opts.sheetRows && opts.sheetRows < tagr)
                        continue;
                      rowobj = {};
                      rowrite = false;
                      if (tag.ht) {
                        rowrite = true;
                        rowobj.hpt = parseFloat(tag.ht);
                        rowobj.hpx = pt2px(rowobj.hpt);
                      }
                      if (tag.hidden == "1") {
                        rowrite = true;
                        rowobj.hidden = true;
                      }
                      if (tag.outlineLevel != null) {
                        rowrite = true;
                        rowobj.level = +tag.outlineLevel;
                      }
                      if (rowrite)
                        rows[tagr - 1] = rowobj;
                    }
                    break;
                  case "<":
                    rstarti = ri;
                    break;
                }
            if (rstarti >= ri)
              break;
            tag = parsexmltag(x.slice(rstarti, ri), true);
            tagr = tag.r != null ? parseInt(tag.r, 10) : tagr + 1;
            tagc = -1;
            if (opts.sheetRows && opts.sheetRows < tagr)
              continue;
            if (guess.s.r > tagr - 1)
              guess.s.r = tagr - 1;
            if (guess.e.r < tagr - 1)
              guess.e.r = tagr - 1;
            if (opts && opts.cellStyles) {
              rowobj = {};
              rowrite = false;
              if (tag.ht) {
                rowrite = true;
                rowobj.hpt = parseFloat(tag.ht);
                rowobj.hpx = pt2px(rowobj.hpt);
              }
              if (tag.hidden == "1") {
                rowrite = true;
                rowobj.hidden = true;
              }
              if (tag.outlineLevel != null) {
                rowrite = true;
                rowobj.level = +tag.outlineLevel;
              }
              if (rowrite)
                rows[tagr - 1] = rowobj;
            }
            cells = x.slice(ri).split(cellregex);
            for (var rslice = 0; rslice != cells.length; ++rslice)
              if (cells[rslice].trim().charAt(0) != "<")
                break;
            cells = cells.slice(rslice);
            for (ri = 0; ri != cells.length; ++ri) {
              x = cells[ri].trim();
              if (x.length === 0)
                continue;
              cref = x.match(rregex);
              idx = ri;
              i = 0;
              cc = 0;
              x = "<c " + (x.slice(0, 1) == "<" ? ">" : "") + x;
              if (cref != null && cref.length === 2) {
                idx = 0;
                d = cref[1];
                for (i = 0; i != d.length; ++i) {
                  if ((cc = d.charCodeAt(i) - 64) < 1 || cc > 26)
                    break;
                  idx = 26 * idx + cc;
                }
                --idx;
                tagc = idx;
              } else
                ++tagc;
              for (i = 0; i != x.length; ++i)
                if (x.charCodeAt(i) === 62)
                  break;
              ++i;
              tag = parsexmltag(x.slice(0, i), true);
              if (!tag.r)
                tag.r = encode_cell({ r: tagr - 1, c: tagc });
              d = x.slice(i);
              p = { t: "" };
              if ((cref = d.match(match_v)) != null && cref[1] !== "")
                p.v = unescapexml(cref[1]);
              if (opts.cellFormula) {
                if ((cref = d.match(match_f)) != null && cref[1] !== "") {
                  p.f = unescapexml(utf8read(cref[1])).replace(/\r\n/g, "\n");
                  if (!opts.xlfn)
                    p.f = _xlfn(p.f);
                  if (cref[0].indexOf('t="array"') > -1) {
                    p.F = (d.match(refregex) || [])[1];
                    if (p.F.indexOf(":") > -1)
                      arrayf.push([safe_decode_range(p.F), p.F]);
                  } else if (cref[0].indexOf('t="shared"') > -1) {
                    ftag = parsexmltag(cref[0]);
                    var ___f = unescapexml(utf8read(cref[1]));
                    if (!opts.xlfn)
                      ___f = _xlfn(___f);
                    sharedf[parseInt(ftag.si, 10)] = [ftag, ___f, tag.r];
                  }
                } else if (cref = d.match(/<f[^>]*\/>/)) {
                  ftag = parsexmltag(cref[0]);
                  if (sharedf[ftag.si])
                    p.f = shift_formula_xlsx(sharedf[ftag.si][1], sharedf[ftag.si][2], tag.r);
                }
                var _tag = decode_cell(tag.r);
                for (i = 0; i < arrayf.length; ++i)
                  if (_tag.r >= arrayf[i][0].s.r && _tag.r <= arrayf[i][0].e.r) {
                    if (_tag.c >= arrayf[i][0].s.c && _tag.c <= arrayf[i][0].e.c)
                      p.F = arrayf[i][1];
                  }
              }
              if (tag.t == null && p.v === void 0) {
                if (p.f || p.F) {
                  p.v = 0;
                  p.t = "n";
                } else if (!sheetStubs)
                  continue;
                else
                  p.t = "z";
              } else
                p.t = tag.t || "n";
              if (guess.s.c > tagc)
                guess.s.c = tagc;
              if (guess.e.c < tagc)
                guess.e.c = tagc;
              switch (p.t) {
                case "n":
                  if (p.v == "" || p.v == null) {
                    if (!sheetStubs)
                      continue;
                    p.t = "z";
                  } else
                    p.v = parseFloat(p.v);
                  break;
                case "s":
                  if (typeof p.v == "undefined") {
                    if (!sheetStubs)
                      continue;
                    p.t = "z";
                  } else {
                    sstr = strs[parseInt(p.v, 10)];
                    p.v = sstr.t;
                    p.r = sstr.r;
                    if (opts.cellHTML)
                      p.h = sstr.h;
                  }
                  break;
                case "str":
                  p.t = "s";
                  p.v = p.v != null ? utf8read(p.v) : "";
                  if (opts.cellHTML)
                    p.h = escapehtml(p.v);
                  break;
                case "inlineStr":
                  cref = d.match(isregex);
                  p.t = "s";
                  if (cref != null && (sstr = parse_si(cref[1]))) {
                    p.v = sstr.t;
                    if (opts.cellHTML)
                      p.h = sstr.h;
                  } else
                    p.v = "";
                  break;
                case "b":
                  p.v = parsexmlbool(p.v);
                  break;
                case "d":
                  if (opts.cellDates)
                    p.v = parseDate(p.v, 1);
                  else {
                    p.v = datenum(parseDate(p.v, 1));
                    p.t = "n";
                  }
                  break;
                case "e":
                  if (!opts || opts.cellText !== false)
                    p.w = p.v;
                  p.v = RBErr[p.v];
                  break;
              }
              fmtid = fillid = 0;
              cf = null;
              if (do_format && tag.s !== void 0) {
                cf = styles.CellXf[tag.s];
                if (cf != null) {
                  if (cf.numFmtId != null)
                    fmtid = cf.numFmtId;
                  if (opts.cellStyles) {
                    if (cf.fillId != null)
                      fillid = cf.fillId;
                  }
                }
              }
              safe_format(p, fmtid, fillid, opts, themes, styles);
              if (opts.cellDates && do_format && p.t == "n" && fmt_is_date(table_fmt[fmtid])) {
                p.t = "d";
                p.v = numdate(p.v);
              }
              if (tag.cm && opts.xlmeta) {
                var cm = (opts.xlmeta.Cell || [])[+tag.cm - 1];
                if (cm && cm.type == "XLDAPR")
                  p.D = true;
              }
              if (dense) {
                var _r = decode_cell(tag.r);
                if (!s[_r.r])
                  s[_r.r] = [];
                s[_r.r][_r.c] = p;
              } else
                s[tag.r] = p;
            }
          }
          if (rows.length > 0)
            s["!rows"] = rows;
        };
      }();
      function write_ws_xml_data(ws, opts, idx, wb) {
        var o = [], r = [], range = safe_decode_range(ws["!ref"]), cell = "", ref, rr = "", cols = [], R = 0, C = 0, rows = ws["!rows"];
        var dense = Array.isArray(ws);
        var params = { r: rr }, row, height = -1;
        for (C = range.s.c; C <= range.e.c; ++C)
          cols[C] = encode_col(C);
        for (R = range.s.r; R <= range.e.r; ++R) {
          r = [];
          rr = encode_row(R);
          for (C = range.s.c; C <= range.e.c; ++C) {
            ref = cols[C] + rr;
            var _cell = dense ? (ws[R] || [])[C] : ws[ref];
            if (_cell === void 0)
              continue;
            if ((cell = write_ws_xml_cell(_cell, ref, ws, opts, idx, wb)) != null)
              r.push(cell);
          }
          if (r.length > 0 || rows && rows[R]) {
            params = { r: rr };
            if (rows && rows[R]) {
              row = rows[R];
              if (row.hidden)
                params.hidden = 1;
              height = -1;
              if (row.hpx)
                height = px2pt(row.hpx);
              else if (row.hpt)
                height = row.hpt;
              if (height > -1) {
                params.ht = height;
                params.customHeight = 1;
              }
              if (row.level) {
                params.outlineLevel = row.level;
              }
            }
            o[o.length] = writextag("row", r.join(""), params);
          }
        }
        if (rows)
          for (; R < rows.length; ++R) {
            if (rows && rows[R]) {
              params = { r: R + 1 };
              row = rows[R];
              if (row.hidden)
                params.hidden = 1;
              height = -1;
              if (row.hpx)
                height = px2pt(row.hpx);
              else if (row.hpt)
                height = row.hpt;
              if (height > -1) {
                params.ht = height;
                params.customHeight = 1;
              }
              if (row.level) {
                params.outlineLevel = row.level;
              }
              o[o.length] = writextag("row", "", params);
            }
          }
        return o.join("");
      }
      function write_ws_xml(idx, opts, wb, rels) {
        var o = [XML_HEADER, writextag("worksheet", null, {
          "xmlns": XMLNS_main[0],
          "xmlns:r": XMLNS.r
        })];
        var s = wb.SheetNames[idx], sidx = 0, rdata = "";
        var ws = wb.Sheets[s];
        if (ws == null)
          ws = {};
        var ref = ws["!ref"] || "A1";
        var range = safe_decode_range(ref);
        if (range.e.c > 16383 || range.e.r > 1048575) {
          if (opts.WTF)
            throw new Error("Range " + ref + " exceeds format limit A1:XFD1048576");
          range.e.c = Math.min(range.e.c, 16383);
          range.e.r = Math.min(range.e.c, 1048575);
          ref = encode_range(range);
        }
        if (!rels)
          rels = {};
        ws["!comments"] = [];
        var _drawing = [];
        write_ws_xml_sheetpr(ws, wb, idx, opts, o);
        o[o.length] = writextag("dimension", null, { "ref": ref });
        o[o.length] = write_ws_xml_sheetviews(ws, opts, idx, wb);
        if (opts.sheetFormat)
          o[o.length] = writextag("sheetFormatPr", null, {
            defaultRowHeight: opts.sheetFormat.defaultRowHeight || "16",
            baseColWidth: opts.sheetFormat.baseColWidth || "10",
            outlineLevelRow: opts.sheetFormat.outlineLevelRow || "7"
          });
        if (ws["!cols"] != null && ws["!cols"].length > 0)
          o[o.length] = write_ws_xml_cols(ws, ws["!cols"]);
        o[sidx = o.length] = "<sheetData/>";
        ws["!links"] = [];
        if (ws["!ref"] != null) {
          rdata = write_ws_xml_data(ws, opts, idx, wb, rels);
          if (rdata.length > 0)
            o[o.length] = rdata;
        }
        if (o.length > sidx + 1) {
          o[o.length] = "</sheetData>";
          o[sidx] = o[sidx].replace("/>", ">");
        }
        if (ws["!protect"])
          o[o.length] = write_ws_xml_protection(ws["!protect"]);
        if (ws["!autofilter"] != null)
          o[o.length] = write_ws_xml_autofilter(ws["!autofilter"], ws, wb, idx);
        if (ws["!merges"] != null && ws["!merges"].length > 0)
          o[o.length] = write_ws_xml_merges(ws["!merges"]);
        var relc = -1, rel, rId = -1;
        if (ws["!links"].length > 0) {
          o[o.length] = "<hyperlinks>";
          ws["!links"].forEach(function(l) {
            if (!l[1].Target)
              return;
            rel = { "ref": l[0] };
            if (l[1].Target.charAt(0) != "#") {
              rId = add_rels(rels, -1, escapexml(l[1].Target).replace(/#.*$/, ""), RELS.HLINK);
              rel["r:id"] = "rId" + rId;
            }
            if ((relc = l[1].Target.indexOf("#")) > -1)
              rel.location = escapexml(l[1].Target.slice(relc + 1));
            if (l[1].Tooltip)
              rel.tooltip = escapexml(l[1].Tooltip);
            o[o.length] = writextag("hyperlink", null, rel);
          });
          o[o.length] = "</hyperlinks>";
        }
        delete ws["!links"];
        if (ws["!margins"] != null)
          o[o.length] = write_ws_xml_margins(ws["!margins"]);
        if (!opts || opts.ignoreEC || opts.ignoreEC == void 0)
          o[o.length] = writetag("ignoredErrors", writextag("ignoredError", null, { numberStoredAsText: 1, sqref: ref }));
        if (_drawing.length > 0) {
          rId = add_rels(rels, -1, "../drawings/drawing" + (idx + 1) + ".xml", RELS.DRAW);
          o[o.length] = writextag("drawing", null, { "r:id": "rId" + rId });
          ws["!drawing"] = _drawing;
        }
        if (ws["!comments"].length > 0) {
          rId = add_rels(rels, -1, "../drawings/vmlDrawing" + (idx + 1) + ".vml", RELS.VML);
          o[o.length] = writextag("legacyDrawing", null, { "r:id": "rId" + rId });
          ws["!legacy"] = rId;
        }
        if (o.length > 1) {
          o[o.length] = "</worksheet>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_BrtRowHdr(data, length) {
        var z = {};
        var tgt = data.l + length;
        z.r = data.read_shift(4);
        data.l += 4;
        var miyRw = data.read_shift(2);
        data.l += 1;
        var flags = data.read_shift(1);
        data.l = tgt;
        if (flags & 7)
          z.level = flags & 7;
        if (flags & 16)
          z.hidden = true;
        if (flags & 32)
          z.hpt = miyRw / 20;
        return z;
      }
      function write_BrtRowHdr(R, range, ws) {
        var o = new_buf(17 + 8 * 16);
        var row = (ws["!rows"] || [])[R] || {};
        o.write_shift(4, R);
        o.write_shift(4, 0);
        var miyRw = 320;
        if (row.hpx)
          miyRw = px2pt(row.hpx) * 20;
        else if (row.hpt)
          miyRw = row.hpt * 20;
        o.write_shift(2, miyRw);
        o.write_shift(1, 0);
        var flags = 0;
        if (row.level)
          flags |= row.level;
        if (row.hidden)
          flags |= 16;
        if (row.hpx || row.hpt)
          flags |= 32;
        o.write_shift(1, flags);
        o.write_shift(1, 0);
        var ncolspan = 0, lcs = o.l;
        o.l += 4;
        var caddr = { r: R, c: 0 };
        for (var i = 0; i < 16; ++i) {
          if (range.s.c > i + 1 << 10 || range.e.c < i << 10)
            continue;
          var first2 = -1, last2 = -1;
          for (var j = i << 10; j < i + 1 << 10; ++j) {
            caddr.c = j;
            var cell = Array.isArray(ws) ? (ws[caddr.r] || [])[caddr.c] : ws[encode_cell(caddr)];
            if (cell) {
              if (first2 < 0)
                first2 = j;
              last2 = j;
            }
          }
          if (first2 < 0)
            continue;
          ++ncolspan;
          o.write_shift(4, first2);
          o.write_shift(4, last2);
        }
        var l = o.l;
        o.l = lcs;
        o.write_shift(4, ncolspan);
        o.l = l;
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function write_row_header(ba, ws, range, R) {
        var o = write_BrtRowHdr(R, range, ws);
        if (o.length > 17 || (ws["!rows"] || [])[R])
          write_record(ba, 0, o);
      }
      var parse_BrtWsDim = parse_UncheckedRfX;
      var write_BrtWsDim = write_UncheckedRfX;
      function parse_BrtWsFmtInfo() {
      }
      function parse_BrtWsProp(data, length) {
        var z = {};
        var f = data[data.l];
        ++data.l;
        z.above = !(f & 64);
        z.left = !(f & 128);
        data.l += 18;
        z.name = parse_XLSBCodeName(data, length - 19);
        return z;
      }
      function write_BrtWsProp(str, outl, o) {
        if (o == null)
          o = new_buf(84 + 4 * str.length);
        var f = 192;
        if (outl) {
          if (outl.above)
            f &= ~64;
          if (outl.left)
            f &= ~128;
        }
        o.write_shift(1, f);
        for (var i = 1; i < 3; ++i)
          o.write_shift(1, 0);
        write_BrtColor({ auto: 1 }, o);
        o.write_shift(-4, -1);
        o.write_shift(-4, -1);
        write_XLSBCodeName(str, o);
        return o.slice(0, o.l);
      }
      function parse_BrtCellBlank(data) {
        var cell = parse_XLSBCell(data);
        return [cell];
      }
      function write_BrtCellBlank(cell, ncell, o) {
        if (o == null)
          o = new_buf(8);
        return write_XLSBCell(ncell, o);
      }
      function parse_BrtShortBlank(data) {
        var cell = parse_XLSBShortCell(data);
        return [cell];
      }
      function write_BrtShortBlank(cell, ncell, o) {
        if (o == null)
          o = new_buf(4);
        return write_XLSBShortCell(ncell, o);
      }
      function parse_BrtCellBool(data) {
        var cell = parse_XLSBCell(data);
        var fBool = data.read_shift(1);
        return [cell, fBool, "b"];
      }
      function write_BrtCellBool(cell, ncell, o) {
        if (o == null)
          o = new_buf(9);
        write_XLSBCell(ncell, o);
        o.write_shift(1, cell.v ? 1 : 0);
        return o;
      }
      function parse_BrtShortBool(data) {
        var cell = parse_XLSBShortCell(data);
        var fBool = data.read_shift(1);
        return [cell, fBool, "b"];
      }
      function write_BrtShortBool(cell, ncell, o) {
        if (o == null)
          o = new_buf(5);
        write_XLSBShortCell(ncell, o);
        o.write_shift(1, cell.v ? 1 : 0);
        return o;
      }
      function parse_BrtCellError(data) {
        var cell = parse_XLSBCell(data);
        var bError = data.read_shift(1);
        return [cell, bError, "e"];
      }
      function write_BrtCellError(cell, ncell, o) {
        if (o == null)
          o = new_buf(9);
        write_XLSBCell(ncell, o);
        o.write_shift(1, cell.v);
        return o;
      }
      function parse_BrtShortError(data) {
        var cell = parse_XLSBShortCell(data);
        var bError = data.read_shift(1);
        return [cell, bError, "e"];
      }
      function write_BrtShortError(cell, ncell, o) {
        if (o == null)
          o = new_buf(8);
        write_XLSBShortCell(ncell, o);
        o.write_shift(1, cell.v);
        o.write_shift(2, 0);
        o.write_shift(1, 0);
        return o;
      }
      function parse_BrtCellIsst(data) {
        var cell = parse_XLSBCell(data);
        var isst = data.read_shift(4);
        return [cell, isst, "s"];
      }
      function write_BrtCellIsst(cell, ncell, o) {
        if (o == null)
          o = new_buf(12);
        write_XLSBCell(ncell, o);
        o.write_shift(4, ncell.v);
        return o;
      }
      function parse_BrtShortIsst(data) {
        var cell = parse_XLSBShortCell(data);
        var isst = data.read_shift(4);
        return [cell, isst, "s"];
      }
      function write_BrtShortIsst(cell, ncell, o) {
        if (o == null)
          o = new_buf(8);
        write_XLSBShortCell(ncell, o);
        o.write_shift(4, ncell.v);
        return o;
      }
      function parse_BrtCellReal(data) {
        var cell = parse_XLSBCell(data);
        var value2 = parse_Xnum(data);
        return [cell, value2, "n"];
      }
      function write_BrtCellReal(cell, ncell, o) {
        if (o == null)
          o = new_buf(16);
        write_XLSBCell(ncell, o);
        write_Xnum(cell.v, o);
        return o;
      }
      function parse_BrtShortReal(data) {
        var cell = parse_XLSBShortCell(data);
        var value2 = parse_Xnum(data);
        return [cell, value2, "n"];
      }
      function write_BrtShortReal(cell, ncell, o) {
        if (o == null)
          o = new_buf(12);
        write_XLSBShortCell(ncell, o);
        write_Xnum(cell.v, o);
        return o;
      }
      function parse_BrtCellRk(data) {
        var cell = parse_XLSBCell(data);
        var value2 = parse_RkNumber(data);
        return [cell, value2, "n"];
      }
      function write_BrtCellRk(cell, ncell, o) {
        if (o == null)
          o = new_buf(12);
        write_XLSBCell(ncell, o);
        write_RkNumber(cell.v, o);
        return o;
      }
      function parse_BrtShortRk(data) {
        var cell = parse_XLSBShortCell(data);
        var value2 = parse_RkNumber(data);
        return [cell, value2, "n"];
      }
      function write_BrtShortRk(cell, ncell, o) {
        if (o == null)
          o = new_buf(8);
        write_XLSBShortCell(ncell, o);
        write_RkNumber(cell.v, o);
        return o;
      }
      function parse_BrtCellRString(data) {
        var cell = parse_XLSBCell(data);
        var value2 = parse_RichStr(data);
        return [cell, value2, "is"];
      }
      function parse_BrtCellSt(data) {
        var cell = parse_XLSBCell(data);
        var value2 = parse_XLWideString(data);
        return [cell, value2, "str"];
      }
      function write_BrtCellSt(cell, ncell, o) {
        if (o == null)
          o = new_buf(12 + 4 * cell.v.length);
        write_XLSBCell(ncell, o);
        write_XLWideString(cell.v, o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function parse_BrtShortSt(data) {
        var cell = parse_XLSBShortCell(data);
        var value2 = parse_XLWideString(data);
        return [cell, value2, "str"];
      }
      function write_BrtShortSt(cell, ncell, o) {
        if (o == null)
          o = new_buf(8 + 4 * cell.v.length);
        write_XLSBShortCell(ncell, o);
        write_XLWideString(cell.v, o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function parse_BrtFmlaBool(data, length, opts) {
        var end = data.l + length;
        var cell = parse_XLSBCell(data);
        cell.r = opts["!row"];
        var value2 = data.read_shift(1);
        var o = [cell, value2, "b"];
        if (opts.cellFormula) {
          data.l += 2;
          var formula = parse_XLSBCellParsedFormula(data, end - data.l, opts);
          o[3] = stringify_formula(formula, null, cell, opts.supbooks, opts);
        } else
          data.l = end;
        return o;
      }
      function parse_BrtFmlaError(data, length, opts) {
        var end = data.l + length;
        var cell = parse_XLSBCell(data);
        cell.r = opts["!row"];
        var value2 = data.read_shift(1);
        var o = [cell, value2, "e"];
        if (opts.cellFormula) {
          data.l += 2;
          var formula = parse_XLSBCellParsedFormula(data, end - data.l, opts);
          o[3] = stringify_formula(formula, null, cell, opts.supbooks, opts);
        } else
          data.l = end;
        return o;
      }
      function parse_BrtFmlaNum(data, length, opts) {
        var end = data.l + length;
        var cell = parse_XLSBCell(data);
        cell.r = opts["!row"];
        var value2 = parse_Xnum(data);
        var o = [cell, value2, "n"];
        if (opts.cellFormula) {
          data.l += 2;
          var formula = parse_XLSBCellParsedFormula(data, end - data.l, opts);
          o[3] = stringify_formula(formula, null, cell, opts.supbooks, opts);
        } else
          data.l = end;
        return o;
      }
      function parse_BrtFmlaString(data, length, opts) {
        var end = data.l + length;
        var cell = parse_XLSBCell(data);
        cell.r = opts["!row"];
        var value2 = parse_XLWideString(data);
        var o = [cell, value2, "str"];
        if (opts.cellFormula) {
          data.l += 2;
          var formula = parse_XLSBCellParsedFormula(data, end - data.l, opts);
          o[3] = stringify_formula(formula, null, cell, opts.supbooks, opts);
        } else
          data.l = end;
        return o;
      }
      var parse_BrtMergeCell = parse_UncheckedRfX;
      var write_BrtMergeCell = write_UncheckedRfX;
      function write_BrtBeginMergeCells(cnt, o) {
        if (o == null)
          o = new_buf(4);
        o.write_shift(4, cnt);
        return o;
      }
      function parse_BrtHLink(data, length) {
        var end = data.l + length;
        var rfx = parse_UncheckedRfX(data, 16);
        var relId = parse_XLNullableWideString(data);
        var loc = parse_XLWideString(data);
        var tooltip = parse_XLWideString(data);
        var display = parse_XLWideString(data);
        data.l = end;
        var o = { rfx, relId, loc, display };
        if (tooltip)
          o.Tooltip = tooltip;
        return o;
      }
      function write_BrtHLink(l, rId) {
        var o = new_buf(50 + 4 * (l[1].Target.length + (l[1].Tooltip || "").length));
        write_UncheckedRfX({ s: decode_cell(l[0]), e: decode_cell(l[0]) }, o);
        write_RelID("rId" + rId, o);
        var locidx = l[1].Target.indexOf("#");
        var loc = locidx == -1 ? "" : l[1].Target.slice(locidx + 1);
        write_XLWideString(loc || "", o);
        write_XLWideString(l[1].Tooltip || "", o);
        write_XLWideString("", o);
        return o.slice(0, o.l);
      }
      function parse_BrtPane() {
      }
      function parse_BrtArrFmla(data, length, opts) {
        var end = data.l + length;
        var rfx = parse_RfX(data, 16);
        var fAlwaysCalc = data.read_shift(1);
        var o = [rfx];
        o[2] = fAlwaysCalc;
        if (opts.cellFormula) {
          var formula = parse_XLSBArrayParsedFormula(data, end - data.l, opts);
          o[1] = formula;
        } else
          data.l = end;
        return o;
      }
      function parse_BrtShrFmla(data, length, opts) {
        var end = data.l + length;
        var rfx = parse_UncheckedRfX(data, 16);
        var o = [rfx];
        if (opts.cellFormula) {
          var formula = parse_XLSBSharedParsedFormula(data, end - data.l, opts);
          o[1] = formula;
          data.l = end;
        } else
          data.l = end;
        return o;
      }
      function write_BrtColInfo(C, col, o) {
        if (o == null)
          o = new_buf(18);
        var p = col_obj_w(C, col);
        o.write_shift(-4, C);
        o.write_shift(-4, C);
        o.write_shift(4, (p.width || 10) * 256);
        o.write_shift(
          4,
          0
          /*ixfe*/
        );
        var flags = 0;
        if (col.hidden)
          flags |= 1;
        if (typeof p.width == "number")
          flags |= 2;
        if (col.level)
          flags |= col.level << 8;
        o.write_shift(2, flags);
        return o;
      }
      var BrtMarginKeys = ["left", "right", "top", "bottom", "header", "footer"];
      function parse_BrtMargins(data) {
        var margins = {};
        BrtMarginKeys.forEach(function(k) {
          margins[k] = parse_Xnum(data, 8);
        });
        return margins;
      }
      function write_BrtMargins(margins, o) {
        if (o == null)
          o = new_buf(6 * 8);
        default_margins(margins);
        BrtMarginKeys.forEach(function(k) {
          write_Xnum(margins[k], o);
        });
        return o;
      }
      function parse_BrtBeginWsView(data) {
        var f = data.read_shift(2);
        data.l += 28;
        return { RTL: f & 32 };
      }
      function write_BrtBeginWsView(ws, Workbook, o) {
        if (o == null)
          o = new_buf(30);
        var f = 924;
        if ((((Workbook || {}).Views || [])[0] || {}).RTL)
          f |= 32;
        o.write_shift(2, f);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(1, 0);
        o.write_shift(1, 0);
        o.write_shift(2, 0);
        o.write_shift(2, 100);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(2, 0);
        o.write_shift(4, 0);
        return o;
      }
      function write_BrtCellIgnoreEC(ref) {
        var o = new_buf(24);
        o.write_shift(4, 4);
        o.write_shift(4, 1);
        write_UncheckedRfX(ref, o);
        return o;
      }
      function write_BrtSheetProtection(sp, o) {
        if (o == null)
          o = new_buf(16 * 4 + 2);
        o.write_shift(2, sp.password ? crypto_CreatePasswordVerifier_Method1(sp.password) : 0);
        o.write_shift(4, 1);
        [
          ["objects", false],
          // fObjects
          ["scenarios", false],
          // fScenarios
          ["formatCells", true],
          // fFormatCells
          ["formatColumns", true],
          // fFormatColumns
          ["formatRows", true],
          // fFormatRows
          ["insertColumns", true],
          // fInsertColumns
          ["insertRows", true],
          // fInsertRows
          ["insertHyperlinks", true],
          // fInsertHyperlinks
          ["deleteColumns", true],
          // fDeleteColumns
          ["deleteRows", true],
          // fDeleteRows
          ["selectLockedCells", false],
          // fSelLockedCells
          ["sort", true],
          // fSort
          ["autoFilter", true],
          // fAutoFilter
          ["pivotTables", true],
          // fPivotTables
          ["selectUnlockedCells", false]
          // fSelUnlockedCells
        ].forEach(function(n) {
          if (n[1])
            o.write_shift(4, sp[n[0]] != null && !sp[n[0]] ? 1 : 0);
          else
            o.write_shift(4, sp[n[0]] != null && sp[n[0]] ? 0 : 1);
        });
        return o;
      }
      function parse_BrtDVal() {
      }
      function parse_BrtDVal14() {
      }
      function parse_ws_bin(data, _opts, idx, rels, wb, themes, styles) {
        if (!data)
          return data;
        var opts = _opts || {};
        if (!rels)
          rels = { "!id": {} };
        if (DENSE != null && opts.dense == null)
          opts.dense = DENSE;
        var s = opts.dense ? [] : {};
        var ref;
        var refguess = { s: { r: 2e6, c: 2e6 }, e: { r: 0, c: 0 } };
        var state = [];
        var pass = false, end = false;
        var row, p, cf, R, C, addr, sstr, rr, cell;
        var merges = [];
        opts.biff = 12;
        opts["!row"] = 0;
        var ai = 0, af = false;
        var arrayf = [];
        var sharedf = {};
        var supbooks = opts.supbooks || wb.supbooks || [[]];
        supbooks.sharedf = sharedf;
        supbooks.arrayf = arrayf;
        supbooks.SheetNames = wb.SheetNames || wb.Sheets.map(function(x) {
          return x.name;
        });
        if (!opts.supbooks) {
          opts.supbooks = supbooks;
          if (wb.Names)
            for (var i = 0; i < wb.Names.length; ++i)
              supbooks[0][i + 1] = wb.Names[i];
        }
        var colinfo = [], rowinfo = [];
        var seencol = false;
        XLSBRecordEnum[16] = { n: "BrtShortReal", f: parse_BrtShortReal };
        var cm, vm;
        recordhopper(data, function ws_parse(val, RR, RT) {
          if (end)
            return;
          switch (RT) {
            case 148:
              ref = val;
              break;
            case 0:
              row = val;
              if (opts.sheetRows && opts.sheetRows <= row.r)
                end = true;
              rr = encode_row(R = row.r);
              opts["!row"] = row.r;
              if (val.hidden || val.hpt || val.level != null) {
                if (val.hpt)
                  val.hpx = pt2px(val.hpt);
                rowinfo[val.r] = val;
              }
              break;
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 11:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 62:
              p = { t: val[2] };
              switch (val[2]) {
                case "n":
                  p.v = val[1];
                  break;
                case "s":
                  sstr = strs[val[1]];
                  p.v = sstr.t;
                  p.r = sstr.r;
                  break;
                case "b":
                  p.v = val[1] ? true : false;
                  break;
                case "e":
                  p.v = val[1];
                  if (opts.cellText !== false)
                    p.w = BErr[p.v];
                  break;
                case "str":
                  p.t = "s";
                  p.v = val[1];
                  break;
                case "is":
                  p.t = "s";
                  p.v = val[1].t;
                  break;
              }
              if (cf = styles.CellXf[val[0].iStyleRef])
                safe_format(p, cf.numFmtId, null, opts, themes, styles);
              C = val[0].c == -1 ? C + 1 : val[0].c;
              if (opts.dense) {
                if (!s[R])
                  s[R] = [];
                s[R][C] = p;
              } else
                s[encode_col(C) + rr] = p;
              if (opts.cellFormula) {
                af = false;
                for (ai = 0; ai < arrayf.length; ++ai) {
                  var aii = arrayf[ai];
                  if (row.r >= aii[0].s.r && row.r <= aii[0].e.r) {
                    if (C >= aii[0].s.c && C <= aii[0].e.c) {
                      p.F = encode_range(aii[0]);
                      af = true;
                    }
                  }
                }
                if (!af && val.length > 3)
                  p.f = val[3];
              }
              if (refguess.s.r > row.r)
                refguess.s.r = row.r;
              if (refguess.s.c > C)
                refguess.s.c = C;
              if (refguess.e.r < row.r)
                refguess.e.r = row.r;
              if (refguess.e.c < C)
                refguess.e.c = C;
              if (opts.cellDates && cf && p.t == "n" && fmt_is_date(table_fmt[cf.numFmtId])) {
                var _d = SSF_parse_date_code(p.v);
                if (_d) {
                  p.t = "d";
                  p.v = new Date(_d.y, _d.m - 1, _d.d, _d.H, _d.M, _d.S, _d.u);
                }
              }
              if (cm) {
                if (cm.type == "XLDAPR")
                  p.D = true;
                cm = void 0;
              }
              if (vm)
                vm = void 0;
              break;
            case 1:
            case 12:
              if (!opts.sheetStubs || pass)
                break;
              p = { t: "z", v: void 0 };
              C = val[0].c == -1 ? C + 1 : val[0].c;
              if (opts.dense) {
                if (!s[R])
                  s[R] = [];
                s[R][C] = p;
              } else
                s[encode_col(C) + rr] = p;
              if (refguess.s.r > row.r)
                refguess.s.r = row.r;
              if (refguess.s.c > C)
                refguess.s.c = C;
              if (refguess.e.r < row.r)
                refguess.e.r = row.r;
              if (refguess.e.c < C)
                refguess.e.c = C;
              if (cm) {
                if (cm.type == "XLDAPR")
                  p.D = true;
                cm = void 0;
              }
              if (vm)
                vm = void 0;
              break;
            case 176:
              merges.push(val);
              break;
            case 49:
              {
                cm = ((opts.xlmeta || {}).Cell || [])[val - 1];
              }
              break;
            case 494:
              var rel = rels["!id"][val.relId];
              if (rel) {
                val.Target = rel.Target;
                if (val.loc)
                  val.Target += "#" + val.loc;
                val.Rel = rel;
              } else if (val.relId == "") {
                val.Target = "#" + val.loc;
              }
              for (R = val.rfx.s.r; R <= val.rfx.e.r; ++R)
                for (C = val.rfx.s.c; C <= val.rfx.e.c; ++C) {
                  if (opts.dense) {
                    if (!s[R])
                      s[R] = [];
                    if (!s[R][C])
                      s[R][C] = { t: "z", v: void 0 };
                    s[R][C].l = val;
                  } else {
                    addr = encode_cell({ c: C, r: R });
                    if (!s[addr])
                      s[addr] = { t: "z", v: void 0 };
                    s[addr].l = val;
                  }
                }
              break;
            case 426:
              if (!opts.cellFormula)
                break;
              arrayf.push(val);
              cell = opts.dense ? s[R][C] : s[encode_col(C) + rr];
              cell.f = stringify_formula(val[1], refguess, { r: row.r, c: C }, supbooks, opts);
              cell.F = encode_range(val[0]);
              break;
            case 427:
              if (!opts.cellFormula)
                break;
              sharedf[encode_cell(val[0].s)] = val[1];
              cell = opts.dense ? s[R][C] : s[encode_col(C) + rr];
              cell.f = stringify_formula(val[1], refguess, { r: row.r, c: C }, supbooks, opts);
              break;
            case 60:
              if (!opts.cellStyles)
                break;
              while (val.e >= val.s) {
                colinfo[val.e--] = { width: val.w / 256, hidden: !!(val.flags & 1), level: val.level };
                if (!seencol) {
                  seencol = true;
                  find_mdw_colw(val.w / 256);
                }
                process_col(colinfo[val.e + 1]);
              }
              break;
            case 161:
              s["!autofilter"] = { ref: encode_range(val) };
              break;
            case 476:
              s["!margins"] = val;
              break;
            case 147:
              if (!wb.Sheets[idx])
                wb.Sheets[idx] = {};
              if (val.name)
                wb.Sheets[idx].CodeName = val.name;
              if (val.above || val.left)
                s["!outline"] = { above: val.above, left: val.left };
              break;
            case 137:
              if (!wb.Views)
                wb.Views = [{}];
              if (!wb.Views[0])
                wb.Views[0] = {};
              if (val.RTL)
                wb.Views[0].RTL = true;
              break;
            case 485:
              break;
            case 64:
            case 1053:
              break;
            case 151:
              break;
            case 152:
            case 175:
            case 644:
            case 625:
            case 562:
            case 396:
            case 1112:
            case 1146:
            case 471:
            case 1050:
            case 649:
            case 1105:
            case 589:
            case 607:
            case 564:
            case 1055:
            case 168:
            case 174:
            case 1180:
            case 499:
            case 507:
            case 550:
            case 171:
            case 167:
            case 1177:
            case 169:
            case 1181:
            case 551:
            case 552:
            case 661:
            case 639:
            case 478:
            case 537:
            case 477:
            case 536:
            case 1103:
            case 680:
            case 1104:
            case 1024:
            case 663:
            case 535:
            case 678:
            case 504:
            case 1043:
            case 428:
            case 170:
            case 3072:
            case 50:
            case 2070:
            case 1045:
              break;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            case 37:
              state.push(RT);
              pass = true;
              break;
            case 38:
              state.pop();
              pass = false;
              break;
            default:
              if (RR.T) {
              } else if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        }, opts);
        delete opts.supbooks;
        delete opts["!row"];
        if (!s["!ref"] && (refguess.s.r < 2e6 || ref && (ref.e.r > 0 || ref.e.c > 0 || ref.s.r > 0 || ref.s.c > 0)))
          s["!ref"] = encode_range(ref || refguess);
        if (opts.sheetRows && s["!ref"]) {
          var tmpref = safe_decode_range(s["!ref"]);
          if (opts.sheetRows <= +tmpref.e.r) {
            tmpref.e.r = opts.sheetRows - 1;
            if (tmpref.e.r > refguess.e.r)
              tmpref.e.r = refguess.e.r;
            if (tmpref.e.r < tmpref.s.r)
              tmpref.s.r = tmpref.e.r;
            if (tmpref.e.c > refguess.e.c)
              tmpref.e.c = refguess.e.c;
            if (tmpref.e.c < tmpref.s.c)
              tmpref.s.c = tmpref.e.c;
            s["!fullref"] = s["!ref"];
            s["!ref"] = encode_range(tmpref);
          }
        }
        if (merges.length > 0)
          s["!merges"] = merges;
        if (colinfo.length > 0)
          s["!cols"] = colinfo;
        if (rowinfo.length > 0)
          s["!rows"] = rowinfo;
        return s;
      }
      function write_ws_bin_cell(ba, cell, R, C, opts, ws, last_seen) {
        if (cell.v === void 0)
          return false;
        var vv = "";
        switch (cell.t) {
          case "b":
            vv = cell.v ? "1" : "0";
            break;
          case "d":
            cell = dup(cell);
            cell.z = cell.z || table_fmt[14];
            cell.v = datenum(parseDate(cell.v));
            cell.t = "n";
            break;
          case "n":
          case "e":
            vv = "" + cell.v;
            break;
          default:
            vv = cell.v;
            break;
        }
        var o = { r: R, c: C };
        o.s = get_cell_style(opts.cellXfs, cell, opts);
        if (cell.l)
          ws["!links"].push([encode_cell(o), cell.l]);
        if (cell.c)
          ws["!comments"].push([encode_cell(o), cell.c]);
        switch (cell.t) {
          case "s":
          case "str":
            if (opts.bookSST) {
              vv = get_sst_id(opts.Strings, cell.v, opts.revStrings);
              o.t = "s";
              o.v = vv;
              if (last_seen)
                write_record(ba, 18, write_BrtShortIsst(cell, o));
              else
                write_record(ba, 7, write_BrtCellIsst(cell, o));
            } else {
              o.t = "str";
              if (last_seen)
                write_record(ba, 17, write_BrtShortSt(cell, o));
              else
                write_record(ba, 6, write_BrtCellSt(cell, o));
            }
            return true;
          case "n":
            if (cell.v == (cell.v | 0) && cell.v > -1e3 && cell.v < 1e3) {
              if (last_seen)
                write_record(ba, 13, write_BrtShortRk(cell, o));
              else
                write_record(ba, 2, write_BrtCellRk(cell, o));
            } else {
              if (last_seen)
                write_record(ba, 16, write_BrtShortReal(cell, o));
              else
                write_record(ba, 5, write_BrtCellReal(cell, o));
            }
            return true;
          case "b":
            o.t = "b";
            if (last_seen)
              write_record(ba, 15, write_BrtShortBool(cell, o));
            else
              write_record(ba, 4, write_BrtCellBool(cell, o));
            return true;
          case "e":
            o.t = "e";
            if (last_seen)
              write_record(ba, 14, write_BrtShortError(cell, o));
            else
              write_record(ba, 3, write_BrtCellError(cell, o));
            return true;
        }
        if (last_seen)
          write_record(ba, 12, write_BrtShortBlank(cell, o));
        else
          write_record(ba, 1, write_BrtCellBlank(cell, o));
        return true;
      }
      function write_CELLTABLE(ba, ws, idx, opts) {
        var range = safe_decode_range(ws["!ref"] || "A1"), ref, rr = "", cols = [];
        write_record(
          ba,
          145
          /* BrtBeginSheetData */
        );
        var dense = Array.isArray(ws);
        var cap = range.e.r;
        if (ws["!rows"])
          cap = Math.max(range.e.r, ws["!rows"].length - 1);
        for (var R = range.s.r; R <= cap; ++R) {
          rr = encode_row(R);
          write_row_header(ba, ws, range, R);
          var last_seen = false;
          if (R <= range.e.r)
            for (var C = range.s.c; C <= range.e.c; ++C) {
              if (R === range.s.r)
                cols[C] = encode_col(C);
              ref = cols[C] + rr;
              var cell = dense ? (ws[R] || [])[C] : ws[ref];
              if (!cell) {
                last_seen = false;
                continue;
              }
              last_seen = write_ws_bin_cell(ba, cell, R, C, opts, ws, last_seen);
            }
        }
        write_record(
          ba,
          146
          /* BrtEndSheetData */
        );
      }
      function write_MERGECELLS(ba, ws) {
        if (!ws || !ws["!merges"])
          return;
        write_record(ba, 177, write_BrtBeginMergeCells(ws["!merges"].length));
        ws["!merges"].forEach(function(m) {
          write_record(ba, 176, write_BrtMergeCell(m));
        });
        write_record(
          ba,
          178
          /* BrtEndMergeCells */
        );
      }
      function write_COLINFOS(ba, ws) {
        if (!ws || !ws["!cols"])
          return;
        write_record(
          ba,
          390
          /* BrtBeginColInfos */
        );
        ws["!cols"].forEach(function(m, i) {
          if (m)
            write_record(ba, 60, write_BrtColInfo(i, m));
        });
        write_record(
          ba,
          391
          /* BrtEndColInfos */
        );
      }
      function write_IGNOREECS(ba, ws) {
        if (!ws || !ws["!ref"])
          return;
        write_record(
          ba,
          648
          /* BrtBeginCellIgnoreECs */
        );
        write_record(ba, 649, write_BrtCellIgnoreEC(safe_decode_range(ws["!ref"])));
        write_record(
          ba,
          650
          /* BrtEndCellIgnoreECs */
        );
      }
      function write_HLINKS(ba, ws, rels) {
        ws["!links"].forEach(function(l) {
          if (!l[1].Target)
            return;
          var rId = add_rels(rels, -1, l[1].Target.replace(/#.*$/, ""), RELS.HLINK);
          write_record(ba, 494, write_BrtHLink(l, rId));
        });
        delete ws["!links"];
      }
      function write_LEGACYDRAWING(ba, ws, idx, rels) {
        if (ws["!comments"].length > 0) {
          var rId = add_rels(rels, -1, "../drawings/vmlDrawing" + (idx + 1) + ".vml", RELS.VML);
          write_record(ba, 551, write_RelID("rId" + rId));
          ws["!legacy"] = rId;
        }
      }
      function write_AUTOFILTER(ba, ws, wb, idx) {
        if (!ws["!autofilter"])
          return;
        var data = ws["!autofilter"];
        var ref = typeof data.ref === "string" ? data.ref : encode_range(data.ref);
        if (!wb.Workbook)
          wb.Workbook = { Sheets: [] };
        if (!wb.Workbook.Names)
          wb.Workbook.Names = [];
        var names = wb.Workbook.Names;
        var range = decode_range(ref);
        if (range.s.r == range.e.r) {
          range.e.r = decode_range(ws["!ref"]).e.r;
          ref = encode_range(range);
        }
        for (var i = 0; i < names.length; ++i) {
          var name = names[i];
          if (name.Name != "_xlnm._FilterDatabase")
            continue;
          if (name.Sheet != idx)
            continue;
          name.Ref = "'" + wb.SheetNames[idx] + "'!" + ref;
          break;
        }
        if (i == names.length)
          names.push({ Name: "_xlnm._FilterDatabase", Sheet: idx, Ref: "'" + wb.SheetNames[idx] + "'!" + ref });
        write_record(ba, 161, write_UncheckedRfX(safe_decode_range(ref)));
        write_record(
          ba,
          162
          /* BrtEndAFilter */
        );
      }
      function write_WSVIEWS2(ba, ws, Workbook) {
        write_record(
          ba,
          133
          /* BrtBeginWsViews */
        );
        {
          write_record(ba, 137, write_BrtBeginWsView(ws, Workbook));
          write_record(
            ba,
            138
            /* BrtEndWsView */
          );
        }
        write_record(
          ba,
          134
          /* BrtEndWsViews */
        );
      }
      function write_WSFMTINFO() {
      }
      function write_SHEETPROTECT(ba, ws) {
        if (!ws["!protect"])
          return;
        write_record(ba, 535, write_BrtSheetProtection(ws["!protect"]));
      }
      function write_ws_bin(idx, opts, wb, rels) {
        var ba = buf_array();
        var s = wb.SheetNames[idx], ws = wb.Sheets[s] || {};
        var c = s;
        try {
          if (wb && wb.Workbook)
            c = wb.Workbook.Sheets[idx].CodeName || c;
        } catch (e) {
        }
        var r = safe_decode_range(ws["!ref"] || "A1");
        if (r.e.c > 16383 || r.e.r > 1048575) {
          if (opts.WTF)
            throw new Error("Range " + (ws["!ref"] || "A1") + " exceeds format limit A1:XFD1048576");
          r.e.c = Math.min(r.e.c, 16383);
          r.e.r = Math.min(r.e.c, 1048575);
        }
        ws["!links"] = [];
        ws["!comments"] = [];
        write_record(
          ba,
          129
          /* BrtBeginSheet */
        );
        if (wb.vbaraw || ws["!outline"])
          write_record(ba, 147, write_BrtWsProp(c, ws["!outline"]));
        write_record(ba, 148, write_BrtWsDim(r));
        write_WSVIEWS2(ba, ws, wb.Workbook);
        write_WSFMTINFO(ba, ws);
        write_COLINFOS(ba, ws, idx, opts, wb);
        write_CELLTABLE(ba, ws, idx, opts, wb);
        write_SHEETPROTECT(ba, ws);
        write_AUTOFILTER(ba, ws, wb, idx);
        write_MERGECELLS(ba, ws);
        write_HLINKS(ba, ws, rels);
        if (ws["!margins"])
          write_record(ba, 476, write_BrtMargins(ws["!margins"]));
        if (!opts || opts.ignoreEC || opts.ignoreEC == void 0)
          write_IGNOREECS(ba, ws);
        write_LEGACYDRAWING(ba, ws, idx, rels);
        write_record(
          ba,
          130
          /* BrtEndSheet */
        );
        return ba.end();
      }
      function parse_Cache(data) {
        var col = [];
        var num = data.match(/^<c:numCache>/);
        var f;
        (data.match(/<c:pt idx="(\d*)">(.*?)<\/c:pt>/mg) || []).forEach(function(pt) {
          var q = pt.match(/<c:pt idx="(\d*?)"><c:v>(.*)<\/c:v><\/c:pt>/);
          if (!q)
            return;
          col[+q[1]] = num ? +q[2] : q[2];
        });
        var nf = unescapexml((data.match(/<c:formatCode>([\s\S]*?)<\/c:formatCode>/) || ["", "General"])[1]);
        (data.match(/<c:f>(.*?)<\/c:f>/mg) || []).forEach(function(F) {
          f = F.replace(/<.*?>/g, "");
        });
        return [col, nf, f];
      }
      function parse_chart(data, name, opts, rels, wb, csheet) {
        var cs = csheet || { "!type": "chart" };
        if (!data)
          return csheet;
        var C = 0, R = 0, col = "A";
        var refguess = { s: { r: 2e6, c: 2e6 }, e: { r: 0, c: 0 } };
        (data.match(/<c:numCache>[\s\S]*?<\/c:numCache>/gm) || []).forEach(function(nc) {
          var cache = parse_Cache(nc);
          refguess.s.r = refguess.s.c = 0;
          refguess.e.c = C;
          col = encode_col(C);
          cache[0].forEach(function(n, i) {
            cs[col + encode_row(i)] = { t: "n", v: n, z: cache[1] };
            R = i;
          });
          if (refguess.e.r < R)
            refguess.e.r = R;
          ++C;
        });
        if (C > 0)
          cs["!ref"] = encode_range(refguess);
        return cs;
      }
      function parse_cs_xml(data, opts, idx, rels, wb) {
        if (!data)
          return data;
        if (!rels)
          rels = { "!id": {} };
        var s = { "!type": "chart", "!drawel": null, "!rel": "" };
        var m;
        var sheetPr = data.match(sheetprregex);
        if (sheetPr)
          parse_ws_xml_sheetpr(sheetPr[0], s, wb, idx);
        if (m = data.match(/drawing r:id="(.*?)"/))
          s["!rel"] = m[1];
        if (rels["!id"][s["!rel"]])
          s["!drawel"] = rels["!id"][s["!rel"]];
        return s;
      }
      function write_cs_xml(idx, opts, wb, rels) {
        var o = [XML_HEADER, writextag("chartsheet", null, {
          "xmlns": XMLNS_main[0],
          "xmlns:r": XMLNS.r
        })];
        o[o.length] = writextag("drawing", null, { "r:id": "rId1" });
        add_rels(rels, -1, "../drawings/drawing" + (idx + 1) + ".xml", RELS.DRAW);
        if (o.length > 2) {
          o[o.length] = "</chartsheet>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_BrtCsProp(data, length) {
        data.l += 10;
        var name = parse_XLWideString(data, length - 10);
        return { name };
      }
      function parse_cs_bin(data, opts, idx, rels, wb) {
        if (!data)
          return data;
        if (!rels)
          rels = { "!id": {} };
        var s = { "!type": "chart", "!drawel": null, "!rel": "" };
        var state = [];
        var pass = false;
        recordhopper(data, function cs_parse(val, R, RT) {
          switch (RT) {
            case 550:
              s["!rel"] = val;
              break;
            case 651:
              if (!wb.Sheets[idx])
                wb.Sheets[idx] = {};
              if (val.name)
                wb.Sheets[idx].CodeName = val.name;
              break;
            case 562:
            case 652:
            case 669:
            case 679:
            case 551:
            case 552:
            case 476:
            case 3072:
              break;
            case 35:
              pass = true;
              break;
            case 36:
              pass = false;
              break;
            case 37:
              state.push(RT);
              break;
            case 38:
              state.pop();
              break;
            default:
              if (R.T > 0)
                state.push(RT);
              else if (R.T < 0)
                state.pop();
              else if (!pass || opts.WTF)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        }, opts);
        if (rels["!id"][s["!rel"]])
          s["!drawel"] = rels["!id"][s["!rel"]];
        return s;
      }
      function write_cs_bin() {
        var ba = buf_array();
        write_record(
          ba,
          129
          /* BrtBeginSheet */
        );
        write_record(
          ba,
          130
          /* BrtEndSheet */
        );
        return ba.end();
      }
      var WBPropsDef = [
        ["allowRefreshQuery", false, "bool"],
        ["autoCompressPictures", true, "bool"],
        ["backupFile", false, "bool"],
        ["checkCompatibility", false, "bool"],
        ["CodeName", ""],
        ["date1904", false, "bool"],
        ["defaultThemeVersion", 0, "int"],
        ["filterPrivacy", false, "bool"],
        ["hidePivotFieldList", false, "bool"],
        ["promptedSolutions", false, "bool"],
        ["publishItems", false, "bool"],
        ["refreshAllConnections", false, "bool"],
        ["saveExternalLinkValues", true, "bool"],
        ["showBorderUnselectedTables", true, "bool"],
        ["showInkAnnotation", true, "bool"],
        ["showObjects", "all"],
        ["showPivotChartFilter", false, "bool"],
        ["updateLinks", "userSet"]
      ];
      var WBViewDef = [
        ["activeTab", 0, "int"],
        ["autoFilterDateGrouping", true, "bool"],
        ["firstSheet", 0, "int"],
        ["minimized", false, "bool"],
        ["showHorizontalScroll", true, "bool"],
        ["showSheetTabs", true, "bool"],
        ["showVerticalScroll", true, "bool"],
        ["tabRatio", 600, "int"],
        ["visibility", "visible"]
        //window{Height,Width}, {x,y}Window
      ];
      var SheetDef = [
        //['state', 'visible']
      ];
      var CalcPrDef = [
        ["calcCompleted", "true"],
        ["calcMode", "auto"],
        ["calcOnSave", "true"],
        ["concurrentCalc", "true"],
        ["fullCalcOnLoad", "false"],
        ["fullPrecision", "true"],
        ["iterate", "false"],
        ["iterateCount", "100"],
        ["iterateDelta", "0.001"],
        ["refMode", "A1"]
      ];
      function push_defaults_array(target, defaults) {
        for (var j = 0; j != target.length; ++j) {
          var w = target[j];
          for (var i = 0; i != defaults.length; ++i) {
            var z = defaults[i];
            if (w[z[0]] == null)
              w[z[0]] = z[1];
            else
              switch (z[2]) {
                case "bool":
                  if (typeof w[z[0]] == "string")
                    w[z[0]] = parsexmlbool(w[z[0]]);
                  break;
                case "int":
                  if (typeof w[z[0]] == "string")
                    w[z[0]] = parseInt(w[z[0]], 10);
                  break;
              }
          }
        }
      }
      function push_defaults(target, defaults) {
        for (var i = 0; i != defaults.length; ++i) {
          var z = defaults[i];
          if (target[z[0]] == null)
            target[z[0]] = z[1];
          else
            switch (z[2]) {
              case "bool":
                if (typeof target[z[0]] == "string")
                  target[z[0]] = parsexmlbool(target[z[0]]);
                break;
              case "int":
                if (typeof target[z[0]] == "string")
                  target[z[0]] = parseInt(target[z[0]], 10);
                break;
            }
        }
      }
      function parse_wb_defaults(wb) {
        push_defaults(wb.WBProps, WBPropsDef);
        push_defaults(wb.CalcPr, CalcPrDef);
        push_defaults_array(wb.WBView, WBViewDef);
        push_defaults_array(wb.Sheets, SheetDef);
        _ssfopts.date1904 = parsexmlbool(wb.WBProps.date1904);
      }
      function safe1904(wb) {
        if (!wb.Workbook)
          return "false";
        if (!wb.Workbook.WBProps)
          return "false";
        return parsexmlbool(wb.Workbook.WBProps.date1904) ? "true" : "false";
      }
      var badchars = "][*?/\\".split("");
      function check_ws_name(n, safe) {
        if (n.length > 31) {
          if (safe)
            return false;
          throw new Error("Sheet names cannot exceed 31 chars");
        }
        var _good = true;
        badchars.forEach(function(c) {
          if (n.indexOf(c) == -1)
            return;
          if (!safe)
            throw new Error("Sheet name cannot contain : \\ / ? * [ ]");
          _good = false;
        });
        return _good;
      }
      function check_wb_names(N, S, codes) {
        N.forEach(function(n, i) {
          check_ws_name(n);
          for (var j = 0; j < i; ++j)
            if (n == N[j])
              throw new Error("Duplicate Sheet Name: " + n);
          if (codes) {
            var cn = S && S[i] && S[i].CodeName || n;
            if (cn.charCodeAt(0) == 95 && cn.length > 22)
              throw new Error("Bad Code Name: Worksheet" + cn);
          }
        });
      }
      function check_wb(wb) {
        if (!wb || !wb.SheetNames || !wb.Sheets)
          throw new Error("Invalid Workbook");
        if (!wb.SheetNames.length)
          throw new Error("Workbook is empty");
        var Sheets = wb.Workbook && wb.Workbook.Sheets || [];
        check_wb_names(wb.SheetNames, Sheets, !!wb.vbaraw);
        for (var i = 0; i < wb.SheetNames.length; ++i)
          check_ws(wb.Sheets[wb.SheetNames[i]], wb.SheetNames[i], i);
      }
      var wbnsregex = /<\w+:workbook/;
      function parse_wb_xml(data, opts) {
        if (!data)
          throw new Error("Could not find file");
        var wb = { AppVersion: {}, WBProps: {}, WBView: [], Sheets: [], CalcPr: {}, Names: [], xmlns: "" };
        var pass = false, xmlns = "xmlns";
        var dname = {}, dnstart = 0;
        data.replace(tagregex, function xml_wb(x, idx) {
          var y = parsexmltag(x);
          switch (strip_ns(y[0])) {
            case "<?xml":
              break;
            case "<workbook":
              if (x.match(wbnsregex))
                xmlns = "xmlns" + x.match(/<(\w+):/)[1];
              wb.xmlns = y[xmlns];
              break;
            case "</workbook>":
              break;
            case "<fileVersion":
              delete y[0];
              wb.AppVersion = y;
              break;
            case "<fileVersion/>":
            case "</fileVersion>":
              break;
            case "<fileSharing":
              break;
            case "<fileSharing/>":
              break;
            case "<workbookPr":
            case "<workbookPr/>":
              WBPropsDef.forEach(function(w) {
                if (y[w[0]] == null)
                  return;
                switch (w[2]) {
                  case "bool":
                    wb.WBProps[w[0]] = parsexmlbool(y[w[0]]);
                    break;
                  case "int":
                    wb.WBProps[w[0]] = parseInt(y[w[0]], 10);
                    break;
                  default:
                    wb.WBProps[w[0]] = y[w[0]];
                }
              });
              if (y.codeName)
                wb.WBProps.CodeName = utf8read(y.codeName);
              break;
            case "</workbookPr>":
              break;
            case "<workbookProtection":
              break;
            case "<workbookProtection/>":
              break;
            case "<bookViews":
            case "<bookViews>":
            case "</bookViews>":
              break;
            case "<workbookView":
            case "<workbookView/>":
              delete y[0];
              wb.WBView.push(y);
              break;
            case "</workbookView>":
              break;
            case "<sheets":
            case "<sheets>":
            case "</sheets>":
              break;
            case "<sheet":
              switch (y.state) {
                case "hidden":
                  y.Hidden = 1;
                  break;
                case "veryHidden":
                  y.Hidden = 2;
                  break;
                default:
                  y.Hidden = 0;
              }
              delete y.state;
              y.name = unescapexml(utf8read(y.name));
              delete y[0];
              wb.Sheets.push(y);
              break;
            case "</sheet>":
              break;
            case "<functionGroups":
            case "<functionGroups/>":
              break;
            case "<functionGroup":
              break;
            case "<externalReferences":
            case "</externalReferences>":
            case "<externalReferences>":
              break;
            case "<externalReference":
              break;
            case "<definedNames/>":
              break;
            case "<definedNames>":
            case "<definedNames":
              pass = true;
              break;
            case "</definedNames>":
              pass = false;
              break;
            case "<definedName":
              {
                dname = {};
                dname.Name = utf8read(y.name);
                if (y.comment)
                  dname.Comment = y.comment;
                if (y.localSheetId)
                  dname.Sheet = +y.localSheetId;
                if (parsexmlbool(y.hidden || "0"))
                  dname.Hidden = true;
                dnstart = idx + x.length;
              }
              break;
            case "</definedName>":
              {
                dname.Ref = unescapexml(utf8read(data.slice(dnstart, idx)));
                wb.Names.push(dname);
              }
              break;
            case "<definedName/>":
              break;
            case "<calcPr":
              delete y[0];
              wb.CalcPr = y;
              break;
            case "<calcPr/>":
              delete y[0];
              wb.CalcPr = y;
              break;
            case "</calcPr>":
              break;
            case "<oleSize":
              break;
            case "<customWorkbookViews>":
            case "</customWorkbookViews>":
            case "<customWorkbookViews":
              break;
            case "<customWorkbookView":
            case "</customWorkbookView>":
              break;
            case "<pivotCaches>":
            case "</pivotCaches>":
            case "<pivotCaches":
              break;
            case "<pivotCache":
              break;
            case "<smartTagPr":
            case "<smartTagPr/>":
              break;
            case "<smartTagTypes":
            case "<smartTagTypes>":
            case "</smartTagTypes>":
              break;
            case "<smartTagType":
              break;
            case "<webPublishing":
            case "<webPublishing/>":
              break;
            case "<fileRecoveryPr":
            case "<fileRecoveryPr/>":
              break;
            case "<webPublishObjects>":
            case "<webPublishObjects":
            case "</webPublishObjects>":
              break;
            case "<webPublishObject":
              break;
            case "<extLst":
            case "<extLst>":
            case "</extLst>":
            case "<extLst/>":
              break;
            case "<ext":
              pass = true;
              break;
            case "</ext>":
              pass = false;
              break;
            case "<ArchID":
              break;
            case "<AlternateContent":
            case "<AlternateContent>":
              pass = true;
              break;
            case "</AlternateContent>":
              pass = false;
              break;
            case "<revisionPtr":
              break;
            default:
              if (!pass && opts.WTF)
                throw new Error("unrecognized " + y[0] + " in workbook");
          }
          return x;
        });
        if (XMLNS_main.indexOf(wb.xmlns) === -1)
          throw new Error("Unknown Namespace: " + wb.xmlns);
        parse_wb_defaults(wb);
        return wb;
      }
      function write_wb_xml(wb) {
        var o = [XML_HEADER];
        o[o.length] = writextag("workbook", null, {
          "xmlns": XMLNS_main[0],
          //'xmlns:mx': XMLNS.mx,
          //'xmlns:s': XMLNS_main[0],
          "xmlns:r": XMLNS.r
        });
        var write_names = wb.Workbook && (wb.Workbook.Names || []).length > 0;
        var workbookPr = { codeName: "ThisWorkbook" };
        if (wb.Workbook && wb.Workbook.WBProps) {
          WBPropsDef.forEach(function(x) {
            if (wb.Workbook.WBProps[x[0]] == null)
              return;
            if (wb.Workbook.WBProps[x[0]] == x[1])
              return;
            workbookPr[x[0]] = wb.Workbook.WBProps[x[0]];
          });
          if (wb.Workbook.WBProps.CodeName) {
            workbookPr.codeName = wb.Workbook.WBProps.CodeName;
            delete workbookPr.CodeName;
          }
        }
        o[o.length] = writextag("workbookPr", null, workbookPr);
        var sheets = wb.Workbook && wb.Workbook.Sheets || [];
        var i = 0;
        if (sheets && sheets[0] && !!sheets[0].Hidden) {
          o[o.length] = "<bookViews>";
          for (i = 0; i != wb.SheetNames.length; ++i) {
            if (!sheets[i])
              break;
            if (!sheets[i].Hidden)
              break;
          }
          if (i == wb.SheetNames.length)
            i = 0;
          o[o.length] = '<workbookView firstSheet="' + i + '" activeTab="' + i + '"/>';
          o[o.length] = "</bookViews>";
        }
        o[o.length] = "<sheets>";
        for (i = 0; i != wb.SheetNames.length; ++i) {
          var sht = { name: escapexml(wb.SheetNames[i].slice(0, 31)) };
          sht.sheetId = "" + (i + 1);
          sht["r:id"] = "rId" + (i + 1);
          if (sheets[i])
            switch (sheets[i].Hidden) {
              case 1:
                sht.state = "hidden";
                break;
              case 2:
                sht.state = "veryHidden";
                break;
            }
          o[o.length] = writextag("sheet", null, sht);
        }
        o[o.length] = "</sheets>";
        if (write_names) {
          o[o.length] = "<definedNames>";
          if (wb.Workbook && wb.Workbook.Names)
            wb.Workbook.Names.forEach(function(n) {
              var d = { name: n.Name };
              if (n.Comment)
                d.comment = n.Comment;
              if (n.Sheet != null)
                d.localSheetId = "" + n.Sheet;
              if (n.Hidden)
                d.hidden = "1";
              if (!n.Ref)
                return;
              o[o.length] = writextag("definedName", escapexml(n.Ref), d);
            });
          o[o.length] = "</definedNames>";
        }
        if (o.length > 2) {
          o[o.length] = "</workbook>";
          o[1] = o[1].replace("/>", ">");
        }
        return o.join("");
      }
      function parse_BrtBundleSh(data, length) {
        var z = {};
        z.Hidden = data.read_shift(4);
        z.iTabID = data.read_shift(4);
        z.strRelID = parse_RelID(data, length - 8);
        z.name = parse_XLWideString(data);
        return z;
      }
      function write_BrtBundleSh(data, o) {
        if (!o)
          o = new_buf(127);
        o.write_shift(4, data.Hidden);
        o.write_shift(4, data.iTabID);
        write_RelID(data.strRelID, o);
        write_XLWideString(data.name.slice(0, 31), o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function parse_BrtWbProp(data, length) {
        var o = {};
        var flags = data.read_shift(4);
        o.defaultThemeVersion = data.read_shift(4);
        var strName = length > 8 ? parse_XLWideString(data) : "";
        if (strName.length > 0)
          o.CodeName = strName;
        o.autoCompressPictures = !!(flags & 65536);
        o.backupFile = !!(flags & 64);
        o.checkCompatibility = !!(flags & 4096);
        o.date1904 = !!(flags & 1);
        o.filterPrivacy = !!(flags & 8);
        o.hidePivotFieldList = !!(flags & 1024);
        o.promptedSolutions = !!(flags & 16);
        o.publishItems = !!(flags & 2048);
        o.refreshAllConnections = !!(flags & 262144);
        o.saveExternalLinkValues = !!(flags & 128);
        o.showBorderUnselectedTables = !!(flags & 4);
        o.showInkAnnotation = !!(flags & 32);
        o.showObjects = ["all", "placeholders", "none"][flags >> 13 & 3];
        o.showPivotChartFilter = !!(flags & 32768);
        o.updateLinks = ["userSet", "never", "always"][flags >> 8 & 3];
        return o;
      }
      function write_BrtWbProp(data, o) {
        if (!o)
          o = new_buf(72);
        var flags = 0;
        if (data) {
          if (data.filterPrivacy)
            flags |= 8;
        }
        o.write_shift(4, flags);
        o.write_shift(4, 0);
        write_XLSBCodeName(data && data.CodeName || "ThisWorkbook", o);
        return o.slice(0, o.l);
      }
      function parse_BrtFRTArchID$(data, length) {
        var o = {};
        data.read_shift(4);
        o.ArchID = data.read_shift(4);
        data.l += length - 8;
        return o;
      }
      function parse_BrtName(data, length, opts) {
        var end = data.l + length;
        data.l += 4;
        data.l += 1;
        var itab = data.read_shift(4);
        var name = parse_XLNameWideString(data);
        var formula = parse_XLSBNameParsedFormula(data, 0, opts);
        var comment = parse_XLNullableWideString(data);
        data.l = end;
        var out = { Name: name, Ptg: formula };
        if (itab < 268435455)
          out.Sheet = itab;
        if (comment)
          out.Comment = comment;
        return out;
      }
      function parse_wb_bin(data, opts) {
        var wb = { AppVersion: {}, WBProps: {}, WBView: [], Sheets: [], CalcPr: {}, xmlns: "" };
        var state = [];
        var pass = false;
        if (!opts)
          opts = {};
        opts.biff = 12;
        var Names = [];
        var supbooks = [[]];
        supbooks.SheetNames = [];
        supbooks.XTI = [];
        XLSBRecordEnum[16] = { n: "BrtFRTArchID$", f: parse_BrtFRTArchID$ };
        recordhopper(data, function hopper_wb(val, R, RT) {
          switch (RT) {
            case 156:
              supbooks.SheetNames.push(val.name);
              wb.Sheets.push(val);
              break;
            case 153:
              wb.WBProps = val;
              break;
            case 39:
              if (val.Sheet != null)
                opts.SID = val.Sheet;
              val.Ref = stringify_formula(val.Ptg, null, null, supbooks, opts);
              delete opts.SID;
              delete val.Ptg;
              Names.push(val);
              break;
            case 1036:
              break;
            case 357:
            case 358:
            case 355:
            case 667:
              if (!supbooks[0].length)
                supbooks[0] = [RT, val];
              else
                supbooks.push([RT, val]);
              supbooks[supbooks.length - 1].XTI = [];
              break;
            case 362:
              if (supbooks.length === 0) {
                supbooks[0] = [];
                supbooks[0].XTI = [];
              }
              supbooks[supbooks.length - 1].XTI = supbooks[supbooks.length - 1].XTI.concat(val);
              supbooks.XTI = supbooks.XTI.concat(val);
              break;
            case 361:
              break;
            case 2071:
            case 158:
            case 143:
            case 664:
            case 353:
              break;
            case 3072:
            case 3073:
            case 534:
            case 677:
            case 157:
            case 610:
            case 2050:
            case 155:
            case 548:
            case 676:
            case 128:
            case 665:
            case 2128:
            case 2125:
            case 549:
            case 2053:
            case 596:
            case 2076:
            case 2075:
            case 2082:
            case 397:
            case 154:
            case 1117:
            case 553:
            case 2091:
              break;
            case 35:
              state.push(RT);
              pass = true;
              break;
            case 36:
              state.pop();
              pass = false;
              break;
            case 37:
              state.push(RT);
              pass = true;
              break;
            case 38:
              state.pop();
              pass = false;
              break;
            case 16:
              break;
            default:
              if (R.T) {
              } else if (!pass || opts.WTF && state[state.length - 1] != 37 && state[state.length - 1] != 35)
                throw new Error("Unexpected record 0x" + RT.toString(16));
          }
        }, opts);
        parse_wb_defaults(wb);
        wb.Names = Names;
        wb.supbooks = supbooks;
        return wb;
      }
      function write_BUNDLESHS(ba, wb) {
        write_record(
          ba,
          143
          /* BrtBeginBundleShs */
        );
        for (var idx = 0; idx != wb.SheetNames.length; ++idx) {
          var viz = wb.Workbook && wb.Workbook.Sheets && wb.Workbook.Sheets[idx] && wb.Workbook.Sheets[idx].Hidden || 0;
          var d = { Hidden: viz, iTabID: idx + 1, strRelID: "rId" + (idx + 1), name: wb.SheetNames[idx] };
          write_record(ba, 156, write_BrtBundleSh(d));
        }
        write_record(
          ba,
          144
          /* BrtEndBundleShs */
        );
      }
      function write_BrtFileVersion(data, o) {
        if (!o)
          o = new_buf(127);
        for (var i = 0; i != 4; ++i)
          o.write_shift(4, 0);
        write_XLWideString("SheetJS", o);
        write_XLWideString(XLSX2.version, o);
        write_XLWideString(XLSX2.version, o);
        write_XLWideString("7262", o);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function write_BrtBookView(idx, o) {
        if (!o)
          o = new_buf(29);
        o.write_shift(-4, 0);
        o.write_shift(-4, 460);
        o.write_shift(4, 28800);
        o.write_shift(4, 17600);
        o.write_shift(4, 500);
        o.write_shift(4, idx);
        o.write_shift(4, idx);
        var flags = 120;
        o.write_shift(1, flags);
        return o.length > o.l ? o.slice(0, o.l) : o;
      }
      function write_BOOKVIEWS(ba, wb) {
        if (!wb.Workbook || !wb.Workbook.Sheets)
          return;
        var sheets = wb.Workbook.Sheets;
        var i = 0, vistab = -1, hidden = -1;
        for (; i < sheets.length; ++i) {
          if (!sheets[i] || !sheets[i].Hidden && vistab == -1)
            vistab = i;
          else if (sheets[i].Hidden == 1 && hidden == -1)
            hidden = i;
        }
        if (hidden > vistab)
          return;
        write_record(
          ba,
          135
          /* BrtBeginBookViews */
        );
        write_record(ba, 158, write_BrtBookView(vistab));
        write_record(
          ba,
          136
          /* BrtEndBookViews */
        );
      }
      function write_wb_bin(wb, opts) {
        var ba = buf_array();
        write_record(
          ba,
          131
          /* BrtBeginBook */
        );
        write_record(ba, 128, write_BrtFileVersion());
        write_record(ba, 153, write_BrtWbProp(wb.Workbook && wb.Workbook.WBProps || null));
        write_BOOKVIEWS(ba, wb, opts);
        write_BUNDLESHS(ba, wb, opts);
        write_record(
          ba,
          132
          /* BrtEndBook */
        );
        return ba.end();
      }
      function parse_wb(data, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_wb_bin(data, opts);
        return parse_wb_xml(data, opts);
      }
      function parse_ws(data, name, idx, opts, rels, wb, themes, styles) {
        if (name.slice(-4) === ".bin")
          return parse_ws_bin(data, opts, idx, rels, wb, themes, styles);
        return parse_ws_xml(data, opts, idx, rels, wb, themes, styles);
      }
      function parse_cs(data, name, idx, opts, rels, wb, themes, styles) {
        if (name.slice(-4) === ".bin")
          return parse_cs_bin(data, opts, idx, rels, wb, themes, styles);
        return parse_cs_xml(data, opts, idx, rels, wb, themes, styles);
      }
      function parse_ms(data, name, idx, opts, rels, wb, themes, styles) {
        if (name.slice(-4) === ".bin")
          return parse_ms_bin(data, opts, idx, rels, wb, themes, styles);
        return parse_ms_xml(data, opts, idx, rels, wb, themes, styles);
      }
      function parse_ds(data, name, idx, opts, rels, wb, themes, styles) {
        if (name.slice(-4) === ".bin")
          return parse_ds_bin(data, opts, idx, rels, wb, themes, styles);
        return parse_ds_xml(data, opts, idx, rels, wb, themes, styles);
      }
      function parse_sty(data, name, themes, opts) {
        if (name.slice(-4) === ".bin")
          return parse_sty_bin(data, themes, opts);
        return parse_sty_xml(data, themes, opts);
      }
      function parse_theme(data, name, opts) {
        return parse_theme_xml(data, opts);
      }
      function parse_sst(data, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_sst_bin(data, opts);
        return parse_sst_xml(data, opts);
      }
      function parse_cmnt(data, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_comments_bin(data, opts);
        return parse_comments_xml(data, opts);
      }
      function parse_cc(data, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_cc_bin(data, name, opts);
        return parse_cc_xml(data, name, opts);
      }
      function parse_xlink(data, rel, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_xlink_bin(data, rel, name, opts);
        return parse_xlink_xml(data, rel, name, opts);
      }
      function parse_xlmeta(data, name, opts) {
        if (name.slice(-4) === ".bin")
          return parse_xlmeta_bin(data, name, opts);
        return parse_xlmeta_xml(data, name, opts);
      }
      function write_wb(wb, name, opts) {
        return (name.slice(-4) === ".bin" ? write_wb_bin : write_wb_xml)(wb, opts);
      }
      function write_ws(data, name, opts, wb, rels) {
        return (name.slice(-4) === ".bin" ? write_ws_bin : write_ws_xml)(data, opts, wb, rels);
      }
      function write_cs(data, name, opts, wb, rels) {
        return (name.slice(-4) === ".bin" ? write_cs_bin : write_cs_xml)(data, opts, wb, rels);
      }
      function write_sty(data, name, opts) {
        return (name.slice(-4) === ".bin" ? write_sty_bin : write_sty_xml)(data, opts);
      }
      function write_sst(data, name, opts) {
        return (name.slice(-4) === ".bin" ? write_sst_bin : write_sst_xml)(data, opts);
      }
      function write_cmnt(data, name, opts) {
        return (name.slice(-4) === ".bin" ? write_comments_bin : write_comments_xml)(data, opts);
      }
      function write_xlmeta(name) {
        return (name.slice(-4) === ".bin" ? write_xlmeta_bin : write_xlmeta_xml)();
      }
      var attregexg2 = /([\w:]+)=((?:")([^"]*)(?:")|(?:')([^']*)(?:'))/g;
      var attregex2 = /([\w:]+)=((?:")(?:[^"]*)(?:")|(?:')(?:[^']*)(?:'))/;
      function xlml_parsexmltag(tag, skip_root) {
        var words = tag.split(/\s+/);
        var z = [];
        if (!skip_root)
          z[0] = words[0];
        if (words.length === 1)
          return z;
        var m = tag.match(attregexg2), y, j, w, i;
        if (m)
          for (i = 0; i != m.length; ++i) {
            y = m[i].match(attregex2);
            if ((j = y[1].indexOf(":")) === -1)
              z[y[1]] = y[2].slice(1, y[2].length - 1);
            else {
              if (y[1].slice(0, 6) === "xmlns:")
                w = "xmlns" + y[1].slice(6);
              else
                w = y[1].slice(j + 1);
              z[w] = y[2].slice(1, y[2].length - 1);
            }
          }
        return z;
      }
      function xlml_parsexmltagobj(tag) {
        var words = tag.split(/\s+/);
        var z = {};
        if (words.length === 1)
          return z;
        var m = tag.match(attregexg2), y, j, w, i;
        if (m)
          for (i = 0; i != m.length; ++i) {
            y = m[i].match(attregex2);
            if ((j = y[1].indexOf(":")) === -1)
              z[y[1]] = y[2].slice(1, y[2].length - 1);
            else {
              if (y[1].slice(0, 6) === "xmlns:")
                w = "xmlns" + y[1].slice(6);
              else
                w = y[1].slice(j + 1);
              z[w] = y[2].slice(1, y[2].length - 1);
            }
          }
        return z;
      }
      var XLMLFormatMap;
      function xlml_format(format2, value2) {
        var fmt = XLMLFormatMap[format2] || unescapexml(format2);
        if (fmt === "General")
          return SSF_general(value2);
        return SSF_format(fmt, value2);
      }
      function xlml_set_custprop(Custprops, key, cp, val) {
        var oval = val;
        switch ((cp[0].match(/dt:dt="([\w.]+)"/) || ["", ""])[1]) {
          case "boolean":
            oval = parsexmlbool(val);
            break;
          case "i2":
          case "int":
            oval = parseInt(val, 10);
            break;
          case "r4":
          case "float":
            oval = parseFloat(val);
            break;
          case "date":
          case "dateTime.tz":
            oval = parseDate(val);
            break;
          case "i8":
          case "string":
          case "fixed":
          case "uuid":
          case "bin.base64":
            break;
          default:
            throw new Error("bad custprop:" + cp[0]);
        }
        Custprops[unescapexml(key)] = oval;
      }
      function safe_format_xlml(cell, nf, o) {
        if (cell.t === "z")
          return;
        if (!o || o.cellText !== false)
          try {
            if (cell.t === "e") {
              cell.w = cell.w || BErr[cell.v];
            } else if (nf === "General") {
              if (cell.t === "n") {
                if ((cell.v | 0) === cell.v)
                  cell.w = cell.v.toString(10);
                else
                  cell.w = SSF_general_num(cell.v);
              } else
                cell.w = SSF_general(cell.v);
            } else
              cell.w = xlml_format(nf || "General", cell.v);
          } catch (e) {
            if (o.WTF)
              throw e;
          }
        try {
          var z = XLMLFormatMap[nf] || nf || "General";
          if (o.cellNF)
            cell.z = z;
          if (o.cellDates && cell.t == "n" && fmt_is_date(z)) {
            var _d = SSF_parse_date_code(cell.v);
            if (_d) {
              cell.t = "d";
              cell.v = new Date(_d.y, _d.m - 1, _d.d, _d.H, _d.M, _d.S, _d.u);
            }
          }
        } catch (e) {
          if (o.WTF)
            throw e;
        }
      }
      function process_style_xlml(styles, stag, opts) {
        if (opts.cellStyles) {
          if (stag.Interior) {
            var I = stag.Interior;
            if (I.Pattern)
              I.patternType = XLMLPatternTypeMap[I.Pattern] || I.Pattern;
          }
        }
        styles[stag.ID] = stag;
      }
      function parse_xlml_data(xml, ss, data, cell, base, styles, csty, row, arrayf, o) {
        var nf = "General", sid = cell.StyleID, S = {};
        o = o || {};
        var interiors = [];
        var i = 0;
        if (sid === void 0 && row)
          sid = row.StyleID;
        if (sid === void 0 && csty)
          sid = csty.StyleID;
        while (styles[sid] !== void 0) {
          if (styles[sid].nf)
            nf = styles[sid].nf;
          if (styles[sid].Interior)
            interiors.push(styles[sid].Interior);
          if (!styles[sid].Parent)
            break;
          sid = styles[sid].Parent;
        }
        switch (data.Type) {
          case "Boolean":
            cell.t = "b";
            cell.v = parsexmlbool(xml);
            break;
          case "String":
            cell.t = "s";
            cell.r = xlml_fixstr(unescapexml(xml));
            cell.v = xml.indexOf("<") > -1 ? unescapexml(ss || xml).replace(/<.*?>/g, "") : cell.r;
            break;
          case "DateTime":
            if (xml.slice(-1) != "Z")
              xml += "Z";
            cell.v = (parseDate(xml) - new Date(Date.UTC(1899, 11, 30))) / (24 * 60 * 60 * 1e3);
            if (cell.v !== cell.v)
              cell.v = unescapexml(xml);
            else if (cell.v < 60)
              cell.v = cell.v - 1;
            if (!nf || nf == "General")
              nf = "yyyy-mm-dd";
          case "Number":
            if (cell.v === void 0)
              cell.v = +xml;
            if (!cell.t)
              cell.t = "n";
            break;
          case "Error":
            cell.t = "e";
            cell.v = RBErr[xml];
            if (o.cellText !== false)
              cell.w = xml;
            break;
          default:
            if (xml == "" && ss == "") {
              cell.t = "z";
            } else {
              cell.t = "s";
              cell.v = xlml_fixstr(ss || xml);
            }
            break;
        }
        safe_format_xlml(cell, nf, o);
        if (o.cellFormula !== false) {
          if (cell.Formula) {
            var fstr = unescapexml(cell.Formula);
            if (fstr.charCodeAt(0) == 61)
              fstr = fstr.slice(1);
            cell.f = rc_to_a1(fstr, base);
            delete cell.Formula;
            if (cell.ArrayRange == "RC")
              cell.F = rc_to_a1("RC:RC", base);
            else if (cell.ArrayRange) {
              cell.F = rc_to_a1(cell.ArrayRange, base);
              arrayf.push([safe_decode_range(cell.F), cell.F]);
            }
          } else {
            for (i = 0; i < arrayf.length; ++i)
              if (base.r >= arrayf[i][0].s.r && base.r <= arrayf[i][0].e.r) {
                if (base.c >= arrayf[i][0].s.c && base.c <= arrayf[i][0].e.c)
                  cell.F = arrayf[i][1];
              }
          }
        }
        if (o.cellStyles) {
          interiors.forEach(function(x) {
            if (!S.patternType && x.patternType)
              S.patternType = x.patternType;
          });
          cell.s = S;
        }
        if (cell.StyleID !== void 0)
          cell.ixfe = cell.StyleID;
      }
      function xlml_clean_comment(comment) {
        comment.t = comment.v || "";
        comment.t = comment.t.replace(/\r\n/g, "\n").replace(/\r/g, "\n");
        comment.v = comment.w = comment.ixfe = void 0;
      }
      function parse_xlml_xml(d, _opts) {
        var opts = _opts || {};
        make_ssf();
        var str = debom(xlml_normalize(d));
        if (opts.type == "binary" || opts.type == "array" || opts.type == "base64") {
          if (typeof $cptable !== "undefined")
            str = $cptable.utils.decode(65001, char_codes(str));
          else
            str = utf8read(str);
        }
        var opening = str.slice(0, 1024).toLowerCase(), ishtml = false;
        opening = opening.replace(/".*?"/g, "");
        if ((opening.indexOf(">") & 1023) > Math.min(opening.indexOf(",") & 1023, opening.indexOf(";") & 1023)) {
          var _o = dup(opts);
          _o.type = "string";
          return PRN.to_workbook(str, _o);
        }
        if (opening.indexOf("<?xml") == -1)
          ["html", "table", "head", "meta", "script", "style", "div"].forEach(function(tag) {
            if (opening.indexOf("<" + tag) >= 0)
              ishtml = true;
          });
        if (ishtml)
          return html_to_workbook(str, opts);
        XLMLFormatMap = {
          "General Number": "General",
          "General Date": table_fmt[22],
          "Long Date": "dddd, mmmm dd, yyyy",
          "Medium Date": table_fmt[15],
          "Short Date": table_fmt[14],
          "Long Time": table_fmt[19],
          "Medium Time": table_fmt[18],
          "Short Time": table_fmt[20],
          "Currency": '"$"#,##0.00_);[Red]\\("$"#,##0.00\\)',
          "Fixed": table_fmt[2],
          "Standard": table_fmt[4],
          "Percent": table_fmt[10],
          "Scientific": table_fmt[11],
          "Yes/No": '"Yes";"Yes";"No";@',
          "True/False": '"True";"True";"False";@',
          "On/Off": '"Yes";"Yes";"No";@'
        };
        var Rn;
        var state = [], tmp;
        if (DENSE != null && opts.dense == null)
          opts.dense = DENSE;
        var sheets = {}, sheetnames = [], cursheet = opts.dense ? [] : {}, sheetname = "";
        var cell = {}, row = {};
        var dtag = xlml_parsexmltag('<Data ss:Type="String">'), didx = 0;
        var c = 0, r = 0;
        var refguess = { s: { r: 2e6, c: 2e6 }, e: { r: 0, c: 0 } };
        var styles = {}, stag = {};
        var ss = "", fidx = 0;
        var merges = [];
        var Props = {}, Custprops = {}, pidx = 0, cp = [];
        var comments = [], comment = {};
        var cstys = [], csty, seencol = false;
        var arrayf = [];
        var rowinfo = [], rowobj = {}, cc = 0, rr = 0;
        var Workbook = { Sheets: [], WBProps: { date1904: false } }, wsprops = {};
        xlmlregex.lastIndex = 0;
        str = str.replace(/<!--([\s\S]*?)-->/mg, "");
        var raw_Rn3 = "";
        while (Rn = xlmlregex.exec(str))
          switch (Rn[3] = (raw_Rn3 = Rn[3]).toLowerCase()) {
            case "data":
              if (raw_Rn3 == "data") {
                if (Rn[1] === "/") {
                  if ((tmp = state.pop())[0] !== Rn[3])
                    throw new Error("Bad state: " + tmp.join("|"));
                } else if (Rn[0].charAt(Rn[0].length - 2) !== "/")
                  state.push([Rn[3], true]);
                break;
              }
              if (state[state.length - 1][1])
                break;
              if (Rn[1] === "/")
                parse_xlml_data(str.slice(didx, Rn.index), ss, dtag, state[state.length - 1][0] == /*"Comment"*/
                "comment" ? comment : cell, { c, r }, styles, cstys[c], row, arrayf, opts);
              else {
                ss = "";
                dtag = xlml_parsexmltag(Rn[0]);
                didx = Rn.index + Rn[0].length;
              }
              break;
            case "cell":
              if (Rn[1] === "/") {
                if (comments.length > 0)
                  cell.c = comments;
                if ((!opts.sheetRows || opts.sheetRows > r) && cell.v !== void 0) {
                  if (opts.dense) {
                    if (!cursheet[r])
                      cursheet[r] = [];
                    cursheet[r][c] = cell;
                  } else
                    cursheet[encode_col(c) + encode_row(r)] = cell;
                }
                if (cell.HRef) {
                  cell.l = { Target: unescapexml(cell.HRef) };
                  if (cell.HRefScreenTip)
                    cell.l.Tooltip = cell.HRefScreenTip;
                  delete cell.HRef;
                  delete cell.HRefScreenTip;
                }
                if (cell.MergeAcross || cell.MergeDown) {
                  cc = c + (parseInt(cell.MergeAcross, 10) | 0);
                  rr = r + (parseInt(cell.MergeDown, 10) | 0);
                  merges.push({ s: { c, r }, e: { c: cc, r: rr } });
                }
                if (!opts.sheetStubs) {
                  if (cell.MergeAcross)
                    c = cc + 1;
                  else
                    ++c;
                } else if (cell.MergeAcross || cell.MergeDown) {
                  for (var cma = c; cma <= cc; ++cma) {
                    for (var cmd = r; cmd <= rr; ++cmd) {
                      if (cma > c || cmd > r) {
                        if (opts.dense) {
                          if (!cursheet[cmd])
                            cursheet[cmd] = [];
                          cursheet[cmd][cma] = { t: "z" };
                        } else
                          cursheet[encode_col(cma) + encode_row(cmd)] = { t: "z" };
                      }
                    }
                  }
                  c = cc + 1;
                } else
                  ++c;
              } else {
                cell = xlml_parsexmltagobj(Rn[0]);
                if (cell.Index)
                  c = +cell.Index - 1;
                if (c < refguess.s.c)
                  refguess.s.c = c;
                if (c > refguess.e.c)
                  refguess.e.c = c;
                if (Rn[0].slice(-2) === "/>")
                  ++c;
                comments = [];
              }
              break;
            case "row":
              if (Rn[1] === "/" || Rn[0].slice(-2) === "/>") {
                if (r < refguess.s.r)
                  refguess.s.r = r;
                if (r > refguess.e.r)
                  refguess.e.r = r;
                if (Rn[0].slice(-2) === "/>") {
                  row = xlml_parsexmltag(Rn[0]);
                  if (row.Index)
                    r = +row.Index - 1;
                }
                c = 0;
                ++r;
              } else {
                row = xlml_parsexmltag(Rn[0]);
                if (row.Index)
                  r = +row.Index - 1;
                rowobj = {};
                if (row.AutoFitHeight == "0" || row.Height) {
                  rowobj.hpx = parseInt(row.Height, 10);
                  rowobj.hpt = px2pt(rowobj.hpx);
                  rowinfo[r] = rowobj;
                }
                if (row.Hidden == "1") {
                  rowobj.hidden = true;
                  rowinfo[r] = rowobj;
                }
              }
              break;
            case "worksheet":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
                sheetnames.push(sheetname);
                if (refguess.s.r <= refguess.e.r && refguess.s.c <= refguess.e.c) {
                  cursheet["!ref"] = encode_range(refguess);
                  if (opts.sheetRows && opts.sheetRows <= refguess.e.r) {
                    cursheet["!fullref"] = cursheet["!ref"];
                    refguess.e.r = opts.sheetRows - 1;
                    cursheet["!ref"] = encode_range(refguess);
                  }
                }
                if (merges.length)
                  cursheet["!merges"] = merges;
                if (cstys.length > 0)
                  cursheet["!cols"] = cstys;
                if (rowinfo.length > 0)
                  cursheet["!rows"] = rowinfo;
                sheets[sheetname] = cursheet;
              } else {
                refguess = { s: { r: 2e6, c: 2e6 }, e: { r: 0, c: 0 } };
                r = c = 0;
                state.push([Rn[3], false]);
                tmp = xlml_parsexmltag(Rn[0]);
                sheetname = unescapexml(tmp.Name);
                cursheet = opts.dense ? [] : {};
                merges = [];
                arrayf = [];
                rowinfo = [];
                wsprops = { name: sheetname, Hidden: 0 };
                Workbook.Sheets.push(wsprops);
              }
              break;
            case "table":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
              } else if (Rn[0].slice(-2) == "/>")
                break;
              else {
                state.push([Rn[3], false]);
                cstys = [];
                seencol = false;
              }
              break;
            case "style":
              if (Rn[1] === "/")
                process_style_xlml(styles, stag, opts);
              else
                stag = xlml_parsexmltag(Rn[0]);
              break;
            case "numberformat":
              stag.nf = unescapexml(xlml_parsexmltag(Rn[0]).Format || "General");
              if (XLMLFormatMap[stag.nf])
                stag.nf = XLMLFormatMap[stag.nf];
              for (var ssfidx = 0; ssfidx != 392; ++ssfidx)
                if (table_fmt[ssfidx] == stag.nf)
                  break;
              if (ssfidx == 392) {
                for (ssfidx = 57; ssfidx != 392; ++ssfidx)
                  if (table_fmt[ssfidx] == null) {
                    SSF_load(stag.nf, ssfidx);
                    break;
                  }
              }
              break;
            case "column":
              if (state[state.length - 1][0] !== /*'Table'*/
              "table")
                break;
              csty = xlml_parsexmltag(Rn[0]);
              if (csty.Hidden) {
                csty.hidden = true;
                delete csty.Hidden;
              }
              if (csty.Width)
                csty.wpx = parseInt(csty.Width, 10);
              if (!seencol && csty.wpx > 10) {
                seencol = true;
                MDW = DEF_MDW;
                for (var _col = 0; _col < cstys.length; ++_col)
                  if (cstys[_col])
                    process_col(cstys[_col]);
              }
              if (seencol)
                process_col(csty);
              cstys[csty.Index - 1 || cstys.length] = csty;
              for (var i = 0; i < +csty.Span; ++i)
                cstys[cstys.length] = dup(csty);
              break;
            case "namedrange":
              if (Rn[1] === "/")
                break;
              if (!Workbook.Names)
                Workbook.Names = [];
              var _NamedRange = parsexmltag(Rn[0]);
              var _DefinedName = {
                Name: _NamedRange.Name,
                Ref: rc_to_a1(_NamedRange.RefersTo.slice(1), { r: 0, c: 0 })
              };
              if (Workbook.Sheets.length > 0)
                _DefinedName.Sheet = Workbook.Sheets.length - 1;
              Workbook.Names.push(_DefinedName);
              break;
            case "namedcell":
              break;
            case "b":
              break;
            case "i":
              break;
            case "u":
              break;
            case "s":
              break;
            case "em":
              break;
            case "h2":
              break;
            case "h3":
              break;
            case "sub":
              break;
            case "sup":
              break;
            case "span":
              break;
            case "alignment":
              break;
            case "borders":
              break;
            case "border":
              break;
            case "font":
              if (Rn[0].slice(-2) === "/>")
                break;
              else if (Rn[1] === "/")
                ss += str.slice(fidx, Rn.index);
              else
                fidx = Rn.index + Rn[0].length;
              break;
            case "interior":
              if (!opts.cellStyles)
                break;
              stag.Interior = xlml_parsexmltag(Rn[0]);
              break;
            case "protection":
              break;
            case "author":
            case "title":
            case "description":
            case "created":
            case "keywords":
            case "subject":
            case "category":
            case "company":
            case "lastauthor":
            case "lastsaved":
            case "lastprinted":
            case "version":
            case "revision":
            case "totaltime":
            case "hyperlinkbase":
            case "manager":
            case "contentstatus":
            case "identifier":
            case "language":
            case "appname":
              if (Rn[0].slice(-2) === "/>")
                break;
              else if (Rn[1] === "/")
                xlml_set_prop(Props, raw_Rn3, str.slice(pidx, Rn.index));
              else
                pidx = Rn.index + Rn[0].length;
              break;
            case "paragraphs":
              break;
            case "styles":
            case "workbook":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
              } else
                state.push([Rn[3], false]);
              break;
            case "comment":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
                xlml_clean_comment(comment);
                comments.push(comment);
              } else {
                state.push([Rn[3], false]);
                tmp = xlml_parsexmltag(Rn[0]);
                comment = { a: tmp.Author };
              }
              break;
            case "autofilter":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/") {
                var AutoFilter = xlml_parsexmltag(Rn[0]);
                cursheet["!autofilter"] = { ref: rc_to_a1(AutoFilter.Range).replace(/\$/g, "") };
                state.push([Rn[3], true]);
              }
              break;
            case "name":
              break;
            case "datavalidation":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
              } else {
                if (Rn[0].charAt(Rn[0].length - 2) !== "/")
                  state.push([Rn[3], true]);
              }
              break;
            case "pixelsperinch":
              break;
            case "componentoptions":
            case "documentproperties":
            case "customdocumentproperties":
            case "officedocumentsettings":
            case "pivottable":
            case "pivotcache":
            case "names":
            case "mapinfo":
            case "pagebreaks":
            case "querytable":
            case "sorting":
            case "schema":
            case "conditionalformatting":
            case "smarttagtype":
            case "smarttags":
            case "excelworkbook":
            case "workbookoptions":
            case "worksheetoptions":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw new Error("Bad state: " + tmp.join("|"));
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/")
                state.push([Rn[3], true]);
              break;
            case "null":
              break;
            default:
              if (state.length == 0 && Rn[3] == "document")
                return parse_fods(str, opts);
              if (state.length == 0 && Rn[3] == "uof")
                return parse_fods(str, opts);
              var seen = true;
              switch (state[state.length - 1][0]) {
                case "officedocumentsettings":
                  switch (Rn[3]) {
                    case "allowpng":
                      break;
                    case "removepersonalinformation":
                      break;
                    case "downloadcomponents":
                      break;
                    case "locationofcomponents":
                      break;
                    case "colors":
                      break;
                    case "color":
                      break;
                    case "index":
                      break;
                    case "rgb":
                      break;
                    case "targetscreensize":
                      break;
                    case "readonlyrecommended":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "componentoptions":
                  switch (Rn[3]) {
                    case "toolbar":
                      break;
                    case "hideofficelogo":
                      break;
                    case "spreadsheetautofit":
                      break;
                    case "label":
                      break;
                    case "caption":
                      break;
                    case "maxheight":
                      break;
                    case "maxwidth":
                      break;
                    case "nextsheetnumber":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "excelworkbook":
                  switch (Rn[3]) {
                    case "date1904":
                      Workbook.WBProps.date1904 = true;
                      break;
                    case "windowheight":
                      break;
                    case "windowwidth":
                      break;
                    case "windowtopx":
                      break;
                    case "windowtopy":
                      break;
                    case "tabratio":
                      break;
                    case "protectstructure":
                      break;
                    case "protectwindow":
                      break;
                    case "protectwindows":
                      break;
                    case "activesheet":
                      break;
                    case "displayinknotes":
                      break;
                    case "firstvisiblesheet":
                      break;
                    case "supbook":
                      break;
                    case "sheetname":
                      break;
                    case "sheetindex":
                      break;
                    case "sheetindexfirst":
                      break;
                    case "sheetindexlast":
                      break;
                    case "dll":
                      break;
                    case "acceptlabelsinformulas":
                      break;
                    case "donotsavelinkvalues":
                      break;
                    case "iteration":
                      break;
                    case "maxiterations":
                      break;
                    case "maxchange":
                      break;
                    case "path":
                      break;
                    case "xct":
                      break;
                    case "count":
                      break;
                    case "selectedsheets":
                      break;
                    case "calculation":
                      break;
                    case "uncalced":
                      break;
                    case "startupprompt":
                      break;
                    case "crn":
                      break;
                    case "externname":
                      break;
                    case "formula":
                      break;
                    case "colfirst":
                      break;
                    case "collast":
                      break;
                    case "wantadvise":
                      break;
                    case "boolean":
                      break;
                    case "error":
                      break;
                    case "text":
                      break;
                    case "ole":
                      break;
                    case "noautorecover":
                      break;
                    case "publishobjects":
                      break;
                    case "donotcalculatebeforesave":
                      break;
                    case "number":
                      break;
                    case "refmoder1c1":
                      break;
                    case "embedsavesmarttags":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "workbookoptions":
                  switch (Rn[3]) {
                    case "owcversion":
                      break;
                    case "height":
                      break;
                    case "width":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "worksheetoptions":
                  switch (Rn[3]) {
                    case "visible":
                      if (Rn[0].slice(-2) === "/>") {
                      } else if (Rn[1] === "/")
                        switch (str.slice(pidx, Rn.index)) {
                          case "SheetHidden":
                            wsprops.Hidden = 1;
                            break;
                          case "SheetVeryHidden":
                            wsprops.Hidden = 2;
                            break;
                        }
                      else
                        pidx = Rn.index + Rn[0].length;
                      break;
                    case "header":
                      if (!cursheet["!margins"])
                        default_margins(cursheet["!margins"] = {}, "xlml");
                      if (!isNaN(+parsexmltag(Rn[0]).Margin))
                        cursheet["!margins"].header = +parsexmltag(Rn[0]).Margin;
                      break;
                    case "footer":
                      if (!cursheet["!margins"])
                        default_margins(cursheet["!margins"] = {}, "xlml");
                      if (!isNaN(+parsexmltag(Rn[0]).Margin))
                        cursheet["!margins"].footer = +parsexmltag(Rn[0]).Margin;
                      break;
                    case "pagemargins":
                      var pagemargins = parsexmltag(Rn[0]);
                      if (!cursheet["!margins"])
                        default_margins(cursheet["!margins"] = {}, "xlml");
                      if (!isNaN(+pagemargins.Top))
                        cursheet["!margins"].top = +pagemargins.Top;
                      if (!isNaN(+pagemargins.Left))
                        cursheet["!margins"].left = +pagemargins.Left;
                      if (!isNaN(+pagemargins.Right))
                        cursheet["!margins"].right = +pagemargins.Right;
                      if (!isNaN(+pagemargins.Bottom))
                        cursheet["!margins"].bottom = +pagemargins.Bottom;
                      break;
                    case "displayrighttoleft":
                      if (!Workbook.Views)
                        Workbook.Views = [];
                      if (!Workbook.Views[0])
                        Workbook.Views[0] = {};
                      Workbook.Views[0].RTL = true;
                      break;
                    case "freezepanes":
                      break;
                    case "frozennosplit":
                      break;
                    case "splithorizontal":
                    case "splitvertical":
                      break;
                    case "donotdisplaygridlines":
                      break;
                    case "activerow":
                      break;
                    case "activecol":
                      break;
                    case "toprowbottompane":
                      break;
                    case "leftcolumnrightpane":
                      break;
                    case "unsynced":
                      break;
                    case "print":
                      break;
                    case "printerrors":
                      break;
                    case "panes":
                      break;
                    case "scale":
                      break;
                    case "pane":
                      break;
                    case "number":
                      break;
                    case "layout":
                      break;
                    case "pagesetup":
                      break;
                    case "selected":
                      break;
                    case "protectobjects":
                      break;
                    case "enableselection":
                      break;
                    case "protectscenarios":
                      break;
                    case "validprinterinfo":
                      break;
                    case "horizontalresolution":
                      break;
                    case "verticalresolution":
                      break;
                    case "numberofcopies":
                      break;
                    case "activepane":
                      break;
                    case "toprowvisible":
                      break;
                    case "leftcolumnvisible":
                      break;
                    case "fittopage":
                      break;
                    case "rangeselection":
                      break;
                    case "papersizeindex":
                      break;
                    case "pagelayoutzoom":
                      break;
                    case "pagebreakzoom":
                      break;
                    case "filteron":
                      break;
                    case "fitwidth":
                      break;
                    case "fitheight":
                      break;
                    case "commentslayout":
                      break;
                    case "zoom":
                      break;
                    case "lefttoright":
                      break;
                    case "gridlines":
                      break;
                    case "allowsort":
                      break;
                    case "allowfilter":
                      break;
                    case "allowinsertrows":
                      break;
                    case "allowdeleterows":
                      break;
                    case "allowinsertcols":
                      break;
                    case "allowdeletecols":
                      break;
                    case "allowinserthyperlinks":
                      break;
                    case "allowformatcells":
                      break;
                    case "allowsizecols":
                      break;
                    case "allowsizerows":
                      break;
                    case "nosummaryrowsbelowdetail":
                      if (!cursheet["!outline"])
                        cursheet["!outline"] = {};
                      cursheet["!outline"].above = true;
                      break;
                    case "tabcolorindex":
                      break;
                    case "donotdisplayheadings":
                      break;
                    case "showpagelayoutzoom":
                      break;
                    case "nosummarycolumnsrightdetail":
                      if (!cursheet["!outline"])
                        cursheet["!outline"] = {};
                      cursheet["!outline"].left = true;
                      break;
                    case "blackandwhite":
                      break;
                    case "donotdisplayzeros":
                      break;
                    case "displaypagebreak":
                      break;
                    case "rowcolheadings":
                      break;
                    case "donotdisplayoutline":
                      break;
                    case "noorientation":
                      break;
                    case "allowusepivottables":
                      break;
                    case "zeroheight":
                      break;
                    case "viewablerange":
                      break;
                    case "selection":
                      break;
                    case "protectcontents":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "pivottable":
                case "pivotcache":
                  switch (Rn[3]) {
                    case "immediateitemsondrop":
                      break;
                    case "showpagemultipleitemlabel":
                      break;
                    case "compactrowindent":
                      break;
                    case "location":
                      break;
                    case "pivotfield":
                      break;
                    case "orientation":
                      break;
                    case "layoutform":
                      break;
                    case "layoutsubtotallocation":
                      break;
                    case "layoutcompactrow":
                      break;
                    case "position":
                      break;
                    case "pivotitem":
                      break;
                    case "datatype":
                      break;
                    case "datafield":
                      break;
                    case "sourcename":
                      break;
                    case "parentfield":
                      break;
                    case "ptlineitems":
                      break;
                    case "ptlineitem":
                      break;
                    case "countofsameitems":
                      break;
                    case "item":
                      break;
                    case "itemtype":
                      break;
                    case "ptsource":
                      break;
                    case "cacheindex":
                      break;
                    case "consolidationreference":
                      break;
                    case "filename":
                      break;
                    case "reference":
                      break;
                    case "nocolumngrand":
                      break;
                    case "norowgrand":
                      break;
                    case "blanklineafteritems":
                      break;
                    case "hidden":
                      break;
                    case "subtotal":
                      break;
                    case "basefield":
                      break;
                    case "mapchilditems":
                      break;
                    case "function":
                      break;
                    case "refreshonfileopen":
                      break;
                    case "printsettitles":
                      break;
                    case "mergelabels":
                      break;
                    case "defaultversion":
                      break;
                    case "refreshname":
                      break;
                    case "refreshdate":
                      break;
                    case "refreshdatecopy":
                      break;
                    case "versionlastrefresh":
                      break;
                    case "versionlastupdate":
                      break;
                    case "versionupdateablemin":
                      break;
                    case "versionrefreshablemin":
                      break;
                    case "calculation":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "pagebreaks":
                  switch (Rn[3]) {
                    case "colbreaks":
                      break;
                    case "colbreak":
                      break;
                    case "rowbreaks":
                      break;
                    case "rowbreak":
                      break;
                    case "colstart":
                      break;
                    case "colend":
                      break;
                    case "rowend":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "autofilter":
                  switch (Rn[3]) {
                    case "autofiltercolumn":
                      break;
                    case "autofiltercondition":
                      break;
                    case "autofilterand":
                      break;
                    case "autofilteror":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "querytable":
                  switch (Rn[3]) {
                    case "id":
                      break;
                    case "autoformatfont":
                      break;
                    case "autoformatpattern":
                      break;
                    case "querysource":
                      break;
                    case "querytype":
                      break;
                    case "enableredirections":
                      break;
                    case "refreshedinxl9":
                      break;
                    case "urlstring":
                      break;
                    case "htmltables":
                      break;
                    case "connection":
                      break;
                    case "commandtext":
                      break;
                    case "refreshinfo":
                      break;
                    case "notitles":
                      break;
                    case "nextid":
                      break;
                    case "columninfo":
                      break;
                    case "overwritecells":
                      break;
                    case "donotpromptforfile":
                      break;
                    case "textwizardsettings":
                      break;
                    case "source":
                      break;
                    case "number":
                      break;
                    case "decimal":
                      break;
                    case "thousandseparator":
                      break;
                    case "trailingminusnumbers":
                      break;
                    case "formatsettings":
                      break;
                    case "fieldtype":
                      break;
                    case "delimiters":
                      break;
                    case "tab":
                      break;
                    case "comma":
                      break;
                    case "autoformatname":
                      break;
                    case "versionlastedit":
                      break;
                    case "versionlastrefresh":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "datavalidation":
                  switch (Rn[3]) {
                    case "range":
                      break;
                    case "type":
                      break;
                    case "min":
                      break;
                    case "max":
                      break;
                    case "sort":
                      break;
                    case "descending":
                      break;
                    case "order":
                      break;
                    case "casesensitive":
                      break;
                    case "value":
                      break;
                    case "errorstyle":
                      break;
                    case "errormessage":
                      break;
                    case "errortitle":
                      break;
                    case "inputmessage":
                      break;
                    case "inputtitle":
                      break;
                    case "combohide":
                      break;
                    case "inputhide":
                      break;
                    case "condition":
                      break;
                    case "qualifier":
                      break;
                    case "useblank":
                      break;
                    case "value1":
                      break;
                    case "value2":
                      break;
                    case "format":
                      break;
                    case "cellrangelist":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "sorting":
                case "conditionalformatting":
                  switch (Rn[3]) {
                    case "range":
                      break;
                    case "type":
                      break;
                    case "min":
                      break;
                    case "max":
                      break;
                    case "sort":
                      break;
                    case "descending":
                      break;
                    case "order":
                      break;
                    case "casesensitive":
                      break;
                    case "value":
                      break;
                    case "errorstyle":
                      break;
                    case "errormessage":
                      break;
                    case "errortitle":
                      break;
                    case "cellrangelist":
                      break;
                    case "inputmessage":
                      break;
                    case "inputtitle":
                      break;
                    case "combohide":
                      break;
                    case "inputhide":
                      break;
                    case "condition":
                      break;
                    case "qualifier":
                      break;
                    case "useblank":
                      break;
                    case "value1":
                      break;
                    case "value2":
                      break;
                    case "format":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "mapinfo":
                case "schema":
                case "data":
                  switch (Rn[3]) {
                    case "map":
                      break;
                    case "entry":
                      break;
                    case "range":
                      break;
                    case "xpath":
                      break;
                    case "field":
                      break;
                    case "xsdtype":
                      break;
                    case "filteron":
                      break;
                    case "aggregate":
                      break;
                    case "elementtype":
                      break;
                    case "attributetype":
                      break;
                    case "schema":
                    case "element":
                    case "complextype":
                    case "datatype":
                    case "all":
                    case "attribute":
                    case "extends":
                      break;
                    case "row":
                      break;
                    default:
                      seen = false;
                  }
                  break;
                case "smarttags":
                  break;
                default:
                  seen = false;
                  break;
              }
              if (seen)
                break;
              if (Rn[3].match(/!\[CDATA/))
                break;
              if (!state[state.length - 1][1])
                throw "Unrecognized tag: " + Rn[3] + "|" + state.join("|");
              if (state[state.length - 1][0] === /*'CustomDocumentProperties'*/
              "customdocumentproperties") {
                if (Rn[0].slice(-2) === "/>")
                  break;
                else if (Rn[1] === "/")
                  xlml_set_custprop(Custprops, raw_Rn3, cp, str.slice(pidx, Rn.index));
                else {
                  cp = Rn;
                  pidx = Rn.index + Rn[0].length;
                }
                break;
              }
              if (opts.WTF)
                throw "Unrecognized tag: " + Rn[3] + "|" + state.join("|");
          }
        var out = {};
        if (!opts.bookSheets && !opts.bookProps)
          out.Sheets = sheets;
        out.SheetNames = sheetnames;
        out.Workbook = Workbook;
        out.SSF = dup(table_fmt);
        out.Props = Props;
        out.Custprops = Custprops;
        return out;
      }
      function parse_xlml(data, opts) {
        fix_read_opts(opts = opts || {});
        switch (opts.type || "base64") {
          case "base64":
            return parse_xlml_xml(Base64_decode(data), opts);
          case "binary":
          case "buffer":
          case "file":
            return parse_xlml_xml(data, opts);
          case "array":
            return parse_xlml_xml(a2s(data), opts);
        }
      }
      function write_props_xlml(wb, opts) {
        var o = [];
        if (wb.Props)
          o.push(xlml_write_docprops(wb.Props, opts));
        if (wb.Custprops)
          o.push(xlml_write_custprops(wb.Props, wb.Custprops, opts));
        return o.join("");
      }
      function write_wb_xlml() {
        return "";
      }
      function write_sty_xlml(wb, opts) {
        var styles = ['<Style ss:ID="Default" ss:Name="Normal"><NumberFormat/></Style>'];
        opts.cellXfs.forEach(function(xf, id) {
          var payload = [];
          payload.push(writextag("NumberFormat", null, { "ss:Format": escapexml(table_fmt[xf.numFmtId]) }));
          var o = { "ss:ID": "s" + (21 + id) };
          styles.push(writextag("Style", payload.join(""), o));
        });
        return writextag("Styles", styles.join(""));
      }
      function write_name_xlml(n) {
        return writextag("NamedRange", null, { "ss:Name": n.Name, "ss:RefersTo": "=" + a1_to_rc(n.Ref, { r: 0, c: 0 }) });
      }
      function write_names_xlml(wb) {
        if (!((wb || {}).Workbook || {}).Names)
          return "";
        var names = wb.Workbook.Names;
        var out = [];
        for (var i = 0; i < names.length; ++i) {
          var n = names[i];
          if (n.Sheet != null)
            continue;
          if (n.Name.match(/^_xlfn\./))
            continue;
          out.push(write_name_xlml(n));
        }
        return writextag("Names", out.join(""));
      }
      function write_ws_xlml_names(ws, opts, idx, wb) {
        if (!ws)
          return "";
        if (!((wb || {}).Workbook || {}).Names)
          return "";
        var names = wb.Workbook.Names;
        var out = [];
        for (var i = 0; i < names.length; ++i) {
          var n = names[i];
          if (n.Sheet != idx)
            continue;
          if (n.Name.match(/^_xlfn\./))
            continue;
          out.push(write_name_xlml(n));
        }
        return out.join("");
      }
      function write_ws_xlml_wsopts(ws, opts, idx, wb) {
        if (!ws)
          return "";
        var o = [];
        if (ws["!margins"]) {
          o.push("<PageSetup>");
          if (ws["!margins"].header)
            o.push(writextag("Header", null, { "x:Margin": ws["!margins"].header }));
          if (ws["!margins"].footer)
            o.push(writextag("Footer", null, { "x:Margin": ws["!margins"].footer }));
          o.push(writextag("PageMargins", null, {
            "x:Bottom": ws["!margins"].bottom || "0.75",
            "x:Left": ws["!margins"].left || "0.7",
            "x:Right": ws["!margins"].right || "0.7",
            "x:Top": ws["!margins"].top || "0.75"
          }));
          o.push("</PageSetup>");
        }
        if (wb && wb.Workbook && wb.Workbook.Sheets && wb.Workbook.Sheets[idx]) {
          if (wb.Workbook.Sheets[idx].Hidden)
            o.push(writextag("Visible", wb.Workbook.Sheets[idx].Hidden == 1 ? "SheetHidden" : "SheetVeryHidden", {}));
          else {
            for (var i = 0; i < idx; ++i)
              if (wb.Workbook.Sheets[i] && !wb.Workbook.Sheets[i].Hidden)
                break;
            if (i == idx)
              o.push("<Selected/>");
          }
        }
        if (((((wb || {}).Workbook || {}).Views || [])[0] || {}).RTL)
          o.push("<DisplayRightToLeft/>");
        if (ws["!protect"]) {
          o.push(writetag("ProtectContents", "True"));
          if (ws["!protect"].objects)
            o.push(writetag("ProtectObjects", "True"));
          if (ws["!protect"].scenarios)
            o.push(writetag("ProtectScenarios", "True"));
          if (ws["!protect"].selectLockedCells != null && !ws["!protect"].selectLockedCells)
            o.push(writetag("EnableSelection", "NoSelection"));
          else if (ws["!protect"].selectUnlockedCells != null && !ws["!protect"].selectUnlockedCells)
            o.push(writetag("EnableSelection", "UnlockedCells"));
          [
            ["formatCells", "AllowFormatCells"],
            ["formatColumns", "AllowSizeCols"],
            ["formatRows", "AllowSizeRows"],
            ["insertColumns", "AllowInsertCols"],
            ["insertRows", "AllowInsertRows"],
            ["insertHyperlinks", "AllowInsertHyperlinks"],
            ["deleteColumns", "AllowDeleteCols"],
            ["deleteRows", "AllowDeleteRows"],
            ["sort", "AllowSort"],
            ["autoFilter", "AllowFilter"],
            ["pivotTables", "AllowUsePivotTables"]
          ].forEach(function(x) {
            if (ws["!protect"][x[0]])
              o.push("<" + x[1] + "/>");
          });
        }
        if (o.length == 0)
          return "";
        return writextag("WorksheetOptions", o.join(""), { xmlns: XLMLNS.x });
      }
      function write_ws_xlml_comment(comments) {
        return comments.map(function(c) {
          var t3 = xlml_unfixstr(c.t || "");
          var d = writextag("ss:Data", t3, { "xmlns": "http://www.w3.org/TR/REC-html40" });
          return writextag("Comment", d, { "ss:Author": c.a });
        }).join("");
      }
      function write_ws_xlml_cell(cell, ref, ws, opts, idx, wb, addr) {
        if (!cell || cell.v == void 0 && cell.f == void 0)
          return "";
        var attr = {};
        if (cell.f)
          attr["ss:Formula"] = "=" + escapexml(a1_to_rc(cell.f, addr));
        if (cell.F && cell.F.slice(0, ref.length) == ref) {
          var end = decode_cell(cell.F.slice(ref.length + 1));
          attr["ss:ArrayRange"] = "RC:R" + (end.r == addr.r ? "" : "[" + (end.r - addr.r) + "]") + "C" + (end.c == addr.c ? "" : "[" + (end.c - addr.c) + "]");
        }
        if (cell.l && cell.l.Target) {
          attr["ss:HRef"] = escapexml(cell.l.Target);
          if (cell.l.Tooltip)
            attr["x:HRefScreenTip"] = escapexml(cell.l.Tooltip);
        }
        if (ws["!merges"]) {
          var marr = ws["!merges"];
          for (var mi = 0; mi != marr.length; ++mi) {
            if (marr[mi].s.c != addr.c || marr[mi].s.r != addr.r)
              continue;
            if (marr[mi].e.c > marr[mi].s.c)
              attr["ss:MergeAcross"] = marr[mi].e.c - marr[mi].s.c;
            if (marr[mi].e.r > marr[mi].s.r)
              attr["ss:MergeDown"] = marr[mi].e.r - marr[mi].s.r;
          }
        }
        var t3 = "", p = "";
        switch (cell.t) {
          case "z":
            if (!opts.sheetStubs)
              return "";
            break;
          case "n":
            t3 = "Number";
            p = String(cell.v);
            break;
          case "b":
            t3 = "Boolean";
            p = cell.v ? "1" : "0";
            break;
          case "e":
            t3 = "Error";
            p = BErr[cell.v];
            break;
          case "d":
            t3 = "DateTime";
            p = new Date(cell.v).toISOString();
            if (cell.z == null)
              cell.z = cell.z || table_fmt[14];
            break;
          case "s":
            t3 = "String";
            p = escapexlml(cell.v || "");
            break;
        }
        var os = get_cell_style(opts.cellXfs, cell, opts);
        attr["ss:StyleID"] = "s" + (21 + os);
        attr["ss:Index"] = addr.c + 1;
        var _v = cell.v != null ? p : "";
        var m = cell.t == "z" ? "" : '<Data ss:Type="' + t3 + '">' + _v + "</Data>";
        if ((cell.c || []).length > 0)
          m += write_ws_xlml_comment(cell.c);
        return writextag("Cell", m, attr);
      }
      function write_ws_xlml_row(R, row) {
        var o = '<Row ss:Index="' + (R + 1) + '"';
        if (row) {
          if (row.hpt && !row.hpx)
            row.hpx = pt2px(row.hpt);
          if (row.hpx)
            o += ' ss:AutoFitHeight="0" ss:Height="' + row.hpx + '"';
          if (row.hidden)
            o += ' ss:Hidden="1"';
        }
        return o + ">";
      }
      function write_ws_xlml_table(ws, opts, idx, wb) {
        if (!ws["!ref"])
          return "";
        var range = safe_decode_range(ws["!ref"]);
        var marr = ws["!merges"] || [], mi = 0;
        var o = [];
        if (ws["!cols"])
          ws["!cols"].forEach(function(n, i) {
            process_col(n);
            var w = !!n.width;
            var p = col_obj_w(i, n);
            var k = { "ss:Index": i + 1 };
            if (w)
              k["ss:Width"] = width2px(p.width);
            if (n.hidden)
              k["ss:Hidden"] = "1";
            o.push(writextag("Column", null, k));
          });
        var dense = Array.isArray(ws);
        for (var R = range.s.r; R <= range.e.r; ++R) {
          var row = [write_ws_xlml_row(R, (ws["!rows"] || [])[R])];
          for (var C = range.s.c; C <= range.e.c; ++C) {
            var skip = false;
            for (mi = 0; mi != marr.length; ++mi) {
              if (marr[mi].s.c > C)
                continue;
              if (marr[mi].s.r > R)
                continue;
              if (marr[mi].e.c < C)
                continue;
              if (marr[mi].e.r < R)
                continue;
              if (marr[mi].s.c != C || marr[mi].s.r != R)
                skip = true;
              break;
            }
            if (skip)
              continue;
            var addr = { r: R, c: C };
            var ref = encode_cell(addr), cell = dense ? (ws[R] || [])[C] : ws[ref];
            row.push(write_ws_xlml_cell(cell, ref, ws, opts, idx, wb, addr));
          }
          row.push("</Row>");
          if (row.length > 2)
            o.push(row.join(""));
        }
        return o.join("");
      }
      function write_ws_xlml(idx, opts, wb) {
        var o = [];
        var s = wb.SheetNames[idx];
        var ws = wb.Sheets[s];
        var t3 = ws ? write_ws_xlml_names(ws, opts, idx, wb) : "";
        if (t3.length > 0)
          o.push("<Names>" + t3 + "</Names>");
        t3 = ws ? write_ws_xlml_table(ws, opts, idx, wb) : "";
        if (t3.length > 0)
          o.push("<Table>" + t3 + "</Table>");
        o.push(write_ws_xlml_wsopts(ws, opts, idx, wb));
        return o.join("");
      }
      function write_xlml(wb, opts) {
        if (!opts)
          opts = {};
        if (!wb.SSF)
          wb.SSF = dup(table_fmt);
        if (wb.SSF) {
          make_ssf();
          SSF_load_table(wb.SSF);
          opts.revssf = evert_num(wb.SSF);
          opts.revssf[wb.SSF[65535]] = 0;
          opts.ssf = wb.SSF;
          opts.cellXfs = [];
          get_cell_style(opts.cellXfs, {}, { revssf: { "General": 0 } });
        }
        var d = [];
        d.push(write_props_xlml(wb, opts));
        d.push(write_wb_xlml(wb, opts));
        d.push("");
        d.push("");
        for (var i = 0; i < wb.SheetNames.length; ++i)
          d.push(writextag("Worksheet", write_ws_xlml(i, opts, wb), { "ss:Name": escapexml(wb.SheetNames[i]) }));
        d[2] = write_sty_xlml(wb, opts);
        d[3] = write_names_xlml(wb, opts);
        return XML_HEADER + writextag("Workbook", d.join(""), {
          "xmlns": XLMLNS.ss,
          "xmlns:o": XLMLNS.o,
          "xmlns:x": XLMLNS.x,
          "xmlns:ss": XLMLNS.ss,
          "xmlns:dt": XLMLNS.dt,
          "xmlns:html": XLMLNS.html
        });
      }
      function parse_compobj(obj) {
        var v = {};
        var o = obj.content;
        o.l = 28;
        v.AnsiUserType = o.read_shift(0, "lpstr-ansi");
        v.AnsiClipboardFormat = parse_ClipboardFormatOrAnsiString(o);
        if (o.length - o.l <= 4)
          return v;
        var m = o.read_shift(4);
        if (m == 0 || m > 40)
          return v;
        o.l -= 4;
        v.Reserved1 = o.read_shift(0, "lpstr-ansi");
        if (o.length - o.l <= 4)
          return v;
        m = o.read_shift(4);
        if (m !== 1907505652)
          return v;
        v.UnicodeClipboardFormat = parse_ClipboardFormatOrUnicodeString(o);
        m = o.read_shift(4);
        if (m == 0 || m > 40)
          return v;
        o.l -= 4;
        v.Reserved2 = o.read_shift(0, "lpwstr");
      }
      var CONTINUE_RT = [60, 1084, 2066, 2165, 2175];
      function slurp(RecordType, R, blob, length, opts) {
        var l = length;
        var bufs = [];
        var d = blob.slice(blob.l, blob.l + l);
        if (opts && opts.enc && opts.enc.insitu && d.length > 0)
          switch (RecordType) {
            case 9:
            case 521:
            case 1033:
            case 2057:
            case 47:
            case 405:
            case 225:
            case 406:
            case 312:
            case 404:
            case 10:
              break;
            case 133:
              break;
            default:
              opts.enc.insitu(d);
          }
        bufs.push(d);
        blob.l += l;
        var nextrt = __readUInt16LE(blob, blob.l), next = XLSRecordEnum[nextrt];
        var start = 0;
        while (next != null && CONTINUE_RT.indexOf(nextrt) > -1) {
          l = __readUInt16LE(blob, blob.l + 2);
          start = blob.l + 4;
          if (nextrt == 2066)
            start += 4;
          else if (nextrt == 2165 || nextrt == 2175) {
            start += 12;
          }
          d = blob.slice(start, blob.l + 4 + l);
          bufs.push(d);
          blob.l += 4 + l;
          next = XLSRecordEnum[nextrt = __readUInt16LE(blob, blob.l)];
        }
        var b = bconcat(bufs);
        prep_blob(b, 0);
        var ll = 0;
        b.lens = [];
        for (var j = 0; j < bufs.length; ++j) {
          b.lens.push(ll);
          ll += bufs[j].length;
        }
        if (b.length < length)
          throw "XLS Record 0x" + RecordType.toString(16) + " Truncated: " + b.length + " < " + length;
        return R.f(b, b.length, opts);
      }
      function safe_format_xf(p, opts, date1904) {
        if (p.t === "z")
          return;
        if (!p.XF)
          return;
        var fmtid = 0;
        try {
          fmtid = p.z || p.XF.numFmtId || 0;
          if (opts.cellNF)
            p.z = table_fmt[fmtid];
        } catch (e) {
          if (opts.WTF)
            throw e;
        }
        if (!opts || opts.cellText !== false)
          try {
            if (p.t === "e") {
              p.w = p.w || BErr[p.v];
            } else if (fmtid === 0 || fmtid == "General") {
              if (p.t === "n") {
                if ((p.v | 0) === p.v)
                  p.w = p.v.toString(10);
                else
                  p.w = SSF_general_num(p.v);
              } else
                p.w = SSF_general(p.v);
            } else
              p.w = SSF_format(fmtid, p.v, { date1904: !!date1904, dateNF: opts && opts.dateNF });
          } catch (e) {
            if (opts.WTF)
              throw e;
          }
        if (opts.cellDates && fmtid && p.t == "n" && fmt_is_date(table_fmt[fmtid] || String(fmtid))) {
          var _d = SSF_parse_date_code(p.v);
          if (_d) {
            p.t = "d";
            p.v = new Date(_d.y, _d.m - 1, _d.d, _d.H, _d.M, _d.S, _d.u);
          }
        }
      }
      function make_cell(val, ixfe, t3) {
        return { v: val, ixfe, t: t3 };
      }
      function parse_workbook(blob, options) {
        var wb = { opts: {} };
        var Sheets = {};
        if (DENSE != null && options.dense == null)
          options.dense = DENSE;
        var out = options.dense ? [] : {};
        var Directory = {};
        var range = {};
        var last_formula = null;
        var sst = [];
        var cur_sheet = "";
        var Preamble = {};
        var lastcell, last_cell = "", cc, cmnt, rngC, rngR;
        var sharedf = {};
        var arrayf = [];
        var temp_val;
        var country;
        var XFs = [];
        var palette = [];
        var Workbook = { Sheets: [], WBProps: { date1904: false }, Views: [{}] }, wsprops = {};
        var get_rgb = function getrgb(icv) {
          if (icv < 8)
            return XLSIcv[icv];
          if (icv < 64)
            return palette[icv - 8] || XLSIcv[icv];
          return XLSIcv[icv];
        };
        var process_cell_style = function pcs(cell, line, options2) {
          var xfd = line.XF.data;
          if (!xfd || !xfd.patternType || !options2 || !options2.cellStyles)
            return;
          line.s = {};
          line.s.patternType = xfd.patternType;
          var t3;
          if (t3 = rgb2Hex(get_rgb(xfd.icvFore))) {
            line.s.fgColor = { rgb: t3 };
          }
          if (t3 = rgb2Hex(get_rgb(xfd.icvBack))) {
            line.s.bgColor = { rgb: t3 };
          }
        };
        var addcell = function addcell2(cell, line, options2) {
          if (file_depth > 1)
            return;
          if (options2.sheetRows && cell.r >= options2.sheetRows)
            return;
          if (options2.cellStyles && line.XF && line.XF.data)
            process_cell_style(cell, line, options2);
          delete line.ixfe;
          delete line.XF;
          lastcell = cell;
          last_cell = encode_cell(cell);
          if (!range || !range.s || !range.e)
            range = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
          if (cell.r < range.s.r)
            range.s.r = cell.r;
          if (cell.c < range.s.c)
            range.s.c = cell.c;
          if (cell.r + 1 > range.e.r)
            range.e.r = cell.r + 1;
          if (cell.c + 1 > range.e.c)
            range.e.c = cell.c + 1;
          if (options2.cellFormula && line.f) {
            for (var afi = 0; afi < arrayf.length; ++afi) {
              if (arrayf[afi][0].s.c > cell.c || arrayf[afi][0].s.r > cell.r)
                continue;
              if (arrayf[afi][0].e.c < cell.c || arrayf[afi][0].e.r < cell.r)
                continue;
              line.F = encode_range(arrayf[afi][0]);
              if (arrayf[afi][0].s.c != cell.c || arrayf[afi][0].s.r != cell.r)
                delete line.f;
              if (line.f)
                line.f = "" + stringify_formula(arrayf[afi][1], range, cell, supbooks, opts);
              break;
            }
          }
          {
            if (options2.dense) {
              if (!out[cell.r])
                out[cell.r] = [];
              out[cell.r][cell.c] = line;
            } else
              out[last_cell] = line;
          }
        };
        var opts = {
          enc: false,
          // encrypted
          sbcch: 0,
          // cch in the preceding SupBook
          snames: [],
          // sheetnames
          sharedf,
          // shared formulae by address
          arrayf,
          // array formulae array
          rrtabid: [],
          // RRTabId
          lastuser: "",
          // Last User from WriteAccess
          biff: 8,
          // BIFF version
          codepage: 0,
          // CP from CodePage record
          winlocked: 0,
          // fLockWn from WinProtect
          cellStyles: !!options && !!options.cellStyles,
          WTF: !!options && !!options.wtf
        };
        if (options.password)
          opts.password = options.password;
        var themes;
        var merges = [];
        var objects = [];
        var colinfo = [], rowinfo = [];
        var seencol = false;
        var supbooks = [];
        supbooks.SheetNames = opts.snames;
        supbooks.sharedf = opts.sharedf;
        supbooks.arrayf = opts.arrayf;
        supbooks.names = [];
        supbooks.XTI = [];
        var last_RT = 0;
        var file_depth = 0;
        var BIFF2Fmt = 0, BIFF2FmtTable = [];
        var FilterDatabases = [];
        var last_lbl;
        opts.codepage = 1200;
        set_cp(1200);
        var seen_codepage = false;
        while (blob.l < blob.length - 1) {
          var s = blob.l;
          var RecordType = blob.read_shift(2);
          if (RecordType === 0 && last_RT === 10)
            break;
          var length = blob.l === blob.length ? 0 : blob.read_shift(2);
          var R = XLSRecordEnum[RecordType];
          if (R && R.f) {
            if (options.bookSheets) {
              if (last_RT === 133 && RecordType !== 133)
                break;
            }
            last_RT = RecordType;
            if (R.r === 2 || R.r == 12) {
              var rt = blob.read_shift(2);
              length -= 2;
              if (!opts.enc && rt !== RecordType && ((rt & 255) << 8 | rt >> 8) !== RecordType)
                throw new Error("rt mismatch: " + rt + "!=" + RecordType);
              if (R.r == 12) {
                blob.l += 10;
                length -= 10;
              }
            }
            var val = {};
            if (RecordType === 10)
              val = R.f(blob, length, opts);
            else
              val = slurp(RecordType, R, blob, length, opts);
            if (file_depth == 0 && [9, 521, 1033, 2057].indexOf(last_RT) === -1)
              continue;
            switch (RecordType) {
              case 34:
                wb.opts.Date1904 = Workbook.WBProps.date1904 = val;
                break;
              case 134:
                wb.opts.WriteProtect = true;
                break;
              case 47:
                if (!opts.enc)
                  blob.l = 0;
                opts.enc = val;
                if (!options.password)
                  throw new Error("File is password-protected");
                if (val.valid == null)
                  throw new Error("Encryption scheme unsupported");
                if (!val.valid)
                  throw new Error("Password is incorrect");
                break;
              case 92:
                opts.lastuser = val;
                break;
              case 66:
                var cpval = Number(val);
                switch (cpval) {
                  case 21010:
                    cpval = 1200;
                    break;
                  case 32768:
                    cpval = 1e4;
                    break;
                  case 32769:
                    cpval = 1252;
                    break;
                }
                set_cp(opts.codepage = cpval);
                seen_codepage = true;
                break;
              case 317:
                opts.rrtabid = val;
                break;
              case 25:
                opts.winlocked = val;
                break;
              case 439:
                wb.opts["RefreshAll"] = val;
                break;
              case 12:
                wb.opts["CalcCount"] = val;
                break;
              case 16:
                wb.opts["CalcDelta"] = val;
                break;
              case 17:
                wb.opts["CalcIter"] = val;
                break;
              case 13:
                wb.opts["CalcMode"] = val;
                break;
              case 14:
                wb.opts["CalcPrecision"] = val;
                break;
              case 95:
                wb.opts["CalcSaveRecalc"] = val;
                break;
              case 15:
                opts.CalcRefMode = val;
                break;
              case 2211:
                wb.opts.FullCalc = val;
                break;
              case 129:
                if (val.fDialog)
                  out["!type"] = "dialog";
                if (!val.fBelow)
                  (out["!outline"] || (out["!outline"] = {})).above = true;
                if (!val.fRight)
                  (out["!outline"] || (out["!outline"] = {})).left = true;
                break;
              case 224:
                XFs.push(val);
                break;
              case 430:
                supbooks.push([val]);
                supbooks[supbooks.length - 1].XTI = [];
                break;
              case 35:
              case 547:
                supbooks[supbooks.length - 1].push(val);
                break;
              case 24:
              case 536:
                last_lbl = {
                  Name: val.Name,
                  Ref: stringify_formula(val.rgce, range, null, supbooks, opts)
                };
                if (val.itab > 0)
                  last_lbl.Sheet = val.itab - 1;
                supbooks.names.push(last_lbl);
                if (!supbooks[0]) {
                  supbooks[0] = [];
                  supbooks[0].XTI = [];
                }
                supbooks[supbooks.length - 1].push(val);
                if (val.Name == "_xlnm._FilterDatabase" && val.itab > 0) {
                  if (val.rgce && val.rgce[0] && val.rgce[0][0] && val.rgce[0][0][0] == "PtgArea3d")
                    FilterDatabases[val.itab - 1] = { ref: encode_range(val.rgce[0][0][1][2]) };
                }
                break;
              case 22:
                opts.ExternCount = val;
                break;
              case 23:
                if (supbooks.length == 0) {
                  supbooks[0] = [];
                  supbooks[0].XTI = [];
                }
                supbooks[supbooks.length - 1].XTI = supbooks[supbooks.length - 1].XTI.concat(val);
                supbooks.XTI = supbooks.XTI.concat(val);
                break;
              case 2196:
                if (opts.biff < 8)
                  break;
                if (last_lbl != null)
                  last_lbl.Comment = val[1];
                break;
              case 18:
                out["!protect"] = val;
                break;
              case 19:
                if (val !== 0 && opts.WTF)
                  console.error("Password verifier: " + val);
                break;
              case 133:
                {
                  Directory[val.pos] = val;
                  opts.snames.push(val.name);
                }
                break;
              case 10:
                {
                  if (--file_depth)
                    break;
                  if (range.e) {
                    if (range.e.r > 0 && range.e.c > 0) {
                      range.e.r--;
                      range.e.c--;
                      out["!ref"] = encode_range(range);
                      if (options.sheetRows && options.sheetRows <= range.e.r) {
                        var tmpri = range.e.r;
                        range.e.r = options.sheetRows - 1;
                        out["!fullref"] = out["!ref"];
                        out["!ref"] = encode_range(range);
                        range.e.r = tmpri;
                      }
                      range.e.r++;
                      range.e.c++;
                    }
                    if (merges.length > 0)
                      out["!merges"] = merges;
                    if (objects.length > 0)
                      out["!objects"] = objects;
                    if (colinfo.length > 0)
                      out["!cols"] = colinfo;
                    if (rowinfo.length > 0)
                      out["!rows"] = rowinfo;
                    Workbook.Sheets.push(wsprops);
                  }
                  if (cur_sheet === "")
                    Preamble = out;
                  else
                    Sheets[cur_sheet] = out;
                  out = options.dense ? [] : {};
                }
                break;
              case 9:
              case 521:
              case 1033:
              case 2057:
                {
                  if (opts.biff === 8)
                    opts.biff = {
                      9: 2,
                      521: 3,
                      1033: 4
                    }[RecordType] || {
                      512: 2,
                      768: 3,
                      1024: 4,
                      1280: 5,
                      1536: 8,
                      2: 2,
                      7: 2
                    }[val.BIFFVer] || 8;
                  opts.biffguess = val.BIFFVer == 0;
                  if (val.BIFFVer == 0 && val.dt == 4096) {
                    opts.biff = 5;
                    seen_codepage = true;
                    set_cp(opts.codepage = 28591);
                  }
                  if (opts.biff == 8 && val.BIFFVer == 0 && val.dt == 16)
                    opts.biff = 2;
                  if (file_depth++)
                    break;
                  out = options.dense ? [] : {};
                  if (opts.biff < 8 && !seen_codepage) {
                    seen_codepage = true;
                    set_cp(opts.codepage = options.codepage || 1252);
                  }
                  if (opts.biff < 5 || val.BIFFVer == 0 && val.dt == 4096) {
                    if (cur_sheet === "")
                      cur_sheet = "Sheet1";
                    range = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
                    var fakebs8 = { pos: blob.l - length, name: cur_sheet };
                    Directory[fakebs8.pos] = fakebs8;
                    opts.snames.push(cur_sheet);
                  } else
                    cur_sheet = (Directory[s] || { name: "" }).name;
                  if (val.dt == 32)
                    out["!type"] = "chart";
                  if (val.dt == 64)
                    out["!type"] = "macro";
                  merges = [];
                  objects = [];
                  opts.arrayf = arrayf = [];
                  colinfo = [];
                  rowinfo = [];
                  seencol = false;
                  wsprops = { Hidden: (Directory[s] || { hs: 0 }).hs, name: cur_sheet };
                }
                break;
              case 515:
              case 3:
              case 2:
                {
                  if (out["!type"] == "chart") {
                    if (options.dense ? (out[val.r] || [])[val.c] : out[encode_cell({ c: val.c, r: val.r })])
                      ++val.c;
                  }
                  temp_val = { ixfe: val.ixfe, XF: XFs[val.ixfe] || {}, v: val.val, t: "n" };
                  if (BIFF2Fmt > 0)
                    temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                  safe_format_xf(temp_val, options, wb.opts.Date1904);
                  addcell({ c: val.c, r: val.r }, temp_val, options);
                }
                break;
              case 5:
              case 517:
                {
                  temp_val = { ixfe: val.ixfe, XF: XFs[val.ixfe], v: val.val, t: val.t };
                  if (BIFF2Fmt > 0)
                    temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                  safe_format_xf(temp_val, options, wb.opts.Date1904);
                  addcell({ c: val.c, r: val.r }, temp_val, options);
                }
                break;
              case 638:
                {
                  temp_val = { ixfe: val.ixfe, XF: XFs[val.ixfe], v: val.rknum, t: "n" };
                  if (BIFF2Fmt > 0)
                    temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                  safe_format_xf(temp_val, options, wb.opts.Date1904);
                  addcell({ c: val.c, r: val.r }, temp_val, options);
                }
                break;
              case 189:
                {
                  for (var j = val.c; j <= val.C; ++j) {
                    var ixfe = val.rkrec[j - val.c][0];
                    temp_val = { ixfe, XF: XFs[ixfe], v: val.rkrec[j - val.c][1], t: "n" };
                    if (BIFF2Fmt > 0)
                      temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                    safe_format_xf(temp_val, options, wb.opts.Date1904);
                    addcell({ c: j, r: val.r }, temp_val, options);
                  }
                }
                break;
              case 6:
              case 518:
              case 1030:
                {
                  if (val.val == "String") {
                    last_formula = val;
                    break;
                  }
                  temp_val = make_cell(val.val, val.cell.ixfe, val.tt);
                  temp_val.XF = XFs[temp_val.ixfe];
                  if (options.cellFormula) {
                    var _f = val.formula;
                    if (_f && _f[0] && _f[0][0] && _f[0][0][0] == "PtgExp") {
                      var _fr = _f[0][0][1][0], _fc = _f[0][0][1][1];
                      var _fe = encode_cell({ r: _fr, c: _fc });
                      if (sharedf[_fe])
                        temp_val.f = "" + stringify_formula(val.formula, range, val.cell, supbooks, opts);
                      else
                        temp_val.F = ((options.dense ? (out[_fr] || [])[_fc] : out[_fe]) || {}).F;
                    } else
                      temp_val.f = "" + stringify_formula(val.formula, range, val.cell, supbooks, opts);
                  }
                  if (BIFF2Fmt > 0)
                    temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                  safe_format_xf(temp_val, options, wb.opts.Date1904);
                  addcell(val.cell, temp_val, options);
                  last_formula = val;
                }
                break;
              case 7:
              case 519:
                {
                  if (last_formula) {
                    last_formula.val = val;
                    temp_val = make_cell(val, last_formula.cell.ixfe, "s");
                    temp_val.XF = XFs[temp_val.ixfe];
                    if (options.cellFormula) {
                      temp_val.f = "" + stringify_formula(last_formula.formula, range, last_formula.cell, supbooks, opts);
                    }
                    if (BIFF2Fmt > 0)
                      temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                    safe_format_xf(temp_val, options, wb.opts.Date1904);
                    addcell(last_formula.cell, temp_val, options);
                    last_formula = null;
                  } else
                    throw new Error("String record expects Formula");
                }
                break;
              case 33:
              case 545:
                {
                  arrayf.push(val);
                  var _arraystart = encode_cell(val[0].s);
                  cc = options.dense ? (out[val[0].s.r] || [])[val[0].s.c] : out[_arraystart];
                  if (options.cellFormula && cc) {
                    if (!last_formula)
                      break;
                    if (!_arraystart || !cc)
                      break;
                    cc.f = "" + stringify_formula(val[1], range, val[0], supbooks, opts);
                    cc.F = encode_range(val[0]);
                  }
                }
                break;
              case 1212:
                {
                  if (!options.cellFormula)
                    break;
                  if (last_cell) {
                    if (!last_formula)
                      break;
                    sharedf[encode_cell(last_formula.cell)] = val[0];
                    cc = options.dense ? (out[last_formula.cell.r] || [])[last_formula.cell.c] : out[encode_cell(last_formula.cell)];
                    (cc || {}).f = "" + stringify_formula(val[0], range, lastcell, supbooks, opts);
                  }
                }
                break;
              case 253:
                temp_val = make_cell(sst[val.isst].t, val.ixfe, "s");
                if (sst[val.isst].h)
                  temp_val.h = sst[val.isst].h;
                temp_val.XF = XFs[temp_val.ixfe];
                if (BIFF2Fmt > 0)
                  temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                safe_format_xf(temp_val, options, wb.opts.Date1904);
                addcell({ c: val.c, r: val.r }, temp_val, options);
                break;
              case 513:
                if (options.sheetStubs) {
                  temp_val = { ixfe: val.ixfe, XF: XFs[val.ixfe], t: "z" };
                  if (BIFF2Fmt > 0)
                    temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                  safe_format_xf(temp_val, options, wb.opts.Date1904);
                  addcell({ c: val.c, r: val.r }, temp_val, options);
                }
                break;
              case 190:
                if (options.sheetStubs) {
                  for (var _j = val.c; _j <= val.C; ++_j) {
                    var _ixfe = val.ixfe[_j - val.c];
                    temp_val = { ixfe: _ixfe, XF: XFs[_ixfe], t: "z" };
                    if (BIFF2Fmt > 0)
                      temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                    safe_format_xf(temp_val, options, wb.opts.Date1904);
                    addcell({ c: _j, r: val.r }, temp_val, options);
                  }
                }
                break;
              case 214:
              case 516:
              case 4:
                temp_val = make_cell(val.val, val.ixfe, "s");
                temp_val.XF = XFs[temp_val.ixfe];
                if (BIFF2Fmt > 0)
                  temp_val.z = BIFF2FmtTable[temp_val.ixfe >> 8 & 63];
                safe_format_xf(temp_val, options, wb.opts.Date1904);
                addcell({ c: val.c, r: val.r }, temp_val, options);
                break;
              case 0:
              case 512:
                {
                  if (file_depth === 1)
                    range = val;
                }
                break;
              case 252:
                {
                  sst = val;
                }
                break;
              case 1054:
                {
                  if (opts.biff == 4) {
                    BIFF2FmtTable[BIFF2Fmt++] = val[1];
                    for (var b4idx = 0; b4idx < BIFF2Fmt + 163; ++b4idx)
                      if (table_fmt[b4idx] == val[1])
                        break;
                    if (b4idx >= 163)
                      SSF_load(val[1], BIFF2Fmt + 163);
                  } else
                    SSF_load(val[1], val[0]);
                }
                break;
              case 30:
                {
                  BIFF2FmtTable[BIFF2Fmt++] = val;
                  for (var b2idx = 0; b2idx < BIFF2Fmt + 163; ++b2idx)
                    if (table_fmt[b2idx] == val)
                      break;
                  if (b2idx >= 163)
                    SSF_load(val, BIFF2Fmt + 163);
                }
                break;
              case 229:
                merges = merges.concat(val);
                break;
              case 93:
                objects[val.cmo[0]] = opts.lastobj = val;
                break;
              case 438:
                opts.lastobj.TxO = val;
                break;
              case 127:
                opts.lastobj.ImData = val;
                break;
              case 440:
                {
                  for (rngR = val[0].s.r; rngR <= val[0].e.r; ++rngR)
                    for (rngC = val[0].s.c; rngC <= val[0].e.c; ++rngC) {
                      cc = options.dense ? (out[rngR] || [])[rngC] : out[encode_cell({ c: rngC, r: rngR })];
                      if (cc)
                        cc.l = val[1];
                    }
                }
                break;
              case 2048:
                {
                  for (rngR = val[0].s.r; rngR <= val[0].e.r; ++rngR)
                    for (rngC = val[0].s.c; rngC <= val[0].e.c; ++rngC) {
                      cc = options.dense ? (out[rngR] || [])[rngC] : out[encode_cell({ c: rngC, r: rngR })];
                      if (cc && cc.l)
                        cc.l.Tooltip = val[1];
                    }
                }
                break;
              case 28:
                {
                  if (opts.biff <= 5 && opts.biff >= 2)
                    break;
                  cc = options.dense ? (out[val[0].r] || [])[val[0].c] : out[encode_cell(val[0])];
                  var noteobj = objects[val[2]];
                  if (!cc) {
                    if (options.dense) {
                      if (!out[val[0].r])
                        out[val[0].r] = [];
                      cc = out[val[0].r][val[0].c] = { t: "z" };
                    } else {
                      cc = out[encode_cell(val[0])] = { t: "z" };
                    }
                    range.e.r = Math.max(range.e.r, val[0].r);
                    range.s.r = Math.min(range.s.r, val[0].r);
                    range.e.c = Math.max(range.e.c, val[0].c);
                    range.s.c = Math.min(range.s.c, val[0].c);
                  }
                  if (!cc.c)
                    cc.c = [];
                  cmnt = { a: val[1], t: noteobj.TxO.t };
                  cc.c.push(cmnt);
                }
                break;
              case 2173:
                update_xfext(XFs[val.ixfe], val.ext);
                break;
              case 125:
                {
                  if (!opts.cellStyles)
                    break;
                  while (val.e >= val.s) {
                    colinfo[val.e--] = { width: val.w / 256, level: val.level || 0, hidden: !!(val.flags & 1) };
                    if (!seencol) {
                      seencol = true;
                      find_mdw_colw(val.w / 256);
                    }
                    process_col(colinfo[val.e + 1]);
                  }
                }
                break;
              case 520:
                {
                  var rowobj = {};
                  if (val.level != null) {
                    rowinfo[val.r] = rowobj;
                    rowobj.level = val.level;
                  }
                  if (val.hidden) {
                    rowinfo[val.r] = rowobj;
                    rowobj.hidden = true;
                  }
                  if (val.hpt) {
                    rowinfo[val.r] = rowobj;
                    rowobj.hpt = val.hpt;
                    rowobj.hpx = pt2px(val.hpt);
                  }
                }
                break;
              case 38:
              case 39:
              case 40:
              case 41:
                if (!out["!margins"])
                  default_margins(out["!margins"] = {});
                out["!margins"][{ 38: "left", 39: "right", 40: "top", 41: "bottom" }[RecordType]] = val;
                break;
              case 161:
                if (!out["!margins"])
                  default_margins(out["!margins"] = {});
                out["!margins"].header = val.header;
                out["!margins"].footer = val.footer;
                break;
              case 574:
                if (val.RTL)
                  Workbook.Views[0].RTL = true;
                break;
              case 146:
                palette = val;
                break;
              case 2198:
                themes = val;
                break;
              case 140:
                country = val;
                break;
              case 442:
                {
                  if (!cur_sheet)
                    Workbook.WBProps.CodeName = val || "ThisWorkbook";
                  else
                    wsprops.CodeName = val || wsprops.name;
                }
                break;
            }
          } else {
            if (!R)
              console.error("Missing Info for XLS Record 0x" + RecordType.toString(16));
            blob.l += length;
          }
        }
        wb.SheetNames = keys3(Directory).sort(function(a, b) {
          return Number(a) - Number(b);
        }).map(function(x) {
          return Directory[x].name;
        });
        if (!options.bookSheets)
          wb.Sheets = Sheets;
        if (!wb.SheetNames.length && Preamble["!ref"]) {
          wb.SheetNames.push("Sheet1");
          if (wb.Sheets)
            wb.Sheets["Sheet1"] = Preamble;
        } else
          wb.Preamble = Preamble;
        if (wb.Sheets)
          FilterDatabases.forEach(function(r, i) {
            wb.Sheets[wb.SheetNames[i]]["!autofilter"] = r;
          });
        wb.Strings = sst;
        wb.SSF = dup(table_fmt);
        if (opts.enc)
          wb.Encryption = opts.enc;
        if (themes)
          wb.Themes = themes;
        wb.Metadata = {};
        if (country !== void 0)
          wb.Metadata.Country = country;
        if (supbooks.names.length > 0)
          Workbook.Names = supbooks.names;
        wb.Workbook = Workbook;
        return wb;
      }
      var PSCLSID = {
        SI: "e0859ff2f94f6810ab9108002b27b3d9",
        DSI: "02d5cdd59c2e1b10939708002b2cf9ae",
        UDI: "05d5cdd59c2e1b10939708002b2cf9ae"
      };
      function parse_xls_props(cfb, props, o) {
        var DSI = CFB.find(cfb, "/!DocumentSummaryInformation");
        if (DSI && DSI.size > 0)
          try {
            var DocSummary = parse_PropertySetStream(DSI, DocSummaryPIDDSI, PSCLSID.DSI);
            for (var d in DocSummary)
              props[d] = DocSummary[d];
          } catch (e) {
            if (o.WTF)
              throw e;
          }
        var SI = CFB.find(cfb, "/!SummaryInformation");
        if (SI && SI.size > 0)
          try {
            var Summary = parse_PropertySetStream(SI, SummaryPIDSI, PSCLSID.SI);
            for (var s in Summary)
              if (props[s] == null)
                props[s] = Summary[s];
          } catch (e) {
            if (o.WTF)
              throw e;
          }
        if (props.HeadingPairs && props.TitlesOfParts) {
          load_props_pairs(props.HeadingPairs, props.TitlesOfParts, props, o);
          delete props.HeadingPairs;
          delete props.TitlesOfParts;
        }
      }
      function write_xls_props(wb, cfb) {
        var DSEntries = [], SEntries = [], CEntries = [];
        var i = 0, Keys;
        var DocSummaryRE = evert_key(DocSummaryPIDDSI, "n");
        var SummaryRE = evert_key(SummaryPIDSI, "n");
        if (wb.Props) {
          Keys = keys3(wb.Props);
          for (i = 0; i < Keys.length; ++i)
            (Object.prototype.hasOwnProperty.call(DocSummaryRE, Keys[i]) ? DSEntries : Object.prototype.hasOwnProperty.call(SummaryRE, Keys[i]) ? SEntries : CEntries).push([Keys[i], wb.Props[Keys[i]]]);
        }
        if (wb.Custprops) {
          Keys = keys3(wb.Custprops);
          for (i = 0; i < Keys.length; ++i)
            if (!Object.prototype.hasOwnProperty.call(wb.Props || {}, Keys[i]))
              (Object.prototype.hasOwnProperty.call(DocSummaryRE, Keys[i]) ? DSEntries : Object.prototype.hasOwnProperty.call(SummaryRE, Keys[i]) ? SEntries : CEntries).push([Keys[i], wb.Custprops[Keys[i]]]);
        }
        var CEntries2 = [];
        for (i = 0; i < CEntries.length; ++i) {
          if (XLSPSSkip.indexOf(CEntries[i][0]) > -1 || PseudoPropsPairs.indexOf(CEntries[i][0]) > -1)
            continue;
          if (CEntries[i][1] == null)
            continue;
          CEntries2.push(CEntries[i]);
        }
        if (SEntries.length)
          CFB.utils.cfb_add(cfb, "/SummaryInformation", write_PropertySetStream(SEntries, PSCLSID.SI, SummaryRE, SummaryPIDSI));
        if (DSEntries.length || CEntries2.length)
          CFB.utils.cfb_add(cfb, "/DocumentSummaryInformation", write_PropertySetStream(DSEntries, PSCLSID.DSI, DocSummaryRE, DocSummaryPIDDSI, CEntries2.length ? CEntries2 : null, PSCLSID.UDI));
      }
      function parse_xlscfb(cfb, options) {
        if (!options)
          options = {};
        fix_read_opts(options);
        reset_cp();
        if (options.codepage)
          set_ansi(options.codepage);
        var CompObj, WB;
        if (cfb.FullPaths) {
          if (CFB.find(cfb, "/encryption"))
            throw new Error("File is password-protected");
          CompObj = CFB.find(cfb, "!CompObj");
          WB = CFB.find(cfb, "/Workbook") || CFB.find(cfb, "/Book");
        } else {
          switch (options.type) {
            case "base64":
              cfb = s2a(Base64_decode(cfb));
              break;
            case "binary":
              cfb = s2a(cfb);
              break;
            case "buffer":
              break;
            case "array":
              if (!Array.isArray(cfb))
                cfb = Array.prototype.slice.call(cfb);
              break;
          }
          prep_blob(cfb, 0);
          WB = { content: cfb };
        }
        var WorkbookP;
        var _data;
        if (CompObj)
          parse_compobj(CompObj);
        if (options.bookProps && !options.bookSheets)
          WorkbookP = {};
        else {
          var T = has_buf ? "buffer" : "array";
          if (WB && WB.content)
            WorkbookP = parse_workbook(WB.content, options);
          else if ((_data = CFB.find(cfb, "PerfectOffice_MAIN")) && _data.content)
            WorkbookP = WK_.to_workbook(_data.content, (options.type = T, options));
          else if ((_data = CFB.find(cfb, "NativeContent_MAIN")) && _data.content)
            WorkbookP = WK_.to_workbook(_data.content, (options.type = T, options));
          else if ((_data = CFB.find(cfb, "MN0")) && _data.content)
            throw new Error("Unsupported Works 4 for Mac file");
          else
            throw new Error("Cannot find Workbook stream");
          if (options.bookVBA && cfb.FullPaths && CFB.find(cfb, "/_VBA_PROJECT_CUR/VBA/dir"))
            WorkbookP.vbaraw = make_vba_xls(cfb);
        }
        var props = {};
        if (cfb.FullPaths)
          parse_xls_props(cfb, props, options);
        WorkbookP.Props = WorkbookP.Custprops = props;
        if (options.bookFiles)
          WorkbookP.cfb = cfb;
        return WorkbookP;
      }
      function write_xlscfb(wb, opts) {
        var o = opts || {};
        var cfb = CFB.utils.cfb_new({ root: "R" });
        var wbpath = "/Workbook";
        switch (o.bookType || "xls") {
          case "xls":
            o.bookType = "biff8";
          case "xla":
            if (!o.bookType)
              o.bookType = "xla";
          case "biff8":
            wbpath = "/Workbook";
            o.biff = 8;
            break;
          case "biff5":
            wbpath = "/Book";
            o.biff = 5;
            break;
          default:
            throw new Error("invalid type " + o.bookType + " for XLS CFB");
        }
        CFB.utils.cfb_add(cfb, wbpath, write_biff_buf(wb, o));
        if (o.biff == 8 && (wb.Props || wb.Custprops))
          write_xls_props(wb, cfb);
        if (o.biff == 8 && wb.vbaraw)
          fill_vba_xls(cfb, CFB.read(wb.vbaraw, { type: typeof wb.vbaraw == "string" ? "binary" : "buffer" }));
        return cfb;
      }
      var XLSBRecordEnum = {
        0: {
          /* n:"BrtRowHdr", */
          f: parse_BrtRowHdr
        },
        1: {
          /* n:"BrtCellBlank", */
          f: parse_BrtCellBlank
        },
        2: {
          /* n:"BrtCellRk", */
          f: parse_BrtCellRk
        },
        3: {
          /* n:"BrtCellError", */
          f: parse_BrtCellError
        },
        4: {
          /* n:"BrtCellBool", */
          f: parse_BrtCellBool
        },
        5: {
          /* n:"BrtCellReal", */
          f: parse_BrtCellReal
        },
        6: {
          /* n:"BrtCellSt", */
          f: parse_BrtCellSt
        },
        7: {
          /* n:"BrtCellIsst", */
          f: parse_BrtCellIsst
        },
        8: {
          /* n:"BrtFmlaString", */
          f: parse_BrtFmlaString
        },
        9: {
          /* n:"BrtFmlaNum", */
          f: parse_BrtFmlaNum
        },
        10: {
          /* n:"BrtFmlaBool", */
          f: parse_BrtFmlaBool
        },
        11: {
          /* n:"BrtFmlaError", */
          f: parse_BrtFmlaError
        },
        12: {
          /* n:"BrtShortBlank", */
          f: parse_BrtShortBlank
        },
        13: {
          /* n:"BrtShortRk", */
          f: parse_BrtShortRk
        },
        14: {
          /* n:"BrtShortError", */
          f: parse_BrtShortError
        },
        15: {
          /* n:"BrtShortBool", */
          f: parse_BrtShortBool
        },
        16: {
          /* n:"BrtShortReal", */
          f: parse_BrtShortReal
        },
        17: {
          /* n:"BrtShortSt", */
          f: parse_BrtShortSt
        },
        18: {
          /* n:"BrtShortIsst", */
          f: parse_BrtShortIsst
        },
        19: {
          /* n:"BrtSSTItem", */
          f: parse_RichStr
        },
        20: {
          /* n:"BrtPCDIMissing" */
        },
        21: {
          /* n:"BrtPCDINumber" */
        },
        22: {
          /* n:"BrtPCDIBoolean" */
        },
        23: {
          /* n:"BrtPCDIError" */
        },
        24: {
          /* n:"BrtPCDIString" */
        },
        25: {
          /* n:"BrtPCDIDatetime" */
        },
        26: {
          /* n:"BrtPCDIIndex" */
        },
        27: {
          /* n:"BrtPCDIAMissing" */
        },
        28: {
          /* n:"BrtPCDIANumber" */
        },
        29: {
          /* n:"BrtPCDIABoolean" */
        },
        30: {
          /* n:"BrtPCDIAError" */
        },
        31: {
          /* n:"BrtPCDIAString" */
        },
        32: {
          /* n:"BrtPCDIADatetime" */
        },
        33: {
          /* n:"BrtPCRRecord" */
        },
        34: {
          /* n:"BrtPCRRecordDt" */
        },
        35: {
          /* n:"BrtFRTBegin", */
          T: 1
        },
        36: {
          /* n:"BrtFRTEnd", */
          T: -1
        },
        37: {
          /* n:"BrtACBegin", */
          T: 1
        },
        38: {
          /* n:"BrtACEnd", */
          T: -1
        },
        39: {
          /* n:"BrtName", */
          f: parse_BrtName
        },
        40: {
          /* n:"BrtIndexRowBlock" */
        },
        42: {
          /* n:"BrtIndexBlock" */
        },
        43: {
          /* n:"BrtFont", */
          f: parse_BrtFont
        },
        44: {
          /* n:"BrtFmt", */
          f: parse_BrtFmt
        },
        45: {
          /* n:"BrtFill", */
          f: parse_BrtFill
        },
        46: {
          /* n:"BrtBorder", */
          f: parse_BrtBorder
        },
        47: {
          /* n:"BrtXF", */
          f: parse_BrtXF
        },
        48: {
          /* n:"BrtStyle" */
        },
        49: {
          /* n:"BrtCellMeta", */
          f: parse_Int32LE
        },
        50: {
          /* n:"BrtValueMeta" */
        },
        51: {
          /* n:"BrtMdb" */
          f: parse_BrtMdb
        },
        52: {
          /* n:"BrtBeginFmd", */
          T: 1
        },
        53: {
          /* n:"BrtEndFmd", */
          T: -1
        },
        54: {
          /* n:"BrtBeginMdx", */
          T: 1
        },
        55: {
          /* n:"BrtEndMdx", */
          T: -1
        },
        56: {
          /* n:"BrtBeginMdxTuple", */
          T: 1
        },
        57: {
          /* n:"BrtEndMdxTuple", */
          T: -1
        },
        58: {
          /* n:"BrtMdxMbrIstr" */
        },
        59: {
          /* n:"BrtStr" */
        },
        60: {
          /* n:"BrtColInfo", */
          f: parse_ColInfo
        },
        62: {
          /* n:"BrtCellRString", */
          f: parse_BrtCellRString
        },
        63: {
          /* n:"BrtCalcChainItem$", */
          f: parse_BrtCalcChainItem$
        },
        64: {
          /* n:"BrtDVal", */
          f: parse_BrtDVal
        },
        65: {
          /* n:"BrtSxvcellNum" */
        },
        66: {
          /* n:"BrtSxvcellStr" */
        },
        67: {
          /* n:"BrtSxvcellBool" */
        },
        68: {
          /* n:"BrtSxvcellErr" */
        },
        69: {
          /* n:"BrtSxvcellDate" */
        },
        70: {
          /* n:"BrtSxvcellNil" */
        },
        128: {
          /* n:"BrtFileVersion" */
        },
        129: {
          /* n:"BrtBeginSheet", */
          T: 1
        },
        130: {
          /* n:"BrtEndSheet", */
          T: -1
        },
        131: {
          /* n:"BrtBeginBook", */
          T: 1,
          f: parsenoop,
          p: 0
        },
        132: {
          /* n:"BrtEndBook", */
          T: -1
        },
        133: {
          /* n:"BrtBeginWsViews", */
          T: 1
        },
        134: {
          /* n:"BrtEndWsViews", */
          T: -1
        },
        135: {
          /* n:"BrtBeginBookViews", */
          T: 1
        },
        136: {
          /* n:"BrtEndBookViews", */
          T: -1
        },
        137: {
          /* n:"BrtBeginWsView", */
          T: 1,
          f: parse_BrtBeginWsView
        },
        138: {
          /* n:"BrtEndWsView", */
          T: -1
        },
        139: {
          /* n:"BrtBeginCsViews", */
          T: 1
        },
        140: {
          /* n:"BrtEndCsViews", */
          T: -1
        },
        141: {
          /* n:"BrtBeginCsView", */
          T: 1
        },
        142: {
          /* n:"BrtEndCsView", */
          T: -1
        },
        143: {
          /* n:"BrtBeginBundleShs", */
          T: 1
        },
        144: {
          /* n:"BrtEndBundleShs", */
          T: -1
        },
        145: {
          /* n:"BrtBeginSheetData", */
          T: 1
        },
        146: {
          /* n:"BrtEndSheetData", */
          T: -1
        },
        147: {
          /* n:"BrtWsProp", */
          f: parse_BrtWsProp
        },
        148: {
          /* n:"BrtWsDim", */
          f: parse_BrtWsDim,
          p: 16
        },
        151: {
          /* n:"BrtPane", */
          f: parse_BrtPane
        },
        152: {
          /* n:"BrtSel" */
        },
        153: {
          /* n:"BrtWbProp", */
          f: parse_BrtWbProp
        },
        154: {
          /* n:"BrtWbFactoid" */
        },
        155: {
          /* n:"BrtFileRecover" */
        },
        156: {
          /* n:"BrtBundleSh", */
          f: parse_BrtBundleSh
        },
        157: {
          /* n:"BrtCalcProp" */
        },
        158: {
          /* n:"BrtBookView" */
        },
        159: {
          /* n:"BrtBeginSst", */
          T: 1,
          f: parse_BrtBeginSst
        },
        160: {
          /* n:"BrtEndSst", */
          T: -1
        },
        161: {
          /* n:"BrtBeginAFilter", */
          T: 1,
          f: parse_UncheckedRfX
        },
        162: {
          /* n:"BrtEndAFilter", */
          T: -1
        },
        163: {
          /* n:"BrtBeginFilterColumn", */
          T: 1
        },
        164: {
          /* n:"BrtEndFilterColumn", */
          T: -1
        },
        165: {
          /* n:"BrtBeginFilters", */
          T: 1
        },
        166: {
          /* n:"BrtEndFilters", */
          T: -1
        },
        167: {
          /* n:"BrtFilter" */
        },
        168: {
          /* n:"BrtColorFilter" */
        },
        169: {
          /* n:"BrtIconFilter" */
        },
        170: {
          /* n:"BrtTop10Filter" */
        },
        171: {
          /* n:"BrtDynamicFilter" */
        },
        172: {
          /* n:"BrtBeginCustomFilters", */
          T: 1
        },
        173: {
          /* n:"BrtEndCustomFilters", */
          T: -1
        },
        174: {
          /* n:"BrtCustomFilter" */
        },
        175: {
          /* n:"BrtAFilterDateGroupItem" */
        },
        176: {
          /* n:"BrtMergeCell", */
          f: parse_BrtMergeCell
        },
        177: {
          /* n:"BrtBeginMergeCells", */
          T: 1
        },
        178: {
          /* n:"BrtEndMergeCells", */
          T: -1
        },
        179: {
          /* n:"BrtBeginPivotCacheDef", */
          T: 1
        },
        180: {
          /* n:"BrtEndPivotCacheDef", */
          T: -1
        },
        181: {
          /* n:"BrtBeginPCDFields", */
          T: 1
        },
        182: {
          /* n:"BrtEndPCDFields", */
          T: -1
        },
        183: {
          /* n:"BrtBeginPCDField", */
          T: 1
        },
        184: {
          /* n:"BrtEndPCDField", */
          T: -1
        },
        185: {
          /* n:"BrtBeginPCDSource", */
          T: 1
        },
        186: {
          /* n:"BrtEndPCDSource", */
          T: -1
        },
        187: {
          /* n:"BrtBeginPCDSRange", */
          T: 1
        },
        188: {
          /* n:"BrtEndPCDSRange", */
          T: -1
        },
        189: {
          /* n:"BrtBeginPCDFAtbl", */
          T: 1
        },
        190: {
          /* n:"BrtEndPCDFAtbl", */
          T: -1
        },
        191: {
          /* n:"BrtBeginPCDIRun", */
          T: 1
        },
        192: {
          /* n:"BrtEndPCDIRun", */
          T: -1
        },
        193: {
          /* n:"BrtBeginPivotCacheRecords", */
          T: 1
        },
        194: {
          /* n:"BrtEndPivotCacheRecords", */
          T: -1
        },
        195: {
          /* n:"BrtBeginPCDHierarchies", */
          T: 1
        },
        196: {
          /* n:"BrtEndPCDHierarchies", */
          T: -1
        },
        197: {
          /* n:"BrtBeginPCDHierarchy", */
          T: 1
        },
        198: {
          /* n:"BrtEndPCDHierarchy", */
          T: -1
        },
        199: {
          /* n:"BrtBeginPCDHFieldsUsage", */
          T: 1
        },
        200: {
          /* n:"BrtEndPCDHFieldsUsage", */
          T: -1
        },
        201: {
          /* n:"BrtBeginExtConnection", */
          T: 1
        },
        202: {
          /* n:"BrtEndExtConnection", */
          T: -1
        },
        203: {
          /* n:"BrtBeginECDbProps", */
          T: 1
        },
        204: {
          /* n:"BrtEndECDbProps", */
          T: -1
        },
        205: {
          /* n:"BrtBeginECOlapProps", */
          T: 1
        },
        206: {
          /* n:"BrtEndECOlapProps", */
          T: -1
        },
        207: {
          /* n:"BrtBeginPCDSConsol", */
          T: 1
        },
        208: {
          /* n:"BrtEndPCDSConsol", */
          T: -1
        },
        209: {
          /* n:"BrtBeginPCDSCPages", */
          T: 1
        },
        210: {
          /* n:"BrtEndPCDSCPages", */
          T: -1
        },
        211: {
          /* n:"BrtBeginPCDSCPage", */
          T: 1
        },
        212: {
          /* n:"BrtEndPCDSCPage", */
          T: -1
        },
        213: {
          /* n:"BrtBeginPCDSCPItem", */
          T: 1
        },
        214: {
          /* n:"BrtEndPCDSCPItem", */
          T: -1
        },
        215: {
          /* n:"BrtBeginPCDSCSets", */
          T: 1
        },
        216: {
          /* n:"BrtEndPCDSCSets", */
          T: -1
        },
        217: {
          /* n:"BrtBeginPCDSCSet", */
          T: 1
        },
        218: {
          /* n:"BrtEndPCDSCSet", */
          T: -1
        },
        219: {
          /* n:"BrtBeginPCDFGroup", */
          T: 1
        },
        220: {
          /* n:"BrtEndPCDFGroup", */
          T: -1
        },
        221: {
          /* n:"BrtBeginPCDFGItems", */
          T: 1
        },
        222: {
          /* n:"BrtEndPCDFGItems", */
          T: -1
        },
        223: {
          /* n:"BrtBeginPCDFGRange", */
          T: 1
        },
        224: {
          /* n:"BrtEndPCDFGRange", */
          T: -1
        },
        225: {
          /* n:"BrtBeginPCDFGDiscrete", */
          T: 1
        },
        226: {
          /* n:"BrtEndPCDFGDiscrete", */
          T: -1
        },
        227: {
          /* n:"BrtBeginPCDSDTupleCache", */
          T: 1
        },
        228: {
          /* n:"BrtEndPCDSDTupleCache", */
          T: -1
        },
        229: {
          /* n:"BrtBeginPCDSDTCEntries", */
          T: 1
        },
        230: {
          /* n:"BrtEndPCDSDTCEntries", */
          T: -1
        },
        231: {
          /* n:"BrtBeginPCDSDTCEMembers", */
          T: 1
        },
        232: {
          /* n:"BrtEndPCDSDTCEMembers", */
          T: -1
        },
        233: {
          /* n:"BrtBeginPCDSDTCEMember", */
          T: 1
        },
        234: {
          /* n:"BrtEndPCDSDTCEMember", */
          T: -1
        },
        235: {
          /* n:"BrtBeginPCDSDTCQueries", */
          T: 1
        },
        236: {
          /* n:"BrtEndPCDSDTCQueries", */
          T: -1
        },
        237: {
          /* n:"BrtBeginPCDSDTCQuery", */
          T: 1
        },
        238: {
          /* n:"BrtEndPCDSDTCQuery", */
          T: -1
        },
        239: {
          /* n:"BrtBeginPCDSDTCSets", */
          T: 1
        },
        240: {
          /* n:"BrtEndPCDSDTCSets", */
          T: -1
        },
        241: {
          /* n:"BrtBeginPCDSDTCSet", */
          T: 1
        },
        242: {
          /* n:"BrtEndPCDSDTCSet", */
          T: -1
        },
        243: {
          /* n:"BrtBeginPCDCalcItems", */
          T: 1
        },
        244: {
          /* n:"BrtEndPCDCalcItems", */
          T: -1
        },
        245: {
          /* n:"BrtBeginPCDCalcItem", */
          T: 1
        },
        246: {
          /* n:"BrtEndPCDCalcItem", */
          T: -1
        },
        247: {
          /* n:"BrtBeginPRule", */
          T: 1
        },
        248: {
          /* n:"BrtEndPRule", */
          T: -1
        },
        249: {
          /* n:"BrtBeginPRFilters", */
          T: 1
        },
        250: {
          /* n:"BrtEndPRFilters", */
          T: -1
        },
        251: {
          /* n:"BrtBeginPRFilter", */
          T: 1
        },
        252: {
          /* n:"BrtEndPRFilter", */
          T: -1
        },
        253: {
          /* n:"BrtBeginPNames", */
          T: 1
        },
        254: {
          /* n:"BrtEndPNames", */
          T: -1
        },
        255: {
          /* n:"BrtBeginPName", */
          T: 1
        },
        256: {
          /* n:"BrtEndPName", */
          T: -1
        },
        257: {
          /* n:"BrtBeginPNPairs", */
          T: 1
        },
        258: {
          /* n:"BrtEndPNPairs", */
          T: -1
        },
        259: {
          /* n:"BrtBeginPNPair", */
          T: 1
        },
        260: {
          /* n:"BrtEndPNPair", */
          T: -1
        },
        261: {
          /* n:"BrtBeginECWebProps", */
          T: 1
        },
        262: {
          /* n:"BrtEndECWebProps", */
          T: -1
        },
        263: {
          /* n:"BrtBeginEcWpTables", */
          T: 1
        },
        264: {
          /* n:"BrtEndECWPTables", */
          T: -1
        },
        265: {
          /* n:"BrtBeginECParams", */
          T: 1
        },
        266: {
          /* n:"BrtEndECParams", */
          T: -1
        },
        267: {
          /* n:"BrtBeginECParam", */
          T: 1
        },
        268: {
          /* n:"BrtEndECParam", */
          T: -1
        },
        269: {
          /* n:"BrtBeginPCDKPIs", */
          T: 1
        },
        270: {
          /* n:"BrtEndPCDKPIs", */
          T: -1
        },
        271: {
          /* n:"BrtBeginPCDKPI", */
          T: 1
        },
        272: {
          /* n:"BrtEndPCDKPI", */
          T: -1
        },
        273: {
          /* n:"BrtBeginDims", */
          T: 1
        },
        274: {
          /* n:"BrtEndDims", */
          T: -1
        },
        275: {
          /* n:"BrtBeginDim", */
          T: 1
        },
        276: {
          /* n:"BrtEndDim", */
          T: -1
        },
        277: {
          /* n:"BrtIndexPartEnd" */
        },
        278: {
          /* n:"BrtBeginStyleSheet", */
          T: 1
        },
        279: {
          /* n:"BrtEndStyleSheet", */
          T: -1
        },
        280: {
          /* n:"BrtBeginSXView", */
          T: 1
        },
        281: {
          /* n:"BrtEndSXVI", */
          T: -1
        },
        282: {
          /* n:"BrtBeginSXVI", */
          T: 1
        },
        283: {
          /* n:"BrtBeginSXVIs", */
          T: 1
        },
        284: {
          /* n:"BrtEndSXVIs", */
          T: -1
        },
        285: {
          /* n:"BrtBeginSXVD", */
          T: 1
        },
        286: {
          /* n:"BrtEndSXVD", */
          T: -1
        },
        287: {
          /* n:"BrtBeginSXVDs", */
          T: 1
        },
        288: {
          /* n:"BrtEndSXVDs", */
          T: -1
        },
        289: {
          /* n:"BrtBeginSXPI", */
          T: 1
        },
        290: {
          /* n:"BrtEndSXPI", */
          T: -1
        },
        291: {
          /* n:"BrtBeginSXPIs", */
          T: 1
        },
        292: {
          /* n:"BrtEndSXPIs", */
          T: -1
        },
        293: {
          /* n:"BrtBeginSXDI", */
          T: 1
        },
        294: {
          /* n:"BrtEndSXDI", */
          T: -1
        },
        295: {
          /* n:"BrtBeginSXDIs", */
          T: 1
        },
        296: {
          /* n:"BrtEndSXDIs", */
          T: -1
        },
        297: {
          /* n:"BrtBeginSXLI", */
          T: 1
        },
        298: {
          /* n:"BrtEndSXLI", */
          T: -1
        },
        299: {
          /* n:"BrtBeginSXLIRws", */
          T: 1
        },
        300: {
          /* n:"BrtEndSXLIRws", */
          T: -1
        },
        301: {
          /* n:"BrtBeginSXLICols", */
          T: 1
        },
        302: {
          /* n:"BrtEndSXLICols", */
          T: -1
        },
        303: {
          /* n:"BrtBeginSXFormat", */
          T: 1
        },
        304: {
          /* n:"BrtEndSXFormat", */
          T: -1
        },
        305: {
          /* n:"BrtBeginSXFormats", */
          T: 1
        },
        306: {
          /* n:"BrtEndSxFormats", */
          T: -1
        },
        307: {
          /* n:"BrtBeginSxSelect", */
          T: 1
        },
        308: {
          /* n:"BrtEndSxSelect", */
          T: -1
        },
        309: {
          /* n:"BrtBeginISXVDRws", */
          T: 1
        },
        310: {
          /* n:"BrtEndISXVDRws", */
          T: -1
        },
        311: {
          /* n:"BrtBeginISXVDCols", */
          T: 1
        },
        312: {
          /* n:"BrtEndISXVDCols", */
          T: -1
        },
        313: {
          /* n:"BrtEndSXLocation", */
          T: -1
        },
        314: {
          /* n:"BrtBeginSXLocation", */
          T: 1
        },
        315: {
          /* n:"BrtEndSXView", */
          T: -1
        },
        316: {
          /* n:"BrtBeginSXTHs", */
          T: 1
        },
        317: {
          /* n:"BrtEndSXTHs", */
          T: -1
        },
        318: {
          /* n:"BrtBeginSXTH", */
          T: 1
        },
        319: {
          /* n:"BrtEndSXTH", */
          T: -1
        },
        320: {
          /* n:"BrtBeginISXTHRws", */
          T: 1
        },
        321: {
          /* n:"BrtEndISXTHRws", */
          T: -1
        },
        322: {
          /* n:"BrtBeginISXTHCols", */
          T: 1
        },
        323: {
          /* n:"BrtEndISXTHCols", */
          T: -1
        },
        324: {
          /* n:"BrtBeginSXTDMPS", */
          T: 1
        },
        325: {
          /* n:"BrtEndSXTDMPs", */
          T: -1
        },
        326: {
          /* n:"BrtBeginSXTDMP", */
          T: 1
        },
        327: {
          /* n:"BrtEndSXTDMP", */
          T: -1
        },
        328: {
          /* n:"BrtBeginSXTHItems", */
          T: 1
        },
        329: {
          /* n:"BrtEndSXTHItems", */
          T: -1
        },
        330: {
          /* n:"BrtBeginSXTHItem", */
          T: 1
        },
        331: {
          /* n:"BrtEndSXTHItem", */
          T: -1
        },
        332: {
          /* n:"BrtBeginMetadata", */
          T: 1
        },
        333: {
          /* n:"BrtEndMetadata", */
          T: -1
        },
        334: {
          /* n:"BrtBeginEsmdtinfo", */
          T: 1
        },
        335: {
          /* n:"BrtMdtinfo", */
          f: parse_BrtMdtinfo
        },
        336: {
          /* n:"BrtEndEsmdtinfo", */
          T: -1
        },
        337: {
          /* n:"BrtBeginEsmdb", */
          f: parse_BrtBeginEsmdb,
          T: 1
        },
        338: {
          /* n:"BrtEndEsmdb", */
          T: -1
        },
        339: {
          /* n:"BrtBeginEsfmd", */
          T: 1
        },
        340: {
          /* n:"BrtEndEsfmd", */
          T: -1
        },
        341: {
          /* n:"BrtBeginSingleCells", */
          T: 1
        },
        342: {
          /* n:"BrtEndSingleCells", */
          T: -1
        },
        343: {
          /* n:"BrtBeginList", */
          T: 1
        },
        344: {
          /* n:"BrtEndList", */
          T: -1
        },
        345: {
          /* n:"BrtBeginListCols", */
          T: 1
        },
        346: {
          /* n:"BrtEndListCols", */
          T: -1
        },
        347: {
          /* n:"BrtBeginListCol", */
          T: 1
        },
        348: {
          /* n:"BrtEndListCol", */
          T: -1
        },
        349: {
          /* n:"BrtBeginListXmlCPr", */
          T: 1
        },
        350: {
          /* n:"BrtEndListXmlCPr", */
          T: -1
        },
        351: {
          /* n:"BrtListCCFmla" */
        },
        352: {
          /* n:"BrtListTrFmla" */
        },
        353: {
          /* n:"BrtBeginExternals", */
          T: 1
        },
        354: {
          /* n:"BrtEndExternals", */
          T: -1
        },
        355: {
          /* n:"BrtSupBookSrc", */
          f: parse_RelID
        },
        357: {
          /* n:"BrtSupSelf" */
        },
        358: {
          /* n:"BrtSupSame" */
        },
        359: {
          /* n:"BrtSupTabs" */
        },
        360: {
          /* n:"BrtBeginSupBook", */
          T: 1
        },
        361: {
          /* n:"BrtPlaceholderName" */
        },
        362: {
          /* n:"BrtExternSheet", */
          f: parse_ExternSheet
        },
        363: {
          /* n:"BrtExternTableStart" */
        },
        364: {
          /* n:"BrtExternTableEnd" */
        },
        366: {
          /* n:"BrtExternRowHdr" */
        },
        367: {
          /* n:"BrtExternCellBlank" */
        },
        368: {
          /* n:"BrtExternCellReal" */
        },
        369: {
          /* n:"BrtExternCellBool" */
        },
        370: {
          /* n:"BrtExternCellError" */
        },
        371: {
          /* n:"BrtExternCellString" */
        },
        372: {
          /* n:"BrtBeginEsmdx", */
          T: 1
        },
        373: {
          /* n:"BrtEndEsmdx", */
          T: -1
        },
        374: {
          /* n:"BrtBeginMdxSet", */
          T: 1
        },
        375: {
          /* n:"BrtEndMdxSet", */
          T: -1
        },
        376: {
          /* n:"BrtBeginMdxMbrProp", */
          T: 1
        },
        377: {
          /* n:"BrtEndMdxMbrProp", */
          T: -1
        },
        378: {
          /* n:"BrtBeginMdxKPI", */
          T: 1
        },
        379: {
          /* n:"BrtEndMdxKPI", */
          T: -1
        },
        380: {
          /* n:"BrtBeginEsstr", */
          T: 1
        },
        381: {
          /* n:"BrtEndEsstr", */
          T: -1
        },
        382: {
          /* n:"BrtBeginPRFItem", */
          T: 1
        },
        383: {
          /* n:"BrtEndPRFItem", */
          T: -1
        },
        384: {
          /* n:"BrtBeginPivotCacheIDs", */
          T: 1
        },
        385: {
          /* n:"BrtEndPivotCacheIDs", */
          T: -1
        },
        386: {
          /* n:"BrtBeginPivotCacheID", */
          T: 1
        },
        387: {
          /* n:"BrtEndPivotCacheID", */
          T: -1
        },
        388: {
          /* n:"BrtBeginISXVIs", */
          T: 1
        },
        389: {
          /* n:"BrtEndISXVIs", */
          T: -1
        },
        390: {
          /* n:"BrtBeginColInfos", */
          T: 1
        },
        391: {
          /* n:"BrtEndColInfos", */
          T: -1
        },
        392: {
          /* n:"BrtBeginRwBrk", */
          T: 1
        },
        393: {
          /* n:"BrtEndRwBrk", */
          T: -1
        },
        394: {
          /* n:"BrtBeginColBrk", */
          T: 1
        },
        395: {
          /* n:"BrtEndColBrk", */
          T: -1
        },
        396: {
          /* n:"BrtBrk" */
        },
        397: {
          /* n:"BrtUserBookView" */
        },
        398: {
          /* n:"BrtInfo" */
        },
        399: {
          /* n:"BrtCUsr" */
        },
        400: {
          /* n:"BrtUsr" */
        },
        401: {
          /* n:"BrtBeginUsers", */
          T: 1
        },
        403: {
          /* n:"BrtEOF" */
        },
        404: {
          /* n:"BrtUCR" */
        },
        405: {
          /* n:"BrtRRInsDel" */
        },
        406: {
          /* n:"BrtRREndInsDel" */
        },
        407: {
          /* n:"BrtRRMove" */
        },
        408: {
          /* n:"BrtRREndMove" */
        },
        409: {
          /* n:"BrtRRChgCell" */
        },
        410: {
          /* n:"BrtRREndChgCell" */
        },
        411: {
          /* n:"BrtRRHeader" */
        },
        412: {
          /* n:"BrtRRUserView" */
        },
        413: {
          /* n:"BrtRRRenSheet" */
        },
        414: {
          /* n:"BrtRRInsertSh" */
        },
        415: {
          /* n:"BrtRRDefName" */
        },
        416: {
          /* n:"BrtRRNote" */
        },
        417: {
          /* n:"BrtRRConflict" */
        },
        418: {
          /* n:"BrtRRTQSIF" */
        },
        419: {
          /* n:"BrtRRFormat" */
        },
        420: {
          /* n:"BrtRREndFormat" */
        },
        421: {
          /* n:"BrtRRAutoFmt" */
        },
        422: {
          /* n:"BrtBeginUserShViews", */
          T: 1
        },
        423: {
          /* n:"BrtBeginUserShView", */
          T: 1
        },
        424: {
          /* n:"BrtEndUserShView", */
          T: -1
        },
        425: {
          /* n:"BrtEndUserShViews", */
          T: -1
        },
        426: {
          /* n:"BrtArrFmla", */
          f: parse_BrtArrFmla
        },
        427: {
          /* n:"BrtShrFmla", */
          f: parse_BrtShrFmla
        },
        428: {
          /* n:"BrtTable" */
        },
        429: {
          /* n:"BrtBeginExtConnections", */
          T: 1
        },
        430: {
          /* n:"BrtEndExtConnections", */
          T: -1
        },
        431: {
          /* n:"BrtBeginPCDCalcMems", */
          T: 1
        },
        432: {
          /* n:"BrtEndPCDCalcMems", */
          T: -1
        },
        433: {
          /* n:"BrtBeginPCDCalcMem", */
          T: 1
        },
        434: {
          /* n:"BrtEndPCDCalcMem", */
          T: -1
        },
        435: {
          /* n:"BrtBeginPCDHGLevels", */
          T: 1
        },
        436: {
          /* n:"BrtEndPCDHGLevels", */
          T: -1
        },
        437: {
          /* n:"BrtBeginPCDHGLevel", */
          T: 1
        },
        438: {
          /* n:"BrtEndPCDHGLevel", */
          T: -1
        },
        439: {
          /* n:"BrtBeginPCDHGLGroups", */
          T: 1
        },
        440: {
          /* n:"BrtEndPCDHGLGroups", */
          T: -1
        },
        441: {
          /* n:"BrtBeginPCDHGLGroup", */
          T: 1
        },
        442: {
          /* n:"BrtEndPCDHGLGroup", */
          T: -1
        },
        443: {
          /* n:"BrtBeginPCDHGLGMembers", */
          T: 1
        },
        444: {
          /* n:"BrtEndPCDHGLGMembers", */
          T: -1
        },
        445: {
          /* n:"BrtBeginPCDHGLGMember", */
          T: 1
        },
        446: {
          /* n:"BrtEndPCDHGLGMember", */
          T: -1
        },
        447: {
          /* n:"BrtBeginQSI", */
          T: 1
        },
        448: {
          /* n:"BrtEndQSI", */
          T: -1
        },
        449: {
          /* n:"BrtBeginQSIR", */
          T: 1
        },
        450: {
          /* n:"BrtEndQSIR", */
          T: -1
        },
        451: {
          /* n:"BrtBeginDeletedNames", */
          T: 1
        },
        452: {
          /* n:"BrtEndDeletedNames", */
          T: -1
        },
        453: {
          /* n:"BrtBeginDeletedName", */
          T: 1
        },
        454: {
          /* n:"BrtEndDeletedName", */
          T: -1
        },
        455: {
          /* n:"BrtBeginQSIFs", */
          T: 1
        },
        456: {
          /* n:"BrtEndQSIFs", */
          T: -1
        },
        457: {
          /* n:"BrtBeginQSIF", */
          T: 1
        },
        458: {
          /* n:"BrtEndQSIF", */
          T: -1
        },
        459: {
          /* n:"BrtBeginAutoSortScope", */
          T: 1
        },
        460: {
          /* n:"BrtEndAutoSortScope", */
          T: -1
        },
        461: {
          /* n:"BrtBeginConditionalFormatting", */
          T: 1
        },
        462: {
          /* n:"BrtEndConditionalFormatting", */
          T: -1
        },
        463: {
          /* n:"BrtBeginCFRule", */
          T: 1
        },
        464: {
          /* n:"BrtEndCFRule", */
          T: -1
        },
        465: {
          /* n:"BrtBeginIconSet", */
          T: 1
        },
        466: {
          /* n:"BrtEndIconSet", */
          T: -1
        },
        467: {
          /* n:"BrtBeginDatabar", */
          T: 1
        },
        468: {
          /* n:"BrtEndDatabar", */
          T: -1
        },
        469: {
          /* n:"BrtBeginColorScale", */
          T: 1
        },
        470: {
          /* n:"BrtEndColorScale", */
          T: -1
        },
        471: {
          /* n:"BrtCFVO" */
        },
        472: {
          /* n:"BrtExternValueMeta" */
        },
        473: {
          /* n:"BrtBeginColorPalette", */
          T: 1
        },
        474: {
          /* n:"BrtEndColorPalette", */
          T: -1
        },
        475: {
          /* n:"BrtIndexedColor" */
        },
        476: {
          /* n:"BrtMargins", */
          f: parse_BrtMargins
        },
        477: {
          /* n:"BrtPrintOptions" */
        },
        478: {
          /* n:"BrtPageSetup" */
        },
        479: {
          /* n:"BrtBeginHeaderFooter", */
          T: 1
        },
        480: {
          /* n:"BrtEndHeaderFooter", */
          T: -1
        },
        481: {
          /* n:"BrtBeginSXCrtFormat", */
          T: 1
        },
        482: {
          /* n:"BrtEndSXCrtFormat", */
          T: -1
        },
        483: {
          /* n:"BrtBeginSXCrtFormats", */
          T: 1
        },
        484: {
          /* n:"BrtEndSXCrtFormats", */
          T: -1
        },
        485: {
          /* n:"BrtWsFmtInfo", */
          f: parse_BrtWsFmtInfo
        },
        486: {
          /* n:"BrtBeginMgs", */
          T: 1
        },
        487: {
          /* n:"BrtEndMGs", */
          T: -1
        },
        488: {
          /* n:"BrtBeginMGMaps", */
          T: 1
        },
        489: {
          /* n:"BrtEndMGMaps", */
          T: -1
        },
        490: {
          /* n:"BrtBeginMG", */
          T: 1
        },
        491: {
          /* n:"BrtEndMG", */
          T: -1
        },
        492: {
          /* n:"BrtBeginMap", */
          T: 1
        },
        493: {
          /* n:"BrtEndMap", */
          T: -1
        },
        494: {
          /* n:"BrtHLink", */
          f: parse_BrtHLink
        },
        495: {
          /* n:"BrtBeginDCon", */
          T: 1
        },
        496: {
          /* n:"BrtEndDCon", */
          T: -1
        },
        497: {
          /* n:"BrtBeginDRefs", */
          T: 1
        },
        498: {
          /* n:"BrtEndDRefs", */
          T: -1
        },
        499: {
          /* n:"BrtDRef" */
        },
        500: {
          /* n:"BrtBeginScenMan", */
          T: 1
        },
        501: {
          /* n:"BrtEndScenMan", */
          T: -1
        },
        502: {
          /* n:"BrtBeginSct", */
          T: 1
        },
        503: {
          /* n:"BrtEndSct", */
          T: -1
        },
        504: {
          /* n:"BrtSlc" */
        },
        505: {
          /* n:"BrtBeginDXFs", */
          T: 1
        },
        506: {
          /* n:"BrtEndDXFs", */
          T: -1
        },
        507: {
          /* n:"BrtDXF" */
        },
        508: {
          /* n:"BrtBeginTableStyles", */
          T: 1
        },
        509: {
          /* n:"BrtEndTableStyles", */
          T: -1
        },
        510: {
          /* n:"BrtBeginTableStyle", */
          T: 1
        },
        511: {
          /* n:"BrtEndTableStyle", */
          T: -1
        },
        512: {
          /* n:"BrtTableStyleElement" */
        },
        513: {
          /* n:"BrtTableStyleClient" */
        },
        514: {
          /* n:"BrtBeginVolDeps", */
          T: 1
        },
        515: {
          /* n:"BrtEndVolDeps", */
          T: -1
        },
        516: {
          /* n:"BrtBeginVolType", */
          T: 1
        },
        517: {
          /* n:"BrtEndVolType", */
          T: -1
        },
        518: {
          /* n:"BrtBeginVolMain", */
          T: 1
        },
        519: {
          /* n:"BrtEndVolMain", */
          T: -1
        },
        520: {
          /* n:"BrtBeginVolTopic", */
          T: 1
        },
        521: {
          /* n:"BrtEndVolTopic", */
          T: -1
        },
        522: {
          /* n:"BrtVolSubtopic" */
        },
        523: {
          /* n:"BrtVolRef" */
        },
        524: {
          /* n:"BrtVolNum" */
        },
        525: {
          /* n:"BrtVolErr" */
        },
        526: {
          /* n:"BrtVolStr" */
        },
        527: {
          /* n:"BrtVolBool" */
        },
        528: {
          /* n:"BrtBeginCalcChain$", */
          T: 1
        },
        529: {
          /* n:"BrtEndCalcChain$", */
          T: -1
        },
        530: {
          /* n:"BrtBeginSortState", */
          T: 1
        },
        531: {
          /* n:"BrtEndSortState", */
          T: -1
        },
        532: {
          /* n:"BrtBeginSortCond", */
          T: 1
        },
        533: {
          /* n:"BrtEndSortCond", */
          T: -1
        },
        534: {
          /* n:"BrtBookProtection" */
        },
        535: {
          /* n:"BrtSheetProtection" */
        },
        536: {
          /* n:"BrtRangeProtection" */
        },
        537: {
          /* n:"BrtPhoneticInfo" */
        },
        538: {
          /* n:"BrtBeginECTxtWiz", */
          T: 1
        },
        539: {
          /* n:"BrtEndECTxtWiz", */
          T: -1
        },
        540: {
          /* n:"BrtBeginECTWFldInfoLst", */
          T: 1
        },
        541: {
          /* n:"BrtEndECTWFldInfoLst", */
          T: -1
        },
        542: {
          /* n:"BrtBeginECTwFldInfo", */
          T: 1
        },
        548: {
          /* n:"BrtFileSharing" */
        },
        549: {
          /* n:"BrtOleSize" */
        },
        550: {
          /* n:"BrtDrawing", */
          f: parse_RelID
        },
        551: {
          /* n:"BrtLegacyDrawing" */
        },
        552: {
          /* n:"BrtLegacyDrawingHF" */
        },
        553: {
          /* n:"BrtWebOpt" */
        },
        554: {
          /* n:"BrtBeginWebPubItems", */
          T: 1
        },
        555: {
          /* n:"BrtEndWebPubItems", */
          T: -1
        },
        556: {
          /* n:"BrtBeginWebPubItem", */
          T: 1
        },
        557: {
          /* n:"BrtEndWebPubItem", */
          T: -1
        },
        558: {
          /* n:"BrtBeginSXCondFmt", */
          T: 1
        },
        559: {
          /* n:"BrtEndSXCondFmt", */
          T: -1
        },
        560: {
          /* n:"BrtBeginSXCondFmts", */
          T: 1
        },
        561: {
          /* n:"BrtEndSXCondFmts", */
          T: -1
        },
        562: {
          /* n:"BrtBkHim" */
        },
        564: {
          /* n:"BrtColor" */
        },
        565: {
          /* n:"BrtBeginIndexedColors", */
          T: 1
        },
        566: {
          /* n:"BrtEndIndexedColors", */
          T: -1
        },
        569: {
          /* n:"BrtBeginMRUColors", */
          T: 1
        },
        570: {
          /* n:"BrtEndMRUColors", */
          T: -1
        },
        572: {
          /* n:"BrtMRUColor" */
        },
        573: {
          /* n:"BrtBeginDVals", */
          T: 1
        },
        574: {
          /* n:"BrtEndDVals", */
          T: -1
        },
        577: {
          /* n:"BrtSupNameStart" */
        },
        578: {
          /* n:"BrtSupNameValueStart" */
        },
        579: {
          /* n:"BrtSupNameValueEnd" */
        },
        580: {
          /* n:"BrtSupNameNum" */
        },
        581: {
          /* n:"BrtSupNameErr" */
        },
        582: {
          /* n:"BrtSupNameSt" */
        },
        583: {
          /* n:"BrtSupNameNil" */
        },
        584: {
          /* n:"BrtSupNameBool" */
        },
        585: {
          /* n:"BrtSupNameFmla" */
        },
        586: {
          /* n:"BrtSupNameBits" */
        },
        587: {
          /* n:"BrtSupNameEnd" */
        },
        588: {
          /* n:"BrtEndSupBook", */
          T: -1
        },
        589: {
          /* n:"BrtCellSmartTagProperty" */
        },
        590: {
          /* n:"BrtBeginCellSmartTag", */
          T: 1
        },
        591: {
          /* n:"BrtEndCellSmartTag", */
          T: -1
        },
        592: {
          /* n:"BrtBeginCellSmartTags", */
          T: 1
        },
        593: {
          /* n:"BrtEndCellSmartTags", */
          T: -1
        },
        594: {
          /* n:"BrtBeginSmartTags", */
          T: 1
        },
        595: {
          /* n:"BrtEndSmartTags", */
          T: -1
        },
        596: {
          /* n:"BrtSmartTagType" */
        },
        597: {
          /* n:"BrtBeginSmartTagTypes", */
          T: 1
        },
        598: {
          /* n:"BrtEndSmartTagTypes", */
          T: -1
        },
        599: {
          /* n:"BrtBeginSXFilters", */
          T: 1
        },
        600: {
          /* n:"BrtEndSXFilters", */
          T: -1
        },
        601: {
          /* n:"BrtBeginSXFILTER", */
          T: 1
        },
        602: {
          /* n:"BrtEndSXFilter", */
          T: -1
        },
        603: {
          /* n:"BrtBeginFills", */
          T: 1
        },
        604: {
          /* n:"BrtEndFills", */
          T: -1
        },
        605: {
          /* n:"BrtBeginCellWatches", */
          T: 1
        },
        606: {
          /* n:"BrtEndCellWatches", */
          T: -1
        },
        607: {
          /* n:"BrtCellWatch" */
        },
        608: {
          /* n:"BrtBeginCRErrs", */
          T: 1
        },
        609: {
          /* n:"BrtEndCRErrs", */
          T: -1
        },
        610: {
          /* n:"BrtCrashRecErr" */
        },
        611: {
          /* n:"BrtBeginFonts", */
          T: 1
        },
        612: {
          /* n:"BrtEndFonts", */
          T: -1
        },
        613: {
          /* n:"BrtBeginBorders", */
          T: 1
        },
        614: {
          /* n:"BrtEndBorders", */
          T: -1
        },
        615: {
          /* n:"BrtBeginFmts", */
          T: 1
        },
        616: {
          /* n:"BrtEndFmts", */
          T: -1
        },
        617: {
          /* n:"BrtBeginCellXFs", */
          T: 1
        },
        618: {
          /* n:"BrtEndCellXFs", */
          T: -1
        },
        619: {
          /* n:"BrtBeginStyles", */
          T: 1
        },
        620: {
          /* n:"BrtEndStyles", */
          T: -1
        },
        625: {
          /* n:"BrtBigName" */
        },
        626: {
          /* n:"BrtBeginCellStyleXFs", */
          T: 1
        },
        627: {
          /* n:"BrtEndCellStyleXFs", */
          T: -1
        },
        628: {
          /* n:"BrtBeginComments", */
          T: 1
        },
        629: {
          /* n:"BrtEndComments", */
          T: -1
        },
        630: {
          /* n:"BrtBeginCommentAuthors", */
          T: 1
        },
        631: {
          /* n:"BrtEndCommentAuthors", */
          T: -1
        },
        632: {
          /* n:"BrtCommentAuthor", */
          f: parse_BrtCommentAuthor
        },
        633: {
          /* n:"BrtBeginCommentList", */
          T: 1
        },
        634: {
          /* n:"BrtEndCommentList", */
          T: -1
        },
        635: {
          /* n:"BrtBeginComment", */
          T: 1,
          f: parse_BrtBeginComment
        },
        636: {
          /* n:"BrtEndComment", */
          T: -1
        },
        637: {
          /* n:"BrtCommentText", */
          f: parse_BrtCommentText
        },
        638: {
          /* n:"BrtBeginOleObjects", */
          T: 1
        },
        639: {
          /* n:"BrtOleObject" */
        },
        640: {
          /* n:"BrtEndOleObjects", */
          T: -1
        },
        641: {
          /* n:"BrtBeginSxrules", */
          T: 1
        },
        642: {
          /* n:"BrtEndSxRules", */
          T: -1
        },
        643: {
          /* n:"BrtBeginActiveXControls", */
          T: 1
        },
        644: {
          /* n:"BrtActiveX" */
        },
        645: {
          /* n:"BrtEndActiveXControls", */
          T: -1
        },
        646: {
          /* n:"BrtBeginPCDSDTCEMembersSortBy", */
          T: 1
        },
        648: {
          /* n:"BrtBeginCellIgnoreECs", */
          T: 1
        },
        649: {
          /* n:"BrtCellIgnoreEC" */
        },
        650: {
          /* n:"BrtEndCellIgnoreECs", */
          T: -1
        },
        651: {
          /* n:"BrtCsProp", */
          f: parse_BrtCsProp
        },
        652: {
          /* n:"BrtCsPageSetup" */
        },
        653: {
          /* n:"BrtBeginUserCsViews", */
          T: 1
        },
        654: {
          /* n:"BrtEndUserCsViews", */
          T: -1
        },
        655: {
          /* n:"BrtBeginUserCsView", */
          T: 1
        },
        656: {
          /* n:"BrtEndUserCsView", */
          T: -1
        },
        657: {
          /* n:"BrtBeginPcdSFCIEntries", */
          T: 1
        },
        658: {
          /* n:"BrtEndPCDSFCIEntries", */
          T: -1
        },
        659: {
          /* n:"BrtPCDSFCIEntry" */
        },
        660: {
          /* n:"BrtBeginListParts", */
          T: 1
        },
        661: {
          /* n:"BrtListPart" */
        },
        662: {
          /* n:"BrtEndListParts", */
          T: -1
        },
        663: {
          /* n:"BrtSheetCalcProp" */
        },
        664: {
          /* n:"BrtBeginFnGroup", */
          T: 1
        },
        665: {
          /* n:"BrtFnGroup" */
        },
        666: {
          /* n:"BrtEndFnGroup", */
          T: -1
        },
        667: {
          /* n:"BrtSupAddin" */
        },
        668: {
          /* n:"BrtSXTDMPOrder" */
        },
        669: {
          /* n:"BrtCsProtection" */
        },
        671: {
          /* n:"BrtBeginWsSortMap", */
          T: 1
        },
        672: {
          /* n:"BrtEndWsSortMap", */
          T: -1
        },
        673: {
          /* n:"BrtBeginRRSort", */
          T: 1
        },
        674: {
          /* n:"BrtEndRRSort", */
          T: -1
        },
        675: {
          /* n:"BrtRRSortItem" */
        },
        676: {
          /* n:"BrtFileSharingIso" */
        },
        677: {
          /* n:"BrtBookProtectionIso" */
        },
        678: {
          /* n:"BrtSheetProtectionIso" */
        },
        679: {
          /* n:"BrtCsProtectionIso" */
        },
        680: {
          /* n:"BrtRangeProtectionIso" */
        },
        681: {
          /* n:"BrtDValList" */
        },
        1024: {
          /* n:"BrtRwDescent" */
        },
        1025: {
          /* n:"BrtKnownFonts" */
        },
        1026: {
          /* n:"BrtBeginSXTupleSet", */
          T: 1
        },
        1027: {
          /* n:"BrtEndSXTupleSet", */
          T: -1
        },
        1028: {
          /* n:"BrtBeginSXTupleSetHeader", */
          T: 1
        },
        1029: {
          /* n:"BrtEndSXTupleSetHeader", */
          T: -1
        },
        1030: {
          /* n:"BrtSXTupleSetHeaderItem" */
        },
        1031: {
          /* n:"BrtBeginSXTupleSetData", */
          T: 1
        },
        1032: {
          /* n:"BrtEndSXTupleSetData", */
          T: -1
        },
        1033: {
          /* n:"BrtBeginSXTupleSetRow", */
          T: 1
        },
        1034: {
          /* n:"BrtEndSXTupleSetRow", */
          T: -1
        },
        1035: {
          /* n:"BrtSXTupleSetRowItem" */
        },
        1036: {
          /* n:"BrtNameExt" */
        },
        1037: {
          /* n:"BrtPCDH14" */
        },
        1038: {
          /* n:"BrtBeginPCDCalcMem14", */
          T: 1
        },
        1039: {
          /* n:"BrtEndPCDCalcMem14", */
          T: -1
        },
        1040: {
          /* n:"BrtSXTH14" */
        },
        1041: {
          /* n:"BrtBeginSparklineGroup", */
          T: 1
        },
        1042: {
          /* n:"BrtEndSparklineGroup", */
          T: -1
        },
        1043: {
          /* n:"BrtSparkline" */
        },
        1044: {
          /* n:"BrtSXDI14" */
        },
        1045: {
          /* n:"BrtWsFmtInfoEx14" */
        },
        1046: {
          /* n:"BrtBeginConditionalFormatting14", */
          T: 1
        },
        1047: {
          /* n:"BrtEndConditionalFormatting14", */
          T: -1
        },
        1048: {
          /* n:"BrtBeginCFRule14", */
          T: 1
        },
        1049: {
          /* n:"BrtEndCFRule14", */
          T: -1
        },
        1050: {
          /* n:"BrtCFVO14" */
        },
        1051: {
          /* n:"BrtBeginDatabar14", */
          T: 1
        },
        1052: {
          /* n:"BrtBeginIconSet14", */
          T: 1
        },
        1053: {
          /* n:"BrtDVal14", */
          f: parse_BrtDVal14
        },
        1054: {
          /* n:"BrtBeginDVals14", */
          T: 1
        },
        1055: {
          /* n:"BrtColor14" */
        },
        1056: {
          /* n:"BrtBeginSparklines", */
          T: 1
        },
        1057: {
          /* n:"BrtEndSparklines", */
          T: -1
        },
        1058: {
          /* n:"BrtBeginSparklineGroups", */
          T: 1
        },
        1059: {
          /* n:"BrtEndSparklineGroups", */
          T: -1
        },
        1061: {
          /* n:"BrtSXVD14" */
        },
        1062: {
          /* n:"BrtBeginSXView14", */
          T: 1
        },
        1063: {
          /* n:"BrtEndSXView14", */
          T: -1
        },
        1064: {
          /* n:"BrtBeginSXView16", */
          T: 1
        },
        1065: {
          /* n:"BrtEndSXView16", */
          T: -1
        },
        1066: {
          /* n:"BrtBeginPCD14", */
          T: 1
        },
        1067: {
          /* n:"BrtEndPCD14", */
          T: -1
        },
        1068: {
          /* n:"BrtBeginExtConn14", */
          T: 1
        },
        1069: {
          /* n:"BrtEndExtConn14", */
          T: -1
        },
        1070: {
          /* n:"BrtBeginSlicerCacheIDs", */
          T: 1
        },
        1071: {
          /* n:"BrtEndSlicerCacheIDs", */
          T: -1
        },
        1072: {
          /* n:"BrtBeginSlicerCacheID", */
          T: 1
        },
        1073: {
          /* n:"BrtEndSlicerCacheID", */
          T: -1
        },
        1075: {
          /* n:"BrtBeginSlicerCache", */
          T: 1
        },
        1076: {
          /* n:"BrtEndSlicerCache", */
          T: -1
        },
        1077: {
          /* n:"BrtBeginSlicerCacheDef", */
          T: 1
        },
        1078: {
          /* n:"BrtEndSlicerCacheDef", */
          T: -1
        },
        1079: {
          /* n:"BrtBeginSlicersEx", */
          T: 1
        },
        1080: {
          /* n:"BrtEndSlicersEx", */
          T: -1
        },
        1081: {
          /* n:"BrtBeginSlicerEx", */
          T: 1
        },
        1082: {
          /* n:"BrtEndSlicerEx", */
          T: -1
        },
        1083: {
          /* n:"BrtBeginSlicer", */
          T: 1
        },
        1084: {
          /* n:"BrtEndSlicer", */
          T: -1
        },
        1085: {
          /* n:"BrtSlicerCachePivotTables" */
        },
        1086: {
          /* n:"BrtBeginSlicerCacheOlapImpl", */
          T: 1
        },
        1087: {
          /* n:"BrtEndSlicerCacheOlapImpl", */
          T: -1
        },
        1088: {
          /* n:"BrtBeginSlicerCacheLevelsData", */
          T: 1
        },
        1089: {
          /* n:"BrtEndSlicerCacheLevelsData", */
          T: -1
        },
        1090: {
          /* n:"BrtBeginSlicerCacheLevelData", */
          T: 1
        },
        1091: {
          /* n:"BrtEndSlicerCacheLevelData", */
          T: -1
        },
        1092: {
          /* n:"BrtBeginSlicerCacheSiRanges", */
          T: 1
        },
        1093: {
          /* n:"BrtEndSlicerCacheSiRanges", */
          T: -1
        },
        1094: {
          /* n:"BrtBeginSlicerCacheSiRange", */
          T: 1
        },
        1095: {
          /* n:"BrtEndSlicerCacheSiRange", */
          T: -1
        },
        1096: {
          /* n:"BrtSlicerCacheOlapItem" */
        },
        1097: {
          /* n:"BrtBeginSlicerCacheSelections", */
          T: 1
        },
        1098: {
          /* n:"BrtSlicerCacheSelection" */
        },
        1099: {
          /* n:"BrtEndSlicerCacheSelections", */
          T: -1
        },
        1100: {
          /* n:"BrtBeginSlicerCacheNative", */
          T: 1
        },
        1101: {
          /* n:"BrtEndSlicerCacheNative", */
          T: -1
        },
        1102: {
          /* n:"BrtSlicerCacheNativeItem" */
        },
        1103: {
          /* n:"BrtRangeProtection14" */
        },
        1104: {
          /* n:"BrtRangeProtectionIso14" */
        },
        1105: {
          /* n:"BrtCellIgnoreEC14" */
        },
        1111: {
          /* n:"BrtList14" */
        },
        1112: {
          /* n:"BrtCFIcon" */
        },
        1113: {
          /* n:"BrtBeginSlicerCachesPivotCacheIDs", */
          T: 1
        },
        1114: {
          /* n:"BrtEndSlicerCachesPivotCacheIDs", */
          T: -1
        },
        1115: {
          /* n:"BrtBeginSlicers", */
          T: 1
        },
        1116: {
          /* n:"BrtEndSlicers", */
          T: -1
        },
        1117: {
          /* n:"BrtWbProp14" */
        },
        1118: {
          /* n:"BrtBeginSXEdit", */
          T: 1
        },
        1119: {
          /* n:"BrtEndSXEdit", */
          T: -1
        },
        1120: {
          /* n:"BrtBeginSXEdits", */
          T: 1
        },
        1121: {
          /* n:"BrtEndSXEdits", */
          T: -1
        },
        1122: {
          /* n:"BrtBeginSXChange", */
          T: 1
        },
        1123: {
          /* n:"BrtEndSXChange", */
          T: -1
        },
        1124: {
          /* n:"BrtBeginSXChanges", */
          T: 1
        },
        1125: {
          /* n:"BrtEndSXChanges", */
          T: -1
        },
        1126: {
          /* n:"BrtSXTupleItems" */
        },
        1128: {
          /* n:"BrtBeginSlicerStyle", */
          T: 1
        },
        1129: {
          /* n:"BrtEndSlicerStyle", */
          T: -1
        },
        1130: {
          /* n:"BrtSlicerStyleElement" */
        },
        1131: {
          /* n:"BrtBeginStyleSheetExt14", */
          T: 1
        },
        1132: {
          /* n:"BrtEndStyleSheetExt14", */
          T: -1
        },
        1133: {
          /* n:"BrtBeginSlicerCachesPivotCacheID", */
          T: 1
        },
        1134: {
          /* n:"BrtEndSlicerCachesPivotCacheID", */
          T: -1
        },
        1135: {
          /* n:"BrtBeginConditionalFormattings", */
          T: 1
        },
        1136: {
          /* n:"BrtEndConditionalFormattings", */
          T: -1
        },
        1137: {
          /* n:"BrtBeginPCDCalcMemExt", */
          T: 1
        },
        1138: {
          /* n:"BrtEndPCDCalcMemExt", */
          T: -1
        },
        1139: {
          /* n:"BrtBeginPCDCalcMemsExt", */
          T: 1
        },
        1140: {
          /* n:"BrtEndPCDCalcMemsExt", */
          T: -1
        },
        1141: {
          /* n:"BrtPCDField14" */
        },
        1142: {
          /* n:"BrtBeginSlicerStyles", */
          T: 1
        },
        1143: {
          /* n:"BrtEndSlicerStyles", */
          T: -1
        },
        1144: {
          /* n:"BrtBeginSlicerStyleElements", */
          T: 1
        },
        1145: {
          /* n:"BrtEndSlicerStyleElements", */
          T: -1
        },
        1146: {
          /* n:"BrtCFRuleExt" */
        },
        1147: {
          /* n:"BrtBeginSXCondFmt14", */
          T: 1
        },
        1148: {
          /* n:"BrtEndSXCondFmt14", */
          T: -1
        },
        1149: {
          /* n:"BrtBeginSXCondFmts14", */
          T: 1
        },
        1150: {
          /* n:"BrtEndSXCondFmts14", */
          T: -1
        },
        1152: {
          /* n:"BrtBeginSortCond14", */
          T: 1
        },
        1153: {
          /* n:"BrtEndSortCond14", */
          T: -1
        },
        1154: {
          /* n:"BrtEndDVals14", */
          T: -1
        },
        1155: {
          /* n:"BrtEndIconSet14", */
          T: -1
        },
        1156: {
          /* n:"BrtEndDatabar14", */
          T: -1
        },
        1157: {
          /* n:"BrtBeginColorScale14", */
          T: 1
        },
        1158: {
          /* n:"BrtEndColorScale14", */
          T: -1
        },
        1159: {
          /* n:"BrtBeginSxrules14", */
          T: 1
        },
        1160: {
          /* n:"BrtEndSxrules14", */
          T: -1
        },
        1161: {
          /* n:"BrtBeginPRule14", */
          T: 1
        },
        1162: {
          /* n:"BrtEndPRule14", */
          T: -1
        },
        1163: {
          /* n:"BrtBeginPRFilters14", */
          T: 1
        },
        1164: {
          /* n:"BrtEndPRFilters14", */
          T: -1
        },
        1165: {
          /* n:"BrtBeginPRFilter14", */
          T: 1
        },
        1166: {
          /* n:"BrtEndPRFilter14", */
          T: -1
        },
        1167: {
          /* n:"BrtBeginPRFItem14", */
          T: 1
        },
        1168: {
          /* n:"BrtEndPRFItem14", */
          T: -1
        },
        1169: {
          /* n:"BrtBeginCellIgnoreECs14", */
          T: 1
        },
        1170: {
          /* n:"BrtEndCellIgnoreECs14", */
          T: -1
        },
        1171: {
          /* n:"BrtDxf14" */
        },
        1172: {
          /* n:"BrtBeginDxF14s", */
          T: 1
        },
        1173: {
          /* n:"BrtEndDxf14s", */
          T: -1
        },
        1177: {
          /* n:"BrtFilter14" */
        },
        1178: {
          /* n:"BrtBeginCustomFilters14", */
          T: 1
        },
        1180: {
          /* n:"BrtCustomFilter14" */
        },
        1181: {
          /* n:"BrtIconFilter14" */
        },
        1182: {
          /* n:"BrtPivotCacheConnectionName" */
        },
        2048: {
          /* n:"BrtBeginDecoupledPivotCacheIDs", */
          T: 1
        },
        2049: {
          /* n:"BrtEndDecoupledPivotCacheIDs", */
          T: -1
        },
        2050: {
          /* n:"BrtDecoupledPivotCacheID" */
        },
        2051: {
          /* n:"BrtBeginPivotTableRefs", */
          T: 1
        },
        2052: {
          /* n:"BrtEndPivotTableRefs", */
          T: -1
        },
        2053: {
          /* n:"BrtPivotTableRef" */
        },
        2054: {
          /* n:"BrtSlicerCacheBookPivotTables" */
        },
        2055: {
          /* n:"BrtBeginSxvcells", */
          T: 1
        },
        2056: {
          /* n:"BrtEndSxvcells", */
          T: -1
        },
        2057: {
          /* n:"BrtBeginSxRow", */
          T: 1
        },
        2058: {
          /* n:"BrtEndSxRow", */
          T: -1
        },
        2060: {
          /* n:"BrtPcdCalcMem15" */
        },
        2067: {
          /* n:"BrtQsi15" */
        },
        2068: {
          /* n:"BrtBeginWebExtensions", */
          T: 1
        },
        2069: {
          /* n:"BrtEndWebExtensions", */
          T: -1
        },
        2070: {
          /* n:"BrtWebExtension" */
        },
        2071: {
          /* n:"BrtAbsPath15" */
        },
        2072: {
          /* n:"BrtBeginPivotTableUISettings", */
          T: 1
        },
        2073: {
          /* n:"BrtEndPivotTableUISettings", */
          T: -1
        },
        2075: {
          /* n:"BrtTableSlicerCacheIDs" */
        },
        2076: {
          /* n:"BrtTableSlicerCacheID" */
        },
        2077: {
          /* n:"BrtBeginTableSlicerCache", */
          T: 1
        },
        2078: {
          /* n:"BrtEndTableSlicerCache", */
          T: -1
        },
        2079: {
          /* n:"BrtSxFilter15" */
        },
        2080: {
          /* n:"BrtBeginTimelineCachePivotCacheIDs", */
          T: 1
        },
        2081: {
          /* n:"BrtEndTimelineCachePivotCacheIDs", */
          T: -1
        },
        2082: {
          /* n:"BrtTimelineCachePivotCacheID" */
        },
        2083: {
          /* n:"BrtBeginTimelineCacheIDs", */
          T: 1
        },
        2084: {
          /* n:"BrtEndTimelineCacheIDs", */
          T: -1
        },
        2085: {
          /* n:"BrtBeginTimelineCacheID", */
          T: 1
        },
        2086: {
          /* n:"BrtEndTimelineCacheID", */
          T: -1
        },
        2087: {
          /* n:"BrtBeginTimelinesEx", */
          T: 1
        },
        2088: {
          /* n:"BrtEndTimelinesEx", */
          T: -1
        },
        2089: {
          /* n:"BrtBeginTimelineEx", */
          T: 1
        },
        2090: {
          /* n:"BrtEndTimelineEx", */
          T: -1
        },
        2091: {
          /* n:"BrtWorkBookPr15" */
        },
        2092: {
          /* n:"BrtPCDH15" */
        },
        2093: {
          /* n:"BrtBeginTimelineStyle", */
          T: 1
        },
        2094: {
          /* n:"BrtEndTimelineStyle", */
          T: -1
        },
        2095: {
          /* n:"BrtTimelineStyleElement" */
        },
        2096: {
          /* n:"BrtBeginTimelineStylesheetExt15", */
          T: 1
        },
        2097: {
          /* n:"BrtEndTimelineStylesheetExt15", */
          T: -1
        },
        2098: {
          /* n:"BrtBeginTimelineStyles", */
          T: 1
        },
        2099: {
          /* n:"BrtEndTimelineStyles", */
          T: -1
        },
        2100: {
          /* n:"BrtBeginTimelineStyleElements", */
          T: 1
        },
        2101: {
          /* n:"BrtEndTimelineStyleElements", */
          T: -1
        },
        2102: {
          /* n:"BrtDxf15" */
        },
        2103: {
          /* n:"BrtBeginDxfs15", */
          T: 1
        },
        2104: {
          /* n:"BrtEndDxfs15", */
          T: -1
        },
        2105: {
          /* n:"BrtSlicerCacheHideItemsWithNoData" */
        },
        2106: {
          /* n:"BrtBeginItemUniqueNames", */
          T: 1
        },
        2107: {
          /* n:"BrtEndItemUniqueNames", */
          T: -1
        },
        2108: {
          /* n:"BrtItemUniqueName" */
        },
        2109: {
          /* n:"BrtBeginExtConn15", */
          T: 1
        },
        2110: {
          /* n:"BrtEndExtConn15", */
          T: -1
        },
        2111: {
          /* n:"BrtBeginOledbPr15", */
          T: 1
        },
        2112: {
          /* n:"BrtEndOledbPr15", */
          T: -1
        },
        2113: {
          /* n:"BrtBeginDataFeedPr15", */
          T: 1
        },
        2114: {
          /* n:"BrtEndDataFeedPr15", */
          T: -1
        },
        2115: {
          /* n:"BrtTextPr15" */
        },
        2116: {
          /* n:"BrtRangePr15" */
        },
        2117: {
          /* n:"BrtDbCommand15" */
        },
        2118: {
          /* n:"BrtBeginDbTables15", */
          T: 1
        },
        2119: {
          /* n:"BrtEndDbTables15", */
          T: -1
        },
        2120: {
          /* n:"BrtDbTable15" */
        },
        2121: {
          /* n:"BrtBeginDataModel", */
          T: 1
        },
        2122: {
          /* n:"BrtEndDataModel", */
          T: -1
        },
        2123: {
          /* n:"BrtBeginModelTables", */
          T: 1
        },
        2124: {
          /* n:"BrtEndModelTables", */
          T: -1
        },
        2125: {
          /* n:"BrtModelTable" */
        },
        2126: {
          /* n:"BrtBeginModelRelationships", */
          T: 1
        },
        2127: {
          /* n:"BrtEndModelRelationships", */
          T: -1
        },
        2128: {
          /* n:"BrtModelRelationship" */
        },
        2129: {
          /* n:"BrtBeginECTxtWiz15", */
          T: 1
        },
        2130: {
          /* n:"BrtEndECTxtWiz15", */
          T: -1
        },
        2131: {
          /* n:"BrtBeginECTWFldInfoLst15", */
          T: 1
        },
        2132: {
          /* n:"BrtEndECTWFldInfoLst15", */
          T: -1
        },
        2133: {
          /* n:"BrtBeginECTWFldInfo15", */
          T: 1
        },
        2134: {
          /* n:"BrtFieldListActiveItem" */
        },
        2135: {
          /* n:"BrtPivotCacheIdVersion" */
        },
        2136: {
          /* n:"BrtSXDI15" */
        },
        2137: {
          /* n:"BrtBeginModelTimeGroupings", */
          T: 1
        },
        2138: {
          /* n:"BrtEndModelTimeGroupings", */
          T: -1
        },
        2139: {
          /* n:"BrtBeginModelTimeGrouping", */
          T: 1
        },
        2140: {
          /* n:"BrtEndModelTimeGrouping", */
          T: -1
        },
        2141: {
          /* n:"BrtModelTimeGroupingCalcCol" */
        },
        3072: {
          /* n:"BrtUid" */
        },
        3073: {
          /* n:"BrtRevisionPtr" */
        },
        4096: {
          /* n:"BrtBeginDynamicArrayPr", */
          T: 1
        },
        4097: {
          /* n:"BrtEndDynamicArrayPr", */
          T: -1
        },
        5002: {
          /* n:"BrtBeginRichValueBlock", */
          T: 1
        },
        5003: {
          /* n:"BrtEndRichValueBlock", */
          T: -1
        },
        5081: {
          /* n:"BrtBeginRichFilters", */
          T: 1
        },
        5082: {
          /* n:"BrtEndRichFilters", */
          T: -1
        },
        5083: {
          /* n:"BrtRichFilter" */
        },
        5084: {
          /* n:"BrtBeginRichFilterColumn", */
          T: 1
        },
        5085: {
          /* n:"BrtEndRichFilterColumn", */
          T: -1
        },
        5086: {
          /* n:"BrtBeginCustomRichFilters", */
          T: 1
        },
        5087: {
          /* n:"BrtEndCustomRichFilters", */
          T: -1
        },
        5088: {
          /* n:"BrtCustomRichFilter" */
        },
        5089: {
          /* n:"BrtTop10RichFilter" */
        },
        5090: {
          /* n:"BrtDynamicRichFilter" */
        },
        5092: {
          /* n:"BrtBeginRichSortCondition", */
          T: 1
        },
        5093: {
          /* n:"BrtEndRichSortCondition", */
          T: -1
        },
        5094: {
          /* n:"BrtRichFilterDateGroupItem" */
        },
        5095: {
          /* n:"BrtBeginCalcFeatures", */
          T: 1
        },
        5096: {
          /* n:"BrtEndCalcFeatures", */
          T: -1
        },
        5097: {
          /* n:"BrtCalcFeature" */
        },
        5099: {
          /* n:"BrtExternalLinksPr" */
        },
        65535: { n: "" }
      };
      var XLSRecordEnum = {
        /* [MS-XLS] 2.3 Record Enumeration 2021-08-17 */
        6: {
          /* n:"Formula", */
          f: parse_Formula
        },
        10: {
          /* n:"EOF", */
          f: parsenoop2
        },
        12: {
          /* n:"CalcCount", */
          f: parseuint16
        },
        //
        13: {
          /* n:"CalcMode", */
          f: parseuint16
        },
        //
        14: {
          /* n:"CalcPrecision", */
          f: parsebool
        },
        //
        15: {
          /* n:"CalcRefMode", */
          f: parsebool
        },
        //
        16: {
          /* n:"CalcDelta", */
          f: parse_Xnum
        },
        //
        17: {
          /* n:"CalcIter", */
          f: parsebool
        },
        //
        18: {
          /* n:"Protect", */
          f: parsebool
        },
        19: {
          /* n:"Password", */
          f: parseuint16
        },
        20: {
          /* n:"Header", */
          f: parse_XLHeaderFooter
        },
        21: {
          /* n:"Footer", */
          f: parse_XLHeaderFooter
        },
        23: {
          /* n:"ExternSheet", */
          f: parse_ExternSheet
        },
        24: {
          /* n:"Lbl", */
          f: parse_Lbl
        },
        25: {
          /* n:"WinProtect", */
          f: parsebool
        },
        26: {
          /* n:"VerticalPageBreaks", */
        },
        27: {
          /* n:"HorizontalPageBreaks", */
        },
        28: {
          /* n:"Note", */
          f: parse_Note
        },
        29: {
          /* n:"Selection", */
        },
        34: {
          /* n:"Date1904", */
          f: parsebool
        },
        35: {
          /* n:"ExternName", */
          f: parse_ExternName
        },
        38: {
          /* n:"LeftMargin", */
          f: parse_Xnum
        },
        // *
        39: {
          /* n:"RightMargin", */
          f: parse_Xnum
        },
        // *
        40: {
          /* n:"TopMargin", */
          f: parse_Xnum
        },
        // *
        41: {
          /* n:"BottomMargin", */
          f: parse_Xnum
        },
        // *
        42: {
          /* n:"PrintRowCol", */
          f: parsebool
        },
        43: {
          /* n:"PrintGrid", */
          f: parsebool
        },
        47: {
          /* n:"FilePass", */
          f: parse_FilePass
        },
        49: {
          /* n:"Font", */
          f: parse_Font
        },
        51: {
          /* n:"PrintSize", */
          f: parseuint16
        },
        60: {
          /* n:"Continue", */
        },
        61: {
          /* n:"Window1", */
          f: parse_Window1
        },
        64: {
          /* n:"Backup", */
          f: parsebool
        },
        65: {
          /* n:"Pane", */
          f: parse_Pane
        },
        66: {
          /* n:"CodePage", */
          f: parseuint16
        },
        77: {
          /* n:"Pls", */
        },
        80: {
          /* n:"DCon", */
        },
        81: {
          /* n:"DConRef", */
        },
        82: {
          /* n:"DConName", */
        },
        85: {
          /* n:"DefColWidth", */
          f: parseuint16
        },
        89: {
          /* n:"XCT", */
        },
        90: {
          /* n:"CRN", */
        },
        91: {
          /* n:"FileSharing", */
        },
        92: {
          /* n:"WriteAccess", */
          f: parse_WriteAccess
        },
        93: {
          /* n:"Obj", */
          f: parse_Obj
        },
        94: {
          /* n:"Uncalced", */
        },
        95: {
          /* n:"CalcSaveRecalc", */
          f: parsebool
        },
        //
        96: {
          /* n:"Template", */
        },
        97: {
          /* n:"Intl", */
        },
        99: {
          /* n:"ObjProtect", */
          f: parsebool
        },
        125: {
          /* n:"ColInfo", */
          f: parse_ColInfo
        },
        128: {
          /* n:"Guts", */
          f: parse_Guts
        },
        129: {
          /* n:"WsBool", */
          f: parse_WsBool
        },
        130: {
          /* n:"GridSet", */
          f: parseuint16
        },
        131: {
          /* n:"HCenter", */
          f: parsebool
        },
        132: {
          /* n:"VCenter", */
          f: parsebool
        },
        133: {
          /* n:"BoundSheet8", */
          f: parse_BoundSheet8
        },
        134: {
          /* n:"WriteProtect", */
        },
        140: {
          /* n:"Country", */
          f: parse_Country
        },
        141: {
          /* n:"HideObj", */
          f: parseuint16
        },
        144: {
          /* n:"Sort", */
        },
        146: {
          /* n:"Palette", */
          f: parse_Palette
        },
        151: {
          /* n:"Sync", */
        },
        152: {
          /* n:"LPr", */
        },
        153: {
          /* n:"DxGCol", */
        },
        154: {
          /* n:"FnGroupName", */
        },
        155: {
          /* n:"FilterMode", */
        },
        156: {
          /* n:"BuiltInFnGroupCount", */
          f: parseuint16
        },
        157: {
          /* n:"AutoFilterInfo", */
        },
        158: {
          /* n:"AutoFilter", */
        },
        160: {
          /* n:"Scl", */
          f: parse_Scl
        },
        161: {
          /* n:"Setup", */
          f: parse_Setup
        },
        174: {
          /* n:"ScenMan", */
        },
        175: {
          /* n:"SCENARIO", */
        },
        176: {
          /* n:"SxView", */
        },
        177: {
          /* n:"Sxvd", */
        },
        178: {
          /* n:"SXVI", */
        },
        180: {
          /* n:"SxIvd", */
        },
        181: {
          /* n:"SXLI", */
        },
        182: {
          /* n:"SXPI", */
        },
        184: {
          /* n:"DocRoute", */
        },
        185: {
          /* n:"RecipName", */
        },
        189: {
          /* n:"MulRk", */
          f: parse_MulRk
        },
        190: {
          /* n:"MulBlank", */
          f: parse_MulBlank
        },
        193: {
          /* n:"Mms", */
          f: parsenoop2
        },
        197: {
          /* n:"SXDI", */
        },
        198: {
          /* n:"SXDB", */
        },
        199: {
          /* n:"SXFDB", */
        },
        200: {
          /* n:"SXDBB", */
        },
        201: {
          /* n:"SXNum", */
        },
        202: {
          /* n:"SxBool", */
          f: parsebool
        },
        203: {
          /* n:"SxErr", */
        },
        204: {
          /* n:"SXInt", */
        },
        205: {
          /* n:"SXString", */
        },
        206: {
          /* n:"SXDtr", */
        },
        207: {
          /* n:"SxNil", */
        },
        208: {
          /* n:"SXTbl", */
        },
        209: {
          /* n:"SXTBRGIITM", */
        },
        210: {
          /* n:"SxTbpg", */
        },
        211: {
          /* n:"ObProj", */
        },
        213: {
          /* n:"SXStreamID", */
        },
        215: {
          /* n:"DBCell", */
        },
        216: {
          /* n:"SXRng", */
        },
        217: {
          /* n:"SxIsxoper", */
        },
        218: {
          /* n:"BookBool", */
          f: parseuint16
        },
        220: {
          /* n:"DbOrParamQry", */
        },
        221: {
          /* n:"ScenarioProtect", */
          f: parsebool
        },
        222: {
          /* n:"OleObjectSize", */
        },
        224: {
          /* n:"XF", */
          f: parse_XF
        },
        225: {
          /* n:"InterfaceHdr", */
          f: parse_InterfaceHdr
        },
        226: {
          /* n:"InterfaceEnd", */
          f: parsenoop2
        },
        227: {
          /* n:"SXVS", */
        },
        229: {
          /* n:"MergeCells", */
          f: parse_MergeCells
        },
        233: {
          /* n:"BkHim", */
        },
        235: {
          /* n:"MsoDrawingGroup", */
        },
        236: {
          /* n:"MsoDrawing", */
        },
        237: {
          /* n:"MsoDrawingSelection", */
        },
        239: {
          /* n:"PhoneticInfo", */
        },
        240: {
          /* n:"SxRule", */
        },
        241: {
          /* n:"SXEx", */
        },
        242: {
          /* n:"SxFilt", */
        },
        244: {
          /* n:"SxDXF", */
        },
        245: {
          /* n:"SxItm", */
        },
        246: {
          /* n:"SxName", */
        },
        247: {
          /* n:"SxSelect", */
        },
        248: {
          /* n:"SXPair", */
        },
        249: {
          /* n:"SxFmla", */
        },
        251: {
          /* n:"SxFormat", */
        },
        252: {
          /* n:"SST", */
          f: parse_SST
        },
        253: {
          /* n:"LabelSst", */
          f: parse_LabelSst
        },
        255: {
          /* n:"ExtSST", */
          f: parse_ExtSST
        },
        256: {
          /* n:"SXVDEx", */
        },
        259: {
          /* n:"SXFormula", */
        },
        290: {
          /* n:"SXDBEx", */
        },
        311: {
          /* n:"RRDInsDel", */
        },
        312: {
          /* n:"RRDHead", */
        },
        315: {
          /* n:"RRDChgCell", */
        },
        317: {
          /* n:"RRTabId", */
          f: parseuint16a
        },
        318: {
          /* n:"RRDRenSheet", */
        },
        319: {
          /* n:"RRSort", */
        },
        320: {
          /* n:"RRDMove", */
        },
        330: {
          /* n:"RRFormat", */
        },
        331: {
          /* n:"RRAutoFmt", */
        },
        333: {
          /* n:"RRInsertSh", */
        },
        334: {
          /* n:"RRDMoveBegin", */
        },
        335: {
          /* n:"RRDMoveEnd", */
        },
        336: {
          /* n:"RRDInsDelBegin", */
        },
        337: {
          /* n:"RRDInsDelEnd", */
        },
        338: {
          /* n:"RRDConflict", */
        },
        339: {
          /* n:"RRDDefName", */
        },
        340: {
          /* n:"RRDRstEtxp", */
        },
        351: {
          /* n:"LRng", */
        },
        352: {
          /* n:"UsesELFs", */
          f: parsebool
        },
        353: {
          /* n:"DSF", */
          f: parsenoop2
        },
        401: {
          /* n:"CUsr", */
        },
        402: {
          /* n:"CbUsr", */
        },
        403: {
          /* n:"UsrInfo", */
        },
        404: {
          /* n:"UsrExcl", */
        },
        405: {
          /* n:"FileLock", */
        },
        406: {
          /* n:"RRDInfo", */
        },
        407: {
          /* n:"BCUsrs", */
        },
        408: {
          /* n:"UsrChk", */
        },
        425: {
          /* n:"UserBView", */
        },
        426: {
          /* n:"UserSViewBegin", */
        },
        427: {
          /* n:"UserSViewEnd", */
        },
        428: {
          /* n:"RRDUserView", */
        },
        429: {
          /* n:"Qsi", */
        },
        430: {
          /* n:"SupBook", */
          f: parse_SupBook
        },
        431: {
          /* n:"Prot4Rev", */
          f: parsebool
        },
        432: {
          /* n:"CondFmt", */
        },
        433: {
          /* n:"CF", */
        },
        434: {
          /* n:"DVal", */
        },
        437: {
          /* n:"DConBin", */
        },
        438: {
          /* n:"TxO", */
          f: parse_TxO
        },
        439: {
          /* n:"RefreshAll", */
          f: parsebool
        },
        //
        440: {
          /* n:"HLink", */
          f: parse_HLink
        },
        441: {
          /* n:"Lel", */
        },
        442: {
          /* n:"CodeName", */
          f: parse_XLUnicodeString
        },
        443: {
          /* n:"SXFDBType", */
        },
        444: {
          /* n:"Prot4RevPass", */
          f: parseuint16
        },
        445: {
          /* n:"ObNoMacros", */
        },
        446: {
          /* n:"Dv", */
        },
        448: {
          /* n:"Excel9File", */
          f: parsenoop2
        },
        449: {
          /* n:"RecalcId", */
          f: parse_RecalcId,
          r: 2
        },
        450: {
          /* n:"EntExU2", */
          f: parsenoop2
        },
        512: {
          /* n:"Dimensions", */
          f: parse_Dimensions
        },
        513: {
          /* n:"Blank", */
          f: parse_Blank
        },
        515: {
          /* n:"Number", */
          f: parse_Number
        },
        516: {
          /* n:"Label", */
          f: parse_Label
        },
        517: {
          /* n:"BoolErr", */
          f: parse_BoolErr
        },
        519: {
          /* n:"String", */
          f: parse_String
        },
        520: {
          /* n:"Row", */
          f: parse_Row
        },
        523: {
          /* n:"Index", */
        },
        545: {
          /* n:"Array", */
          f: parse_Array
        },
        549: {
          /* n:"DefaultRowHeight", */
          f: parse_DefaultRowHeight
        },
        566: {
          /* n:"Table", */
        },
        574: {
          /* n:"Window2", */
          f: parse_Window2
        },
        638: {
          /* n:"RK", */
          f: parse_RK
        },
        659: {
          /* n:"Style", */
        },
        1048: {
          /* n:"BigName", */
        },
        1054: {
          /* n:"Format", */
          f: parse_Format
        },
        1084: {
          /* n:"ContinueBigName", */
        },
        1212: {
          /* n:"ShrFmla", */
          f: parse_ShrFmla
        },
        2048: {
          /* n:"HLinkTooltip", */
          f: parse_HLinkTooltip
        },
        2049: {
          /* n:"WebPub", */
        },
        2050: {
          /* n:"QsiSXTag", */
        },
        2051: {
          /* n:"DBQueryExt", */
        },
        2052: {
          /* n:"ExtString", */
        },
        2053: {
          /* n:"TxtQry", */
        },
        2054: {
          /* n:"Qsir", */
        },
        2055: {
          /* n:"Qsif", */
        },
        2056: {
          /* n:"RRDTQSIF", */
        },
        2057: {
          /* n:"BOF", */
          f: parse_BOF
        },
        2058: {
          /* n:"OleDbConn", */
        },
        2059: {
          /* n:"WOpt", */
        },
        2060: {
          /* n:"SXViewEx", */
        },
        2061: {
          /* n:"SXTH", */
        },
        2062: {
          /* n:"SXPIEx", */
        },
        2063: {
          /* n:"SXVDTEx", */
        },
        2064: {
          /* n:"SXViewEx9", */
        },
        2066: {
          /* n:"ContinueFrt", */
        },
        2067: {
          /* n:"RealTimeData", */
        },
        2128: {
          /* n:"ChartFrtInfo", */
        },
        2129: {
          /* n:"FrtWrapper", */
        },
        2130: {
          /* n:"StartBlock", */
        },
        2131: {
          /* n:"EndBlock", */
        },
        2132: {
          /* n:"StartObject", */
        },
        2133: {
          /* n:"EndObject", */
        },
        2134: {
          /* n:"CatLab", */
        },
        2135: {
          /* n:"YMult", */
        },
        2136: {
          /* n:"SXViewLink", */
        },
        2137: {
          /* n:"PivotChartBits", */
        },
        2138: {
          /* n:"FrtFontList", */
        },
        2146: {
          /* n:"SheetExt", */
        },
        2147: {
          /* n:"BookExt", */
          r: 12
        },
        2148: {
          /* n:"SXAddl", */
        },
        2149: {
          /* n:"CrErr", */
        },
        2150: {
          /* n:"HFPicture", */
        },
        2151: {
          /* n:"FeatHdr", */
          f: parsenoop2
        },
        2152: {
          /* n:"Feat", */
        },
        2154: {
          /* n:"DataLabExt", */
        },
        2155: {
          /* n:"DataLabExtContents", */
        },
        2156: {
          /* n:"CellWatch", */
        },
        2161: {
          /* n:"FeatHdr11", */
        },
        2162: {
          /* n:"Feature11", */
        },
        2164: {
          /* n:"DropDownObjIds", */
        },
        2165: {
          /* n:"ContinueFrt11", */
        },
        2166: {
          /* n:"DConn", */
        },
        2167: {
          /* n:"List12", */
        },
        2168: {
          /* n:"Feature12", */
        },
        2169: {
          /* n:"CondFmt12", */
        },
        2170: {
          /* n:"CF12", */
        },
        2171: {
          /* n:"CFEx", */
        },
        2172: {
          /* n:"XFCRC", */
          f: parse_XFCRC,
          r: 12
        },
        2173: {
          /* n:"XFExt", */
          f: parse_XFExt,
          r: 12
        },
        2174: {
          /* n:"AutoFilter12", */
        },
        2175: {
          /* n:"ContinueFrt12", */
        },
        2180: {
          /* n:"MDTInfo", */
        },
        2181: {
          /* n:"MDXStr", */
        },
        2182: {
          /* n:"MDXTuple", */
        },
        2183: {
          /* n:"MDXSet", */
        },
        2184: {
          /* n:"MDXProp", */
        },
        2185: {
          /* n:"MDXKPI", */
        },
        2186: {
          /* n:"MDB", */
        },
        2187: {
          /* n:"PLV", */
        },
        2188: {
          /* n:"Compat12", */
          f: parsebool,
          r: 12
        },
        2189: {
          /* n:"DXF", */
        },
        2190: {
          /* n:"TableStyles", */
          r: 12
        },
        2191: {
          /* n:"TableStyle", */
        },
        2192: {
          /* n:"TableStyleElement", */
        },
        2194: {
          /* n:"StyleExt", */
        },
        2195: {
          /* n:"NamePublish", */
        },
        2196: {
          /* n:"NameCmt", */
          f: parse_NameCmt,
          r: 12
        },
        2197: {
          /* n:"SortData", */
        },
        2198: {
          /* n:"Theme", */
          f: parse_Theme,
          r: 12
        },
        2199: {
          /* n:"GUIDTypeLib", */
        },
        2200: {
          /* n:"FnGrp12", */
        },
        2201: {
          /* n:"NameFnGrp12", */
        },
        2202: {
          /* n:"MTRSettings", */
          f: parse_MTRSettings,
          r: 12
        },
        2203: {
          /* n:"CompressPictures", */
          f: parsenoop2
        },
        2204: {
          /* n:"HeaderFooter", */
        },
        2205: {
          /* n:"CrtLayout12", */
        },
        2206: {
          /* n:"CrtMlFrt", */
        },
        2207: {
          /* n:"CrtMlFrtContinue", */
        },
        2211: {
          /* n:"ForceFullCalculation", */
          f: parse_ForceFullCalculation
        },
        2212: {
          /* n:"ShapePropsStream", */
        },
        2213: {
          /* n:"TextPropsStream", */
        },
        2214: {
          /* n:"RichTextStream", */
        },
        2215: {
          /* n:"CrtLayout12A", */
        },
        4097: {
          /* n:"Units", */
        },
        4098: {
          /* n:"Chart", */
        },
        4099: {
          /* n:"Series", */
        },
        4102: {
          /* n:"DataFormat", */
        },
        4103: {
          /* n:"LineFormat", */
        },
        4105: {
          /* n:"MarkerFormat", */
        },
        4106: {
          /* n:"AreaFormat", */
        },
        4107: {
          /* n:"PieFormat", */
        },
        4108: {
          /* n:"AttachedLabel", */
        },
        4109: {
          /* n:"SeriesText", */
        },
        4116: {
          /* n:"ChartFormat", */
        },
        4117: {
          /* n:"Legend", */
        },
        4118: {
          /* n:"SeriesList", */
        },
        4119: {
          /* n:"Bar", */
        },
        4120: {
          /* n:"Line", */
        },
        4121: {
          /* n:"Pie", */
        },
        4122: {
          /* n:"Area", */
        },
        4123: {
          /* n:"Scatter", */
        },
        4124: {
          /* n:"CrtLine", */
        },
        4125: {
          /* n:"Axis", */
        },
        4126: {
          /* n:"Tick", */
        },
        4127: {
          /* n:"ValueRange", */
        },
        4128: {
          /* n:"CatSerRange", */
        },
        4129: {
          /* n:"AxisLine", */
        },
        4130: {
          /* n:"CrtLink", */
        },
        4132: {
          /* n:"DefaultText", */
        },
        4133: {
          /* n:"Text", */
        },
        4134: {
          /* n:"FontX", */
          f: parseuint16
        },
        4135: {
          /* n:"ObjectLink", */
        },
        4146: {
          /* n:"Frame", */
        },
        4147: {
          /* n:"Begin", */
        },
        4148: {
          /* n:"End", */
        },
        4149: {
          /* n:"PlotArea", */
        },
        4154: {
          /* n:"Chart3d", */
        },
        4156: {
          /* n:"PicF", */
        },
        4157: {
          /* n:"DropBar", */
        },
        4158: {
          /* n:"Radar", */
        },
        4159: {
          /* n:"Surf", */
        },
        4160: {
          /* n:"RadarArea", */
        },
        4161: {
          /* n:"AxisParent", */
        },
        4163: {
          /* n:"LegendException", */
        },
        4164: {
          /* n:"ShtProps", */
          f: parse_ShtProps
        },
        4165: {
          /* n:"SerToCrt", */
        },
        4166: {
          /* n:"AxesUsed", */
        },
        4168: {
          /* n:"SBaseRef", */
        },
        4170: {
          /* n:"SerParent", */
        },
        4171: {
          /* n:"SerAuxTrend", */
        },
        4174: {
          /* n:"IFmtRecord", */
        },
        4175: {
          /* n:"Pos", */
        },
        4176: {
          /* n:"AlRuns", */
        },
        4177: {
          /* n:"BRAI", */
        },
        4187: {
          /* n:"SerAuxErrBar", */
        },
        4188: {
          /* n:"ClrtClient", */
          f: parse_ClrtClient
        },
        4189: {
          /* n:"SerFmt", */
        },
        4191: {
          /* n:"Chart3DBarShape", */
        },
        4192: {
          /* n:"Fbi", */
        },
        4193: {
          /* n:"BopPop", */
        },
        4194: {
          /* n:"AxcExt", */
        },
        4195: {
          /* n:"Dat", */
        },
        4196: {
          /* n:"PlotGrowth", */
        },
        4197: {
          /* n:"SIIndex", */
        },
        4198: {
          /* n:"GelFrame", */
        },
        4199: {
          /* n:"BopPopCustom", */
        },
        4200: {
          /* n:"Fbi2", */
        },
        0: {
          /* n:"Dimensions", */
          f: parse_Dimensions
        },
        1: {
          /* n:"BIFF2BLANK", */
        },
        2: {
          /* n:"BIFF2INT", */
          f: parse_BIFF2INT
        },
        3: {
          /* n:"BIFF2NUM", */
          f: parse_BIFF2NUM
        },
        4: {
          /* n:"BIFF2STR", */
          f: parse_BIFF2STR
        },
        5: {
          /* n:"BoolErr", */
          f: parse_BoolErr
        },
        7: {
          /* n:"String", */
          f: parse_BIFF2STRING
        },
        8: {
          /* n:"BIFF2ROW", */
        },
        9: {
          /* n:"BOF", */
          f: parse_BOF
        },
        11: {
          /* n:"Index", */
        },
        22: {
          /* n:"ExternCount", */
          f: parseuint16
        },
        30: {
          /* n:"BIFF2FORMAT", */
          f: parse_BIFF2Format
        },
        31: {
          /* n:"BIFF2FMTCNT", */
        },
        /* 16-bit cnt of BIFF2FORMAT records */
        32: {
          /* n:"BIFF2COLINFO", */
        },
        33: {
          /* n:"Array", */
          f: parse_Array
        },
        36: {
          /* n:"COLWIDTH", */
        },
        37: {
          /* n:"DefaultRowHeight", */
          f: parse_DefaultRowHeight
        },
        // 0x2c ??
        // 0x2d ??
        // 0x2e ??
        // 0x30 FONTCOUNT: number of fonts
        50: {
          /* n:"BIFF2FONTXTRA", */
          f: parse_BIFF2FONTXTRA
        },
        // 0x35: INFOOPTS
        // 0x36: TABLE (BIFF2 only)
        // 0x37: TABLE2 (BIFF2 only)
        // 0x38: WNDESK
        // 0x39 ??
        // 0x3a: BEGINPREF
        // 0x3b: ENDPREF
        62: {
          /* n:"BIFF2WINDOW2", */
        },
        // 0x3f ??
        // 0x46: SHOWSCROLL
        // 0x47: SHOWFORMULA
        // 0x48: STATUSBAR
        // 0x49: SHORTMENUS
        // 0x4A:
        // 0x4B:
        // 0x4C:
        // 0x4E:
        // 0x4F:
        // 0x58: TOOLBAR (BIFF3)
        /* - - - */
        52: {
          /* n:"DDEObjName", */
        },
        67: {
          /* n:"BIFF2XF", */
        },
        68: {
          /* n:"BIFF2XFINDEX", */
          f: parseuint16
        },
        69: {
          /* n:"BIFF2FONTCLR", */
        },
        86: {
          /* n:"BIFF4FMTCNT", */
        },
        /* 16-bit cnt, similar to BIFF2 */
        126: {
          /* n:"RK", */
        },
        /* Not necessarily same as 0x027e */
        127: {
          /* n:"ImData", */
          f: parse_ImData
        },
        135: {
          /* n:"Addin", */
        },
        136: {
          /* n:"Edg", */
        },
        137: {
          /* n:"Pub", */
        },
        // 0x8A
        // 0x8B LH: alternate menu key flag (BIFF3/4)
        // 0x8E
        // 0x8F
        145: {
          /* n:"Sub", */
        },
        // 0x93 STYLE
        148: {
          /* n:"LHRecord", */
        },
        149: {
          /* n:"LHNGraph", */
        },
        150: {
          /* n:"Sound", */
        },
        // 0xA2 FNPROTO: function prototypes (BIFF4)
        // 0xA3
        // 0xA8
        169: {
          /* n:"CoordList", */
        },
        171: {
          /* n:"GCW", */
        },
        188: {
          /* n:"ShrFmla", */
        },
        /* Not necessarily same as 0x04bc */
        191: {
          /* n:"ToolbarHdr", */
        },
        192: {
          /* n:"ToolbarEnd", */
        },
        194: {
          /* n:"AddMenu", */
        },
        195: {
          /* n:"DelMenu", */
        },
        214: {
          /* n:"RString", */
          f: parse_RString
        },
        223: {
          /* n:"UDDesc", */
        },
        234: {
          /* n:"TabIdConf", */
        },
        354: {
          /* n:"XL5Modify", */
        },
        421: {
          /* n:"FileSharing2", */
        },
        518: {
          /* n:"Formula", */
          f: parse_Formula
        },
        521: {
          /* n:"BOF", */
          f: parse_BOF
        },
        536: {
          /* n:"Lbl", */
          f: parse_Lbl
        },
        547: {
          /* n:"ExternName", */
          f: parse_ExternName
        },
        561: {
          /* n:"Font", */
        },
        579: {
          /* n:"BIFF3XF", */
        },
        1030: {
          /* n:"Formula", */
          f: parse_Formula
        },
        1033: {
          /* n:"BOF", */
          f: parse_BOF
        },
        1091: {
          /* n:"BIFF4XF", */
        },
        2157: {
          /* n:"FeatInfo", */
        },
        2163: {
          /* n:"FeatInfo11", */
        },
        2177: {
          /* n:"SXAddl12", */
        },
        2240: {
          /* n:"AutoWebPub", */
        },
        2241: {
          /* n:"ListObj", */
        },
        2242: {
          /* n:"ListField", */
        },
        2243: {
          /* n:"ListDV", */
        },
        2244: {
          /* n:"ListCondFmt", */
        },
        2245: {
          /* n:"ListCF", */
        },
        2246: {
          /* n:"FMQry", */
        },
        2247: {
          /* n:"FMSQry", */
        },
        2248: {
          /* n:"PLV", */
        },
        2249: {
          /* n:"LnExt", */
        },
        2250: {
          /* n:"MkrExt", */
        },
        2251: {
          /* n:"CrtCoopt", */
        },
        2262: {
          /* n:"FRTArchId$", */
          r: 12
        },
        29282: {}
      };
      function write_biff_rec(ba, type, payload, length) {
        var t3 = type;
        if (isNaN(t3))
          return;
        var len = length || (payload || []).length || 0;
        var o = ba.next(4);
        o.write_shift(2, t3);
        o.write_shift(2, len);
        if (len > 0 && is_buf(payload))
          ba.push(payload);
      }
      function write_biff_continue(ba, type, payload, length) {
        var len = length || (payload || []).length || 0;
        if (len <= 8224)
          return write_biff_rec(ba, type, payload, len);
        var t3 = type;
        if (isNaN(t3))
          return;
        var parts = payload.parts || [], sidx = 0;
        var i = 0, w = 0;
        while (w + (parts[sidx] || 8224) <= 8224) {
          w += parts[sidx] || 8224;
          sidx++;
        }
        var o = ba.next(4);
        o.write_shift(2, t3);
        o.write_shift(2, w);
        ba.push(payload.slice(i, i + w));
        i += w;
        while (i < len) {
          o = ba.next(4);
          o.write_shift(2, 60);
          w = 0;
          while (w + (parts[sidx] || 8224) <= 8224) {
            w += parts[sidx] || 8224;
            sidx++;
          }
          o.write_shift(2, w);
          ba.push(payload.slice(i, i + w));
          i += w;
        }
      }
      function write_BIFF2Cell(out, r, c) {
        if (!out)
          out = new_buf(7);
        out.write_shift(2, r);
        out.write_shift(2, c);
        out.write_shift(2, 0);
        out.write_shift(1, 0);
        return out;
      }
      function write_BIFF2BERR(r, c, val, t3) {
        var out = new_buf(9);
        write_BIFF2Cell(out, r, c);
        write_Bes(val, t3 || "b", out);
        return out;
      }
      function write_BIFF2LABEL(r, c, val) {
        var out = new_buf(8 + 2 * val.length);
        write_BIFF2Cell(out, r, c);
        out.write_shift(1, val.length);
        out.write_shift(val.length, val, "sbcs");
        return out.l < out.length ? out.slice(0, out.l) : out;
      }
      function write_ws_biff2_cell(ba, cell, R, C) {
        if (cell.v != null)
          switch (cell.t) {
            case "d":
            case "n":
              var v = cell.t == "d" ? datenum(parseDate(cell.v)) : cell.v;
              if (v == (v | 0) && v >= 0 && v < 65536)
                write_biff_rec(ba, 2, write_BIFF2INT(R, C, v));
              else
                write_biff_rec(ba, 3, write_BIFF2NUM(R, C, v));
              return;
            case "b":
            case "e":
              write_biff_rec(ba, 5, write_BIFF2BERR(R, C, cell.v, cell.t));
              return;
            case "s":
            case "str":
              write_biff_rec(ba, 4, write_BIFF2LABEL(R, C, (cell.v || "").slice(0, 255)));
              return;
          }
        write_biff_rec(ba, 1, write_BIFF2Cell(null, R, C));
      }
      function write_ws_biff2(ba, ws, idx, opts) {
        var dense = Array.isArray(ws);
        var range = safe_decode_range(ws["!ref"] || "A1"), ref, rr = "", cols = [];
        if (range.e.c > 255 || range.e.r > 16383) {
          if (opts.WTF)
            throw new Error("Range " + (ws["!ref"] || "A1") + " exceeds format limit A1:IV16384");
          range.e.c = Math.min(range.e.c, 255);
          range.e.r = Math.min(range.e.c, 16383);
          ref = encode_range(range);
        }
        for (var R = range.s.r; R <= range.e.r; ++R) {
          rr = encode_row(R);
          for (var C = range.s.c; C <= range.e.c; ++C) {
            if (R === range.s.r)
              cols[C] = encode_col(C);
            ref = cols[C] + rr;
            var cell = dense ? (ws[R] || [])[C] : ws[ref];
            if (!cell)
              continue;
            write_ws_biff2_cell(ba, cell, R, C, opts);
          }
        }
      }
      function write_biff2_buf(wb, opts) {
        var o = opts || {};
        if (DENSE != null && o.dense == null)
          o.dense = DENSE;
        var ba = buf_array();
        var idx = 0;
        for (var i = 0; i < wb.SheetNames.length; ++i)
          if (wb.SheetNames[i] == o.sheet)
            idx = i;
        if (idx == 0 && !!o.sheet && wb.SheetNames[0] != o.sheet)
          throw new Error("Sheet not found: " + o.sheet);
        write_biff_rec(ba, o.biff == 4 ? 1033 : o.biff == 3 ? 521 : 9, write_BOF(wb, 16, o));
        write_ws_biff2(ba, wb.Sheets[wb.SheetNames[idx]], idx, o, wb);
        write_biff_rec(ba, 10);
        return ba.end();
      }
      function write_FONTS_biff8(ba, data, opts) {
        write_biff_rec(ba, 49, write_Font({
          sz: 12,
          color: { theme: 1 },
          name: "Arial",
          family: 2,
          scheme: "minor"
        }, opts));
      }
      function write_FMTS_biff8(ba, NF, opts) {
        if (!NF)
          return;
        [[5, 8], [23, 26], [41, 44], [
          /*63*/
          50,
          /*66],[164,*/
          392
        ]].forEach(function(r) {
          for (var i = r[0]; i <= r[1]; ++i)
            if (NF[i] != null)
              write_biff_rec(ba, 1054, write_Format(i, NF[i], opts));
        });
      }
      function write_FEAT(ba, ws) {
        var o = new_buf(19);
        o.write_shift(4, 2151);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(2, 3);
        o.write_shift(1, 1);
        o.write_shift(4, 0);
        write_biff_rec(ba, 2151, o);
        o = new_buf(39);
        o.write_shift(4, 2152);
        o.write_shift(4, 0);
        o.write_shift(4, 0);
        o.write_shift(2, 3);
        o.write_shift(1, 0);
        o.write_shift(4, 0);
        o.write_shift(2, 1);
        o.write_shift(4, 4);
        o.write_shift(2, 0);
        write_Ref8U(safe_decode_range(ws["!ref"] || "A1"), o);
        o.write_shift(4, 4);
        write_biff_rec(ba, 2152, o);
      }
      function write_CELLXFS_biff8(ba, opts) {
        for (var i = 0; i < 16; ++i)
          write_biff_rec(ba, 224, write_XF({ numFmtId: 0, style: true }, 0, opts));
        opts.cellXfs.forEach(function(c) {
          write_biff_rec(ba, 224, write_XF(c, 0, opts));
        });
      }
      function write_ws_biff8_hlinks(ba, ws) {
        for (var R = 0; R < ws["!links"].length; ++R) {
          var HL = ws["!links"][R];
          write_biff_rec(ba, 440, write_HLink(HL));
          if (HL[1].Tooltip)
            write_biff_rec(ba, 2048, write_HLinkTooltip(HL));
        }
        delete ws["!links"];
      }
      function write_ws_cols_biff8(ba, cols) {
        if (!cols)
          return;
        var cnt = 0;
        cols.forEach(function(col, idx) {
          if (++cnt <= 256 && col) {
            write_biff_rec(ba, 125, write_ColInfo(col_obj_w(idx, col), idx));
          }
        });
      }
      function write_ws_biff8_cell(ba, cell, R, C, opts) {
        var os = 16 + get_cell_style(opts.cellXfs, cell, opts);
        if (cell.v == null && !cell.bf) {
          write_biff_rec(ba, 513, write_XLSCell(R, C, os));
          return;
        }
        if (cell.bf)
          write_biff_rec(ba, 6, write_Formula(cell, R, C, opts, os));
        else
          switch (cell.t) {
            case "d":
            case "n":
              var v = cell.t == "d" ? datenum(parseDate(cell.v)) : cell.v;
              write_biff_rec(ba, 515, write_Number(R, C, v, os, opts));
              break;
            case "b":
            case "e":
              write_biff_rec(ba, 517, write_BoolErr(R, C, cell.v, os, opts, cell.t));
              break;
            case "s":
            case "str":
              if (opts.bookSST) {
                var isst = get_sst_id(opts.Strings, cell.v, opts.revStrings);
                write_biff_rec(ba, 253, write_LabelSst(R, C, isst, os, opts));
              } else
                write_biff_rec(ba, 516, write_Label(R, C, (cell.v || "").slice(0, 255), os, opts));
              break;
            default:
              write_biff_rec(ba, 513, write_XLSCell(R, C, os));
          }
      }
      function write_ws_biff8(idx, opts, wb) {
        var ba = buf_array();
        var s = wb.SheetNames[idx], ws = wb.Sheets[s] || {};
        var _WB = (wb || {}).Workbook || {};
        var _sheet = (_WB.Sheets || [])[idx] || {};
        var dense = Array.isArray(ws);
        var b8 = opts.biff == 8;
        var ref, rr = "", cols = [];
        var range = safe_decode_range(ws["!ref"] || "A1");
        var MAX_ROWS = b8 ? 65536 : 16384;
        if (range.e.c > 255 || range.e.r >= MAX_ROWS) {
          if (opts.WTF)
            throw new Error("Range " + (ws["!ref"] || "A1") + " exceeds format limit A1:IV16384");
          range.e.c = Math.min(range.e.c, 255);
          range.e.r = Math.min(range.e.c, MAX_ROWS - 1);
        }
        write_biff_rec(ba, 2057, write_BOF(wb, 16, opts));
        write_biff_rec(ba, 13, writeuint16(1));
        write_biff_rec(ba, 12, writeuint16(100));
        write_biff_rec(ba, 15, writebool(true));
        write_biff_rec(ba, 17, writebool(false));
        write_biff_rec(ba, 16, write_Xnum(1e-3));
        write_biff_rec(ba, 95, writebool(true));
        write_biff_rec(ba, 42, writebool(false));
        write_biff_rec(ba, 43, writebool(false));
        write_biff_rec(ba, 130, writeuint16(1));
        write_biff_rec(ba, 128, write_Guts([0, 0]));
        write_biff_rec(ba, 131, writebool(false));
        write_biff_rec(ba, 132, writebool(false));
        if (b8)
          write_ws_cols_biff8(ba, ws["!cols"]);
        write_biff_rec(ba, 512, write_Dimensions(range, opts));
        if (b8)
          ws["!links"] = [];
        for (var R = range.s.r; R <= range.e.r; ++R) {
          rr = encode_row(R);
          for (var C = range.s.c; C <= range.e.c; ++C) {
            if (R === range.s.r)
              cols[C] = encode_col(C);
            ref = cols[C] + rr;
            var cell = dense ? (ws[R] || [])[C] : ws[ref];
            if (!cell)
              continue;
            write_ws_biff8_cell(ba, cell, R, C, opts);
            if (b8 && cell.l)
              ws["!links"].push([ref, cell.l]);
          }
        }
        var cname = _sheet.CodeName || _sheet.name || s;
        if (b8)
          write_biff_rec(ba, 574, write_Window2((_WB.Views || [])[0]));
        if (b8 && (ws["!merges"] || []).length)
          write_biff_rec(ba, 229, write_MergeCells(ws["!merges"]));
        if (b8)
          write_ws_biff8_hlinks(ba, ws);
        write_biff_rec(ba, 442, write_XLUnicodeString(cname, opts));
        if (b8)
          write_FEAT(ba, ws);
        write_biff_rec(
          ba,
          10
          /* EOF */
        );
        return ba.end();
      }
      function write_biff8_global(wb, bufs, opts) {
        var A = buf_array();
        var _WB = (wb || {}).Workbook || {};
        var _sheets = _WB.Sheets || [];
        var _wb = _WB.WBProps || {};
        var b8 = opts.biff == 8, b5 = opts.biff == 5;
        write_biff_rec(A, 2057, write_BOF(wb, 5, opts));
        if (opts.bookType == "xla")
          write_biff_rec(
            A,
            135
            /* Addin */
          );
        write_biff_rec(A, 225, b8 ? writeuint16(1200) : null);
        write_biff_rec(A, 193, writezeroes(2));
        if (b5)
          write_biff_rec(
            A,
            191
            /* ToolbarHdr */
          );
        if (b5)
          write_biff_rec(
            A,
            192
            /* ToolbarEnd */
          );
        write_biff_rec(
          A,
          226
          /* InterfaceEnd */
        );
        write_biff_rec(A, 92, write_WriteAccess("SheetJS", opts));
        write_biff_rec(A, 66, writeuint16(b8 ? 1200 : 1252));
        if (b8)
          write_biff_rec(A, 353, writeuint16(0));
        if (b8)
          write_biff_rec(
            A,
            448
            /* Excel9File */
          );
        write_biff_rec(A, 317, write_RRTabId(wb.SheetNames.length));
        if (b8 && wb.vbaraw)
          write_biff_rec(
            A,
            211
            /* ObProj */
          );
        if (b8 && wb.vbaraw) {
          var cname = _wb.CodeName || "ThisWorkbook";
          write_biff_rec(A, 442, write_XLUnicodeString(cname, opts));
        }
        write_biff_rec(A, 156, writeuint16(17));
        write_biff_rec(A, 25, writebool(false));
        write_biff_rec(A, 18, writebool(false));
        write_biff_rec(A, 19, writeuint16(0));
        if (b8)
          write_biff_rec(A, 431, writebool(false));
        if (b8)
          write_biff_rec(A, 444, writeuint16(0));
        write_biff_rec(A, 61, write_Window1(opts));
        write_biff_rec(A, 64, writebool(false));
        write_biff_rec(A, 141, writeuint16(0));
        write_biff_rec(A, 34, writebool(safe1904(wb) == "true"));
        write_biff_rec(A, 14, writebool(true));
        if (b8)
          write_biff_rec(A, 439, writebool(false));
        write_biff_rec(A, 218, writeuint16(0));
        write_FONTS_biff8(A, wb, opts);
        write_FMTS_biff8(A, wb.SSF, opts);
        write_CELLXFS_biff8(A, opts);
        if (b8)
          write_biff_rec(A, 352, writebool(false));
        var a = A.end();
        var C = buf_array();
        if (b8)
          write_biff_rec(C, 140, write_Country());
        if (b8 && opts.Strings)
          write_biff_continue(C, 252, write_SST(opts.Strings, opts));
        write_biff_rec(
          C,
          10
          /* EOF */
        );
        var c = C.end();
        var B = buf_array();
        var blen = 0, j = 0;
        for (j = 0; j < wb.SheetNames.length; ++j)
          blen += (b8 ? 12 : 11) + (b8 ? 2 : 1) * wb.SheetNames[j].length;
        var start = a.length + blen + c.length;
        for (j = 0; j < wb.SheetNames.length; ++j) {
          var _sheet = _sheets[j] || {};
          write_biff_rec(B, 133, write_BoundSheet8({ pos: start, hs: _sheet.Hidden || 0, dt: 0, name: wb.SheetNames[j] }, opts));
          start += bufs[j].length;
        }
        var b = B.end();
        if (blen != b.length)
          throw new Error("BS8 " + blen + " != " + b.length);
        var out = [];
        if (a.length)
          out.push(a);
        if (b.length)
          out.push(b);
        if (c.length)
          out.push(c);
        return bconcat(out);
      }
      function write_biff8_buf(wb, opts) {
        var o = opts || {};
        var bufs = [];
        if (wb && !wb.SSF) {
          wb.SSF = dup(table_fmt);
        }
        if (wb && wb.SSF) {
          make_ssf();
          SSF_load_table(wb.SSF);
          o.revssf = evert_num(wb.SSF);
          o.revssf[wb.SSF[65535]] = 0;
          o.ssf = wb.SSF;
        }
        o.Strings = [];
        o.Strings.Count = 0;
        o.Strings.Unique = 0;
        fix_write_opts(o);
        o.cellXfs = [];
        get_cell_style(o.cellXfs, {}, { revssf: { "General": 0 } });
        if (!wb.Props)
          wb.Props = {};
        for (var i = 0; i < wb.SheetNames.length; ++i)
          bufs[bufs.length] = write_ws_biff8(i, o, wb);
        bufs.unshift(write_biff8_global(wb, bufs, o));
        return bconcat(bufs);
      }
      function write_biff_buf(wb, opts) {
        for (var i = 0; i <= wb.SheetNames.length; ++i) {
          var ws = wb.Sheets[wb.SheetNames[i]];
          if (!ws || !ws["!ref"])
            continue;
          var range = decode_range(ws["!ref"]);
          if (range.e.c > 255) {
            if (typeof console != "undefined" && console.error)
              console.error("Worksheet '" + wb.SheetNames[i] + "' extends beyond column IV (255).  Data may be lost.");
          }
        }
        var o = opts || {};
        switch (o.biff || 2) {
          case 8:
          case 5:
            return write_biff8_buf(wb, opts);
          case 4:
          case 3:
          case 2:
            return write_biff2_buf(wb, opts);
        }
        throw new Error("invalid type " + o.bookType + " for BIFF");
      }
      function html_to_sheet(str, _opts) {
        var opts = _opts || {};
        if (DENSE != null && opts.dense == null)
          opts.dense = DENSE;
        var ws = opts.dense ? [] : {};
        str = str.replace(/<!--.*?-->/g, "");
        var mtch = str.match(/<table/i);
        if (!mtch)
          throw new Error("Invalid HTML: could not find <table>");
        var mtch2 = str.match(/<\/table/i);
        var i = mtch.index, j = mtch2 && mtch2.index || str.length;
        var rows = split_regex(str.slice(i, j), /(:?<tr[^>]*>)/i, "<tr>");
        var R = -1, C = 0, RS = 0, CS = 0;
        var range = { s: { r: 1e7, c: 1e7 }, e: { r: 0, c: 0 } };
        var merges = [];
        for (i = 0; i < rows.length; ++i) {
          var row = rows[i].trim();
          var hd = row.slice(0, 3).toLowerCase();
          if (hd == "<tr") {
            ++R;
            if (opts.sheetRows && opts.sheetRows <= R) {
              --R;
              break;
            }
            C = 0;
            continue;
          }
          if (hd != "<td" && hd != "<th")
            continue;
          var cells = row.split(/<\/t[dh]>/i);
          for (j = 0; j < cells.length; ++j) {
            var cell = cells[j].trim();
            if (!cell.match(/<t[dh]/i))
              continue;
            var m = cell, cc = 0;
            while (m.charAt(0) == "<" && (cc = m.indexOf(">")) > -1)
              m = m.slice(cc + 1);
            for (var midx = 0; midx < merges.length; ++midx) {
              var _merge = merges[midx];
              if (_merge.s.c == C && _merge.s.r < R && R <= _merge.e.r) {
                C = _merge.e.c + 1;
                midx = -1;
              }
            }
            var tag = parsexmltag(cell.slice(0, cell.indexOf(">")));
            CS = tag.colspan ? +tag.colspan : 1;
            if ((RS = +tag.rowspan) > 1 || CS > 1)
              merges.push({ s: { r: R, c: C }, e: { r: R + (RS || 1) - 1, c: C + CS - 1 } });
            var _t = tag.t || tag["data-t"] || "";
            if (!m.length) {
              C += CS;
              continue;
            }
            m = htmldecode(m);
            if (range.s.r > R)
              range.s.r = R;
            if (range.e.r < R)
              range.e.r = R;
            if (range.s.c > C)
              range.s.c = C;
            if (range.e.c < C)
              range.e.c = C;
            if (!m.length) {
              C += CS;
              continue;
            }
            var o = { t: "s", v: m };
            if (opts.raw || !m.trim().length || _t == "s") {
            } else if (m === "TRUE")
              o = { t: "b", v: true };
            else if (m === "FALSE")
              o = { t: "b", v: false };
            else if (!isNaN(fuzzynum(m)))
              o = { t: "n", v: fuzzynum(m) };
            else if (!isNaN(fuzzydate(m).getDate())) {
              o = { t: "d", v: parseDate(m) };
              if (!opts.cellDates)
                o = { t: "n", v: datenum(o.v) };
              o.z = opts.dateNF || table_fmt[14];
            }
            if (opts.dense) {
              if (!ws[R])
                ws[R] = [];
              ws[R][C] = o;
            } else
              ws[encode_cell({ r: R, c: C })] = o;
            C += CS;
          }
        }
        ws["!ref"] = encode_range(range);
        if (merges.length)
          ws["!merges"] = merges;
        return ws;
      }
      function make_html_row(ws, r, R, o) {
        var M = ws["!merges"] || [];
        var oo = [];
        for (var C = r.s.c; C <= r.e.c; ++C) {
          var RS = 0, CS = 0;
          for (var j = 0; j < M.length; ++j) {
            if (M[j].s.r > R || M[j].s.c > C)
              continue;
            if (M[j].e.r < R || M[j].e.c < C)
              continue;
            if (M[j].s.r < R || M[j].s.c < C) {
              RS = -1;
              break;
            }
            RS = M[j].e.r - M[j].s.r + 1;
            CS = M[j].e.c - M[j].s.c + 1;
            break;
          }
          if (RS < 0)
            continue;
          var coord = encode_cell({ r: R, c: C });
          var cell = o.dense ? (ws[R] || [])[C] : ws[coord];
          var w = cell && cell.v != null && (cell.h || escapehtml(cell.w || (format_cell(cell), cell.w) || "")) || "";
          var sp = {};
          if (RS > 1)
            sp.rowspan = RS;
          if (CS > 1)
            sp.colspan = CS;
          if (o.editable)
            w = '<span contenteditable="true">' + w + "</span>";
          else if (cell) {
            sp["data-t"] = cell && cell.t || "z";
            if (cell.v != null)
              sp["data-v"] = cell.v;
            if (cell.z != null)
              sp["data-z"] = cell.z;
            if (cell.l && (cell.l.Target || "#").charAt(0) != "#")
              w = '<a href="' + cell.l.Target + '">' + w + "</a>";
          }
          sp.id = (o.id || "sjs") + "-" + coord;
          oo.push(writextag("td", w, sp));
        }
        var preamble = "<tr>";
        return preamble + oo.join("") + "</tr>";
      }
      var HTML_BEGIN = '<html><head><meta charset="utf-8"/><title>SheetJS Table Export</title></head><body>';
      var HTML_END = "</body></html>";
      function html_to_workbook(str, opts) {
        var mtch = str.match(/<table[\s\S]*?>[\s\S]*?<\/table>/gi);
        if (!mtch || mtch.length == 0)
          throw new Error("Invalid HTML: could not find <table>");
        if (mtch.length == 1)
          return sheet_to_workbook(html_to_sheet(mtch[0], opts), opts);
        var wb = book_new();
        mtch.forEach(function(s, idx) {
          book_append_sheet(wb, html_to_sheet(s, opts), "Sheet" + (idx + 1));
        });
        return wb;
      }
      function make_html_preamble(ws, R, o) {
        var out = [];
        return out.join("") + "<table" + (o && o.id ? ' id="' + o.id + '"' : "") + ">";
      }
      function sheet_to_html(ws, opts) {
        var o = opts || {};
        var header = o.header != null ? o.header : HTML_BEGIN;
        var footer = o.footer != null ? o.footer : HTML_END;
        var out = [header];
        var r = decode_range(ws["!ref"]);
        o.dense = Array.isArray(ws);
        out.push(make_html_preamble(ws, r, o));
        for (var R = r.s.r; R <= r.e.r; ++R)
          out.push(make_html_row(ws, r, R, o));
        out.push("</table>" + footer);
        return out.join("");
      }
      function sheet_add_dom(ws, table, _opts) {
        var opts = _opts || {};
        if (DENSE != null)
          opts.dense = DENSE;
        var or_R = 0, or_C = 0;
        if (opts.origin != null) {
          if (typeof opts.origin == "number")
            or_R = opts.origin;
          else {
            var _origin = typeof opts.origin == "string" ? decode_cell(opts.origin) : opts.origin;
            or_R = _origin.r;
            or_C = _origin.c;
          }
        }
        var rows = table.getElementsByTagName("tr");
        var sheetRows = Math.min(opts.sheetRows || 1e7, rows.length);
        var range = { s: { r: 0, c: 0 }, e: { r: or_R, c: or_C } };
        if (ws["!ref"]) {
          var _range = decode_range(ws["!ref"]);
          range.s.r = Math.min(range.s.r, _range.s.r);
          range.s.c = Math.min(range.s.c, _range.s.c);
          range.e.r = Math.max(range.e.r, _range.e.r);
          range.e.c = Math.max(range.e.c, _range.e.c);
          if (or_R == -1)
            range.e.r = or_R = _range.e.r + 1;
        }
        var merges = [], midx = 0;
        var rowinfo = ws["!rows"] || (ws["!rows"] = []);
        var _R = 0, R = 0, _C = 0, C = 0, RS = 0, CS = 0;
        if (!ws["!cols"])
          ws["!cols"] = [];
        for (; _R < rows.length && R < sheetRows; ++_R) {
          var row = rows[_R];
          if (is_dom_element_hidden(row)) {
            if (opts.display)
              continue;
            rowinfo[R] = { hidden: true };
          }
          var elts = row.children;
          for (_C = C = 0; _C < elts.length; ++_C) {
            var elt = elts[_C];
            if (opts.display && is_dom_element_hidden(elt))
              continue;
            var v = elt.hasAttribute("data-v") ? elt.getAttribute("data-v") : elt.hasAttribute("v") ? elt.getAttribute("v") : htmldecode(elt.innerHTML);
            var z = elt.getAttribute("data-z") || elt.getAttribute("z");
            for (midx = 0; midx < merges.length; ++midx) {
              var m = merges[midx];
              if (m.s.c == C + or_C && m.s.r < R + or_R && R + or_R <= m.e.r) {
                C = m.e.c + 1 - or_C;
                midx = -1;
              }
            }
            CS = +elt.getAttribute("colspan") || 1;
            if ((RS = +elt.getAttribute("rowspan") || 1) > 1 || CS > 1)
              merges.push({ s: { r: R + or_R, c: C + or_C }, e: { r: R + or_R + (RS || 1) - 1, c: C + or_C + (CS || 1) - 1 } });
            var o = { t: "s", v };
            var _t = elt.getAttribute("data-t") || elt.getAttribute("t") || "";
            if (v != null) {
              if (v.length == 0)
                o.t = _t || "z";
              else if (opts.raw || v.trim().length == 0 || _t == "s") {
              } else if (v === "TRUE")
                o = { t: "b", v: true };
              else if (v === "FALSE")
                o = { t: "b", v: false };
              else if (!isNaN(fuzzynum(v)))
                o = { t: "n", v: fuzzynum(v) };
              else if (!isNaN(fuzzydate(v).getDate())) {
                o = { t: "d", v: parseDate(v) };
                if (!opts.cellDates)
                  o = { t: "n", v: datenum(o.v) };
                o.z = opts.dateNF || table_fmt[14];
              }
            }
            if (o.z === void 0 && z != null)
              o.z = z;
            var l = "", Aelts = elt.getElementsByTagName("A");
            if (Aelts && Aelts.length) {
              for (var Aelti = 0; Aelti < Aelts.length; ++Aelti)
                if (Aelts[Aelti].hasAttribute("href")) {
                  l = Aelts[Aelti].getAttribute("href");
                  if (l.charAt(0) != "#")
                    break;
                }
            }
            if (l && l.charAt(0) != "#")
              o.l = { Target: l };
            if (opts.dense) {
              if (!ws[R + or_R])
                ws[R + or_R] = [];
              ws[R + or_R][C + or_C] = o;
            } else
              ws[encode_cell({ c: C + or_C, r: R + or_R })] = o;
            if (range.e.c < C + or_C)
              range.e.c = C + or_C;
            C += CS;
          }
          ++R;
        }
        if (merges.length)
          ws["!merges"] = (ws["!merges"] || []).concat(merges);
        range.e.r = Math.max(range.e.r, R - 1 + or_R);
        ws["!ref"] = encode_range(range);
        if (R >= sheetRows)
          ws["!fullref"] = encode_range((range.e.r = rows.length - _R + R - 1 + or_R, range));
        return ws;
      }
      function parse_dom_table(table, _opts) {
        var opts = _opts || {};
        var ws = opts.dense ? [] : {};
        return sheet_add_dom(ws, table, _opts);
      }
      function table_to_book(table, opts) {
        return sheet_to_workbook(parse_dom_table(table, opts), opts);
      }
      function is_dom_element_hidden(element) {
        var display = "";
        var get_computed_style = get_get_computed_style_function(element);
        if (get_computed_style)
          display = get_computed_style(element).getPropertyValue("display");
        if (!display)
          display = element.style && element.style.display;
        return display === "none";
      }
      function get_get_computed_style_function(element) {
        if (element.ownerDocument.defaultView && typeof element.ownerDocument.defaultView.getComputedStyle === "function")
          return element.ownerDocument.defaultView.getComputedStyle;
        if (typeof getComputedStyle === "function")
          return getComputedStyle;
        return null;
      }
      function parse_text_p(text) {
        var fixed = text.replace(/[\t\r\n]/g, " ").trim().replace(/ +/g, " ").replace(/<text:s\/>/g, " ").replace(/<text:s text:c="(\d+)"\/>/g, function($$, $1) {
          return Array(parseInt($1, 10) + 1).join(" ");
        }).replace(/<text:tab[^>]*\/>/g, "	").replace(/<text:line-break\/>/g, "\n");
        var v = unescapexml(fixed.replace(/<[^>]*>/g, ""));
        return [v];
      }
      var number_formats_ods = {
        /* ods name: [short ssf fmt, long ssf fmt] */
        day: ["d", "dd"],
        month: ["m", "mm"],
        year: ["y", "yy"],
        hours: ["h", "hh"],
        minutes: ["m", "mm"],
        seconds: ["s", "ss"],
        "am-pm": ["A/P", "AM/PM"],
        "day-of-week": ["ddd", "dddd"],
        era: ["e", "ee"],
        /* there is no native representation of LO "Q" format */
        quarter: ["\\Qm", 'm\\"th quarter"']
      };
      function parse_content_xml(d, _opts) {
        var opts = _opts || {};
        if (DENSE != null && opts.dense == null)
          opts.dense = DENSE;
        var str = xlml_normalize(d);
        var state = [], tmp;
        var tag;
        var NFtag = { name: "" }, NF = "", pidx = 0;
        var sheetag;
        var rowtag;
        var Sheets = {}, SheetNames = [];
        var ws = opts.dense ? [] : {};
        var Rn, q;
        var ctag = { value: "" };
        var textp = "", textpidx = 0, textptag;
        var textR = [];
        var R = -1, C = -1, range = { s: { r: 1e6, c: 1e7 }, e: { r: 0, c: 0 } };
        var row_ol = 0;
        var number_format_map = {};
        var merges = [], mrange = {}, mR = 0, mC = 0;
        var rowinfo = [], rowpeat = 1, colpeat = 1;
        var arrayf = [];
        var WB = { Names: [] };
        var atag = {};
        var _Ref = ["", ""];
        var comments = [], comment = {};
        var creator = "", creatoridx = 0;
        var isstub = false, intable = false;
        var i = 0;
        xlmlregex.lastIndex = 0;
        str = str.replace(/<!--([\s\S]*?)-->/mg, "").replace(/<!DOCTYPE[^\[]*\[[^\]]*\]>/gm, "");
        while (Rn = xlmlregex.exec(str))
          switch (Rn[3] = Rn[3].replace(/_.*$/, "")) {
            case "table":
            case "\u5DE5\u4F5C\u8868":
              if (Rn[1] === "/") {
                if (range.e.c >= range.s.c && range.e.r >= range.s.r)
                  ws["!ref"] = encode_range(range);
                else
                  ws["!ref"] = "A1:A1";
                if (opts.sheetRows > 0 && opts.sheetRows <= range.e.r) {
                  ws["!fullref"] = ws["!ref"];
                  range.e.r = opts.sheetRows - 1;
                  ws["!ref"] = encode_range(range);
                }
                if (merges.length)
                  ws["!merges"] = merges;
                if (rowinfo.length)
                  ws["!rows"] = rowinfo;
                sheetag.name = sheetag["\u540D\u79F0"] || sheetag.name;
                if (typeof JSON !== "undefined")
                  JSON.stringify(sheetag);
                SheetNames.push(sheetag.name);
                Sheets[sheetag.name] = ws;
                intable = false;
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/") {
                sheetag = parsexmltag(Rn[0], false);
                R = C = -1;
                range.s.r = range.s.c = 1e7;
                range.e.r = range.e.c = 0;
                ws = opts.dense ? [] : {};
                merges = [];
                rowinfo = [];
                intable = true;
              }
              break;
            case "table-row-group":
              if (Rn[1] === "/")
                --row_ol;
              else
                ++row_ol;
              break;
            case "table-row":
            case "\u884C":
              if (Rn[1] === "/") {
                R += rowpeat;
                rowpeat = 1;
                break;
              }
              rowtag = parsexmltag(Rn[0], false);
              if (rowtag["\u884C\u53F7"])
                R = rowtag["\u884C\u53F7"] - 1;
              else if (R == -1)
                R = 0;
              rowpeat = +rowtag["number-rows-repeated"] || 1;
              if (rowpeat < 10) {
                for (i = 0; i < rowpeat; ++i)
                  if (row_ol > 0)
                    rowinfo[R + i] = { level: row_ol };
              }
              C = -1;
              break;
            case "covered-table-cell":
              if (Rn[1] !== "/")
                ++C;
              if (opts.sheetStubs) {
                if (opts.dense) {
                  if (!ws[R])
                    ws[R] = [];
                  ws[R][C] = { t: "z" };
                } else
                  ws[encode_cell({ r: R, c: C })] = { t: "z" };
              }
              textp = "";
              textR = [];
              break;
            case "table-cell":
            case "\u6570\u636E":
              if (Rn[0].charAt(Rn[0].length - 2) === "/") {
                ++C;
                ctag = parsexmltag(Rn[0], false);
                colpeat = parseInt(ctag["number-columns-repeated"] || "1", 10);
                q = { t: "z", v: null };
                if (ctag.formula && opts.cellFormula != false)
                  q.f = ods_to_csf_formula(unescapexml(ctag.formula));
                if ((ctag["\u6570\u636E\u7C7B\u578B"] || ctag["value-type"]) == "string") {
                  q.t = "s";
                  q.v = unescapexml(ctag["string-value"] || "");
                  if (opts.dense) {
                    if (!ws[R])
                      ws[R] = [];
                    ws[R][C] = q;
                  } else {
                    ws[encode_cell({ r: R, c: C })] = q;
                  }
                }
                C += colpeat - 1;
              } else if (Rn[1] !== "/") {
                ++C;
                textp = "";
                textpidx = 0;
                textR = [];
                colpeat = 1;
                var rptR = rowpeat ? R + rowpeat - 1 : R;
                if (C > range.e.c)
                  range.e.c = C;
                if (C < range.s.c)
                  range.s.c = C;
                if (R < range.s.r)
                  range.s.r = R;
                if (rptR > range.e.r)
                  range.e.r = rptR;
                ctag = parsexmltag(Rn[0], false);
                comments = [];
                comment = {};
                q = { t: ctag["\u6570\u636E\u7C7B\u578B"] || ctag["value-type"], v: null };
                if (opts.cellFormula) {
                  if (ctag.formula)
                    ctag.formula = unescapexml(ctag.formula);
                  if (ctag["number-matrix-columns-spanned"] && ctag["number-matrix-rows-spanned"]) {
                    mR = parseInt(ctag["number-matrix-rows-spanned"], 10) || 0;
                    mC = parseInt(ctag["number-matrix-columns-spanned"], 10) || 0;
                    mrange = { s: { r: R, c: C }, e: { r: R + mR - 1, c: C + mC - 1 } };
                    q.F = encode_range(mrange);
                    arrayf.push([mrange, q.F]);
                  }
                  if (ctag.formula)
                    q.f = ods_to_csf_formula(ctag.formula);
                  else
                    for (i = 0; i < arrayf.length; ++i)
                      if (R >= arrayf[i][0].s.r && R <= arrayf[i][0].e.r) {
                        if (C >= arrayf[i][0].s.c && C <= arrayf[i][0].e.c)
                          q.F = arrayf[i][1];
                      }
                }
                if (ctag["number-columns-spanned"] || ctag["number-rows-spanned"]) {
                  mR = parseInt(ctag["number-rows-spanned"], 10) || 0;
                  mC = parseInt(ctag["number-columns-spanned"], 10) || 0;
                  mrange = { s: { r: R, c: C }, e: { r: R + mR - 1, c: C + mC - 1 } };
                  merges.push(mrange);
                }
                if (ctag["number-columns-repeated"])
                  colpeat = parseInt(ctag["number-columns-repeated"], 10);
                switch (q.t) {
                  case "boolean":
                    q.t = "b";
                    q.v = parsexmlbool(ctag["boolean-value"]);
                    break;
                  case "float":
                    q.t = "n";
                    q.v = parseFloat(ctag.value);
                    break;
                  case "percentage":
                    q.t = "n";
                    q.v = parseFloat(ctag.value);
                    break;
                  case "currency":
                    q.t = "n";
                    q.v = parseFloat(ctag.value);
                    break;
                  case "date":
                    q.t = "d";
                    q.v = parseDate(ctag["date-value"]);
                    if (!opts.cellDates) {
                      q.t = "n";
                      q.v = datenum(q.v);
                    }
                    q.z = "m/d/yy";
                    break;
                  case "time":
                    q.t = "n";
                    q.v = parse_isodur(ctag["time-value"]) / 86400;
                    if (opts.cellDates) {
                      q.t = "d";
                      q.v = numdate(q.v);
                    }
                    q.z = "HH:MM:SS";
                    break;
                  case "number":
                    q.t = "n";
                    q.v = parseFloat(ctag["\u6570\u636E\u6570\u503C"]);
                    break;
                  default:
                    if (q.t === "string" || q.t === "text" || !q.t) {
                      q.t = "s";
                      if (ctag["string-value"] != null) {
                        textp = unescapexml(ctag["string-value"]);
                        textR = [];
                      }
                    } else
                      throw new Error("Unsupported value type " + q.t);
                }
              } else {
                isstub = false;
                if (q.t === "s") {
                  q.v = textp || "";
                  if (textR.length)
                    q.R = textR;
                  isstub = textpidx == 0;
                }
                if (atag.Target)
                  q.l = atag;
                if (comments.length > 0) {
                  q.c = comments;
                  comments = [];
                }
                if (textp && opts.cellText !== false)
                  q.w = textp;
                if (isstub) {
                  q.t = "z";
                  delete q.v;
                }
                if (!isstub || opts.sheetStubs) {
                  if (!(opts.sheetRows && opts.sheetRows <= R)) {
                    for (var rpt = 0; rpt < rowpeat; ++rpt) {
                      colpeat = parseInt(ctag["number-columns-repeated"] || "1", 10);
                      if (opts.dense) {
                        if (!ws[R + rpt])
                          ws[R + rpt] = [];
                        ws[R + rpt][C] = rpt == 0 ? q : dup(q);
                        while (--colpeat > 0)
                          ws[R + rpt][C + colpeat] = dup(q);
                      } else {
                        ws[encode_cell({ r: R + rpt, c: C })] = q;
                        while (--colpeat > 0)
                          ws[encode_cell({ r: R + rpt, c: C + colpeat })] = dup(q);
                      }
                      if (range.e.c <= C)
                        range.e.c = C;
                    }
                  }
                }
                colpeat = parseInt(ctag["number-columns-repeated"] || "1", 10);
                C += colpeat - 1;
                colpeat = 0;
                q = {};
                textp = "";
                textR = [];
              }
              atag = {};
              break;
            case "document":
            case "document-content":
            case "\u7535\u5B50\u8868\u683C\u6587\u6863":
            case "spreadsheet":
            case "\u4E3B\u4F53":
            case "scripts":
            case "styles":
            case "font-face-decls":
            case "master-styles":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw "Bad state: " + tmp;
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/")
                state.push([Rn[3], true]);
              break;
            case "annotation":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw "Bad state: " + tmp;
                comment.t = textp;
                if (textR.length)
                  comment.R = textR;
                comment.a = creator;
                comments.push(comment);
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/") {
                state.push([Rn[3], false]);
              }
              creator = "";
              creatoridx = 0;
              textp = "";
              textpidx = 0;
              textR = [];
              break;
            case "creator":
              if (Rn[1] === "/") {
                creator = str.slice(creatoridx, Rn.index);
              } else
                creatoridx = Rn.index + Rn[0].length;
              break;
            case "meta":
            case "\u5143\u6570\u636E":
            case "settings":
            case "config-item-set":
            case "config-item-map-indexed":
            case "config-item-map-entry":
            case "config-item-map-named":
            case "shapes":
            case "frame":
            case "text-box":
            case "image":
            case "data-pilot-tables":
            case "list-style":
            case "form":
            case "dde-links":
            case "event-listeners":
            case "chart":
              if (Rn[1] === "/") {
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw "Bad state: " + tmp;
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/")
                state.push([Rn[3], false]);
              textp = "";
              textpidx = 0;
              textR = [];
              break;
            case "scientific-number":
              break;
            case "currency-symbol":
              break;
            case "currency-style":
              break;
            case "number-style":
            case "percentage-style":
            case "date-style":
            case "time-style":
              if (Rn[1] === "/") {
                number_format_map[NFtag.name] = NF;
                if ((tmp = state.pop())[0] !== Rn[3])
                  throw "Bad state: " + tmp;
              } else if (Rn[0].charAt(Rn[0].length - 2) !== "/") {
                NF = "";
                NFtag = parsexmltag(Rn[0], false);
                state.push([Rn[3], true]);
              }
              break;
            case "script":
              break;
            case "libraries":
              break;
            case "automatic-styles":
              break;
            case "default-style":
            case "page-layout":
              break;
            case "style":
              break;
            case "map":
              break;
            case "font-face":
              break;
            case "paragraph-properties":
              break;
            case "table-properties":
              break;
            case "table-column-properties":
              break;
            case "table-row-properties":
              break;
            case "table-cell-properties":
              break;
            case "number":
              switch (state[state.length - 1][0]) {
                case "time-style":
                case "date-style":
                  tag = parsexmltag(Rn[0], false);
                  NF += number_formats_ods[Rn[3]][tag.style === "long" ? 1 : 0];
                  break;
              }
              break;
            case "fraction":
              break;
            case "day":
            case "month":
            case "year":
            case "era":
            case "day-of-week":
            case "week-of-year":
            case "quarter":
            case "hours":
            case "minutes":
            case "seconds":
            case "am-pm":
              switch (state[state.length - 1][0]) {
                case "time-style":
                case "date-style":
                  tag = parsexmltag(Rn[0], false);
                  NF += number_formats_ods[Rn[3]][tag.style === "long" ? 1 : 0];
                  break;
              }
              break;
            case "boolean-style":
              break;
            case "boolean":
              break;
            case "text-style":
              break;
            case "text":
              if (Rn[0].slice(-2) === "/>")
                break;
              else if (Rn[1] === "/")
                switch (state[state.length - 1][0]) {
                  case "number-style":
                  case "date-style":
                  case "time-style":
                    NF += str.slice(pidx, Rn.index);
                    break;
                }
              else
                pidx = Rn.index + Rn[0].length;
              break;
            case "named-range":
              tag = parsexmltag(Rn[0], false);
              _Ref = ods_to_csf_3D(tag["cell-range-address"]);
              var nrange = { Name: tag.name, Ref: _Ref[0] + "!" + _Ref[1] };
              if (intable)
                nrange.Sheet = SheetNames.length;
              WB.Names.push(nrange);
              break;
            case "text-content":
              break;
            case "text-properties":
              break;
            case "embedded-text":
              break;
            case "body":
            case "\u7535\u5B50\u8868\u683C":
              break;
            case "forms":
              break;
            case "table-column":
              break;
            case "table-header-rows":
              break;
            case "table-rows":
              break;
            case "table-column-group":
              break;
            case "table-header-columns":
              break;
            case "table-columns":
              break;
            case "null-date":
              break;
            case "graphic-properties":
              break;
            case "calculation-settings":
              break;
            case "named-expressions":
              break;
            case "label-range":
              break;
            case "label-ranges":
              break;
            case "named-expression":
              break;
            case "sort":
              break;
            case "sort-by":
              break;
            case "sort-groups":
              break;
            case "tab":
              break;
            case "line-break":
              break;
            case "span":
              break;
            case "p":
            case "\u6587\u672C\u4E32":
              if (["master-styles"].indexOf(state[state.length - 1][0]) > -1)
                break;
              if (Rn[1] === "/" && (!ctag || !ctag["string-value"])) {
                var ptp = parse_text_p(str.slice(textpidx, Rn.index), textptag);
                textp = (textp.length > 0 ? textp + "\n" : "") + ptp[0];
              } else {
                textptag = parsexmltag(Rn[0], false);
                textpidx = Rn.index + Rn[0].length;
              }
              break;
            case "s":
              break;
            case "database-range":
              if (Rn[1] === "/")
                break;
              try {
                _Ref = ods_to_csf_3D(parsexmltag(Rn[0])["target-range-address"]);
                Sheets[_Ref[0]]["!autofilter"] = { ref: _Ref[1] };
              } catch (e) {
              }
              break;
            case "date":
              break;
            case "object":
              break;
            case "title":
            case "\u6807\u9898":
              break;
            case "desc":
              break;
            case "binary-data":
              break;
            case "table-source":
              break;
            case "scenario":
              break;
            case "iteration":
              break;
            case "content-validations":
              break;
            case "content-validation":
              break;
            case "help-message":
              break;
            case "error-message":
              break;
            case "database-ranges":
              break;
            case "filter":
              break;
            case "filter-and":
              break;
            case "filter-or":
              break;
            case "filter-condition":
              break;
            case "list-level-style-bullet":
              break;
            case "list-level-style-number":
              break;
            case "list-level-properties":
              break;
            case "sender-firstname":
            case "sender-lastname":
            case "sender-initials":
            case "sender-title":
            case "sender-position":
            case "sender-email":
            case "sender-phone-private":
            case "sender-fax":
            case "sender-company":
            case "sender-phone-work":
            case "sender-street":
            case "sender-city":
            case "sender-postal-code":
            case "sender-country":
            case "sender-state-or-province":
            case "author-name":
            case "author-initials":
            case "chapter":
            case "file-name":
            case "template-name":
            case "sheet-name":
              break;
            case "event-listener":
              break;
            case "initial-creator":
            case "creation-date":
            case "print-date":
            case "generator":
            case "document-statistic":
            case "user-defined":
            case "editing-duration":
            case "editing-cycles":
              break;
            case "config-item":
              break;
            case "page-number":
              break;
            case "page-count":
              break;
            case "time":
              break;
            case "cell-range-source":
              break;
            case "detective":
              break;
            case "operation":
              break;
            case "highlighted-range":
              break;
            case "data-pilot-table":
            case "source-cell-range":
            case "source-service":
            case "data-pilot-field":
            case "data-pilot-level":
            case "data-pilot-subtotals":
            case "data-pilot-subtotal":
            case "data-pilot-members":
            case "data-pilot-member":
            case "data-pilot-display-info":
            case "data-pilot-sort-info":
            case "data-pilot-layout-info":
            case "data-pilot-field-reference":
            case "data-pilot-groups":
            case "data-pilot-group":
            case "data-pilot-group-member":
              break;
            case "rect":
              break;
            case "dde-connection-decls":
            case "dde-connection-decl":
            case "dde-link":
            case "dde-source":
              break;
            case "properties":
              break;
            case "property":
              break;
            case "a":
              if (Rn[1] !== "/") {
                atag = parsexmltag(Rn[0], false);
                if (!atag.href)
                  break;
                atag.Target = unescapexml(atag.href);
                delete atag.href;
                if (atag.Target.charAt(0) == "#" && atag.Target.indexOf(".") > -1) {
                  _Ref = ods_to_csf_3D(atag.Target.slice(1));
                  atag.Target = "#" + _Ref[0] + "!" + _Ref[1];
                } else if (atag.Target.match(/^\.\.[\\\/]/))
                  atag.Target = atag.Target.slice(3);
              }
              break;
            case "table-protection":
              break;
            case "data-pilot-grand-total":
              break;
            case "office-document-common-attrs":
              break;
            default:
              switch (Rn[2]) {
                case "dc:":
                case "calcext:":
                case "loext:":
                case "ooo:":
                case "chartooo:":
                case "draw:":
                case "style:":
                case "chart:":
                case "form:":
                case "uof:":
                case "\u8868:":
                case "\u5B57:":
                  break;
                default:
                  if (opts.WTF)
                    throw new Error(Rn);
              }
          }
        var out = {
          Sheets,
          SheetNames,
          Workbook: WB
        };
        if (opts.bookSheets)
          delete out.Sheets;
        return out;
      }
      function parse_ods(zip, opts) {
        opts = opts || {};
        if (safegetzipfile(zip, "META-INF/manifest.xml"))
          parse_manifest(getzipdata(zip, "META-INF/manifest.xml"), opts);
        var content = getzipstr(zip, "content.xml");
        if (!content)
          throw new Error("Missing content.xml in ODS / UOF file");
        var wb = parse_content_xml(utf8read(content), opts);
        if (safegetzipfile(zip, "meta.xml"))
          wb.Props = parse_core_props(getzipdata(zip, "meta.xml"));
        return wb;
      }
      function parse_fods(data, opts) {
        return parse_content_xml(data, opts);
      }
      var write_styles_ods = /* @__PURE__ */ function() {
        var master_styles = [
          "<office:master-styles>",
          '<style:master-page style:name="mp1" style:page-layout-name="mp1">',
          "<style:header/>",
          '<style:header-left style:display="false"/>',
          "<style:footer/>",
          '<style:footer-left style:display="false"/>',
          "</style:master-page>",
          "</office:master-styles>"
        ].join("");
        var payload = "<office:document-styles " + wxt_helper({
          "xmlns:office": "urn:oasis:names:tc:opendocument:xmlns:office:1.0",
          "xmlns:table": "urn:oasis:names:tc:opendocument:xmlns:table:1.0",
          "xmlns:style": "urn:oasis:names:tc:opendocument:xmlns:style:1.0",
          "xmlns:text": "urn:oasis:names:tc:opendocument:xmlns:text:1.0",
          "xmlns:draw": "urn:oasis:names:tc:opendocument:xmlns:drawing:1.0",
          "xmlns:fo": "urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0",
          "xmlns:xlink": "http://www.w3.org/1999/xlink",
          "xmlns:dc": "http://purl.org/dc/elements/1.1/",
          "xmlns:number": "urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0",
          "xmlns:svg": "urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0",
          "xmlns:of": "urn:oasis:names:tc:opendocument:xmlns:of:1.2",
          "office:version": "1.2"
        }) + ">" + master_styles + "</office:document-styles>";
        return function wso() {
          return XML_HEADER + payload;
        };
      }();
      var write_content_ods = /* @__PURE__ */ function() {
        var write_text_p = function(text) {
          return escapexml(text).replace(/  +/g, function($$) {
            return '<text:s text:c="' + $$.length + '"/>';
          }).replace(/\t/g, "<text:tab/>").replace(/\n/g, "</text:p><text:p>").replace(/^ /, "<text:s/>").replace(/ $/, "<text:s/>");
        };
        var null_cell_xml = "          <table:table-cell />\n";
        var covered_cell_xml = "          <table:covered-table-cell/>\n";
        var write_ws2 = function(ws, wb, i) {
          var o = [];
          o.push('      <table:table table:name="' + escapexml(wb.SheetNames[i]) + '" table:style-name="ta1">\n');
          var R = 0, C = 0, range = decode_range(ws["!ref"] || "A1");
          var marr = ws["!merges"] || [], mi = 0;
          var dense = Array.isArray(ws);
          if (ws["!cols"]) {
            for (C = 0; C <= range.e.c; ++C)
              o.push("        <table:table-column" + (ws["!cols"][C] ? ' table:style-name="co' + ws["!cols"][C].ods + '"' : "") + "></table:table-column>\n");
          }
          var H = "", ROWS = ws["!rows"] || [];
          for (R = 0; R < range.s.r; ++R) {
            H = ROWS[R] ? ' table:style-name="ro' + ROWS[R].ods + '"' : "";
            o.push("        <table:table-row" + H + "></table:table-row>\n");
          }
          for (; R <= range.e.r; ++R) {
            H = ROWS[R] ? ' table:style-name="ro' + ROWS[R].ods + '"' : "";
            o.push("        <table:table-row" + H + ">\n");
            for (C = 0; C < range.s.c; ++C)
              o.push(null_cell_xml);
            for (; C <= range.e.c; ++C) {
              var skip = false, ct = {}, textp = "";
              for (mi = 0; mi != marr.length; ++mi) {
                if (marr[mi].s.c > C)
                  continue;
                if (marr[mi].s.r > R)
                  continue;
                if (marr[mi].e.c < C)
                  continue;
                if (marr[mi].e.r < R)
                  continue;
                if (marr[mi].s.c != C || marr[mi].s.r != R)
                  skip = true;
                ct["table:number-columns-spanned"] = marr[mi].e.c - marr[mi].s.c + 1;
                ct["table:number-rows-spanned"] = marr[mi].e.r - marr[mi].s.r + 1;
                break;
              }
              if (skip) {
                o.push(covered_cell_xml);
                continue;
              }
              var ref = encode_cell({ r: R, c: C }), cell = dense ? (ws[R] || [])[C] : ws[ref];
              if (cell && cell.f) {
                ct["table:formula"] = escapexml(csf_to_ods_formula(cell.f));
                if (cell.F) {
                  if (cell.F.slice(0, ref.length) == ref) {
                    var _Fref = decode_range(cell.F);
                    ct["table:number-matrix-columns-spanned"] = _Fref.e.c - _Fref.s.c + 1;
                    ct["table:number-matrix-rows-spanned"] = _Fref.e.r - _Fref.s.r + 1;
                  }
                }
              }
              if (!cell) {
                o.push(null_cell_xml);
                continue;
              }
              switch (cell.t) {
                case "b":
                  textp = cell.v ? "TRUE" : "FALSE";
                  ct["office:value-type"] = "boolean";
                  ct["office:boolean-value"] = cell.v ? "true" : "false";
                  break;
                case "n":
                  textp = cell.w || String(cell.v || 0);
                  ct["office:value-type"] = "float";
                  ct["office:value"] = cell.v || 0;
                  break;
                case "s":
                case "str":
                  textp = cell.v == null ? "" : cell.v;
                  ct["office:value-type"] = "string";
                  break;
                case "d":
                  textp = cell.w || parseDate(cell.v).toISOString();
                  ct["office:value-type"] = "date";
                  ct["office:date-value"] = parseDate(cell.v).toISOString();
                  ct["table:style-name"] = "ce1";
                  break;
                default:
                  o.push(null_cell_xml);
                  continue;
              }
              var text_p = write_text_p(textp);
              if (cell.l && cell.l.Target) {
                var _tgt = cell.l.Target;
                _tgt = _tgt.charAt(0) == "#" ? "#" + csf_to_ods_3D(_tgt.slice(1)) : _tgt;
                if (_tgt.charAt(0) != "#" && !_tgt.match(/^\w+:/))
                  _tgt = "../" + _tgt;
                text_p = writextag("text:a", text_p, { "xlink:href": _tgt.replace(/&/g, "&amp;") });
              }
              o.push("          " + writextag("table:table-cell", writextag("text:p", text_p, {}), ct) + "\n");
            }
            o.push("        </table:table-row>\n");
          }
          o.push("      </table:table>\n");
          return o.join("");
        };
        var write_automatic_styles_ods = function(o, wb) {
          o.push(" <office:automatic-styles>\n");
          o.push('  <number:date-style style:name="N37" number:automatic-order="true">\n');
          o.push('   <number:month number:style="long"/>\n');
          o.push("   <number:text>/</number:text>\n");
          o.push('   <number:day number:style="long"/>\n');
          o.push("   <number:text>/</number:text>\n");
          o.push("   <number:year/>\n");
          o.push("  </number:date-style>\n");
          var cidx = 0;
          wb.SheetNames.map(function(n) {
            return wb.Sheets[n];
          }).forEach(function(ws) {
            if (!ws)
              return;
            if (ws["!cols"]) {
              for (var C = 0; C < ws["!cols"].length; ++C)
                if (ws["!cols"][C]) {
                  var colobj = ws["!cols"][C];
                  if (colobj.width == null && colobj.wpx == null && colobj.wch == null)
                    continue;
                  process_col(colobj);
                  colobj.ods = cidx;
                  var w = ws["!cols"][C].wpx + "px";
                  o.push('  <style:style style:name="co' + cidx + '" style:family="table-column">\n');
                  o.push('   <style:table-column-properties fo:break-before="auto" style:column-width="' + w + '"/>\n');
                  o.push("  </style:style>\n");
                  ++cidx;
                }
            }
          });
          var ridx = 0;
          wb.SheetNames.map(function(n) {
            return wb.Sheets[n];
          }).forEach(function(ws) {
            if (!ws)
              return;
            if (ws["!rows"]) {
              for (var R = 0; R < ws["!rows"].length; ++R)
                if (ws["!rows"][R]) {
                  ws["!rows"][R].ods = ridx;
                  var h = ws["!rows"][R].hpx + "px";
                  o.push('  <style:style style:name="ro' + ridx + '" style:family="table-row">\n');
                  o.push('   <style:table-row-properties fo:break-before="auto" style:row-height="' + h + '"/>\n');
                  o.push("  </style:style>\n");
                  ++ridx;
                }
            }
          });
          o.push('  <style:style style:name="ta1" style:family="table" style:master-page-name="mp1">\n');
          o.push('   <style:table-properties table:display="true" style:writing-mode="lr-tb"/>\n');
          o.push("  </style:style>\n");
          o.push('  <style:style style:name="ce1" style:family="table-cell" style:parent-style-name="Default" style:data-style-name="N37"/>\n');
          o.push(" </office:automatic-styles>\n");
        };
        return function wcx(wb, opts) {
          var o = [XML_HEADER];
          var attr = wxt_helper({
            "xmlns:office": "urn:oasis:names:tc:opendocument:xmlns:office:1.0",
            "xmlns:table": "urn:oasis:names:tc:opendocument:xmlns:table:1.0",
            "xmlns:style": "urn:oasis:names:tc:opendocument:xmlns:style:1.0",
            "xmlns:text": "urn:oasis:names:tc:opendocument:xmlns:text:1.0",
            "xmlns:draw": "urn:oasis:names:tc:opendocument:xmlns:drawing:1.0",
            "xmlns:fo": "urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0",
            "xmlns:xlink": "http://www.w3.org/1999/xlink",
            "xmlns:dc": "http://purl.org/dc/elements/1.1/",
            "xmlns:meta": "urn:oasis:names:tc:opendocument:xmlns:meta:1.0",
            "xmlns:number": "urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0",
            "xmlns:presentation": "urn:oasis:names:tc:opendocument:xmlns:presentation:1.0",
            "xmlns:svg": "urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0",
            "xmlns:chart": "urn:oasis:names:tc:opendocument:xmlns:chart:1.0",
            "xmlns:dr3d": "urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0",
            "xmlns:math": "http://www.w3.org/1998/Math/MathML",
            "xmlns:form": "urn:oasis:names:tc:opendocument:xmlns:form:1.0",
            "xmlns:script": "urn:oasis:names:tc:opendocument:xmlns:script:1.0",
            "xmlns:ooo": "http://openoffice.org/2004/office",
            "xmlns:ooow": "http://openoffice.org/2004/writer",
            "xmlns:oooc": "http://openoffice.org/2004/calc",
            "xmlns:dom": "http://www.w3.org/2001/xml-events",
            "xmlns:xforms": "http://www.w3.org/2002/xforms",
            "xmlns:xsd": "http://www.w3.org/2001/XMLSchema",
            "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance",
            "xmlns:sheet": "urn:oasis:names:tc:opendocument:sh33tjs:1.0",
            "xmlns:rpt": "http://openoffice.org/2005/report",
            "xmlns:of": "urn:oasis:names:tc:opendocument:xmlns:of:1.2",
            "xmlns:xhtml": "http://www.w3.org/1999/xhtml",
            "xmlns:grddl": "http://www.w3.org/2003/g/data-view#",
            "xmlns:tableooo": "http://openoffice.org/2009/table",
            "xmlns:drawooo": "http://openoffice.org/2010/draw",
            "xmlns:calcext": "urn:org:documentfoundation:names:experimental:calc:xmlns:calcext:1.0",
            "xmlns:loext": "urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0",
            "xmlns:field": "urn:openoffice:names:experimental:ooo-ms-interop:xmlns:field:1.0",
            "xmlns:formx": "urn:openoffice:names:experimental:ooxml-odf-interop:xmlns:form:1.0",
            "xmlns:css3t": "http://www.w3.org/TR/css3-text/",
            "office:version": "1.2"
          });
          var fods = wxt_helper({
            "xmlns:config": "urn:oasis:names:tc:opendocument:xmlns:config:1.0",
            "office:mimetype": "application/vnd.oasis.opendocument.spreadsheet"
          });
          if (opts.bookType == "fods") {
            o.push("<office:document" + attr + fods + ">\n");
            o.push(write_meta_ods().replace(/office:document-meta/g, "office:meta"));
          } else
            o.push("<office:document-content" + attr + ">\n");
          write_automatic_styles_ods(o, wb);
          o.push("  <office:body>\n");
          o.push("    <office:spreadsheet>\n");
          for (var i = 0; i != wb.SheetNames.length; ++i)
            o.push(write_ws2(wb.Sheets[wb.SheetNames[i]], wb, i, opts));
          o.push("    </office:spreadsheet>\n");
          o.push("  </office:body>\n");
          if (opts.bookType == "fods")
            o.push("</office:document>");
          else
            o.push("</office:document-content>");
          return o.join("");
        };
      }();
      function write_ods(wb, opts) {
        if (opts.bookType == "fods")
          return write_content_ods(wb, opts);
        var zip = zip_new();
        var f = "";
        var manifest = [];
        var rdf = [];
        f = "mimetype";
        zip_add_file(zip, f, "application/vnd.oasis.opendocument.spreadsheet");
        f = "content.xml";
        zip_add_file(zip, f, write_content_ods(wb, opts));
        manifest.push([f, "text/xml"]);
        rdf.push([f, "ContentFile"]);
        f = "styles.xml";
        zip_add_file(zip, f, write_styles_ods(wb, opts));
        manifest.push([f, "text/xml"]);
        rdf.push([f, "StylesFile"]);
        f = "meta.xml";
        zip_add_file(zip, f, XML_HEADER + write_meta_ods());
        manifest.push([f, "text/xml"]);
        rdf.push([f, "MetadataFile"]);
        f = "manifest.rdf";
        zip_add_file(zip, f, write_rdf(
          rdf
          /*, opts*/
        ));
        manifest.push([f, "application/rdf+xml"]);
        f = "META-INF/manifest.xml";
        zip_add_file(zip, f, write_manifest(
          manifest
          /*, opts*/
        ));
        return zip;
      }
      function u8_to_dataview(array) {
        return new DataView(array.buffer, array.byteOffset, array.byteLength);
      }
      function u8str(u8) {
        return typeof TextDecoder != "undefined" ? new TextDecoder().decode(u8) : utf8read(a2s(u8));
      }
      function stru8(str) {
        return typeof TextEncoder != "undefined" ? new TextEncoder().encode(str) : s2a(utf8write(str));
      }
      function u8contains(body, search) {
        outer:
          for (var L = 0; L <= body.length - search.length; ++L) {
            for (var j = 0; j < search.length; ++j)
              if (body[L + j] != search[j])
                continue outer;
            return true;
          }
        return false;
      }
      function u8concat(u8a) {
        var len = u8a.reduce(function(acc, x) {
          return acc + x.length;
        }, 0);
        var out = new Uint8Array(len);
        var off = 0;
        u8a.forEach(function(u8) {
          out.set(u8, off);
          off += u8.length;
        });
        return out;
      }
      function popcnt(x) {
        x -= x >> 1 & 1431655765;
        x = (x & 858993459) + (x >> 2 & 858993459);
        return (x + (x >> 4) & 252645135) * 16843009 >>> 24;
      }
      function readDecimal128LE(buf, offset) {
        var exp = (buf[offset + 15] & 127) << 7 | buf[offset + 14] >> 1;
        var mantissa = buf[offset + 14] & 1;
        for (var j = offset + 13; j >= offset; --j)
          mantissa = mantissa * 256 + buf[j];
        return (buf[offset + 15] & 128 ? -mantissa : mantissa) * Math.pow(10, exp - 6176);
      }
      function writeDecimal128LE(buf, offset, value2) {
        var exp = Math.floor(value2 == 0 ? 0 : Math.LOG10E * Math.log(Math.abs(value2))) + 6176 - 20;
        var mantissa = value2 / Math.pow(10, exp - 6176);
        buf[offset + 15] |= exp >> 7;
        buf[offset + 14] |= (exp & 127) << 1;
        for (var i = 0; mantissa >= 1; ++i, mantissa /= 256)
          buf[offset + i] = mantissa & 255;
        buf[offset + 15] |= value2 >= 0 ? 0 : 128;
      }
      function parse_varint49(buf, ptr) {
        var l = ptr ? ptr[0] : 0;
        var usz = buf[l] & 127;
        varint:
          if (buf[l++] >= 128) {
            usz |= (buf[l] & 127) << 7;
            if (buf[l++] < 128)
              break varint;
            usz |= (buf[l] & 127) << 14;
            if (buf[l++] < 128)
              break varint;
            usz |= (buf[l] & 127) << 21;
            if (buf[l++] < 128)
              break varint;
            usz += (buf[l] & 127) * Math.pow(2, 28);
            ++l;
            if (buf[l++] < 128)
              break varint;
            usz += (buf[l] & 127) * Math.pow(2, 35);
            ++l;
            if (buf[l++] < 128)
              break varint;
            usz += (buf[l] & 127) * Math.pow(2, 42);
            ++l;
            if (buf[l++] < 128)
              break varint;
          }
        if (ptr)
          ptr[0] = l;
        return usz;
      }
      function write_varint49(v) {
        var usz = new Uint8Array(7);
        usz[0] = v & 127;
        var L = 1;
        sz:
          if (v > 127) {
            usz[L - 1] |= 128;
            usz[L] = v >> 7 & 127;
            ++L;
            if (v <= 16383)
              break sz;
            usz[L - 1] |= 128;
            usz[L] = v >> 14 & 127;
            ++L;
            if (v <= 2097151)
              break sz;
            usz[L - 1] |= 128;
            usz[L] = v >> 21 & 127;
            ++L;
            if (v <= 268435455)
              break sz;
            usz[L - 1] |= 128;
            usz[L] = v / 256 >>> 21 & 127;
            ++L;
            if (v <= 34359738367)
              break sz;
            usz[L - 1] |= 128;
            usz[L] = v / 65536 >>> 21 & 127;
            ++L;
            if (v <= 4398046511103)
              break sz;
            usz[L - 1] |= 128;
            usz[L] = v / 16777216 >>> 21 & 127;
            ++L;
          }
        return usz.slice(0, L);
      }
      function varint_to_i32(buf) {
        var l = 0, i32 = buf[l] & 127;
        varint:
          if (buf[l++] >= 128) {
            i32 |= (buf[l] & 127) << 7;
            if (buf[l++] < 128)
              break varint;
            i32 |= (buf[l] & 127) << 14;
            if (buf[l++] < 128)
              break varint;
            i32 |= (buf[l] & 127) << 21;
            if (buf[l++] < 128)
              break varint;
            i32 |= (buf[l] & 127) << 28;
          }
        return i32;
      }
      function parse_shallow(buf) {
        var out = [], ptr = [0];
        while (ptr[0] < buf.length) {
          var off = ptr[0];
          var num = parse_varint49(buf, ptr);
          var type = num & 7;
          num = Math.floor(num / 8);
          var len = 0;
          var res;
          if (num == 0)
            break;
          switch (type) {
            case 0:
              {
                var l = ptr[0];
                while (buf[ptr[0]++] >= 128)
                  ;
                res = buf.slice(l, ptr[0]);
              }
              break;
            case 5:
              len = 4;
              res = buf.slice(ptr[0], ptr[0] + len);
              ptr[0] += len;
              break;
            case 1:
              len = 8;
              res = buf.slice(ptr[0], ptr[0] + len);
              ptr[0] += len;
              break;
            case 2:
              len = parse_varint49(buf, ptr);
              res = buf.slice(ptr[0], ptr[0] + len);
              ptr[0] += len;
              break;
            case 3:
            case 4:
            default:
              throw new Error("PB Type ".concat(type, " for Field ").concat(num, " at offset ").concat(off));
          }
          var v = { data: res, type };
          if (out[num] == null)
            out[num] = [v];
          else
            out[num].push(v);
        }
        return out;
      }
      function write_shallow(proto) {
        var out = [];
        proto.forEach(function(field, idx) {
          field.forEach(function(item) {
            if (!item.data)
              return;
            out.push(write_varint49(idx * 8 + item.type));
            if (item.type == 2)
              out.push(write_varint49(item.data.length));
            out.push(item.data);
          });
        });
        return u8concat(out);
      }
      function mappa(data, cb) {
        return (data == null ? void 0 : data.map(function(d) {
          return cb(d.data);
        })) || [];
      }
      function parse_iwa_file(buf) {
        var _a;
        var out = [], ptr = [0];
        while (ptr[0] < buf.length) {
          var len = parse_varint49(buf, ptr);
          var ai = parse_shallow(buf.slice(ptr[0], ptr[0] + len));
          ptr[0] += len;
          var res = {
            id: varint_to_i32(ai[1][0].data),
            messages: []
          };
          ai[2].forEach(function(b) {
            var mi = parse_shallow(b.data);
            var fl = varint_to_i32(mi[3][0].data);
            res.messages.push({
              meta: mi,
              data: buf.slice(ptr[0], ptr[0] + fl)
            });
            ptr[0] += fl;
          });
          if ((_a = ai[3]) == null ? void 0 : _a[0])
            res.merge = varint_to_i32(ai[3][0].data) >>> 0 > 0;
          out.push(res);
        }
        return out;
      }
      function write_iwa_file(ias) {
        var bufs = [];
        ias.forEach(function(ia) {
          var ai = [];
          ai[1] = [{ data: write_varint49(ia.id), type: 0 }];
          ai[2] = [];
          if (ia.merge != null)
            ai[3] = [{ data: write_varint49(+!!ia.merge), type: 0 }];
          var midata = [];
          ia.messages.forEach(function(mi) {
            midata.push(mi.data);
            mi.meta[3] = [{ type: 0, data: write_varint49(mi.data.length) }];
            ai[2].push({ data: write_shallow(mi.meta), type: 2 });
          });
          var aipayload = write_shallow(ai);
          bufs.push(write_varint49(aipayload.length));
          bufs.push(aipayload);
          midata.forEach(function(mid) {
            return bufs.push(mid);
          });
        });
        return u8concat(bufs);
      }
      function parse_snappy_chunk(type, buf) {
        if (type != 0)
          throw new Error("Unexpected Snappy chunk type ".concat(type));
        var ptr = [0];
        var usz = parse_varint49(buf, ptr);
        var chunks = [];
        while (ptr[0] < buf.length) {
          var tag = buf[ptr[0]] & 3;
          if (tag == 0) {
            var len = buf[ptr[0]++] >> 2;
            if (len < 60)
              ++len;
            else {
              var c = len - 59;
              len = buf[ptr[0]];
              if (c > 1)
                len |= buf[ptr[0] + 1] << 8;
              if (c > 2)
                len |= buf[ptr[0] + 2] << 16;
              if (c > 3)
                len |= buf[ptr[0] + 3] << 24;
              len >>>= 0;
              len++;
              ptr[0] += c;
            }
            chunks.push(buf.slice(ptr[0], ptr[0] + len));
            ptr[0] += len;
            continue;
          } else {
            var offset = 0, length = 0;
            if (tag == 1) {
              length = (buf[ptr[0]] >> 2 & 7) + 4;
              offset = (buf[ptr[0]++] & 224) << 3;
              offset |= buf[ptr[0]++];
            } else {
              length = (buf[ptr[0]++] >> 2) + 1;
              if (tag == 2) {
                offset = buf[ptr[0]] | buf[ptr[0] + 1] << 8;
                ptr[0] += 2;
              } else {
                offset = (buf[ptr[0]] | buf[ptr[0] + 1] << 8 | buf[ptr[0] + 2] << 16 | buf[ptr[0] + 3] << 24) >>> 0;
                ptr[0] += 4;
              }
            }
            chunks = [u8concat(chunks)];
            if (offset == 0)
              throw new Error("Invalid offset 0");
            if (offset > chunks[0].length)
              throw new Error("Invalid offset beyond length");
            if (length >= offset) {
              chunks.push(chunks[0].slice(-offset));
              length -= offset;
              while (length >= chunks[chunks.length - 1].length) {
                chunks.push(chunks[chunks.length - 1]);
                length -= chunks[chunks.length - 1].length;
              }
            }
            chunks.push(chunks[0].slice(-offset, -offset + length));
          }
        }
        var o = u8concat(chunks);
        if (o.length != usz)
          throw new Error("Unexpected length: ".concat(o.length, " != ").concat(usz));
        return o;
      }
      function decompress_iwa_file(buf) {
        var out = [];
        var l = 0;
        while (l < buf.length) {
          var t3 = buf[l++];
          var len = buf[l] | buf[l + 1] << 8 | buf[l + 2] << 16;
          l += 3;
          out.push(parse_snappy_chunk(t3, buf.slice(l, l + len)));
          l += len;
        }
        if (l !== buf.length)
          throw new Error("data is not a valid framed stream!");
        return u8concat(out);
      }
      function compress_iwa_file(buf) {
        var out = [];
        var l = 0;
        while (l < buf.length) {
          var c = Math.min(buf.length - l, 268435455);
          var frame = new Uint8Array(4);
          out.push(frame);
          var usz = write_varint49(c);
          var L = usz.length;
          out.push(usz);
          if (c <= 60) {
            L++;
            out.push(new Uint8Array([c - 1 << 2]));
          } else if (c <= 256) {
            L += 2;
            out.push(new Uint8Array([240, c - 1 & 255]));
          } else if (c <= 65536) {
            L += 3;
            out.push(new Uint8Array([244, c - 1 & 255, c - 1 >> 8 & 255]));
          } else if (c <= 16777216) {
            L += 4;
            out.push(new Uint8Array([248, c - 1 & 255, c - 1 >> 8 & 255, c - 1 >> 16 & 255]));
          } else if (c <= 4294967296) {
            L += 5;
            out.push(new Uint8Array([252, c - 1 & 255, c - 1 >> 8 & 255, c - 1 >> 16 & 255, c - 1 >>> 24 & 255]));
          }
          out.push(buf.slice(l, l + c));
          L += c;
          frame[0] = 0;
          frame[1] = L & 255;
          frame[2] = L >> 8 & 255;
          frame[3] = L >> 16 & 255;
          l += c;
        }
        return u8concat(out);
      }
      function parse_old_storage(buf, sst, rsst, v) {
        var dv = u8_to_dataview(buf);
        var flags = dv.getUint32(4, true);
        var data_offset = (v > 1 ? 12 : 8) + popcnt(flags & (v > 1 ? 3470 : 398)) * 4;
        var ridx = -1, sidx = -1, ieee = NaN, dt = new Date(2001, 0, 1);
        if (flags & 512) {
          ridx = dv.getUint32(data_offset, true);
          data_offset += 4;
        }
        data_offset += popcnt(flags & (v > 1 ? 12288 : 4096)) * 4;
        if (flags & 16) {
          sidx = dv.getUint32(data_offset, true);
          data_offset += 4;
        }
        if (flags & 32) {
          ieee = dv.getFloat64(data_offset, true);
          data_offset += 8;
        }
        if (flags & 64) {
          dt.setTime(dt.getTime() + dv.getFloat64(data_offset, true) * 1e3);
          data_offset += 8;
        }
        var ret;
        switch (buf[2]) {
          case 0:
            break;
          case 2:
            ret = { t: "n", v: ieee };
            break;
          case 3:
            ret = { t: "s", v: sst[sidx] };
            break;
          case 5:
            ret = { t: "d", v: dt };
            break;
          case 6:
            ret = { t: "b", v: ieee > 0 };
            break;
          case 7:
            ret = { t: "n", v: ieee / 86400 };
            break;
          case 8:
            ret = { t: "e", v: 0 };
            break;
          case 9:
            {
              if (ridx > -1)
                ret = { t: "s", v: rsst[ridx] };
              else if (sidx > -1)
                ret = { t: "s", v: sst[sidx] };
              else if (!isNaN(ieee))
                ret = { t: "n", v: ieee };
              else
                throw new Error("Unsupported cell type ".concat(buf.slice(0, 4)));
            }
            break;
          default:
            throw new Error("Unsupported cell type ".concat(buf.slice(0, 4)));
        }
        return ret;
      }
      function parse_new_storage(buf, sst, rsst) {
        var dv = u8_to_dataview(buf);
        var flags = dv.getUint32(8, true);
        var data_offset = 12;
        var ridx = -1, sidx = -1, d128 = NaN, ieee = NaN, dt = new Date(2001, 0, 1);
        if (flags & 1) {
          d128 = readDecimal128LE(buf, data_offset);
          data_offset += 16;
        }
        if (flags & 2) {
          ieee = dv.getFloat64(data_offset, true);
          data_offset += 8;
        }
        if (flags & 4) {
          dt.setTime(dt.getTime() + dv.getFloat64(data_offset, true) * 1e3);
          data_offset += 8;
        }
        if (flags & 8) {
          sidx = dv.getUint32(data_offset, true);
          data_offset += 4;
        }
        if (flags & 16) {
          ridx = dv.getUint32(data_offset, true);
          data_offset += 4;
        }
        var ret;
        switch (buf[1]) {
          case 0:
            break;
          case 2:
            ret = { t: "n", v: d128 };
            break;
          case 3:
            ret = { t: "s", v: sst[sidx] };
            break;
          case 5:
            ret = { t: "d", v: dt };
            break;
          case 6:
            ret = { t: "b", v: ieee > 0 };
            break;
          case 7:
            ret = { t: "n", v: ieee / 86400 };
            break;
          case 8:
            ret = { t: "e", v: 0 };
            break;
          case 9:
            {
              if (ridx > -1)
                ret = { t: "s", v: rsst[ridx] };
              else
                throw new Error("Unsupported cell type ".concat(buf[1], " : ").concat(flags & 31, " : ").concat(buf.slice(0, 4)));
            }
            break;
          case 10:
            ret = { t: "n", v: d128 };
            break;
          default:
            throw new Error("Unsupported cell type ".concat(buf[1], " : ").concat(flags & 31, " : ").concat(buf.slice(0, 4)));
        }
        return ret;
      }
      function write_new_storage(cell, sst) {
        var out = new Uint8Array(32), dv = u8_to_dataview(out), l = 12, flags = 0;
        out[0] = 5;
        switch (cell.t) {
          case "n":
            out[1] = 2;
            writeDecimal128LE(out, l, cell.v);
            flags |= 1;
            l += 16;
            break;
          case "b":
            out[1] = 6;
            dv.setFloat64(l, cell.v ? 1 : 0, true);
            flags |= 2;
            l += 8;
            break;
          case "s":
            if (sst.indexOf(cell.v) == -1)
              throw new Error("Value ".concat(cell.v, " missing from SST!"));
            out[1] = 3;
            dv.setUint32(l, sst.indexOf(cell.v), true);
            flags |= 8;
            l += 4;
            break;
          default:
            throw "unsupported cell type " + cell.t;
        }
        dv.setUint32(8, flags, true);
        return out.slice(0, l);
      }
      function write_old_storage(cell, sst) {
        var out = new Uint8Array(32), dv = u8_to_dataview(out), l = 12, flags = 0;
        out[0] = 3;
        switch (cell.t) {
          case "n":
            out[2] = 2;
            dv.setFloat64(l, cell.v, true);
            flags |= 32;
            l += 8;
            break;
          case "b":
            out[2] = 6;
            dv.setFloat64(l, cell.v ? 1 : 0, true);
            flags |= 32;
            l += 8;
            break;
          case "s":
            if (sst.indexOf(cell.v) == -1)
              throw new Error("Value ".concat(cell.v, " missing from SST!"));
            out[2] = 3;
            dv.setUint32(l, sst.indexOf(cell.v), true);
            flags |= 16;
            l += 4;
            break;
          default:
            throw "unsupported cell type " + cell.t;
        }
        dv.setUint32(4, flags, true);
        return out.slice(0, l);
      }
      function parse_cell_storage(buf, sst, rsst) {
        switch (buf[0]) {
          case 0:
          case 1:
          case 2:
          case 3:
            return parse_old_storage(buf, sst, rsst, buf[0]);
          case 5:
            return parse_new_storage(buf, sst, rsst);
          default:
            throw new Error("Unsupported payload version ".concat(buf[0]));
        }
      }
      function parse_TSP_Reference(buf) {
        var pb = parse_shallow(buf);
        return parse_varint49(pb[1][0].data);
      }
      function write_TSP_Reference(idx) {
        var out = [];
        out[1] = [{ type: 0, data: write_varint49(idx) }];
        return write_shallow(out);
      }
      function parse_TST_TableDataList(M, root2) {
        var pb = parse_shallow(root2.data);
        var type = varint_to_i32(pb[1][0].data);
        var entries = pb[3];
        var data = [];
        (entries || []).forEach(function(entry) {
          var le = parse_shallow(entry.data);
          var key = varint_to_i32(le[1][0].data) >>> 0;
          switch (type) {
            case 1:
              data[key] = u8str(le[3][0].data);
              break;
            case 8:
              {
                var rt = M[parse_TSP_Reference(le[9][0].data)][0];
                var rtp = parse_shallow(rt.data);
                var rtpref = M[parse_TSP_Reference(rtp[1][0].data)][0];
                var mtype = varint_to_i32(rtpref.meta[1][0].data);
                if (mtype != 2001)
                  throw new Error("2000 unexpected reference to ".concat(mtype));
                var tswpsa = parse_shallow(rtpref.data);
                data[key] = tswpsa[3].map(function(x) {
                  return u8str(x.data);
                }).join("");
              }
              break;
          }
        });
        return data;
      }
      function parse_TST_TileRowInfo(u8, type) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n;
        var pb = parse_shallow(u8);
        var R = varint_to_i32(pb[1][0].data) >>> 0;
        var cnt = varint_to_i32(pb[2][0].data) >>> 0;
        var wide_offsets = ((_b = (_a = pb[8]) == null ? void 0 : _a[0]) == null ? void 0 : _b.data) && varint_to_i32(pb[8][0].data) > 0 || false;
        var used_storage_u8, used_storage;
        if (((_d = (_c = pb[7]) == null ? void 0 : _c[0]) == null ? void 0 : _d.data) && type != 0) {
          used_storage_u8 = (_f = (_e = pb[7]) == null ? void 0 : _e[0]) == null ? void 0 : _f.data;
          used_storage = (_h = (_g = pb[6]) == null ? void 0 : _g[0]) == null ? void 0 : _h.data;
        } else if (((_j = (_i = pb[4]) == null ? void 0 : _i[0]) == null ? void 0 : _j.data) && type != 1) {
          used_storage_u8 = (_l = (_k = pb[4]) == null ? void 0 : _k[0]) == null ? void 0 : _l.data;
          used_storage = (_n = (_m = pb[3]) == null ? void 0 : _m[0]) == null ? void 0 : _n.data;
        } else
          throw "NUMBERS Tile missing ".concat(type, " cell storage");
        var width = wide_offsets ? 4 : 1;
        var used_storage_offsets = u8_to_dataview(used_storage_u8);
        var offsets = [];
        for (var C = 0; C < used_storage_u8.length / 2; ++C) {
          var off = used_storage_offsets.getUint16(C * 2, true);
          if (off < 65535)
            offsets.push([C, off]);
        }
        if (offsets.length != cnt)
          throw "Expected ".concat(cnt, " cells, found ").concat(offsets.length);
        var cells = [];
        for (C = 0; C < offsets.length - 1; ++C)
          cells[offsets[C][0]] = used_storage.subarray(offsets[C][1] * width, offsets[C + 1][1] * width);
        if (offsets.length >= 1)
          cells[offsets[offsets.length - 1][0]] = used_storage.subarray(offsets[offsets.length - 1][1] * width);
        return { R, cells };
      }
      function parse_TST_Tile(M, root2) {
        var _a;
        var pb = parse_shallow(root2.data);
        var storage = ((_a = pb == null ? void 0 : pb[7]) == null ? void 0 : _a[0]) ? varint_to_i32(pb[7][0].data) >>> 0 > 0 ? 1 : 0 : -1;
        var ri = mappa(pb[5], function(u8) {
          return parse_TST_TileRowInfo(u8, storage);
        });
        return {
          nrows: varint_to_i32(pb[4][0].data) >>> 0,
          data: ri.reduce(function(acc, x) {
            if (!acc[x.R])
              acc[x.R] = [];
            x.cells.forEach(function(cell, C) {
              if (acc[x.R][C])
                throw new Error("Duplicate cell r=".concat(x.R, " c=").concat(C));
              acc[x.R][C] = cell;
            });
            return acc;
          }, [])
        };
      }
      function parse_TST_TableModelArchive(M, root2, ws) {
        var _a;
        var pb = parse_shallow(root2.data);
        var range = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
        range.e.r = (varint_to_i32(pb[6][0].data) >>> 0) - 1;
        if (range.e.r < 0)
          throw new Error("Invalid row varint ".concat(pb[6][0].data));
        range.e.c = (varint_to_i32(pb[7][0].data) >>> 0) - 1;
        if (range.e.c < 0)
          throw new Error("Invalid col varint ".concat(pb[7][0].data));
        ws["!ref"] = encode_range(range);
        var store = parse_shallow(pb[4][0].data);
        var sst = parse_TST_TableDataList(M, M[parse_TSP_Reference(store[4][0].data)][0]);
        var rsst = ((_a = store[17]) == null ? void 0 : _a[0]) ? parse_TST_TableDataList(M, M[parse_TSP_Reference(store[17][0].data)][0]) : [];
        var tile = parse_shallow(store[3][0].data);
        var _R = 0;
        tile[1].forEach(function(t3) {
          var tl = parse_shallow(t3.data);
          var ref = M[parse_TSP_Reference(tl[2][0].data)][0];
          var mtype = varint_to_i32(ref.meta[1][0].data);
          if (mtype != 6002)
            throw new Error("6001 unexpected reference to ".concat(mtype));
          var _tile = parse_TST_Tile(M, ref);
          _tile.data.forEach(function(row, R) {
            row.forEach(function(buf, C) {
              var addr = encode_cell({ r: _R + R, c: C });
              var res = parse_cell_storage(buf, sst, rsst);
              if (res)
                ws[addr] = res;
            });
          });
          _R += _tile.nrows;
        });
      }
      function parse_TST_TableInfoArchive(M, root2) {
        var pb = parse_shallow(root2.data);
        var out = { "!ref": "A1" };
        var tableref = M[parse_TSP_Reference(pb[2][0].data)];
        var mtype = varint_to_i32(tableref[0].meta[1][0].data);
        if (mtype != 6001)
          throw new Error("6000 unexpected reference to ".concat(mtype));
        parse_TST_TableModelArchive(M, tableref[0], out);
        return out;
      }
      function parse_TN_SheetArchive(M, root2) {
        var _a;
        var pb = parse_shallow(root2.data);
        var out = {
          name: ((_a = pb[1]) == null ? void 0 : _a[0]) ? u8str(pb[1][0].data) : "",
          sheets: []
        };
        var shapeoffs = mappa(pb[2], parse_TSP_Reference);
        shapeoffs.forEach(function(off) {
          M[off].forEach(function(m) {
            var mtype = varint_to_i32(m.meta[1][0].data);
            if (mtype == 6e3)
              out.sheets.push(parse_TST_TableInfoArchive(M, m));
          });
        });
        return out;
      }
      function parse_TN_DocumentArchive(M, root2) {
        var out = book_new();
        var pb = parse_shallow(root2.data);
        var sheetoffs = mappa(pb[1], parse_TSP_Reference);
        sheetoffs.forEach(function(off) {
          M[off].forEach(function(m) {
            var mtype = varint_to_i32(m.meta[1][0].data);
            if (mtype == 2) {
              var root22 = parse_TN_SheetArchive(M, m);
              root22.sheets.forEach(function(sheet, idx) {
                book_append_sheet(out, sheet, idx == 0 ? root22.name : root22.name + "_" + idx, true);
              });
            }
          });
        });
        if (out.SheetNames.length == 0)
          throw new Error("Empty NUMBERS file");
        return out;
      }
      function parse_numbers_iwa(cfb) {
        var _a, _b, _c, _d;
        var M = {}, indices = [];
        cfb.FullPaths.forEach(function(p) {
          if (p.match(/\.iwpv2/))
            throw new Error("Unsupported password protection");
        });
        cfb.FileIndex.forEach(function(s) {
          if (!s.name.match(/\.iwa$/))
            return;
          var o;
          try {
            o = decompress_iwa_file(s.content);
          } catch (e) {
            return console.log("?? " + s.content.length + " " + (e.message || e));
          }
          var packets;
          try {
            packets = parse_iwa_file(o);
          } catch (e) {
            return console.log("## " + (e.message || e));
          }
          packets.forEach(function(packet) {
            M[packet.id] = packet.messages;
            indices.push(packet.id);
          });
        });
        if (!indices.length)
          throw new Error("File has no messages");
        var docroot = ((_d = (_c = (_b = (_a = M == null ? void 0 : M[1]) == null ? void 0 : _a[0]) == null ? void 0 : _b.meta) == null ? void 0 : _c[1]) == null ? void 0 : _d[0].data) && varint_to_i32(M[1][0].meta[1][0].data) == 1 && M[1][0];
        if (!docroot)
          indices.forEach(function(idx) {
            M[idx].forEach(function(iwam) {
              var mtype = varint_to_i32(iwam.meta[1][0].data) >>> 0;
              if (mtype == 1) {
                if (!docroot)
                  docroot = iwam;
                else
                  throw new Error("Document has multiple roots");
              }
            });
          });
        if (!docroot)
          throw new Error("Cannot find Document root");
        return parse_TN_DocumentArchive(M, docroot);
      }
      function write_tile_row(tri, data, SST) {
        var _a, _b, _c, _d;
        if (!((_a = tri[6]) == null ? void 0 : _a[0]) || !((_b = tri[7]) == null ? void 0 : _b[0]))
          throw "Mutation only works on post-BNC storages!";
        var wide_offsets = ((_d = (_c = tri[8]) == null ? void 0 : _c[0]) == null ? void 0 : _d.data) && varint_to_i32(tri[8][0].data) > 0 || false;
        if (wide_offsets)
          throw "Math only works with normal offsets";
        var cnt = 0;
        var dv = u8_to_dataview(tri[7][0].data), last_offset = 0, cell_storage = [];
        var _dv = u8_to_dataview(tri[4][0].data), _last_offset = 0, _cell_storage = [];
        for (var C = 0; C < data.length; ++C) {
          if (data[C] == null) {
            dv.setUint16(C * 2, 65535, true);
            _dv.setUint16(C * 2, 65535);
            continue;
          }
          dv.setUint16(C * 2, last_offset, true);
          _dv.setUint16(C * 2, _last_offset, true);
          var celload, _celload;
          switch (typeof data[C]) {
            case "string":
              celload = write_new_storage({ t: "s", v: data[C] }, SST);
              _celload = write_old_storage({ t: "s", v: data[C] }, SST);
              break;
            case "number":
              celload = write_new_storage({ t: "n", v: data[C] }, SST);
              _celload = write_old_storage({ t: "n", v: data[C] }, SST);
              break;
            case "boolean":
              celload = write_new_storage({ t: "b", v: data[C] }, SST);
              _celload = write_old_storage({ t: "b", v: data[C] }, SST);
              break;
            default:
              throw new Error("Unsupported value " + data[C]);
          }
          cell_storage.push(celload);
          last_offset += celload.length;
          _cell_storage.push(_celload);
          _last_offset += _celload.length;
          ++cnt;
        }
        tri[2][0].data = write_varint49(cnt);
        for (; C < tri[7][0].data.length / 2; ++C) {
          dv.setUint16(C * 2, 65535, true);
          _dv.setUint16(C * 2, 65535, true);
        }
        tri[6][0].data = u8concat(cell_storage);
        tri[3][0].data = u8concat(_cell_storage);
        return cnt;
      }
      function write_numbers_iwa(wb, opts) {
        if (!opts || !opts.numbers)
          throw new Error("Must pass a `numbers` option -- check the README");
        var ws = wb.Sheets[wb.SheetNames[0]];
        if (wb.SheetNames.length > 1)
          console.error("The Numbers writer currently writes only the first table");
        var range = decode_range(ws["!ref"]);
        range.s.r = range.s.c = 0;
        var trunc = false;
        if (range.e.c > 9) {
          trunc = true;
          range.e.c = 9;
        }
        if (range.e.r > 49) {
          trunc = true;
          range.e.r = 49;
        }
        if (trunc)
          console.error("The Numbers writer is currently limited to ".concat(encode_range(range)));
        var data = sheet_to_json(ws, { range, header: 1 });
        var SST = ["~Sh33tJ5~"];
        data.forEach(function(row) {
          return row.forEach(function(cell) {
            if (typeof cell == "string")
              SST.push(cell);
          });
        });
        var dependents = {};
        var indices = [];
        var cfb = CFB.read(opts.numbers, { type: "base64" });
        cfb.FileIndex.map(function(fi, idx) {
          return [fi, cfb.FullPaths[idx]];
        }).forEach(function(row) {
          var fi = row[0], fp = row[1];
          if (fi.type != 2)
            return;
          if (!fi.name.match(/\.iwa/))
            return;
          var old_content = fi.content;
          var raw1 = decompress_iwa_file(old_content);
          var x2 = parse_iwa_file(raw1);
          x2.forEach(function(packet2) {
            indices.push(packet2.id);
            dependents[packet2.id] = { deps: [], location: fp, type: varint_to_i32(packet2.messages[0].meta[1][0].data) };
          });
        });
        indices.sort(function(x2, y2) {
          return x2 - y2;
        });
        var indices_varint = indices.filter(function(x2) {
          return x2 > 1;
        }).map(function(x2) {
          return [x2, write_varint49(x2)];
        });
        cfb.FileIndex.map(function(fi, idx) {
          return [fi, cfb.FullPaths[idx]];
        }).forEach(function(row) {
          var fi = row[0], fp = row[1];
          if (!fi.name.match(/\.iwa/))
            return;
          var x2 = parse_iwa_file(decompress_iwa_file(fi.content));
          x2.forEach(function(ia) {
            ia.messages.forEach(function(m) {
              indices_varint.forEach(function(ivi) {
                if (ia.messages.some(function(mess) {
                  return varint_to_i32(mess.meta[1][0].data) != 11006 && u8contains(mess.data, ivi[1]);
                })) {
                  dependents[ivi[0]].deps.push(ia.id);
                }
              });
            });
          });
        });
        function get_unique_msgid() {
          for (var i = 927262; i < 2e6; ++i)
            if (!dependents[i])
              return i;
          throw new Error("Too many messages");
        }
        var entry = CFB.find(cfb, dependents[1].location);
        var x = parse_iwa_file(decompress_iwa_file(entry.content));
        var docroot;
        for (var xi = 0; xi < x.length; ++xi) {
          var packet = x[xi];
          if (packet.id == 1)
            docroot = packet;
        }
        var sheetrootref = parse_TSP_Reference(parse_shallow(docroot.messages[0].data)[1][0].data);
        entry = CFB.find(cfb, dependents[sheetrootref].location);
        x = parse_iwa_file(decompress_iwa_file(entry.content));
        for (xi = 0; xi < x.length; ++xi) {
          packet = x[xi];
          if (packet.id == sheetrootref)
            docroot = packet;
        }
        sheetrootref = parse_TSP_Reference(parse_shallow(docroot.messages[0].data)[2][0].data);
        entry = CFB.find(cfb, dependents[sheetrootref].location);
        x = parse_iwa_file(decompress_iwa_file(entry.content));
        for (xi = 0; xi < x.length; ++xi) {
          packet = x[xi];
          if (packet.id == sheetrootref)
            docroot = packet;
        }
        sheetrootref = parse_TSP_Reference(parse_shallow(docroot.messages[0].data)[2][0].data);
        entry = CFB.find(cfb, dependents[sheetrootref].location);
        x = parse_iwa_file(decompress_iwa_file(entry.content));
        for (xi = 0; xi < x.length; ++xi) {
          packet = x[xi];
          if (packet.id == sheetrootref)
            docroot = packet;
        }
        var pb = parse_shallow(docroot.messages[0].data);
        {
          pb[6][0].data = write_varint49(range.e.r + 1);
          pb[7][0].data = write_varint49(range.e.c + 1);
          var cruidsref = parse_TSP_Reference(pb[46][0].data);
          var oldbucket = CFB.find(cfb, dependents[cruidsref].location);
          var _x = parse_iwa_file(decompress_iwa_file(oldbucket.content));
          {
            for (var j = 0; j < _x.length; ++j) {
              if (_x[j].id == cruidsref)
                break;
            }
            if (_x[j].id != cruidsref)
              throw "Bad ColumnRowUIDMapArchive";
            var cruids = parse_shallow(_x[j].messages[0].data);
            cruids[1] = [];
            cruids[2] = [], cruids[3] = [];
            for (var C = 0; C <= range.e.c; ++C) {
              var uuid = [];
              uuid[1] = uuid[2] = [{ type: 0, data: write_varint49(C + 420690) }];
              cruids[1].push({ type: 2, data: write_shallow(uuid) });
              cruids[2].push({ type: 0, data: write_varint49(C) });
              cruids[3].push({ type: 0, data: write_varint49(C) });
            }
            cruids[4] = [];
            cruids[5] = [], cruids[6] = [];
            for (var R = 0; R <= range.e.r; ++R) {
              uuid = [];
              uuid[1] = uuid[2] = [{ type: 0, data: write_varint49(R + 726270) }];
              cruids[4].push({ type: 2, data: write_shallow(uuid) });
              cruids[5].push({ type: 0, data: write_varint49(R) });
              cruids[6].push({ type: 0, data: write_varint49(R) });
            }
            _x[j].messages[0].data = write_shallow(cruids);
          }
          oldbucket.content = compress_iwa_file(write_iwa_file(_x));
          oldbucket.size = oldbucket.content.length;
          delete pb[46];
          var store = parse_shallow(pb[4][0].data);
          {
            store[7][0].data = write_varint49(range.e.r + 1);
            var row_headers = parse_shallow(store[1][0].data);
            var row_header_ref = parse_TSP_Reference(row_headers[2][0].data);
            oldbucket = CFB.find(cfb, dependents[row_header_ref].location);
            _x = parse_iwa_file(decompress_iwa_file(oldbucket.content));
            {
              if (_x[0].id != row_header_ref)
                throw "Bad HeaderStorageBucket";
              var base_bucket = parse_shallow(_x[0].messages[0].data);
              for (R = 0; R < data.length; ++R) {
                var _bucket = parse_shallow(base_bucket[2][0].data);
                _bucket[1][0].data = write_varint49(R);
                _bucket[4][0].data = write_varint49(data[R].length);
                base_bucket[2][R] = { type: base_bucket[2][0].type, data: write_shallow(_bucket) };
              }
              _x[0].messages[0].data = write_shallow(base_bucket);
            }
            oldbucket.content = compress_iwa_file(write_iwa_file(_x));
            oldbucket.size = oldbucket.content.length;
            var col_header_ref = parse_TSP_Reference(store[2][0].data);
            oldbucket = CFB.find(cfb, dependents[col_header_ref].location);
            _x = parse_iwa_file(decompress_iwa_file(oldbucket.content));
            {
              if (_x[0].id != col_header_ref)
                throw "Bad HeaderStorageBucket";
              base_bucket = parse_shallow(_x[0].messages[0].data);
              for (C = 0; C <= range.e.c; ++C) {
                _bucket = parse_shallow(base_bucket[2][0].data);
                _bucket[1][0].data = write_varint49(C);
                _bucket[4][0].data = write_varint49(range.e.r + 1);
                base_bucket[2][C] = { type: base_bucket[2][0].type, data: write_shallow(_bucket) };
              }
              _x[0].messages[0].data = write_shallow(base_bucket);
            }
            oldbucket.content = compress_iwa_file(write_iwa_file(_x));
            oldbucket.size = oldbucket.content.length;
            var sstref = parse_TSP_Reference(store[4][0].data);
            (function() {
              var sentry = CFB.find(cfb, dependents[sstref].location);
              var sx = parse_iwa_file(decompress_iwa_file(sentry.content));
              var sstroot;
              for (var sxi = 0; sxi < sx.length; ++sxi) {
                var packet2 = sx[sxi];
                if (packet2.id == sstref)
                  sstroot = packet2;
              }
              var sstdata = parse_shallow(sstroot.messages[0].data);
              {
                sstdata[3] = [];
                var newsst = [];
                SST.forEach(function(str, i) {
                  newsst[1] = [{ type: 0, data: write_varint49(i) }];
                  newsst[2] = [{ type: 0, data: write_varint49(1) }];
                  newsst[3] = [{ type: 2, data: stru8(str) }];
                  sstdata[3].push({ type: 2, data: write_shallow(newsst) });
                });
              }
              sstroot.messages[0].data = write_shallow(sstdata);
              var sy = write_iwa_file(sx);
              var raw32 = compress_iwa_file(sy);
              sentry.content = raw32;
              sentry.size = sentry.content.length;
            })();
            var tile = parse_shallow(store[3][0].data);
            {
              var t3 = tile[1][0];
              delete tile[2];
              var tl = parse_shallow(t3.data);
              {
                var tileref = parse_TSP_Reference(tl[2][0].data);
                (function() {
                  var tentry = CFB.find(cfb, dependents[tileref].location);
                  var tx = parse_iwa_file(decompress_iwa_file(tentry.content));
                  var tileroot;
                  for (var sxi = 0; sxi < tx.length; ++sxi) {
                    var packet2 = tx[sxi];
                    if (packet2.id == tileref)
                      tileroot = packet2;
                  }
                  var tiledata = parse_shallow(tileroot.messages[0].data);
                  {
                    delete tiledata[6];
                    delete tile[7];
                    var rowload = new Uint8Array(tiledata[5][0].data);
                    tiledata[5] = [];
                    var cnt = 0;
                    for (var R2 = 0; R2 <= range.e.r; ++R2) {
                      var tilerow = parse_shallow(rowload);
                      cnt += write_tile_row(tilerow, data[R2], SST);
                      tilerow[1][0].data = write_varint49(R2);
                      tiledata[5].push({ data: write_shallow(tilerow), type: 2 });
                    }
                    tiledata[1] = [{ type: 0, data: write_varint49(range.e.c + 1) }];
                    tiledata[2] = [{ type: 0, data: write_varint49(range.e.r + 1) }];
                    tiledata[3] = [{ type: 0, data: write_varint49(cnt) }];
                    tiledata[4] = [{ type: 0, data: write_varint49(range.e.r + 1) }];
                  }
                  tileroot.messages[0].data = write_shallow(tiledata);
                  var ty = write_iwa_file(tx);
                  var raw32 = compress_iwa_file(ty);
                  tentry.content = raw32;
                  tentry.size = tentry.content.length;
                })();
              }
              t3.data = write_shallow(tl);
            }
            store[3][0].data = write_shallow(tile);
          }
          pb[4][0].data = write_shallow(store);
        }
        docroot.messages[0].data = write_shallow(pb);
        var y = write_iwa_file(x);
        var raw3 = compress_iwa_file(y);
        entry.content = raw3;
        entry.size = entry.content.length;
        return cfb;
      }
      function fix_opts_func(defaults) {
        return function fix_opts(opts) {
          for (var i = 0; i != defaults.length; ++i) {
            var d = defaults[i];
            if (opts[d[0]] === void 0)
              opts[d[0]] = d[1];
            if (d[2] === "n")
              opts[d[0]] = Number(opts[d[0]]);
          }
        };
      }
      function fix_read_opts(opts) {
        fix_opts_func([
          ["cellNF", false],
          /* emit cell number format string as .z */
          ["cellHTML", true],
          /* emit html string as .h */
          ["cellFormula", true],
          /* emit formulae as .f */
          ["cellStyles", false],
          /* emits style/theme as .s */
          ["cellText", true],
          /* emit formatted text as .w */
          ["cellDates", false],
          /* emit date cells with type `d` */
          ["sheetStubs", false],
          /* emit empty cells */
          ["sheetRows", 0, "n"],
          /* read n rows (0 = read all rows) */
          ["bookDeps", false],
          /* parse calculation chains */
          ["bookSheets", false],
          /* only try to get sheet names (no Sheets) */
          ["bookProps", false],
          /* only try to get properties (no Sheets) */
          ["bookFiles", false],
          /* include raw file structure (keys, files, cfb) */
          ["bookVBA", false],
          /* include vba raw data (vbaraw) */
          ["password", ""],
          /* password */
          ["WTF", false]
          /* WTF mode (throws errors) */
        ])(opts);
      }
      function fix_write_opts(opts) {
        fix_opts_func([
          ["cellDates", false],
          /* write date cells with type `d` */
          ["bookSST", false],
          /* Generate Shared String Table */
          ["bookType", "xlsx"],
          /* Type of workbook (xlsx/m/b) */
          ["compression", false],
          /* Use file compression */
          ["WTF", false]
          /* WTF mode (throws errors) */
        ])(opts);
      }
      function get_sheet_type(n) {
        if (RELS.WS.indexOf(n) > -1)
          return "sheet";
        if (RELS.CS && n == RELS.CS)
          return "chart";
        if (RELS.DS && n == RELS.DS)
          return "dialog";
        if (RELS.MS && n == RELS.MS)
          return "macro";
        return n && n.length ? n : "sheet";
      }
      function safe_parse_wbrels(wbrels, sheets) {
        if (!wbrels)
          return 0;
        try {
          wbrels = sheets.map(function pwbr(w) {
            if (!w.id)
              w.id = w.strRelID;
            return [w.name, wbrels["!id"][w.id].Target, get_sheet_type(wbrels["!id"][w.id].Type)];
          });
        } catch (e) {
          return null;
        }
        return !wbrels || wbrels.length === 0 ? null : wbrels;
      }
      function safe_parse_sheet(zip, path2, relsPath, sheet, idx, sheetRels, sheets, stype, opts, wb, themes, styles) {
        try {
          sheetRels[sheet] = parse_rels(getzipstr(zip, relsPath, true), path2);
          var data = getzipdata(zip, path2);
          var _ws;
          switch (stype) {
            case "sheet":
              _ws = parse_ws(data, path2, idx, opts, sheetRels[sheet], wb, themes, styles);
              break;
            case "chart":
              _ws = parse_cs(data, path2, idx, opts, sheetRels[sheet], wb, themes, styles);
              if (!_ws || !_ws["!drawel"])
                break;
              var dfile = resolve_path(_ws["!drawel"].Target, path2);
              var drelsp = get_rels_path(dfile);
              var draw = parse_drawing(getzipstr(zip, dfile, true), parse_rels(getzipstr(zip, drelsp, true), dfile));
              var chartp = resolve_path(draw, dfile);
              var crelsp = get_rels_path(chartp);
              _ws = parse_chart(getzipstr(zip, chartp, true), chartp, opts, parse_rels(getzipstr(zip, crelsp, true), chartp), wb, _ws);
              break;
            case "macro":
              _ws = parse_ms(data, path2, idx, opts, sheetRels[sheet], wb, themes, styles);
              break;
            case "dialog":
              _ws = parse_ds(data, path2, idx, opts, sheetRels[sheet], wb, themes, styles);
              break;
            default:
              throw new Error("Unrecognized sheet type " + stype);
          }
          sheets[sheet] = _ws;
          var tcomments = [];
          if (sheetRels && sheetRels[sheet])
            keys3(sheetRels[sheet]).forEach(function(n) {
              var dfile2 = "";
              if (sheetRels[sheet][n].Type == RELS.CMNT) {
                dfile2 = resolve_path(sheetRels[sheet][n].Target, path2);
                var comments = parse_cmnt(getzipdata(zip, dfile2, true), dfile2, opts);
                if (!comments || !comments.length)
                  return;
                sheet_insert_comments(_ws, comments, false);
              }
              if (sheetRels[sheet][n].Type == RELS.TCMNT) {
                dfile2 = resolve_path(sheetRels[sheet][n].Target, path2);
                tcomments = tcomments.concat(parse_tcmnt_xml(getzipdata(zip, dfile2, true), opts));
              }
            });
          if (tcomments && tcomments.length)
            sheet_insert_comments(_ws, tcomments, true, opts.people || []);
        } catch (e) {
          if (opts.WTF)
            throw e;
        }
      }
      function strip_front_slash(x) {
        return x.charAt(0) == "/" ? x.slice(1) : x;
      }
      function parse_zip(zip, opts) {
        make_ssf();
        opts = opts || {};
        fix_read_opts(opts);
        if (safegetzipfile(zip, "META-INF/manifest.xml"))
          return parse_ods(zip, opts);
        if (safegetzipfile(zip, "objectdata.xml"))
          return parse_ods(zip, opts);
        if (safegetzipfile(zip, "Index/Document.iwa")) {
          if (typeof Uint8Array == "undefined")
            throw new Error("NUMBERS file parsing requires Uint8Array support");
          if (typeof parse_numbers_iwa != "undefined") {
            if (zip.FileIndex)
              return parse_numbers_iwa(zip);
            var _zip = CFB.utils.cfb_new();
            zipentries(zip).forEach(function(e) {
              zip_add_file(_zip, e, getzipbin(zip, e));
            });
            return parse_numbers_iwa(_zip);
          }
          throw new Error("Unsupported NUMBERS file");
        }
        if (!safegetzipfile(zip, "[Content_Types].xml")) {
          if (safegetzipfile(zip, "index.xml.gz"))
            throw new Error("Unsupported NUMBERS 08 file");
          if (safegetzipfile(zip, "index.xml"))
            throw new Error("Unsupported NUMBERS 09 file");
          throw new Error("Unsupported ZIP file");
        }
        var entries = zipentries(zip);
        var dir = parse_ct(getzipstr(zip, "[Content_Types].xml"));
        var xlsb = false;
        var sheets, binname;
        if (dir.workbooks.length === 0) {
          binname = "xl/workbook.xml";
          if (getzipdata(zip, binname, true))
            dir.workbooks.push(binname);
        }
        if (dir.workbooks.length === 0) {
          binname = "xl/workbook.bin";
          if (!getzipdata(zip, binname, true))
            throw new Error("Could not find workbook");
          dir.workbooks.push(binname);
          xlsb = true;
        }
        if (dir.workbooks[0].slice(-3) == "bin")
          xlsb = true;
        var themes = {};
        var styles = {};
        if (!opts.bookSheets && !opts.bookProps) {
          strs = [];
          if (dir.sst)
            try {
              strs = parse_sst(getzipdata(zip, strip_front_slash(dir.sst)), dir.sst, opts);
            } catch (e) {
              if (opts.WTF)
                throw e;
            }
          if (opts.cellStyles && dir.themes.length)
            themes = parse_theme(getzipstr(zip, dir.themes[0].replace(/^\//, ""), true) || "", dir.themes[0], opts);
          if (dir.style)
            styles = parse_sty(getzipdata(zip, strip_front_slash(dir.style)), dir.style, themes, opts);
        }
        dir.links.map(function(link) {
          try {
            var rels = parse_rels(getzipstr(zip, get_rels_path(strip_front_slash(link))), link);
            return parse_xlink(getzipdata(zip, strip_front_slash(link)), rels, link, opts);
          } catch (e) {
          }
        });
        var wb = parse_wb(getzipdata(zip, strip_front_slash(dir.workbooks[0])), dir.workbooks[0], opts);
        var props = {}, propdata = "";
        if (dir.coreprops.length) {
          propdata = getzipdata(zip, strip_front_slash(dir.coreprops[0]), true);
          if (propdata)
            props = parse_core_props(propdata);
          if (dir.extprops.length !== 0) {
            propdata = getzipdata(zip, strip_front_slash(dir.extprops[0]), true);
            if (propdata)
              parse_ext_props(propdata, props, opts);
          }
        }
        var custprops = {};
        if (!opts.bookSheets || opts.bookProps) {
          if (dir.custprops.length !== 0) {
            propdata = getzipstr(zip, strip_front_slash(dir.custprops[0]), true);
            if (propdata)
              custprops = parse_cust_props(propdata, opts);
          }
        }
        var out = {};
        if (opts.bookSheets || opts.bookProps) {
          if (wb.Sheets)
            sheets = wb.Sheets.map(function pluck(x) {
              return x.name;
            });
          else if (props.Worksheets && props.SheetNames.length > 0)
            sheets = props.SheetNames;
          if (opts.bookProps) {
            out.Props = props;
            out.Custprops = custprops;
          }
          if (opts.bookSheets && typeof sheets !== "undefined")
            out.SheetNames = sheets;
          if (opts.bookSheets ? out.SheetNames : opts.bookProps)
            return out;
        }
        sheets = {};
        var deps = {};
        if (opts.bookDeps && dir.calcchain)
          deps = parse_cc(getzipdata(zip, strip_front_slash(dir.calcchain)), dir.calcchain, opts);
        var i = 0;
        var sheetRels = {};
        var path2, relsPath;
        {
          var wbsheets = wb.Sheets;
          props.Worksheets = wbsheets.length;
          props.SheetNames = [];
          for (var j = 0; j != wbsheets.length; ++j) {
            props.SheetNames[j] = wbsheets[j].name;
          }
        }
        var wbext = xlsb ? "bin" : "xml";
        var wbrelsi = dir.workbooks[0].lastIndexOf("/");
        var wbrelsfile = (dir.workbooks[0].slice(0, wbrelsi + 1) + "_rels/" + dir.workbooks[0].slice(wbrelsi + 1) + ".rels").replace(/^\//, "");
        if (!safegetzipfile(zip, wbrelsfile))
          wbrelsfile = "xl/_rels/workbook." + wbext + ".rels";
        var wbrels = parse_rels(getzipstr(zip, wbrelsfile, true), wbrelsfile.replace(/_rels.*/, "s5s"));
        if ((dir.metadata || []).length >= 1) {
          opts.xlmeta = parse_xlmeta(getzipdata(zip, strip_front_slash(dir.metadata[0])), dir.metadata[0], opts);
        }
        if ((dir.people || []).length >= 1) {
          opts.people = parse_people_xml(getzipdata(zip, strip_front_slash(dir.people[0])), opts);
        }
        if (wbrels)
          wbrels = safe_parse_wbrels(wbrels, wb.Sheets);
        var nmode = getzipdata(zip, "xl/worksheets/sheet.xml", true) ? 1 : 0;
        wsloop:
          for (i = 0; i != props.Worksheets; ++i) {
            var stype = "sheet";
            if (wbrels && wbrels[i]) {
              path2 = "xl/" + wbrels[i][1].replace(/[\/]?xl\//, "");
              if (!safegetzipfile(zip, path2))
                path2 = wbrels[i][1];
              if (!safegetzipfile(zip, path2))
                path2 = wbrelsfile.replace(/_rels\/.*$/, "") + wbrels[i][1];
              stype = wbrels[i][2];
            } else {
              path2 = "xl/worksheets/sheet" + (i + 1 - nmode) + "." + wbext;
              path2 = path2.replace(/sheet0\./, "sheet.");
            }
            relsPath = path2.replace(/^(.*)(\/)([^\/]*)$/, "$1/_rels/$3.rels");
            if (opts && opts.sheets != null)
              switch (typeof opts.sheets) {
                case "number":
                  if (i != opts.sheets)
                    continue wsloop;
                  break;
                case "string":
                  if (props.SheetNames[i].toLowerCase() != opts.sheets.toLowerCase())
                    continue wsloop;
                  break;
                default:
                  if (Array.isArray && Array.isArray(opts.sheets)) {
                    var snjseen = false;
                    for (var snj = 0; snj != opts.sheets.length; ++snj) {
                      if (typeof opts.sheets[snj] == "number" && opts.sheets[snj] == i)
                        snjseen = 1;
                      if (typeof opts.sheets[snj] == "string" && opts.sheets[snj].toLowerCase() == props.SheetNames[i].toLowerCase())
                        snjseen = 1;
                    }
                    if (!snjseen)
                      continue wsloop;
                  }
              }
            safe_parse_sheet(zip, path2, relsPath, props.SheetNames[i], i, sheetRels, sheets, stype, opts, wb, themes, styles);
          }
        out = {
          Directory: dir,
          Workbook: wb,
          Props: props,
          Custprops: custprops,
          Deps: deps,
          Sheets: sheets,
          SheetNames: props.SheetNames,
          Strings: strs,
          Styles: styles,
          Themes: themes,
          SSF: dup(table_fmt)
        };
        if (opts && opts.bookFiles) {
          if (zip.files) {
            out.keys = entries;
            out.files = zip.files;
          } else {
            out.keys = [];
            out.files = {};
            zip.FullPaths.forEach(function(p, idx) {
              p = p.replace(/^Root Entry[\/]/, "");
              out.keys.push(p);
              out.files[p] = zip.FileIndex[idx];
            });
          }
        }
        if (opts && opts.bookVBA) {
          if (dir.vba.length > 0)
            out.vbaraw = getzipdata(zip, strip_front_slash(dir.vba[0]), true);
          else if (dir.defaults && dir.defaults.bin === CT_VBA)
            out.vbaraw = getzipdata(zip, "xl/vbaProject.bin", true);
        }
        return out;
      }
      function parse_xlsxcfb(cfb, _opts) {
        var opts = _opts || {};
        var f = "Workbook", data = CFB.find(cfb, f);
        try {
          f = "/!DataSpaces/Version";
          data = CFB.find(cfb, f);
          if (!data || !data.content)
            throw new Error("ECMA-376 Encrypted file missing " + f);
          parse_DataSpaceVersionInfo(data.content);
          f = "/!DataSpaces/DataSpaceMap";
          data = CFB.find(cfb, f);
          if (!data || !data.content)
            throw new Error("ECMA-376 Encrypted file missing " + f);
          var dsm = parse_DataSpaceMap(data.content);
          if (dsm.length !== 1 || dsm[0].comps.length !== 1 || dsm[0].comps[0].t !== 0 || dsm[0].name !== "StrongEncryptionDataSpace" || dsm[0].comps[0].v !== "EncryptedPackage")
            throw new Error("ECMA-376 Encrypted file bad " + f);
          f = "/!DataSpaces/DataSpaceInfo/StrongEncryptionDataSpace";
          data = CFB.find(cfb, f);
          if (!data || !data.content)
            throw new Error("ECMA-376 Encrypted file missing " + f);
          var seds = parse_DataSpaceDefinition(data.content);
          if (seds.length != 1 || seds[0] != "StrongEncryptionTransform")
            throw new Error("ECMA-376 Encrypted file bad " + f);
          f = "/!DataSpaces/TransformInfo/StrongEncryptionTransform/!Primary";
          data = CFB.find(cfb, f);
          if (!data || !data.content)
            throw new Error("ECMA-376 Encrypted file missing " + f);
          parse_Primary(data.content);
        } catch (e) {
        }
        f = "/EncryptionInfo";
        data = CFB.find(cfb, f);
        if (!data || !data.content)
          throw new Error("ECMA-376 Encrypted file missing " + f);
        var einfo = parse_EncryptionInfo(data.content);
        f = "/EncryptedPackage";
        data = CFB.find(cfb, f);
        if (!data || !data.content)
          throw new Error("ECMA-376 Encrypted file missing " + f);
        if (einfo[0] == 4 && typeof decrypt_agile !== "undefined")
          return decrypt_agile(einfo[1], data.content, opts.password || "", opts);
        if (einfo[0] == 2 && typeof decrypt_std76 !== "undefined")
          return decrypt_std76(einfo[1], data.content, opts.password || "", opts);
        throw new Error("File is password-protected");
      }
      function write_zip(wb, opts) {
        if (opts.bookType == "ods")
          return write_ods(wb, opts);
        if (opts.bookType == "numbers")
          return write_numbers_iwa(wb, opts);
        if (opts.bookType == "xlsb")
          return write_zip_xlsxb(wb, opts);
        return write_zip_xlsx(wb, opts);
      }
      function write_zip_xlsxb(wb, opts) {
        _shapeid = 1024;
        if (wb && !wb.SSF) {
          wb.SSF = dup(table_fmt);
        }
        if (wb && wb.SSF) {
          make_ssf();
          SSF_load_table(wb.SSF);
          opts.revssf = evert_num(wb.SSF);
          opts.revssf[wb.SSF[65535]] = 0;
          opts.ssf = wb.SSF;
        }
        opts.rels = {};
        opts.wbrels = {};
        opts.Strings = [];
        opts.Strings.Count = 0;
        opts.Strings.Unique = 0;
        if (browser_has_Map)
          opts.revStrings = /* @__PURE__ */ new Map();
        else {
          opts.revStrings = {};
          opts.revStrings.foo = [];
          delete opts.revStrings.foo;
        }
        var wbext = opts.bookType == "xlsb" ? "bin" : "xml";
        var vbafmt = VBAFMTS.indexOf(opts.bookType) > -1;
        var ct = new_ct();
        fix_write_opts(opts = opts || {});
        var zip = zip_new();
        var f = "", rId = 0;
        opts.cellXfs = [];
        get_cell_style(opts.cellXfs, {}, { revssf: { "General": 0 } });
        if (!wb.Props)
          wb.Props = {};
        f = "docProps/core.xml";
        zip_add_file(zip, f, write_core_props(wb.Props, opts));
        ct.coreprops.push(f);
        add_rels(opts.rels, 2, f, RELS.CORE_PROPS);
        f = "docProps/app.xml";
        if (wb.Props && wb.Props.SheetNames) {
        } else if (!wb.Workbook || !wb.Workbook.Sheets)
          wb.Props.SheetNames = wb.SheetNames;
        else {
          var _sn = [];
          for (var _i = 0; _i < wb.SheetNames.length; ++_i)
            if ((wb.Workbook.Sheets[_i] || {}).Hidden != 2)
              _sn.push(wb.SheetNames[_i]);
          wb.Props.SheetNames = _sn;
        }
        wb.Props.Worksheets = wb.Props.SheetNames.length;
        zip_add_file(zip, f, write_ext_props(wb.Props, opts));
        ct.extprops.push(f);
        add_rels(opts.rels, 3, f, RELS.EXT_PROPS);
        if (wb.Custprops !== wb.Props && keys3(wb.Custprops || {}).length > 0) {
          f = "docProps/custom.xml";
          zip_add_file(zip, f, write_cust_props(wb.Custprops, opts));
          ct.custprops.push(f);
          add_rels(opts.rels, 4, f, RELS.CUST_PROPS);
        }
        for (rId = 1; rId <= wb.SheetNames.length; ++rId) {
          var wsrels = { "!id": {} };
          var ws = wb.Sheets[wb.SheetNames[rId - 1]];
          var _type = (ws || {})["!type"] || "sheet";
          switch (_type) {
            case "chart":
            default:
              f = "xl/worksheets/sheet" + rId + "." + wbext;
              zip_add_file(zip, f, write_ws(rId - 1, f, opts, wb, wsrels));
              ct.sheets.push(f);
              add_rels(opts.wbrels, -1, "worksheets/sheet" + rId + "." + wbext, RELS.WS[0]);
          }
          if (ws) {
            var comments = ws["!comments"];
            var need_vml = false;
            var cf = "";
            if (comments && comments.length > 0) {
              cf = "xl/comments" + rId + "." + wbext;
              zip_add_file(zip, cf, write_cmnt(comments, cf, opts));
              ct.comments.push(cf);
              add_rels(wsrels, -1, "../comments" + rId + "." + wbext, RELS.CMNT);
              need_vml = true;
            }
            if (ws["!legacy"]) {
              if (need_vml)
                zip_add_file(zip, "xl/drawings/vmlDrawing" + rId + ".vml", write_comments_vml(rId, ws["!comments"]));
            }
            delete ws["!comments"];
            delete ws["!legacy"];
          }
          if (wsrels["!id"].rId1)
            zip_add_file(zip, get_rels_path(f), write_rels(wsrels));
        }
        if (opts.Strings != null && opts.Strings.length > 0) {
          f = "xl/sharedStrings." + wbext;
          zip_add_file(zip, f, write_sst(opts.Strings, f, opts));
          ct.strs.push(f);
          add_rels(opts.wbrels, -1, "sharedStrings." + wbext, RELS.SST);
        }
        f = "xl/workbook." + wbext;
        zip_add_file(zip, f, write_wb(wb, f, opts));
        ct.workbooks.push(f);
        add_rels(opts.rels, 1, f, RELS.WB);
        f = "xl/theme/theme1.xml";
        zip_add_file(zip, f, write_theme(wb.Themes, opts));
        ct.themes.push(f);
        add_rels(opts.wbrels, -1, "theme/theme1.xml", RELS.THEME);
        f = "xl/styles." + wbext;
        zip_add_file(zip, f, write_sty(wb, f, opts));
        ct.styles.push(f);
        add_rels(opts.wbrels, -1, "styles." + wbext, RELS.STY);
        if (wb.vbaraw && vbafmt) {
          f = "xl/vbaProject.bin";
          zip_add_file(zip, f, wb.vbaraw);
          ct.vba.push(f);
          add_rels(opts.wbrels, -1, "vbaProject.bin", RELS.VBA);
        }
        f = "xl/metadata." + wbext;
        zip_add_file(zip, f, write_xlmeta(f));
        ct.metadata.push(f);
        add_rels(opts.wbrels, -1, "metadata." + wbext, RELS.XLMETA);
        zip_add_file(zip, "[Content_Types].xml", write_ct(ct, opts));
        zip_add_file(zip, "_rels/.rels", write_rels(opts.rels));
        zip_add_file(zip, "xl/_rels/workbook." + wbext + ".rels", write_rels(opts.wbrels));
        delete opts.revssf;
        delete opts.ssf;
        return zip;
      }
      function write_zip_xlsx(wb, opts) {
        _shapeid = 1024;
        if (wb && !wb.SSF) {
          wb.SSF = dup(table_fmt);
        }
        if (wb && wb.SSF) {
          make_ssf();
          SSF_load_table(wb.SSF);
          opts.revssf = evert_num(wb.SSF);
          opts.revssf[wb.SSF[65535]] = 0;
          opts.ssf = wb.SSF;
        }
        opts.rels = {};
        opts.wbrels = {};
        opts.Strings = [];
        opts.Strings.Count = 0;
        opts.Strings.Unique = 0;
        if (browser_has_Map)
          opts.revStrings = /* @__PURE__ */ new Map();
        else {
          opts.revStrings = {};
          opts.revStrings.foo = [];
          delete opts.revStrings.foo;
        }
        var wbext = "xml";
        var vbafmt = VBAFMTS.indexOf(opts.bookType) > -1;
        var ct = new_ct();
        fix_write_opts(opts = opts || {});
        var zip = zip_new();
        var f = "", rId = 0;
        opts.cellXfs = [];
        get_cell_style(opts.cellXfs, {}, { revssf: { "General": 0 } });
        if (!wb.Props)
          wb.Props = {};
        f = "docProps/core.xml";
        zip_add_file(zip, f, write_core_props(wb.Props, opts));
        ct.coreprops.push(f);
        add_rels(opts.rels, 2, f, RELS.CORE_PROPS);
        f = "docProps/app.xml";
        if (wb.Props && wb.Props.SheetNames) {
        } else if (!wb.Workbook || !wb.Workbook.Sheets)
          wb.Props.SheetNames = wb.SheetNames;
        else {
          var _sn = [];
          for (var _i = 0; _i < wb.SheetNames.length; ++_i)
            if ((wb.Workbook.Sheets[_i] || {}).Hidden != 2)
              _sn.push(wb.SheetNames[_i]);
          wb.Props.SheetNames = _sn;
        }
        wb.Props.Worksheets = wb.Props.SheetNames.length;
        zip_add_file(zip, f, write_ext_props(wb.Props, opts));
        ct.extprops.push(f);
        add_rels(opts.rels, 3, f, RELS.EXT_PROPS);
        if (wb.Custprops !== wb.Props && keys3(wb.Custprops || {}).length > 0) {
          f = "docProps/custom.xml";
          zip_add_file(zip, f, write_cust_props(wb.Custprops, opts));
          ct.custprops.push(f);
          add_rels(opts.rels, 4, f, RELS.CUST_PROPS);
        }
        var people = ["SheetJ5"];
        opts.tcid = 0;
        for (rId = 1; rId <= wb.SheetNames.length; ++rId) {
          var wsrels = { "!id": {} };
          var ws = wb.Sheets[wb.SheetNames[rId - 1]];
          var _type = (ws || {})["!type"] || "sheet";
          switch (_type) {
            case "chart":
            default:
              f = "xl/worksheets/sheet" + rId + "." + wbext;
              zip_add_file(zip, f, write_ws_xml(rId - 1, opts, wb, wsrels));
              ct.sheets.push(f);
              add_rels(opts.wbrels, -1, "worksheets/sheet" + rId + "." + wbext, RELS.WS[0]);
          }
          if (ws) {
            var comments = ws["!comments"];
            var need_vml = false;
            var cf = "";
            if (comments && comments.length > 0) {
              var needtc = false;
              comments.forEach(function(carr) {
                carr[1].forEach(function(c) {
                  if (c.T == true)
                    needtc = true;
                });
              });
              if (needtc) {
                cf = "xl/threadedComments/threadedComment" + rId + "." + wbext;
                zip_add_file(zip, cf, write_tcmnt_xml(comments, people, opts));
                ct.threadedcomments.push(cf);
                add_rels(wsrels, -1, "../threadedComments/threadedComment" + rId + "." + wbext, RELS.TCMNT);
              }
              cf = "xl/comments" + rId + "." + wbext;
              zip_add_file(zip, cf, write_comments_xml(comments, opts));
              ct.comments.push(cf);
              add_rels(wsrels, -1, "../comments" + rId + "." + wbext, RELS.CMNT);
              need_vml = true;
            }
            if (ws["!legacy"]) {
              if (need_vml)
                zip_add_file(zip, "xl/drawings/vmlDrawing" + rId + ".vml", write_comments_vml(rId, ws["!comments"]));
            }
            delete ws["!comments"];
            delete ws["!legacy"];
          }
          if (wsrels["!id"].rId1)
            zip_add_file(zip, get_rels_path(f), write_rels(wsrels));
        }
        if (opts.Strings != null && opts.Strings.length > 0) {
          f = "xl/sharedStrings." + wbext;
          zip_add_file(zip, f, write_sst_xml(opts.Strings, opts));
          ct.strs.push(f);
          add_rels(opts.wbrels, -1, "sharedStrings." + wbext, RELS.SST);
        }
        f = "xl/workbook." + wbext;
        zip_add_file(zip, f, write_wb_xml(wb, opts));
        ct.workbooks.push(f);
        add_rels(opts.rels, 1, f, RELS.WB);
        f = "xl/theme/theme1.xml";
        zip_add_file(zip, f, write_theme(wb.Themes, opts));
        ct.themes.push(f);
        add_rels(opts.wbrels, -1, "theme/theme1.xml", RELS.THEME);
        f = "xl/styles." + wbext;
        zip_add_file(zip, f, write_sty_xml(wb, opts));
        ct.styles.push(f);
        add_rels(opts.wbrels, -1, "styles." + wbext, RELS.STY);
        if (wb.vbaraw && vbafmt) {
          f = "xl/vbaProject.bin";
          zip_add_file(zip, f, wb.vbaraw);
          ct.vba.push(f);
          add_rels(opts.wbrels, -1, "vbaProject.bin", RELS.VBA);
        }
        f = "xl/metadata." + wbext;
        zip_add_file(zip, f, write_xlmeta_xml());
        ct.metadata.push(f);
        add_rels(opts.wbrels, -1, "metadata." + wbext, RELS.XLMETA);
        if (people.length > 1) {
          f = "xl/persons/person.xml";
          zip_add_file(zip, f, write_people_xml(people, opts));
          ct.people.push(f);
          add_rels(opts.wbrels, -1, "persons/person.xml", RELS.PEOPLE);
        }
        zip_add_file(zip, "[Content_Types].xml", write_ct(ct, opts));
        zip_add_file(zip, "_rels/.rels", write_rels(opts.rels));
        zip_add_file(zip, "xl/_rels/workbook." + wbext + ".rels", write_rels(opts.wbrels));
        delete opts.revssf;
        delete opts.ssf;
        return zip;
      }
      function firstbyte(f, o) {
        var x = "";
        switch ((o || {}).type || "base64") {
          case "buffer":
            return [f[0], f[1], f[2], f[3], f[4], f[5], f[6], f[7]];
          case "base64":
            x = Base64_decode(f.slice(0, 12));
            break;
          case "binary":
            x = f;
            break;
          case "array":
            return [f[0], f[1], f[2], f[3], f[4], f[5], f[6], f[7]];
          default:
            throw new Error("Unrecognized type " + (o && o.type || "undefined"));
        }
        return [x.charCodeAt(0), x.charCodeAt(1), x.charCodeAt(2), x.charCodeAt(3), x.charCodeAt(4), x.charCodeAt(5), x.charCodeAt(6), x.charCodeAt(7)];
      }
      function read_cfb(cfb, opts) {
        if (CFB.find(cfb, "EncryptedPackage"))
          return parse_xlsxcfb(cfb, opts);
        return parse_xlscfb(cfb, opts);
      }
      function read_zip(data, opts) {
        var zip, d = data;
        var o = opts || {};
        if (!o.type)
          o.type = has_buf && Buffer.isBuffer(data) ? "buffer" : "base64";
        zip = zip_read(d, o);
        return parse_zip(zip, o);
      }
      function read_plaintext(data, o) {
        var i = 0;
        main:
          while (i < data.length)
            switch (data.charCodeAt(i)) {
              case 10:
              case 13:
              case 32:
                ++i;
                break;
              case 60:
                return parse_xlml(data.slice(i), o);
              default:
                break main;
            }
        return PRN.to_workbook(data, o);
      }
      function read_plaintext_raw(data, o) {
        var str = "", bytes = firstbyte(data, o);
        switch (o.type) {
          case "base64":
            str = Base64_decode(data);
            break;
          case "binary":
            str = data;
            break;
          case "buffer":
            str = data.toString("binary");
            break;
          case "array":
            str = cc2str(data);
            break;
          default:
            throw new Error("Unrecognized type " + o.type);
        }
        if (bytes[0] == 239 && bytes[1] == 187 && bytes[2] == 191)
          str = utf8read(str);
        o.type = "binary";
        return read_plaintext(str, o);
      }
      function read_utf16(data, o) {
        var d = data;
        if (o.type == "base64")
          d = Base64_decode(d);
        d = $cptable.utils.decode(1200, d.slice(2), "str");
        o.type = "binary";
        return read_plaintext(d, o);
      }
      function bstrify(data) {
        return !data.match(/[^\x00-\x7F]/) ? data : utf8write(data);
      }
      function read_prn(data, d, o, str) {
        if (str) {
          o.type = "string";
          return PRN.to_workbook(data, o);
        }
        return PRN.to_workbook(d, o);
      }
      function readSync(data, opts) {
        reset_cp();
        var o = opts || {};
        if (typeof ArrayBuffer !== "undefined" && data instanceof ArrayBuffer)
          return readSync(new Uint8Array(data), (o = dup(o), o.type = "array", o));
        if (typeof Uint8Array !== "undefined" && data instanceof Uint8Array && !o.type)
          o.type = typeof Deno !== "undefined" ? "buffer" : "array";
        var d = data, n = [0, 0, 0, 0], str = false;
        if (o.cellStyles) {
          o.cellNF = true;
          o.sheetStubs = true;
        }
        _ssfopts = {};
        if (o.dateNF)
          _ssfopts.dateNF = o.dateNF;
        if (!o.type)
          o.type = has_buf && Buffer.isBuffer(data) ? "buffer" : "base64";
        if (o.type == "file") {
          o.type = has_buf ? "buffer" : "binary";
          d = read_binary(data);
          if (typeof Uint8Array !== "undefined" && !has_buf)
            o.type = "array";
        }
        if (o.type == "string") {
          str = true;
          o.type = "binary";
          o.codepage = 65001;
          d = bstrify(data);
        }
        if (o.type == "array" && typeof Uint8Array !== "undefined" && data instanceof Uint8Array && typeof ArrayBuffer !== "undefined") {
          var ab = new ArrayBuffer(3), vu = new Uint8Array(ab);
          vu.foo = "bar";
          if (!vu.foo) {
            o = dup(o);
            o.type = "array";
            return readSync(ab2a(d), o);
          }
        }
        switch ((n = firstbyte(d, o))[0]) {
          case 208:
            if (n[1] === 207 && n[2] === 17 && n[3] === 224 && n[4] === 161 && n[5] === 177 && n[6] === 26 && n[7] === 225)
              return read_cfb(CFB.read(d, o), o);
            break;
          case 9:
            if (n[1] <= 8)
              return parse_xlscfb(d, o);
            break;
          case 60:
            return parse_xlml(d, o);
          case 73:
            if (n[1] === 73 && n[2] === 42 && n[3] === 0)
              throw new Error("TIFF Image File is not a spreadsheet");
            if (n[1] === 68)
              return read_wb_ID(d, o);
            break;
          case 84:
            if (n[1] === 65 && n[2] === 66 && n[3] === 76)
              return DIF.to_workbook(d, o);
            break;
          case 80:
            return n[1] === 75 && n[2] < 9 && n[3] < 9 ? read_zip(d, o) : read_prn(data, d, o, str);
          case 239:
            return n[3] === 60 ? parse_xlml(d, o) : read_prn(data, d, o, str);
          case 255:
            if (n[1] === 254) {
              return read_utf16(d, o);
            } else if (n[1] === 0 && n[2] === 2 && n[3] === 0)
              return WK_.to_workbook(d, o);
            break;
          case 0:
            if (n[1] === 0) {
              if (n[2] >= 2 && n[3] === 0)
                return WK_.to_workbook(d, o);
              if (n[2] === 0 && (n[3] === 8 || n[3] === 9))
                return WK_.to_workbook(d, o);
            }
            break;
          case 3:
          case 131:
          case 139:
          case 140:
            return DBF.to_workbook(d, o);
          case 123:
            if (n[1] === 92 && n[2] === 114 && n[3] === 116)
              return RTF.to_workbook(d, o);
            break;
          case 10:
          case 13:
          case 32:
            return read_plaintext_raw(d, o);
          case 137:
            if (n[1] === 80 && n[2] === 78 && n[3] === 71)
              throw new Error("PNG Image File is not a spreadsheet");
            break;
        }
        if (DBF_SUPPORTED_VERSIONS.indexOf(n[0]) > -1 && n[2] <= 12 && n[3] <= 31)
          return DBF.to_workbook(d, o);
        return read_prn(data, d, o, str);
      }
      function readFileSync(filename, opts) {
        var o = opts || {};
        o.type = "file";
        return readSync(filename, o);
      }
      function write_cfb_ctr(cfb, o) {
        switch (o.type) {
          case "base64":
          case "binary":
            break;
          case "buffer":
          case "array":
            o.type = "";
            break;
          case "file":
            return write_dl(o.file, CFB.write(cfb, { type: has_buf ? "buffer" : "" }));
          case "string":
            throw new Error("'string' output type invalid for '" + o.bookType + "' files");
          default:
            throw new Error("Unrecognized type " + o.type);
        }
        return CFB.write(cfb, o);
      }
      function write_zip_type(wb, opts) {
        var o = dup(opts || {});
        var z = write_zip(wb, o);
        return write_zip_denouement(z, o);
      }
      function write_zip_typeXLSX(wb, opts) {
        var o = dup(opts || {});
        var z = write_zip_xlsx(wb, o);
        return write_zip_denouement(z, o);
      }
      function write_zip_denouement(z, o) {
        var oopts = {};
        var ftype = has_buf ? "nodebuffer" : typeof Uint8Array !== "undefined" ? "array" : "string";
        if (o.compression)
          oopts.compression = "DEFLATE";
        if (o.password)
          oopts.type = ftype;
        else
          switch (o.type) {
            case "base64":
              oopts.type = "base64";
              break;
            case "binary":
              oopts.type = "string";
              break;
            case "string":
              throw new Error("'string' output type invalid for '" + o.bookType + "' files");
            case "buffer":
            case "file":
              oopts.type = ftype;
              break;
            default:
              throw new Error("Unrecognized type " + o.type);
          }
        var out = z.FullPaths ? CFB.write(z, { fileType: "zip", type: { "nodebuffer": "buffer", "string": "binary" }[oopts.type] || oopts.type, compression: !!o.compression }) : z.generate(oopts);
        if (typeof Deno !== "undefined") {
          if (typeof out == "string") {
            if (o.type == "binary" || o.type == "base64")
              return out;
            out = new Uint8Array(s2ab(out));
          }
        }
        if (o.password && typeof encrypt_agile !== "undefined")
          return write_cfb_ctr(encrypt_agile(out, o.password), o);
        if (o.type === "file")
          return write_dl(o.file, out);
        return o.type == "string" ? utf8read(out) : out;
      }
      function write_cfb_type(wb, opts) {
        var o = opts || {};
        var cfb = write_xlscfb(wb, o);
        return write_cfb_ctr(cfb, o);
      }
      function write_string_type(out, opts, bom) {
        if (!bom)
          bom = "";
        var o = bom + out;
        switch (opts.type) {
          case "base64":
            return Base64_encode(utf8write(o));
          case "binary":
            return utf8write(o);
          case "string":
            return out;
          case "file":
            return write_dl(opts.file, o, "utf8");
          case "buffer": {
            if (has_buf)
              return Buffer_from(o, "utf8");
            else if (typeof TextEncoder !== "undefined")
              return new TextEncoder().encode(o);
            else
              return write_string_type(o, { type: "binary" }).split("").map(function(c) {
                return c.charCodeAt(0);
              });
          }
        }
        throw new Error("Unrecognized type " + opts.type);
      }
      function write_stxt_type(out, opts) {
        switch (opts.type) {
          case "base64":
            return Base64_encode(out);
          case "binary":
            return out;
          case "string":
            return out;
          case "file":
            return write_dl(opts.file, out, "binary");
          case "buffer": {
            if (has_buf)
              return Buffer_from(out, "binary");
            else
              return out.split("").map(function(c) {
                return c.charCodeAt(0);
              });
          }
        }
        throw new Error("Unrecognized type " + opts.type);
      }
      function write_binary_type(out, opts) {
        switch (opts.type) {
          case "string":
          case "base64":
          case "binary":
            var bstr = "";
            for (var i = 0; i < out.length; ++i)
              bstr += String.fromCharCode(out[i]);
            return opts.type == "base64" ? Base64_encode(bstr) : opts.type == "string" ? utf8read(bstr) : bstr;
          case "file":
            return write_dl(opts.file, out);
          case "buffer":
            return out;
          default:
            throw new Error("Unrecognized type " + opts.type);
        }
      }
      function writeSyncXLSX(wb, opts) {
        reset_cp();
        check_wb(wb);
        var o = dup(opts || {});
        if (o.cellStyles) {
          o.cellNF = true;
          o.sheetStubs = true;
        }
        if (o.type == "array") {
          o.type = "binary";
          var out = writeSyncXLSX(wb, o);
          o.type = "array";
          return s2ab(out);
        }
        return write_zip_typeXLSX(wb, o);
      }
      function writeSync(wb, opts) {
        reset_cp();
        check_wb(wb);
        var o = dup(opts || {});
        if (o.cellStyles) {
          o.cellNF = true;
          o.sheetStubs = true;
        }
        if (o.type == "array") {
          o.type = "binary";
          var out = writeSync(wb, o);
          o.type = "array";
          return s2ab(out);
        }
        var idx = 0;
        if (o.sheet) {
          if (typeof o.sheet == "number")
            idx = o.sheet;
          else
            idx = wb.SheetNames.indexOf(o.sheet);
          if (!wb.SheetNames[idx])
            throw new Error("Sheet not found: " + o.sheet + " : " + typeof o.sheet);
        }
        switch (o.bookType || "xlsb") {
          case "xml":
          case "xlml":
            return write_string_type(write_xlml(wb, o), o);
          case "slk":
          case "sylk":
            return write_string_type(SYLK.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "htm":
          case "html":
            return write_string_type(sheet_to_html(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "txt":
            return write_stxt_type(sheet_to_txt(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "csv":
            return write_string_type(sheet_to_csv(wb.Sheets[wb.SheetNames[idx]], o), o, "\uFEFF");
          case "dif":
            return write_string_type(DIF.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "dbf":
            return write_binary_type(DBF.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "prn":
            return write_string_type(PRN.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "rtf":
            return write_string_type(RTF.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "eth":
            return write_string_type(ETH.from_sheet(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "fods":
            return write_string_type(write_ods(wb, o), o);
          case "wk1":
            return write_binary_type(WK_.sheet_to_wk1(wb.Sheets[wb.SheetNames[idx]], o), o);
          case "wk3":
            return write_binary_type(WK_.book_to_wk3(wb, o), o);
          case "biff2":
            if (!o.biff)
              o.biff = 2;
          case "biff3":
            if (!o.biff)
              o.biff = 3;
          case "biff4":
            if (!o.biff)
              o.biff = 4;
            return write_binary_type(write_biff_buf(wb, o), o);
          case "biff5":
            if (!o.biff)
              o.biff = 5;
          case "biff8":
          case "xla":
          case "xls":
            if (!o.biff)
              o.biff = 8;
            return write_cfb_type(wb, o);
          case "xlsx":
          case "xlsm":
          case "xlam":
          case "xlsb":
          case "numbers":
          case "ods":
            return write_zip_type(wb, o);
          default:
            throw new Error("Unrecognized bookType |" + o.bookType + "|");
        }
      }
      function resolve_book_type(o) {
        if (o.bookType)
          return;
        var _BT = {
          "xls": "biff8",
          "htm": "html",
          "slk": "sylk",
          "socialcalc": "eth",
          "Sh33tJS": "WTF"
        };
        var ext = o.file.slice(o.file.lastIndexOf(".")).toLowerCase();
        if (ext.match(/^\.[a-z]+$/))
          o.bookType = ext.slice(1);
        o.bookType = _BT[o.bookType] || o.bookType;
      }
      function writeFileSync(wb, filename, opts) {
        var o = opts || {};
        o.type = "file";
        o.file = filename;
        resolve_book_type(o);
        return writeSync(wb, o);
      }
      function writeFileSyncXLSX(wb, filename, opts) {
        var o = opts || {};
        o.type = "file";
        o.file = filename;
        resolve_book_type(o);
        return writeSyncXLSX(wb, o);
      }
      function writeFileAsync(filename, wb, opts, cb) {
        var o = opts || {};
        o.type = "file";
        o.file = filename;
        resolve_book_type(o);
        o.type = "buffer";
        var _cb = cb;
        if (!(_cb instanceof Function))
          _cb = opts;
        return _fs.writeFile(filename, writeSync(wb, o), _cb);
      }
      function make_json_row(sheet, r, R, cols, header, hdr, dense, o) {
        var rr = encode_row(R);
        var defval = o.defval, raw = o.raw || !Object.prototype.hasOwnProperty.call(o, "raw");
        var isempty = true;
        var row = header === 1 ? [] : {};
        if (header !== 1) {
          if (Object.defineProperty)
            try {
              Object.defineProperty(row, "__rowNum__", { value: R, enumerable: false });
            } catch (e) {
              row.__rowNum__ = R;
            }
          else
            row.__rowNum__ = R;
        }
        if (!dense || sheet[R])
          for (var C = r.s.c; C <= r.e.c; ++C) {
            var val = dense ? sheet[R][C] : sheet[cols[C] + rr];
            if (val === void 0 || val.t === void 0) {
              if (defval === void 0)
                continue;
              if (hdr[C] != null) {
                row[hdr[C]] = defval;
              }
              continue;
            }
            var v = val.v;
            switch (val.t) {
              case "z":
                if (v == null)
                  break;
                continue;
              case "e":
                v = v == 0 ? null : void 0;
                break;
              case "s":
              case "d":
              case "b":
              case "n":
                break;
              default:
                throw new Error("unrecognized type " + val.t);
            }
            if (hdr[C] != null) {
              if (v == null) {
                if (val.t == "e" && v === null)
                  row[hdr[C]] = null;
                else if (defval !== void 0)
                  row[hdr[C]] = defval;
                else if (raw && v === null)
                  row[hdr[C]] = null;
                else
                  continue;
              } else {
                row[hdr[C]] = raw && (val.t !== "n" || val.t === "n" && o.rawNumbers !== false) ? v : format_cell(val, v, o);
              }
              if (v != null)
                isempty = false;
            }
          }
        return { row, isempty };
      }
      function sheet_to_json(sheet, opts) {
        if (sheet == null || sheet["!ref"] == null)
          return [];
        var val = { t: "n", v: 0 }, header = 0, offset = 1, hdr = [], v = 0, vv = "";
        var r = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
        var o = opts || {};
        var range = o.range != null ? o.range : sheet["!ref"];
        if (o.header === 1)
          header = 1;
        else if (o.header === "A")
          header = 2;
        else if (Array.isArray(o.header))
          header = 3;
        else if (o.header == null)
          header = 0;
        switch (typeof range) {
          case "string":
            r = safe_decode_range(range);
            break;
          case "number":
            r = safe_decode_range(sheet["!ref"]);
            r.s.r = range;
            break;
          default:
            r = range;
        }
        if (header > 0)
          offset = 0;
        var rr = encode_row(r.s.r);
        var cols = [];
        var out = [];
        var outi = 0, counter = 0;
        var dense = Array.isArray(sheet);
        var R = r.s.r, C = 0;
        var header_cnt = {};
        if (dense && !sheet[R])
          sheet[R] = [];
        var colinfo = o.skipHidden && sheet["!cols"] || [];
        var rowinfo = o.skipHidden && sheet["!rows"] || [];
        for (C = r.s.c; C <= r.e.c; ++C) {
          if ((colinfo[C] || {}).hidden)
            continue;
          cols[C] = encode_col(C);
          val = dense ? sheet[R][C] : sheet[cols[C] + rr];
          switch (header) {
            case 1:
              hdr[C] = C - r.s.c;
              break;
            case 2:
              hdr[C] = cols[C];
              break;
            case 3:
              hdr[C] = o.header[C - r.s.c];
              break;
            default:
              if (val == null)
                val = { w: "__EMPTY", t: "s" };
              vv = v = format_cell(val, null, o);
              counter = header_cnt[v] || 0;
              if (!counter)
                header_cnt[v] = 1;
              else {
                do {
                  vv = v + "_" + counter++;
                } while (header_cnt[vv]);
                header_cnt[v] = counter;
                header_cnt[vv] = 1;
              }
              hdr[C] = vv;
          }
        }
        for (R = r.s.r + offset; R <= r.e.r; ++R) {
          if ((rowinfo[R] || {}).hidden)
            continue;
          var row = make_json_row(sheet, r, R, cols, header, hdr, dense, o);
          if (row.isempty === false || (header === 1 ? o.blankrows !== false : !!o.blankrows))
            out[outi++] = row.row;
        }
        out.length = outi;
        return out;
      }
      var qreg = /"/g;
      function make_csv_row(sheet, r, R, cols, fs2, rs, FS, o) {
        var isempty = true;
        var row = [], txt = "", rr = encode_row(R);
        for (var C = r.s.c; C <= r.e.c; ++C) {
          if (!cols[C])
            continue;
          var val = o.dense ? (sheet[R] || [])[C] : sheet[cols[C] + rr];
          if (val == null)
            txt = "";
          else if (val.v != null) {
            isempty = false;
            txt = "" + (o.rawNumbers && val.t == "n" ? val.v : format_cell(val, null, o));
            for (var i = 0, cc = 0; i !== txt.length; ++i)
              if ((cc = txt.charCodeAt(i)) === fs2 || cc === rs || cc === 34 || o.forceQuotes) {
                txt = '"' + txt.replace(qreg, '""') + '"';
                break;
              }
            if (txt == "ID")
              txt = '"ID"';
          } else if (val.f != null && !val.F) {
            isempty = false;
            txt = "=" + val.f;
            if (txt.indexOf(",") >= 0)
              txt = '"' + txt.replace(qreg, '""') + '"';
          } else
            txt = "";
          row.push(txt);
        }
        if (o.blankrows === false && isempty)
          return null;
        return row.join(FS);
      }
      function sheet_to_csv(sheet, opts) {
        var out = [];
        var o = opts == null ? {} : opts;
        if (sheet == null || sheet["!ref"] == null)
          return "";
        var r = safe_decode_range(sheet["!ref"]);
        var FS = o.FS !== void 0 ? o.FS : ",", fs2 = FS.charCodeAt(0);
        var RS = o.RS !== void 0 ? o.RS : "\n", rs = RS.charCodeAt(0);
        var endregex = new RegExp((FS == "|" ? "\\|" : FS) + "+$");
        var row = "", cols = [];
        o.dense = Array.isArray(sheet);
        var colinfo = o.skipHidden && sheet["!cols"] || [];
        var rowinfo = o.skipHidden && sheet["!rows"] || [];
        for (var C = r.s.c; C <= r.e.c; ++C)
          if (!(colinfo[C] || {}).hidden)
            cols[C] = encode_col(C);
        var w = 0;
        for (var R = r.s.r; R <= r.e.r; ++R) {
          if ((rowinfo[R] || {}).hidden)
            continue;
          row = make_csv_row(sheet, r, R, cols, fs2, rs, FS, o);
          if (row == null) {
            continue;
          }
          if (o.strip)
            row = row.replace(endregex, "");
          if (row || o.blankrows !== false)
            out.push((w++ ? RS : "") + row);
        }
        delete o.dense;
        return out.join("");
      }
      function sheet_to_txt(sheet, opts) {
        if (!opts)
          opts = {};
        opts.FS = "	";
        opts.RS = "\n";
        var s = sheet_to_csv(sheet, opts);
        if (typeof $cptable == "undefined" || opts.type == "string")
          return s;
        var o = $cptable.utils.encode(1200, s, "str");
        return String.fromCharCode(255) + String.fromCharCode(254) + o;
      }
      function sheet_to_formulae(sheet) {
        var y = "", x, val = "";
        if (sheet == null || sheet["!ref"] == null)
          return [];
        var r = safe_decode_range(sheet["!ref"]), rr = "", cols = [], C;
        var cmds = [];
        var dense = Array.isArray(sheet);
        for (C = r.s.c; C <= r.e.c; ++C)
          cols[C] = encode_col(C);
        for (var R = r.s.r; R <= r.e.r; ++R) {
          rr = encode_row(R);
          for (C = r.s.c; C <= r.e.c; ++C) {
            y = cols[C] + rr;
            x = dense ? (sheet[R] || [])[C] : sheet[y];
            val = "";
            if (x === void 0)
              continue;
            else if (x.F != null) {
              y = x.F;
              if (!x.f)
                continue;
              val = x.f;
              if (y.indexOf(":") == -1)
                y = y + ":" + y;
            }
            if (x.f != null)
              val = x.f;
            else if (x.t == "z")
              continue;
            else if (x.t == "n" && x.v != null)
              val = "" + x.v;
            else if (x.t == "b")
              val = x.v ? "TRUE" : "FALSE";
            else if (x.w !== void 0)
              val = "'" + x.w;
            else if (x.v === void 0)
              continue;
            else if (x.t == "s")
              val = "'" + x.v;
            else
              val = "" + x.v;
            cmds[cmds.length] = y + "=" + val;
          }
        }
        return cmds;
      }
      function sheet_add_json(_ws, js, opts) {
        var o = opts || {};
        var offset = +!o.skipHeader;
        var ws = _ws || {};
        var _R = 0, _C = 0;
        if (ws && o.origin != null) {
          if (typeof o.origin == "number")
            _R = o.origin;
          else {
            var _origin = typeof o.origin == "string" ? decode_cell(o.origin) : o.origin;
            _R = _origin.r;
            _C = _origin.c;
          }
        }
        var cell;
        var range = { s: { c: 0, r: 0 }, e: { c: _C, r: _R + js.length - 1 + offset } };
        if (ws["!ref"]) {
          var _range = safe_decode_range(ws["!ref"]);
          range.e.c = Math.max(range.e.c, _range.e.c);
          range.e.r = Math.max(range.e.r, _range.e.r);
          if (_R == -1) {
            _R = _range.e.r + 1;
            range.e.r = _R + js.length - 1 + offset;
          }
        } else {
          if (_R == -1) {
            _R = 0;
            range.e.r = js.length - 1 + offset;
          }
        }
        var hdr = o.header || [], C = 0;
        js.forEach(function(JS, R) {
          keys3(JS).forEach(function(k) {
            if ((C = hdr.indexOf(k)) == -1)
              hdr[C = hdr.length] = k;
            var v = JS[k];
            var t3 = "z";
            var z = "";
            var ref = encode_cell({ c: _C + C, r: _R + R + offset });
            cell = ws_get_cell_stub(ws, ref);
            if (v && typeof v === "object" && !(v instanceof Date)) {
              ws[ref] = v;
            } else {
              if (typeof v == "number")
                t3 = "n";
              else if (typeof v == "boolean")
                t3 = "b";
              else if (typeof v == "string")
                t3 = "s";
              else if (v instanceof Date) {
                t3 = "d";
                if (!o.cellDates) {
                  t3 = "n";
                  v = datenum(v);
                }
                z = o.dateNF || table_fmt[14];
              } else if (v === null && o.nullError) {
                t3 = "e";
                v = 0;
              }
              if (!cell)
                ws[ref] = cell = { t: t3, v };
              else {
                cell.t = t3;
                cell.v = v;
                delete cell.w;
                delete cell.R;
                if (z)
                  cell.z = z;
              }
              if (z)
                cell.z = z;
            }
          });
        });
        range.e.c = Math.max(range.e.c, _C + hdr.length - 1);
        var __R = encode_row(_R);
        if (offset)
          for (C = 0; C < hdr.length; ++C)
            ws[encode_col(C + _C) + __R] = { t: "s", v: hdr[C] };
        ws["!ref"] = encode_range(range);
        return ws;
      }
      function json_to_sheet(js, opts) {
        return sheet_add_json(null, js, opts);
      }
      function ws_get_cell_stub(ws, R, C) {
        if (typeof R == "string") {
          if (Array.isArray(ws)) {
            var RC = decode_cell(R);
            if (!ws[RC.r])
              ws[RC.r] = [];
            return ws[RC.r][RC.c] || (ws[RC.r][RC.c] = { t: "z" });
          }
          return ws[R] || (ws[R] = { t: "z" });
        }
        if (typeof R != "number")
          return ws_get_cell_stub(ws, encode_cell(R));
        return ws_get_cell_stub(ws, encode_cell({ r: R, c: C || 0 }));
      }
      function wb_sheet_idx(wb, sh) {
        if (typeof sh == "number") {
          if (sh >= 0 && wb.SheetNames.length > sh)
            return sh;
          throw new Error("Cannot find sheet # " + sh);
        } else if (typeof sh == "string") {
          var idx = wb.SheetNames.indexOf(sh);
          if (idx > -1)
            return idx;
          throw new Error("Cannot find sheet name |" + sh + "|");
        } else
          throw new Error("Cannot find sheet |" + sh + "|");
      }
      function book_new() {
        return { SheetNames: [], Sheets: {} };
      }
      function book_append_sheet(wb, ws, name, roll) {
        var i = 1;
        if (!name) {
          for (; i <= 65535; ++i, name = void 0)
            if (wb.SheetNames.indexOf(name = "Sheet" + i) == -1)
              break;
        }
        if (!name || wb.SheetNames.length >= 65535)
          throw new Error("Too many worksheets");
        if (roll && wb.SheetNames.indexOf(name) >= 0) {
          var m = name.match(/(^.*?)(\d+)$/);
          i = m && +m[2] || 0;
          var root2 = m && m[1] || name;
          for (++i; i <= 65535; ++i)
            if (wb.SheetNames.indexOf(name = root2 + i) == -1)
              break;
        }
        check_ws_name(name);
        if (wb.SheetNames.indexOf(name) >= 0)
          throw new Error("Worksheet with name |" + name + "| already exists!");
        wb.SheetNames.push(name);
        wb.Sheets[name] = ws;
        return name;
      }
      function book_set_sheet_visibility(wb, sh, vis) {
        if (!wb.Workbook)
          wb.Workbook = {};
        if (!wb.Workbook.Sheets)
          wb.Workbook.Sheets = [];
        var idx = wb_sheet_idx(wb, sh);
        if (!wb.Workbook.Sheets[idx])
          wb.Workbook.Sheets[idx] = {};
        switch (vis) {
          case 0:
          case 1:
          case 2:
            break;
          default:
            throw new Error("Bad sheet visibility setting " + vis);
        }
        wb.Workbook.Sheets[idx].Hidden = vis;
      }
      function cell_set_number_format(cell, fmt) {
        cell.z = fmt;
        return cell;
      }
      function cell_set_hyperlink(cell, target, tooltip) {
        if (!target) {
          delete cell.l;
        } else {
          cell.l = { Target: target };
          if (tooltip)
            cell.l.Tooltip = tooltip;
        }
        return cell;
      }
      function cell_set_internal_link(cell, range, tooltip) {
        return cell_set_hyperlink(cell, "#" + range, tooltip);
      }
      function cell_add_comment(cell, text, author) {
        if (!cell.c)
          cell.c = [];
        cell.c.push({ t: text, a: author || "SheetJS" });
      }
      function sheet_set_array_formula(ws, range, formula, dynamic) {
        var rng = typeof range != "string" ? range : safe_decode_range(range);
        var rngstr = typeof range == "string" ? range : encode_range(range);
        for (var R = rng.s.r; R <= rng.e.r; ++R)
          for (var C = rng.s.c; C <= rng.e.c; ++C) {
            var cell = ws_get_cell_stub(ws, R, C);
            cell.t = "n";
            cell.F = rngstr;
            delete cell.v;
            if (R == rng.s.r && C == rng.s.c) {
              cell.f = formula;
              if (dynamic)
                cell.D = true;
            }
          }
        return ws;
      }
      var utils2 = {
        encode_col,
        encode_row,
        encode_cell,
        encode_range,
        decode_col,
        decode_row,
        split_cell,
        decode_cell,
        decode_range,
        format_cell,
        sheet_add_aoa,
        sheet_add_json,
        sheet_add_dom,
        aoa_to_sheet,
        json_to_sheet,
        table_to_sheet: parse_dom_table,
        table_to_book,
        sheet_to_csv,
        sheet_to_txt,
        sheet_to_json,
        sheet_to_html,
        sheet_to_formulae,
        sheet_to_row_object_array: sheet_to_json,
        sheet_get_cell: ws_get_cell_stub,
        book_new,
        book_append_sheet,
        book_set_sheet_visibility,
        cell_set_number_format,
        cell_set_hyperlink,
        cell_set_internal_link,
        cell_add_comment,
        sheet_set_array_formula,
        consts: {
          SHEET_VISIBLE: 0,
          SHEET_HIDDEN: 1,
          SHEET_VERY_HIDDEN: 2
        }
      };
      var _Readable;
      function set_readable(R) {
        _Readable = R;
      }
      function write_csv_stream(sheet, opts) {
        var stream = _Readable();
        var o = opts == null ? {} : opts;
        if (sheet == null || sheet["!ref"] == null) {
          stream.push(null);
          return stream;
        }
        var r = safe_decode_range(sheet["!ref"]);
        var FS = o.FS !== void 0 ? o.FS : ",", fs2 = FS.charCodeAt(0);
        var RS = o.RS !== void 0 ? o.RS : "\n", rs = RS.charCodeAt(0);
        var endregex = new RegExp((FS == "|" ? "\\|" : FS) + "+$");
        var row = "", cols = [];
        o.dense = Array.isArray(sheet);
        var colinfo = o.skipHidden && sheet["!cols"] || [];
        var rowinfo = o.skipHidden && sheet["!rows"] || [];
        for (var C = r.s.c; C <= r.e.c; ++C)
          if (!(colinfo[C] || {}).hidden)
            cols[C] = encode_col(C);
        var R = r.s.r;
        var BOM = false, w = 0;
        stream._read = function() {
          if (!BOM) {
            BOM = true;
            return stream.push("\uFEFF");
          }
          while (R <= r.e.r) {
            ++R;
            if ((rowinfo[R - 1] || {}).hidden)
              continue;
            row = make_csv_row(sheet, r, R - 1, cols, fs2, rs, FS, o);
            if (row != null) {
              if (o.strip)
                row = row.replace(endregex, "");
              if (row || o.blankrows !== false)
                return stream.push((w++ ? RS : "") + row);
            }
          }
          return stream.push(null);
        };
        return stream;
      }
      function write_html_stream(ws, opts) {
        var stream = _Readable();
        var o = opts || {};
        var header = o.header != null ? o.header : HTML_BEGIN;
        var footer = o.footer != null ? o.footer : HTML_END;
        stream.push(header);
        var r = decode_range(ws["!ref"]);
        o.dense = Array.isArray(ws);
        stream.push(make_html_preamble(ws, r, o));
        var R = r.s.r;
        var end = false;
        stream._read = function() {
          if (R > r.e.r) {
            if (!end) {
              end = true;
              stream.push("</table>" + footer);
            }
            return stream.push(null);
          }
          while (R <= r.e.r) {
            stream.push(make_html_row(ws, r, R, o));
            ++R;
            break;
          }
        };
        return stream;
      }
      function write_json_stream(sheet, opts) {
        var stream = _Readable({ objectMode: true });
        if (sheet == null || sheet["!ref"] == null) {
          stream.push(null);
          return stream;
        }
        var val = { t: "n", v: 0 }, header = 0, offset = 1, hdr = [], v = 0, vv = "";
        var r = { s: { r: 0, c: 0 }, e: { r: 0, c: 0 } };
        var o = opts || {};
        var range = o.range != null ? o.range : sheet["!ref"];
        if (o.header === 1)
          header = 1;
        else if (o.header === "A")
          header = 2;
        else if (Array.isArray(o.header))
          header = 3;
        switch (typeof range) {
          case "string":
            r = safe_decode_range(range);
            break;
          case "number":
            r = safe_decode_range(sheet["!ref"]);
            r.s.r = range;
            break;
          default:
            r = range;
        }
        if (header > 0)
          offset = 0;
        var rr = encode_row(r.s.r);
        var cols = [];
        var counter = 0;
        var dense = Array.isArray(sheet);
        var R = r.s.r, C = 0;
        var header_cnt = {};
        if (dense && !sheet[R])
          sheet[R] = [];
        var colinfo = o.skipHidden && sheet["!cols"] || [];
        var rowinfo = o.skipHidden && sheet["!rows"] || [];
        for (C = r.s.c; C <= r.e.c; ++C) {
          if ((colinfo[C] || {}).hidden)
            continue;
          cols[C] = encode_col(C);
          val = dense ? sheet[R][C] : sheet[cols[C] + rr];
          switch (header) {
            case 1:
              hdr[C] = C - r.s.c;
              break;
            case 2:
              hdr[C] = cols[C];
              break;
            case 3:
              hdr[C] = o.header[C - r.s.c];
              break;
            default:
              if (val == null)
                val = { w: "__EMPTY", t: "s" };
              vv = v = format_cell(val, null, o);
              counter = header_cnt[v] || 0;
              if (!counter)
                header_cnt[v] = 1;
              else {
                do {
                  vv = v + "_" + counter++;
                } while (header_cnt[vv]);
                header_cnt[v] = counter;
                header_cnt[vv] = 1;
              }
              hdr[C] = vv;
          }
        }
        R = r.s.r + offset;
        stream._read = function() {
          while (R <= r.e.r) {
            if ((rowinfo[R - 1] || {}).hidden)
              continue;
            var row = make_json_row(sheet, r, R, cols, header, hdr, dense, o);
            ++R;
            if (row.isempty === false || (header === 1 ? o.blankrows !== false : !!o.blankrows)) {
              stream.push(row.row);
              return;
            }
          }
          return stream.push(null);
        };
        return stream;
      }
      var __stream = {
        to_json: write_json_stream,
        to_html: write_html_stream,
        to_csv: write_csv_stream,
        set_readable
      };
      if (typeof parse_xlscfb !== "undefined")
        XLSX2.parse_xlscfb = parse_xlscfb;
      XLSX2.parse_zip = parse_zip;
      XLSX2.read = readSync;
      XLSX2.readFile = readFileSync;
      XLSX2.readFileSync = readFileSync;
      XLSX2.write = writeSync;
      XLSX2.writeFile = writeFileSync;
      XLSX2.writeFileSync = writeFileSync;
      XLSX2.writeFileAsync = writeFileAsync;
      XLSX2.utils = utils2;
      XLSX2.writeXLSX = writeSyncXLSX;
      XLSX2.writeFileXLSX = writeFileSyncXLSX;
      XLSX2.SSF = SSF;
      if (typeof __stream !== "undefined")
        XLSX2.stream = __stream;
      if (typeof CFB !== "undefined")
        XLSX2.CFB = CFB;
      if (typeof require !== "undefined") {
        var strmod = require("stream");
        if ((strmod || {}).Readable)
          set_readable(strmod.Readable);
      }
    }
    if (typeof exports !== "undefined")
      make_xlsx_lib(exports);
    else if (typeof module2 !== "undefined" && module2.exports)
      make_xlsx_lib(module2.exports);
    else if (typeof define === "function" && define.amd)
      define("xlsx", function() {
        if (!XLSX.version)
          make_xlsx_lib(XLSX);
        return XLSX;
      });
    else
      make_xlsx_lib(XLSX);
    if (typeof window !== "undefined" && !window.XLSX)
      try {
        window.XLSX = XLSX;
      } catch (e) {
      }
  }
});

// src/bin/index.ts
var import_commander = __toESM(require_commander());
var import_lodash5 = __toESM(require_lodash());

// package.json
var version = "3.0.8";

// src/bin/transform.ts
var import_chalk2 = __toESM(require_source());
var import_path = __toESM(require("path"));
var import_fs = __toESM(require("fs"));
var import_glob = __toESM(require_glob());
var import_ora = __toESM(require_ora());
var import_inquirer = __toESM(require_inquirer());

// src/core/parser.ts
var import_parser = __toESM(require_lib2());
var import_vue_eslint_parser_private = __toESM(require_vue_eslint_parser_private());
var import_lodash2 = __toESM(require_lodash());

// src/core/constants.ts
var IgnoreFileCode = "code-i18n-disabled";
var IgnoreNextLineCode = "code-i18n-disabled-next-line";
var AnchorToken = "$$$hq0109$$$";

// src/utils/index.ts
var import_core = __toESM(require_lib28());
var import_lodash = __toESM(require_lodash());
var import_helper_module_imports = __toESM(require_lib32());
var t = __toESM(require_lib11());
function isContainChinese(str) {
  return /[\u4e00-\u9fa5]/.test(str);
}
function isIgnoreLine(ignoreLine, node) {
  if (node.loc && ignoreLine[node.loc.start.line]) {
    return false;
  }
  return true;
}
function formatLocation(content, location) {
  const c = content.split("\n");
  let ret = 0;
  for (let i = 0; i < location.line - 1; i++) {
    ret += c[i].length + 1;
  }
  ret += location.column;
  return ret;
}
function minmax(...position) {
  return [(0, import_lodash.min)(position), (0, import_lodash.max)(position)];
}
function isObjectKey(path2) {
  if (path2.parentPath.isObjectProperty()) {
    const key = path2.parentPath.get("key");
    if (key.isStringLiteral() && key.node.value === path2.node.value) {
      return true;
    }
  }
  return false;
}
function isContainChineseWithAst(ast, ignoreLine) {
  let ret = false;
  const changeResult = (path2) => {
    ret = true;
    path2.stop();
  };
  (0, import_core.traverse)(ast, {
    StringLiteral(path2) {
      if (isContainChinese(path2.node.value) && isIgnoreLine(ignoreLine, path2.node) && !isObjectKey(path2)) {
        changeResult(path2);
      }
    },
    TemplateLiteral(path2) {
      if (path2.node.quasis.find((quasi) => isContainChinese(quasi.value.raw)) && isIgnoreLine(ignoreLine, path2.node)) {
        changeResult(path2);
      }
    },
    JSXText(path2) {
      if (isContainChinese(path2.node.value) && isIgnoreLine(ignoreLine, path2.node)) {
        changeResult(path2);
      }
    },
    JSXAttribute(path2) {
      const { value: value2 } = path2.node;
      if (t.isStringLiteral(value2) && isContainChinese(value2.value) && isIgnoreLine(ignoreLine, path2.node)) {
        changeResult(path2);
      }
    }
  });
  return ret;
}
function findFunctionCompNodePath(path2) {
  return path2.findParent((parentPath) => {
    const funDeclaration = parentPath.isFunctionDeclaration() || parentPath.isArrowFunctionExpression();
    if (funDeclaration) {
      if (t.isExpression(parentPath.node.body)) {
        return t.isJSXElement(parentPath.node.body);
      }
      const returnNode = parentPath.node.body.body.find(
        (item) => t.isReturnStatement(item)
      );
      return t.isJSXElement(returnNode.argument);
    }
    return false;
  });
}
function findAndInsertScopeIdentifierWithFunctionBody(path2, name, i18nFunctionName, funcPath, callExpressionIdentifier) {
  const node = (0, import_lodash.values)(path2.scope.bindings).find((item) => {
    const node2 = item.path.node;
    return t.isVariableDeclarator(node2) && t.isCallExpression(node2.init) && t.isIdentifier(node2.init.callee) && node2.init.callee.name === name;
  });
  if (node) {
    return node.identifier;
  } else {
    const identifier3 = t.identifier(i18nFunctionName);
    const node2 = t.variableDeclaration("const", [
      t.variableDeclarator(
        t.objectPattern([t.objectProperty(identifier3, identifier3, false, true)]),
        t.callExpression(callExpressionIdentifier || t.identifier(name), [])
      )
    ]);
    if ((0, import_lodash.isNull)(funcPath)) {
      const blockPath = path2.findParent((parentPath) => {
        return parentPath.isProgram();
      });
      if (blockPath) {
        blockPath.node.body.splice(1, 0, node2);
      }
    } else {
      const body = funcPath.get("body").get("body");
      if ((0, import_lodash.isArray)(body)) {
        body[0].insertBefore(node2);
      } else {
        const ret = funcPath.get("body");
        if (!t.isBlockStatement(ret.node)) {
          funcPath.set("body", t.blockStatement([node2, t.returnStatement(ret.node)]));
        }
      }
    }
    return identifier3;
  }
}
function insertCallExpressionWithFunctionBody(path2, i18nHookName, i18nFunctionName, callExpressionIdentifier, experimental, type, isVueSetup) {
  if (!experimental) {
    return null;
  }
  if (type === "js") {
    return callExpressionIdentifier;
  }
  let identifier3 = null;
  const functionDeclaration = findFunctionCompNodePath(path2);
  if (functionDeclaration || isVueSetup) {
    identifier3 = findAndInsertScopeIdentifierWithFunctionBody(
      path2,
      i18nHookName,
      i18nFunctionName,
      functionDeclaration,
      callExpressionIdentifier
    );
  }
  return identifier3;
}
function insertIfNotExitI18nLib(path2, i18nLibName, i18nHookName, i18nFunctionName, type) {
  const program2 = t.isFile(path2) ? path2 : path2.findParent((path3) => path3.isProgram())?.node;
  let hasImport = false, count = 0, identifier3 = null, name = i18nHookName;
  if (type === "js") {
    name = i18nFunctionName;
  }
  (0, import_core.traverse)(program2, {
    ImportDeclaration() {
      hasImport = true;
      count++;
    }
  });
  (0, import_core.traverse)(program2, {
    ImportDeclaration(path3) {
      count--;
      if (path3.node.source.value === i18nLibName) {
        const specifiers = path3.node.specifiers.filter((item) => t.isImportSpecifier(item));
        if (!specifiers.find((item) => item.local.name === name)) {
          identifier3 = path3.scope.generateDeclaredUidIdentifier(name);
          const useTranslationSpecifier = t.importSpecifier(t.identifier(name), identifier3);
          path3.node.specifiers.push(useTranslationSpecifier);
          path3.replaceWith(path3.node);
        }
      } else if (count === 0) {
        identifier3 = (0, import_helper_module_imports.addNamed)(path3, name, i18nLibName);
        path3.stop();
      }
    }
  });
  if (!hasImport) {
    (0, import_core.traverse)(program2, {
      Program(path3) {
        identifier3 = (0, import_helper_module_imports.addNamed)(path3, name, i18nLibName);
        path3.stop();
      }
    });
  }
  return identifier3;
}

// src/core/parser.ts
var Plugins = {
  js: [],
  vue: [],
  jsx: ["jsx"],
  ts: ["typescript"],
  tsx: ["jsx", "typescript"]
};
var Parser = class {
  origin;
  content;
  type;
  ast;
  parserOptions;
  astVueTemplate;
  vueScriptContent;
  ignoreLine;
  ignoreFile;
  constructor(props) {
    const DEFAULT_PARSER_OPTIONS = {
      // https://github.com/eslint/espree#options
      vue: {
        sourceType: "module",
        ecmaVersion: 11,
        ecmaFeatures: {
          experimentalObjectRestSpread: true
        }
      },
      babel: {
        sourceType: "module"
      }
    };
    this.parserOptions = (0, import_lodash2.merge)(DEFAULT_PARSER_OPTIONS, props.parserOptions);
    this.origin = props.content;
    this.content = props.content;
    this.type = props.type;
    this.ignoreLine = {};
    if (this.isVue) {
      const ast = this._parserVue();
      if (ast.body.length) {
        const body = ast.body;
        const position = [];
        if (ast.comments?.length) {
          position.push(
            formatLocation(this.content, (0, import_lodash2.first)(ast.comments).loc.start),
            formatLocation(this.content, (0, import_lodash2.last)(ast.comments).loc.end)
          );
        }
        position.push(
          formatLocation(this.content, (0, import_lodash2.first)(body).loc.start),
          formatLocation(this.content, (0, import_lodash2.last)(body).loc.end) + 1
        );
        const [start, end] = minmax(...position);
        this.vueScriptContent = this.content.slice(start, end);
        this.ast = this._parserByBabel(this.vueScriptContent, Plugins["tsx"]);
        this.content = this.content.slice(0, start) + AnchorToken + this.content.slice(end);
      }
      this.astVueTemplate = this._parserVue();
    } else {
      this.ast = this._parserByBabel();
    }
    this._comment();
  }
  get isVue() {
    return this.type === "vue";
  }
  get isVueSetup() {
    return this.content.includes("<script setup");
  }
  get isReact() {
    return this.type === "jsx" || this.type === "tsx";
  }
  get isJS() {
    return this.type === "js";
  }
  get realContent() {
    return this.vueScriptContent || this.content;
  }
  _parserVue() {
    return (0, import_vue_eslint_parser_private.parse)(this.content, this.parserOptions.vue);
  }
  _parserByBabel(content, plugin) {
    const options = this.parserOptions.babel;
    options.plugins = (plugin || []).concat(options.plugins || []).concat(Plugins[this.type]);
    return (0, import_parser.parse)(content || this.content, options);
  }
  _comment() {
    const { comments } = this.ast || { comments: null };
    if (comments && comments.length) {
      const ignore = comments.find((item) => item.value.trim() === IgnoreFileCode);
      if (ignore) {
        this.ignoreFile = {
          code: this.origin,
          stack: []
        };
      }
      comments.forEach((comment) => {
        this.ignoreLine[comment.loc.start.line + 1] = comment.value.trim() === IgnoreNextLineCode;
      });
    }
  }
};

// src/core/transform.ts
var import_lodash3 = __toESM(require_lodash());
var import_generator = __toESM(require_lib14());
var import_traverse = __toESM(require_lib20());

// src/core/vue.ts
var import_vue_eslint_parser_private2 = __toESM(require_vue_eslint_parser_private());
var VueHelpers = class {
  map;
  parser;
  options;
  identifier = "$t";
  stack;
  content;
  constructor(parser, options) {
    this.map = /* @__PURE__ */ new Map();
    this.options = options;
    this.parser = parser;
    this.stack = [];
    this.content = this.parser.content;
    this.identifier = this.options?.identifier || this.identifier;
  }
  _renderKey(ast, value2) {
    const loc = ast.loc;
    return this.options?.ruleKey ? this.options.ruleKey(ast, this.options.path, value2) : `${ast.type}_${loc.start.line}_${loc.start.column}_${loc.end.line}_${loc.end.column}`;
  }
  _generate() {
    const stack = [];
    const map = [...this.map.entries()];
    let code = this.content;
    for (const [k, v] of map) {
      code = code.slice(0, k.range[0]) + v + code.slice(k.range[1]);
      stack.push({
        [k.key]: k.language
      });
      for (let i = 0; i < map.length; i++) {
        const [k1] = map[i];
        if (k1.range[0] > k.range[1]) {
          const diff = k.length - (k.sourceLength || k.source.length);
          const range = [k1.range[0] + diff, k1.range[1] + diff];
          map[i][0] = {
            ...map[i][0],
            range
          };
        }
        if (k1.range[0] > k.range[0] && k1.range[1] < k.range[1]) {
          const diff = code.indexOf(k1.source);
          const range = [diff, diff + k1.source.length];
          map[i][0] = {
            ...map[i][0],
            range
          };
        }
      }
    }
    this.map = /* @__PURE__ */ new Map();
    this.stack.push(...stack);
    this.content = code;
    return {
      code,
      stack: this.stack
    };
  }
  _traverseTemplateBody(ast) {
    if (!isContainChinese(ast.value)) {
      return;
    }
    if (!isIgnoreLine(this.parser.ignoreLine, ast)) {
      return;
    }
    const key = this._renderKey(ast, ast.value);
    if (ast.type === "VText") {
      const v = `{{${this.identifier}('${key}')}}`;
      const sourceLength = this.parser.content.slice(ast.range[0], ast.range[1]).length;
      this.map.set(
        {
          type: "VText",
          source: ast.value,
          sourceLength,
          range: ast.range,
          key,
          language: ast.value,
          length: v.length
        },
        v
      );
    }
    if (ast.type === "VLiteral") {
      const rawkey = ast.parent.key.rawName;
      const source = this.parser.content.slice(ast.parent.range[0], ast.parent.range[1]);
      const v = `:${rawkey}="${this.identifier}('${key}')"`;
      this.map.set(
        {
          type: "VLiteral",
          source,
          range: ast.parent.range,
          key,
          language: ast.value,
          length: v.length
        },
        v
      );
    }
    if (ast.type === "Literal") {
      const source = ast.raw;
      const v = `${this.identifier}('${key}')`;
      this.map.set(
        {
          type: "Literal",
          source,
          range: ast.range,
          key,
          language: source.slice(1, -1),
          length: v.length
        },
        v
      );
    }
  }
  _traverseTemplateLiteral(ast) {
    if (ast.quasis.find((quasi) => isContainChinese(quasi.value.raw)) && isIgnoreLine(this.parser.ignoreLine, ast)) {
      const content = this.content;
      const source = content.slice(ast.start, ast.end);
      const args = ast.expressions.map((expression) => {
        return content.slice(expression.start, expression.end);
      });
      let language = source, i = 0;
      args.map((arg) => {
        const regexp = new RegExp(
          `\\$\\{.{0,}${arg.split("").map((item) => /[\da-zA-Z]/.test(item) ? item : "\\" + item).join("").slice(2)}.{0,}\\}`
        );
        language = language.replace(regexp, `{${i++}}`);
      });
      const key = this._renderKey(ast, language);
      const v = `${this.identifier}('${key}'${args.length ? "," : ""} ${args.join(", ")})`;
      this.map.set(
        {
          type: "TemplateLiteral",
          source,
          range: ast.range,
          key,
          language: language.slice(1, -1),
          length: v.length
        },
        v
      );
    }
  }
  _traverse(ast, keys3) {
    const self2 = this;
    (0, import_vue_eslint_parser_private2.traverseNodes)(ast, {
      visitorKeys: keys3.reduce((prev, curr) => {
        prev[curr] = [curr];
        return prev;
      }, {}),
      enterNode(node, parent) {
        if (keys3.includes(node.type) && node.type === "TemplateLiteral") {
          self2._traverseTemplateLiteral(node);
        } else {
          self2._traverseTemplateBody(node);
        }
      },
      leaveNode(node, parent) {
      }
    });
  }
  _transform() {
    this._traverse(this.parser.astVueTemplate, ["Literal", "VText", "VAttribute", "VLiteral"]);
    const { code } = this._generate();
    const ast = (0, import_vue_eslint_parser_private2.parse)(code, this.parser.parserOptions.vue);
    this._traverse(ast, ["TemplateLiteral"]);
  }
  generate(scriptRet) {
    this._transform();
    const templateRet = this._generate();
    templateRet.code = templateRet.code.replace(AnchorToken, scriptRet.code + "\n");
    templateRet.stack = templateRet.stack.concat(scriptRet.stack);
    templateRet.ast = scriptRet.ast;
    return templateRet;
  }
};

// src/core/transform.ts
var t2 = __toESM(require_lib11());
var defaultRenderOptions = {
  retainLines: true,
  jsescOption: {
    quotes: "single"
  }
};
var defaultOptions = {
  react: {
    i18n: "i18next",
    i18nLibName: "react-i18next",
    i18nHookName: "useTranslation",
    i18nFunctionName: "t"
  },
  experimental: false
};
var Transform = class {
  parser;
  options;
  stack;
  identifier = "$t";
  VueHelpers;
  constructor(parser, options) {
    this.parser = parser;
    this.options = (0, import_lodash3.merge)((0, import_lodash3.cloneDeep)(defaultOptions), options);
    this.identifier = this.options?.identifier || this.identifier;
    this.stack = [];
    this.VueHelpers = new VueHelpers(parser, options);
  }
  _key(node, value2) {
    const loc = node.loc;
    return this.options?.ruleKey ? this.options.ruleKey(node, this.options.path, value2) : `${node.type}_${loc.start.line}_${loc.start.column}_${loc.end.line}_${loc.end.column}`;
  }
  _StringFunction(node, identifier3) {
    const key = String(this._key(node, node.value));
    this.stack.push({
      [key]: node.value
    });
    return t2.callExpression(identifier3 || t2.identifier(this.identifier), [t2.stringLiteral(key)]);
  }
  _TemplateFunction(node, identifier3) {
    const args = [];
    let index = 0;
    const value2 = [...node.expressions, ...node.quasis].sort((a, b) => {
      return a.end - b.start;
    }).map((item) => {
      if (t2.isTemplateElement(item)) {
        return item.value.raw;
      }
      return `{${index++}}`;
    });
    const key = String(this._key(node, value2.join("")));
    this.stack.push({
      [key]: value2.join("")
    });
    node.expressions.map((expression) => {
      if (!t2.isTSType(expression)) {
        args.push(expression);
      }
    });
    return t2.callExpression(identifier3 || t2.identifier(this.identifier), [
      t2.stringLiteral(key),
      ...args
    ]);
  }
  _JSXTextFunction(node, identifier3) {
    const key = String(this._key(node, node.value));
    this.stack.push({
      [key]: node.value
    });
    return t2.jSXExpressionContainer(
      t2.callExpression(identifier3 || t2.identifier(this.identifier), [t2.stringLiteral(key)])
    );
  }
  _JSXAttributeFunction(node, identifier3) {
    const value2 = node.value.value;
    const key = String(this._key(node, value2));
    this.stack.push({
      [key]: value2
    });
    const valueNode = t2.jSXExpressionContainer(
      t2.callExpression(identifier3 || t2.identifier(this.identifier), [t2.stringLiteral(key)])
    );
    return t2.jSXAttribute(node.name, valueNode);
  }
  _transform() {
    const { i18nHookName, i18nFunctionName, i18nLibName } = this.options.react;
    const { isVueSetup, type, ignoreLine } = this.parser;
    const experimental = this.options.experimental;
    const ast = (0, import_lodash3.cloneDeep)(this.parser.ast);
    const self2 = this;
    let callExpressionIdentifier = null;
    if (experimental && isContainChineseWithAst(ast, ignoreLine)) {
      callExpressionIdentifier = insertIfNotExitI18nLib(
        ast,
        i18nLibName,
        i18nHookName,
        i18nFunctionName,
        type
      );
    }
    (0, import_traverse.default)(ast, {
      StringLiteral(path2) {
        if (isContainChinese(path2.node.value) && isIgnoreLine(ignoreLine, path2.node) && !isObjectKey(path2)) {
          const identifier3 = insertCallExpressionWithFunctionBody(
            path2,
            i18nHookName,
            i18nFunctionName,
            callExpressionIdentifier,
            experimental,
            type,
            isVueSetup
          );
          path2.replaceWith(self2._StringFunction(path2.node, identifier3));
        }
      },
      TemplateLiteral(path2) {
        if (path2.node.quasis.find((quasi) => isContainChinese(quasi.value.raw)) && isIgnoreLine(ignoreLine, path2.node)) {
          const identifier3 = insertCallExpressionWithFunctionBody(
            path2,
            i18nHookName,
            i18nFunctionName,
            callExpressionIdentifier,
            experimental,
            type,
            isVueSetup
          );
          path2.replaceWith(self2._TemplateFunction(path2.node, identifier3));
        }
      },
      JSXText(path2) {
        if (isContainChinese(path2.node.value) && isIgnoreLine(ignoreLine, path2.node)) {
          const identifier3 = insertCallExpressionWithFunctionBody(
            path2,
            i18nHookName,
            i18nFunctionName,
            callExpressionIdentifier,
            experimental,
            type,
            isVueSetup
          );
          path2.replaceWith(self2._JSXTextFunction(path2.node, identifier3));
        }
      },
      JSXAttribute(path2) {
        const { value: value2 } = path2.node;
        if (t2.isStringLiteral(value2) && isContainChinese(value2.value) && isIgnoreLine(ignoreLine, path2.node)) {
          const identifier3 = insertCallExpressionWithFunctionBody(
            path2,
            i18nHookName,
            i18nFunctionName,
            callExpressionIdentifier,
            experimental,
            type,
            isVueSetup
          );
          path2.replaceWith(self2._JSXAttributeFunction(path2.node, identifier3));
        }
      }
    });
    return ast;
  }
  _generate(ast, options) {
    const { code } = (0, import_generator.default)(ast, options, this.parser.realContent);
    return {
      code,
      stack: this.stack,
      ast
    };
  }
  render(options = defaultRenderOptions) {
    if (this.parser.ignoreFile) {
      return this.parser.ignoreFile;
    }
    const ast = this._transform();
    const config = (0, import_lodash3.merge)(defaultRenderOptions, options || {});
    const babelRet = this._generate(ast, config);
    if (this.parser.isVue) {
      return this.VueHelpers.generate(babelRet);
    }
    return babelRet;
  }
};

// src/index.ts
function transformCode(code, config) {
  const parser = new Parser({
    content: code,
    type: config.type,
    parserOptions: config.parserOptions
  });
  const transform = new Transform(parser, config);
  return transform.render(config.generatorOptions);
}

// src/bin/transform.ts
var import_lodash4 = __toESM(require_lodash());
var import_prettier = __toESM(require_prettier());

// src/utils/assert.ts
var import_chalk = __toESM(require_source());
function log(...message) {
  console.log(`${import_chalk.default.blue(`[${Date.now()}] [Log] Debug `)}`, ...message);
}

// src/bin/transform.ts
var import_xlsx = __toESM(require_xlsx());
var root = process.cwd();
var spinner = (0, import_ora.default)();
function checkFileExist(path2) {
  return new Promise((r) => {
    import_fs.default.access(path2, (err) => {
      return r(!err);
    });
  }).catch((e) => {
    console.log(import_chalk2.default.red(e));
  });
}
function crop(s) {
  return s.length > 36 ? s.slice(0, 18) + " ...... " + s.slice(-18) : s;
}
function writeLanguage(stackPath, language) {
  try {
    const data = JSON.stringify(language);
    const isOutputJson = /\.json$/.test(stackPath);
    if (isOutputJson) {
      import_fs.default.writeFileSync(
        stackPath,
        (0, import_prettier.format)(data, {
          parser: "json"
        })
      );
    } else {
      const sheetData = Object.entries(language).reduce((acc, [key, text]) => {
        acc.push({
          key,
          contentType: "text",
          zh: text,
          description: null,
          zh_TW: null,
          enSingle: null,
          enPlural: null
        });
        return acc;
      }, []);
      const wb = import_xlsx.utils.book_new();
      import_xlsx.utils.book_append_sheet(wb, import_xlsx.utils.json_to_sheet(sheetData), "sheet1");
      (0, import_xlsx.writeFile)(wb, stackPath);
    }
    console.log(import_chalk2.default.green("The language pack is written successfully, location: " + stackPath));
  } catch (e) {
    console.log(e);
  }
}
function writeCode(path2, code) {
  try {
    import_fs.default.writeFileSync(path2, code);
    console.log(import_chalk2.default.green(`The writing is successful, the file name is '${path2}'`));
  } catch (e) {
    console.log(e);
  }
}
async function formatOutput(message, { stack }) {
  const t3 = message.map(({ code, stack: stack2, name }) => {
    return {
      name: name || null,
      code: crop(code),
      stack: crop(stack2.map((s) => JSON.stringify(s)).join(","))
    };
  });
  console.table(t3);
  if (stack) {
    const stackPath = import_path.default.resolve(root, stack);
    const so = message.map((m) => m.stack).flat();
    let o = so.reduce((prev, cur) => {
      const k = (0, import_lodash4.keys)(cur)[0];
      prev[k] = cur[k];
      return prev;
    }, {});
    const have = await checkFileExist(stackPath);
    if (have) {
      import_inquirer.default.prompt({
        type: "list",
        name: "language",
        message: `The file already exists, please select the corresponding operation? (${stackPath})`,
        choices: ["cover" /* Cover */, "merge" /* Merge */, "interrupt" /* Interrupt */]
      }).then(({ language }) => {
        const answer = language;
        if (answer === "cover" /* Cover */) {
        }
        if (answer === "merge" /* Merge */) {
          try {
            o = Object.assign(o, require(stackPath));
          } catch (e) {
            console.log(e);
          }
        }
        if (answer === "interrupt" /* Interrupt */) {
          return;
        }
        writeLanguage(stackPath, o);
      });
    } else {
      writeLanguage(stackPath, o);
    }
  }
}
function transformFile(filename, write, config) {
  const filepath = import_path.default.resolve(root, filename);
  const filetype = import_path.default.extname(filepath).slice(1);
  const content = import_fs.default.readFileSync(filepath, "utf-8");
  let { code, stack, ast } = transformCode(content, {
    type: filetype,
    path: filepath,
    ...config
  });
  if (config.prettier && typeof config.prettier === "function") {
    code = config.prettier(code, ast);
  }
  if (typeof write === "string") {
    const codePath = import_path.default.resolve(root, write);
    writeCode(codePath, code);
  }
  if (typeof write === "boolean" && write) {
    writeCode(filepath, code);
  }
  return { code, stack };
}
function transformDirectory(dir, config) {
  spinner.start("Transform ...");
  const dirpath = import_path.default.resolve(root, dir);
  return new Promise((resolve, reject) => {
    (0, import_glob.default)(
      `**/*.${config.type}`,
      {
        cwd: dirpath,
        ignore: config.ignore
      },
      (err, matches) => {
        if (err) {
          reject(err);
        } else {
          const paths = matches.map((item) => import_path.default.join(dirpath, item));
          const content = paths.map((p) => import_fs.default.readFileSync(p, "utf-8"));
          const message = content.map(
            (item, index) => /[\u4e00-\u9fa5]/.test(item) ? { content: item, path: paths[index] } : false
          ).filter((a) => a).map((source) => {
            if (!source) {
              return;
            }
            try {
              if (config.debug) {
                log("Source: ", source);
              }
              let { code, stack, ast } = transformCode(source.content, {
                ...config,
                path: source.path
              });
              if (config.prettier && typeof config.prettier === "function") {
                code = config.prettier(code, ast);
              }
              if (config.write && stack.length > 0) {
                import_fs.default.writeFileSync(source.path, code, { encoding: "utf-8" });
              }
              return { code, stack, name: source.path };
            } catch (e) {
              spinner.fail(
                "Conversion failed " + import_chalk2.default.blue(source.path + ":\n") + JSON.stringify(e)
              );
            }
          }).filter((item) => {
            return item?.stack.length;
          });
          spinner.succeed("Successful conversion");
          resolve(message);
        }
      }
    );
  });
}
async function exec(command) {
  const configFile = import_path.default.resolve(root, ".code-i18n.js");
  let config = {
    write: false
  };
  if (command.config) {
    config = require(import_path.default.resolve(root, command.config));
  } else {
    const have = await checkFileExist(configFile);
    if (have) {
      config = require(configFile);
    }
  }
  config = (0, import_lodash4.merge)(config, (0, import_lodash4.cloneDeep)(command));
  if (config.debug) {
    log("Config: ", config);
  }
  if (["code", "name", "dir"].filter((item) => (0, import_lodash4.keys)(config).includes(item)).length >= 2) {
    console.log(import_chalk2.default.yellow("Only one of code, name, dir can be selected"));
    return;
  }
  if (config.code && !config.type) {
    console.log(import_chalk2.default.yellow("When using the optional code parameter, you must specify its type"));
    return;
  }
  if (config.dir && typeof config.write === "string") {
    console.log(import_chalk2.default.yellow("Cannot use --write(path) when using --dir"));
    return;
  }
  if (config.dir && !config.type) {
    console.log(
      import_chalk2.default.yellow(
        "When you specify the path, you must set its --type, let me know which files you need to convert"
      )
    );
    return;
  }
  if (config.type && !["js", "jsx", "ts", "tsx", "vue"].includes(config.type)) {
    console.log(
      import_chalk2.default.yellow(
        `The optional type parameter is ${config.type}, one of these must be specified ['js','jsx','ts','tsx','vue']`
      )
    );
    return;
  }
  if (config.code) {
    let { code, stack, ast } = transformCode(config.code, config);
    if (config.prettier && typeof config.prettier === "function") {
      code = config.prettier(code, ast);
    }
    if (typeof config.write === "string") {
      const filename = import_path.default.resolve(root, config.write);
      import_fs.default.writeFileSync(filename, code);
    }
    if (typeof config.write === "boolean" && config.write) {
      console.log(import_chalk2.default.yellow("When using --code, --write needs to specify the path"));
    }
    formatOutput([{ code, stack }], config);
  }
  if (config.name) {
    const { code, stack } = transformFile(config.name, config.write, config);
    formatOutput([{ code, stack, name: config.name }], config);
  }
  if (config.dir) {
    if (config.type) {
      config = (0, import_lodash4.merge)(config, { type: config.type });
    }
    const message = await transformDirectory(config.dir, config);
    formatOutput(message, config);
    if (config.write) {
      console.log(
        import_chalk2.default.green(`The writing is successful, and the following path is '${config.dir}'`)
      );
    }
  }
}

// src/bin/index.ts
var program = new import_commander.Command();
program.version(version, "-v, --version");
program.name("code-i18n").usage("[options]");
program.description("Convert your code to help you code quickly (internationalization)").allowUnknownOption().option("--debug", "Output more information for debugging the program", false).option(
  "-e,  --experimental",
  "Experimental features, such as automatic node insertion, arrow expression replacement, etc. Disabled by default.",
  false
).option("--config <path>", "Specify the configuration file").option("-c, --code <code>", "Convert the specified code").option("-n, --name <file name>", "Convert the specified file").option("-d, --dir <directory>", "Convert files under the specified path").option(
  "-s, --stack <file name>",
  "Specify the output location of the collected language pack (json)"
).option(
  "-w, --write [path]",
  "Specify the write path (only used in --code and --name) or overwrite the current file",
  false
).option(
  "-t, --type <js | jsx | ts | tsx | vue>",
  "Specify the current code type, must be specified when using --code"
).action((command) => {
  if (isEmpty(command)) {
    program.outputHelp();
  } else {
    exec(command);
  }
}).parse(process.argv);
function isEmpty(command) {
  return (0, import_lodash5.keys)(command).length <= 2;
}
/*! Bundled license information:

lodash/lodash.js:
  (**
   * @license
   * Lodash <https://lodash.com/>
   * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
   * Released under MIT license <https://lodash.com/license>
   * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
   * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
   *)

safe-buffer/index.js:
  (*! safe-buffer. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> *)

tmp/lib/tmp.js:
  (*!
   * Tmp
   *
   * Copyright (c) 2011-2017 KARASZI Istvan <github@spam.raszi.hu>
   *
   * MIT Licensed
   *)

uri-js/dist/es5/uri.all.js:
  (** @license URI.js v4.4.1 (c) 2011 Gary Court. License: http://github.com/garycourt/uri-js *)

is-extglob/index.js:
  (*!
   * is-extglob <https://github.com/jonschlinkert/is-extglob>
   *
   * Copyright (c) 2014-2016, Jon Schlinkert.
   * Licensed under the MIT License.
   *)

is-glob/index.js:
  (*!
   * is-glob <https://github.com/jonschlinkert/is-glob>
   *
   * Copyright (c) 2014-2017, Jon Schlinkert.
   * Released under the MIT License.
   *)

eslint/lib/rules/utils/patterns/letters.js:
  (**
   * @fileoverview Pattern for detecting any letter (even letters outside of ASCII).
   * NOTE: This file was generated using this script in JSCS based on the Unicode 7.0.0 standard: https://github.com/jscs-dev/node-jscs/blob/f5ed14427deb7e7aac84f3056a5aab2d9f3e563e/publish/helpers/generate-patterns.js
   * Do not edit this file by hand-- please use https://github.com/mathiasbynens/regenerate to regenerate the regular expression exported from this file.
   * @author Kevin Partington
   * @license MIT License (from JSCS). See below.
   *)

regexpp/index.js:
  (*! @author Toru Nagashima <https://github.com/mysticatea> *)

eslint-utils/index.js:
  (*! @author Toru Nagashima <https://github.com/mysticatea> *)

natural-compare/index.js:
  (*
   * @version    1.4.0
   * @date       2015-10-26
   * @stability  3 - Stable
   * @author     Lauri Rooden (https://github.com/litejs/natural-compare-lite)
   * @license    MIT License
   *)

imurmurhash/imurmurhash.js:
  (**
   * @preserve
   * JS Implementation of incremental MurmurHash3 (r150) (as of May 10, 2013)
   *
   * @author <a href="mailto:jensyt@gmail.com">Jens Taylor</a>
   * @see http://github.com/homebrewing/brauhaus-diff
   * @author <a href="mailto:gary.court@gmail.com">Gary Court</a>
   * @see http://github.com/garycourt/murmurhash-js
   * @author <a href="mailto:aappleby@gmail.com">Austin Appleby</a>
   * @see http://sites.google.com/site/murmurhash/
   *)

flatted/cjs/index.js:
  (*! (c) 2020 Andrea Giammarchi *)

queue-microtask/index.js:
  (*! queue-microtask. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> *)

run-parallel/index.js:
  (*! run-parallel. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> *)

xlsx/dist/cpexcel.js:
  (*! cpexcel.js (C) 2013-present SheetJS -- http://sheetjs.com *)
  (*! cputils.js (C) 2013-present SheetJS -- http://sheetjs.com *)

xlsx/xlsx.js:
  (*! xlsx.js (C) 2013-present SheetJS -- http://sheetjs.com *)
  (*! sheetjs (C) 2013-present SheetJS -- http://sheetjs.com *)
*/
